(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   7369900,     113713]*)
(*NotebookOutlinePosition[   7371395,     113762]*)
(*  CellTagsIndexPosition[   7371317,     113756]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["Chapter 4. Wavelet Image Processing",
  TextAlignment->Left,
  TextJustification->0,
  FormatType->InputForm,
  FontFamily->"Times New Roman",
  FontSize->24]], "Title",
  TextAlignment->Left,
  TextJustification->0,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4.1 Introduction",
  FormatType->InputForm,
  FontFamily->"Times New Roman"]], "Section",
  FormatType->InputForm],

Cell[TextData[{
  StyleBox["\t",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["This chapter introduces the applications of the wavelet transform \
to the image data. As described in the previous chapters, we have three types \
of image data. The first represents the static monochrome image, the second \
represents the color image and the third is the three-dimensional shadowed \
lighting image. The monochrome image data are housed in the two-dimensional \
arrays. Also, the monochrome three-dimensional shadowed lighting image data \
are housed in the two-dimensional arrays. The color image data are housed in \
the three two-dimensional arrays, which house the red, green and blue color \
components. Similarly, the color three-dimensional shadowed lighting image \
data are housed in the three two-dimensional arrays. Thus, it looks like to \
use the two-dimensional wavelet transform for the image data processing. \
However, consideration of the time depended images, i.e. animation image \
data, leads to use the three-dimensional wavelet transform. The monochrome \
animation image data are essentially housed in the three-dimensional arrays. \
Further, the color animation image data have to be housed by the three \
three-dimensional arrays.\n\tThe first section of this chapter describes \
about the discrete orthogonal wavelet transform, which employ the Daubechies, \
Coifman and Baylkin's base functions. Details of the discrete orthogonal \
wavelet are not described but the n",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" dimensional wavelet transform ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" code is described.\n\tThe second section describes the \
monochrome image data compression and expansion by the wavelet transform. \
This section is an introduction of the wavelet image processing. Also, this \
section demonstrates that Mathematically remarkable image compression rate is \
possible by the wavelet transform.\n\tThe third section concerns with the \
color image compression and recovery. It is revealed that the compression \
rate and recoverability depend on the order of base function.\n\tThe fourth \
section proposes one of the orthogonal color image decomposition. In chapter \
3, we have projected the color image components red, green and blue, to the \
x-, y-, and z-axes in the Cartesian coordinate, respectively. In this \
section, the color image data are represented in the spherical coordinate. \
The magnitude of color image characteristic vector corresponds to a radius. \
The attitude and longitude are represented in terms of their directional \
co-sinusoidal components. In continuation to this section, the fifth section \
describes about the wavelet compression and recovery to the color image data \
represented in terms of the spherical coordinate quantities. The sixth \
section reveals that the color image data compression rate by the wavelet \
transform depends on the way of image data representations. Namely, higher \
recoverability can be achieved by the spherical coordinate representation.\n\t\
The seventh and final sections are concerning with the expansion of a small \
number of color animation data to a large number of ones by the wavelet \
transform. This demonstrates that a three-dimensional wavelet transform makes \
it possible to increase the number of animation data.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(SetDirectory["\<C:\\WINDOWS\\\:ff83\:ff9e\:ff7d\:ff78\:ff84\
\:ff6f\:ff8c\:ff9f\\\:30a6\:30a8\:30fc\:30d6\:30ec\:30c3\:30c8\:5909\:63db\
\:306e\:57fa\:790e\:3068\:5fdc\:7528Rev.12\\n-D_Wavelet_Transform\\\>"];\),
      FontColor->RGBColor[1, 0, 0],
      Background->RGBColor[0, 1, 0]]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["4.2 ",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["Preparation of ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontSlant->"Italic"]
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["4.2.1 ",
    FontFamily->"Times New Roman",
    FontSize->12],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontSlant->"Italic"],
  StyleBox[" utilities and packages",
    FontFamily->"Times New Roman",
    FontSize->12]
}], "Subsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Before to move on the practical image processing, we have to install the \
memory conserve utilities and the warning messages suppressing command for \
the similar variable name. In addition, the \
\[OpenCurlyDoubleQuote]LinearAlgebra`MatrixManipulation\
\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]Graphics`ContourPlot3D\
\[CloseCurlyDoubleQuote] packages have to be installed.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontFamily->"Century",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" utilities and add-on packages",
    FontFamily->"Century",
    FontSize->10.5]
}], "Subsubsection"],

Cell["\<\
<<Utilities`MemoryConserve`
$MemoryIncrement=100000;
Off[General::spell1,General::spell,
\tMemoryConserve::start,MemoryConserve::end];
<< LinearAlgebra`MatrixManipulation`;
<<Graphics`ContourPlot3D`;\
\>", "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["4.2.2 ",
    FontFamily->"Times New Roman",
    FontSize->12],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" functions",
    FontFamily->"Times New Roman",
    FontSize->10.5]
}], "Subsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Here, we define several functions that have been described and used in the \
previous chapters. The functions \[OpenCurlyDoubleQuote]rgbBMP\
\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]convertRGB\
\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]grad2D\
\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]curl2D\
\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]eigen2DVect\
\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]vectorMag2D\
\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]laplace2D\
\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]poissonSOR2D\
\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]imageNormalize\
\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]hueColor\
\[CloseCurlyDoubleQuote] have been defined in the previous chapters, so that \
the comments of such functions are not described. \n\tHowever, the functions \
\[OpenCurlyDoubleQuote]vectorMag3D\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]corRelation\[CloseCurlyDoubleQuote], \"colorImage3D\" \
\[OpenCurlyDoubleQuote]illusion3D\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]momoryUsed\[CloseCurlyDoubleQuote] are newly defined \
in this chapter, so that their comments will be described.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function rgbBMP",
  FontFamily->"Times New Roman",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["   ",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["The function ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "\[OpenCurlyDoubleQuote]convertRGB\[CloseCurlyDoubleQuote] converts the \
numerical data representing color image into a RGB form in order to visualize \
the image on the Mathematica notebook. The parameter \
\[OpenCurlyDoubleQuote]colorData\[CloseCurlyDoubleQuote] refers to a list \
including the numerical values.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    \(\(rgbBMP[colorFile_] := \n\t
        Module[{i = 0, j = 0, k = 0, dim = {0}, 
            input = {{{0. }}}}, \n\t\tlink = 
            Install["\<RGBsplit.exe\>"]; \n\t\tinput = 
            RGBsplit[colorFile]; \n\t\tUninstall[link]; 
          Pause[0.01]; \n\t\tdim = Dimensions[input]; \n\t\tTable[
            input[\([i, j, k]\)], {k, 3}, \n\t\t\t{i, dim[\([1]\)]}, {j, 
              dim[\([2]\)]}]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function convertRGB",
  FontFamily->"Times New Roman",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["   ",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["The function ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "\[OpenCurlyDoubleQuote]convertRGB\[CloseCurlyDoubleQuote] converts the \
numerical data representing color image into a RGB form in order to visualize \
the image on the Mathematica notebook. The parameter \
\[OpenCurlyDoubleQuote]colorData\[CloseCurlyDoubleQuote] refers to a list \
including the numerical values.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    \(\(convertRGB[colorData_] := \n\t
        Module[{i = 0, j = 0, dim = {0}, out}, \n\t\tdim = 
            Dimensions[
              colorData]; \n\t\ \ Graphics[\n\t\t\tRasterArray[\n\t\t\t\t\
Table[RGBColor[colorData[\([1, i, j]\)], \n\t\t\t\t\tcolorData[\([2, i, 
                      j]\)], colorData[\([3, i, j]\)]], \n\t\t\t{i, \ 
                  dim[\([2]\)]}, \ {j, \ dim[\([3]\)]}]]]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function grad2D",
  FontFamily->"Times New Roman",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["   ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["The function ",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["\[OpenCurlyDoubleQuote]grad2D\[CloseCurlyDoubleQuote] compute the \
divergent vectors of a monochrome image. The parameter \
\[OpenCurlyDoubleQuote]data2D\[CloseCurlyDoubleQuote] refers to a \
two-dimensional list including the numerical values as the scalar \
potentials.",
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
grad2D=Compile[{{data2D,_Real,2}},
\tModule[{i=0,j=0,dim={0},c1={{0.}},c2={{0.}},
\t\te2d={{0.}}},
\t\tdim=Dimensions[data2D];
\t\tc1={Table[data2D[[1,j]],{j,dim[[2]]}]};
\t\tc2=Transpose[{Join[{data2D[[1,1]]},
\t\t\tTable[data2D[[i,1]],{i,dim[[1]]}]]}];
\t\te2D=AppendRows[c2,AppendColumns[c1,data2D]];
\tTable[{-0.5(e2D[[i,j]]+e2D[[i+1,j]])+
\t\t\t0.5(e2D[[i,j+1]]+e2D[[i+1,j+1]]),
\t\t\t-0.5(e2D[[i,j]]+e2D[[i,j+1]])+
\t\t\t0.5(e2D[[i+1,j]]+e2D[[i+1,j+1]])},
\t\t\t{i,dim[[1]],1,-1},{j,dim[[2]]}]]];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function curl2D",
  FontFamily->"Times New Roman",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["   ",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["The ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["\[OpenCurlyDoubleQuote]curl2D\[CloseCurlyDoubleQuote] function is \
defined by a following function, where a parameter \
\[OpenCurlyDoubleQuote]darta2D\[CloseCurlyDoubleQuote] refers to a \
two-dimensional list containing one of the vector potential components Both \
of the functions \[OpenCurlyDoubleQuote]grad2D\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]curl2D\[CloseCurlyDoubleQuote] are based on the \
central finite differences.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
curl2D=Compile[{{data2D,_Real,2}},
\tModule[{i=0,j=0,dim={0},c1={{0.}},c2={{0.}},
\t\te2D={{0.}}},
\t\tdim=Dimensions[data2D];
\t\tc1={Table[data2D[[1,j]],{j,dim[[2]]}]};
\t\tc2=Transpose[{Join[{data2D[[1,1]]},
\t\t\tTable[data2D[[i,1]],{i,dim[[1]]}]]}];
\t\te2D=AppendRows[c2,AppendColumns[c1,data2D]];
\tTable[{-0.5(e2D[[i,j]]+e2D[[i,j+1]])+
\t\t0.5(e2D[[i+1,j]]+e2D[[i+1,j+1]]),
\t\t0.5(e2D[[i,j]]+e2D[[i+1,j]])-
\t\t0.5(e2D[[i,j+1]]+e2D[[i+1,j+1]])},
\t{i,dim[[1]],1,-1},{j,dim[[2]]}]]];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function eigen2DVect",
  FontFamily->"Times New Roman",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["   ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["The ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "\[OpenCurlyDoubleQuote]eigen2DVect\[CloseCurlyDoubleQuote] function is \
given by a summation of divergent and rotational vector components. The \
parameter \[OpenCurlyDoubleQuote]monoSample\[CloseCurlyDoubleQuote] is a \
two-dimensional list regarded as either scalar or one component of vector \
potentials.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
eigen2DVect[monoSample_]:=Module[{out},
\tout=-grad2D[monoSample]+curl2D[monoSample];out]\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function vectorMag2D",
  FontFamily->"Times New Roman",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["   The ",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "\[OpenCurlyDoubleQuote]vectorMag2D\[CloseCurlyDoubleQuote] function \
computes the magnitudes of the two-dimensional vectors including a list \
\[OpenCurlyDoubleQuote]vector2D\[CloseCurlyDoubleQuote].",
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
vectorMag2D=Compile[{{vector2D,_Real,3}},
\tModule[{i=0,j=0,dim={0}},
\t\tdim=Dimensions[vector2D];
\t\tSqrt[Table[vector2D[[i,j,1]]^2+vector2D[[i,j,2]]^2,
\t\t\t{i,dim[[1]],1,-1},{j,dim[[2]]}]]]];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function laplace2D",
  FontFamily->"Times New Roman",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["The ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "\[OpenCurlyDoubleQuote]laplace2D\[CloseCurlyDoubleQuote] function carries \
out the Laplacian operation to the input data listed in \
\[OpenCurlyDoubleQuote]data2D\[CloseCurlyDoubleQuote]. This operation is \
based on the 9 points finite difference formula assuming the zero Dirichlet \
boundary condition along an image enclosing line.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
laplace2D=Compile[{{data2D,_Real,2}},
\tModule[{e2D={{0.}},out={{0.}},dim={0},
\t\tmax=0.,i=0,j=0,nx=0,ny=0},
\t\t\tdim=Dimensions[data2D];
\t\t\tny=dim[[1]]+1;nx=dim[[2]]+1;
\t\t\te2D=Table[0.,{ny+1},{nx+1}];
\t\t\tDo[e2D[[i,j]]=data2D[[i-1,j-1]],
\t\t\t\t{i,2,ny},{j,2,nx}];
\t\t\tTable[e2D[[i+1,j-1]]+4.*e2D[[i+1,j]]+
\t\t\t\te2D[[i+1,j+1]]+4.*e2D[[i,j-1]]-
\t\t\t\t20.*e2D[[i,j]]+4.*e2D[[i,j+1]]+
\t\t\t\te2D[[i-1,j-1]]+4.*e2D[[i-1,j]]+
\t\t\t\te2D[[i-1,j+1]],
\t\t\t{i,2,ny},{j,2,nx}]/6.]];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function poissonSOR2D",
  FontFamily->"Times New Roman",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["   ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["The ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "\[OpenCurlyDoubleQuote]poissonSOR2D\[CloseCurlyDoubleQuote] function gives \
an iterative solution of the Poisson's equation. A discretizing strategy used \
in this code is a 9 point finite difference formula, and an over relaxation \
method solves a system of linear equations. In order to get a solution as \
soon as possible, a MathLink utility is employed. A command \
\[OpenCurlyDoubleQuote]Pause\[CloseCurlyDoubleQuote] is essential for \
establishing a reliable linkage between the Mathematica kernel and external \
object.\n   The function \[OpenCurlyDoubleQuote]poissonSOR2D has two \
parameters. One is the source density. Also, the other is a one-dimensional \
list including the desired number of pixels; the first and second integers of \
this list refer to the number of pixels in the directions of x- and y-axes, \
respectively.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["\t",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->10.5]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
poissonSOR2D[source2D_,size_]:= 
\tModule[{i,j,relax = 1.8,link,in,out,dim,
\t\tdx,dy,interP}, 
    dim= Dimensions[source2D];
    dx=(1.*(dim[[2]]-1))/(size[[2]]-1); 
    dy=(1.*(dim[[1]]-1))/(size[[1]]-1);
    interP=ListInterpolation[source2D]; 
    in=Table[interP[i,j],
    \t{i,1,dim[[1]],dy},{j,1,dim[[2]],dx}];
    link = Install[\"Sor04.exe\"];Pause[0.01];
    out=Sor[in,relax];
    Uninstall[link];
    out]; \
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function imageNormalize",
  FontFamily->"Century",
  FontSize->10.5,
  FontWeight->"Bold"]], "Subsubsection"],

Cell[TextData[StyleBox[
"   This function \"imageNormalize\"  converts the two-dimensional image data \
between the values 0 and 1. ",
  FontFamily->"Times New Roman"]], "Text"],

Cell[BoxData[
    \(\(imageNormalize = 
        Compile[{{data2D, _Real, 
              2}}, \n\t\tModule[{minimum = 
                Min[data2D]}, \n\t\t\t\((data2D - minimum)\)/
              Max[data2D - minimum]]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function hueColor",
  FontFamily->"Times New Roman",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["   The ",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "\[OpenCurlyDoubleQuote]hueColor\[CloseCurlyDoubleQuote] function yields a \
customized hue color function. This function gives a color pattern only \
depending on an absolute value of  \[OpenCurlyDoubleQuote]z\
\[CloseCurlyDoubleQuote]. The graphics objects \
\[OpenCurlyDoubleQuote]colorBar10\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]colorBar5\[CloseCurlyDoubleQuote] are the color \
tables.",
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
hueColor[z_]:=Hue[Abs[z],Abs[z],1];
colorBar10=ListDensityPlot[Table[i,{2},{i,0.,1,0.1}],
\tFrame->False,Mesh->False,AspectRatio->0.1,
\tColorFunction->hueColor,DisplayFunction->Identity];
colorBar5=ListDensityPlot[Table[i,{2},{i,0.,1,0.2}],
\tFrame->False,Mesh->False,AspectRatio->0.1,
\tColorFunction->hueColor,DisplayFunction->Identity];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function VectorMag3D",
  FontFamily->"Times New Roman",
  FontSize->11]], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["A ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " function \[OpenCurlyDoubleQuote]vectorMag3D\[CloseCurlyDoubleQuote] \
computes the magnitude of the three-dimensional vectors on a plane surface. A \
parameter \[OpenCurlyDoubleQuote]vectorData3D\[CloseCurlyDoubleQuote] refers \
to the three-dimensional vector data on a two-dimensional plane. This \
function has been introduced in chapter 3.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
vectorMag3D=Compile[{{vectorData3D,_Real,3}},
\tModule[{mag={{0.}},max=0.,min=0.,i=0,j=0,dim={0}},
\t\tdim=Dimensions[vectorData3D];
\t\tmag=Sqrt[Table[vectorData3D[[1,i,j]]^2+
\t\t\tvectorData3D[[2,i,j]]^2+
\t\t\tvectorData3D[[3,i,j]]^2,
\t\t\t{i,dim[[2]]},{j,dim[[3]]}]];
\t\tmin=Min[mag];max=Max[mag-min];
\t\tIf[max=!=0.,Return[(mag-min)/max],
\t\t\tPrint[\"Zero vectors !\"];
\t\tReturn[mag]]]];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function corRelation",
  FontFamily->"Times New Roman",
  FontSize->11]], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["A ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " function \[OpenCurlyDoubleQuote]corRelation\[CloseCurlyDoubleQuote] \
computes a correlation coefficient between the lists \[OpenCurlyDoubleQuote]a\
\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]b\[CloseCurlyDoubleQuote]. The lists \
\[OpenCurlyDoubleQuote]a\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]b\
\[CloseCurlyDoubleQuote] have to contain the real numerical values and the \
same length array. This function has been introduced in chapter 3.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
corRelation=Compile[{{a,_Real,1},{b,_Real,1}},
\tModule[{aa={0.},bb={0.},av=0.,bv=0.},
\tav=Apply[Plus,a]/Length[a]; bv=Apply[Plus,b]/Length[b];
\taa=a-av; bb=b-bv; aa.bb/(Sqrt[aa.aa]*Sqrt[bb.bb])]];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function colorImage3D",
  FontFamily->"Times New Roman",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["A ",
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " function \[OpenCurlyDoubleQuote]colorImage3D\[CloseCurlyDoubleQuote] \
produces the three-dimensional color images. The parameter \
\[OpenCurlyDoubleQuote]color\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]rotation\[CloseCurlyDoubleQuote] of this function are \
the list containing color image data and a integer giving a number of \
lighting angle subdivisions.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell["\<\
colorImage3D[color_,rotation_]:=
\tModule[{view,dim,vector,dummy,sol,i,j,k,p},
\t\tview=Table[{Cos[2.Pi i/rotation],Sin[2.Pi i/rotation]},
\t\t\t{i,0,rotation-1}];
\t\tdim=Dimensions[color];\t\t
\t\tvector=Table[eigen2DVect[color[[i]]],{i,dim[[1]]}];
\t\tdummy=Table[vector[[p,i,j]].view[[k]],
\t\t\t{k,rotation},{p,dim[[1]]},
\t\t\t{i,dim[[2]],1,-1},{j,dim[[3]]}];
\t\tTable[(1-imageNormalize[dummy[[i,j]]])*color[[j]],
\t\t{i,rotation},{j,dim[[1]]}]];\t\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function illusion3D",
  FontFamily->"Times New Roman",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["A ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " function \[OpenCurlyDoubleQuote]illusion3D\[CloseCurlyDoubleQuote] gives \
a set of illusive color image data. This function is based on the functions \
\[OpenCurlyDoubleQuote]eigen2Dvect\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]poissonSOR2D\[CloseCurlyDoubleQuote]. The parameter \
\[OpenCurlyDoubleQuote]color\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]rotation\[CloseCurlyDoubleQuote] are the list \
containing color image data and a integer giving a number of lighting angle \
subdivisions. This function has been introduced in chapter 3.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
illusion3D[color_,rotation_]:=
\tModule[{view,dim,vector,dummy,sol,i,j,k,p},
\t\tview=Table[{Cos[2.Pi i/rotation],Sin[2.Pi i/rotation]},
\t\t\t{i,0,rotation-1}];
\t\tdim=Dimensions[color];\t\t
\t\tvector=Table[eigen2DVect[color[[i]]],{i,dim[[1]]}];
\t\tdummy=Table[vector[[p,i,j]].view[[k]],
\t\t\t{k,rotation},{p,dim[[1]]},
\t\t\t{i,dim[[2]],1,-1},{j,dim[[3]]}];
\t\tsol=Table[poissonSOR2D[-dummy[[i,j]],
\t\t\t{dim[[2]],dim[[3]]}],{i,rotation},{j,dim[[1]]}];
\t\tTable[imageNormalize[sol[[i,j]]],{i,rotation},{j,dim[[1]]}]];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function memoryUsed",
  FontFamily->"Times New Roman",
  FontSize->9]], "Subsubsection"],

Cell[TextData[{
  "\t",
  StyleBox[
  "This function gives the used memories after removing previous \
\[OpenCurlyDoubleQuote]In\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]Out\[CloseCurlyDoubleQuote] objects. This function has \
been introduced in chapter 3.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell["\<\
memoryUsed:=Module[{},
\tUnprotect[In,Out];Clear[In,Out];Protect[In,Out];
\tPrint[Round[N[MemoryInUse[]/1000]],\"K Bytes used\"]];\
\>", "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["4.2.3 ",
    FontFamily->"Times New Roman",
    FontSize->12],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontSlant->"Italic"],
  StyleBox[" functions for the discrete wavelet transform",
    FontFamily->"Times New Roman",
    FontSize->12]
}], "Subsection"],

Cell[TextData[{
  "\t",
  StyleBox["In this ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " notebook includes the discrete orthogonal base function of \
\[OpenCurlyDoubleQuote]Daubechies 2-20",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]Coifman 6-30",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]Baylkin 6",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["-18",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[
  "\[CloseCurlyDoubleQuote]. All of the coefficients are included in the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " notebook, but are not explicitly described in the text. If you desire to \
see such coefficients, open the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica notebook.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Wavelets base functions",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Times New Roman"]], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Daubechies base function", "Text"],

Cell["\<\
daub2={{1.,1.},{1.,-1.}}/Sqrt[2.];

daub4={{1.+Sqrt[3.], 3.+Sqrt[3.],3.-Sqrt[3.], 1.-Sqrt[3.]},
\t{1.-Sqrt[3.],-3.+Sqrt[3.],3.+Sqrt[3.],-1.-Sqrt[3.]}}/
\t(4 Sqrt[2.]);
\t
daub6={{ .332670552950, .806891509311, .459877502118,
\t\t-.135011020010, -.085441273882, .035226291882},
\t   { .035226291882, .085441273882,-.135011020010,
\t    -.459877502118,.806891509311,-.332670552950}};
\t   
daub8={{ 0.325803428051, 1.010945715092, 0.892200138246,
\t    -0.039575026236,-0.264507167369, 0.043616300475,
\t     0.046503601071,-0.014986989330},
\t   {-0.014986989330,-0.046503601071, 0.043616300475,
\t\t 0.264507167369,-0.039575026236,-0.892200138246,
\t\t 1.010945715092,-0.325803428051}}/Sqrt[2.];
\t\t
daub10={{ .160102397974, .603829269797, .724308528438,
\t\t  .138428145901,-.242294887066,-.032244869585,
\t\t  .077571493840,-.006241490213,-.012580751999,
\t\t  .003335725285},
\t    { .003335725285, .012580751999,-.006241490213,
\t     -.077571493840,-.032244869585, .242294887066,
\t      .138428145901,-.724308528438, .603829269797,
\t     -.160102397974}};
\t     
daub12={{ 0.111540743350, 0.494623890398, 0.751133908021,
\t\t  0.315250351709,-0.226264693965,-0.129766867567,
\t\t  0.097501605587, 0.027522865530,-0.031582039318,
\t\t  0.000553842201, 0.004777257511,-0.001077301085},
\t\t{-0.001077301085,-0.004777257511, 0.000553842201,
\t\t  0.031582039318, 0.027522865530,-0.097501605587,
\t\t -0.129766867567, 0.226264693965, 0.315250351709,
\t\t -0.751133908021, 0.494623890398,-0.111540743350}};
\t\t 
daub14={{ .077852054085, .396539319482, .729132090846, 
 \t\t  .469782287405,-.143906003929,-.224036184994,
 \t\t  .071309219267, .080612609151,-.038029936935, 
\t\t -.016574541631, .012550998556, .000429577973, 
\t\t -.001801640704, .000353713800},
\t\t{ .000353713800, .001801640704, .000429577973, 
\t\t -.012550998556,-.016574541631, .038029936935,
\t\t  .080612609151,-.071309219267,-.224036184994,
\t\t  .143906003929, .469782287405,-.729132090846,
\t\t  .396539319482,-.077852054085}};
\t\t  
daub16={{ .054415842243, .312871590914, .675630736297, 
 \t\t  .585354683654,-.015829105256,-.284015542962,
 \t\t  .000472484574, .128747426620,-.017369301002, 
\t\t -.044088253931, .013981027917, .008746094047, 
\t\t -.004870352993,-.000391740373, .000675449406,
\t\t -.000117476784},
\t\t{-.000117476784,-.000675449406,-.000391740373,
\t\t  .004870352993, .008746094047,-.013981027917,
\t\t -.044088253931, .017369301002, .128747426620,
\t\t -.000472484574,-.284015542962, .015829105256,
\t\t  .585354683654,-.675630736297, .312871590914,
\t\t -.054415842243}};
\t\t
daub18={{ .038077947364, .243834674613, .604823123690, 
 \t\t  .657288078051, .133197385825,-.293273783279, 
\t\t -.096840783223, .148540749338, .030725681479,
\t\t -.067632829061, .000250947115, .022361662124,
\t\t -.004723204758,-.004281503682, .001847646883,
          .000230385764,-.000251963189, .000039347320},
        { .000039347320, .000251963189, .000230385764,
         -.001847646883,-.004281503682, .004723204758,
          .022361662124,-.000250947115,-.067632829061,
         -.030725681479, .148540749338, .096840783223,
         -.293273783279,-.133197385825, .657288078051, 
         -.604823123690, .243834674613,-.038077947364}};
        
daub20={{ 0.026670057901, 0.188176800078, 0.527201188932,
\t\t  0.688459039454, 0.281172343661,-0.249846424327,
\t\t -0.195946274377, 0.127369340336, 0.093057364604,
\t\t -0.071394147166,-0.029457536822, 0.033212674059,
\t\t  0.003606553567,-0.010733175483, 0.001395351747,
\t\t  0.001992405295,-0.000685856695,-0.000116466855,
\t\t  0.000093588670,-0.000013264203},
\t\t{-0.000013264203,-0.000093588670,-0.000116466855,
\t\t  0.000685856695, 0.001992405295,-0.001395351747,
\t\t -0.010733175483,-0.003606553567, 0.033212674059,
\t\t  0.029457536822,-0.071394147166,-0.093057364604,
\t\t  0.127369340336, 0.195946274377,-0.249846424327,
\t\t -0.281172343661, 0.688459039454,-0.527201188932,
\t\t  0.188176800078,-0.026670057901}};\
\>", "Input"],

Cell["Coifman's base functions", "Text"],

Cell["\<\
coif6={{-.051429728471, .238929728471, .602859456942, 
 \t\t .272140543058,-.051429972847,-.011070271529},
 \t   {-.011070271529, .051429972847, .272140543058,
\t\t-.602859456942, .238929728471, .051429728471}}*
\t\tSqrt[2.];
\t\t
coif12={{ .011587596739,-.029320137980,-.047639590310, 
 \t\t  .273021046535, .574682393857, .294867193696,
\t\t -.054085607092,-.042026480461, .016744410163, 
 \t\t  .003967883613,-.001289203356,-.000509505399},
 \t\t{-.000509505399, .001289203356, .003967883613,
 \t\t -.016744410163,-.042026480461, .054085607092,
 \t\t  .294867193696,-.574682393857, .273021046535,
\t\t  .047639590310,-.029320137980,-.011587596739}}*
\t\t Sqrt[2.];
\t\t  
coif18={{-.002682418671, .005503126709, .016583560479, 
\t\t -.046507764479,-.043220763560, .286503335274,
 \t\t  .561285256870, .302983571773,-.050770140755, 
\t\t -.058196250762, .024434094321, .011229240962, 
\t\t -.006369601011,-.001820458916, .000790205101,
 \t\t  .000329665174,-.000050192775,-.000024465734},
 \t\t{-.000024465734, .000050192775, .000329665174,
 \t\t -.000790205101,-.001820458916, .006369601011,
 \t\t  .011229240962,-.024434094321,-.058196250762,
 \t\t  .050770140755, .302983571773,-.561285256870,
 \t\t  .286503335274, .043220763560,-.046507764479,
 \t\t -.016583560479, .005503126709, .002682418671}}*
 \t\tSqrt[2.];
 \t\t 
coif24={{ .000630961046,-.001152224852,-.005194524026, 
 \t\t  .011362459244, .018867235378,-.057464234429, 
\t\t -.039652648517, .293667390895, .553126452562, 
 \t\t  .307157326198,-.047112738865,-.068038127051,
 \t\t  .027813640153, .017735837438,-.010756318517,
\t\t -.004001012886, .002652665946, .000895594529,
\t\t -.000416500571,-.000183829769, .000044080354, 
 \t\t  .000022082857,-.000002304942,-.000001262175},
 \t\t{-.000001262175, .000002304942, .000022082857,
 \t\t -.000044080354,-.000183829769, .000416500571,
 \t\t  .000895594529,-.002652665946,-.004001012886,
 \t\t  .010756318517, .017735837438,-.027813640153,
 \t\t -.068038127051, .047112738865, .307157326198,
 \t\t -.553126452562, .293667390895, .039652648517,
 \t\t -.057464234429,-.018867235378, .011362459244,
 \t\t  .005194524026,-.001152224852,-.000630961046}}*
 \t\tSqrt[2.];
 \t\t  
coif30={{-.000149963800, .000253561200, .001540245700, 
\t\t -.002941110800,-.007163781900, .016552066400, 
 \t\t  .019917804300,-.064997262800,-.036800073600,
 \t\t  .298092323500, .547505429400, .309706849000, 
\t\t -.043866050800,-.074652238900, .029195879500, 
 \t\t  .023110777000,-.013973687900,-.006480090000, 
 \t\t  .004783001400, .001720654700,-.001175822200,
\t\t -.000451227000, .000213729800, .000099377600,
\t\t -.000029232100,-.000015072000, .000002640800, 
 \t\t  .000001459300,-.000000118400,-.000000067300},
 \t\t{-.000000067300, .000000118400, .000001459300,
 \t\t -.000002640800,-.000015072000, .000029232100,
 \t\t  .000099377600,-.000213729800,-.000451227000,
 \t\t  .001175822200, .001720654700,-.004783001400,
 \t\t -.006480090000, .013973687900, .023110777000,
 \t\t -.029195879500,-.074652238900, .043866050800,
 \t\t  .309706849000,-.547505429400, .298092323500,
 \t\t  .036800073600,-.064997262800,-.019917804300,
 \t\t  .016552066400, .007163781900,-.002941110800,
 \t\t -.001540245700, .000253561200, .000149963800}}*
 \t\tSqrt[2.];\
\>", "Input"],

Cell["Baylkin's base function", "Text"],

Cell["\<\
bay6={{ .038580777748,-.126969125396,-.077161555496, 
 \t\t.607491641386, .745687558934, .226584265197},
 \t  { .226584265197,-.745687558934, .607491641386,
 \t    .077161555496,-.126969125396,-.038580777748}};
 \t    
bay12={{ .001194572696,-.012845579553, .024804330519, 
 \t\t .050023519962,-.155357222860,-.071638282295, 
 \t\t .570465001450, .750336305853, .280611651902,
\t\t-.007410383519,-.014611552521,-.001358799059},
\t   {-.001358799059, .014611552521,-.007410383519,
\t    -.280611651902, .750336305853,-.570465001450,
\t    -.071638282295, .155357222860, .050023519962,
\t    -.024804330519,-.012845579553,-.001194572696}};
\t    
bay18={{-.001691851019,-.003487876220, .019191160680, 
 \t\t .021671094636,-.098507213321,-.056997424478, 
 \t\t .456787122173, .789319409004, .380557130852,
\t\t-.070438748795,-.056514193868, .036409962613,
 \t\t .008760130709,-.011194759274,-.001921335414,
 \t\t .002041380977, .000445830398,-.000216257277},
 \t   {-.000216257277,-.000445830398, .002041380977,
 \t     .001921335414,-.011194759274,-.008760130709,
 \t     .036409962613, .056514193868,-.070438748795,
 \t    -.380557130852, .789319409004,-.456787122173,
 \t    -.056997424478, .098507213321, .021671094636,
 \t    -.019191160680,-.003487876220, .001691851019}};\
\>", "Input"],

Cell["C matrix", "Text"],

Cell["\<\
c[n_,baseType_]:=Module[{mat,i,result},
\tresult=mat=AppendRows[baseType,
\t\tZeroMatrix[2,n-Length[baseType[[1]]]]];
       \trotateRightofList[a_List]:=RotateRight/@ a;
        rotateRight[b_List,k_]:=
        Nest[rotateRightofList,b,k];
        Do[result=
        \tAppendColumns[result,rotateRight[mat,2 i]],
            {i,n/2-1}];
\tresult];\
\>", "Input"],

Cell["C' matrix", "Text"],

Cell["\<\
cPrime[i_,n_,baseType_]:=BlockMatrix[{{c[n/2^i,baseType],
\tZeroMatrix[n/2^i,n-n/2^i]},{ZeroMatrix[n-n/2^i,n/2^i],
\tIdentityMatrix[n-n/2^i]}}]\
\>", "Input"],

Cell["p and p' matrices", "Text"],

Cell["\<\
p[n_]:=Module[{mat,i},mat=IdentityMatrix[n];
\tDo[mat[[i]]=RotateRight[mat[[i]],i-1],{i,2,n}];
    Do[mat[[i]]=RotateRight[mat[[i]]],{i,n/2+1,n}];
    mat];

pPrime[i_,n_,baseType_]:=BlockMatrix[{{p[n/2^i],
\tZeroMatrix[n/2^i,n-n/2^i]},{ZeroMatrix[n-n/2^i,n/2^i],
  \tIdentityMatrix[n-n/2^i]}}];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Wavelets transform matrix",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Times New Roman"]], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "\tThis function gives a wavelet transform matrix with order \
\[OpenCurlyDoubleQuote]n\[CloseCurlyDoubleQuote] by \[OpenCurlyDoubleQuote]n\
\[CloseCurlyDoubleQuote] using a base function \
\[OpenCurlyDoubleQuote]baseType\[CloseCurlyDoubleQuote]. The parameter \
\[OpenCurlyDoubleQuote]n\[CloseCurlyDoubleQuote] must be the integer and the \
power of 2. For example, a 4 by 4 wavelet transform matrix using the \
Daubechies 2",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["nd",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[
  " order base function is obtained by \
\[OpenCurlyDoubleQuote]waveletMatrix[4,daub4]\[CloseCurlyDoubleQuote].",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
waveletMatrix[n_,baseType_]:=
\tApply[Dot,Flatten[Table[{pPrime[j,n,baseType],
\t\tcPrime[j,n,baseType]},{j,Log[2,n]-
\t\tCeiling[Log[2.,Length[baseType[[2]]]]],1,-1}],
\t\t1]].p[n].c[n,baseType];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Wavelets transform function",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Times New Roman"]], "Subsubsection"],

Cell[TextData[{
  "\t",
  StyleBox[
  "This function carries out the wavelet and inverse wavelet transforms to a \
\[OpenCurlyDoubleQuote]n\[CloseCurlyDoubleQuote]-th dimensional \
\[OpenCurlyDoubleQuote]data\[CloseCurlyDoubleQuote] using a transform matrix \
\[OpenCurlyDoubleQuote]wMat\[CloseCurlyDoubleQuote]. For example, if we wish \
to carry out a wavelet transform to a three-dimensional 32 by 32 by 32 array \
\[OpenCurlyDoubleQuote]data\[CloseCurlyDoubleQuote] using the base functions \
\[OpenCurlyDoubleQuote]daub2\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]daub4\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]daub8\[CloseCurlyDoubleQuote], then a waveletpectrum \
\[OpenCurlyDoubleQuote]wSpect\[CloseCurlyDoubleQuote] is obtained by the \
following steps.\n1) Create the transform matrices by\n",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox[
  "wMat={waveletMatrix[32,daub2],waveletMatrix[32,daub4],waveletMatrix[32,\
daub8]};\n",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["2) Carry out a wavelet transform by\n",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["wSpect=waveletND[data,wMat,3];\n\t",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[
  "If we wish to carry out an inverse wavelet transform to the waveletpectrum \
\[OpenCurlyDoubleQuote]wSpect\[CloseCurlyDoubleQuote], then it is carried out \
by the following steps.\n1) Transpose the transform matrices by\n",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["wMatTrans={Transpose[waveletMatrix[32,daub2]],",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["\n",
    TextAlignment->Left,
    TextJustification->1,
    FontWeight->"Bold"],
  StyleBox["\t\t",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[
  "Transpose[waveletMatrix[32,daub4]],Transpose[waveletMatrix[32,daub8]]};",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["\n",
    TextAlignment->Left,
    TextJustification->1],
  StyleBox["2) Carry out an inverse transform by\n",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["recover=waveletND[data,wMatTrans,3];",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    \(\(waveletND[data_, \ wMat_, n_] := \n\ \ Block[{s, ww}, \ 
          s = Join[{n}, Table[i, {i, n - 1}]]; \n\ \ \ \ \ \ \ ww = 
            Transpose[wMat[\([1]\)] . data, \ s\ ]\ ; \n\t\t\ \ Do[
            ww = Transpose[wMat[\([i]\)] . ww, \ s\ ], {i, 2, n}]\ ; 
          ww\ \ ];\)\)], "Input"],

Cell[TextData[{
  "\t",
  StyleBox[
  "A practical example of the wavelet transform is given bellow. Figure 1 \
shows an example three-dimensional data \"data3D\".",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
data3D = Table[x^2+2*y^2+3*z^2,{z,-.875,.875,.25},
\t{y,-.875,.875,.25},{x,-.875,.875,.25}];\
\>", "Input",
  CellTags->"S5.34.1"],

Cell[CellGroupData[{

Cell["\<\
ListContourPlot3D[data3D,PlotLabel->\"Fig.1. Example of 3D data\",
 \tMeshRange -> {{-.875,.875}, {-.875,.875}, {-.875,.875}},
    Contours -> {1.5, 3.},Lighting -> False, Axes -> True,
    ContourStyle -> {{RGBColor[0,1,0]},{RGBColor[1,0,0]}},
    ImageSize->{200,200}];\
\>", "Input",
  CellTags->"S5.34.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 200 200 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.5 1.098 -77 0 ]
[.5 1.098 77 12.5625 ]
[.2003 .18358 -22.7644 -9 ]
[.2003 .18358 1.2356 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.51877 .04916 -15.276 -9 ]
[.51877 .04916 2.72399 0 ]
[.10564 .8938 -13.4798 0 ]
[.10564 .8938 10.5202 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.32269 1.04596 -9.5143 0 ]
[.32269 1.04596 8.4857 9 ]
[.05748 .36099 -24 -2.70532 ]
[.05748 .36099 0 6.29468 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.00936 .66224 -18 -2.97637 ]
[.00936 .66224 0 6.02363 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.098 -138 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.813 moveto
(.1) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Example) show
153.000 12.813 moveto
(of) show
171.000 12.813 moveto
(3) show
177.000 12.813 moveto
(D) show
189.000 12.813 moveto
(data) show
213.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.21003 .19443 m
.2149 .19986 L
s
[(-0.5)] .2003 .18358 .89703 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.52711 .06111 m
.53128 .06709 L
s
[(0.5)] .51877 .04916 .69733 1 Mshowa
.125 Mabswid
.23999 .18184 m
.24287 .18512 L
s
.27032 .16909 m
.27316 .17241 L
s
.30102 .15618 m
.30383 .15953 L
s
.33211 .14311 m
.33487 .14649 L
s
.39546 .11647 m
.39814 .11992 L
s
.42774 .10289 m
.43038 .10638 L
s
.46044 .08915 m
.46304 .09266 L
s
.49356 .07522 m
.49611 .07877 L
s
.18044 .20688 m
.18339 .2101 L
s
.1512 .21917 m
.15419 .22236 L
s
.12231 .23132 m
.12534 .23448 L
s
.09377 .24332 m
.09683 .24645 L
s
.56109 .04682 m
.56355 .05044 L
s
.59553 .03235 m
.59793 .036 L
s
.63042 .01768 m
.63277 .02136 L
s
.66577 .00281 m
.66807 .00653 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.10743 .87934 m
.10832 .8721 L
s
[(-0.5)] .10564 .8938 .12332 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.32352 1.03141 m
.32393 1.02413 L
s
[(0.5)] .32269 1.04596 .05714 -1 Mshowa
.125 Mabswid
.13144 .89624 m
.13194 .89189 L
s
.15486 .91272 m
.15533 .90837 L
s
.17772 .92881 m
.17816 .92446 L
s
.20004 .94451 m
.20045 .94016 L
s
.24311 .97483 m
.24347 .97047 L
s
.26391 .98946 m
.26423 .9851 L
s
.28423 1.00376 m
.28453 .9994 L
s
.30409 1.01774 m
.30437 1.01338 L
s
.08281 .86201 m
.08338 .85768 L
s
.05756 .84424 m
.05816 .83991 L
s
.03165 .82601 m
.03229 .82169 L
s
.00506 .8073 m
.00574 .80298 L
s
.34252 1.04478 m
.34274 1.04041 L
s
.3611 1.05786 m
.3613 1.05349 L
s
.37928 1.07065 m
.37946 1.06628 L
s
.39708 1.08318 m
.39724 1.07881 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.07102 .35559 m
.07779 .35289 L
s
[(-0.5)] .05748 .36099 1 -0.39882 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02316 .65756 m
.03007 .65523 L
s
[(0.5)] .00936 .66224 1 -0.33859 Mshowa
.125 Mabswid
.06665 .38318 m
.07072 .38158 L
s
.06219 .4113 m
.06627 .40972 L
s
.05765 .43998 m
.06173 .43842 L
s
.05301 .46922 m
.0571 .46768 L
s
.04346 .52947 m
.04757 .52797 L
s
.03854 .56051 m
.04266 .55904 L
s
.03352 .5922 m
.03765 .59075 L
s
.0284 .62454 m
.03253 .62311 L
s
.07531 .32853 m
.07936 .32689 L
s
.07952 .30196 m
.08356 .30031 L
s
.08365 .27589 m
.08769 .27422 L
s
.0877 .2503 m
.09174 .24861 L
s
.01782 .69129 m
.02197 .68991 L
s
.01236 .72574 m
.01652 .72439 L
s
.00678 .76094 m
.01095 .75961 L
s
.00108 .79691 m
.00526 .79561 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48113 .61679 m .4857 .62944 L .4188 .6815 L p 0 1 0 r
F P
0 g
s
.4188 .6815 m .39579 .61841 L .48113 .61679 L p 0 1 0 r
F P
0 g
s
.44853 .54567 m .48113 .61679 L .39579 .61841 L p 0 1 0 r
F P
0 g
s
.39579 .61841 m .38157 .58813 L .44853 .54567 L p 0 1 0 r
F P
0 g
s
.4857 .62944 m .51087 .61374 L .48113 .61679 L closepath p 0 1 0 r
F P
0 g
s
.51087 .61374 m .48113 .61679 L .44853 .54567 L p 0 1 0 r
F P
0 g
s
.51633 .50946 m .55313 .59172 L .51087 .61374 L p 0 1 0 r
F P
0 g
s
.44853 .54567 m .51633 .50946 L p .51087 .61374 L 0 1 0 r
F P
0 g
s
.44853 .54567 m .38157 .58813 L .34225 .5198 L p 0 1 0 r
F P
0 g
s
.6219 .56291 m .55313 .59172 L .51633 .50946 L p 0 1 0 r
F P
0 g
s
.49993 .47884 m .51633 .50946 L .44853 .54567 L p 0 1 0 r
F P
0 g
s
.44853 .54567 m .41244 .48065 L .49993 .47884 L p 0 1 0 r
F P
0 g
s
.41244 .48065 m .44853 .54567 L p .34225 .5198 L 0 1 0 r
F P
0 g
s
.51633 .50946 m .58545 .47943 L .6219 .56291 L p 0 1 0 r
F P
0 g
s
.57857 .46613 m .58545 .47943 L .51633 .50946 L p 0 1 0 r
F P
0 g
s
.51633 .50946 m .49993 .47884 L .57857 .46613 L p 0 1 0 r
F P
0 g
s
.69257 .54042 m .6219 .56291 L .58545 .47943 L p 0 1 0 r
F P
0 g
s
.34225 .5198 m .40432 .4799 L .41244 .48065 L p 0 1 0 r
F P
0 g
s
.40432 .4799 m .34225 .5198 L .30068 .46298 L p 0 1 0 r
F P
0 g
s
.30068 .46298 m .31781 .45183 L .40432 .4799 L p 0 1 0 r
F P
0 g
s
.58545 .47943 m .65641 .45557 L .69257 .54042 L p 0 1 0 r
F P
0 g
s
.64965 .44201 m .65641 .45557 L .58545 .47943 L p 0 1 0 r
F P
0 g
s
.58545 .47943 m .57857 .46613 L .64965 .44201 L p 0 1 0 r
F P
0 g
s
.76571 .52436 m .69257 .54042 L .65641 .45557 L p 0 1 0 r
F P
0 g
s
.31781 .45183 m .30068 .46298 L .25613 .41757 L p 0 1 0 r
F P
0 g
s
.25613 .41757 m .27362 .40607 L .31781 .45183 L p 0 1 0 r
F P
0 g
s
.65641 .45557 m .72979 .43796 L .76571 .52436 L p 0 1 0 r
F P
0 g
s
.7142 .40558 m .72979 .43796 L .65641 .45557 L p 0 1 0 r
F P
0 g
s
.65641 .45557 m .64965 .44201 L .7142 .40558 L p 0 1 0 r
F P
0 g
s
.44556 .66277 m .47199 .63814 L .43844 .63877 L closepath p 1 0 0 r
F P
0 g
s
.47199 .63814 m .43844 .63877 L .40636 .56982 L p 1 0 0 r
F P
0 g
s
.43844 .63877 m .44556 .66277 L .39196 .72899 L p 1 0 0 r
F P
0 g
s
.3384 .63034 m .43844 .63877 L p .39196 .72899 L 1 0 0 r
F P
0 g
s
.40636 .56982 m .43844 .63877 L .3384 .63034 L p 1 0 0 r
F P
0 g
s
.47199 .63814 m .52398 .63288 L p .45946 .72779 L 1 0 0 r
F P
0 g
s
.45946 .72779 m .44556 .66277 L .47199 .63814 L p 1 0 0 r
F P
0 g
s
.52398 .63288 m .516 .61069 L .47199 .63814 L closepath p 1 0 0 r
F P
0 g
s
.47712 .52494 m .516 .61069 L .47199 .63814 L p 1 0 0 r
F P
0 g
s
.40636 .56982 m .47712 .52494 L p .47199 .63814 L 1 0 0 r
F P
0 g
s
.45946 .72779 m .44556 .66277 L .39196 .72899 L closepath p 1 0 0 r
F P
0 g
s
.81303 .5185 m .76571 .52436 L .72979 .43796 L p 0 1 0 r
F P
0 g
s
.54327 .71978 m .52398 .63288 L .60178 .61753 L p 1 0 0 r
F P
0 g
s
.58738 .57715 m .60178 .61753 L .52398 .63288 L p 1 0 0 r
F P
0 g
s
.52398 .63288 m .516 .61069 L .58738 .57715 L p 1 0 0 r
F P
0 g
s
.52398 .63288 m .54327 .71978 L .45946 .72779 L p 1 0 0 r
F P
0 g
s
.58738 .57715 m .516 .61069 L .47712 .52494 L p 1 0 0 r
F P
0 g
s
.39196 .72899 m .36684 .727 L .3384 .63034 L p 1 0 0 r
F P
0 g
s
.3384 .63034 m .33587 .62505 L .40636 .56982 L p 1 0 0 r
F P
0 g
s
.40636 .56982 m .33587 .62505 L .29326 .5611 L p 1 0 0 r
F P
0 g
s
.39196 .72899 m .45946 .72779 L .45802 .79735 L p 1 0 0 r
F P
0 g
s
.45802 .79735 m .38908 .79852 L .39196 .72899 L p 1 0 0 r
F P
0 g
s
.36684 .727 m .39196 .72899 L .38908 .79852 L p 1 0 0 r
F P
0 g
s
.45802 .79735 m .45946 .72779 L .54327 .71978 L p 1 0 0 r
F P
0 g
s
.38908 .79852 m .36342 .79658 L .36684 .727 L p 1 0 0 r
F P
0 g
s
.47712 .52494 m .40636 .56982 L .36491 .50464 L p 1 0 0 r
F P
0 g
s
.29326 .5611 m .36491 .50464 L .40636 .56982 L p 1 0 0 r
F P
0 g
s
.72979 .43796 m .80623 .4268 L p .81303 .5185 L 0 1 0 r
F P
0 g
s
.7731 .35533 m .80623 .4268 L .72979 .43796 L p 0 1 0 r
F P
0 g
s
.72979 .43796 m .7142 .40558 L .7731 .35533 L p 0 1 0 r
F P
0 g
s
.54364 .78954 m .54327 .71978 L .62192 .70513 L p 1 0 0 r
F P
0 g
s
.60178 .61753 m .62192 .70513 L .54327 .71978 L p 1 0 0 r
F P
0 g
s
.54327 .71978 m .54364 .78954 L .45802 .79735 L p 1 0 0 r
F P
0 g
s
.84223 .51761 m .81303 .5185 L .83753 .50402 L closepath p 0 1 0 r
F P
0 g
s
.80623 .4268 m .83753 .50402 L .81303 .5185 L p 0 1 0 r
F P
0 g
s
.62192 .70513 m .60178 .61753 L .6752 .59485 L p 1 0 0 r
F P
0 g
s
.66071 .55386 m .6752 .59485 L .60178 .61753 L p 1 0 0 r
F P
0 g
s
.60178 .61753 m .58738 .57715 L .66071 .55386 L p 1 0 0 r
F P
0 g
s
.62496 .47094 m .66071 .55386 L .58738 .57715 L p 1 0 0 r
F P
0 g
s
.58738 .57715 m .55134 .49563 L .62496 .47094 L p 1 0 0 r
F P
0 g
s
.55134 .49563 m .58738 .57715 L p .47712 .52494 L 1 0 0 r
F P
0 g
s
.47712 .52494 m .53082 .4989 L .55134 .49563 L p 1 0 0 r
F P
0 g
s
.47712 .52494 m .53082 .4989 L .46214 .5003 L closepath p 1 0 0 r
F P
0 g
s
.46214 .5003 m .47712 .52494 L p .36491 .50464 L 1 0 0 r
F P
0 g
s
.27362 .40607 m .25613 .41757 L .20772 .38383 L p 0 1 0 r
F P
0 g
s
.20772 .38383 m .27384 .33989 L .27362 .40607 L p 0 1 0 r
F P
0 g
s
.89989 .45638 m .92382 .52617 L .84223 .51761 L p 0 1 0 r
F P
0 g
s
.84223 .51761 m .83753 .50402 L .89989 .45638 L p 0 1 0 r
F P
0 g
s
.88646 .42236 m .89989 .45638 L .83753 .50402 L p 0 1 0 r
F P
0 g
s
.83753 .50402 m .80623 .4268 L .88646 .42236 L p 0 1 0 r
F P
0 g
s
.624 .77526 m .62192 .70513 L .69625 .68348 L p 1 0 0 r
F P
0 g
s
.6752 .59485 m .69625 .68348 L .62192 .70513 L p 1 0 0 r
F P
0 g
s
.62192 .70513 m .624 .77526 L .54364 .78954 L p 1 0 0 r
F P
0 g
s
.53082 .4989 m .46214 .5003 L .43657 .46293 L p 1 0 0 r
F P
0 g
s
.36491 .50464 m .39172 .4874 L .46214 .5003 L p 1 0 0 r
F P
0 g
s
.46214 .5003 m .43657 .46293 L .39172 .4874 L closepath p 1 0 0 r
F P
0 g
s
.55134 .49563 m .54892 .49103 L .53082 .4989 L closepath p 1 0 0 r
F P
0 g
s
.50939 .43034 m .54892 .49103 L .53082 .4989 L p 1 0 0 r
F P
0 g
s
.43657 .46293 m .50939 .43034 L p .53082 .4989 L 1 0 0 r
F P
0 g
s
.36491 .50464 m .29326 .5611 L .247 .51674 L p 1 0 0 r
F P
0 g
s
.62258 .46625 m .62496 .47094 L .55134 .49563 L p 1 0 0 r
F P
0 g
s
.55134 .49563 m .54892 .49103 L .62258 .46625 L p 1 0 0 r
F P
0 g
s
.62258 .46625 m .54892 .49103 L .50939 .43034 L p 1 0 0 r
F P
0 g
s
.69625 .68348 m .6752 .59485 L .74501 .56421 L p 1 0 0 r
F P
0 g
s
.73688 .541 m .74501 .56421 L .6752 .59485 L p 1 0 0 r
F P
0 g
s
.6752 .59485 m .66071 .55386 L .73688 .541 L p 1 0 0 r
F P
0 g
s
.44112 .83769 m .38908 .79852 L .45802 .79735 L closepath p 1 0 0 r
F P
0 g
s
.38908 .79852 m .44112 .83769 L p .3258 .84147 L 1 0 0 r
F P
0 g
s
.3258 .84147 m .36342 .79658 L .38908 .79852 L p 1 0 0 r
F P
0 g
s
.39172 .4874 m .36491 .50464 L .3204 .45864 L p 1 0 0 r
F P
0 g
s
.247 .51674 m .3204 .45864 L .36491 .50464 L p 1 0 0 r
F P
0 g
s
.38138 .9645 m .41017 .9385 L .48147 .95776 L p 0 1 0 r
F P
0 g
s
.45802 .79735 m .54364 .78954 L .52383 .84382 L p 1 0 0 r
F P
0 g
s
.44112 .83769 m .45802 .79735 L p .52383 .84382 L 1 0 0 r
F P
0 g
s
.69893 .45074 m .73688 .541 L .66071 .55386 L p 1 0 0 r
F P
0 g
s
.64139 .46174 m .69893 .45074 L p .66071 .55386 L 1 0 0 r
F P
0 g
s
.66071 .55386 m .62496 .47094 L .64139 .46174 L p 1 0 0 r
F P
0 g
s
.3204 .45864 m .3478 .44083 L .39172 .4874 L p 1 0 0 r
F P
0 g
s
.39359 .41544 m .3478 .44083 L .39172 .4874 L p 1 0 0 r
F P
0 g
s
.39172 .4874 m .43657 .46293 L .39359 .41544 L p 1 0 0 r
F P
0 g
s
.85167 .3443 m .88646 .42236 L .80623 .4268 L p 0 1 0 r
F P
0 g
s
.77746 .34998 m .85167 .3443 L p .80623 .4268 L 0 1 0 r
F P
0 g
s
.80623 .4268 m .7731 .35533 L .77746 .34998 L p 0 1 0 r
F P
0 g
s
.52383 .84382 m .54364 .78954 L .624 .77526 L p 1 0 0 r
F P
0 g
s
.7 .75413 m .69625 .68348 L .76707 .65423 L p 1 0 0 r
F P
0 g
s
.74501 .56421 m .76707 .65423 L .69625 .68348 L p 1 0 0 r
F P
0 g
s
.69625 .68348 m .7 .75413 L .624 .77526 L p 1 0 0 r
F P
0 g
s
.50939 .43034 m .43657 .46293 L .39359 .41544 L p 1 0 0 r
F P
0 g
s
.62496 .47094 m .62258 .46625 L .64139 .46174 L closepath p 1 0 0 r
F P
0 g
s
.64139 .46174 m .62258 .46625 L .58408 .40415 L p 1 0 0 r
F P
0 g
s
.50939 .43034 m .58408 .40415 L .62258 .46625 L p 1 0 0 r
F P
0 g
s
.60688 .82958 m .624 .77526 L .7 .75413 L p 1 0 0 r
F P
0 g
s
.624 .77526 m .60688 .82958 L .52383 .84382 L p 1 0 0 r
F P
0 g
s
.69893 .45074 m .64139 .46174 L .68491 .4245 L closepath p 1 0 0 r
F P
0 g
s
.66129 .38445 m .68491 .4245 L .64139 .46174 L p 1 0 0 r
F P
0 g
s
.58408 .40415 m .66129 .38445 L p .64139 .46174 L 1 0 0 r
F P
0 g
s
.76707 .65423 m .74501 .56421 L .78648 .53976 L p 1 0 0 r
F P
0 g
s
.74501 .56421 m .73688 .541 L .78648 .53976 L closepath p 1 0 0 r
F P
0 g
s
.78648 .53976 m .73688 .541 L .69893 .45074 L p 1 0 0 r
F P
0 g
s
.58408 .40415 m .50939 .43034 L .46784 .38139 L p 1 0 0 r
F P
0 g
s
.39359 .41544 m .46784 .38139 L .50939 .43034 L p 1 0 0 r
F P
0 g
s
.27384 .33989 m .20772 .38383 L .15433 .36235 L p 0 1 0 r
F P
0 g
s
.77746 .34998 m .85167 .3443 L .81715 .27766 L p 0 1 0 r
F P
0 g
s
.81715 .27766 m .79636 .27964 L .77746 .34998 L p 0 1 0 r
F P
0 g
s
.3204 .45864 m .247 .51674 L .19577 .49257 L p 1 0 0 r
F P
0 g
s
.50916 .96042 m .47614 .96308 L .48147 .95776 L closepath p 0 1 0 r
F P
0 g
s
.48147 .95776 m .47614 .96308 L .38138 .9645 L p 0 1 0 r
F P
0 g
s
.3478 .44083 m .3204 .45864 L .27155 .43236 L p 1 0 0 r
F P
0 g
s
.19577 .49257 m .27155 .43236 L .3204 .45864 L p 1 0 0 r
F P
0 g
s
.27681 .33446 m .27384 .33989 L p .15433 .36235 L 0 1 0 r
F P
0 g
s
.52383 .84382 m .46837 .8487 L .44112 .83769 L p 1 0 0 r
F P
0 g
s
.46837 .8487 m .43258 .84929 L .44112 .83769 L closepath p 1 0 0 r
F P
0 g
s
.44112 .83769 m .43258 .84929 L .3258 .84147 L p 1 0 0 r
F P
0 g
s
.77249 .72558 m .76707 .65423 L .83514 .61655 L p 1 0 0 r
F P
0 g
s
.81771 .54755 m .83514 .61655 L .76707 .65423 L p 1 0 0 r
F P
0 g
s
.78648 .53976 m .81771 .54755 L p .76707 .65423 L 1 0 0 r
F P
0 g
s
.76707 .65423 m .77249 .72558 L .7 .75413 L p 1 0 0 r
F P
0 g
s
.36503 .39356 m .3478 .44083 L p .27155 .43236 L 1 0 0 r
F P
0 g
s
.3478 .44083 m .36503 .39356 L .39359 .41544 L closepath p 1 0 0 r
F P
0 g
s
.22882 .31244 m .27681 .33446 L .32564 .2802 L p 0 1 0 r
F P
0 g
s
.15433 .36235 m .22882 .31244 L .27681 .33446 L p 0 1 0 r
F P
0 g
s
.68542 .80849 m .7 .75413 L .77249 .72558 L p 1 0 0 r
F P
0 g
s
.7 .75413 m .68542 .80849 L .60688 .82958 L p 1 0 0 r
F P
0 g
s
.36372 .97107 m .38138 .9645 L .47614 .96308 L p 0 1 0 r
F P
0 g
s
.69893 .45074 m .77906 .44671 L p .78648 .53976 L 1 0 0 r
F P
0 g
s
.74195 .37419 m .77906 .44671 L .69893 .45074 L p 1 0 0 r
F P
0 g
s
.7112 .37636 m .74195 .37419 L p .69893 .45074 L 1 0 0 r
F P
0 g
s
.69893 .45074 m .68491 .4245 L .7112 .37636 L p 1 0 0 r
F P
0 g
s
.43753 .97871 m .47614 .96308 L .50916 .96042 L p 0 1 0 r
F P
0 g
s
.47614 .96308 m .43753 .97871 L .36372 .97107 L p 0 1 0 r
F P
0 g
s
.81771 .54755 m .78648 .53976 L .80987 .52186 L closepath p 1 0 0 r
F P
0 g
s
.77906 .44671 m .80987 .52186 L .78648 .53976 L p 1 0 0 r
F P
0 g
s
.50916 .96042 m .5563 .95952 L p .43753 .97871 L 0 1 0 r
F P
0 g
s
.66129 .38445 m .58408 .40415 L .54396 .35376 L p 1 0 0 r
F P
0 g
s
.46784 .38139 m .54396 .35376 L .58408 .40415 L p 1 0 0 r
F P
0 g
s
.36503 .39356 m .39359 .41544 L .46784 .38139 L p 1 0 0 r
F P
0 g
s
.39509 .85987 m .43258 .84929 L .46837 .8487 L p 1 0 0 r
F P
0 g
s
.43258 .84929 m .39509 .85987 L .32271 .84224 L p 1 0 0 r
F P
0 g
s
.32271 .84224 m .3258 .84147 L .43258 .84929 L p 1 0 0 r
F P
0 g
s
.5152 .8517 m .46837 .8487 L .52383 .84382 L closepath p 1 0 0 r
F P
0 g
s
.46837 .8487 m .5152 .8517 L p .39509 .85987 L 1 0 0 r
F P
0 g
s
.68491 .4245 m .66129 .38445 L .7112 .37636 L closepath p 1 0 0 r
F P
0 g
s
.5152 .8517 m .52383 .84382 L .60688 .82958 L p 1 0 0 r
F P
0 g
s
.80987 .52186 m .86653 .45991 L p .88432 .58136 L 1 0 0 r
F P
0 g
s
.88432 .58136 m .81771 .54755 L .80987 .52186 L p 1 0 0 r
F P
0 g
s
.86414 .45392 m .86653 .45991 L .80987 .52186 L p 1 0 0 r
F P
0 g
s
.80987 .52186 m .77906 .44671 L .86414 .45392 L p 1 0 0 r
F P
0 g
s
.83514 .61655 m .81771 .54755 L .88432 .58136 L closepath p 1 0 0 r
F P
0 g
s
.63389 .94924 m .5563 .95952 L .51479 .97758 L p 0 1 0 r
F P
0 g
s
.5563 .95952 m .51479 .97758 L .43753 .97871 L p 0 1 0 r
F P
0 g
s
.39509 .85987 m .32271 .84224 L .27297 .82909 L p 1 0 0 r
F P
0 g
s
.36372 .97107 m .43753 .97871 L .39349 .9794 L p 0 1 0 r
F P
0 g
s
.31488 .9715 m .36372 .97107 L p .39349 .9794 L 0 1 0 r
F P
0 g
s
.54396 .35376 m .46784 .38139 L .42347 .3444 L p 1 0 0 r
F P
0 g
s
.46784 .38139 m .42347 .3444 L p .36503 .39356 L 1 0 0 r
F P
0 g
s
.84225 .68875 m .77249 .72558 L .76032 .77994 L p 1 0 0 r
F P
0 g
s
.83514 .61655 m .84225 .68875 L .77249 .72558 L p 1 0 0 r
F P
0 g
s
.77249 .72558 m .76032 .77994 L .68542 .80849 L p 1 0 0 r
F P
0 g
s
.88432 .58136 m .83514 .61655 L .84225 .68875 L p 1 0 0 r
F P
0 g
s
.59264 .84375 m .60688 .82958 L .68542 .80849 L p 1 0 0 r
F P
0 g
s
.60688 .82958 m .59264 .84375 L .5152 .8517 L p 1 0 0 r
F P
0 g
s
.5152 .8517 m .59264 .84375 L .55434 .85623 L p 1 0 0 r
F P
0 g
s
.47162 .86514 m .5152 .8517 L p .55434 .85623 L 1 0 0 r
F P
0 g
s
.5152 .8517 m .47162 .86514 L .39509 .85987 L p 1 0 0 r
F P
0 g
s
.7112 .37636 m .66129 .38445 L .62261 .33262 L p 1 0 0 r
F P
0 g
s
.54396 .35376 m .62261 .33262 L .66129 .38445 L p 1 0 0 r
F P
0 g
s
.86414 .45392 m .77906 .44671 L .74195 .37419 L p 1 0 0 r
F P
0 g
s
.34717 .38278 m .40426 .35339 L .36503 .39356 L closepath p 1 0 0 r
F P
0 g
s
.42347 .3444 m .40426 .35339 L .36503 .39356 L p 1 0 0 r
F P
0 g
s
.27155 .43236 m .34717 .38278 L .36503 .39356 L p 1 0 0 r
F P
0 g
s
.13251 .35939 m .15433 .36235 L .22882 .31244 L p 0 1 0 r
F P
0 g
s
.1923 .49243 m .19577 .49257 L .27155 .43236 L p 1 0 0 r
F P
0 g
s
.30384 .26892 m .32564 .2802 L .38897 .23686 L p 0 1 0 r
F P
0 g
s
.32564 .2802 m .30384 .26892 L .22882 .31244 L p 0 1 0 r
F P
0 g
s
.79636 .27964 m .81715 .27766 L .78239 .22219 L p 0 1 0 r
F P
0 g
s
.78239 .22219 m .76121 .22454 L .79636 .27964 L p 0 1 0 r
F P
0 g
s
.22739 .4283 m .1923 .49243 L .14458 .52642 L p 1 0 0 r
F P
0 g
s
.27155 .43236 m .22739 .4283 L .1923 .49243 L p 1 0 0 r
F P
0 g
s
.22739 .4283 m .27155 .43236 L .34717 .38278 L p 1 0 0 r
F P
0 g
s
.54396 .35376 m .62261 .33262 L .59756 .30799 L p 1 0 0 r
F P
0 g
s
.50145 .31528 m .54396 .35376 L p .59756 .30799 L 1 0 0 r
F P
0 g
s
.42347 .3444 m .50145 .31528 L .54396 .35376 L p 1 0 0 r
F P
0 g
s
.71374 .9297 m .63389 .94924 L .59507 .96717 L p 0 1 0 r
F P
0 g
s
.51479 .97758 m .59507 .96717 L .63389 .94924 L p 0 1 0 r
F P
0 g
s
.7112 .37636 m .74195 .37419 L .70473 .32095 L p 1 0 0 r
F P
0 g
s
.70473 .32095 m .67343 .32365 L .7112 .37636 L p 1 0 0 r
F P
0 g
s
.62261 .33262 m .67343 .32365 L .7112 .37636 L p 1 0 0 r
F P
0 g
s
.1793 .30339 m .22882 .31244 L .30384 .26892 L p 0 1 0 r
F P
0 g
s
.22882 .31244 m .1793 .30339 L .13251 .35939 L p 0 1 0 r
F P
0 g
s
.67247 .82247 m .68542 .80849 L .76032 .77994 L p 1 0 0 r
F P
0 g
s
.68542 .80849 m .67247 .82247 L .59264 .84375 L p 1 0 0 r
F P
0 g
s
.40426 .35339 m .34717 .38278 L .29533 .37549 L p 1 0 0 r
F P
0 g
s
.34717 .38278 m .29533 .37549 L p .22739 .4283 L 1 0 0 r
F P
0 g
s
.39349 .9794 m .43753 .97871 L .51479 .97758 L p 0 1 0 r
F P
0 g
s
.55434 .85623 m .59264 .84375 L .67247 .82247 L p 1 0 0 r
F P
0 g
s
.84225 .68875 m .89275 .65434 L .88432 .58136 L p 1 0 0 r
F P
0 g
s
.89919 .56637 m .88432 .58136 L .89275 .65434 L p 1 0 0 r
F P
0 g
s
.86653 .45991 m .89919 .56637 L .88432 .58136 L p 1 0 0 r
F P
0 g
s
.39509 .85987 m .47162 .86514 L .45448 .86038 L p 1 0 0 r
F P
0 g
s
.34663 .847 m .39509 .85987 L p .45448 .86038 L 1 0 0 r
F P
0 g
s
.27297 .82909 m .34663 .847 L .39509 .85987 L p 1 0 0 r
F P
0 g
s
.74195 .37419 m .82776 .37958 L .86414 .45392 L p 1 0 0 r
F P
0 g
s
.82776 .37958 m .74195 .37419 L .70473 .32095 L p 1 0 0 r
F P
0 g
s
.0924 .36847 m .13251 .35939 L .1793 .30339 L p 0 1 0 r
F P
0 g
s
.83497 .72911 m .89275 .65434 L .84225 .68875 L closepath p 1 0 0 r
F P
0 g
s
.83497 .72911 m .84225 .68875 L p .76032 .77994 L 1 0 0 r
F P
0 g
s
.38897 .23686 m .37997 .23165 L .30384 .26892 L p 0 1 0 r
F P
0 g
s
.37997 .23165 m .30384 .26892 L .24971 .25646 L p 0 1 0 r
F P
0 g
s
.30384 .26892 m .24971 .25646 L p .1793 .30339 L 0 1 0 r
F P
0 g
s
.42056 .34293 m .40426 .35339 L p .29533 .37549 L 1 0 0 r
F P
0 g
s
.40426 .35339 m .42056 .34293 L .42347 .3444 L closepath p 1 0 0 r
F P
0 g
s
.79532 .90064 m .71374 .9297 L .67792 .94703 L p 0 1 0 r
F P
0 g
s
.59507 .96717 m .67792 .94703 L .71374 .9297 L p 0 1 0 r
F P
0 g
s
.67343 .32365 m .59756 .30799 L .62261 .33262 L closepath p 1 0 0 r
F P
0 g
s
.42056 .34293 m .42347 .3444 L .50145 .31528 L p 1 0 0 r
F P
0 g
s
.37997 .23165 m .38897 .23686 L .46644 .20609 L p 0 1 0 r
F P
0 g
s
.89275 .65434 m .90805 .63966 L .89919 .56637 L p 1 0 0 r
F P
0 g
s
.34663 .847 m .27297 .82909 L .22199 .78844 L p 1 0 0 r
F P
0 g
s
.3745 .33433 m .42056 .34293 L .49869 .31371 L p 1 0 0 r
F P
0 g
s
.50145 .31528 m .49869 .31371 L .42056 .34293 L p 1 0 0 r
F P
0 g
s
.29533 .37549 m .3745 .33433 L .42056 .34293 L p 1 0 0 r
F P
0 g
s
.39349 .9794 m .38401 .97877 L .31488 .9715 L p 0 1 0 r
F P
0 g
s
.38401 .97877 m .31488 .9715 L .26356 .9533 L p 0 1 0 r
F P
0 g
s
.76032 .77994 m .75385 .78749 L .67247 .82247 L p 1 0 0 r
F P
0 g
s
.67247 .82247 m .63695 .83424 L .55434 .85623 L p 1 0 0 r
F P
0 g
s
.63695 .83424 m .67247 .82247 L .75385 .78749 L p 1 0 0 r
F P
0 g
s
.76121 .22454 m .78239 .22219 L .74679 .17797 L p 0 1 0 r
F P
0 g
s
.74679 .17797 m .66848 .1877 L .76121 .22454 L p 0 1 0 r
F P
0 g
s
.75385 .78749 m .80498 .75711 L .76032 .77994 L closepath p 1 0 0 r
F P
0 g
s
.76032 .77994 m .80498 .75711 L .83497 .72911 L p 1 0 0 r
F P
0 g
s
.46644 .20609 m .45786 .20058 L .37997 .23165 L p 0 1 0 r
F P
0 g
s
.45786 .20058 m .37997 .23165 L .32859 .21733 L p 0 1 0 r
F P
0 g
s
.24971 .25646 m .32859 .21733 L .37997 .23165 L p 0 1 0 r
F P
0 g
s
.51479 .97758 m .49553 .97789 L .39349 .9794 L p 0 1 0 r
F P
0 g
s
.49553 .97789 m .51479 .97758 L .59507 .96717 L p 0 1 0 r
F P
0 g
s
.84684 .87654 m .79532 .90064 L .76276 .91688 L p 0 1 0 r
F P
0 g
s
.67792 .94703 m .76276 .91688 L .79532 .90064 L p 0 1 0 r
F P
0 g
s
.67343 .32365 m .70473 .32095 L p .58207 .29552 L 1 0 0 r
F P
0 g
s
.58207 .29552 m .59756 .30799 L .67343 .32365 L p 1 0 0 r
F P
0 g
s
.59756 .30799 m .52132 .30971 L .50145 .31528 L p 1 0 0 r
F P
0 g
s
.52132 .30971 m .49869 .31371 L .50145 .31528 L closepath p 1 0 0 r
F P
0 g
s
.45786 .20058 m .46644 .20609 L .55703 .18913 L p 0 1 0 r
F P
0 g
s
.55434 .85623 m .53136 .85914 L .47162 .86514 L p 1 0 0 r
F P
0 g
s
.53136 .85914 m .45448 .86038 L .47162 .86514 L closepath p 1 0 0 r
F P
0 g
s
.89275 .65434 m .90805 .63966 L p .83026 .74037 L 1 0 0 r
F P
0 g
s
.83026 .74037 m .83497 .72911 L .89275 .65434 L p 1 0 0 r
F P
0 g
s
.21582 .4361 m .24608 .40798 L .22739 .4283 L closepath p 1 0 0 r
F P
0 g
s
.29533 .37549 m .24608 .40798 L .22739 .4283 L p 1 0 0 r
F P
0 g
s
.21582 .4361 m .22739 .4283 L p .14458 .52642 L 1 0 0 r
F P
0 g
s
.87458 .86369 m .84684 .87654 L p .76276 .91688 L 0 1 0 r
F P
0 g
s
.84684 .87654 m .87458 .86369 L .87772 .8586 L closepath p 0 1 0 r
F P
0 g
s
.80498 .75711 m .75385 .78749 L .71916 .79862 L p 1 0 0 r
F P
0 g
s
.75385 .78749 m .71916 .79862 L p .63695 .83424 L 1 0 0 r
F P
0 g
s
.45526 .30371 m .49869 .31371 L .52132 .30971 L p 1 0 0 r
F P
0 g
s
.49869 .31371 m .45526 .30371 L .3745 .33433 L p 1 0 0 r
F P
0 g
s
.58207 .29552 m .52132 .30971 L .59756 .30799 L closepath p 1 0 0 r
F P
0 g
s
.52132 .30971 m .58207 .29552 L p .45526 .30371 L 1 0 0 r
F P
0 g
s
.70473 .32095 m .792 .32501 L .82776 .37958 L p 1 0 0 r
F P
0 g
s
.87458 .86369 m .87772 .8586 L .9592 .7971 L p 0 1 0 r
F P
0 g
s
.792 .32501 m .70473 .32095 L .66646 .28738 L p 1 0 0 r
F P
0 g
s
.70473 .32095 m .66646 .28738 L .58207 .29552 L p 1 0 0 r
F P
0 g
s
.80498 .75711 m .83026 .74037 L .83497 .72911 L closepath p 1 0 0 r
F P
0 g
s
.83026 .74037 m .80498 .75711 L p .71916 .79862 L 1 0 0 r
F P
0 g
s
.55703 .18913 m .53822 .17574 L .45786 .20058 L p 0 1 0 r
F P
0 g
s
.53822 .17574 m .45786 .20058 L .40926 .18459 L p 0 1 0 r
F P
0 g
s
.32859 .21733 m .40926 .18459 L .45786 .20058 L p 0 1 0 r
F P
0 g
s
.17155 .30485 m .20089 .28506 L .1793 .30339 L closepath p 0 1 0 r
F P
0 g
s
.24971 .25646 m .20089 .28506 L .1793 .30339 L p 0 1 0 r
F P
0 g
s
.1793 .30339 m .17155 .30485 L .0924 .36847 L p 0 1 0 r
F P
0 g
s
.53822 .17574 m .55703 .18913 L .65914 .18668 L p 0 1 0 r
F P
0 g
s
.9592 .7971 m .94573 .82123 L .87458 .86369 L p 0 1 0 r
F P
0 g
s
.66848 .1877 m .74679 .17797 L p .62185 .15728 L 0 1 0 r
F P
0 g
s
.62185 .15728 m .65914 .18668 L .66848 .1877 L p 0 1 0 r
F P
0 g
s
.65914 .18668 m .62185 .15728 L .53822 .17574 L p 0 1 0 r
F P
0 g
s
.14458 .52642 m .15307 .51042 L .21582 .4361 L p 1 0 0 r
F P
0 g
s
.15307 .51042 m .14458 .52642 L .13529 .60052 L p 1 0 0 r
F P
0 g
s
.90805 .63966 m .89193 .68222 L .83026 .74037 L p 1 0 0 r
F P
0 g
s
.26356 .9533 m .28246 .95521 L .38401 .97877 L p 0 1 0 r
F P
0 g
s
.59507 .96717 m .58735 .96722 L .49553 .97789 L p 0 1 0 r
F P
0 g
s
.76276 .91688 m .84899 .87654 L .87458 .86369 L p 0 1 0 r
F P
0 g
s
.84899 .87654 m .87458 .86369 L .94573 .82123 L p 0 1 0 r
F P
0 g
s
.58735 .96722 m .59507 .96717 L .67792 .94703 L p 0 1 0 r
F P
0 g
s
.24608 .40798 m .28353 .37875 L .29533 .37549 L closepath p 1 0 0 r
F P
0 g
s
.24608 .40798 m .28353 .37875 L p .18984 .47045 L 1 0 0 r
F P
0 g
s
.18984 .47045 m .21582 .4361 L .24608 .40798 L p 1 0 0 r
F P
0 g
s
.15307 .51042 m .18984 .47045 L .21582 .4361 L closepath p 1 0 0 r
F P
0 g
s
.45448 .86038 m .37553 .84891 L .34663 .847 L p 1 0 0 r
F P
0 g
s
.37553 .84891 m .34663 .847 L .29638 .80573 L p 1 0 0 r
F P
0 g
s
.22199 .78844 m .29638 .80573 L .34663 .847 L p 1 0 0 r
F P
0 g
s
.42503 .84645 m .45448 .86038 L .53136 .85914 L p 1 0 0 r
F P
0 g
s
.42503 .84645 m .37553 .84891 L .45448 .86038 L closepath p 1 0 0 r
F P
0 g
s
.29638 .80573 m .22199 .78844 L .17092 .71887 L p 1 0 0 r
F P
0 g
s
.55166 .85598 m .53136 .85914 L .55434 .85623 L closepath p 1 0 0 r
F P
0 g
s
.53136 .85914 m .55166 .85598 L p .42503 .84645 L 1 0 0 r
F P
0 g
s
.55166 .85598 m .55434 .85623 L .63695 .83424 L p 1 0 0 r
F P
0 g
s
.28353 .37875 m .29533 .37549 L .3745 .33433 L p 1 0 0 r
F P
0 g
s
.80473 .7477 m .83026 .74037 L .89193 .68222 L p 1 0 0 r
F P
0 g
s
.71916 .79862 m .80473 .7477 L .83026 .74037 L p 1 0 0 r
F P
0 g
s
.13529 .60052 m .1439 .58483 L .15307 .51042 L p 1 0 0 r
F P
0 g
s
.18984 .47045 m .15307 .51042 L .1439 .58483 L p 1 0 0 r
F P
0 g
s
.58207 .29552 m .66646 .28738 L .63392 .27738 L p 1 0 0 r
F P
0 g
s
.5387 .28379 m .58207 .29552 L p .63392 .27738 L 1 0 0 r
F P
0 g
s
.58207 .29552 m .5387 .28379 L .45526 .30371 L p 1 0 0 r
F P
0 g
s
.67792 .94703 m .67069 .94694 L .58735 .96722 L p 0 1 0 r
F P
0 g
s
.63695 .83424 m .63444 .83393 L .55166 .85598 L p 1 0 0 r
F P
0 g
s
.63444 .83393 m .55166 .85598 L .50707 .83311 L p 1 0 0 r
F P
0 g
s
.55166 .85598 m .50707 .83311 L .42503 .84645 L p 1 0 0 r
F P
0 g
s
.37553 .84891 m .42503 .84645 L .37599 .80422 L p 1 0 0 r
F P
0 g
s
.37599 .80422 m .32569 .80732 L .37553 .84891 L p 1 0 0 r
F P
0 g
s
.29638 .80573 m .32569 .80732 L .37553 .84891 L p 1 0 0 r
F P
0 g
s
.28246 .95521 m .26356 .9533 L .21036 .91479 L p 0 1 0 r
F P
0 g
s
.53822 .17574 m .62185 .15728 L .58469 .14096 L p 0 1 0 r
F P
0 g
s
.49248 .15826 m .53822 .17574 L p .58469 .14096 L 0 1 0 r
F P
0 g
s
.40926 .18459 m .49248 .15826 L .53822 .17574 L p 0 1 0 r
F P
0 g
s
.67069 .94694 m .67792 .94703 L .76276 .91688 L p 0 1 0 r
F P
0 g
s
.3745 .33433 m .35443 .33948 L .28353 .37875 L p 1 0 0 r
F P
0 g
s
.25069 .42345 m .28353 .37875 L .35443 .33948 L p 1 0 0 r
F P
0 g
s
.28353 .37875 m .25069 .42345 L .18984 .47045 L p 1 0 0 r
F P
0 g
s
.21036 .91479 m .2295 .91652 L .28246 .95521 L p 0 1 0 r
F P
0 g
s
.35443 .33948 m .3745 .33433 L .45526 .30371 L p 1 0 0 r
F P
0 g
s
.74679 .17797 m .70967 .14546 L .62185 .15728 L p 0 1 0 r
F P
0 g
s
.63444 .83393 m .65546 .82603 L .63695 .83424 L closepath p 1 0 0 r
F P
0 g
s
.71916 .79862 m .65546 .82603 L .63695 .83424 L p 1 0 0 r
F P
0 g
s
.66646 .28738 m .75601 .29063 L .792 .32501 L p 1 0 0 r
F P
0 g
s
.16784 .71278 m .13529 .60052 L .1439 .58483 L p 1 0 0 r
F P
0 g
s
.76276 .91688 m .74702 .9161 L .67069 .94694 L p 0 1 0 r
F P
0 g
s
.65546 .82603 m .63444 .83393 L .5921 .80989 L p 1 0 0 r
F P
0 g
s
.50707 .83311 m .5921 .80989 L .63444 .83393 L p 1 0 0 r
F P
0 g
s
.50707 .83311 m .42503 .84645 L .37599 .80422 L p 1 0 0 r
F P
0 g
s
.17092 .71887 m .24546 .73453 L .29638 .80573 L p 1 0 0 r
F P
0 g
s
.20465 .65244 m .24546 .73453 L .17092 .71887 L p 1 0 0 r
F P
0 g
s
.17092 .71887 m .16784 .71278 L .20465 .65244 L p 1 0 0 r
F P
0 g
s
.19615 .62326 m .20465 .65244 L .16784 .71278 L p 1 0 0 r
F P
0 g
s
.1439 .58483 m .19615 .62326 L p .16784 .71278 L 1 0 0 r
F P
0 g
s
.70475 .79267 m .65546 .82603 L p .5921 .80989 L 1 0 0 r
F P
0 g
s
.65546 .82603 m .70475 .79267 L .71916 .79862 L closepath p 1 0 0 r
F P
0 g
s
.74702 .9161 m .76276 .91688 L .84899 .87654 L p 0 1 0 r
F P
0 g
s
.18137 .54561 m .18984 .47045 L .25069 .42345 L p 1 0 0 r
F P
0 g
s
.1439 .58483 m .18137 .54561 L .18984 .47045 L p 1 0 0 r
F P
0 g
s
.94573 .82123 m .93592 .82605 L .84899 .87654 L p 0 1 0 r
F P
0 g
s
.32569 .80732 m .29638 .80573 L .24546 .73453 L p 1 0 0 r
F P
0 g
s
.63392 .27738 m .66646 .28738 L .75601 .29063 L p 1 0 0 r
F P
0 g
s
.19615 .62326 m .1439 .58483 L .18137 .54561 L closepath p 1 0 0 r
F P
0 g
s
.45526 .30371 m .43654 .30832 L .35443 .33948 L p 1 0 0 r
F P
0 g
s
.43654 .30832 m .45526 .30371 L .5387 .28379 L p 1 0 0 r
F P
0 g
s
.58469 .14096 m .62185 .15728 L .70967 .14546 L p 0 1 0 r
F P
0 g
s
.70475 .79267 m .71916 .79862 L .80473 .7477 L p 1 0 0 r
F P
0 g
s
.3238 .38354 m .35443 .33948 L .43654 .30832 L p 1 0 0 r
F P
0 g
s
.35443 .33948 m .3238 .38354 L .25069 .42345 L p 1 0 0 r
F P
0 g
s
.8176 .87324 m .84899 .87654 L .93592 .82605 L p 0 1 0 r
F P
0 g
s
.84899 .87654 m .8176 .87324 L .74702 .9161 L p 0 1 0 r
F P
0 g
s
.37599 .80422 m .32569 .80732 L .34446 .76483 L closepath p 1 0 0 r
F P
0 g
s
.32529 .73712 m .34446 .76483 L .32569 .80732 L p 1 0 0 r
F P
0 g
s
.24546 .73453 m .32529 .73712 L p .32569 .80732 L 1 0 0 r
F P
0 g
s
.2295 .91652 m .21036 .91479 L .156 .85477 L p 0 1 0 r
F P
0 g
s
.5921 .80989 m .50707 .83311 L .45961 .78964 L p 1 0 0 r
F P
0 g
s
.37599 .80422 m .45961 .78964 L .50707 .83311 L p 1 0 0 r
F P
0 g
s
.89193 .68222 m .89014 .68262 L .80473 .7477 L p 1 0 0 r
F P
0 g
s
.89014 .68262 m .80473 .7477 L .76843 .72931 L p 1 0 0 r
F P
0 g
s
.80473 .7477 m .76843 .72931 L p .70475 .79267 L 1 0 0 r
F P
0 g
s
.156 .85477 m .22788 .85998 L .2295 .91652 L p 0 1 0 r
F P
0 g
s
.76843 .72931 m .8571 .66155 L .89014 .68262 L p 1 0 0 r
F P
0 g
s
.93592 .82605 m .90579 .82032 L p .8176 .87324 L 0 1 0 r
F P
0 g
s
.67952 .7765 m .73503 .74931 L .70475 .79267 L closepath p 1 0 0 r
F P
0 g
s
.76843 .72931 m .73503 .74931 L .70475 .79267 L p 1 0 0 r
F P
0 g
s
.5921 .80989 m .67952 .7765 L .70475 .79267 L p 1 0 0 r
F P
0 g
s
.27475 .63326 m .32529 .73712 L .24546 .73453 L p 1 0 0 r
F P
0 g
s
.2245 .63325 m .27475 .63326 L p .24546 .73453 L 1 0 0 r
F P
0 g
s
.24546 .73453 m .20465 .65244 L .2245 .63325 L p 1 0 0 r
F P
0 g
s
.40981 .72439 m .45961 .78964 L .37599 .80422 L p 1 0 0 r
F P
0 g
s
.38831 .7285 m .40981 .72439 L p .37599 .80422 L 1 0 0 r
F P
0 g
s
.37599 .80422 m .34446 .76483 L .38831 .7285 L p 1 0 0 r
F P
0 g
s
.63392 .27738 m .59278 .27832 L .5387 .28379 L p 1 0 0 r
F P
0 g
s
.59278 .27832 m .52915 .28614 L .5387 .28379 L closepath p 1 0 0 r
F P
0 g
s
.5387 .28379 m .52915 .28614 L .43654 .30832 L p 1 0 0 r
F P
0 g
s
.40882 .35182 m .43654 .30832 L .52915 .28614 L p 1 0 0 r
F P
0 g
s
.43654 .30832 m .40882 .35182 L .3238 .38354 L p 1 0 0 r
F P
0 g
s
.18137 .54561 m .24357 .49944 L p .2245 .63325 L 1 0 0 r
F P
0 g
s
.2245 .63325 m .19615 .62326 L .18137 .54561 L p 1 0 0 r
F P
0 g
s
.25069 .42345 m .24357 .49944 L .18137 .54561 L p 1 0 0 r
F P
0 g
s
.24357 .49944 m .25069 .42345 L .3238 .38354 L p 1 0 0 r
F P
0 g
s
.67952 .7765 m .5921 .80989 L .54648 .76496 L p 1 0 0 r
F P
0 g
s
.45961 .78964 m .54648 .76496 L .5921 .80989 L p 1 0 0 r
F P
0 g
s
.70967 .14546 m .69531 .13825 L .58469 .14096 L p 0 1 0 r
F P
0 g
s
.75601 .29063 m .75378 .28987 L .63392 .27738 L p 1 0 0 r
F P
0 g
s
.58469 .14096 m .54618 .14603 L .49248 .15826 L p 0 1 0 r
F P
0 g
s
.20465 .65244 m .19615 .62326 L .2245 .63325 L closepath p 1 0 0 r
F P
0 g
s
.63392 .27738 m .75378 .28987 L .72871 .31772 L p 1 0 0 r
F P
0 g
s
.22788 .85998 m .156 .85477 L .10133 .77264 L p 0 1 0 r
F P
0 g
s
.50502 .32922 m .52915 .28614 L .59278 .27832 L p 1 0 0 r
F P
0 g
s
.52915 .28614 m .50502 .32922 L .40882 .35182 L p 1 0 0 r
F P
0 g
s
.34446 .76483 m .32529 .73712 L .38831 .7285 L closepath p 1 0 0 r
F P
0 g
s
.62638 .28398 m .59278 .27832 L .63392 .27738 L closepath p 1 0 0 r
F P
0 g
s
.59278 .27832 m .62638 .28398 L p .50502 .32922 L 1 0 0 r
F P
0 g
s
.62638 .28398 m .63392 .27738 L p .72871 .31772 L 1 0 0 r
F P
0 g
s
.73503 .74931 m .67952 .7765 L .63603 .72988 L p 1 0 0 r
F P
0 g
s
.54648 .76496 m .63603 .72988 L .67952 .7765 L p 1 0 0 r
F P
0 g
s
.54648 .76496 m .45961 .78964 L .40981 .72439 L p 1 0 0 r
F P
0 g
s
.57918 .14138 m .54618 .14603 L .58469 .14096 L closepath p 0 1 0 r
F P
0 g
s
.27475 .63326 m .2245 .63325 L .26452 .60558 L closepath p 1 0 0 r
F P
0 g
s
.24357 .49944 m .26452 .60558 L .2245 .63325 L p 1 0 0 r
F P
0 g
s
.57918 .14138 m .58469 .14096 L .69531 .13825 L p 0 1 0 r
F P
0 g
s
.38831 .7285 m .32529 .73712 L .27475 .63326 L p 1 0 0 r
F P
0 g
s
.69531 .13825 m .67098 .14032 L .57918 .14138 L p 0 1 0 r
F P
0 g
s
.31845 .46018 m .3238 .38354 L .40882 .35182 L p 1 0 0 r
F P
0 g
s
.3238 .38354 m .31845 .46018 L .24357 .49944 L p 1 0 0 r
F P
0 g
s
.90579 .82032 m .82289 .86865 L .8176 .87324 L p 0 1 0 r
F P
0 g
s
.63603 .72988 m .69299 .70148 L .73503 .74931 L p 1 0 0 r
F P
0 g
s
.72734 .68069 m .69299 .70148 L .73503 .74931 L p 1 0 0 r
F P
0 g
s
.73503 .74931 m .76843 .72931 L .72734 .68069 L p 1 0 0 r
F P
0 g
s
.72871 .31772 m .69734 .3145 L .62638 .28398 L p 1 0 0 r
F P
0 g
s
.69734 .3145 m .61127 .31644 L .62638 .28398 L closepath p 1 0 0 r
F P
0 g
s
.62638 .28398 m .61127 .31644 L .50502 .32922 L p 1 0 0 r
F P
0 g
s
.26452 .60558 m .24357 .49944 L .31845 .46018 L p 1 0 0 r
F P
0 g
s
.87089 .79406 m .84735 .80788 L .82289 .86865 L p 0 1 0 r
F P
0 g
s
.82289 .86865 m .90579 .82032 L .87089 .79406 L p 0 1 0 r
F P
0 g
s
.8571 .66155 m .76843 .72931 L .72734 .68069 L p 1 0 0 r
F P
0 g
s
.10133 .77264 m .18006 .77631 L p .22788 .85998 L 0 1 0 r
F P
0 g
s
.1326 .68301 m .18006 .77631 L .10133 .77264 L p 0 1 0 r
F P
0 g
s
.10133 .77264 m .08124 .73394 L .1326 .68301 L p 0 1 0 r
F P
0 g
s
.72734 .68069 m .81869 .61056 L .8571 .66155 L p 1 0 0 r
F P
0 g
s
.18006 .77631 m .23124 .85531 L .22788 .85998 L p 0 1 0 r
F P
0 g
s
.12617 .66592 m .1326 .68301 L .08124 .73394 L p 0 1 0 r
F P
0 g
s
.08124 .73394 m .04989 .65119 L .12617 .66592 L p 0 1 0 r
F P
0 g
s
.63603 .72988 m .54648 .76496 L .4981 .69793 L p 1 0 0 r
F P
0 g
s
.40981 .72439 m .4981 .69793 L .54648 .76496 L p 1 0 0 r
F P
0 g
s
.27475 .63326 m .35933 .61929 L p .38831 .7285 L 1 0 0 r
F P
0 g
s
.34067 .56832 m .35933 .61929 L .27475 .63326 L p 1 0 0 r
F P
0 g
s
.27475 .63326 m .26452 .60558 L .34067 .56832 L p 1 0 0 r
F P
0 g
s
.26381 .7702 m .28775 .80836 L .23124 .85531 L p 0 1 0 r
F P
0 g
s
.23124 .85531 m .18006 .77631 L .26381 .7702 L p 0 1 0 r
F P
0 g
s
.31845 .46018 m .34067 .56832 L .26452 .60558 L p 1 0 0 r
F P
0 g
s
.40981 .72439 m .38831 .7285 L .40666 .71901 L closepath p 1 0 0 r
F P
0 g
s
.35933 .61929 m .40666 .71901 L .38831 .7285 L p 1 0 0 r
F P
0 g
s
.40566 .42895 m .40882 .35182 L .50502 .32922 L p 1 0 0 r
F P
0 g
s
.40882 .35182 m .40566 .42895 L .31845 .46018 L p 1 0 0 r
F P
0 g
s
.495 .69243 m .4981 .69793 L .40981 .72439 L p 1 0 0 r
F P
0 g
s
.40981 .72439 m .40666 .71901 L .495 .69243 L p 1 0 0 r
F P
0 g
s
.44803 .59059 m .495 .69243 L .40666 .71901 L p 1 0 0 r
F P
0 g
s
.40666 .71901 m .35933 .61929 L .44803 .59059 L p 1 0 0 r
F P
0 g
s
.63603 .72988 m .69299 .70148 L .60712 .68721 L closepath p 1 0 0 r
F P
0 g
s
.60712 .68721 m .63603 .72988 L p .4981 .69793 L 1 0 0 r
F P
0 g
s
.34067 .56832 m .31845 .46018 L .40566 .42895 L p 1 0 0 r
F P
0 g
s
.50444 .40668 m .50502 .32922 L .61127 .31644 L p 1 0 0 r
F P
0 g
s
.50502 .32922 m .50444 .40668 L .40566 .42895 L p 1 0 0 r
F P
0 g
s
.2094 .66072 m .26381 .7702 L .18006 .77631 L p 0 1 0 r
F P
0 g
s
.15663 .66625 m .2094 .66072 L p .18006 .77631 L 0 1 0 r
F P
0 g
s
.18006 .77631 m .1326 .68301 L .15663 .66625 L p 0 1 0 r
F P
0 g
s
.6821 .60021 m .72734 .68069 L .69299 .70148 L p 1 0 0 r
F P
0 g
s
.58924 .65735 m .6821 .60021 L p .69299 .70148 L 1 0 0 r
F P
0 g
s
.69299 .70148 m .60712 .68721 L .58924 .65735 L p 1 0 0 r
F P
0 g
s
.69734 .3145 m .72871 .31772 L .73425 .39534 L p 1 0 0 r
F P
0 g
s
.42922 .53866 m .44803 .59059 L .35933 .61929 L p 1 0 0 r
F P
0 g
s
.35933 .61929 m .34067 .56832 L .42922 .53866 L p 1 0 0 r
F P
0 g
s
.61127 .31644 m .69734 .3145 L .70203 .39216 L p 1 0 0 r
F P
0 g
s
.70203 .39216 m .6136 .39407 L .61127 .31644 L p 1 0 0 r
F P
0 g
s
.61127 .31644 m .6136 .39407 L .50444 .40668 L p 1 0 0 r
F P
0 g
s
.81869 .61056 m .72734 .68069 L .6821 .60021 L p 1 0 0 r
F P
0 g
s
.73425 .39534 m .70203 .39216 L .69734 .3145 L p 1 0 0 r
F P
0 g
s
.40566 .42895 m .42922 .53866 L .34067 .56832 L p 1 0 0 r
F P
0 g
s
.4981 .69793 m .52065 .68878 L .60712 .68721 L p 1 0 0 r
F P
0 g
s
.4981 .69793 m .52065 .68878 L .495 .69243 L closepath p 1 0 0 r
F P
0 g
s
.52065 .68878 m .495 .69243 L .44803 .59059 L p 1 0 0 r
F P
0 g
s
.6821 .60021 m .77543 .52809 L .81869 .61056 L p 1 0 0 r
F P
0 g
s
.60712 .68721 m .58924 .65735 L .52065 .68878 L closepath p 1 0 0 r
F P
0 g
s
.53986 .54676 m .58924 .65735 L .52065 .68878 L p 1 0 0 r
F P
0 g
s
.44803 .59059 m .53986 .54676 L p .52065 .68878 L 1 0 0 r
F P
0 g
s
.42922 .53866 m .40566 .42895 L .50444 .40668 L p 1 0 0 r
F P
0 g
s
.1326 .68301 m .12617 .66592 L .15663 .66625 L closepath p 0 1 0 r
F P
0 g
s
.35218 .75367 m .36236 .77051 L .28775 .80836 L p 0 1 0 r
F P
0 g
s
.28775 .80836 m .26381 .7702 L .35218 .75367 L p 0 1 0 r
F P
0 g
s
.83128 .74532 m .80705 .7597 L .84735 .80788 L p 0 1 0 r
F P
0 g
s
.84735 .80788 m .87089 .79406 L .83128 .74532 L p 0 1 0 r
F P
0 g
s
.6821 .60021 m .58924 .65735 L .53986 .54676 L p 1 0 0 r
F P
0 g
s
.52938 .5175 m .53986 .54676 L .44803 .59059 L p 1 0 0 r
F P
0 g
s
.44803 .59059 m .42922 .53866 L .52938 .5175 L p 1 0 0 r
F P
0 g
s
.50444 .40668 m .52938 .5175 L .42922 .53866 L p 1 0 0 r
F P
0 g
s
.50444 .40668 m .6136 .39407 L p .59829 .51003 L 1 0 0 r
F P
0 g
s
.59829 .51003 m .52938 .5175 L .50444 .40668 L p 1 0 0 r
F P
0 g
s
.35218 .75367 m .26381 .7702 L .2094 .66072 L p 0 1 0 r
F P
0 g
s
.77252 .52106 m .77543 .52809 L .6821 .60021 L p 1 0 0 r
F P
0 g
s
.6821 .60021 m .64285 .50913 L .77252 .52106 L p 1 0 0 r
F P
0 g
s
.64285 .50913 m .6821 .60021 L p .53986 .54676 L 1 0 0 r
F P
0 g
s
.73425 .39534 m .77252 .52106 L .64285 .50913 L p 1 0 0 r
F P
0 g
s
.70203 .39216 m .73425 .39534 L p .64285 .50913 L 1 0 0 r
F P
0 g
s
.63329 .47743 m .70203 .39216 L .6136 .39407 L closepath p 1 0 0 r
F P
0 g
s
.6136 .39407 m .63329 .47743 L .59829 .51003 L p 1 0 0 r
F P
0 g
s
.64285 .50913 m .63329 .47743 L .70203 .39216 L p 1 0 0 r
F P
0 g
s
.53986 .54676 m .59829 .51003 L .64285 .50913 L p 1 0 0 r
F P
0 g
s
.53986 .54676 m .59829 .51003 L .52938 .5175 L closepath p 1 0 0 r
F P
0 g
s
.2094 .66072 m .29792 .64159 L .35218 .75367 L p 0 1 0 r
F P
0 g
s
.64285 .50913 m .63329 .47743 L .59829 .51003 L closepath p 1 0 0 r
F P
0 g
s
.44462 .72618 m .45462 .74345 L .36236 .77051 L p 0 1 0 r
F P
0 g
s
.36236 .77051 m .35218 .75367 L .44462 .72618 L p 0 1 0 r
F P
0 g
s
.44462 .72618 m .35218 .75367 L .29792 .64159 L p 0 1 0 r
F P
0 g
s
.78726 .67269 m .69683 .7272 L .80705 .7597 L p 0 1 0 r
F P
0 g
s
.80705 .7597 m .83128 .74532 L .78726 .67269 L p 0 1 0 r
F P
0 g
s
.54048 .6874 m .56315 .72846 L .45462 .74345 L p 0 1 0 r
F P
0 g
s
.45462 .74345 m .44462 .72618 L .54048 .6874 L p 0 1 0 r
F P
0 g
s
.29792 .64159 m .39077 .61159 L .44462 .72618 L p 0 1 0 r
F P
0 g
s
.54048 .6874 m .44462 .72618 L .39077 .61159 L p 0 1 0 r
F P
0 g
s
.63899 .63717 m .68564 .7263 L .56315 .72846 L p 0 1 0 r
F P
0 g
s
.56315 .72846 m .54048 .6874 L .63899 .63717 L p 0 1 0 r
F P
0 g
s
.73929 .57555 m .78726 .67269 L .69683 .7272 L p 0 1 0 r
F P
0 g
s
.63899 .63717 m .73929 .57555 L p .69683 .7272 L 0 1 0 r
F P
0 g
s
.69683 .7272 m .68564 .7263 L .63899 .63717 L p 0 1 0 r
F P
0 g
s
.39077 .61159 m .48727 .5704 L .54048 .6874 L p 0 1 0 r
F P
0 g
s
.63899 .63717 m .54048 .6874 L .48727 .5704 L p 0 1 0 r
F P
0 g
s
.72027 .53049 m .73929 .57555 L .63899 .63717 L p 0 1 0 r
F P
0 g
s
.63899 .63717 m .59329 .53302 L .72027 .53049 L p 0 1 0 r
F P
0 g
s
.59329 .53302 m .63899 .63717 L p .48727 .5704 L 0 1 0 r
F P
0 g
s
.48727 .5704 m .5491 .53775 L .59329 .53302 L p 0 1 0 r
F P
0 g
s
.59329 .53302 m .58659 .51417 L .5491 .53775 L closepath p 0 1 0 r
F P
0 g
s
.68706 .43582 m .72027 .53049 L .59329 .53302 L p 0 1 0 r
F P
0 g
s
.59329 .53302 m .58659 .51417 L .68706 .43582 L p 0 1 0 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.21003 .19443 m
.2149 .19986 L
s
[(-0.5)] .2003 .18358 .89703 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.52711 .06111 m
.53128 .06709 L
s
[(0.5)] .51877 .04916 .69733 1 Mshowa
.125 Mabswid
.23999 .18184 m
.24287 .18512 L
s
.27032 .16909 m
.27316 .17241 L
s
.30102 .15618 m
.30383 .15953 L
s
.33211 .14311 m
.33487 .14649 L
s
.39546 .11647 m
.39814 .11992 L
s
.42774 .10289 m
.43038 .10638 L
s
.46044 .08915 m
.46304 .09266 L
s
.49356 .07522 m
.49611 .07877 L
s
.18044 .20688 m
.18339 .2101 L
s
.1512 .21917 m
.15419 .22236 L
s
.12231 .23132 m
.12534 .23448 L
s
.09377 .24332 m
.09683 .24645 L
s
.56109 .04682 m
.56355 .05044 L
s
.59553 .03235 m
.59793 .036 L
s
.63042 .01768 m
.63277 .02136 L
s
.66577 .00281 m
.66807 .00653 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.10743 .87934 m
.10832 .8721 L
s
[(-0.5)] .10564 .8938 .12332 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.32352 1.03141 m
.32393 1.02413 L
s
[(0.5)] .32269 1.04596 .05714 -1 Mshowa
.125 Mabswid
.13144 .89624 m
.13194 .89189 L
s
.15486 .91272 m
.15533 .90837 L
s
.17772 .92881 m
.17816 .92446 L
s
.20004 .94451 m
.20045 .94016 L
s
.24311 .97483 m
.24347 .97047 L
s
.26391 .98946 m
.26423 .9851 L
s
.28423 1.00376 m
.28453 .9994 L
s
.30409 1.01774 m
.30437 1.01338 L
s
.08281 .86201 m
.08338 .85768 L
s
.05756 .84424 m
.05816 .83991 L
s
.03165 .82601 m
.03229 .82169 L
s
.00506 .8073 m
.00574 .80298 L
s
.34252 1.04478 m
.34274 1.04041 L
s
.3611 1.05786 m
.3613 1.05349 L
s
.37928 1.07065 m
.37946 1.06628 L
s
.39708 1.08318 m
.39724 1.07881 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{200, 200},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000380000b1P00`40o`000?l0003ob?ooo`00HOoo
o`800004oooo0P0000Coool200006?ooo`80000ooooo001Poooo00@0003oooooool00008oooo00@0
003oooooool0000Eoooo1@0003koool0063oool010000?ooooooo`0000_oool00`000?ooooooo`0A
oooo0P0000?oool20000?_ooo`00H?ooo`040000oooooooo00002Oooo`80000Aoooo0`0000Goool0
0`000?ooo`00000moooo001Poooo00@0003oooooool00009oooo00<0003oooooool03_ooo`800002
oooo00<0003oooooool00oooo`030000oooo000003goool0067oool200002_ooo`<0000<oooo0P00
00[oool010000?ooooooo`0003coool007Woool400002oooo`050000oooooooooooo000003_oool0
07Ooool200003oooo`050000oooooooooooo000003_oool007Goool200004Oooo`030000oooooooo
00;oool00`000?ooooooo`0hoooo001boooo0`000003oooo0000oooo017oool00`000?ooooooo`02
oooo00<0003oooooool0=oooo`00L?ooo`80000Goooo00<0003oooooool00_ooo`030000oooooooo
03Ooool006koool300006?ooo`030000oooooooo00?oool00`000?ooooooo`0foooo001?oooo0P00
01[oool300000oooo`030000oooooooo01Goool00`000?ooooooo`03oooo00<0003oooooool0=_oo
o`00C_ooo`040000oooooooo00005oooo`80000Noooo00<0003oooooool01?ooo`030000oooooooo
03Goool004koool010000?ooooooo`0001Goool200000_ooo`030000oooooooo01_oool00`000?oo
ooooo`05oooo00<0003oooooool0=?ooo`00C_ooo`040000oooooooo00004_ooo`<0000Roooo00<0
003oooooool01Oooo`030000oooooooo03Coool004koool010000?ooooooo`00013oool2000000?o
ool0003oool08_ooo`030000oooooooo00Koool00`000?ooooooo`0coooo001?oooo0P0000ooool2
00009oooo`030000oooooooo00Koool00`000?ooooooo`0coooo001Moooo0`0002Woool00`000?oo
ooooo`07oooo00<0003oooooool0<_ooo`00Foooo`80000/oooo00<0003oooooool02?ooo`030000
oooooooo037oool005Woool20000;_ooo`030000oooooooo00Soool00`000?ooooooo`0aoooo001F
oooo0`00033oool00`000?ooooooo`09oooo00<0003oooooool0<?ooo`00E?ooo`80000coooo00<0
003oooooool02_ooo`030000oooooooo02ooool002[oool200001?ooo`800004oooo0P0001[oool2
000000?oool0003oool0<_ooo`030000oooooooo00[oool00`000?ooooooo`0_oooo000Yoooo00@0
003oooooool00008oooo00@0003oooooool0000Foooo0`0002GooolG00002Oooo`030000oooooooo
02koool002Woool010000?ooooooo`0000_oool00`000?ooooooo`0Boooo0`00027oool60000103o
0080000=0?l000<00000o`0000000`0000Ooool00`000?ooooooo`0^oooo000Soooo100000;oool0
10000?ooooooo`0000Woool200004oooo`80000Poooo100000`0o`0200001@3o00P000040?l000<0
003oooooool01Oooo`030000oooooooo02goool002Woool010000?ooooooo`0000Woool00`000?oo
ooooo`0?oooo0`0001koool400004@3o00H000060?l000<00000o`00o`00103o00030000oooooooo
00Goool00`000?ooooooo`0/oooo000Zoooo0P0000[oool300003Oooo`80000Moooo100000<0o`02
0000303o00@000030?l000<00000o`00o`001P3o000300000?l00?l000D0o`0200001Oooo`030000
oooooooo02coool004Coool200007?ooo`<000090?l00`0000@0o`050000203o000300000?l00?l0
00D0o`000`00003o003o00070?l000<0003oooooool00oooo`030000oooooooo02_oool0047oool3
00006_ooo`@0000?0?l0100000h0o`0200001@3o000300000?l00?l000D0o`0400001?ooo`030000
oooooooo02_oool003ooool200006_ooo`<0000?0?l010000080o`020000403o000300000?l00?l0
0080o`000`00003o000000050000103o00030000oooooooo00;oool00`000?ooooooo`0Zoooo000m
oooo0P0001[oool200000`3o0080000:0?l00`0000P0o`0G00002`3o00030000oooooooo00;oool0
0`000?ooooooo`0Yoooo000joooo0`0001[oool200001`3o00<000030?l0100000H0o`0300005ooo
o`80000;0?l000<0003oooooool00_ooo`030000oooooooo02Woool003Soool2000000?oool0003o
ool05oooo`<0000<0?l00`0000<0o`0500007?ooo`030000oooo0000008000090?l000<0003ooooo
ool00_ooo`030000oooooooo02Soool003Goool300006_ooo`80000=0?l00P000080o`0400008Ooo
o`030000oooooooo00;oool20000203o00030000oooooooo00;oool00`000?ooooooo`0Woooo000c
oooo100001Woool20000303o00<000030?l000<0003oooooool08oooo`030000oooooooo00Coool3
00001P3o00050000oooooooooooo000002Woool0033oool300006oooo`<0000:0?l00`000080o`02
0000:?ooo`030000oooooooo00Ooool20000103o00030000oooooooo00;oool00`000?ooooooo`0V
oooo000_oooo0`0001[oool200000`3o00@000040?l00P000080o`030000:_ooo`030000oooooooo
00Woool600000oooo`030000oooooooo02Koool002_oool400006oooo`8000090?l0100000040?l0
000000000000;Oooo`030000oooooooo00_oool01@00003o003o003o00000003oooo00<0003ooooo
ool09Oooo`00:_ooo`<0000Koooo0P0000/0o`02000000<0o`0000000000<?ooo`030000oooooooo
00_oool01@00003o003o003o00000004oooo00<0003oooooool09?ooo`009_ooo`040000oooo0000
00007?ooo`80000;0?l00P000080o`000`000?ooooooo`0`oooo00<0003oooooool03?ooo`050000
0?l00?l00?l0000000?oool00`000?ooooooo`0Toooo000Voooo0P0001coool200002`3o00800002
0?l00P0003Coool00`000?ooooooo`0<oooo00D00000o`00o`00o`0000000oooo`030000oooooooo
02?oool002Goool300006_ooo`80000;0?l00P0000<0o`000`000?ooooooo`0doooo00<0003ooooo
ool03?ooo`0500000?l00?l00?l0000000?oool00`000?ooooooo`0Soooo000Voooo00<0003oool0
00006?ooo`<000090?l00P0000@0o`000`000?ooooooo`0eoooo00<0003oooooool03Oooo`050000
0?l00?l00?l0000000?oool00`000?ooooooo`0Roooo000Voooo00@0003oooooool0000Eoooo0P00
00<0o`0400000`3o008000050?l000<0003oooooool0=_ooo`030000oooooooo00koool01@00003o
003o003o00000003oooo00<0003oooooool08Oooo`009Oooo`030000oooooooo00;oool00`000?oo
ooooo`0@oooo0P0000T0o`0300001@3o0080000ioooo00<0003oooooool03_ooo`0500000?l00?l0
0?l0000000?oool00`000?ooooooo`0Qoooo000Uoooo00<0003oooooool00oooo`030000oooooooo
00goool200002`3o008000000`3o0000000000020?l000<0003oooooool09Ooooa000004oooo00<0
003oooooool03oooo`D00003oooo00<0003oooooool08?ooo`009Oooo`030000oooooooo00Coool0
0`000?ooooooo`0:oooo0P0000/0o`0200001@3o0080000Roooo200000Go000500001?l000X0000<
oooo00<00000o`00o`000P3o00040000oooooooo00008_ooo`009Oooo`030000oooooooo00Goool0
0`000?ooooooo`08oooo00<00000o`00o`002@3o008000070?l000<0003oooooool07Oooo`H0000=
o`0000<0003o003o00000P0000Ko00000`000?l00?l00003o`001`0000Coool00`00003o003o0003
0?l000D0003oooooooooool000008Oooo`009Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo0P0000X0o`020000203o00030000oooooooo01[oool5000000?o0000003o00003ol000030000
o`00o`0000;o000200001?l000030000o`00o`0000Oo000010000?l00?l0000000?oool00`00003o
003o00040?l000D0003oooooooooool000008?ooo`009?ooo`800009oooo00<0003oooooool00ooo
o`8000090?l00P0000T0o`000`000?ooooooo`0Eoooo1P0000Ko00000`000?l00?l0000=o`0000<0
003o003o00001Ol000<000000ol000000?l00007o`0000<0003o003o00000_l000040000oooooooo
00001P3o00050000oooooooooooo0000023oool002Coool00`000?ooooooo`09oooo00@0003ooooo
ooooool500001@3o0080000:0?l000<0003oooooool04_ooo`@0000;o`0000<0003o003o00003_l0
00030000o`00o`0000So000200002?l000030000o`00o`0000?o00000`000?ooo`0000070?l000D0
003oooooooooool000007oooo`009?ooo`030000oooooooo00[oool010000?ooo`00000000@0o`05
00002`3o00030000oooooooo017oool300003_l000030000o`00o`0000go00000`000?l00?l00005
o`002P0000?o00000`000?l00?l00005o`0000<00000o`00o`001P3o00030000oooooooo00;oool0
0`000?ooooooo`0Loooo000Toooo00<0003oooooool02_ooo`<000070?l00P0000030?l000000000
00P0o`000`000?ooooooo`0@oooo0P0000;o00000`000?l00?l0000;o`0000<0003o003o00002_l0
00`00005o`0000<0003o000000000_l000H00006o`0000<00000o`00o`001P3o00050000oooooooo
oooo000001koool002Coool00`000?ooooooo`09oooo00<00000o`0000001`3o000300000?l00?l0
00<0o`0200001@3o00030000oooooooo00ooool200000ol000030000o`00o`0000co000010000?l0
0?l00?l000T00004o`0000<0003o003o00002_l000030000o`00000000Co000010000?l00?l00?l0
00P000070?l000<0003oooooool00_ooo`030000oooooooo01_oool002?oool200002_ooo`030000
0?l0000000H0o`020000203o008000020?l000<0003oooooool03_ooo`800005o`0000<0003o003o
00002_l000H0000=o`0000<0003o003o00002_l000030000o`00000000Co00000`000?l00?l00009
o`0000<00000o`00o`001@3o00050000oooooooooooo000001goool002Coool00`000?ooooooo`07
oooo00@00000o`00o`0000050?l000<00000o`00o`002P3o0080000?oooo0P0000Ko00000`000?l0
0?l00007o`0010000003o`000000o`00013o00000`000?l00?l0000:o`0000<0003o000000001?l0
00030000o`00o`0000Wo00000`00003o003o00050?l000<0003oooooool00_ooo`030000oooooooo
01[oool002?oool00`000?ooooooo`06oooo0P000080o`000`00003o003o00020?l00P0000h0o`00
0`000?ooooooo`0;oooo0P0000So00000`000?l00?l00003o`00100000Go00000`000?l00?l0000?
o`0000<0003o003o00002ol000800004o`0000<0003o003o00002_l0000300000?l0000000H00004
oooo00<0003oooooool06Oooo`008oooo`030000oooooooo00Goool01@00003o003o003o00000004
0?l000<00000o`00o`00303o00<0000;oooo0P0000Wo00000`000?l00?l0000400002Ol000030000
o`00o`0000oo00000`000?l00?l0000;o`000P0000Co00000`000?l00?l0000;o`0000<00000o`00
o`00103o00030000oooooooo00;oool00`000?ooooooo`0Ioooo000Soooo0P0000Goool01@00003o
003o003o000000030?l00P0000h0o`001000003o003o000000Woool300002Ol000@0000=o`0000<0
003o003o00003ol000030000o`00o`0000_o000200001?l000030000o`00o`0000_o00000`00003o
003o00050?l000<0003oooooool00_ooo`030000oooooooo01Soool002?oool00`000?ooooooo`02
oooo0P000080o`0700003@3o008000030?l000<0003oooooool01Oooo`8000000ol000000?l00006
o`000`000003o`000000o`0000ko00000`000?l00?l0000?o`0000<0003o003o00002ol000800005
o`0000<0003o003o00002ol0000300000?l00?l000@0o`000`000?ooooooo`02oooo00<0003ooooo
ool06?ooo`004?ooo`800004oooo0P0000Coool200001Oooo`040000oooooooooooo1@0000Ooool2
00002@3o008000050?l000<0003oooooool00oooo`800003o`0000<0003o003o00000_l000<00004
o`0000<0003o003o00003Ol000030000o`00o`0000oo00000`000?l00?l0000;o`000P0000Go0000
0`000?l00?l0000<o`0000<00000o`00o`00103o00030000oooooooo00;oool00`000?ooooooo`0G
oooo000?oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool00P00
00goool200001P3o000300000?l00?l000D0o`0010000?ooooooooooo`800004o`0000<0003o003o
00000`0000Oo00000`000?l00?l0000=o`0000<0003o003o00003ol000030000o`00o`0000_o0002
00001Ol000T00006o`0000<00000o`00o`00103o00030000oooooooo00?oool00`000?ooooooo`0F
oooo000?oooo00@0003oooooool0000;oooo00D0003oooooooooool000005?ooo`8000020?l00P00
00P0o`0010000?ooo`00000000Go000400002_l000030000o`00o`0000go00000`000?l00?l0000?
o`0000<0003o003o00002ol000800005o`000P0000Oo000800001P3o00030000oooooooo00;oool0
0`000?ooooooo`0Foooo0009oooo100000;oool010000?ooooooo`0000Woool200001?ooo`80000E
oooo0P0000X0o`0200001_l00080000=o`0000<0003o003o00003Ol000030000o`00o`0000oo0000
0`000?l00?l0000;o`000P0000Go00000`000?l00000000=o`0000<00000o`00o`00103o00030000
oooooooo00?oool00`000?ooooooo`0Eoooo000?oooo00@0003oooooool00009oooo00<0003ooooo
ool00oooo`030000oooooooo01Koool00`00003o003o00060?l00P0000Go00000`000?l00000000>
o`0000<0003o003o00003Ol000030000o`00o`0000oo00000`000?l00?l0000;o`000P0000Go0000
0`000?l00000000>o`0000<00000o`00o`000`3o00030000oooooooo00Coool00`000?ooooooo`0D
oooo000@oooo0P0000[oool300000oooo`030000oooooooo01Ooool200001@3o00030000o`000000
00?o000200000_l000030000o`00o`0000_o00000`000?l00?l0000>o`0000<0003o003o00002ol0
01X00002o`0000<0003o003o00002ol0000300000?l00?l000@0o`000`000?ooooooo`03oooo00<0
003oooooool05?ooo`008_ooo`030000oooooooo01Woool00`00003o003o0002000000?o0000003o
00000_l000030000o`00o`0000;o00000`000?l00?l0000;o`0000<0003o003o00003_l000030000
o`00o`0000;o000900001?l000030000o`00o`0000_o00000`000?l00?l00004o`0000@0003o003o
0000000>o`0000<00000o`00o`000`3o00030000oooooooo00Coool00`000?ooooooo`0Coooo000R
oooo00<0003oooooool06_ooo`800002o`0000<0003o003o00000P0000Go00000`000?l00?l0000;
o`0000<0003o003o00003?l000L0000>o`0000<0003o003o00002Ol000800007o`0000@0003o003o
0000000=o`0000<00000o`00o`00103o00030000oooooooo00?oool00`000?ooooooo`0Coooo000Q
oooo0P0001coool01@000?l00?l000000?l0000200001ol000030000o`00o`0000_o00000`000?l0
0?l00008o`00100000;o00000`000?l00?l0000@o`0000<0003o003o00002Ol000800007o`0000@0
003o003o0000000>o`0000<00000o`00o`000`3o00030000oooooooo00?oool200005?ooo`008Ooo
o`030000oooooooo01[oool010000?l00?l00?l000800009o`0000<0003o003o00002ol000030000
o`00o`0000Co000400001_l000030000o`00o`00013o00000`000?l00?l00008o`0000<0003o0000
00001ol000050000o`00o`00o`00000000go00000`00003o003o00040?l000<0003oool000000P00
0003oooo0000oooo01?oool0027oool00`000?ooooooo`0Ioooo00D0003o003o003o000000002_l0
00030000o`00o`0000co00000`000?l00?l0000400002ol000030000o`00o`0000oo00000`000?l0
0?l00007o`0000@0003o003o00000007o`0000D0003o003o003o000000003_l000P00004oooo00<0
003oooooool04_ooo`008Oooo`030000oooooooo01Soool00`000?l00?l00002o`0000<0003o003o
00002?l000030000o`00o`0000_o000400003ol000030000o`00o`00013o00000`000?l00?l00005
o`0000D0003o003o003o000000002?l000050000o`00o`00o`00000000go00000`00003o003o0003
0?l000<0003oooooool00oooo`030000oooooooo01;oool0027oool00`000?ooooooo`0Goooo00<0
003o003o00000P000003o`000000o`0000Wo00000`000?l00?l00008o`000`000003o`000000o`00
013o00000`000?l00?l0000@o`0000<0003o003o00001?l000040000o`00o`00o`000P0000So0000
1@000?l00?l00?l00000000>o`0000<00000o`00o`000`3o00030000oooooooo00?oool00`000?oo
ooooo`0Aoooo000Poooo0P0001Soool010000?l00?l0000000?o00000`000?l00?l00008o`0000<0
003o003o00001Ol000<00004o`0000<0003o003o00003ol000030000o`00o`00013o00000`000?l0
0?l00004o`0000<0003o003o00000P000003o`000000o`0000Ko00000`000?l00?l00002o`0000<0
003o003o00002ol0000300000?l00?l000<0o`000`000?ooooooo`03oooo00<0003oooooool04Ooo
o`008Oooo`030000oooooooo01Goool2000000?o0000003o00000ol000030000o`00o`0000So0000
0`000?l00?l00002o`000`0000So00000`000?l00?l0000>o`0000<0003o003o00004Ol000030000
o`00o`0000;o000010000?l0000000000080o`0200002?l000`00007o`0000<00000o`00o`000`3o
00030000oooooooo00;oool00`000?ooooooo`0Aoooo000Poooo00<0003oooooool05_ooo`030000
o`00000000Go00000`000?l00?l00008o`0000<0003o000000000P0000_o00000`000?l00?l0000?
o`0000<0003o003o00004?l000070000o`00o`00o`000000o`00000000@0o`0200002?l000030000
o`00o`0000;o00000`000?l00?l00004o`00200000D0o`000`000?ooooooo`02oooo00<0003ooooo
ool04Oooo`008?ooo`030000oooooooo01Goool300001_l000030000o`00o`0000So000200003_l0
00030000o`00o`0000oo00000`000?l00?l0000@o`0000H0003o003o0000003o000000050?l00P00
00So00000`000?l00?l00002o`0000<0003o003o00002ol0000400000?l00?l00?l00`0000Coool0
0`000?ooooooo`0Aoooo000Poooo00<0003oooooool05?ooo`800007o`0000<0003o003o00001ol0
00<0000?o`0000<0003o003o00003ol000030000o`00o`00013o00000`000?l00?l0000200001`3o
00030000o`00o`0000Ko00000`000?l00?l00003o`0000<0003o003o00002Ol0008000020?l000D0
0000o`00o`00o`0000000oooo`030000oooooooo017oool0023oool00`000?ooooooo`0Coooo0P00
00So00000`000?l00?l00005o`000P0000;o00000`000?l00?l0000>o`0000<0003o003o00003_l0
00030000o`00o`00017o000200002@3o00030000o`00o`0000Oo00000`000?l00?l00002o`0000<0
003o003o00002?l000030000o`00o`00008000040?l000D0003oooooooooool000004oooo`008?oo
o`030000oooooooo01;oool00ol0000000000008o`0000<0003o003o00001?l000030000o`00o`00
00?o00000`000?l00?l0000=o`0000<0003o003o00003ol000030000o`00o`00013o00000`00003o
003o00080?l000<0003o003o00001ol000030000o`00o`0000?o00000`000?l00?l00006o`0000D0
003o003o003o000000001@3o00030000oooooooo00;oool00`000?ooooooo`0@oooo000Poooo00<0
003oooooool04_ooo`030000o`00000000So00000`000?l00?l00002o`000P0000Ko00000`000?l0
0?l0000=o`0000<0003o003o00003ol000030000o`00o`0000ko000200002`3o00800008o`0000<0
003o003o00000ol000030000o`00o`0000Go00000`000?l00?l00002o`0000<00000o`00o`00103o
00050000oooooooooooo000001;oool001ooool00`000?ooooooo`0Boooo00<0003o000000002Ol0
00030000o`00o`0000800008o`0000<0003o003o00003Ol000030000o`00o`0000oo00000`000?l0
0?l0000=o`0000<00000o`00o`002`3o00800009o`0000<0003o003o00000ol000030000o`00o`00
00?o00000`000?l00?l00004o`0000<00000o`00o`000`3o00050000oooooooooooo000001;oool0
01ooool200004_ooo`8000000ol000000?l00008o`000`0000[o00000`000?l00?l0000=o`0000<0
003o003o00003ol000030000o`00o`0000co00000`00003o003o000<0?l00P0000Wo00000`000?l0
0?l00003o`0000<0003o003o00000ol000030000o`00o`0000Co00000`00003o003o00030?l000D0
003oooooooooool000004_ooo`007oooo`030000oooooooo013oool01Ol000000?l00?l000000009
o`0000<0003o003o00002ol000030000o`00o`0000go00000`000?l00?l0000>o`0000<0003o003o
00002_l00080000?0?l00P0000Wo00000`000?l00?l00004o`0000D0003o003o003o000000001ol0
000300000?l00?l000@0o`0010000?ooooooo`0001;oool001Soool200001Oooo`030000oooooooo
00ooool00ol000000?l00002o`0000<0003o003o00001Ol000<0000=o`0000<0003o003o00003Ol0
00030000o`00o`0000oo00000`000?l00?l00007o`000P000140o`000`00003o00000008o`0000<0
003o003o00001?l000040000o`00o`0000002Ol0000300000?l00?l000<0o`0010000?ooooooo`00
01;oool001Ooool010000?ooooooo`0000Coool00`000?ooooooo`0?oooo00<0003o003o00000_l0
00030000o`00o`0000Co000010000?l00?l0000000go00000`000?l00?l0000=o`0000<0003o003o
00003ol000040000o`00o`00o`001`000180o`000`00003o0000000400001Ol000030000o`00o`00
00Co000200002_l0000300000?l00?l000<0o`0010000?ooooooo`0001;oool001Ooool010000?oo
ooooo`0000Coool00`000?ooooooo`0>oooo0P0000Co00000`000?l00?l00002o`000P0000Co0000
0`000?l00?l0000:o`0000<0003o003o00003Ol000030000o`00o`0000go000600001?l000<0000B
0?l000<00000o`0000001?l000H00006o`0000<0003o003o00002Ol0000300000?l00?l000@0o`00
10000?ooooooo`00017oool001Ooool010000?ooooooo`0000?oool00`000?ooooooo`0>oooo00<0
003o000000000ol000040000o`00o`00o`000P0000Ko00000`000?l00?l0000:o`0000<0003o003o
00003_l000030000o`00o`0000Ko000600000_l000030000o`00o`0000Co00001@00003o003o003o
0000000A0?l000@00000o`00o`000009o`0000<0003o003o00000_l00080000<o`001`0000;oool0
0`000?ooooooo`0?oooo000Goooo00@0003oooooool00003oooo0P0000ooool200001?l000040000
o`00o`0000002?l000030000o`00o`0000_o00000`000?l00?l0000=o`0000<0003o003o00001P00
00Wo000010000?l00?l00?l0008000000`3o00000000000G00002Ol000030000o`00o`0000800000
0ol000000?l0000;o`0000<0003oooooool01_ooo`030000oooooooo00ooool001Soool200001?oo
o`030000oooooooo00koool200001?l000<00009o`0000<0003o003o00002ol000030000o`00o`00
00co000400003ol000030000o`00o`0000@000030?l000<00000o`00o`00403o000400000?l00?l0
00001ol000030000o`00000000800003o`0000<0003o003o00002Ol000030000oooooooo00Koool0
0`000?ooooooo`0?oooo000Noooo00<0003oooooool03_ooo`800004o`0000<0003o003o00002Ol0
00030000o`00o`0000_o00000`000?l00?l00009o`000`000003o`000000o`00017o00020000203o
000300000?l00?l000l0o`001000003o003o000000Go000200000_l000030000o`00o`0000800000
0ol000000?l0000;o`0000<0003oooooool01Oooo`030000oooooooo00ooool001koool00`000?oo
ooooo`0>oooo0P0000?o000200002ol000030000o`00o`0000_o00000`000?l00?l00006o`000`00
00Go00000`000?l00?l0000=o`000P0000X0o`000`00003o003o000?0?l000D00000o`00o`00o`00
00000ol000030000o`00o`0000?o000010000?l00?l00?l00080000<o`0000<0003oooooool01Ooo
o`030000oooooooo00ooool001koool00`000?ooooooo`0>oooo0P0000;o00000`000?l00000000<
o`0000<0003o003o00002ol000030000o`00o`0000;o000300002?l000030000o`00o`0000_o0002
00003@3o000300000?l00?l000h0o`001@00003o003o003o00000002o`0000<0003o003o00001?l0
00030000o`00o`0000;o000300002_l000030000oooooooo00Goool00`000?ooooooo`0?oooo000M
oooo0P00013oool01?l000000?l0000000?o00000`000?l00?l00009o`0000<0003o003o00003Ol0
00<0000;o`0000<0003o003o00002Ol00080000?0?l000<00000o`00o`003P3o000300000?l00?l0
0080o`0200002?l000030000o`00o`0000;o000010000?l00000000000Wo00000`000?ooooooo`05
oooo00<0003oooooool03_ooo`007Oooo`030000oooooooo00koool200000_l000050000o`00o`00
o`00000000_o00000`000?l00?l0000;o`000P0000oo00000`000?l00?l00006o`000P000180o`00
0`00003o003o000=0?l000<00000o`00o`000P3o00030000o`00o`0000Oo00000`000?l00?l00002
o`0000@0003o003o003o000200001ol000030000oooooooo00Goool00`000?ooooooo`0>oooo000M
oooo00<0003oooooool03_ooo`8000000ol000000?l00003o`0000<0003o003o00002Ol000030000
o`00o`0000Wo000300004?l000030000o`00o`0000Co00020000503o000300000?l00?l000d0o`00
0`00003o003o00030?l000<0003o003o00001ol000050000o`00o`00o`00000000Go000200001?l0
00800007oooo00<0003oooooool03_ooo`007Oooo`030000oooooooo00koool00`000?l000000005
o`0000<0003o003o00002Ol000030000o`00o`0000Oo000200000ol000030000o`00o`0000go0000
0`000?l00?l00002o`000P0000030?l000000?l001@0o`000`00003o003o000<0?l000<00000o`00
o`000`3o00030000o`00o`0000Oo00001@000?l00?l00?l000000007o`000P000004o`000000o`00
00001oooo`030000oooooooo00koool001goool00`000?ooooooo`0>oooo0P0000Oo00000`000?l0
0?l00008o`0000<0003o003o00001Ol000800005o`0000<0003o003o00003_l000040000o`000000
0000103o000300000?l00?l00180o`000`00003o003o000;0?l00P0000<0o`02000000<0o`00003o
00002?l000050000o`00o`00o`00000000So000010000?l00?l0000000Ooool00`000?ooooooo`0>
oooo000Loooo0P00013oool2o`0000<0003o003o00001?l000030000o`00o`0000Wo00000`000?l0
0?l00002o`000P0000Oo00000`000?l00?l0000=o`000`0000H0o`000`00003o003o000B0?l000<0
0000o`00o`00203o00<000020?l00`0000<0o`000`000?l00?l00007o`0000D0003o003o003o0000
00001_l000<00002o`0000<0003oooooool01Oooo`030000oooooooo00koool001goool00`000?oo
ooooo`0>oooo00<0003o003o00000P0000Co00000`000?l00?l00009o`0000<0003o003o00000P00
00[o00000`000?l00?l00009o`00100000T0o`000`00003o003o000B0?l000<00000o`00o`000`3o
00@000050?l00P0000D0o`000`000?l00?l00007o`0000@0003o003o00000005o`0000@0003o003o
00000002o`0000<0003oooooool01Oooo`030000oooooooo00koool001coool00`000?ooooooo`0?
oooo00<0003o003o00000_l000050000o`00o`00o`00000000co000200003?l000030000o`00o`00
00Ko00040000303o000300000?l00?l00180o`000`00003o003o000300001`3o008000000`3o0000
003o00040?l000<0003o003o00001ol000040000o`00o`0000000ol000800004o`0000@0003o003o
00000007oooo00<0003oooooool03Oooo`007?ooo`030000oooooooo00ooool00`000?l00?l00003
o`0000@0003o003o0000000;o`0000<0003o003o00003?l000030000o`00o`0000?o000500003`3o
000300000?l00?l00140o`030000203o008000040?l000<00000o`00o`000`3o00030000o`00o`00
00Oo00000`000?l00?l0000300001_l000040000o`00o`0000001oooo`030000oooooooo00goool0
01coool00`000?ooooooo`0@oooo00<0003o003o00000ol0008000000ol000000?l00007o`000P00
0003o`000000o`0000go00000`000?l00000000500004@3o000300000?l00?l000h0o`03000000<0
o`000000o`001P3o008000070?l000<00000o`00o`000P3o00030000o`00o`0000Ko00001@000?l0
00000?l000000008o`0000@0003o003o00000007oooo00<0003oooooool03Oooo`007?ooo`030000
oooooooo013oool00`000?l00?l00005o`000P0000Oo00001@000?l00?l00?l00000000;o`002000
00030?l000000?l00180o`000`00003o003o000:0?l00`0000D0o`000`00003o003o00030?l000<0
0000o`00o`00203o000300000?l00?l00080o`000`000?l00?l00003o`000P0000?o000200002?l0
00040000o`00o`0000001oooo`030000oooooooo00goool001_oool200004_ooo`030000o`00o`00
00Ko000300000ol000800005o`0000@0003o003o003o000700000_l000<000050?l000<00000o`00
o`00403o000300000?l00?l000H0o`040000203o000400000?l00?l00?l00P0000`0o`001@00003o
003o003o00000004o`0000<0003o003o00000ol000800008o`0000@0003o003o00000007oooo00<0
003oooooool03Oooo`007?ooo`030000oooooooo013oool00`000?l00?l00006o`0000<0003o003o
00003P0000Go00040000203o000300000?l00?l00140o`000`00003o003o00020?l00`0000d0o`03
00003P3o000300000?l00?l00080o`0010000?l00?l0000000Oo00000`000?l00?l00006o`0000@0
003o003o00000007oooo00<0003oooooool03Oooo`006oooo`030000oooooooo01;oool00`000?l0
0?l00005o`0000D0003o003o003o000000003_l000<0000=0?l000<00000o`00o`00403o00030000
0?l000000080000?0?l00P000140o`001`00003o003o003o00000?l000000009o`0000<0003o003o
00002?l000030000oooooooo00Goool00`000?ooooooo`0=oooo000Koooo00<0003oooooool04_oo
o`030000o`00o`0000Ko00000`000?l00000000:o`001@000100o`000`00003o003o000?0?l00`00
0100o`0200000P3o000300000?l00?l000l0o`001@00003o003o003o0000000;o`0000<0003o003o
00001ol000030000oooooooo00Koool00`000?ooooooo`0<oooo000Koooo00@0003oooooooooool3
00003_ooo`030000o`00o`0000Ko000200001ol000D000020?l000<00000o`00o`00403o00030000
0?l00?l000/0o`0300000P3o000300000?l00?l000`0o`020000103o000300000?l00?l00100o`00
1000003o003o000000_o00000`000?l00?l00006o`0000<0003oooooool01oooo`030000oooooooo
00coool001_oool200000_ooo`0300000?l00?l000@0000:oooo00<0003o003o00001_l000040000
o`00o`00o`001@0000P0o`000`00003o003o000?0?l000<00000o`00o`001`3o00@000060?l000<0
0000o`00o`002@3o008000070?l000<00000o`00o`00403o000400000?l00?l000002ol000030000
o`00o`0000Go00000`000?ooooooo`07oooo00<0003oooooool03?ooo`002?ooo`800004oooo0P00
00Coool200001Oooo`030000oooooooo00;oool00`00003o003o00030?l0100000Ooool5o`001`00
00d0o`000`00003o003o000@0?l000<00000o`00o`000`3o00<0000:0?l000<00000o`00o`001`3o
008000090?l000<00000o`00o`00403o000400000?l00?l000003?l000050000o`00o`00o`000000
00;o00000`000?ooooooo`07oooo00<0003oooooool03?ooo`001oooo`040000oooooooo00002?oo
o`040000oooooooo00001?ooo`030000oooooooo00;oool00`00003o003o00070?l0300001D0o`00
0`00003o003o000?0?l000<00000o`00o`000`0000h0o`000`00003o003o00040?l00P0000`0o`00
0`00003o003o000@0?l000@00000o`00o`00000:o`0000D0003o0000003o000000000ol000030000
oooooooo00Ooool00`000?ooooooo`0<oooo0007oooo00@0003oooooool0000;oooo00<0003ooooo
ool00_ooo`030000oooooooo00;oool00`00003o003o00090?l000D00000o`00o`00o`0000002P3o
000300000?l00?l000d0o`000`00003o003o000?0?l00`000140o`000`00003o003o00020?l00P00
00h0o`000`00003o003o000A0?l000<00000o`0000002?l000800003o`000P0000;o00000`000?oo
ooooo`08oooo00<0003oooooool03?ooo`001oooo`040000oooooooo00002Oooo`800004oooo00<0
003oooooool01?ooo`0300000?l00?l000T0o`030000303o000300000?l00?l000d0o`000`00003o
003o000:0?l0100000030?l000000?l00180o`001000003o000000000140o`000`00003o003o000@
0?l00P0000030?l00000o`0000Go00000`000?l00?l00005o`0000<0003o000000002_ooo`030000
oooooooo00coool000Ooool010000?ooooooo`0000Woool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`0300000?l00?l000T0o`000`00003o003o000<0?l000<00000o`00o`003@3o00030000
0?l00?l000L0o`0300001P3o000300000?l00?l000l0o`0300004`3o000300000?l00?l000h0o`02
00000P3o00800005o`0000<0003o003o00001ol00080000;oooo00<0003oooooool02oooo`002?oo
o`80000:oooo0`0000?oool00`000?ooooooo`05oooo00<00000o`00o`001`3o000300000?l00000
00h0o`000`00003o003o000=0?l000<00000o`00o`000`3o00<000090?l000<00000o`00o`003@3o
008000020?l000<00000o`00o`004P3o000300000?l00?l000`0o`000`00003o003o00030?l00P00
00?o00000`000?l00?l00007o`000P0000coool00`000?ooooooo`0;oooo000Joooo00<0003ooooo
ool01Oooo`0300000?l00?l000H0o`001000003o003o000000h0o`000`00003o003o000=0?l000<0
0000o`00o`000`0000d0o`000`00003o003o000:0?l00P0000@0o`000`00003o003o000B0?l000<0
0000o`00o`002P3o008000060?l00P000003o`000000000000So000300003Oooo`030000oooooooo
00_oool001[oool00`000?ooooooo`05oooo00<00000o`00o`001@3o000300000?l00?l00080o`00
0`00003o003o000<0?l000<00000o`00o`00303o00<0000@0?l000<00000o`00o`00203o00800007
0?l000<00000o`00o`004P3o000300000?l00?l000L0o`0200002@3o00800009o`000P0000ooool0
0`000?ooooooo`0;oooo000Joooo00<0003oooooool01_ooo`0300000?l00?l00080o`0200001@3o
000300000?l00?l000`0o`000`00003o003o00080?l0100000030?l000000?l00140o`000`00003o
003o00040?l00`0000T0o`000`00003o003o000B0?l000<00000o`00o`001P3o000300000?l00?l0
00X0o`0200001ol00080000@oooo00<0003oooooool02oooo`006Oooo`030000oooooooo00Ooool0
1@00003o003o003o000000080?l000<00000o`00o`00303o000300000?l00?l000@0o`0300001P3o
000300000?l00?l000l0o`000`00003o003o00020?l00P0000d0o`000`00003o003o000B0?l000<0
0000o`00o`000`3o0080000>0?l000<0003o003o00001?l00080000Aoooo00<0003oooooool02ooo
o`006Oooo`030000oooooooo00Ooool01000003o003o000000T0o`000`00003o003o000<0?l000@0
0000o`00o`00o`0300002@3o000300000?l00?l00100o`001000003o0000000000l0o`000`00003o
003o000B0?l000@00000o`00o`00o`0200004@3o00040000o`00o`00o`000`0001;oool00`000?oo
ooooo`0;oooo000Ioooo00<0003oooooool02?ooo`80000;0?l000<00000o`00o`00303o00<0000=
0?l000<00000o`00o`003P3o00<0000@0?l06`000180o`000`000?l00?l0000300005?ooo`030000
oooooooo00[oool001Woool00`000?ooooooo`08oooo00<00000o`00o`002P3o000300000?l00?l0
00P0o`0500003`3o000300000?l00?l000/0o`0300000P3o000300000?l00?l000P0o`0600003Ol0
00<0000;o`000`000100o`0300005_ooo`030000oooooooo00[oool001Woool00`000?ooooooo`09
oooo00<00000o`00o`002P3o000300000?l00?l000@0o`0300001@3o000300000?l00?l000d0o`00
0`00003o003o00070?l00`0000D0o`000`00003o003o00020?l01P0000;o00000`000?l00?l0000<
o`000P0000;o00000`000?l00?l0000;o`00100000d0o`0200005oooo`030000oooooooo00[oool0
01Woool00`000?ooooooo`09oooo00<00000o`00o`002P3o000400000?l00?l00?l00`0000P0o`00
0`00003o003o000=0?l000<00000o`00o`000`3o00@000080?l01@0000So00000`000?l00?l00009
o`000`0000Go00000`000?l00?l0000;o`0000<0003o003o00000`0000/0o`0200005_ooo`030000
oooooooo00[oool001Soool00`000?ooooooo`0;oooo00<00000o`00o`002P3o00<0000<0?l000<0
0000o`00o`003@3o000300000?l00000008000090?l00`0000ko00000`000?l00?l00006o`000P00
00Wo00000`000?l00?l0000;o`000P0000?o000300001`3o000400000?l0000000005Oooo`030000
oooooooo00[oool001Soool00`000?ooooooo`0;oooo00<00000o`00o`001`3o00@0000>0?l000<0
0000o`00o`002P3o00D000090?l01000017o00000`000?l00?l00002o`000`0000co00000`000?l0
0?l00008o`000P0000So000300000P3o008000030?l000<0003oooooool04oooo`030000oooooooo
00[oool001Soool00`000?ooooooo`0<oooo00<00000o`00o`000P3o00@000040?l000<00000o`00
o`00303o000400000?l00?l00?l0200000@0o`000`00003o003o00030?l0100000?o00000`000?l0
0?l0000?o`0000<0003o003o00000P00013o00000`000?l00?l00005o`000P000003o`000000o`00
00Oo000500001@3o0080000Doooo00<0003oooooool02_ooo`006?ooo`030000oooooooo00coool0
0`00003o000000020000203o000300000?l00?l000T0o`070000303o000300000?l00?l000<00008
o`0000<0003o003o00003_l000<0000Co`0000<0003o003o00000_l000800002o`0000<0003o003o
00001Ol000@00003oooo00<00000o`00o`000`3o0080000Doooo00<0003oooooool02Oooo`006?oo
o`030000oooooooo00_oool900001P3o000400000?l00?l00?l01`0000@0o`000`00003o003o000<
0?l00`0000co00000`000?l00?l00009o`00100000;o00000`000?l00?l0000Bo`0000@0003o0000
00000003o`0000<0003o003o00001?l000@00006oooo00<00000o`00o`000`3o0080000Coooo00<0
003oooooool02Oooo`006?ooo`030000oooooooo00Soool300000oooo`H0o`0:00002`3o00030000
0?l00?l000X0o`0300003ol000030000o`00o`0000Co000400001ol000030000o`00o`00017o0002
00001?l000030000o`00o`0000?o000400002Oooo`0300000?l00?l000<0o`0200004_ooo`030000
oooooooo00Woool001Ooool00`000?ooooooo`06oooo0`0000Koool00`00003o003o000:0?l000<0
0000o`00o`00303o000300000?l00?l000L0o`0200000ol000030000o`00o`0000co00000`000?l0
0?l0000400003?l000030000o`00o`0000go000300000_l000800002o`0000@0003o003o003o0004
00003?ooo`0300000?l00?l00080o`0200004_ooo`030000oooooooo00Woool001Ooool00`000?oo
ooooo`02oooo100000[oool00`00003o003o00090?l000<00000o`00o`00303o000300000?l00?l0
00D0o`0300001?l000030000o`00o`0000[o000500004Ol00080000:o`000`0000Oo000200000_l0
00@0000>oooo00<00000o`00o`000`3o0080000Aoooo00<0003oooooool02Oooo`005oooo`D0000?
oooo00<00000o`00o`002@3o000300000?l00?l000`0o`000`00003o003o00020?l00P0000;o0000
0`000?l00?l00003o`0000<0003o003o00000_l000L00004o`0000<0003o003o00004Ol000030000
o`00o`0000Co000300002_l000030000o`00000000<0000Aoooo00<00000o`00o`000`3o0080000=
oooo00@0003oooooool0000;oooo000Goooo0P0001;oool00`00003o003o000:0?l000<00000o`00
o`002`3o000300000?l00?l000<00002o`0000<0003o003o00000_l000L0000<o`0000<0003o003o
00004Ol000030000o`00o`0000<0000;o`000P000004o`000000000000005?ooo`0300000?l00?l0
008000000`3o00000000000:oooo0P0000?oool00`000?ooooooo`09oooo000Goooo0`0001;oool0
0`00003o003o00090?l000<00000o`00o`00303o00800003o`001`0000Co00000`000?l00?l0000=
o`0000<0003o003o00004?l000<0000=o`0000@0003o00000000000Hoooo0P0000D0o`000`000?oo
ooooo`06oooo00<00000o`0000001?ooo`030000oooooooo00Soool001[oool00`000?ooooooo`0@
oooo00<00000o`00o`002@3o000300000?l00?l000X0o`000`000?l00?l00002o`0000D0003o003o
003o000000002?l00080000>o`000P0000co000400000_l000030000o`00o`0000[o000300006_oo
o`0300000?l00?l000@0o`0300001Oooo`80o`000`000?ooooooo`03oooo00<0003oooooool02?oo
o`006oooo`80000@oooo00<00000o`00o`002P3o000300000?l00?l000P0o`000`000?l00?l00004
o`0000D0003o003o003o000000002Ol000030000o`00o`0000go00000`000?l00?l00005o`001000
00So000200001ol000<0000Koooo00<00000o`00o`001P3o000300000?l0000000<000030?l000<0
003oooooool00oooo`030000oooooooo00Soool001coool200004?ooo`0300000?l00?l000X0o`00
0`00003o003o00060?l00`0000Ko000200000_l000030000o`00o`0000Oo00000`000?l00?l0000=
o`0000<0003o003o0000100000ko000200000ol000<0000Moooo00<00000o`00o`001P3o00800003
0?l0100000Koool00`000?ooooooo`08oooo000Noooo00<0003oooooool03Oooo`0300000?l00?l0
00X0o`000`00003o003o00040?l00P0000?oool400001?l000030000o`00o`0000800008o`000P00
00_o000500005?l000<0000Ooooo00<00000o`00o`001@3o008000020?l000<00000o`00o`000P00
00Soool00`000?ooooooo`08oooo000Ooooo0P0000koool00`00003o003o000:0?l000<00000o`00
o`000P3o00030000oooooooo00Goool500000_l000050000o`00o`00o`00000000Wo00000`000?l0
0?l00002o`001P0000Co000200003_l000@0000Soooo00<00000o`00o`000`3o008000050?l00P00
00[oool00`000?ooooooo`08oooo000Poooo0P0000koool00`00003o003o000:0?l000@00000o`00
o`00000;oooo0P000003o`000000000000<000000ol000000?l00004o`00200000co000200002Ol0
00<0000Woooo00<00000o`00o`000P3o000300000?l00?l000<0o`0300002oooo`030000oooooooo
00Soool002;oool00`000?ooooooo`0;oooo00<00000o`00o`002P3o000300000?l0000000ooool2
00000_l000P00005o`000P0000oo000200000ol000@0000Yoooo00@00000o`00o`00o`020000103o
00<00002oooo00<0003oooooool02Oooo`030000oooooooo00Ooool002?oool300002oooo`H00007
0?l000<0003oooooool04_ooo`D00002o`001`000003o`000000000000oo00030000;Oooo`80o`02
0000103o00<00005oooo00<0003oooooool02?ooo`030000oooooooo00Ooool002Goool00`000?oo
ooooo`0:oooo1@3o00L0000Ioooo0`0000Oo000B0000;oooo`<000040?l00`0000Soool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`009_ooo`80000;oooo2P3o00030000oooooooo01_oool0
0`000?ooooooo`02oooo300003Koool00`00003o003o00020?l00`0000_oool00`000?ooooooo`06
oooo00<0003oooooool01oooo`00:?ooo`80000:oooo00<00000o`00o`001P3o00030000oooooooo
01_oool00`000?ooooooo`13oooo1`0000koool00`000?ooooooo`05oooo00<0003oooooool01ooo
o`00:Oooo`030000oooooooo00Woool00`00003o003o00050?l000<0003oooooool06oooo`030000
oooooooo047oool200000`3o0080000@oooo00<0003oooooool01Oooo`030000oooooooo00Ooool0
02[oool200002_ooo`0300000?l00?l000@0o`000`000?ooooooo`0Koooo00<0003oooooool0?ooo
o`8000030?l00P0001?oool00`000?ooooooo`04oooo00<0003oooooool01oooo`00;?ooo`800008
oooo00<00000o`00o`00103o00030000oooooooo01_oool00`000?ooooooo`0noooo00@00000o`00
o`00o`0200005_ooo`030000oooooooo00Coool00`000?ooooooo`06oooo000]oooo0P0000Soool0
0`00003o003o00030?l000<0003oooooool06oooo`030000oooooooo03coool200000P3o0080000I
oooo00<0003oooooool00oooo`030000oooooooo00Koool002ooool00`000?ooooooo`06oooo00<0
0000o`00o`000P3o00030000oooooooo01_oool00`000?ooooooo`0joooo0P000080o`0200007?oo
o`030000oooooooo00;oool00`000?ooooooo`06oooo000`oooo0P0000Ooool01@00003o003o003o
0000000Moooo00<0003oooooool0>?ooo`8000020?l00P0001koool00`000?ooooooo`02oooo00<0
003oooooool01_ooo`008oooo`800004oooo0P0000Coool400001oooo`@0000Moooo00<0003ooooo
ool0=_ooo`H0000Qoooo00D0003oooooooooool000002?ooo`008_ooo`040000oooooooo00002?oo
o`060000oooooooo0000oooo00001oooo`<0o`000`000?ooooooo`0Joooo00<0003oooooool0<ooo
o`<000020?l000<0003oooooool08oooo`040000oooooooo00002?ooo`008_ooo`040000oooooooo
00002oooo`030000oooooooo00800007oooo0P3o0080000Joooo00<0003oooooool0<?ooo`@00000
0`3o00000?ooo`0Xoooo00<0003oool000002?ooo`007?ooo`@00002oooo00@0003oooooool00009
oooo0P0000Goool00`000?ooooooo`05oooo00@00000o`00o`00000Ioooo00<0003oooooool0;Ooo
o`H0000]oooo00<0003oool000001oooo`008_ooo`040000oooooooo00002Oooo`030000oooooooo
00Goool00`000?ooo`000006oooo00<00000o`0000006?ooo`<0000Yoooo1`00033oool00`000?oo
o`000007oooo000Soooo0P0000[oool300001_ooo`800007oooo00@00000o`000000000Foooo00<0
0000o`00o`00100002;oool70000=?ooo`800007oooo000joooo00<0003oool000001_ooo`030000
0?l0000001?oool200001`3o00@0000Ioooo2@0003Koool300001oooo`00>oooo`800008oooo1000
00ooool00`00003o003o000;0?l01@0000koool;0000=_ooo`@0000:oooo000loooo0P0000Woool6
00002Oooob<000030?l01@0003Coool500003_ooo`00?_ooo`030000oooo000000Soool200000P3o
00/0000=0?l00P0000/0o`0200000`3o00H0000doooo100001?oool003ooool200002_ooo`/00002
0?l01P0000D0o`0200002P3o00T0000eoooo100001Ooool0047oool00`000?ooooooo`0>oooo8000
03Koool500006oooo`00@_ooo`80000Goooo00<0003oooooool0A_ooo`@0000Poooo0013oooo0P00
01Koool00`000?ooooooo`11oooo1@0002Coool003_oool200002?ooo`030000oooo000001?oool0
0`000?ooooooo`0moooo100002Woool003[oool010000?ooooooo`0000Soool200004_ooo`030000
oooooooo03Woool50000;Oooo`00>_ooo`040000oooooooo00002_ooo`030000oooooooo00ooool0
0`000?ooooooo`0eoooo100003;oool003[oool010000?ooooooo`0000_oool200003oooo`030000
oooooooo037oool40000=_ooo`00>_ooo`040000oooooooo00003?ooo`8000000oooo`000?ooo`0;
oooo00<0003oooooool0;?ooo`D0000joooo000koooo0P0000ooool200003?ooo`030000oooooooo
02Soool40000?oooo`00COooo`80000;oooo00<0003oooooool08oooo`D00013oooo001?oooo00<0
003oool000002?ooo`030000oooooooo01ooool40000B?ooo`00D?ooo`800008oooo00<0003ooooo
ool06_ooo`D0001<oooo001Aoooo0P000003oooo0000oooo00Coool00`000?ooooooo`0Foooo1000
057oool005?oool200001Oooo`030000oooooooo017oool50000EOooo`00E?ooo`800004oooo00<0
003oooooool03Oooo`@0001Joooo0016oooo0P0000Coool200001?ooo`800002oooo0P0000;oool0
0`000?ooooooo`09oooo100005koool004Goool010000?ooooooo`0000Soool010000?ooooooo`00
00;oool010000?ooooooo`0000Koool50000H_ooo`00AOooo`040000oooooooo00002oooo`040000
oooooooooooo0`0000;oool40000Ioooo`00AOooo`040000oooooooo00002Oooo`800006oooo0`00
06_oool004Goool010000?ooooooo`0000Woool00`000?ooooooo`1coooo0016oooo0P0000[oool3
0000Loooo`00b?ooo`00b?ooo`00;Oooo`<0000boooo0`0006?oool0033oool00`000?ooooooo`0`
oooo00<0003oooooool0H_ooo`008Oooo`<00004oooo0`0000?oool300000oooo`800003oooo1@00
00;oool200002?ooo`D000001?ooo`0000000?ooo`800002oooo1`000005oooo0000oooo0000oooo
00<00003oooo0`0000Coool300002Oooo`800003oooo100000Woool200000_ooo`@0000:oooo1000
0003oooo0000000000<00002oooo0P0000?oool500004_ooo`008_ooo`030000oooooooo00Coool0
1@000?ooooooooooo`000002oooo00<0003oooooool02?ooo`030000oooooooo00goool010000?oo
ooooo`0000;oool00`000?ooo`000003oooo100000;oool01`000?ooo`000?ooo`000?ooo`000002
oooo00D0003oooooooooool000001?ooo`030000oooooooo00Woool010000?ooooooo`0000?oool0
0`000?ooooooo`08oooo00@0003oooooool00002oooo00@0003oooooool00008oooo00@0003ooooo
ool00002oooo100000;oool010000?ooooooo`0000;oool400004oooo`008_ooo`030000oooooooo
00Coool01@000?ooooooooooo`000002oooo00<0003oooooool02?ooo`030000oooooooo00goool0
0`000?ooooooo`04oooo00<0003oooooool01Oooo`0:0000oooooooo0000oooo0000oooo0000oooo
00000_ooo`050000oooooooooooo000000Coool400002?ooo`040000oooooooo00000oooo`030000
oooooooo00[oool01@000?ooooooooooo`000002oooo00<0003oooooool01_ooo`040000oooooooo
00001Oooo`040000oooooooo00002?ooo`030000oooooooo017oool002;oool200001?ooo`800004
oooo100000Woool00`000?ooooooo`0=oooo0P0000?oool2000000?oool0000000000oooo`<00000
1oooo`00000000000?ooo`000?ooo`0400001?ooo`030000oooooooo00?oool200002_ooo`800003
oooo100000_oool010000?ooooooo`0000;oool00`000?ooooooo`07oooo0`0000?oool3000000?o
ool0000000000`0000?oool300004oooo`008_ooo`040000oooooooo00005Oooo`030000oooooooo
00goool010000?ooooooo`0001_oool00`000?ooooooo`0Eoooo00<0003oooooool02?ooo`040000
oooooooo00000_ooo`040000oooooooo00002oooo`030000oooooooo00Koool00`000?ooooooo`0J
oooo000Qoooo1@0000?oool00`000?ooooooo`0>oooo0P0000koool500006_ooo`80000Hoooo0P00
00Woool200000_ooo`@0000;oooo0P0002Goool00<Soool00<Soool00001\
\>"],
  ImageRangeCache->{{{0, 199}, {199, 0}} -> {-0.0685637, -0.003469, \
0.0050692, 0.0050692}}]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox["Using the Daubechies 2",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["nd",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[", 4",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" and 6",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[
  " order base functions, we construct the wavelet transform matrix \"wMat\", \
and then we compute a wavelet spectrum \"wSpect\". Figure 2 shows the wavelet \
spectrum.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
base={daub2,daub4,daub6};
wMat=Table[waveletMatrix[8,base[[i]]],{i,3}];
wSpect=waveletND[data3D,wMat,3];
ListContourPlot3D[wSpect,PlotLabel->\"Fig.2.3D wavelet spectrum\",
 \tMeshRange -> {{-1,1}, {-1,1}, {-1,1}},
\tMeshRange -> {{-1,1}, {-1,1}, {-1,1}},
\tContours -> {1.5, 3.},Lighting -> False, Axes -> True,
    ContourStyle -> {{RGBColor[0,1,0]},{RGBColor[1,0,0]}},
    ImageSize->{200,200}];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.15628 
%%ImageSize: 200 200 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0865476 1.22944 0 1.22944 [
[.5 1.16878 -77 0 ]
[.5 1.16878 77 12.5625 ]
[.09059 .21864 -11.699 -9 ]
[.09059 .21864 .30102 0 ]
[.20136 .17209 -28.2281 -9 ]
[.20136 .17209 1.77186 0 ]
[.31686 .12358 -21.7671 -9 ]
[.31686 .12358 2.23292 0 ]
[.43739 .07297 -26.1896 -9 ]
[.43739 .07297 3.81045 0 ]
[.56329 .02014 -5.03405 -9 ]
[.56329 .02014 .96595 0 ]
[.01015 .87625 -6.84344 0 ]
[.01015 .87625 5.15656 9 ]
[.19196 1.00729 -13.0573 0 ]
[.19196 1.00729 10.9428 9 ]
[.34609 1.11838 -3.13909 0 ]
[.34609 1.11838 2.86091 9 ]
[.0731 .25302 -12 -2.62739 ]
[.0731 .25302 0 6.37261 ]
[.04343 .457 -24 -2.79144 ]
[.04343 .457 0 6.20856 ]
[.00951 .6902 -6 -2.98127 ]
[.00951 .6902 0 6.01873 ]
[ 0 0 0 0 ]
[ 1 1.15628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.16878 -138 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.813 moveto
(.2) show
93.000 12.813 moveto
(.3) show
105.000 12.813 moveto
(D) show
117.000 12.813 moveto
(wavelet) show
165.000 12.813 moveto
(spectrum) show
213.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.08906 .23485 m
.65047 0 L
s
.10117 .22978 m
.10646 .23535 L
s
[(-1)] .09059 .21864 .94983 1 Mshowa
.21153 .18362 m
.21661 .18938 L
s
[(-0.75)] .20136 .17209 .88188 1 Mshowa
.32656 .1355 m
.33141 .14146 L
s
[(-0.5)] .31686 .12358 .81392 1 Mshowa
.44658 .08529 m
.45118 .09145 L
s
[(-0.25)] .43739 .07297 .74597 1 Mshowa
.57192 .03286 m
.57623 .03922 L
s
[(0)] .56329 .02014 .67802 1 Mshowa
.125 Mabswid
.12288 .2207 m
.12603 .22406 L
s
.14477 .21154 m
.1479 .21493 L
s
.16684 .20231 m
.16994 .20572 L
s
.18909 .193 m
.19217 .19644 L
s
.23415 .17415 m
.23717 .17763 L
s
.25696 .16461 m
.25996 .16811 L
s
.27997 .15499 m
.28294 .15851 L
s
.30317 .14528 m
.30611 .14883 L
s
.35016 .12563 m
.35304 .12923 L
s
.37395 .11567 m
.3768 .11929 L
s
.39796 .10563 m
.40078 .10928 L
s
.42216 .0955 m
.42495 .09918 L
s
.47121 .07499 m
.47394 .07871 L
s
.49606 .06459 m
.49875 .06834 L
s
.52112 .05411 m
.52378 .05788 L
s
.54641 .04353 m
.54903 .04732 L
s
.59765 .0221 m
.6002 .02594 L
s
.62362 .01123 m
.62613 .0151 L
s
.64982 .00027 m
.6523 .00416 L
s
.25 Mabswid
0 .85214 m
.42042 1.15628 L
s
.01229 .86103 m
.01336 .85342 L
s
[(-1)] .01015 .87625 .14057 -1 Mshowa
.19331 .99198 m
.19398 .98433 L
s
[(-0.5)] .19196 1.00729 .0881 -1 Mshowa
.34681 1.10303 m
.34716 1.09535 L
s
[(0)] .34609 1.11838 .04636 -1 Mshowa
.125 Mabswid
.05104 .88907 m
.05163 .88449 L
s
.08846 .91613 m
.089 .91155 L
s
.1246 .94228 m
.12509 .93769 L
s
.15953 .96754 m
.15997 .96296 L
s
.22599 1.01563 m
.22636 1.01103 L
s
.25764 1.03852 m
.25796 1.03392 L
s
.28829 1.0607 m
.28858 1.0561 L
s
.318 1.08219 m
.31825 1.07758 L
s
.37475 1.12324 m
.37493 1.11863 L
s
.40186 1.14286 m
.40201 1.13825 L
s
.25 Mabswid
.08906 .23485 m
0 .85214 L
s
.08729 .24711 m
.09438 .24416 L
s
[(-1)] .0731 .25302 1 -0.41614 Mshowa
.05779 .45155 m
.06498 .44882 L
s
[(-0.5)] .04343 .457 1 -0.37968 Mshowa
.02407 .68529 m
.03135 .68283 L
s
[(0)] .00951 .6902 1 -0.33749 Mshowa
.125 Mabswid
.08169 .28592 m
.08596 .28418 L
s
.07595 .32573 m
.08022 .32401 L
s
.07005 .36658 m
.07434 .36488 L
s
.064 .4085 m
.0683 .40684 L
s
.05142 .49576 m
.05574 .49415 L
s
.04486 .54119 m
.04919 .53961 L
s
.03813 .58788 m
.04247 .58634 L
s
.0312 .6359 m
.03555 .63439 L
s
.01674 .73612 m
.02112 .73468 L
s
.00919 .78845 m
.01358 .78705 L
s
.00141 .84235 m
.00582 .84099 L
s
.25 Mabswid
.08906 .23485 m
0 .85214 L
s
0 .85214 m
.42042 1.15628 L
s
.42042 1.15628 m
.43563 .59681 L
s
.43563 .59681 m
.08906 .23485 L
s
.65047 0 m
.92763 .43516 L
s
.92763 .43516 m
1 1.02289 L
s
1 1.02289 m
.67851 .64381 L
s
.67851 .64381 m
.65047 0 L
s
.08906 .23485 m
0 .85214 L
s
0 .85214 m
.67851 .64381 L
s
.67851 .64381 m
.65047 0 L
s
.65047 0 m
.08906 .23485 L
s
.43563 .59681 m
.92763 .43516 L
s
.92763 .43516 m
1 1.02289 L
s
1 1.02289 m
.42042 1.15628 L
s
.42042 1.15628 m
.43563 .59681 L
s
0 0 m
1 0 L
1 1.15628 L
0 1.15628 L
closepath
clip
newpath
.5 Mabswid
.34644 .55225 m .37545 .5308 L .49122 .49098 L p 1 0 0 r
F P
0 g
s
.46506 .5117 m .49122 .49098 L .61188 .44948 L p 1 0 0 r
F P
0 g
s
.49122 .49098 m .46506 .5117 L .34644 .55225 L p 1 0 0 r
F P
0 g
s
.34644 .55225 m .33516 .48865 L .45267 .44705 L p 1 0 0 r
F P
0 g
s
.45267 .44705 m .46506 .5117 L .34644 .55225 L p 1 0 0 r
F P
0 g
s
.58885 .46938 m .61188 .44948 L .73776 .40619 L p 1 0 0 r
F P
0 g
s
.61188 .44948 m .58885 .46938 L .46506 .5117 L p 1 0 0 r
F P
0 g
s
.46506 .5117 m .45267 .44705 L .57526 .40365 L p 1 0 0 r
F P
0 g
s
.57526 .40365 m .58885 .46938 L .46506 .5117 L p 1 0 0 r
F P
0 g
s
.18493 .44582 m .25796 .40788 L .37583 .35948 L p 1 0 0 r
F P
0 g
s
.73776 .40619 m .71816 .42518 L .58885 .46938 L p 1 0 0 r
F P
0 g
s
.71816 .42518 m .77574 .35368 L .73776 .40619 L closepath p 1 0 0 r
F P
0 g
s
.58885 .46938 m .57526 .40365 L .70327 .35833 L p 1 0 0 r
F P
0 g
s
.18586 .43698 m .25292 .40261 L .37017 .35303 L p 0 1 0 r
F P
0 g
s
.70327 .35833 m .71816 .42518 L .58885 .46938 L p 1 0 0 r
F P
0 g
s
.31217 .39669 m .37583 .35948 L .50269 .31283 L p 1 0 0 r
F P
0 g
s
.37583 .35948 m .31217 .39669 L p .1889 .44402 L 1 0 0 r
F P
0 g
s
.3129 .38594 m .37017 .35303 L .49745 .30628 L p 0 1 0 r
F P
0 g
s
.3129 .38594 m .18586 .43698 L p .19386 .43334 L 0 1 0 r
F P
0 g
s
.37017 .35303 m .3129 .38594 L p .19386 .43334 L 0 1 0 r
F P
0 g
s
.44561 .33704 m .3129 .38594 L p .32023 .38278 L 0 1 0 r
F P
0 g
s
.49745 .30628 m .44561 .33704 L p .32023 .38278 L 0 1 0 r
F P
0 g
s
.44534 .34751 m .50269 .31283 L .63825 .26811 L p 1 0 0 r
F P
0 g
s
.44534 .34751 m .31217 .39669 L p .3158 .39509 L 1 0 0 r
F P
0 g
s
.50269 .31283 m .44534 .34751 L p .3158 .39509 L 1 0 0 r
F P
0 g
s
.44561 .33704 m .49745 .30628 L .6343 .26263 L p 0 1 0 r
F P
0 g
s
.6343 .26263 m .585 .28984 L .44561 .33704 L p 0 1 0 r
F P
0 g
s
.44561 .33704 m .36416 .22833 L p .57933 .28827 L 0 1 0 r
F P
0 g
s
.585 .28984 m .44561 .33704 L p .57933 .28827 L 0 1 0 r
F P
0 g
s
.3129 .38594 m .22801 .28099 L p .4396 .33549 L 0 1 0 r
F P
0 g
s
.44561 .33704 m .3129 .38594 L p .4396 .33549 L 0 1 0 r
F P
0 g
s
.63825 .26811 m .58515 .29797 L .44534 .34751 L p 1 0 0 r
F P
0 g
s
.22801 .28099 m .36416 .22833 L .44561 .33704 L p 0 1 0 r
F P
0 g
s
.44534 .34751 m .36331 .24416 L p .58217 .29724 L 1 0 0 r
F P
0 g
s
.58515 .29797 m .44534 .34751 L p .58217 .29724 L 1 0 0 r
F P
0 g
s
.3129 .38594 m .18586 .43698 L .09719 .34069 L p 0 1 0 r
F P
0 g
s
.09719 .34069 m .22801 .28099 L .3129 .38594 L p 0 1 0 r
F P
0 g
s
.31217 .39669 m .22641 .29755 L p .44216 .34679 L 1 0 0 r
F P
0 g
s
.44534 .34751 m .31217 .39669 L p .44216 .34679 L 1 0 0 r
F P
0 g
s
.31217 .39669 m .18493 .44582 L p .1889 .44402 L 1 0 0 r
F P
0 g
s
.71816 .42518 m .77574 .35368 L .70327 .35833 L closepath p 1 0 0 r
F P
0 g
s
.31217 .39669 m .18493 .44582 L .09547 .3532 L p 1 0 0 r
F P
0 g
s
.585 .28984 m .70502 .1442 L .6343 .26263 L closepath p 0 1 0 r
F P
0 g
s
.58515 .29797 m .71498 .14031 L .63825 .26811 L closepath p 1 0 0 r
F P
0 g
s
.30862 .44936 m .35753 .58344 L .22798 .62691 L p 1 0 0 r
F P
0 g
s
.22798 .62691 m .17962 .49617 L .30862 .44936 L p 1 0 0 r
F P
0 g
s
.16703 .61552 m .22798 .62691 L .35753 .58344 L p 1 0 0 r
F P
0 g
s
.30862 .44936 m .17962 .49617 L .08798 .40797 L p 1 0 0 r
F P
0 g
s
.09547 .3532 m .22641 .29755 L .31217 .39669 L p 1 0 0 r
F P
0 g
s
.30573 .49232 m .32824 .55393 L .19739 .59877 L p 0 1 0 r
F P
0 g
s
.19739 .59877 m .17513 .53871 L .30573 .49232 L p 0 1 0 r
F P
0 g
s
.1694 .59312 m .19739 .59877 L .32824 .55393 L p 0 1 0 r
F P
0 g
s
.30573 .49232 m .17513 .53871 L .08205 .45127 L p 0 1 0 r
F P
0 g
s
.44395 .40026 m .49339 .53784 L .35753 .58344 L p 1 0 0 r
F P
0 g
s
.35753 .58344 m .30862 .44936 L .44395 .40026 L p 1 0 0 r
F P
0 g
s
.3005 .56994 m .35753 .58344 L .49339 .53784 L p 1 0 0 r
F P
0 g
s
.35753 .58344 m .3005 .56994 L .16703 .61552 L p 1 0 0 r
F P
0 g
s
.44395 .40026 m .30862 .44936 L .22065 .3568 L p 1 0 0 r
F P
0 g
s
.08798 .40797 m .22065 .3568 L .30862 .44936 L p 1 0 0 r
F P
0 g
s
.32824 .55393 m .30203 .5473 L .1694 .59312 L p 0 1 0 r
F P
0 g
s
.30203 .5473 m .1694 .59312 L .07447 .50672 L p 0 1 0 r
F P
0 g
s
.22641 .29755 m .36331 .24416 L .44534 .34751 L p 1 0 0 r
F P
0 g
s
.44281 .44362 m .46558 .50687 L .32824 .55393 L p 0 1 0 r
F P
0 g
s
.32824 .55393 m .30573 .49232 L .44281 .44362 L p 0 1 0 r
F P
0 g
s
.30203 .5473 m .32824 .55393 L .46558 .50687 L p 0 1 0 r
F P
0 g
s
.3005 .56994 m .16703 .61552 L .07134 .52957 L p 1 0 0 r
F P
0 g
s
.44281 .44362 m .30573 .49232 L .21641 .40048 L p 0 1 0 r
F P
0 g
s
.08205 .45127 m .21641 .40048 L .30573 .49232 L p 0 1 0 r
F P
0 g
s
.70502 .1442 m .585 .28984 L .50742 .18107 L p 0 1 0 r
F P
0 g
s
.50742 .18107 m .62692 .03833 L .70502 .1442 L p 0 1 0 r
F P
0 g
s
.58608 .3487 m .63605 .48997 L .49339 .53784 L p 1 0 0 r
F P
0 g
s
.49339 .53784 m .44395 .40026 L .58608 .3487 L p 1 0 0 r
F P
0 g
s
.44076 .52204 m .49339 .53784 L .63605 .48997 L p 1 0 0 r
F P
0 g
s
.49339 .53784 m .44076 .52204 L .3005 .56994 L p 1 0 0 r
F P
0 g
s
.36416 .22833 m .50742 .18107 L .585 .28984 L p 0 1 0 r
F P
0 g
s
.71498 .14031 m .58515 .29797 L .50734 .19209 L p 1 0 0 r
F P
0 g
s
.50734 .19209 m .64073 .03261 L .71498 .14031 L p 1 0 0 r
F P
0 g
s
.58608 .3487 m .44395 .40026 L .36013 .30299 L p 1 0 0 r
F P
0 g
s
.22065 .3568 m .36013 .30299 L .44395 .40026 L p 1 0 0 r
F P
0 g
s
.46558 .50687 m .44136 .49916 L .30203 .5473 L p 0 1 0 r
F P
0 g
s
.44136 .49916 m .30203 .5473 L .21097 .45648 L p 0 1 0 r
F P
0 g
s
.07447 .50672 m .21097 .45648 L .30203 .5473 L p 0 1 0 r
F P
0 g
s
.36331 .24416 m .50734 .19209 L .58515 .29797 L p 1 0 0 r
F P
0 g
s
.58688 .39244 m .60989 .45741 L .46558 .50687 L p 0 1 0 r
F P
0 g
s
.46558 .50687 m .44281 .44362 L .58688 .39244 L p 0 1 0 r
F P
0 g
s
.44136 .49916 m .46558 .50687 L .60989 .45741 L p 0 1 0 r
F P
0 g
s
.44076 .52204 m .3005 .56994 L .20872 .47957 L p 1 0 0 r
F P
0 g
s
.07134 .52957 m .20872 .47957 L .3005 .56994 L p 1 0 0 r
F P
0 g
s
.58688 .39244 m .44281 .44362 L .35775 .34706 L p 0 1 0 r
F P
0 g
s
.21641 .40048 m .35775 .34706 L .44281 .44362 L p 0 1 0 r
F P
0 g
s
.63605 .48997 m .58608 .3487 L .68582 .39534 L closepath p 1 0 0 r
F P
0 g
s
.60989 .45741 m .58791 .44852 L .44136 .49916 L p 0 1 0 r
F P
0 g
s
.60989 .45741 m .58688 .39244 L .63167 .41423 L closepath p 0 1 0 r
F P
0 g
s
.58791 .44852 m .63167 .41423 L .60989 .45741 L closepath p 0 1 0 r
F P
0 g
s
.58833 .47164 m .68582 .39534 L .63605 .48997 L closepath p 1 0 0 r
F P
0 g
s
.63605 .48997 m .58833 .47164 L .44076 .52204 L p 1 0 0 r
F P
0 g
s
.68582 .39534 m .58608 .3487 L .50696 .24636 L p 1 0 0 r
F P
0 g
s
.36013 .30299 m .50696 .24636 L .58608 .3487 L p 1 0 0 r
F P
0 g
s
.58791 .44852 m .44136 .49916 L .3547 .40358 L p 0 1 0 r
F P
0 g
s
.21097 .45648 m .3547 .40358 L .44136 .49916 L p 0 1 0 r
F P
0 g
s
.13518 .91759 m .17535 .86875 L .31587 .82744 L p 1 0 0 r
F P
0 g
s
.28607 .78401 m .31587 .82744 L .17535 .86875 L p 1 0 0 r
F P
0 g
s
.17535 .86875 m .14474 .8269 L .28607 .78401 L p 1 0 0 r
F P
0 g
s
.58833 .47164 m .44076 .52204 L .35344 .4269 L p 1 0 0 r
F P
0 g
s
.20872 .47957 m .35344 .4269 L .44076 .52204 L p 1 0 0 r
F P
0 g
s
.63167 .41423 m .58688 .39244 L .50666 .29077 L p 0 1 0 r
F P
0 g
s
.35775 .34706 m .50666 .29077 L .58688 .39244 L p 0 1 0 r
F P
0 g
s
.28607 .78401 m .14474 .8269 L .04173 .74591 L p 1 0 0 r
F P
0 g
s
.63167 .41423 m .58791 .44852 L .50626 .3478 L p 0 1 0 r
F P
0 g
s
.3547 .40358 m .50626 .3478 L .58791 .44852 L p 0 1 0 r
F P
0 g
s
.50666 .29077 m .55208 .31159 L .63167 .41423 L p 0 1 0 r
F P
0 g
s
.50626 .3478 m .55208 .31159 L .63167 .41423 L p 0 1 0 r
F P
0 g
s
.27987 .87606 m .31587 .82744 L .46392 .78392 L p 1 0 0 r
F P
0 g
s
.43507 .7388 m .46392 .78392 L .31587 .82744 L p 1 0 0 r
F P
0 g
s
.31587 .82744 m .28607 .78401 L .43507 .7388 L p 1 0 0 r
F P
0 g
s
.31587 .82744 m .27987 .87606 L .13518 .91759 L p 1 0 0 r
F P
0 g
s
.68582 .39534 m .58833 .47164 L .5061 .37134 L p 1 0 0 r
F P
0 g
s
.35344 .4269 m .5061 .37134 L .58833 .47164 L p 1 0 0 r
F P
0 g
s
.50696 .24636 m .6082 .29074 L .68582 .39534 L p 1 0 0 r
F P
0 g
s
.5061 .37134 m .6082 .29074 L .68582 .39534 L p 1 0 0 r
F P
0 g
s
.27987 .87606 m .13518 .91759 L .02898 .83911 L p 1 0 0 r
F P
0 g
s
.43507 .7388 m .28607 .78401 L .18745 .69858 L p 1 0 0 r
F P
0 g
s
.04173 .74591 m .18745 .69858 L .28607 .78401 L p 1 0 0 r
F P
0 g
s
.43262 .83221 m .46392 .78392 L .62011 .73801 L p 1 0 0 r
F P
0 g
s
.59236 .69107 m .62011 .73801 L .46392 .78392 L p 1 0 0 r
F P
0 g
s
.46392 .78392 m .43507 .7388 L .59236 .69107 L p 1 0 0 r
F P
0 g
s
.46392 .78392 m .43262 .83221 L .27987 .87606 L p 1 0 0 r
F P
0 g
s
.43262 .83221 m .27987 .87606 L .17826 .79316 L p 1 0 0 r
F P
0 g
s
.02898 .83911 m .17826 .79316 L .27987 .87606 L p 1 0 0 r
F P
0 g
s
.59236 .69107 m .43507 .7388 L .34147 .64855 L p 1 0 0 r
F P
0 g
s
.18745 .69858 m .34147 .64855 L .43507 .7388 L p 1 0 0 r
F P
0 g
s
.5941 .78586 m .64735 .69205 L .62011 .73801 L closepath p 1 0 0 r
F P
0 g
s
.62011 .73801 m .59236 .69107 L .64735 .69205 L closepath p 1 0 0 r
F P
0 g
s
.62011 .73801 m .5941 .78586 L .43262 .83221 L p 1 0 0 r
F P
0 g
s
.5941 .78586 m .43262 .83221 L .33629 .74451 L p 1 0 0 r
F P
0 g
s
.17826 .79316 m .33629 .74451 L .43262 .83221 L p 1 0 0 r
F P
0 g
s
.64735 .69205 m .59236 .69107 L .50454 .59558 L p 1 0 0 r
F P
0 g
s
.34147 .64855 m .50454 .59558 L .59236 .69107 L p 1 0 0 r
F P
0 g
s
.64735 .69205 m .5941 .78586 L .50386 .69293 L p 1 0 0 r
F P
0 g
s
.50454 .59558 m .56122 .59516 L .64735 .69205 L p 1 0 0 r
F P
0 g
s
.50386 .69293 m .56122 .59516 L .64735 .69205 L p 1 0 0 r
F P
0 g
s
.33629 .74451 m .50386 .69293 L .5941 .78586 L p 1 0 0 r
F P
0 g
s
.25 Mabswid
.65047 0 m
.92763 .43516 L
s
.92763 .43516 m
1 1.02289 L
s
1 1.02289 m
.67851 .64381 L
s
.67851 .64381 m
.65047 0 L
s
.08906 .23485 m
0 .85214 L
s
0 .85214 m
.67851 .64381 L
s
.67851 .64381 m
.65047 0 L
s
.65047 0 m
.08906 .23485 L
s
.08906 .23485 m
.65047 0 L
s
.10117 .22978 m
.10646 .23535 L
s
[(-1)] .09059 .21864 .94983 1 Mshowa
.21153 .18362 m
.21661 .18938 L
s
[(-0.75)] .20136 .17209 .88188 1 Mshowa
.32656 .1355 m
.33141 .14146 L
s
[(-0.5)] .31686 .12358 .81392 1 Mshowa
.44658 .08529 m
.45118 .09145 L
s
[(-0.25)] .43739 .07297 .74597 1 Mshowa
.57192 .03286 m
.57623 .03922 L
s
[(0)] .56329 .02014 .67802 1 Mshowa
.125 Mabswid
.12288 .2207 m
.12603 .22406 L
s
.14477 .21154 m
.1479 .21493 L
s
.16684 .20231 m
.16994 .20572 L
s
.18909 .193 m
.19217 .19644 L
s
.23415 .17415 m
.23717 .17763 L
s
.25696 .16461 m
.25996 .16811 L
s
.27997 .15499 m
.28294 .15851 L
s
.30317 .14528 m
.30611 .14883 L
s
.35016 .12563 m
.35304 .12923 L
s
.37395 .11567 m
.3768 .11929 L
s
.39796 .10563 m
.40078 .10928 L
s
.42216 .0955 m
.42495 .09918 L
s
.47121 .07499 m
.47394 .07871 L
s
.49606 .06459 m
.49875 .06834 L
s
.52112 .05411 m
.52378 .05788 L
s
.54641 .04353 m
.54903 .04732 L
s
.59765 .0221 m
.6002 .02594 L
s
.62362 .01123 m
.62613 .0151 L
s
.64982 .00027 m
.6523 .00416 L
s
.25 Mabswid
0 .85214 m
.42042 1.15628 L
s
.01229 .86103 m
.01336 .85342 L
s
[(-1)] .01015 .87625 .14057 -1 Mshowa
.19331 .99198 m
.19398 .98433 L
s
[(-0.5)] .19196 1.00729 .0881 -1 Mshowa
.34681 1.10303 m
.34716 1.09535 L
s
[(0)] .34609 1.11838 .04636 -1 Mshowa
.125 Mabswid
.05104 .88907 m
.05163 .88449 L
s
.08846 .91613 m
.089 .91155 L
s
.1246 .94228 m
.12509 .93769 L
s
.15953 .96754 m
.15997 .96296 L
s
.22599 1.01563 m
.22636 1.01103 L
s
.25764 1.03852 m
.25796 1.03392 L
s
.28829 1.0607 m
.28858 1.0561 L
s
.318 1.08219 m
.31825 1.07758 L
s
.37475 1.12324 m
.37493 1.11863 L
s
.40186 1.14286 m
.40201 1.13825 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{200, 200},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000380000b1P00`40o`000?l0003ob?ooo`00L_oo
o`80001Doooo001aoooo00@0003oooooool0001Coooo001aoooo00@0003oooooool0001Coooo001a
oooo00@0003oooooool0001Coooo001aoooo00@0003oooooool0001Coooo001boooo0P0000koool2
0000A?ooo`00P?ooo`8000000oooo`0000000013oooo001noooo0P0000?oool20000@oooo`00Nooo
o`<000000oooo`000?ooo`02oooo00<0003oool00000@_ooo`00D?ooo`800004oooo0P0000?oool4
00000oooo`80000Eoooo0`0000Ooool010000?ooooooo`00047oool004ooool010000?ooooooo`00
00Soool00`000?ooooooo`03oooo00@0003oooooool0000Boooo0P0000Soool00`000?ooo`000002
oooo00<0003oooooool0?oooo`00Coooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`0=oooo100000Ooool2000000?o0000000000000oooo`030000oooooooo03koool0
04Woool400000_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200003_ooo`80000:
oooo0P0000;o000200000oooo`030000oooooooo03koool004ooool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`0;oooo0P000003oooo0000oooo00Soool00`00003o
00000003o`0000<0003oooooool00_ooo`030000oooooooo03goool0053oool200002_ooo`800004
oooo0`0000Soool300003Oooo`800004o`000P0000Coool00`000?ooooooo`0loooo001[oooo0P00
00ooool200001Ol000030000o`00000000?oool00`000?ooooooo`0loooo0012oooo0P0000Coool2
00001?ooo`80000Hoooo100000ooool200001_l000030000o`00000000Coool00`000?ooooooo`0k
oooo0011oooo00@0003oooooool00008oooo00@0003oooooool0000Eoooo0P0001;oool200001ol0
00040000o`00o`0000001?ooo`030000oooooooo03[oool0047oool010000?ooooooo`0000_oool0
0`000?ooooooo`0Aoooo0P0000;oool00`000?ooooooo`0>oooo00<00000o`0000002?l000040000
o`00o`0000000oooo`030000oooooooo03[oool003_oool400000_ooo`040000oooooooo00002Ooo
o`80000Aoooo0`0001Coool00`00003o00000009o`0000@0003o003o00000004oooo00<0003ooooo
ool0>Oooo`00@Oooo`040000oooooooo00002Oooo`030000oooooooo00koool200000oooo`030000
oooooooo017oool200002_l000050000o`00o`00o`00000000?oool00`000?ooooooo`0ioooo0012
oooo0P0000[oool300003?ooo`8000000oooo`000?ooo`0Eoooo0P0000_o00000`000?l00?l00002
o`0000D0003oooooooooool00000>_ooo`00F_ooo`<0000Ioooo0P0000co00000`000?l00?l00002
o`0000<0003oooooool00_ooo`030000oooooooo03Ooool005Soool200006oooo`0300000?l00000
00co00000`000?l00?l00003o`0000D0003oooooooooool00000>Oooo`00:Oooo`800004oooo0P00
00Goool00`000?ooooooo`02oooo0P0001Woool2000000?oool0003oool06Oooo`0300000?l00000
00go00000`000?l00?l00004o`0000D0003oooooooooool00000>?ooo`00:?ooo`040000oooooooo
00002_ooo`050000oooooooooooo000000;oool00`000?ooooooo`0Coooo0`0001koool200003_l0
00030000o`00o`0000Go00001@000?ooooooooooo`00000goooo000Xoooo00@0003oooooool0000:
oooo00<0003oooooool01?ooo`030000oooooooo017oool200008?ooo`80000?o`0000<0003o003o
00001Ol000050000oooooooooooo000003Ooool002;oool400000_ooo`040000oooooooo00002ooo
o`040000oooooooooooo0P0001;oool2000000?oool0003oool07_ooo`80000@o`0000<0003o003o
00001_l000050000oooooooooooo000003Koool002Soool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`0>oooo0`0002;oool00`00003o0000000@o`0000<0003o003o
00001Ol000030000oooooooo00?oool00`000?ooooooo`0coooo000Yoooo0P0000Woool400000ooo
o`<0000<oooo0P0002Coool00`00003o0000000Ao`0000<0003o003o00001?l000800005oooo00<0
003oooooool0<oooo`00B?ooo`<0000Toooo00<00000o`0000004_l000030000o`00o`0000?o0002
00001oooo`030000oooooooo03;oool002Soool500006?ooo`<0000Woooo0P0001?o00000`000?l0
0?l00003o`000P0000Ooool00`000?ooooooo`0boooo000Zoooo00<0003oooooool05_ooo`80000Y
oooo0P0001Co00000`000?l00?l00002o`000P0000Woool00`000?ooooooo`0aoooo000Zoooo00<0
003oooooool04oooo`@0000Xoooo0P0000030?l00000o`0001?o000010000?l00?l00?l00080000;
oooo00<0003oooooool0<?ooo`008_ooo`@00004oooo00<0003oooooool04Oooo`80000Yoooo0`00
0080o`000`000?l00?l0000Co`0000H0003o003o0000003o0000000;oooo00<0003oooooool0<?oo
o`00:_ooo`030000oooooooo00ooool200000_ooo`030000oooooooo02Coool200000`3o0080000F
o`0000D0003o0000003o000000003Oooo`030000oooooooo02ooool002Woool200003_ooo`@0000W
oooo0`000080o`0300000_l000030000o`00o`0001?o000200000_l000030000oooooooo00coool0
0`000?ooooooo`0^oooo000goooo0`0002Ooool300000`3o00800006o`0000<0003o003o00004_l0
008000000ol000000?ooo`0>oooo00<0003oooooool0;_ooo`00=Oooo`80000Woooo0`0000<0o`03
00002?l000030000o`00o`0001;o00000`000?l00000000Aoooo00<0003oooooool0;Oooo`00<Ooo
o`D0000Voooo0P0000<0o`0300003?l000030000o`00o`00013o0002000000?o0000003oool04Ooo
o`030000oooooooo02coool0033oool300009_ooo`<000020?l00`00013o00000`000?l00?l0000>
o`0000@0003o00000000000Coooo00<0003oooooool0;?ooo`00;_ooo`80000Voooo0`0000<0o`02
00005?l000030000o`00o`0000co00000`000?l00?l0000200005?ooo`030000oooooooo02_oool0
02coool2000000?oool0003oool08oooo`8000020?l0100001Ko00000`000?l00?l0000;o`0000D0
003o003o003o000000005Oooo`030000oooooooo02_oool002coool200008oooo`<000020?l00`00
01?o000300001?l000030000o`00o`0000[o00001P000?l00?l000000?ooo`0001Goool00`000?oo
ooooo`0Zoooo000/oooo00<0003oool000007oooo`<000020?l00`0000;o00000`000?l00?l0000?
o`000P0000?o000200000ol000030000o`00o`0000So00001`000?l00?l00?l000000?ooo`00000F
oooo00<0003oooooool0:Oooo`009Oooo`D00002oooo00@0003oooooool0000Loooo0P0000<0o`02
00001_l000030000o`00o`0000_o000300001ol000800002o`0000<0003o003o00001_l000050000
o`00o`00o`00000000;oool00`000?ooooooo`0Doooo00<0003oooooool0:Oooo`009oooo`050000
oooooooooooo000000Coool00`000?ooooooo`0Foooo0`000080o`0300002?l000030000o`00o`00
00Wo000200002?l000040000o`00o`00o`000`0000Oo00000`000?l00?l00002o`0000@0003ooooo
ool0000Goooo00<0003oooooool0:?ooo`009oooo`050000oooooooooooo000000Goool00`000?oo
ooooo`0Boooo0`000080o`0300003?l000030000o`00o`0000Go000300002ol000030000o`00o`00
00;o000200001Ol000030000o`00o`0000;o00001@000?ooooooooooo`00000Hoooo00<0003ooooo
ool09oooo`007oooo`@00004oooo00D0003oooooooooool000001_ooo`030000oooooooo00ooool2
00000P3o00<0000@o`0000@0003o003o003o000300003ol000030000o`00o`0000?o000200000_l0
00040000o`00o`00o`000P0000Coool00`000?ooooooo`0Foooo00<0003oooooool09oooo`009ooo
o`040000oooooooooooo0P0000Koool00`000?ooooooo`0;oooo0`000080o`0200005?l000<0000C
o`0000<0003o003o00001?l000<000000ol0000000000006oooo00<0003oooooool05oooo`030000
oooooooo02Koool002Koool200000oooo`030000oooooooo00Koool00`000?ooooooo`08oooo0P00
0080o`0300005?l000<0000?o`000P0000Co00000`000?l00?l00006o`000P0000Soool00`000?oo
ooooo`0Goooo00<0003oooooool09_ooo`00:oooo`030000oooooooo00Ooool00`000?ooooooo`05
oooo0P0000040?l00000000000005Ol00080000@o`000P000080o`0200000ol000030000o`00o`00
00Go00000`000?l000000007oooo00<0003oooooool06?ooo`030000oooooooo02Goool002_oool0
0`000?ooooooo`08oooo00@0003oooooooooool3000000<0o`00000000000_l000030000o`00o`00
013o000300003ol000<000060?l00P0000;o00000`000?l00?l00003o`0000D0003o003o003o0000
00001_ooo`030000oooooooo01Woool00`000?ooooooo`0Toooo000Zoooo00<0003oooooool02_oo
o`<000020?l00P0000Go00000`000?l00?l0000=o`000P0000;o00000`000?l00?l0000;o`000P00
00P0o`000`00003o003o0002000000Co0000003o003o000200001?l000030000oooooooo00Coool0
0`000?ooooooo`0Ioooo00<0003oooooool09?ooo`00:_ooo`030000oooooooo00Woool200000P3o
00800008o`0000<0003o003o00002Ol000<00005o`0000<0003o003o00001ol000<0000;0?l000@0
0000o`00o`00o`02000000?o0000003o00001_l000030000oooooooo00?oool00`000?ooooooo`0J
oooo00<0003oooooool08oooo`00:_ooo`800007oooo0`000080o`0200002ol000030000o`00o`00
00Ko000200002Ol000030000o`00o`0000?o000300003`3o00<000000`3o000000000009o`0000<0
003oooooool00_ooo`030000oooooooo01_oool00`000?ooooooo`0Roooo000Zoooo00<0003ooooo
ool01?ooo`8000020?l00`0000go00000`000?l00?l00004o`000P0000_o000010000?l00?l00?l0
0080000B0?l000D00000o`00o`00o`0000002ol000050000oooooooooooo000001goool00`000?oo
ooooo`0Roooo000Zoooo00<0003oooooool00_ooo`8000020?l00P00017o00000`000?l00?l00003
00003_l000<0000C0?l000D00000o`00o`00o`0000003?l000050000oooooooooooo000001koool0
0`000?ooooooo`0Qoooo000Zoooo00<0003oooooool00P000080o`0200005?l00080000?o`000P00
01@0o`0200000`3o00030000o`00o`0000co000010000?ooooooo`0001ooool00`000?ooooooo`0P
oooo000Yoooo00<0003oooooool00_ooo`<0000Co`000`0000ko00030000503o008000040?l000<0
003o003o00003_l000030000oooo000001ooool00`000?ooooooo`0Poooo000Yoooo00@0003ooooo
ooooool200004ol00080000>o`000`000080o`000`00003o003o000@0?l00P0000@0o`0200004_l0
0080000;oooo1P0000ooool00`000?ooooooo`0Ooooo000Yoooo00<0003oooooool00_ooo`030000
o`00o`0000ko000300003_l0008000060?l000<00000o`00o`00303o00<000050?l000<0003o003o
00004_l000800004oooo1`0000Co00000`000?ooooooo`0>oooo00<0003oooooool07oooo`00:Ooo
o`800004oooo00<0003o003o00002_l000<00002o`0000<0003o003o00002Ol000<000090?l000<0
0000o`00o`00203o00<000070?l000<0003o003o00005?l000030000oooo0000008000000ol00000
0?l00007o`0000<0003oooooool04?ooo`030000oooooooo01koool002Woool00`000?ooooooo`04
oooo00<0003o003o00001_l000<00006o`0000<0003o003o00001Ol000<0000<0?l000<00000o`00
o`001P3o008000080?l00P0001Oo000200001?l000030000o`00o`0000Ko00000`000?ooooooo`0A
oooo00<0003oooooool07Oooo`00:Oooo`030000oooooooo00Goool00`000?l00?l00003o`000P00
00[o000010000?l00?l00?l000<0000@0?l000<00000o`00o`000P3o00<000070?l00`0000;o0000
0`000?l00?l0000Do`0000<0003o000000001?l000030000o`00o`0000Co00000`000?ooooooo`0B
oooo00<0003oooooool07Oooo`00:Oooo`030000oooooooo00Koool00`000?l00000000200003Ol0
00<0000D0?l0100000L0o`0300001_l000030000o`00o`0001?o00000`000?l000000004o`0000<0
003o003o00000ol000030000oooooooo01Coool00`000?ooooooo`0Loooo000Xoooo00<0003ooooo
ool01_ooo`<0000>o`000`0001D0o`0200001`3o00<00009o`0000<0003o003o00004ol000040000
o`00o`0000000ol000030000o`00o`0000;o00000`000?ooooooo`0Foooo00<0003oooooool06ooo
o`00:?ooo`030000oooooooo00?oool300003_l000<0000E0?l00`0000H0o`0300003Ol000030000
o`00o`0001;o000010000?l00000000000?o000010000?l00?l00?l00080000Hoooo00<0003ooooo
ool06oooo`00:?ooo`800002oooo0P0000oo000200000P3o000300000?l00?l00100o`0300001P3o
00<0000Ao`0000<0003o003o00004Ol000<00004o`0000<0003o003o00000P0001[oool00`000?oo
ooooo`0Joooo000Xoooo00<0003oooooool00_ooo`030000o`00o`0000[o000300001@3o00030000
0?l00?l000`0o`0300000P3o000400000?l00?l00?l00`0001Go00000`000?l00?l0000?o`0000@0
003o000000000005o`0000<0003o000000006oooo`030000oooooooo01[oool002Soool00`000?oo
ooooo`03oooo00<0003o003o00001_l000<000090?l000<00000o`00o`002@3o008000060?l00`00
01Wo00000`000?l00?l0000=o`0000@0003o003o00000006o`000P0001goool00`000?ooooooo`0I
oooo000Xoooo00<0003oooooool01?ooo`030000o`00o`0000?o000200003@3o000300000?l00?l0
00D0o`0300001@3o00<0000Lo`0000<0003o003o00003?l000050000o`00o`00o`00000000Go0002
00007oooo`030000oooooooo01Soool002Soool00`000?ooooooo`05oooo00<0003o000000000P00
0100o`001000003o003o003o00<000050?l00`0000;o00000`000?l00?l0000Ko`0000<0003o003o
00002Ol000800003o`000P0000;o000300008Oooo`030000oooooooo01Soool002Ooool00`000?oo
ooooo`05oooo0`0001@0o`0300001P3o00800006o`0000<0003o003o00006ol000030000o`00o`00
00Oo00000`000?l00?l00003o`00100002Coool200006Oooo`009oooo`030000oooooooo00?oool2
00005@3o008000060?l00`0000Wo00000`000?l00?l0000Ko`0000<0003o003o00001Ol000030000
o`00o`0000?o000300008oooo`<000000oooo`000?ooo`0Hoooo000Woooo0P0000;oool20000503o
00<000050?l00`0000co00000`000?l00?l0000Lo`0000<0003o003o00000ol000030000o`00o`00
00Co00000`000?ooo`00000Poooo0`0000Coool00`000?ooooooo`0Goooo000Eoooo0P0000Coool2
00001?ooo`800004oooo00<0003oooooool00_ooo`0300000?l00?l000l0o`0300001@3o00<0000@
o`0000<0003o003o00006ol000040000o`00o`00o`000P0000Ko000010000?ooooooo`0001goool3
00001oooo`030000oooooooo01Ooool001Coool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`03oooo00<00000o`00o`00303o008000020?l000@00000o`00o`00o`02
00005?l000030000o`00o`0001_o00000`000?l000000008o`0000@0003oooooool0000Joooo0`00
00[oool00`000?ooooooo`0Goooo000Doooo00@0003oooooool0000;oooo00D0003oooooooooool0
00001_ooo`0300000?l00?l000P0o`0300001@3o00<0000Go`0000<0003o003o00006_l000<00007
o`0000D0003oooooooooool000005oooo`<0000>oooo00<0003oooooool05_ooo`003_ooo`@00002
oooo00@0003oooooool00009oooo0P0000Coool00`000?ooooooo`05oooo00<00000o`00o`00103o
00<000050?l00`0001_o00000`000?l00?l0000Fo`000`0000?o000200001Ol000050000oooooooo
oooo000001Coool300004Oooo`030000oooooooo01Koool001Coool010000?ooooooo`0000Woool0
0`000?ooooooo`02oooo00<0003oooooool01oooo`0400000?l00?l00?l00P0000D0o`0300000_l0
00030000o`00o`0001[o00000`000?l00?l0000Bo`000`0000So0003000000?o0000003oool00ooo
o`030000oooooooo00ooool300005?ooo`030000oooooooo01Koool001Goool200002_ooo`<00002
oooo00<0003oooooool02?ooo`<000050?l00P0000Ko00000`000?l00?l0000Jo`0000<0003o003o
00003_l000<0000>o`000P0000Coool00`000?ooooooo`0<oooo0`0001Ooool00`000?ooooooo`0F
oooo000Voooo0P0000Koool300001@3o00<00009o`0000<0003o003o00006_l000030000o`00o`00
00_o000200003_l000<00006oooo00<0003oooooool02Oooo`<0000Joooo00<0003oooooool05_oo
o`009_ooo`030000oooooooo00?oool200001@3o00<0000=o`0000<0003o003o00006Ol000030000
o`00o`0000So000300003Ol000<00009oooo00<0003oooooool01_ooo`<0000Moooo00<0003ooooo
ool05_ooo`009_ooo`040000oooooooooooo0P0000@0o`0300004Ol000030000o`00o`0001Wo0000
0`000?l00?l00004o`000`0000go000300003?ooo`030000oooooooo00?oool300008?ooo`030000
oooooooo01Koool002Koool00`000?ooooooo`02oooo00<00000o`00o`000P0001Go00000`000?l0
0?l0000Io`0000<0003o003o00000`0000co000400003oooo`030000oooooooo00<0000Soooo00<0
003oooooool05_ooo`009_ooo`030000oooooooo00;oool300006?l000030000o`00o`0001So0004
00002ol000<0000Boooo100002Ooool00`000?ooooooo`0Eoooo000Uoooo00@0003oooooooooool2
00007?l000030000o`00o`0001Co000300001?l000@00004o`000`0001;oool3000000?oool0003o
ool0:?ooo`030000oooooooo01Goool002Goool00`000?ooooooo`02oooo00<0003o003o00006ol0
00030000o`00o`00013o000300002ol000@0000Boooo0`0000Coool00`000?ooooooo`0Woooo00<0
003oooooool05Oooo`009Oooo`800004oooo00<0003o003o00006ol000030000o`00o`0000co0003
00003Ol00080000Boooo0`0000Ooool00`000?ooooooo`0Woooo00<0003oooooool05Oooo`009Ooo
o`030000oooooooo00Coool200007?l000030000o`00o`0000So000300003Ol000<0000Aoooo0`00
00[oool00`000?ooooooo`0Woooo00<0003oooooool05Oooo`009Oooo`030000oooooooo00Koool0
0`000?l00?l0000Jo`0000<0003o003o00001?l000<0000=o`000`00017oool300003Oooo`030000
oooooooo02Ooool00`000?ooooooo`0Eoooo000Uoooo00<0003oooooool01oooo`030000o`00o`00
01[o00000`000?l00?l0000300003_l00080000Aoooo0`00013oool00`000?ooooooo`0Woooo00<0
003oooooool05Oooo`009?ooo`030000oooooooo00Woool00`000?l00?l0000Io`000`0000ko0003
00004?ooo`<0000Doooo00<0003oooooool09_ooo`030000oooooooo01Goool002Coool00`000?oo
ooooo`0:oooo00<0003o003o00005Ol000<00003o`000`0000So0003000000?oool0003oool03Ooo
o`<0000Goooo00<0003oooooool09oooo`030000oooooooo01Coool002Coool00`000?ooooooo`0;
oooo00<0003o003o00004Ol000<00009o`000`0000?o000200001Oooo`030000oooooooo00Soool3
00006_ooo`030000oooooooo02Ooool00`000?ooooooo`0Doooo000Toooo0P0000goool00`000?l0
0?l0000=o`000`0000oo000300002?ooo`030000oooooooo00Coool300007Oooo`030000oooooooo
02Ooool00`000?ooooooo`0Doooo000Toooo00<0003oooooool03Oooo`80000:o`000`0000oo0003
00003?ooo`030000oooooooo00<00004oooo2`00017oool00`000?ooooooo`0Woooo00<0003ooooo
ool05?ooo`009?ooo`030000oooooooo00ooool00`000?l00?l00004o`000`0000ko000400004?oo
o`800004oooo0`0000Wo00000`000?l00000000@oooo00<0003oooooool09oooo`030000oooooooo
01Coool002Coool00`000?ooooooo`0@oooo00<0003o003o00000`0000ko000300005?ooo`040000
oooooooooooo0P0000Ko00000`000?l00?l00003o`0000@0003o003o0000000?oooo00<0003ooooo
ool09oooo`030000oooooooo01Coool002?oool00`000?ooooooo`0Boooo0`0000go000300005ooo
o`@00009o`0000D0003o003o003o000000001?l000030000oooooooo00coool00`000?ooooooo`0W
oooo00<0003oooooool05?ooo`008oooo`030000oooooooo01Goool500001?l000@0000Hoooo0`00
00go000010000?l00?l0000000Co00000`000?ooooooo`0<oooo00<0003oooooool09oooo`030000
oooooooo01Coool002?oool00`000?ooooooo`0Joooo100001Woool300004Ol000800006o`0000<0
003oooooool02oooo`030000oooooooo02Soool00`000?ooooooo`0Coooo000Soooo0P0003Goool3
00005?l000030000o`00o`0000Ko00000`000?ooooooo`0:oooo00<0003oooooool0:?ooo`030000
oooooooo01?oool002?oool00`000?ooooooo`0boooo0P0001Oo00000`000?l00?l00007o`0000<0
003oooooool02Oooo`030000oooooooo02Soool00`000?ooooooo`0Coooo000Soooo00<0003ooooo
ool0;oooo`<0000Ho`0000<0003o003o00002Ol000030000oooooooo00Ooool20000:_ooo`030000
oooooooo01?oool002?oool00`000?ooooooo`0/oooo0`0001_o00000`000?l00?l0000:o`0000<0
003oooooool00oooo`<00002oooo00<0003oooooool09oooo`030000oooooooo01?oool002;oool0
0`000?ooooooo`0Yoooo100000;o00000`000?l00?l0000Ho`0000<0003o003o00003?l000D00006
oooo00<0003oooooool09_ooo`030000oooooooo01?oool002;oool00`000?ooooooo`0Voooo0`00
00Oo00000`000?l00?l0000Fo`0000<0003o003o00002ol000@0000:oooo00<0003oooooool09Ooo
o`030000oooooooo01?oool002;oool00`000?ooooooo`0Soooo0`0000_o00000`000?l00?l0000E
o`0000<0003o003o00002?l000<00003o`0000<0003oooooool02?ooo`030000oooooooo02Goool0
0`000?ooooooo`0Coooo000Roooo00<0003oooooool07oooo`@0000?o`0000<0003o003o00004ol0
00030000o`00o`0000Go000400001ol000030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0
003oooooool04_ooo`008_ooo`80000Moooo0`0001Co00000`000?l00?l0000Bo`0000<0003o003o
00000_l000<0000<o`0000<0003oooooool02?ooo`030000oooooooo02Coool00`000?ooooooo`0B
oooo000Loooo0P0000Coool00`000?ooooooo`0Hoooo100001So00000`000?l00?l0000?o`000P00
00;o000300004?l000030000oooooooo00Soool00`000?ooooooo`0Soooo00<0003oooooool04_oo
o`006oooo`040000oooooooo00000oooo`030000oooooooo01Goool300007Ol00080000<o`000`00
0004o`000000000000004_l000030000oooooooo00[oool00`000?ooooooo`0Roooo00<0003ooooo
ool04_ooo`006oooo`040000oooooooo00000_ooo`030000oooooooo01?oool300000_l000030000
o`00o`0001go00000`000?l00?l00005o`00200000;o00000`000?l00?l0000@o`0000<0003ooooo
ool02oooo`030000oooooooo027oool00`000?ooooooo`0Boooo000Koooo00@0003oooooool00002
oooo00<0003oooooool04Oooo`800006o`000P0001ko000010000?l00?l00?l000<000001?l00000
0000000000Oo00000`000?l00?l0000>o`0000<0003oooooool03Oooo`030000oooooooo023oool0
0`000?ooooooo`0Boooo000Koooo00@0003oooooool00002oooo00<0003oooooool03_ooo`<0000:
o`0000<0003o003o00007?l000<000001?l000000000000000_o00000`000?l00?l0000=o`0000<0
003oooooool03Oooo`030000oooooooo023oool00`000?ooooooo`0Boooo000Loooo0P0000?oool0
0`000?ooooooo`0;oooo0`0000ko00000`000?l00?l0000Ho`001`0000oo00000`000?l00?l0000;
o`0000<0003oooooool03oooo`030000oooooooo01ooool00`000?ooooooo`0Boooo000Qoooo00<0
003oooooool02?ooo`<0000Bo`0000<0003o003o00004ol000L0000Do`0000<0003o003o00002_l0
00030000oooooooo013oool00`000?ooooooo`0Ooooo00<0003oooooool04Oooo`008Oooo`800007
oooo0P0001Ko00000`000?l00?l0000?o`000`000004o`000000000000006?l000030000o`00o`00
00So00000`000?ooooooo`0Boooo00<0003oooooool07_ooo`030000oooooooo017oool0027oool0
0`000?ooooooo`03oooo0`0001Wo000200003?l000<000001?l000000000000001_o00000`000?l0
0?l00008o`0000<0003oooooool04oooo`030000oooooooo01goool00`000?ooooooo`0Aoooo000P
oooo00<0003oooooool00_ooo`80000No`0000<0003o003o00001_l000L0000Oo`0000<0003o003o
00001_l000030000oooooooo01Goool00`000?ooooooo`0Loooo00<0003oooooool04Oooo`008?oo
o`030000oooooooo00?oool00`000?l00?l0000Mo`0000<0003o003o00000_l000H00003o`0000<0
003o003o00007_l000030000o`00o`0000Go00000`000?ooooooo`0Foooo00<0003oooooool06ooo
o`030000oooooooo017oool0023oool00`000?ooooooo`04oooo0P0001ko000700001ol000030000
o`00o`0001ko00000`000?l00?l00003o`0000<0003oooooool06?ooo`030000oooooooo01[oool0
0`000?ooooooo`0Aoooo000Poooo00<0003oooooool01_ooo`030000o`00o`0001Wo000600002ol0
00030000o`00o`0001ko00000`000?l00?l00002o`0000<0003oooooool06?ooo`030000oooooooo
01[oool00`000?ooooooo`0Aoooo000Poooo00<0003oooooool01oooo`030000o`00o`0001Go0006
00003ol000030000o`00o`0001ko000010000?l00?l0000001coool00`000?ooooooo`0Ioooo00<0
003oooooool04Oooo`008?ooo`030000oooooooo00Soool200004_l000D0000Do`0000<0003o003o
00007_l000030000o`00000001goool00`000?ooooooo`0Hoooo00<0003oooooool04Oooo`007ooo
o`<0000;oooo00<0003o003o00003?l000D0000Ho`000P0001ko000200007oooo`030000oooooooo
01Soool00`000?ooooooo`0@oooo000Ooooo00<0003oooooool03?ooo`030000o`00o`0000So0005
00007Ol000030000o`00o`0001Oo000400008_ooo`030000oooooooo01Ooool00`000?ooooooo`0@
oooo000Ooooo00<0003oooooool03Oooo`800005o`0010000003o`000000o`0001oo00000`000?l0
0?l0000Co`000`0002Ooool00`000?ooooooo`0Foooo00<0003oooooool04?ooo`007oooo`030000
oooooooo00ooool600001Ol00080000Oo`0000<0003o003o00003_l000@0000[oooo00<0003ooooo
ool05Oooo`030000oooooooo013oool001ooool00`000?ooooooo`0=oooo1@0000[o00000`000?l0
0?l0000Mo`0000<0003o003o00002Ol000@0000_oooo00<0003oooooool05Oooo`030000oooooooo
013oool001ooool00`000?ooooooo`0:oooo1@0000ko00000`000?l00?l0000Mo`0000<0003o003o
00001Ol000<0000doooo00<0003oooooool05?ooo`030000oooooooo013oool001ooool00`000?oo
ooooo`06oooo1@0001?o00000`000?l00?l0000Mo`0000<0003o003o0000100003Soool00`000?oo
ooooo`0Coooo00<0003oooooool04?ooo`007_ooo`030000oooooooo00Coool500005ol000030000
o`00o`0001co00030000?Oooo`030000oooooooo01;oool00`000?ooooooo`0@oooo000Noooo0P00
00?oool400006ol00080000Io`000`000003oooo0000oooo03koool00`000?ooooooo`0Boooo00<0
003oooooool03oooo`007_ooo`D000000oooo`000?l0000No`0000<0003o003o00004_l000@00004
oooo00<0003oooooool0?_ooo`030000oooooooo017oool00`000?ooooooo`0?oooo000Noooo0`00
00Coool200007_l000030000o`00o`0000ko000300002?ooo`030000oooooooo03ooool00`000?oo
ooooo`0@oooo00<0003oooooool03oooo`007oooo`800006oooo00<0003o003o00007?l000030000
o`00o`0000[o000300002oooo`030000oooooooo03ooool00`000?ooooooo`0@oooo00<0003ooooo
ool03oooo`008Oooo`030000oooooooo00Coool00`000?l00?l0000Lo`000P0000Ko000400003_oo
o`030000oooooooo043oool00`000?ooooooo`0?oooo00<0003oooooool03oooo`008_ooo`030000
oooooooo00Coool200007_l000030000o`00o`0000<0000Boooo00<0003oooooool0@Oooo`030000
oooooooo00koool00`000?ooooooo`0?oooo000Soooo0P0000Koool00`000?l00?l0000Ko`000`00
01Coool00`000?ooooooo`13oooo00<0003oooooool03Oooo`030000oooooooo00ooool002Goool2
00001Oooo`030000o`00o`0001Ko000400005oooo`030000oooooooo04Coool00`000?ooooooo`0<
oooo00<0003oooooool03oooo`009_ooo`030000oooooooo00Coool200004_l000@0000Koooo00<0
003oooooool0AOooo`030000oooooooo00coool00`000?ooooooo`0>oooo000Woooo0P0000Koool0
0`000?l00?l0000;o`00100001ooool00`000?ooooooo`16oooo00<0003oooooool02oooo`030000
oooooooo00koool0023oool500001?ooo`030000oooooooo00Coool00`000?l00?l00006o`001000
02?oool00`000?ooooooo`16oooo00<0003oooooool02oooo`030000oooooooo00koool002;oool0
0`000?ooooooo`05oooo0`0000Coool200000_l000@0000Woooo00<0003oooooool0Aoooo`030000
oooooooo00[oool00`000?ooooooo`0>oooo000Roooo00<0003oooooool01oooo`030000oooooooo
00Coool20000:oooo`030000oooooooo04Soool00`000?ooooooo`09oooo00<0003oooooool03_oo
o`006_ooo`@00004oooo00<0003oooooool02?ooo`030000oooooooo033oool00`000?ooooooo`19
oooo00<0003oooooool02?ooo`030000oooooooo00koool002;oool00`000?ooooooo`09oooo0P00
033oool00`000?ooooooo`1:oooo00<0003oooooool01oooo`030000oooooooo00koool0027oool2
00003Oooo`030000oooo000002goool00`000?ooooooo`1;oooo00<0003oooooool01_ooo`030000
oooooooo00koool0037oool20000;Oooo`030000oooooooo04coool00`000?ooooooo`06oooo00<0
003oooooool03Oooo`00<oooo`030000oooooooo02[oool00`000?ooooooo`1=oooo00<0003ooooo
ool01Oooo`030000oooooooo00goool003Coool00`000?ooooooo`0Yoooo00<0003oooooool0COoo
o`030000oooooooo00Goool00`000?ooooooo`0=oooo000eoooo0`0002Soool00`000?ooooooo`1>
oooo00<0003oooooool01?ooo`030000oooooooo00goool003Ooool00`000?ooooooo`0Voooo00<0
003oooooool0Coooo`030000oooooooo00?oool00`000?ooooooo`0=oooo000hoooo00<0003ooooo
ool09Oooo`030000oooooooo053oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`00>Ooo
o`8000000oooo`000?ooo`0Roooo00<0003oooooool0DOooo`050000oooooooooooo000000ooool0
03_oool200008oooo`030000oooooooo05;oool010000?ooooooo`0000ooool003coool200008_oo
o`030000oooooooo05?oool010000?ooooooo`0000koool003koool00`000?ooooooo`0Ooooo00<0
003oooooool0Doooo`040000oooooooo00003_ooo`00?oooo`030000oooooooo01koool00`000?oo
ooooo`1Doooo00<0003oool000003_ooo`00@?ooo`80000Noooo00<0003oooooool0EOooo`80000>
oooo0012oooo00<0003oooooool06oooo`030000oooooooo05Coool300003_ooo`00@oooo`80000K
oooo00<0003oooooool0D?ooo`@0000Aoooo000goooo0P0000Coool200001?ooo`@0000Ioooo00<0
003oooooool0C?ooo`@0000Eoooo000foooo00@0003oooooool00008oooo00<0003oooooool00P00
01Woool00`000?ooooooo`18oooo100001Woool003Koool010000?ooooooo`0000_oool010000?oo
o`00000001Ooool00`000?ooooooo`13oooo1@0001goool0033oool400000_ooo`040000oooooooo
00002Oooo`800004oooo00<0003oooooool05?ooo`030000oooooooo03ooool400008_ooo`00=_oo
o`040000oooooooo00002Oooo`030000oooooooo00Coool200005?ooo`030000oooooooo03_oool4
00009_ooo`00=oooo`80000:oooo0`0000Goool200004_ooo`030000oooooooo03Ooool50000:_oo
o`00COooo`030000oooooooo00ooool00`000?ooooooo`0coooo100002ooool004koool300003_oo
o`030000oooooooo02ooool40000<oooo`00D?ooo`030000oooooooo00coool00`000?ooooooo`0[
oooo100003Ooool0057oool00`000?ooooooo`0;oooo00<0003oooooool09_ooo`D0000koooo001B
oooo0`0000[oool00`000?ooooooo`0Roooo1000043oool005Coool00`000?ooooooo`08oooo00<0
003oooooool07_ooo`@00014oooo001Eoooo0P0000Soool00`000?ooooooo`0Ioooo1@0004Soool0
05Ooool200001_ooo`030000oooooooo01Goool40000COooo`00F?ooo`030000oooooooo00Coool0
0`000?ooooooo`0Aoooo1000057oool005Woool200001?ooo`030000oooooooo00goool40000EOoo
o`00Foooo`050000oooo0000oooo000000[oool50000FOooo`00Doooo`800007oooo00@0003ooooo
ool00006oooo100005koool005;oool010000?ooooooo`0000Ooool300000_ooo`@0001Roooo001B
oooo00@0003oooooool00009oooo0`0006Koool005;oool010000?ooooooo`0007;oool005;oool0
10000?ooooooo`0007;oool005?oool20000Loooo`00b?ooo`00;_ooo`<0001Loooo0`0003Soool0
037oool00`000?ooooooo`1Joooo00<0003oooooool0=oooo`008_ooo`<00004oooo0`0000?oool3
00000oooo`800003oooo100000?oool200001?ooo`800002oooo100000[oool00`000?ooo`000002
oooo1@0000;oool200001?ooo`<00002oooo0`0000Coool300000oooo`800009oooo0`0000?oool3
00001?ooo`<00003oooo0`0000?oool200000oooo`@00003oooo1P000004oooo0000oooo00004Ooo
o`008oooo`030000oooooooo00Coool01@000?ooooooooooo`000002oooo00<0003oooooool01_oo
o`030000oooooooo00Woool010000?ooooooo`0000;oool010000?ooooooo`0000Soool01P000?oo
o`000?ooo`000?ooo`@00003oooo0P0000?oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`030000oooooooo00?oool010000?ooooooo`0000_oool010000?ooooooo`0000;oool010000?oo
ooooo`0000Goool00`000?ooooooo`03oooo00@0003oooooool00003oooo00<0003oooooool00_oo
o`040000oooooooo00000_ooo`050000oooo0000oooo0000017oool002?oool00`000?ooooooo`04
oooo00D0003oooooooooool000000_ooo`030000oooooooo00Ooool00`000?ooooooo`0:oooo00D0
003oooooooooool000000_ooo`030000oooooooo00Koool01@000?ooo`000?ooo`000004oooo00@0
003oooooool00002oooo00<0003oooooool0100000?oool00`000?ooooooo`02oooo100000;oool0
0`000?ooooooo`09oooo0`0000?oool010000?ooooooo`0000;oool400000_ooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`040000oooooooo00000_ooo`050000
oooo0000oooo0000017oool002?oool200001?ooo`800004oooo100000Woool00`000?ooooooo`0:
oooo00@0003oooooool00002oooo00<0003oooooool01Oooo`<000000oooo`0000000002oooo0`00
0003oooo0000000000;oool200000_ooo`800004oooo00<0003oooooool00oooo`800002oooo1@00
00Soool4000000?oool0000000000P0000Coool200001?ooo`<000000oooo`000000000300000_oo
o`@000001?ooo`0000000?ooo`8000001_ooo`00000000000?ooo`0001;oool002?oool010000?oo
ooooo`0001?oool010000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`00
027oool00`000?ooooooo`08oooo00<0003oooooool08Oooo`030000oooooooo02Goool002;oool5
00000oooo`030000oooooooo00koool200002_ooo`800002oooo1000027oool20000E_ooo`00b?oo
o`00b?ooo`00\
\>"],
  ImageRangeCache->{{{0, 199}, {199, 0}} -> {-0.09235, -0.0310123, \
0.00526545, 0.00526545}}]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "To recover the original data, we transpose the wavelet transform matrices, \
and then carry out an inverse wavelet transform. In addition, we compute the \
maximum absolute error between the original \"data3D\" and recovered \
\"recover3D\" data. Because of the numerical errors, the recovered data \
\"recover3D\" are not exactly equivalent to the original ones, but the errors \
are negligible small values. \n\tFinal commands remove the needless memories \
and check the used memories. Thereby, it is possible to know that the ",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" front-end uses about 1.7-mega bytes memories",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
wMatTrans=Table[Transpose[wMat[[i]]],{i,3}];
recover3D=waveletND[wSpect,wMatTrans,3];
Max[Abs[data3D-recover3D]]\
\>", "Input"],

Cell[BoxData[
    \(2.644684471420078`*^-11\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Remove[\"data3D\",\"base\",\"wMat\",\"wSpect\",
\t\"wMatTrans\",\"recover3D\"];memoryUsed\
\>", "Input"],

Cell[BoxData[
    InterpretationBox[\(2111\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ 2111, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4.3 Wavelet image compression and recovery",
  FontFamily->"Times New Roman"]], "Section"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4.3.1 Sample images",
  FontFamily->"Times New Roman",
  FontSize->12]], "Subsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "In this section, we have to input a sample color image. The 24-bitmap \
image data file \"AF038-128.bmp\" is read in a list \"sample by the function \
\"rgbBMP\". After that we construct its monochrome image data by computing a \
magnitude distribution of the color image characteristic vectors.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
sample=rgbBMP[\"AF038-128.bmp\"];
monoSample=vectorMag3D[sample];\
\>", "Input"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["After computing a resolution of the input image by the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" command \"Dimensions\", we construct its color and monochrome \
image data. Figure 3 shows the 128 by 128 resolution color and monochrome \
images.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
dim=Dimensions[sample];
sampleG=Show[convertRGB[sample],PlotLabel->\"Color image\",
\tAspectRatio->dim[[2]]/dim[[3]],DisplayFunction->Identity];
monoSampleG=ListDensityPlot[monoSample,PlotRange->All,
\tMesh->False,Frame->False,PlotLabel->\"Monochrome image\",
\tAspectRatio->dim[[2]]/dim[[3]],DisplayFunction->Identity];
Show[GraphicsArray[{sampleG,monoSampleG}],
\tPlotLabel->\"Fig.3. Sample images\",ImageSize->{300,150}];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 300 150 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[.5 .48869 -62 0 ]
[.5 .48869 62 12.5625 ]
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .48869 -123 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.813 moveto
(.3) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sample) show
147.000 12.813 moveto
(images) show
183.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -35 0 ]
[.5 1.0125 35 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Color) show
99.000 12.813 moveto
(image) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEEFCEB5F7D6BD
F7D6BDF7D6BDF7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECE
F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFCEB5EFC6ADEFC6ADEFC6AD
E7B59CE7BDA5E7B59CE7B59CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94
DEAD94DEAD94DEA58CD6A58CD6A584DE9C84D6A58CD6A58CD6A584C69C84D6A58CF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEF7CEB5F7D6BD
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7D6C6F7DECE
F7DECEF7DECEF7D6C6F7D6C6F7D6C6EFCEB5EFCEB5EFC6ADEFC6ADE7BDA5E7BDA5E7BDA5
E7BDA5E7B59CDEAD94DEAD94DEAD94DEAD94DEAD94DEA58CDEAD94DEAD94DEAD94DEA58C
DEAD94DEA58CD6A58CD6A58CD6A58CD6A58CD6A58CD6A584D6A58CC69C84D6A58CF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEF7D6BDF7D6BD
F7D6C6F7D6BDF7D6BDF7DECEF7DECEF7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEF7D6C6
F7D6BDF7D6C6EFCEB5EFCEB5EFCEB5EFC6ADEFC6ADEFC6ADE7BDA5E7BDA5DEB59CE7AD9C
DEAD94DEAD94DEAD94D6A58CD6A58CDEA58CDEAD94DEAD94DEAD94DEA58CDEAD94DEAD94
DEA58CD6A58CDEA58CDEA58CD6A58CDEA58CD6A58CD6A58CD6A584C69C84D6C6BDF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEF7CEB5F7D6BD
F7D6BDF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BD
EFCEB5F7D6BDEFCEB5EFCEB5D6C6B5D6C6B5E7BDA5E7BDA5DEB5A5DEB59CDEB59CDEB59C
DEB59CDEAD94DEAD94DEAD94DEAD94D6A58CDEA58CD6A58CD6A58CDEA58CDEAD94DEA58C
D6A58CDEA58CD6A58CD6A58CDEA58CD6A58CD6A58CD6A58CD6A584D69C84F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEEFCEB5F7D6BD
F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6BDF7D6C6F7D6C6F7D6C6D6C6C6
EFCEB5D6C6BDD6C6B5E7BDA5E7BDA5E7AD9CE7AD9CDEB59CDEAD94DEB59CDEB59CDEB59C
DEB59CDEB59CDEB59CDEB5A5DEAD94D6A58CD6A58CD6A58CD6A58CD6A58CD6A58CDEA58C
D6A58CDEA58CD6A584DEAD94D6A58CD6A58CD6A58CD6A58CD6A58CDEB59CF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6F7D6BDF7D6BD
F7D6C6F7D6BDF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BD
D6C6C6F7BDB5F7BDB5F7BDB5EFBDADEFBDADEFBDA5E7B59CE7AD9CE7AD9CDE9C8CDE9C8C
DE9C8CDEAD94DEAD94DEB59CD69C8CC6ADA5D6A58CD6A58CD6A58CD6A58CD6A58CDEAD94
DEA58CDEA58CD6A58CDEA58CD6A58CD6A58CD6A58CD6A58CD6A58CD6C6BDF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6F7CEB5F7D6BD
F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6BDEFCEB5
F7D6C6F7D6BDF7D6C6F7D6BDEFCEB5F7BDB5F7BDB5EFBDADE7B59CE7AD9CE7AD94DE9C8C
E7AD9CEFB5A5E7AD9CDEB59CDE9C8CD6A58CD6A58CDEB5A5D6A58CD6A58CD6A58CD6A584
D6A58CDE9C84D6A58CD6A58CDEAD94D6A58CD6A58CD6A58CD6A58CF7E7DEF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDF7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6BDF7D6C6F7D6C6EFCEB5EFCEB5EFCEB5F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6BDF7BDB5EFBDADEFBDADEFBDA5E7BDA5E7BDA5
E7AD9CEFB5A5EFBDADEFB5A5E7AD9CDE9C8CDEA58CD69C8CD69C8CD6A58CD6A58CDEAD94
D6A58CD6A58CDEA58CD6A58CDEA58CD6A584D6A58CD6A58CD6A58CF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFCEB5F7D6BDF7D6BD
F7D6BDF7D6C6F7D6BDF7D6BDF7D6C6EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6EFCEB5EFC6ADEFBDADEFC6ADEFBDA5E7BDA5
EFBDA5EFB5A5E7AD9CEFB5A5EFBDA5E7AD9CDE9C8CE7AD94DE9C8CD6A58CDEB5A5DEAD94
D6A58CDEAD94DEA58CDEA58CDEA58CD6A58CD6A58CD6A58CDEB59CF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFCEB5F7D6BDF7D6BD
F7D6BDF7D6BDEFCEB5F7D6C6EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECE
F7DECEF7DECEF7D6C6F7D6C6F7DECEF7DECEF7DECEEFCEB5F7C6ADF7C6ADEFCEB5EFBDAD
EFBDADEFBDADEFB5A5EFB5A5EFB5A5E7AD9CE7AD9CDE9C8CDE9C8CDEAD94DEAD94DEB59C
DEB59CD6A58CDEAD94DEAD94DEA58CDEAD94D6A58CDEAD94F7BDB5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEB5F7D6BDF7D6BD
F7D6BDEFCEB5F7D6C6EFCEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECE
F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDF7D6BDEFC6ADEFCEB5
EFBDADEFBDA5EFBDA5EFB5A5E7B59CE7AD9CE7AD9CE7AD94DEAD94DE9C8CDEA58CDEAD94
DEB5A5DEAD94D6A58CDEA58CD6A58CD6A58CD6A58CDEAD94EFD6CEF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6F7D6BDF7D6BDF7D6BD
EFCEB5EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7DECEF7DECEF7DECEF7DECE
F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7BDB5
F7BDB5EFBDA5EFBDA5E7B59CEFB5A5E7AD94E7AD94E7AD9CE7AD94DE9C8CDEA58CDE9C8C
D6A58CD6A58CDEB59CD6A58CD6A58CDEAD94D6A58CDEAD94EFE7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7DEB5A5EFCEB5F7D6BDEFCEB5
F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECE
F7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6BDF7CEB5EFCEB5
F7C6ADEFC6ADEFBDA5EFBDA5EFBDA5E7AD9CE7AD9CDEA58CE7AD94DEAD94DEA58CDEA58C
D6A58CDEB59CD6A58CDEB5A5DEA58CDEAD94D6A58CDEAD94EFE7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7846B5AEFC6ADF7D6BDEFD6CEF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6BD
F7C6ADEFC6ADEFBDA5EFB5A5EFB5A5E7AD9CE7AD94E7AD94E7AD94E7AD94DEAD94DEA58C
D6A58CDEAD94D6A58CD6A58CDEB59CDEAD94DEAD94DEAD94F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78C7363634A42EFCEB5F7D6C6F7D6BDF7D6C6
F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6
F7D6BDF7D6BDF7DECEF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6BDEFCEB5F7D6BDF7C6AD
EFBDADEFBDA5EFBDA5EFBDA5EFB5A5E7B59CE7B594E7AD94DEA58CE7AD94DEAD94DEAD94
DEA58CD6A58CD6A58CDEAD94DEB59CDEB5A5DEAD94DEAD94F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F76B524A5231298C6352F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6BDEFCEB5EFC6ADEFCEB5EFCEB5EFC6ADEFC6AD
EFBDA5EFBDA5E7BDA5E7B59CEFBDA5E7B59CE7AD94E7AD94E7AD94E7AD9CDEA58CDEA58C
DE9C84D6A58CD6A58CD6A58CDEAD94D6A58CEFBDADDEAD94F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7D6C6CE634A425A3129EFD6CEF7D6C6F7D6BDF7D6BDF7D6C6
F7DECEF7DECEF7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECE
F7DECEF7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7BDB5EFC6ADEFBDA5EFBDA5E7B59CEFBDA5
EFBDA5EFBDA5EFBDA5EFBDA5E7BDA5E7B59CDEAD94E7AD94E7AD94DEAD94DEAD94DEA58C
D6A584D6A584D6A58CD6A584D6A58CD6A58CD6A58CD6C6BDF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEF5A4239734A39F7D6C6EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECE
F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDEFCEB5EFBDA5EFC6ADEFBDA5EFBDA5E7B59C
EFBDA5E7BDA5EFBDA5E7B59CE7B59CE7AD94DEAD94E7B594E7AD94DEAD94E7A58CDEA58C
DEA58CD6A58CD6A584D6A584D6A584DEAD94DEAD94DEB59CF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFF7B635A634231F7D6C6EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECE
F7DECEF7DECEF7D6C6F7D6BDEFCEB5F7C6ADEFBDADEFBDA5EFBDA5E7B59CE7B59CE7B59C
E7B59CE7B59CE7B59CE7B594E7B594E7AD94DEAD94DEAD94DEA58CDEA58CDEA58CDEA58C
DEA58CD6A584DEA58CD6A58CD6A58CDEA58CDEAD94DEAD94EFD6CEF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7947B73634A42BD9C8CEFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7DECEF7DECE
F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7BDB5EFB5A5E7AD9CE7AD9CE7AD9CE7AD9CE7AD94
E7AD9CE7AD94E7AD94E7AD94DEA58CDEA58CDEA58CDEA58CDEA58CD6A58CDEA58CDEA58C
DEA58CD6A584DEA58CDE9C84DE9C84DEA58CDEAD94DEA58CD6A58CEFD6CEF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F76342318C7363F7DECEF7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7DECE
F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6
F7D6C6F7DECEF7D6C6F7BDB5EF948CF7BDB5EF948CE7847BE7847BE7847BE7847BE7847B
E7847BE79484E7AD94DEAD94DEA58CDEA58CDEA58CD6A58CDE9C84D69C84D6A584DEA58C
DEA58CD6A58CDEA58CDEA58CD6A584DEA58CDE9C84D6A58CD6A58CD6A58CF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7CEB5B5634231F7DECEF7D6C6F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7DECEF7DECEF7BDB5F7BDB5F7BDB5EF948CEF948CE7847BE7847BE7847BEF948CE7847B
E7847BE7847BE7847BE7847BDE9C8CDEA58CD6A58CD6A58CD6A584D6A584D6A58CDEA58C
DEA58CDEA58CDEA58CDEA58CD6A584DEA58CD6A58CD6A58CD6A58CDEB59CEFBDADF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
D6C6C6634231EFD6CEF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7DECEF7D6C6F7D6C6
F7D6C6F7D6BDF7CEB5F7CEB5F7CEB5F7D6BDF7CEB5F7D6C6F7D6C6F7D6C6F7D6C6F7BDB5
F7BDB5DECED6F7BDB5F7BDB5EF948CE7847BE78473E77B6BDE6B5ADE6B5AE7847BE77B6B
DE7B6BDE7B6BE7847BE7847BD68C7BE7847BD69C84D6A584D6A584D6A584D69C84DEA58C
DEA58CDEA58CDEA58CDEAD94DEA58CDEA58CDE9C84D6A58CDEAD94DEA58CDEAD94F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
7B635A8C7363EFCEB5F7D6BDF7D6BDF7D6C6F7D6BDF7CEB5F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6BDF7CEB5EFBDA5F7CEB5F7C6ADF7CEB5F7D6C6F7DECEF7D6C6F7BDB5F7BDB5
F7BDB5F7BDB5EFB5A5E79484D67363DE6B5ADE6B5ADE6B5ADE6B5ADE6B5ADE6B5AD67363
DE6B5ADE6B5ADE6B5ADE7B6BE7847BD67B6BCE8C84DE9C8CDE9C84D69C84D69C84D6A584
DE9C84DEA58CDEA58CDEAD94DEA58CDEA58CDEA58CD6A58CD6A58CDEA58CDEAD94EFBDAD
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79C8C8C
5A4239F7DECEEFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6
F7D6BDF7D6BDEFC6ADEFBDA5EFBDA5EFBDA5F7D6BDF7D6C6F7D6C6F7BDB5F7C6ADF7C6AD
EF948CE79484E78473D68C7BDE9C8CE7AD9CC66B52F7BDB5DEB59CB5735AE7AD9CD67B6B
D66352CE5A4AD66352DE6B5ADE7B6BD67B6BD68C7BD68C7BD6A58CD6A584D69C73D6A584
D6A584DEA58CDEA58CE7A58CDEA58CDEAD94DEA58CD6A58CDEA58CDEA58CDEAD94DEB59C
F7E7DEF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6ADBD6B524A
5A3129F7D6C6F7D6BDF7D6BDF7D6C6F7D6BDF7D6BDF7C6ADF7D6C6F7DECEF7D6C6F7DECE
F7CEB5F7CEB5EFC6ADE7B594E7B594EFBDA5F7D6C6F7D6C6F7C6ADEF948CE7AD94E78473
D66352B55239C6ADA5E7AD9CD6C6C6D6C6C6CEB5B5CEB5B5EFBDADBDA59CD6C6BDCEB5B5
AD6B52D69C8CA5634ACE5A4AD67363D67363D67B6BD68C7BD68C7BD69C84D69C84D6A584
DE9C84DEA58CDEAD94E7B594DEAD94DEA58CDE9C84DEA58CDEA58CDEA58CDEAD94D6A58C
DEB59CE7DEEFE7DEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFB59C9C5A4239
C69C84F7D6BDF7D6BDF7D6C6F7D6C6F7D6BDEFC6ADEFBDA5F7DECEF7D6C6F7D6C6F7D6BD
F7C6ADF7C6ADE7B594DE9C84DE9C84F7D6BDF7BDB5E7847BE7847BCE8463842918D67B6B
E7AD9CDE6B5AE79484DE7B6BEFB5A5F7E7E7F7E7DEEFD6CEE77B6BE79484CE8C73CE735A
BD8463BDA59CC69484A56B52A5634ACE5A4AD66352CE8C73CE947BD69C84D69C73D69C73
DE9C84DEA58CDEAD94E7B59CE7B594E7B594DEA58CDEA58CDEAD94DEA58CDEA58CDEAD94
DEAD94D6C6C6F7E7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7ADA5AD9C8C8C523129
EFD6CEF7D6BDF7D6C6F7D6BDF7D6BDF7CEB5EFBDA5EFBDA5F7D6C6F7D6C6F7D6C6F7D6C6
F7C6ADE7B59CE7A58CDE9473E7A58CEFB5A5DE6B5A9C392994634AEFBDADF7DECEF7E7DE
F7E7DEF7EFEFF7EFEFF7E7DEF7E7E7F7EFEFF7E7DEF7DECEEFCEB5EFD6CEEFD6CEEFD6CE
D6C6C6B55239B5735A94736BAD7B6B734A39BD5A42C66B52D67363DE9C84D69C73D69C73
DE9C84DEA58CE7B59CE7BDA5E7B59CE7B594DEA58CDEAD94D6A58CDEAD94DEAD94DEAD94
DEAD94D6C6B5F7F7F7D6C6D6E7DEE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78C7B73634A42845242
EFCEB5F7D6BDF7D6C6F7D6BDF7D6BDF7CEB5EFBDA5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6
F7C6ADE7A58CDE9473CE8463D68C73B552398C29219C5A42D6C6BDF7DECEF7E7DEF7E7DE
F7E7DEF7E7E7F7EFEFF7E7DEF7E7E7F7EFEFF7E7DEF7E7DEEFCEB5F7E7E7F7E7DEEFD6CE
EFD6CEE7BDA5C6ADA5AD5A42945A4A5A3121734229BD5A42C66B52D68C73D6A584D69C73
DE9C84DEA58CE7B59CEFBDA5E7B59CE7B59CE7B594DEA58CDEA58CDEAD94DEA58CDEAD94
DEAD94DEB5A5DED6E7F7EFEFEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7EFE7E7F7F7F7F7EFEFF7EFEFE7DEEFF7EFEFF7EFEFF7F7F79484845A4239C69C84
F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7C6ADEFBDA5F7D6BDF7D6C6F7D6C6F7DECEF7D6BD
E7B59CE7A58CCE8C6BCE8C6B9C39298429187B3121B5735AE7B59CF7E7DEF7D6C6F7E7E7
F7D6BDF7E7DEF7EFEFF7D6C6F7E7DEF7EFEFF7E7DEF7D6C6E7AD9CF7E7E7F7E7DEEFD6CE
F7D6C6D6C6C6D6C6C6EFD6CEA55239AD7B6B4A10084A1008B55239CE5A4AD68C7BD69C84
D69C84DEA58CE7B594EFBDA5EFBDA5E7B59CE7B594DEAD94D6A58CDEAD94DEA58CDEAD94
DEA58CDEB59CCEBDB5CEBDCED6C6D6F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DED6E7634231523129F7D6C6
EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDEFC6ADF7D6BDEFBDA5F7D6C6F7D6C6F7D6C6F7D6BD
E7A58CDE9C84C68C63D68C7BBD5A42A54231842918E78473E79484DE9473EFBDA5F7D6BD
EFB5A5F7DECEF7E7DEE7AD94F7D6BDF7E7DEF7D6BDE7AD94E7AD9CEFBDA5EFD6CEF7D6C6
E7AD94EFCEB5F7D6C6EFCEB5D6A58CDEB5A5BD9C8CBD9C8C734231A54231C66B52D69C84
D69C84DEA58CE7B594EFBDA5EFC6ADE7BDA5E7B59CDEA58CDEAD94DEA58CDE9C84DEA58C
DEA58CDEAD94D6C6B5AD9494CEBDB5D6C6BDDED6E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEBDCE634231312121734A42D6C6C6
F7D6BDF7D6BDF7D6BDF7D6BDEFC6ADEFBDA5F7CEB5EFBDA5F7D6C6F7D6C6F7D6C6EFCEB5
E79484CE8C6BDE9473E7AD94E7AD9CE7AD94DE7B6BDE6B5AE78473E78473DE9473E7AD9C
E79484E7A58CE7A58CE7A58CEFB5A5F7BDB5D67363DE7B6BDE7B6BE79484E7A58CE7AD94
D67363E7A58CEFCEB5E7B59CDEB59CDEB5A5D6A58CBD9C8CA5735A7B2918A54231CE8C73
D69C84DEA58CE7B59CEFBDA5EFC6ADEFBDA5E7B59CDEA58CDEA58CD6A58CD69C84D6A58C
DEA58CDEB59CDEB5A5DED6E7D6C6D6CEBDC6D6C6CEE7DEEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF8C7363422921523129422118C69484F7D6C6
F7D6BDF7D6BDF7D6BDF7C6ADF7C6ADEFC6ADF7C6ADE7AD94F7D6BDF7D6C6F7D6BDF7BDB5
E7A58CCE8463E7B59CEFB5A5EFCEB5F7D6C6F7D6BDF7D6BDF7BDB5EFBDADEFB5A5EFB5A5
E7AD9CEFB5A5E7AD9CE7AD9CEF948CEF948CDE9C8CDE9C84DE7B6BDE7B6BDE6B5ACE735A
D67363D67363DEB59CCE8C6BD68C73EFC6ADCE8C84D6A58CAD7B6B631810732110A55239
D68C7BD6A584E7B594EFBDA5EFC6ADEFBDA5E7B594DEAD94DEA58CD6A584D6A58CDEA58C
DEAD94DEAD94DEB59CF7F7F7F7EFEFDECED6D6C6D6DED6E7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7D6C6D6422921312118633931422918F7D6C6F7BDB5
F7D6BDF7D6BDF7D6BDEFC6ADEFC6ADF7BDB5EFC6ADEFC6ADF7D6BDF7D6C6F7D6BDF7C6AD
E7AD94CE8463E7AD94EFBDADF7DECEF7D6C6F7DECEF7DECEF7D6C6F7DECEF7D6C6F7DECE
F7DECEF7DECEF7DECEF7BDB5F7BDB5F7BDB5EFBDADEFBDADEFB5A5E7AD9CE7847BDE7B6B
E7847BD67B6BD67363C66B52C66B52D69C73C66B52B5735AA54231421010732110844A39
A55239D69C84E7AD94EFBDA5EFBDA5EFBDA5E7B59CDEA58CDEA58CD6A58CD69C84DE9C84
DEA58CDEA58CDEB59CA5847BB59C9CDED6E7E7DEE7DECED6EFE7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7DECED69C8C8C3121185231294229215A3121F7D6C6EFCEB5
F7D6BDF7BDB5F7CEB5EFCEB5F7BDB5EFCEB5EFCEB5EFCEB5F7D6BDF7BDB5F7BDB5EFC6AD
E7AD94DE9C84CE8C6BEFBDADF7D6C6F7DECEF7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6
F7DECEF7DECEF7D6C6F7D6C6F7D6BDF7CEB5EFBDA5EFBDA5EFBDA5EFC6ADE7B594E7B59C
E7AD94DE9C8CDE9C84D68C7BE7847BD67B6BD67363C66B52BD5A429C39299C3929B55239
A54231D68C7BDEA58CEFBDA5EFBDA5EFBDA5E7B594DEAD94DEA58CD6A584D69C84DE9C84
DEA58CDEA58CDEAD94BDA59C734A39F7E7DEF7EFEFEFE7E7EFE7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7E7DEE75A42399C6B52D69C8CB5735A8C5A4AF7D6C6F7D6BD
F7D6BDF7D6BDF7CEB5EFCEB5F7D6BDF7D6BDF7D6BDEFCEB5EFCEB5F7D6BDEFCEB5EFCEB5
E7AD94E7A58CDE9473E7B59CEFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6
F7DECEF7D6C6F7DECEF7D6C6F7D6BDF7C6ADEFBDA5EFBDA5E7B59CEFBDA5EFBDA5E7B59C
E7AD94E7A58CDEA58CDE9C84D69C84DE9C84DE9C84DE9C8CD69C84D68C7BD68C73CE8C6B
CE8463CE8C6BDE9C84E7BDA5EFBDA5EFBDA5E7B59CDEA58CD6A58CDEA58CD6A584DEA58C
DE9C84DEAD94DEAD94C6ADAD8C7B73846352F7F7F7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7DED6E7846352F7D6BDEFCEB5EFBDA5EFBDA5EFCEB5EFCEB5
F7D6BDF7D6BDF7CEB5EFCEB5F7D6BDF7D6BDF7BDB5F7D6C6F7D6BDF7D6BDF7D6BDEFCEB5
E7B59CE7A58CDE9C84DE9473EFC6ADEFCEB5F7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6C6
F7D6C6F7DECEF7DECEF7D6C6F7BDB5EFBDA5EFBDA5E7B594EFBDA5EFBDA5E7B59CE7B59C
E7AD94DEA58CD6A584D6A58CD69C84D6A584D6A584D69C84D69C84D6A584D69C84D69C84
CE8C84D69C84D69C73E7BDA5E7B59CEFBDA5E7B594DEA58CDEA58CD6A584D6A584D6A584
DEA58CDEAD94DEAD94C6ADA57B635ACEBDC6D6C6BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFBDA59CEFCEB5F7D6C6F7D6BDF7D6C6EFCEB5D6C6C6EFCEB5
EFCEB5F7BDB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDEFCEB5
EFBDA5E7B59CE7A58CDE9C84E7B594EFCEB5F7D6BDF7DECEF7DECEF7DECEF7DECEF7D6C6
F7D6C6F7D6C6F7DECEF7DECEF7CEB5EFBDA5EFBDA5E7B594E7B59CEFBDA5E7B594E7B594
E7AD94DEA58CD6A584D69C84CE947BCE8C6BCE947BCE9473CE947BCE947BD68C7BD69C84
D69C73D6A584DE9C84E7B594EFBDA5E7B59CDEAD94DE9C84D69C84D69C84D69C73D6A584
DEA58CD6A58CD6A58CCEB5AD312121CEBDB5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7DED6E7F7D6BDF7D6BDF7D6C6F7D6BDF7DECEEFCEB5EFCEB5F7D6BD
EFCEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7BDB5
EFC6ADEFBDA5E7AD94E7A58CDE9C84EFBDA5EFCEB5F7D6C6F7DECEF7D6C6F7DECEF7D6C6
F7D6C6F7D6BDF7DECEF7D6C6F7D6BDEFCEB5EFBDA5E7A58CE7A58CE7AD94E7B594DEA58C
D6A584D69C84C69C84CE947BCE9473CE947BCE8C73CE9473CE9473CE9473CE8C73CE9473
CE9473D68C7BDEAD94D69C73E7B59CE7B594E7AD94DE9C84D69C84D69C84D69C84D6A584
D6A584DEAD94D6A58CBDA59C523931948484E7DEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7DECED6F7D6BDF7D6C6F7D6BDF7D6BDF7C6ADEFCEB5F7D6BDF7D6BD
F7BDB5F7D6BDF7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BD
F7BDB5EFBDA5E7B59CE7A58CDE9473E7B594EFBDA5F7D6C6F7DECEF7DECEF7DECEF7D6C6
F7D6C6F7D6C6F7D6BDF7D6C6EFCEB5EFBDADE7AD94E7AD9CE7AD9CDEAD94DE9C84DE9C84
D69C73D69C73CE9473CE947BCE8C73CE9473CE9473CE947BCE947BCE9473CE9473CE8C6B
CE9473D6A584DE9C84E7AD94DEAD94DEA58CDEA58CDE9C84D69C84D69C84D69C84D6A584
D6A58CDEA58CD6A58CBDA59C312118634A42948484F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7EFE7E7F7CEB5F7D6BDF7D6C6EFC6ADF7C6ADE7B594F7D6BDD6C6C6F7D6BD
F7CEB5F7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6BD
F7BDB5EFC6ADEFBDA5E7AD94E7A58CE7A58CEFBDA5F7D6C6F7D6C6F7DECEF7DECEF7D6C6
F7BDB5F7C6ADEFCEB5F7D6BDF7D6BDF7C6ADE7B59CE7AD94E7AD94DEAD94D68C73D6A584
D6A58CD69C84CE8C73CE8C73CE9473CE947BCE947BD69C73D69C73CE9473CE9473CE9473
CE8C6BDE9C84E7AD94E7B594E7AD94E7A58CDEA58CD6A58CD69C84D69C84D69C84DE9C84
D6A58CD6A58CDEAD94BD9C8C312121422931CEBDB5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7D6BDF7D6C6F7D6BDF7DECEEFCEB5E7A58CDEAD94F7D6BDEFCEB5F7D6BD
F7D6BDF7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6
EFCEB5EFC6ADEFBDA5E7B594E7A58CDE9C84E7A58CEFCEB5F7DECEF7DECEF7D6C6F7D6BD
F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6BDEFC6ADEFBDA5E7B59CDEAD94DEAD94D69C84
BD846BCE8C73CE8C6BCE8C73CE947BCE9473CE947BD69C73D68C7BD69C73CE9473D69C73
DEA58CE7B59CE7B594E7B594DEA58CDEA58CDEA58CDEA58CD69C84D69C84D69C84D6A58C
DE9C84D6A58CD6A58CA584844A31317B737BF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7D6BDF7D6BDF7D6C6F7DECEE7B59CE7B59CDEAD94F7BDB5EFCEB5F7D6BD
F7BDB5F7D6BDF7D6C6F7DECEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECEF7D6C6
F7D6BDF7CEB5F7C6ADEFBDA5E7B594E7A58CE7A58CEFC6ADF7D6C6F7D6C6F7DECEF7D6C6
F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6BDEFBDADEFBDADE7B59CDEB59CDEA58CDEA58C
DEA58CCE947BCE8C73BD846BCE8C73CE9473CE947BD69C73D69C84D68C7BDE9C84DEAD94
E7AD94E7BDA5E7B59CE7B59CDEA58CE7AD94DEA58CDEA58CDEA58CD6A584D69C84D6A58C
D6A584D6A58CD6A58CAD846B422921523931634A42E7DEEFF7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7E7DEF7CEB5F7D6BDF7D6C6EFCEB5DE9C84E7B594E7BDA5EFCEB5F7BDB5F7D6BD
F7D6BDF7D6BDF7D6C6F7DECEF7DECEF7DECEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7DECE
F7D6BDEFCEB5F7BDB5F7C6ADEFBDA5E7AD94E7A58CE7B59CF7BDB5F7D6C6F7DECEF7D6C6
F7D6C6F7D6C6F7DECEF7E7DEF7DECEF7D6C6EFCEB5EFBDA5E7B59CE7AD9CDEAD94DEA58C
DEA58CDEA58CD6A58CDE9C84BD846BC68C73CE8C6BCE9473D68C7BDEA58CDEA58CE7B59C
E7B59CE7B59CE7B59CE7B59CE7AD94E7A58CDEA58CDE9C84DEA58CD69C84D69C84D69C84
D6A584D6A58CDEB59CB58C73734A395A31293121188C736BDECED6F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7EFCEB5F7D6BDF7D6C6EFCEB5EFC6ADCE8C6BD69C8CEFCEB5EFCEB5F7BDB5F7D6BD
F7D6BDF7D6BDF7D6C6F7DECEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6C6
F7D6C6EFCEB5F7D6BDF7BDB5E7B59CE7B59CE7B594EFBDADEFCEB5F7D6C6F7D6C6F7CEB5
F7D6BDF7D6C6F7DECEF7DECEF7D6C6F7D6BDEFC6ADE7AD94DEA58CDEA58CDEA58CD6A58C
D6A58CD69C84D69C84DE9C8CD69C73BD846BCE8C73D68C7BD69C84DEAD94E7AD9CE7B59C
EFBDA5EFBDA5E7B59CE7BDA5DEB59CDEAD94DEAD94DEA58CD6A58CDEA58CD6A58CD69C84
D6A58CD6A58CDEB59CD69C73C68C63A5634A844A395A4239634A42AD9494F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7E7E7F7C6ADF7D6BDF7C6ADE7B594DEA58CDE9C84DEB59CEFCEB5F7BDB5F7D6BDF7D6BD
F7D6BDF7D6C6F7D6BDF7DECEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECEF7D6C6
F7D6BDF7D6BDF7D6BDF7BDB5EFC6ADEFBDA5EFBDA5E7B59CF7D6C6F7D6C6F7D6C6EFCEB5
EFC6ADF7D6BDF7D6C6F7D6C6EFCEB5F7BDB5EFBDA5DEAD94DEA58CD69C8CD69C8CD69C84
D6A58CD69C84D69C84D69C84CE9473BD8463CE8C6BD69C73DEA58CE7AD9CE7B59CE7B59C
EFBDA5E7B59CE7B59CE7B59CDEAD94DEAD94E7AD94DEAD94DEA58CDEA58CD6A584DEA58C
DEA58CDEA58CDEB59CD69C84D69C73CE8C73BD846B634A428C7B73E7DEE7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7D6C6F7CEB5E7A58CDE9473D67363D67B6BD69C84E7B59CD6C6B5F7D6BDF7D6BDF7D6BD
F7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6
F7D6C6F7D6BDEFCEB5F7BDB5EFC6ADEFBDADEFCEB5F7C6ADF7D6BDF7D6C6F7D6BDEFC6AD
EFBDADEFCEB5F7D6BDF7D6BDF7BDB5EFBDA5E7B594E7AD94DE9C84D69C84D69C84CE947B
CE947BCE947BD69C73CE9473BD846BC68C63CE8C73DE9C8CDEAD94E7B59CE7B59CE7B59C
EFBDA5EFBDA5E7B59CE7B59CDEAD94E7AD94DEA58CDEA58CDEA58CDE9C84D6A584D69C84
DE9C84DEB59CDEB59CD69C84D69C84D69C84D69C84BD9C8CF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7BDB5F7CEB5E79484E77B6BD67B6BCE8C6BDEA58CE7AD9CEFCEB5F7D6BDF7D6C6F7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6
F7D6BDF7BDB5EFCEB5F7C6ADEFBDADEFC6ADEFCEB5F7D6C6F7D6C6F7DECEF7D6C6F7D6BD
F7D6C6F7D6C6F7D6BDF7BDB5EFC6ADEFBDA5E7B59CDEAD94D69C84C69C84C68C73CE947B
CE9473C68C73CE9473CE8C6BCE8C6BCE8C6BD68C7BDEA58CDEAD94E7B59CEFBDA5EFBDA5
E7B59CEFB5A5E7B59CE7B59CE7B594E7AD94DEA58CDEA58CDE9C84D6A58CD6A58CD69C84
D6A58CDEAD94DEB5A5CE9473CE9473D69C73D69C73C6ADA5F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFD6CE
F7BDB5F7C6ADE79484DE9473D67B6BCE8C73D6A58CEFBDA5EFCEB5F7D6BDF7D6C6F7D6BD
F7DECEF7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7BDB5
F7D6BDF7BDB5EFCEB5EFBDADF7C6ADF7BDB5EFCEB5F7D6C6F7D6C6F7DECEF7DECEF7DECE
F7D6C6F7D6C6F7D6C6EFCEB5F7C6ADEFBDA5E7B59CDEA58CD69C84CE947BCE947BC68C73
C68C73C68C73C68C73CE947BCE947BD69C84DEAD94DEAD94E7B59CE7B59CE7BDA5E7BDA5
EFBDA5E7BDA5E7B59CE7AD94DEAD94DEAD94DEA58CDEA58CDE9C8CDE9C8CDE9C8CD69C84
D69C84D6A58CDEB5A5CE8C6BCE8C6BD69C84D69C84DEB59CFFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BDB5
F7CEB5F7BDB5E7A58CE79484CE8C73CE8C73DEAD94EFBDADEFCEB5F7D6C6F7D6BDF7D6C6
F7DECEF7D6C6F7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6BDEFCEB5F7D6BD
EFCEB5F7D6BDF7BDB5EFC6ADEFBDA5EFBDA5EFBDADF7D6C6F7D6C6F7D6C6F7DECEF7D6C6
F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5E7B59CE7AD94DEA58CD69C84C69C84CE947BCE9473
CE947BCE947BCE947BD6A584D69C84DEA58CDEAD94E7AD9CE7AD9CEFBDA5EFBDA5E7B59C
EFBDA5E7B59CE7B59CE7B59CE7AD94DEA58CDEA58CD6A58CD69C8CD69C84D6A58CD69C84
D69C84D69C8CDEB5A5D68C7BD68C7BD69C73D6A58CD69C84F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEEFBDA5
F7CEB5F7D6C6E7A58CDE9C84CE8C6BC68C73DEAD94EFC6ADF7D6BDF7D6C6F7D6C6F7D6C6
F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFCEB5F7D6BDF7D6BD
F7BDB5EFCEB5EFC6ADEFC6ADEFBDA5EFBDADEFC6ADF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6BDF7BDB5EFBDA5E7A58CDEA58CD69C84C69C84CE947BCE947B
CE947BC69C84C69C84D69C84D6A584DEAD94DEAD94E7B59CE7B59CEFBDA5EFBDA5E7BDA5
E7B59CE7B59CE7AD94DEAD94DEAD94DEA58CDE9C84DEA58CDE9C84D69C84D69C84D69C8C
D6A584D69C8CDEB5A5D6A58CDE9C84D6A584D6A58CD68C7BD6C6C6F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDE7B594
F7D6BDE7BDA5E7AD9CDE9C84BD846BC68C73DEB59CEFC6ADEFCEB5EFCEB5F7D6BDF7D6C6
F7DECEF7D6C6F7DECEF7DECEF7D6C6F7D6BDF7D6BDF7D6BDEFCEB5EFCEB5EFCEB5EFBDA5
EFCEB5EFCEB5EFBDADEFBDA5EFBDA5EFCEB5EFCEB5EFCEB5F7D6C6F7D6BDF7D6BDF7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFBDA5E7AD94DEA58CD69C84D69C84C6947BCE947B
C69C84C69C84D69C84D6A58CDE9C84DEA58CE7AD9CE7B59CE7BDA5E7B59CE7BDA5E7B59C
E7BDA5E7B594E7AD94E7AD9CE7AD94DEA58CD6A58CD69C84D6A584D69C8CD69C84D69C84
D69C84DEB59CE7AD9CCE9473D6A584D6A58CDEB59CD68C73DEAD94F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFE7B594E7A58C
CE8C73DE9C8C9C6B529C6B52B57B63BD846BE7BDA5EFCEB5F7D6BDF7D6C6F7D6C6F7D6C6
F7D6C6F7DECEF7D6C6F7D6C6F7D6BDF7D6BDF7CEB5F7D6BDEFCEB5EFC6ADEFBDADEFBDAD
E7BDA5EFBDADEFBDADEFC6ADEFCEB5EFCEB5EFCEB5EFCEB5F7D6BDF7D6C6F7D6C6F7D6BD
F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFBDADE7AD94DEA58CD69C84CE947BCE947BCE947B
CE947BC69C84D69C84D69C84D6A58CDEAD94E7AD9CE7BDA5E7B59CE7AD94E7B59CE7BDA5
E7BDA5E7B59CE7B59CE7AD94DEAD94DEAD94DEAD94DEA58CD6A58CD69C8CD69C84D69C84
D69C8CD6A58CDEB5A5AD6B52CE7352D6A584DEB59CD68C73D68C73EFE7E7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDE7A58CD68C7B
CE8C738C5A42AD735A8C5A4A94634A9C7363E7BDA5F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6EFCEB5EFCEB5EFC6ADEFCEB5EFC6ADEFBDAD
E7B59CE7BDA5E7BDA5E7BDA5EFBDADEFCEB5EFCEB5EFCEB5EFCEB5F7D6C6F7D6C6F7D6BD
F7D6BDF7D6C6F7D6C6F7CEB5EFCEB5EFBDA5E7AD94D69C73D69C84CE947BC68C73CE947B
CE9473CE8C84D69C8CD69C84D6A58CDEAD94DEAD94E7AD9CDEB59CDEAD94E7AD94E7AD94
E7AD9CE7AD94E7AD94E7AD94DEAD94D69C8CDEAD94D6A58CD69C8CD69C84D69C84D6A58C
D6A58CD6A58CC6ADA5B5735AC66B52CE947BD6A58CD69C84D69C73F7BDB5F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6ADDE9473CE947B
734229D69C848C5A4A845242734A42A5735AE7BDA5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6
F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6EFD6CEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5
EFBDADEFBDA5E7AD9CE7AD9CDEAD94E7AD9CEFC6ADEFCEB5EFCEB5F7D6BDF7D6C6F7D6BD
F7D6C6F7D6C6F7D6BDF7D6BDEFBDADE7B59CDEA58CD68C7BCE8C84CE9473CE9473CE947B
C68C73D69C73D69C84D6A58CDEAD94DEA58CDEA58CDEAD94DEAD94E7B59CE7AD9CE7AD94
DEA58CDEAD94DEAD94DEA58CD6A58CDEAD94D6A58CD69C8CD6A58CD6A584D69C84D69C84
D69C8CC6ADA5D6A58CB57B63C68C63CE8C6BCE9473DEA58CD68C7BDEA58CF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFE7B594E79484A5735A
B5735A6342318C5A428C6352846352846B5AE7BDA5F7D6BDF7D6C6EFCEB5F7D6C6F7D6BD
EFCEB5F7D6BDEFCEB5D6C6B5EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6D6C6BDF7D6C6
F7D6C6D6C6B5E7BDA5E7BDA5DEAD94DEA58CDEAD94DEB59CEFCEB5EFCEB5F7D6C6F7D6C6
F7D6C6F7D6C6F7D6BDF7D6BDEFBDA5E7BDA5DEA58CD69C84CE947BCE947BC68C73C68C73
CE947BC69C84D69C8CD6A584DEA58CD6A58CDEA58CDEA58CDEAD94DEAD94DEAD94DEAD94
D69C8CD6A58CDEA58CDEA58CDEAD94DEA58CD6A58CD6A58CD6A584D69C84D6A584D69C84
D69C8CC6ADA5D6A58CB57B63A5634AA55239A54231CE7352D69C73D68C73F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEDE9473E7AD9CAD735A
B5735A421810734A39523129734A42846352E7BDA5F7D6BDF7D6BDEFCEB5EFCEB5F7D6C6
F7D6C6F7D6BDF7D6BDEFCEB5DEB59CC69C84DEB59CD6A584C6947BCE8C84C6947BC69484
C69484D69C8CCE8C84D69C8CDEA58CDE9C8CDEA58CDEAD94E7BDA5EFCEB5F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6BDEFBDADE7B59CDEA58CCE947BCE9473CE9473CE8C6BC68C73
C6947BCE947BCE947BCE947BC69C84D69C8CC69C84D6A58CD6A58CD6A58CDEB59CDEB59C
D6A58CDEAD94DEAD94DEAD94DEAD94DEAD94D6A58CD6A58CD6A58CD6A584D69C84C69C84
D69C8CDEB59CD6A58CB5846BA5634AAD5A42A55239BD5A42CE8463D68C7BF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDDE9473E7AD9CBD846B
734231312118312118422921634231734A42EFC6ADF7D6C6F7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6EFCEB5EFC6ADDEB59CC68C73B5846B845239734A429C6B52BD846BBD846BA5735A
9C7363A56B52B5846BB5735AC6947BD68C7BCE8C73DEAD94E7BDA5EFC6ADF7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6BDEFBDADE7B59CDE9C84D69C73CE947BCE8C6BC68C73C69C73
BD846BB58C73C69C84D69C8CD69C84CE947BC69C84D69C84D69C84C69C84D6A58CDEAD94
DEAD94DEB59CDEAD94E7AD9CDEAD94D6A58CD6A58CD69C8CD69C84D6A58CC69C84C69C84
D6A58CD6A58CD6A58CAD846BA56B52AD5A42AD5A42BD5A42CE8463DE9C84F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFC6ADE77B6BE7AD9CD69C8C
4218104210104229215231295239317B6352EFC6ADF7D6C6EFCEB5F7D6BDF7CEB5F7CEB5
F7D6BDF7D6BDF7D6BDEFCEB5EFC6ADDEB59CC69C84734A39AD846BCEB5BD7B635AAD846B
634A42291818845239734229B57B63AD6B52AD5A42A55239AD5A42E7B594EFC6ADF7D6C6
F7D6C6F7D6C6F7D6C6F7D6BDEFC6ADE7B59CDEA58CD69C73CE9473B58C73C69C73BD8463
BD846BC69C84D6A58CDEAD94DEAD94DEAD94DEAD94DEAD94DEA58CD69C8CD69C8CD69C84
C69C84D6A584DEAD94DEB59CDEAD94DEAD94D6A58CD6A58CC69C84D69C84C69C84D69C84
D6A58CD6A58CD6A58CB5846BAD6B52AD5A42AD5A42BD5A42CE735AD69C84F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFE7B59CCE7352E7AD94EFB5A5
52312939292142293152312963423173524AEFCEB5F7D6BDF7D6C6EFCEB5EFCEB5EFCEB5
F7D6BDF7D6C6F7D6BDEFCEB5EFCEB5D6A58CDEAD94C6947BA5847B5A42395A3121948484
84739429181873524A845239BDA59CB59C9C8C5A42AD5A42D69C73EFBDA5EFCEB5F7D6C6
F7D6C6F7DECEF7DECEF7D6C6EFCEB5EFBDA5DEA58CD69C73CE8C6BBD846BB5735AB5735A
BD8463D6A584DEB59CDEB59CDEB59CDEB59CDEAD94D6A58CD6A58CDEB59CDEB59CD6A58C
D69C8CD6A584D6A58CDEAD94DEB59CDEAD94D6A58CD6A584D6A584C69C84D6A584C69C84
C69C84D6A58CC69C849C736394634AA5634AA5634AC66B52CE8C6BDE9C84F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF734229F7C6ADCE7352DE9C84E7AD94
734A423121214229215231295A3129846352EFCEB5F7D6BDF7D6BDEFCEB5EFCEB5EFCEB5
F7D6BDF7D6C6F7D6BDF7D6BDF7D6C6EFC6ADDEAD94DEAD94EFBDADDEB59C846352634231
5231293121186339296339297B635AAD6B52B5735AC66B52DEA58CE7B59CEFCEB5F7D6BD
F7DECEF7DECEF7E7DEF7D6C6EFCEB5EFBDA5DEA58CD68C7BBD846BBD8463BD8463AD6B52
7B2918844A39C68C73CE947BC68C63B57B63B5846BA56B529C6B52B57B63C6947BC69484
C69C84D6A584D6A584C69C84D6A58CD6A58CD6A58CC69C84C6947BC69C84C69C84D69C84
D69C8CD69C8CC6947B9C6B52945A4AA56B52AD6B52CE8463D68C7BD68C7BFFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE75A31295A3121F7C6ADE7B59CF7C6ADE7B59C
845242392921523129422921523129846352EFC6ADF7D6BDEFCEB5EFCEB5EFCEB5F7CEB5
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDEFCEB5E7B59CDEAD94DEAD94DEB5A5AD846B
9C6B5273524A9C6B52845242AD6B52BD8463B5735AE7B594E7B594E7B594EFCEB5F7D6BD
F7DECEF7E7DEF7E7DEF7D6C6EFC6ADEFBDA5DEA58CD68C7BCE8C6BBD8463BD846BB5735A
A573528C5A42C6ADADD6C6BDBDB5BD8452397B29187342298452429C7363945A528C5A42
B57B63B5846BB58C73B58C73C69C73C6947BC6947BC6947BCE947BCE947BC69C84D69C84
D69C8CC69C84B58C738452428C5A4A8C5A4A9C6B52D68C73D69C73CE8463F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F76342315221184A2118E7A58CF7C6ADE7B59CE7A58C
8C5A4A5242394231393121184229218C6352EFCEB5EFCEB5EFCEB5F7D6BDF7D6BDE7B59C
EFCEB5F7D6BDEFCEB5F7D6C6F7D6C6F7D6BDEFCEB5EFCEB5E7B59CD6A58CD6A58CDEB59C
D6A58CB58C73BD8463B5735ABD8463B5735AD6A584DE9C84E7AD94E7BDA5EFC6ADF7D6BD
F7DECEF7E7DEF7DECEEFCEB5EFC6ADE7BDA5DEA58CD69C73CE8C6BBD8463BD846BBD8463
AD6B52A56B52A5847BDECED67B635AA5847B211010423139845242634231846B5A945A4A
6342319C6B529C73639C6B52A57352B57B63CE8C6BCE947BC69C84D6A584C69C84C69C84
D69C84C6947BAD846B845242734A39846352845242D69C84DEA58CCE7352FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7846B5A5A3129422921421810734229DE9473B5735AA55239
5A42394A31314229213929215231298C7363F7CEB5F7CEB5F7D6BDEFCEB5F7D6C6E7BDA5
C68C73EFBDA5EFCEB5F7D6C6F7D6C6F7DECEF7DECEF7D6C6EFCEB5EFC6ADE7B59CE7B59C
DEAD94DEA58CD6A584D6A584DE9C84DE9C84DEA58CE7B594E7BDA5EFC6ADF7D6BDF7D6C6
F7DECEF7DECEF7DECEF7D6BDEFC6ADEFBDA5DEAD94D69C84C68C73BD8463CE8C6BBD846B
BD8463B5735AC68C73B57B63734A42ADA5AD1810105A5252734A42634231A5847B8C7B73
524239634231734A427B6352B57B63BD8463CE9473D6A584D6A58CD6A58CD6A58CC69C84
C69C84C6947B8C63526B524A734A39523931845239D6A58CCE8C6BCE7352F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7FFFFFF5A31296339295231294218104A10084A1008845242523129
422931523931392921392921523129A5735AEFCEB5F7BDB5EFCEB5EFCEB5F7D6C6EFCEB5
DE9C8CD6A58CDEAD94EFCEB5F7D6C6F7DECEF7DECEF7D6C6F7D6C6EFCEB5EFBDADE7B59C
DEA58CDEA58CDEAD94DEA58CDEA58CDE9C84E7B594E7B594EFBDA5EFC6ADEFC6ADF7D6C6
F7DECEF7DECEF7DECEEFCEB5EFBDADE7B59CDEB59CD6A58CCE9473CE8C6BC69C73C69C73
CE8C6BC69C73D6A58CB58C73C68C736B524A31212131211863392952312973524A5A4239
5A42398463529C6B52C69C73BD846BC69C73D6A584CE9473CE947BD6A58CC69C84C69C84
D6A584C6947B734A42734A39634231523129734231DE9C8CCE735ACE634AF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFE7E75A31215A31296339294229215221184218105A42394A3131
3929213121213121214229214229218C7363EFC6ADF7CEB5F7D6BDF7D6BDEFCEB5F7D6C6
EFCEB5CE947BDEAD94D69C8CEFC6ADEFD6CEF7DECEF7DECEEFD6CEF7D6C6EFCEB5EFC6AD
DEAD94DEAD94DEB59CDEA58CD69C73D68C73D68C73DEAD94E7BDA5E7BDA5EFCEB5F7D6C6
F7DECEF7DECEF7D6C6EFCEB5EFBDA5E7B59CDEAD94D6A58CC69C84CE8C6BCE8C6BCE9473
CE947BCE9473BD8463D6A58CD6A58CA5735A9C7363845242634A428452395239318C6352
AD846BAD735AAD846BB58C73C68C73CE9473C6947BD6A58CC69C84C69C84C69C84C69C84
C69C84AD846B734A39523931634A425A3129633929D6A58CCE634ACE7352FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7AD94A55A31295239316342315A31295A3129523129523931523931
2918183121185231293121185A3129846352EFC6ADF7CEB5F7CEB5F7D6BDEFCEB5F7D6BD
F7D6C6EFBDADDEB59CAD847BBD846BC6947BC6947BB58C73B58C739C6B529C7363846352
8C5A4A94634A94634A8C5A42A56B52AD6B52AD6B52CE947BDEB59CE7BDA5EFCEB5F7D6C6
F7D6C6F7D6BDF7D6BDEFC6ADEFBDA5E7B59CDEB59CD6A58CCE947BCE9473CE8C6BCE8C6B
C69C73CE947BD6A584CE9473D6A58CD6A584D6A58CC6947BC6947BAD846BAD735AAD846B
AD735AC69C73CE947BCE947BD69C73D69C84C69C84D69C84D6A584D6A58CD6A58CD6A584
C69C848463526342315A4239523129422118734231BD846BBD5A42CE7352F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7B5A5A5523129422921422921422921392921422921523129422921
3929213121183121215231295231298C6352EFC6ADEFCEB5F7D6BDEFCEB5F7D6BDF7D6BD
F7D6BDF7D6C6EFCEB5EFBDADD69C8C94736B947B73AD8C84AD7B6BAD7B6B9C6B528C6352
A5735A945A52945A4A945239945A4AB57B63BD846BD69C84E7B59CF7BDB5EFCEB5F7D6C6
F7D6C6EFCEB5EFCEB5EFC6ADEFBDA5EFBDA5DEB59CDEAD94CE8C84C68C73BD8463BD8463
BD8463C68C73CE947BDEAD94DEA58CD6A584CE947BCE9473C69C73C69C73BD846BCE9473
CE947BD69C84D69C73C69C84D69C8CC69C84D69C84C69C84C69C84C69C84C69C84C69C84
B58C73734A424A313142313952423942211894634ABD846BAD5A42C66B52F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7C6ADBD6339294A21184221184221183929214A2118422921211010
422921312118392921523931634A427B6352DEB59CEFC6ADF7CEB5F7D6BDF7D6BDF7D6BD
F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5D6A58CD69C8CD69C8CAD8C84CE8C84D69C8CC69484
C68C73AD847BC6947BBD846BBD846BCE947BDEA58CEFBDADEFCEB5F7D6BDF7D6C6F7D6C6
F7D6C6F7CEB5F7BDB5EFBDA5EFC6ADE7BDA5DEB59CDEAD94CE8C84BD846B9C5A428C5A42
9C5A42B5735AC69C73CE947BD6A584DEA58CD6A584DEA58CDEA58CD6A584D6A584D6A584
C69C84C69C84D6A584D69C8CC69C84D6A58CD69C8CC69C84C69C84D69C8CD6A584C69C84
AD846B6342313929214A3131392921312118C68C73BD8463AD5A42CE7352F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7D6CEDE633931312118422921392921422921523129422921291818
422921422921312121392921634A428C6352D6A58CEFC6ADEFCEB5EFCEB5F7D6BDF7D6BD
F7D6C6F7D6C6F7D6C6F7DECEF7D6C6EFCEB5EFCEB5EFCEB5F7D6C6F7D6C6F7D6C6D6C6BD
F7BDB5D6C6BDF7BDB5D6C6C6F7BDB5F7D6C6EFCEB5EFCEB5EFCEB5F7D6C6F7D6C6F7D6C6
EFCEB5EFCEB5F7CEB5EFBDADEFC6ADEFBDADE7BDA5E7AD9CD6A58CCE947B9C6B52845242
844A39844A39A5735ABD846BCE9473D6A58CD6A58CDEAD94DEA58CD6A58CD6A58CD6A584
D6A58CD69C84D6A58CD6A58CC69C84D6A58CC69C84D6A584C69C84D6A58CC69C84D6A584
8C6352523129392921422931312121523931CE9473CE735AAD5A42C66B52948484F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7E7DEEF734A394229214A2118392921422921392921392921312118
211010422921422921523129634A427B6352C69C84E7BDA5EFC6ADF7CEB5F7D6BDF7D6BD
F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECE
F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BDF7D6BDEFCEB5F7D6C6F7DECEF7D6BD
EFCEB5EFCEB5EFCEB5EFC6ADEFC6ADEFC6ADE7BDA5EFB5A5E7BDA5EFBDADD6A58CBD846B
945A528C5A4A734A39633929634231845242B57B63D6A584D6A58CD6A58CD6A584D6A584
D6A584C69C84C69C84CE947BCE947BC68C73B58C73CE947BD69C8CD6A58CD69C84B58C73
734A393929214229213121215242395A3129AD6B52BD846BA55239B57B636B524ADECED6
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7633931634231523129422921392921422921422921422921
211010422921392921523129734A39846352C69C84DEAD94EFBDA5F7CEB5F7D6BDF7D6BD
F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7E7DE
F7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6EFCEB5
F7BDB5F7BDB5EFCEB5EFC6ADEFBDA5EFC6ADEFBDA5E7BDA5EFBDADE7BDA5DEB5A5DEB5A5
D6A58CBD846B945A528C5A4A7342316339296342317342318C5A4AB58C73C69C73C68C73
CE947BC6947BB58C73B57B639C6B529C6B52BD846BD6A58CD69C84D69C8CD69C84AD846B
5A3129422921422921422921422931422118844A39AD6B52BD8463A5735A735A529C8C8C
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7634A42734A42523931422921422921392921422921422921
312118291818422921634231634A42846352C6947BD6A58CEFC6ADF7CEB5F7D6BDF7D6BD
F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DE
F7DECEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7DECEF7D6C6F7D6BDF7D6C6F7D6BDEFCEB5
F7D6BDF7D6BDEFC6ADEFC6ADEFBDA5EFC6ADEFC6ADEFBDADEFC6ADEFBDADEFBDADE7BDA5
DEB5A5DEAD94D69C8CAD846B9C73638C5A4A734A396342316342318452428C5A4A9C6B52
846B5A8C5A4A9C6B52A5735A9C6B52B5846BD69C8CD6A58CD69C84C69C84CE947BA5735A
5231293121184229214229314A31314221185221188C31297B3121633929735A52B5A5A5
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7734A39734A39634231523129422921523129422921422921
392921211010523129523129634A427B6352B58C73D6A584E7B59CF7CEB5F7D6BDF7D6C6
F7D6BDF7DECEF7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6EFCEB5EFCEB5
EFCEB5EFCEB5EFC6ADF7C6ADEFC6ADEFBDADEFC6ADEFBDADEFC6ADEFC6ADE7BDA5E7B59C
E7BDA5DEB59CDEB59CD6A58CC69C84BD846B9C7363945A52734A39734A39845239845239
845242845242945A52AD735ABD846BC69C84D69C8CC69C84C69C84CE947BC68C738C5A4A
4229214229213929214229213929213121184208006318106339295A42397B6352FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7DED6E773524A734A3973524A523931392921523129422921422921
4229214A31314A31315A4239634A42846352AD846BBD9C8CDEB59CEFBDA5F7D6BDF7D6BD
F7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7DECEF7D6C6F7DECEF7D6BDF7D6BDF7D6BD
F7D6BDF7C6ADEFC6ADEFC6ADEFC6ADEFBDA5EFBDA5EFC6ADEFC6ADEFC6ADEFBDADEFB5A5
E7BDA5E7AD9CDEB59CDEB59CD6A58CD6A58CC69C84CE947BB58C73B57B63A5735A9C6B52
A5735AAD735AC68C73C69C84C69C84D69C84CE8C84C69C84C69C84CE947BB58C73634231
523129422921422921523129392921392921312118523129523129523129735A529C8C8C
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7CEB5B5734A396B524A734A39634231523931523129422921422921
422921422921422921523129634231734A429C7363C6947BDEAD94EFC6ADF7CEB5F7D6BD
F7D6BDF7D6C6F7DECEF7D6C6F7DECEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7D6C6F7D6BDF7D6BDEFCEB5EFCEB5
EFCEB5EFC6ADEFC6ADEFBDA5EFBDA5EFC6ADEFBDADEFCEB5EFBDA5EFC6ADEFBDADE7B59C
E7B59CE7B59CDEB59CDEB59CDEAD94D6A58CD6A58CD69C8CD69C8CCE947BCE947BCE8C84
CE8C73C69C84C69C84D69C84C69C84D69C84CE8C84D69C73C69C84C68C73AD846B5A3129
5231294229213929213929214A31313929213121213121184229215231294A31316B524A
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F79C8C8C734A39734A396342315239315239314A3131422921422921
4A2118523931523129422921634231634231846352AD846BD6A58CEFBDA5EFCEB5F7D6BD
F7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6BDEFCEB5F7D6C6F7D6BD
F7CEB5F7CEB5EFBDA5EFC6ADEFC6ADEFBDA5EFC6ADEFBDA5EFBDA5E7BDA5EFBDA5E7BDA5
E7B59CE7BDA5E7AD94DEB59CDEAD94DEB59CD6A58CDEB59CDEAD94DEAD94D6A58CD6A58C
D6A58CD69C84D69C84D6A584D69C8CD69C84D69C84D69C84CE947BB58C7394634A523129
5231293929214229213929215231293929213929214229214229213121186342316B524A
C6ADADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7846B5A6342316B524A73524A634A42523931633931523129422921
422921422921422921422921523129634231734A398C6352B58C73E7BDA5EFC6ADF7CEB5
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7D6BDEFCEB5F7D6BDF7D6BDEFCEB5
EFC6ADEFC6ADEFC6ADEFBDA5EFBDA5EFC6ADEFC6ADEFBDA5EFBDA5EFB5A5E7B59CE7B59C
E7BDA5E7BDA5E7AD9CE7B59CDEB59CDEAD94DEB59CDEAD94DEAD94D6A58CD6A58CD69C8C
D69C84D69C8CD6A58CD6A58CD69C8CC69C84D69C84C69C84B58C73A5735A734A39523931
4229213929213121215239312918183121213121213929214229212918184A3131634231
AD9C8CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F773524A634231634A426B524A634A425239315A4239523129422921
312118422921422921523129422921634231734A39734A42A57352D6A584EFC6ADEFCEB5
F7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DE
F7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7D6C6F7D6BDF7D6BDF7D6BDEFC6AD
EFC6ADEFBDA5EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFC6ADEFBDA5E7B59CEFBDA5E7BDA5
E7B59CE7B59CDEAD94DEB59CDEAD94DEAD94DEB59CDEA58CD6A58CD6A58CDEA58CD6A58C
D6A58CD6A58CC69C84C69C84C69C84C69C84C69C84CE947BAD846B7B63525A4239422921
3121183121214A3131291818312121291818312118312118211010312118523129634231
A5847BFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7634A42634A426B524A6B524A734A39634A425A4239523129422921
5231293121184A211842292152312952312973524A846352845242C6947BDEAD94F7CEB5
F7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7BDB5EFCEB5
EFCEB5EFBDADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7BDA5E7B59CE7B59C
DEAD94E7B594DEB59CDEB59CDEAD94DEAD94DEAD94DEAD94D6A58CD6A58CD6A58CD6A584
D6A58CD6A58CD6A584D69C84D6A58CD69C84CE947BB58C73A5735A734A39523129422921
392921523129392921312121312121312118312118312118312118392921422921634231
8C7363F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7EFEFF7F7F77B6352734A396B524A634A426B524A634A42523931523931422921
5231293121184229214229215239315239316B524A7B6352846352BD846BDEAD94EFC6AD
F7CEB5F7D6BDF7D6C6F7DECEF7D6C6F7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDEFCEB5EFCEB5
EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B594E7BDA5EFB5A5E7B59CE7B59C
E7B59CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEA58CDEAD94DEA58CD6A58CDEA58C
D6A58CD69C84C69C84C69C84D69C84CE947BC6947BB5846B8C6352634231523129392921
523931523129291818291818312121291818211010291818312121392921422921523931
947B73F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7734A39634231734A39634A42634A426B524A5A42395A4239523129
523129523129422921523129523129422921634231734A42846B5ABD846BD6A584E7BDA5
EFC6ADF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7E7DEF7E7DEF7E7DEF7DECEF7E7DE
F7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7D6C6F7D6C6EFCEB5F7BDB5F7D6BDF7CEB5
EFBDADEFBDA5EFBDA5E7B59CE7B59CEFBDA5EFBDA5E7B59CEFB5A5E7B59CE7BDA5E7B59C
DEAD94E7AD94DEAD94DEAD94DEA58CD6A58CDEAD94DEA58CD6A58CD6A584DEA58CD69C84
D6A58CD69C84D69C84D69C84CE947BCE9473B58C739C7363734A42634A42634231523931
392921392921312121312118291818291818211010291818312118392921312118634231
EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F76B524A6B524A734A396B524A6B524A6B524A6B524A634A425A3129
523129523129312118523129523129523931734A398452429C6B52AD846BCE8C6BE7B59C
EFC6ADF7D6BDF7D6BDF7DECEF7D6C6F7DECEF7D6C6F7DECEF7DECEF7E7DEF7E7DEF7E7DE
F7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDF7D6BDEFBDA5
EFC6ADEFBDA5E7BDA5E7B59CE7B59CE7B59CEFB5A5EFBDA5E7B59CE7AD94E7AD94DEAD94
E7AD9CE7AD9CDEAD94DEAD94DEAD94D6A58CDEA58CD6A58CD6A58CD6A58CD6A58CD69C8C
CE947BC69C84D69C84C69C84C68C73C68C739C73638C7363734A395A4239523129312118
312118312118312121291818291818211010312118291818312121392921523129735A52
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEF734A42634A42634A426B524A734A426B524A735A525239315A4239
523129422921523129523129523931634231634A4273524A8C6352B57B63C68C73DEA58C
EFBDA5EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7E7DEF7DECEF7DECEF7E7DE
F7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BDEFCEB5EFC6ADEFC6AD
EFC6ADEFBDA5E7BDA5E7B59CE7B59CE7BDA5E7B59CEFBDA5E7B59CE7B59CDEB59CE7AD94
DEA58CDEAD94DEAD94DEA58CDEAD94DEA58CD69C8CD6A58CD69C84D69C84D6A58CD69C84
D6A584D69C84C69C84C69C84B58C73AD846B9C73638C5A4A634231523129422921312121
39293131212131212129181829181831212129181831211831211831211852312973524A
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7EFE7E7634A42634A42634231634A426B524A6B524A6B524A634A42634A42
4229214229215239315231295239316342315A4239734A399C6B52B57B63C68C73D6A58C
E7BDA5EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7DECEF7E7DEF7DECEF7E7DEF7E7DEF7DECE
F7E7DEF7E7DEF7E7DEF7DECEF7DECEF7D6C6F7DECEF7D6C6EFCEB5F7BDB5F7CEB5EFBDA5
EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7BDA5E7B59CE7B594E7B59CE7B59CE7AD94DEB59C
DEB59CDEAD94DEAD94DEA58CD69C8CD69C8CD6A58CD6A58CD6A58CD69C8CD6A58CD69C84
D69C84C69C84C69C84C6947BB5846BA5735AA5735A734A39634231523129523129392921
3929215231293929214229213929213121213121183121213929214229215231298C6352
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7EFE7E773524A6B524A5A3129634A4273524A6B524A735A526B524A634A42
5A3129422921523129523931523129523931734A427B6352A5735AA5735AB57B63CE9473
DEAD94EFC6ADEFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7DECEF7E7DEF7DECEF7E7DEF7DECE
F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6EFCEB5EFC6ADEFC6ADF7C6AD
EFBDA5E7B59CE7B59CE7B59CE7B59CE7B59CE7AD9CE7B59CE7B59CE7B59CE7AD9CE7AD9C
E7AD94DEB59CDEAD94D69C8CDEA58CDE9C8CD6A58CD6A58CC69C84D69C84D69C8CD69C84
D69C84CE947BC6947BB58C73AD846B94634A7B6352734A395A3129523129422931422921
4A31315231293121212918183929213929213121212918182918183929215A4239EFE7E7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F77B63525A42395A4239734A396B524A634A42735A526B524A634231
634A424229215239315239315A42395239316342317B63528C7363845242A5735ABD846B
DEA58CEFC6ADEFCEB5EFCEB5F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECE
F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDEFCEB5F7D6BDEFC6ADEFC6ADEFCEB5EFBDA5
EFBDA5EFBDA5E7B594E7B59CE7B59CE7B59CE7B594E7B59CE7B59CE7B59CE7B59CE7AD94
DEAD94DEAD94DEAD94DEAD94DEA58CD6A58CD6A58CD69C8CD69C84C69C84D69C84D69C84
C69C84C69C84B58C73AD846BA5735A7B6352734A425A42395231294A3131392921392921
312118422921312121312121291818291818181010211010291818422921734A42F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7EFEFF7F7F7F7F7F78C736B634A425A4239734A39634A427B63526B524A6B524A634A42
634A425231293929216342315A4239634A42523931734A3973524A7B63529C6B52B57B63
D69C84EFC6ADEFC6ADF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECE
F7D6C6F7D6C6F7DECEF7D6BDF7D6C6F7D6C6F7D6C6EFCEB5EFCEB5F7CEB5EFC6ADEFBDA5
E7B59CE7B59CE7AD9CE7B594E7AD9CE7B59CE7AD94E7AD94E7AD9CE7B59CE7AD94E7AD94
E7AD94E7AD9CD69C8CDE9C84D69C84D6A58CD69C8CD6A584D6A584D69C84D69C84D69C84
CE947BC68C73B5846B9C6B528C5A4A734A39634A42634231422921422921422921392921
3929213121213121212918183121211810102110102918183121185231298C7363F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7947B7373524A5A42396342315A42396B524A634A426B524A5A4239
5A42396B524A523129392921634231523931634A426342317B6352734A42845242AD846B
C68C73E7B59CEFCEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6
F7D6BDF7D6C6F7D6BDEFCEB5F7D6C6F7D6BDF7D6BDF7BDB5EFC6ADEFC6ADEFBDA5EFBDA5
E7AD94E7B594E7AD94E7B594E7AD9CE7B59CE7B59CE7B59CE7B59CE7B594E7A58CE7AD94
DEAD94DEAD94DEA58CDEA58CDEA58CD6A584D6A58CD6A58CD69C84C69C84CE947BCE947B
B58C73AD846BA5735A8C5A4A734A42634231634231523129422921392921392921392921
422921392921312121312121291818211010291818312118523129734A39FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7947B737B635A5A4239634231634A425A423973524A7B635A523931
634A425A42394221185231294229215A42396B524A523931634A42734A39734A399C6B52
B57B63D6A58CE7B59CEFC6ADF7D6BDF7D6BDF7D6BDEFCEB5F7D6C6F7D6BDF7D6BDF7D6C6
F7D6C6F7D6C6F7D6BDF7CEB5EFCEB5EFCEB5F7BDB5EFC6ADF7C6ADEFC6ADE7B594E7B594
E7AD94E7B59CE7B594E7B594E7B594E7B594DEAD94E7AD94DEAD94E7A58CDEAD94DEA58C
DEA58CDEA58CDE9C84D6A58CDEA58CD6A58CD69C8CD6A584D6A584CE947BC68C73C68C73
BD846BA5735A8C5A4A845242634A425A3129523129422921312118312118392921392921
3929213929213929213121213929212918182110103929215A4239734A39F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7B59C9C8C736B634A42634A426B524A634A426B524A73524A634A42
6342315A42395A4239422921523931523931634A42634A425A423973524A6B524A846352
A5735ACE947BD6A584E7B59CEFCEB5EFC6ADEFCEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDEFCEB5EFCEB5EFCEB5F7C6ADF7D6BDEFC6ADEFBDA5EFBDA5E7AD94E7B59C
E7B594E7AD94DEA58CE7AD94DEAD94DEA58CDEAD94E7A58CE7AD94E7A58CDEA58CDE9C84
DEA58CDEA58CDE9C8CDEA58CD6A58CD69C84D6A584D6A584CE947BC69C84C6947BB5846B
AD846BA5735A845242734A39634231523129422921422921312118312118312121312118
422921392921312121291818211010181010291818523931523129846B5AF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7D6BDC694736B73524A6342316B524A634A42634A4273524A7B635A
5239316B524A5239315239315231295239315A42396B524A634A426B524A634A427B6352
8C5A4AB58C73DEA58CE7B59CE7BDA5EFC6ADEFC6ADEFC6ADF7D6BDF7D6BDF7D6BDEFCEB5
F7D6BDF7BDB5EFCEB5EFC6ADEFCEB5EFC6ADEFC6ADEFBDADEFBDADE7B59CE7B59CE7AD94
E7A58CE7AD94E7A58CDE9C84DEA58CE7A58CDE9C84E7B594DEA58CDEA58CDEA58CD6A584
D69C73D69C84D69C8CD6A58CD6A58CD69C84D69C84C69C84C6947BC6947BB58C73AD846B
9C6B528C5A4A734A39734A395A3129523129422921312118291818291818291818312118
3121182110102110101810101810101810103121185239315A4239B59C9CF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F78C736373524A6B524A634A426B524A5A4239634A42735A52
634A42634A424A31314A31315239314A31315A42395A42396B524A5A4239634231734A42
734A399C6B52AD846BC6947BD6A58CE7B59CE7B59CE7BDA5EFC6ADEFCEB5EFC6ADEFCEB5
EFCEB5EFCEB5EFCEB5EFC6ADEFC6ADEFBDADEFC6ADEFC6ADE7BDA5DE9C84DEA58CDE9C84
DEA58CDEA58CDEA58CDE9C84DE9C84DEA58CDEA58CDE9C84DEA58CDE9C84DEA58CD69C73
D69C84D69C73D69C84D69C84CE947BC6947BC6947BC68C73B58C73B57B63A5735AA5735A
9C6B52734A396342315A3129422921523129392921312118312118312118291818291818
291818211010181010181010181010291818523129523931633929F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7FFFFFF9484847B63526B524A734A3973524A634A42634A4A735A52
634A426342315239314229215231295231294A3131634A426B524A73524A524239523129
734A42734A428C5A4AA5735AB58C73C68C73CE947BD6A58CDEB5A5DEB59CEFC6ADEFC6AD
E7BDA5D6C6B5E7BDA5EFBDA5EFC6ADE7B594EFC6ADE7BDA5E7BDA5DEAD94C69C84D69C84
D69C84DEA58CD69C84D69C84D69C84D6A584DE9C84DE9C84DE9C8CDE9C84D69C84D69C84
D69C73D69C73D68C7BD68C7BC69C73CE947BC68C73BD846BB5846BA5735AA5735A8C5A4A
845242734A396342315A3121422921392921312118291818211010291818291818291818
29181821101018101018101018101031212152312952393194736BF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7CEBDC6846B5A73524A5A42396B524A634A42634A42634A42
735A525A42396342315231295231293929216B524A5A42395A42396B524A6B524A73524A
523931734A427B6352846352846352AD7B6BB57B63C6947BDEAD94C6947BD6A58CDEAD94
DEB5A5DEAD94DEB5A5DEB59CDEB59CDEAD94E7BDA5DEAD94D6A58CCE9473B5846BBD846B
BD846BCE9473CE8C6BD68C7BD69C84CE8C6BD69C84CE9473D68C73D68C7BD69C84D69C84
D69C73CE947BCE947BC68C73C68C73C68C73BD846BB5846BAD846B9C6B528C5A4A845242
734231634231523129422921422921211010312118291818291818291818291818291818
211010181010181010181010291818523931422921422921EFE7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF8C73637B635A634A4263423173524A634231634A42
6B524A634A42523129634231523129523129523931523931735A5263524A6B524A634A42
6B524A735A527B6352846B5A8C7363846B5AA5735A947B73B58C73B5846BAD846BB58C73
B58C73B5846BB58C73C6947BD6A584CE8C84D6A58CC6947BAD846BA5735AA5735A9C6B52
A5735AA5735ABD8463BD846BC68C63BD846BCE8C6BC68C73CE947BCE8C6BCE8C6BC68C73
C68C73C68C73BD846BB58C73BD846BB57B63B57B639C73638C6352845242845242734A39
6342315A3129422921422921392921291818312118291818211010211010211010181010
1810101810101810102918184A31315231294229218C6352FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD8C84846B5A6B524A5A42396B524A634A42634A42
634A426B524A5242395231294A3131523129634231634A42634A426B524A735A52735A52
6B524A7B635A634A42735A52735A527B63528C63529C73639C6B5294736B94736BA5735A
8C73639C7363A5735AA5735AB58C73D6A584B58C73AD846B9C73639C6B529C6B528C6352
94634A8C6352A57352B5735AB5735ABD8463BD8463BD8463CE8C6BBD8463BD846BBD846B
AD735AB57B63B5735AB5846BB57B63AD735A9C73639C6B528C5A4A8452427342315A3129
5A3129523129422921422921312118312118291818291818211010211010181010181010
181010181010181010523129392921422921523129EFD6CEF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6CEDE947B736B524A634A42634A426B524A63524A
5242397B63525A42395231295231294A3131523931634231735A526B524A7B635A5A5252
634A427B635A846B5A7B635A735A528C6352A5735A7B6352846B5A8463528C63528C6352
8C63528C5A4A9C6B528C5A4AA5735AA5735AAD846BA5735AA5735A846B5A846352845242
8452428C5A4284524294634A9C6B52A57352AD735AAD735AB57B63B57B63AD735AA5735A
A5735AA5735A9C6B52A5735A9C6B529C6B529C6B52845242845242734A396342315A3129
523129422921422118392921291818291818211010291818211010181010181010181010
1810101810102918184229214A3131392921633931F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD9CA573524A634A42634A426B524A5A4239
63524A63524A634A425239313929215239315A42396B524A735A52735A52735A52735A52
7B635A634A427B635A8C7363846B5A8C6352846B5A846B5A7B6352734A4273524A73524A
734A397B6352734A428452428452428463528C6352846B5A73524A7B635273524A73524A
845242734A428452398452398452428C5A429C6B529C6B529C6B529C6B5294634A846352
9C6B528C5A428C5A4294634A8C63528C5A4A8452427B6352734A395A3129523129523129
523931392921312118312121312118291818291818181010211010211010181010181010
181010211010422921523129312121633931AD8C84F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DED6E78C736B73524A634A42634A426B524A
5A423963524A735A52634A425239315239316B524A634A427B635A7B635A6B524A846B5A
735A52634A4273524A7B6352846352846B5A7B63527B6352845242734A395A423973524A
5A4239634A4273524A63423173524A734A397B6352734A39634A42735A52634A42523129
6342315A42395A4239634231634231634231734A39734231734231734A39734A39734A39
734A396342316342316342316342316342316342316342316339295A3121422921422921
392921312121291818291818312118312121291818291818181010181010181010181010
291818422921422921312121523931734A39FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE794848473524A634A42634A426B524A
634A42634A42634A426B524A634A425A42396B524A7B635A735A52846B5A7B635A7B635A
6B524A634A426B524A734A42734A42846352845242734A39734A395A4239634A425A4239
523931523931634A425A423952312973524A634A42634A42634A425242395A42395A4239
5231295239315239315231295231295A31295A3129634231634231634231634231634231
6342316339295A31296342315A31295239315231295A3129523129523931392921422921
312118392921291818291818291818291818291818181010181010181010181010211010
4229313929214229215A3129634A42D6C6DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6ADAD947B736B524A6B524A634231
6B524A52423963524A634A427B635A6B524A5A42396B524A8C736363524A7B635A7B635A
7B635A7B635A735A527B635273524A734A396B524A734A3973524A523931634A42634A42
524239524239634A426B524A634A42523931634A42634A426342315239314A3131523931
4A31314229214229215231295231294229214229215A3129422921523129523931523129
523129523129523129422921523129422921523129422921523129422921422921392921
312118392921291818211010291818181010211010181010181010181010181010392921
3929215231293121215A3129AD847BF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6CEB5A5A56B524A634A426B524A
634A4263524A6B524A634A42634A427B635A7B635A8C736B5A4239735A52735A526B524A
5A42395239316B524A73524A8463526342316B524A734A42634A42634A42634A425A4239
5A4239634A4273524A5242394A31314A3131524239523129523129523129523129422921
422921392921392921422921422921422921523129392921523129422921422921392921
422921523129422921422921523129422921422921312118422921392921312118211010
312118312118291818181010291818211010181010291818181010181010291818392921
523931312121523129A58484F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFCEBDC694736B6B524A634A42
6B524A634A425239315A423963524A523931735A527B635A7B635A7B635A5242395A4239
7B635A8C73637B6352634A42734A426342315A42395A4239523931523931634A42634A42
5231294229314229315242394A3131422931523129422931523129422931392921392921
312121392921312121392921392921392921422921312118422921422921523129422931
312118392921392921312118422921312121422921312118312121422921312121392921
291818291818291818211010181010181010181010181010291818392921392921392921
4229214229218C6352EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECED6CEBDCE734A42634A42
6B524A6B524A6B524A5A4239634A4263524A524239634A42735A527B635A7B635A735A52
63524A63524A5A42396B524A734A39523931523931634A425A42394A31315A42395A4239
423139422931524239634A424A3131422931523129392921422931392921392921392921
392921312121312118312121392921312121392921312121392921392921312118523129
291818312118312118312118422921422921312118312118291818392921312118312118
312121291818291818291818181010181010291818312121392921312121523931422921
523129845242F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECED6846B5A634A42
5A42396B524A6B524A63524A634A4263524A634A427B635A63524A634A42634A427B635A
7B635A8C736B634A425239316342315231295231295A42395A4239523129634A42523931
5A42394231395242394A31314229213929214229313121213121214A3131392931312121
312121312121291818291818291818392921392921312118291818392921392921312118
392921312121291818392921291818392921312118291818312121291818211010291818
1810101810102918181810101810102110102918183121213121215A4239423139523129
734A42EFE7E7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7947B73846B5A
634A425A42396B524A5A4239634A425242396B524A52423963524A7B635A6B524A634A42
5A42396B524A523931634A425239315231294229214229215A42395231294A3131523129
4A3131312121422921312121422931523129312121392921291818312121312121422921
312121291818291818291818312121291818291818392921312121291818291818312121
312121312121392921211010312121291818291818291818181010291818181010181010
1810101810101810102110103121213121213121183929212918183929214221189C6B52
EFE7E7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7A5847B
846B5A634A426B524A634A426B524A63524A634A42634A42634A42524239634A426B524A
634A42524239523129634A425239315231293929214229214A31314A3131422921422931
4A313152394A312121423139422921312121392921312121312121312121392921392921
291818291818291818312121291818291818291818392921392921291818291818291818
312121312121291818422931312121312121291818211010181010211010181010181010
181010291818312121392931312121291818422931312121392921523129845242AD9C8C
EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEB5BD
947B737B63525A42396B524A634A4263524A63524A7B635A63524A6B524A735A52735A52
634A4A5242395231296B524A5239314229213929213929214229214A3131392921422921
4229215242392918184A3131291818392921312121291818312121291818291818312121
312121291818291818291818312121312121291818312121523129312121181010291818
312121312121392921291818312121291818181010181010181010181010211010291818
312121422931312121312121312121392921523129422921634231734A39A5735AE7DEE7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
C6ADAD8C736B6B524A634A426B524A5A423963524A5A423963524A5A525263524A634A42
5A42395242393929216B524A5231294A3131312121392921312121422921422921312121
312118312118291818312121312121291818312121291818312121291818312121291818
312121291818291818291818291818312121291818312121423139423139423139291818
291818312121312121312121392931312121392921392931392921392921392921312121
4229313121182918183121214A31314229214229216342316342319C6B5294736BF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7CEBDCE94736B735A5263524A6B524A5A423963524A735A52735A52735A527B635A
735A5263524A524239634A425A4239422921422931312121312121291818422921312121
312121312118392921291818392921291818312121291818291818291818291818291818
2918183929212918181810102918182918183929213121213121215242395A5263634A42
5A5252312121422931312121291818312121312121312121392921422931392921312121
3121215242395A4239392921523931634231523129734A398C5A4A8C7363F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F78C737B947B73735A526B524A63524A5A4239634A4263524A735A52735A52
735A52634A4A524239735A525A4239523129523129422921291818312121392921392921
312121291818312118291818392921312121312121211010312121312121291818312121
29181831212129181829181818101029181829181852394A4231393929395A52527B635A
4229314229314231394231395242394229313929213929213121213929215231295A3129
5A42394A31315231295239315231296342316342318452429C6B52F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFF8C737B94736B7B635A735A5263524A5A4239634A4263524A635A63
7B635A63524A735A52634A42634231524239523931422921392921291818312121392921
291818312118312118392921312121392921291818312121291818312121312121291818
2918182918183121212918182918182918182918181810105A525252394A52394A423139
7B635A6B636B7B635A5A4A5A634A4A634A4A735A52634A4A5A4239523129392921392921
5239315239315239315A42396B524A734A39845242846352F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F79C8C9C846B5A6B524A63524A6B524A5A4239634A426B524A
735A526B636B7B6B7B7B635A5A42395A4239634231523931523129312121312121392921
422921312118312121312118291818392921291818291818291818291818312121291818
29181829181831212131212118101029181839292131212129181839293152394A634A42
5A52525242393929313121213929214A31315239315A42395A42395A42395A42396B524A
634A42634A42634A42634231634231734A429C6B52947B73F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78C6352735A527B635A634A426B524A735A52
7B635A7B635A7B635A8C736B7B635A5239315239315239315239314A3131634A42392921
5242394A3131422921422931392921291818312121291818312121312121291818312121
291818392921392931312121312121312121392921423139312121422931524239392939
634A42634A4A3121213929213929214229313929213929213121214A3131422921524239
5239315231296342318452429C6B52945A52DECED6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5A5AD8C73636B524A6B524A6B524A63524A
735A527B635A8C736B9484848C737B6B524A5A3129523931523931523129523129523931
5A42395A42395A4239422921422931392931523129312121312121312121392921422931
31212131212152394A3929214231394229313929214229315A5252423139423139423139
3929313929215242395242394A31315A4239524239523931523129634A42634231523129
634231734A39734A398C5A4A846352DECED6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6DE8C73636B524A5A4239634A42
6B524A7B635A8C736B8C736B8C7B738C736B7B635A5242395239315231294A3131523129
523129634A42634A425A4239524239735A523121214229212918184A3131423139422931
4231394A394A5242395242394231397B737B6B524A635A63392931634A427B635A5A5252
634A4A634A42634A42634A42634A425A42395A4239634A42634A426B524A7B63526B524A
634A42845242A5735A846352F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7948494846B5A735A52
6B524A7B635A8C7B738C7B739C8C8C9484848C7B738C736B73524A7B635A846B5A634A42
5A42394A2118634A42634A42735A525A4A5A634A4263524A5A42393929393121216B636B
634A4A5A52527B635A7B737B5A4A5A5A4A5A5A52527B635A6B636B635A63735A5263524A
6B524A7B635273524A735A5273524A73524A73524A6B524A5A4239634231734A397B6352
94634A734A42A58484FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6CE947B73
7B635A7B635A6B524A735A52735A528C737B7B737B8C7B738C736B8C7B738C736B8C736B
8C7B737B635A634A4A6B524A5A52527B635A7B6B7B7B635A8C7B735A5252634A4A422931
5A4A5A52394A634A4A5A52527B6B7B735A526B524A6B524A634A426B524A735A527B6352
73524A73524A734A42634A42734A39734A396B524A8452428463528C5A4AA5735A7B6352
734A39CEB5BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
B5A5AD6B636B735A527B635A735A528C736B9484848C7B738C736B8C736B846B5A8C736B
8C7B738C736B8C736B8C736B635A637B635A735A528C736B6B636B7B635A7B737B5A4A5A
52394A52394A4231395239315A42397B635A6B524A6B524A6B524A5A42395A4239634231
6342316342315A4239734A428452427B63528463528C5A4A8C5A4A846352734A39734A42
D6C6D6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7CEBDC68C737B7B63527B635A7B635A6B636B8C737B9C8C8C8C7B739484848C7B73
8C7B73846B5A8C7B73947B739484848C7B73947B738C7B738C736B948484735A528C7B73
7B635A6B524A634A4A634A4A5A4239524239634A427B635A735A52634A426B524A6B524A
84524273524A8C5A4A7B63528C63528C73639C7363A5735A845242634A42A58484FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7E7DEEF6B636B5242526B524A635A637B737BAD94948C737B
9C8C8C9484849C8C8C947B738C736B8C7B73A5847B947B73947B73947B738C7363A5847B
947B73947B73846B5A846B5A8C736B8C73638C6352846B5A9C6B528C6352846B5A94736B
94736BAD7B6BAD846BAD846B8C736373524A634A42846352CEBDC6F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7AD9CB58C7B8C8C7B8CAD9494A594A5
C6B5C6B59C9CB59C9CB59C9CA5847BA5847B947B737B635A947B73A5847BA58484A5847B
A5847BA5847B947B73947B73A5847B94736B8C736394736B947B73AD7B6BA5847BAD846B
8C7363846B5A8C736373524A73524A8C7363CEB5BDFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEF
EFE7E7D6C6D6C6B5C6BDB5BDC6B5C6AD9494AD9494A58484947B7394736B8C7B737B6B7B
8C7B73947B73947B73A5847B8C736B94736B8C736B94736B8C736394736B8C7363846B5A
846352846B5A846352947B73AD9CB5FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7EFE7E7E7DEEFEFE7E7F7EFEFEFE7E7D6C6D6CEBDC69C8C9CAD94A59C8C9C948484
947B73947B73947B73947B73947B73A5847B947B738C736B8C736B8C7363846352735A52
846B5AAD94A5F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFE7DEE7DED6E7CEBDC6DECED6D6C6DEEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -50 0 ]
[.5 1.0125 50 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Monochrome) show
129.000 12.813 moveto
(image) show
159.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7DACFD7D7D7DADAE0E0DAE0E0E0E0E0E0E0E0DADADAD7CFCFC9C9C9
BBC0BBBBB2B2B2B2B2B2B2B2B2B2ADA9A7A8A9A9A79DA9F7F7F7F7F7F7F7F7F7F7F7F1F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7
F1F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7E8D2D7D7DADADADAE0DAE0E0E0DAE0E0E0DADADACFCFC9C9C0C0C0
C0BBB2B2B2B2B2ADB2B2B2ADB2ADA9A9A9A9A9A7A99DA9F7F7F7F7F7F7F7F1F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7
F7F7F7F7F7F7F7F7F7E8D7D7DAD7D7E0E0DADAE0E0DAE0DAD7DACFCFCFC9C9C9C0C0B7B8
B2B2B2A9A9ADB2B2B2ADB2B2ADA9ADADA9ADA9A9A79DC4F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7E0D2D7D7DADAE0DADAE0DADADADAD7CFD7CFCFC2C2C0C0BAB7B7B7
B7B2B2B2B2A9ADA9A9ADB2ADA9ADA9A9ADA9A9A9A7A4F1F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F7F1F7F7F7F7F7F1F7F7F1F7F7F7
F7F7F7F1F1F7F7F7F7F7F7F7F7F7F1F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7
F7F7F7F7F7F7F7F7F7DACFD7D7D7DADADADAE0D7DADADAC8CFC4C2C0C0B8B8B7B2B7B7B7
B7B7B7BAB2A9A9A9A9A9A9ADA9ADA7B2A9A9A9A9A9B7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7DAD7D7DAD7DAE0DADADADADADADAD7C8CCCCCCC6C6C4BBB8B8AAAA
AAB2B2B7A6ADA9A9A9A9A9B2ADADA9ADA9A9A9A9A9C4F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7
F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7DAD2D7DAD7DADADADADADADACFD7CFDAD7DAD7CFCCCCC6BBB8B6AA
B8C1B8B7AAA9A9BAA9A9A9A7A9A8A9A9B2A9A9A9A9E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7D7D7DADADADADACFD7DADACFCFCFDADADADADACFD7CCC6C6C4C0C0
B8C1C6C1B8AAADA6A6A9A9B2A9A9ADA9ADA7A9A9A9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7CFD7D7D7DAD7D7DACFDADADADADADAE0E0E0DADADACFC9C6C9C4C0
C4C1B8C1C4B8AAB6AAA9BAB2A9B2ADADADA9A9A9B7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7CFD7D7D7D7CFDACFDADADADADAE0E0E0E0DADAE0E0E0CFCDCDCFC6
C6C6C1C1C1B8B8AAAAB2B2B7B7A9B2B2ADB2A9B2CCF7F7F7F7F7F7F7F7F7F7F7F7F1F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7D2D7D7D7CFDACFD7DADADADAE0E0E0DADADAE0E0E0DADAD7D7C9CF
C6C4C4C1BBB8B8B6B2AAADB2BAB2A9ADA9A9A9B2DAF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7DAD7D7D7CFCFDADADADADAD7E0E0E0E0DADAE0E0E0E0DADADAD7CFCC
CCC4C4BBC1B6B6B8B6AAADAAA9A9B7A9A9B2A9B2E8F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7E2BACFD7CFDADAD7DAD7DADADAE0E0DAE0E0DAE0E0E0E0DAE0DAD7D2CF
CDC9C4C4C4B8B8ADB6B2ADADA9B7A9BAADB2A9B2E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F7F7F7F7F7F7F7F7F1F7F1F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F763C9D7DADADADADADADADADADADAE0DADADADADAE0DAE0D7DADADAD7D7
CDC9C4C1C1B8B6B6B6B6B2ADA9B2A9A9B7B2B2B2F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F76C43CFDAD7DADAE0DADADADADADAE0DADADAD7D7E0DADAD7DADAD7CFD7CD
C6C4C4C4C1BBB9B6ADB6B2B2ADA9A9B2B7BAB2B2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F74B2C62DADADADADAE0DAE0E0E0DADADAE0DADADADAE0E0DAD7CFC9CFCFC9C9
C4C4C0BBC4BBB6B6B6B8ADADA8A9A9A9B2A9C6B2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F1F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7CA4330DADAD7D7DAE0E0DADAE0E0DADADADAE0E0E0DADADAD7D7CCC9C4C4BBC4
C4C4C4C4C0BBB2B6B6B2B2ADA7A7A9A7A9A9A9C4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F13948DACFDADADADADAE0DADADADADADADADADAE0E0E0E0DADAD7CFC4C9C4C4BB
C4C0C4BBBBB6B2B9B6B2B1ADADA9A7A7A7B2B2B7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FF5D3BDACFD7D7DADADADADADADADADADADADADADAE0E0E0DAD7CFCDC6C4C4BBBBBB
BBBBBBB9B9B6B2B2ADADADADADA7ADA9A9ADB2B2DAF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F777439CCFDADADADADADADADADAD7D7D7DAD7DADAE0E0DADADAD7CFCCC1B8B8B8B8B6
B8B6B6B6ADADADADADA9ADADADA7ADA8A8ADB2ADA9DAF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F73B6CE0DADAD7D7DADAE0DADADAD7D7D7DADADAE0E0DADAE0DACCB0CCB0A2A2A2A2A2
A2AAB6B2ADADADA9A8A4A7ADADA9ADADA7ADA8A9A9A9F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7B93BE0DAD7DADAD7DADADADADADAD7CFD7D7DADADADADAE0E0CCCCCCB0B0A2A2A2B0A2
A2A2A2A2AAADA9A9A7A7A9ADADADADADA7ADA9A9A9B7C6F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
C83BDAD7DADADADAD7E0DADADAD7D2D2D2D7D2DADADADACCCCD3CCCCB0A2A09C8F8FA29C
9797A2A29DA2A4A7A7A7A4ADADADADB2ADADA8A9B2ADB2F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
5D6CCFD7D7DAD7D2DADADADADAD7D2C4D2CDD2DAE0DACCCCCCCCC1AA8F8F8F8F8F8F8F8F
8F8F8F97A2939BAAA8A4A4A7A8ADADB2ADADADA9A9ADB2C6F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F789
39E0CFD7D7D7D7D7D7DADADAD7D7C9C4C4C4D7DADACCCDCDB0AAA09DAAB881CCB77DB893
877F878F97939D9DA9A7A0A7A7ADADB1ADB2ADA9ADADB2B7E8F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B64B
30DAD7D7DAD7D7CDDAE0DAE0D2D2C9B9B9C4DADACDB0B6A0876CADB8C8C8B9B9C6A4C4B9
74A66C7F8F8F939D9DA4A4A7A8ADB2B9B2ADA8ADADADB2A9B7E5E5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E59E39
9DD7D7DADAD7C9C4E0DADAD7CDCDB9A8A8D7CCA2A2904393B88FAA97C1EBE8DA9CAA9789
88A49A706C7F87979BA4A0A0A8ADB2BBB9B9ADADB2ADADB2B2C8E8F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A4892C
DAD7DAD7D7D2C4C4DADADADACDBBB1A1B1C18F5664C6E0E8E8F1F1E8EBF1E8E0CFDADADA
C86C7D72804874818FA8A0A0A8ADBBC0BBB9ADB2A9B2B2B2B2C2F7CDE2F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F1F7F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7744355
CFD7DAD7D7D2C4D7DADADADACDB1A1909A6C4963C4E0E8E8E8EBF1E8EBF1E8E8CFEBE8DA
DAC0AD6C612E4274819AA7A0A8ADBBC4BBBBB9ADADB2ADB2B2BADCF1E8F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F1F1F7F7F7F7F7F7F7F7F7E8F7F1F1E5F1F1F780399D
D7DADAD7D7CDC4D7DADAE0D7BBB195955643407DBBE8DAEBD7E8F1DAE8F1E8DAB8EBE8DA
DAC8C8DA64801B1B6C7F9DA4A4ADB9C4C4BBB9B2A9B2ADB2ADB7BBC4CDF1F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7DC3B2CDA
CFD7D7D7D7C9D7C4DADADAD7B1A88F9D745E43A0AAA1C4D7C1E0E8B6D7E8D7B6B8C4DADA
B6CFDACFA9BA9C9C435E81A4A4ADB9C4C9C0BBADB2ADA8ADADB2C295BBC4DCF7F7F7F7F7
F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C43B154AC8
D7D7D7D7C9C4D2C4DADADACFAA95A1B6B8B6978FA0A0A1B8AAB1B1B1C1CC8F9797AAB1B6
8FB1CFBBB7BAA99C753D5E97A4ADBBC4C9C4BBADADA9A4A9ADB7BADCCDC1CAE5F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F16C202C1B9ADA
D7D7D7CDCDC9CDB6D7DAD7CCB190BBC1CFDAD7D7CCC6C1C1B8C1B8B8B0B0AAA897978F89
8F8FB7959AC99BA9802B36649DA7B9C4C9C4B9B2ADA7A9ADB2B2B7F7F1D3CDDCF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2CD2013391EDACC
D7D7D7C9C9CCC9C9D7DAD7CDB690B6C6E0DAE0E0DAE0DAE0E0E0E0CCCCCCC6C6C1B8A297
A2938F8181A0817D5E17365064A4B6C4C4C4BBADADA9A4A8ADADB7849EDCE2D3E8F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D389132C202EDACF
D7CCD2CFCCCFCFCFD7CCCCC9B6A895C6DAE0E0DADAE0DADAE0E0DADAD7D2C4C4C4C9B9BB
B6AAA89DA2938F817456566C5E9DADC4C4C4B9B2ADA7A4A8ADADB2A448E8F1E8E8F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2396CA67D5DDAD7
D7D7D2CFD7D7D7CFCFD7CFCFB6B1A1BBCFDADADADAE0DADAE0DAE0DAD7CDC4C4BBC4C4BB
B6B1ADA8A4A8A8AAA49D9A959095A8C0C4C4BBADA9ADA7ADA8B2B2B0745EF7E8F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DC5ED7CFC4C4CFCF
D7D7D2CFD7D7CCDAD7D7D7CFBBB1A8A1C9CFDAE0E0E0DADADAE0E0DACCC4C4B9C4C4BBBB
B6ADA7A9A4A7A7A4A4A7A4A49BA4A0C0BBC4B9ADADA7A7A7ADB2B2AD5DC1C4F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1A4CFDAD7DACFC8CF
CFCCD7DADADAD7DAD7D7D7CFC4BBB1A8B9CFD7E0E0E0E0DADADAE0E0D2C4C4B9BBC4B9B9
B6ADA7A49B959B999B9B9DA4A0A7A8B9C4BBB2A8A4A4A0A7ADA9A9B615BBF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DCD7D7DAD7E0CFCFD7
CFD7D7D7DADADADAE0DADACCC9C4B6B1A8C4CFDAE0DAE0DADAD7E0DAD7CFC4B1B1B6B9AD
A7A49D9B999B979999999799999DB2A0BBB9B6A8A4A4A4A7A7B2A9A43180E5F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D3D7DAD7D7CDCFD7D7
CCD7D7DADAE0E0E0E0E0DAD7CCC4BBB1A1B9C4DAE0E0E0DADADAD7DACFC6B6B8B8B2A8A8
A0A0999B9799999B9B99999599A7A8B6B2ADADA8A4A4A4A7A9ADA9A4134380F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8D2D7DAC9CDB9D7C8D7
D2D7DADAE0E0E0E0E0E0E0D7CCC9C4B6B1B1C4DADAE0E0DACCCDCFD7D7CDBBB6B6B29AA7
A9A49797999B9BA0A099999995A8B6B9B6B1ADA9A4A4A4A8A9A9B29C1524BBF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D7DAD7E0CFB1B2D7CFD7
D7D7DADAE0E0E0E0E0E0E0DACFC9C4B9B1A8B1CFE0E0DAD7DAD7D7D7DAD7C9C4BBB2B2A4
8A9795979B999BA09DA099A0ADBBB9B9ADADADADA4A4A4A9A8A9A9872A6DF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D7D7DAE0BBBBB2CCCFD7
CCD7DAE0E0E0E0E8E0E0E0DAD7D2CDC4B9B1B1C9DADAE0DADAE0DAE0DAD7C6C6BBB7ADAD
AD9B978A97999BA0A49DA8B2B6C0BBBBADB6ADADADA7A4A9A7A9A983203143E5F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8D2D7DACFA8B9C0CFCCD7
D7D7DAE0E0E0E0E8E8E0E0E0D7CFCCCDC4B6B1BBCCDAE0DADADAE0E8E0DACFC4BBB8B2AD
ADADA9A88A9395999DADADBBBBBBBBBBB6B1ADA8ADA4A4A4A7A9B78B4830136FD3F1F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CFD7DACFC995A6CFCFCCD7
D7D7DAE0E0E8E8E0E0E0E0DADACFD7CCBBBBB9C6CFDADAD2D7DAE0E0DAD7C9B6ADADADA9
A9A4A4AAA08A979DA4B2B8BBC4C4BBC0B7B2B2ADA9ADA9A4A9A9B7A08F6C50394395F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EBCDD7CDB9ADA8B7CFCCD7D7
D7DAD7E0E0E0E0E8E0E0E0DAD7D7D7CCC9C4C4BBDADADACFC9D7DADACFCCC4B2ADA6A6A4
A9A4A4A4998895A0ADB8BBBBC4BBBBBBB2B2B6B2ADADA7ADADADB7A4A0978A4374E2F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DAD2B1A18F93A4BBC2D7D7D7
D7DADAE0E0E0E0E0E0DAE0DADAD7CFCCC9C6CFCDD7DAD7C9C6CFD7D7CCC4B9B6A8A4A49B
9B9BA0998A8F97AAB2BBBBBBC4C4BBBBB2B6ADADADA8A7A4A8B7B7A4A4A4A49CF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CCD2AA9C9395ADB8CFD7DAD7
DADADADAE0E8E0E0E0E0DADAD7CCCFCDC6C9CFDADAE0DAD7DADAD7CCC9C4BBB2A49D939B
9993999595959DADB2BBC4C4BBC1BBBBB9B6ADADA8A9A9A4A9B2BA9999A0A0ADF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DACCCDAAA19397A9C4CFD7DAD7
E0E0DAE0E0E0E0E0E0DADACCD7CCCFC6CDCCCFDADAE0E0E0DADADACFCDC4BBADA49B9B93
9393939B9BA4B2B2BBBBC0C0C4C0BBB6B2B2ADADAAAAAAA4A4A9BA9595A4A4B7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CCD2CCB1AA9797B2C6CFDAD7DA
E0DAE0E0E0DAE0DADAD7CFD7CFD7CCC9C4C4C6DADADAE0DADADADAD7CFBBB6ADA49D9B99
9B9B9BA7A4ADB2B8B8C4C4BBC4BBBBBBB6ADADA9A6A4A9A4A4A6BA9D9DA0A9A4F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E0C4D2DAB1A89593B2C9D7DADADA
E0E0E0DADADADAD7CFCFD7D7CCCFC9C9C4C6C9D7DADAD7DADADADAD7CCC4B1ADA49D9B9B
9B9D9DA4A7B2B2BBBBC4C4C0BBBBB6B2B2ADA8ADA8A4A4A6A7A6BAA9A8A7A99DC8F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D7B9D7C0B8A88A93B7C9CFCFD7DA
E0DAE0E0DAD7D7D7CFCFCFC4CFCFC6C4C4CFCFCFDAD7D7D7DADADADAD7C4B6ADA4A4989B
9D9DA4A9A8ADB8BBC0BBC0BBC0B9B6B8B6ADA9A4A7A6A4A4A4B7B899A7A9B79AB2F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1B9B197AA6C6C818AC0CFD7DADADA
DAE0DADAD7D7D2D7CFC9C6C6C0C6C6C9CFCFCFCFD7DADAD7DADADAD7CFC6B6ADA49B9B9B
9B9DA4A4A9B2B8C0BBB6BBC0C0BBBBB6B2B2B2ADA9A6A4A4A6A9BA7487A7B79A9AE8F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D7B19D975B795D6473C0D7DADAD7DA
DADADAD7DADACFCFC9CFC9C6BBC0C0C0C6CFCFCFCFDADAD7D7DADAD2CFC4B6A0A49B939B
999BA6A4A9B2B2B8B7B2B6B6B8B6B6B6B2A6B2A9A6A4A4A9A9A9AD7D819BA9A4A0CCF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CDA19B42A45D554A75C0D7DADADADA
D7DAD7DADADADADADADADACFC6C4B8B8B2B8C9CFCFD7DAD7DADAD7D7C6BBAD9D9B99999B
93A0A4A9B2ADADB2B2BBB8B6ADB2B2ADA9B2A9A6A9A7A4A4A6ADA9818F9599AD9DADF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1B9AA757D3B5B625E63C0D7DACFDAD7
CFD7CFC2CFDADADADADAC4DADAC2C0C0B2ADB2B7CFCFDADADADAD7D7C4C0ADA49B9B9393
9B9DA6A7ADA9ADADB2B2B2B2A6A9ADADB2ADA9A9A7A4A7A4A6ADA9816C645E87A09AF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8A1B8797D18482C4A5EC0D7D7CFCFDA
DAD7D7CFB79DB7A7989B989A9AA69BA6ADAAADB2C0CFDADADADADAD7C6BBAD9B99999593
989B9B9B9DA69DA9A9A9B7B7A9B2B2B2B2B2A9A9A9A7A49DA6B7A9866C6C6474909DF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D7A1B88A431313203B4AC9DAD7D7D7D7
DACFC9B79386534A6C8A8A757370867D989D97B2C0C9D7DADADADAD7C6BBA8A09B959398
8A8B9DA6A49B9DA4A49DA9B2B2B7B2B8B2A9A9A6A4A99D9DA9A9A983706C6C7490A8F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C99CB8A61817202C315AC9DACFD7D2D2
D7D7D7CFC9B79D4883BB5D83430C534281746C646CB9C9DADADADAD7C9BBADA0998B9888
8A9DA9B2B2B2B2B2ADA6A6A49DA7B2B7B2B2A9A99DA49DA4A9A9A986746C6C7489A4F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFBB87B6C12C1B242C3B4FCFD7DACFCFCF
D7DAD7CFCFA9B29884392E807A0C4F53A49E5B6CA0C4CFDADAE0E0DACFC4ADA0958A7D7D
88A7B7B7B7B7B2A9A9B7B7A9A6A7A9B2B7B2A9A7A79DA79D9DA99D73646C6C8195A8F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF42CD87A8B64A15202C305ECFD7D7CFCFCF
D7DAD7D7DAC9B2B2C6B75E3B2C1337375D747D81ADBBCFD7E0E0E8DACFC4AD9D8A888874
3D50939B8F8186706C81989A9DA7A79DA9A9A99D989D9DA4A6A6986C617074909D9DFFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2302ECDBBCDBB551B2C202C5EC9D7CFCFCFD2
DADADADAD7D7CFBBB2B2BA836C4F6C5574887DB9B9B9CFD7E0E8E8DAC9C4AD9D95888A7D
735BB0C4B5533D425573635B81868B8B989898989B9B9DA4A69D8B555D5D6C9AA090F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F1F7F7F7F7F7F7F7F7F7F7F7F73B2420B1CDBBB15D3629132062CFCFCFD7D7BB
CFD7CFDADAD7CFCFBBA9A9B7A98B887D887DA7A8B6C0C9D7E0E8E0CFC9C0ADA095888A88
747084D35D840429553B63613B6C736C7381959B9DA79D9DA4988355485E55A4AD87FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F76330201842A17D64392A201B2C6CD2D2D7CFDAC0
93C4CFDADAE0E0DACFC9BBBBB2ADA7A7A8A8ADB9C0C9D7DAE0E0E0D7C9C4B2A49388958A
887D93814AA400474A3B8474363B4A5A818899A7A9A9A99D9D98624B483153A99587F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF30372C181B1B552C24311B1B2C75CFCCCFCFDACF
AAA9B2CFDAE0E0DADACFC6BBADADB2ADADA8B9B9C4C9C9DAE0E0E0CFC6BBB7A999959898
9598A98B934B1513372C4F39395E6C988A98A7999BA99D9DA7984A483B2C43AA8981F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7E82E3037202418392A1B151520206CC9D2D7D7CFDA
CF9BB2A6C9DAE0E0DADACFC9B2B2B7ADA09A9AB2C0C0CFDAE0E0DACFC4BBB2A99D959599
9B9988A9A9757355435331628379838B939998A99D9D9D9D9D834831433037A98187FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79B30313B30302C31310C132C13305EC9D2D2D7CFD7
DAC6B7878A98988B8B6C735E5D64645B7074749BB7C0CFDADAD7D7C9C4BBB7A99B999595
989BA799A9A7A9989883798379989B9BA0A49DA4A7A9A9A79D5E3B392C1B438A7487F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A42C2020201B202C201B13152C2C62C9CFD7CFD7D7
D7DACFC6A672778D80806C627563615B61818AA4BBCCCFDADACFCFC9C4C4B7B29B938888
88939BB2ADA79B9998988A999BA4A09DA69DA49D9D9D9D9D8B4A2A29361B648A6C81F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B637201B1B1B20200420131B31435AB7C9D2D7D7D7
DADADAD7CFA9A6A68D9BA69A9387988A8A9BADC6CFD7DADADAD2CCC4C9C0B7B29B8A635B
637D989BA7ADA7ADADA7A7A79D9DA7A69DA9A69D9DA6A79D833B1B2A1B1393886C87F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F1F7F7F7F7F7F7F7F7D33913201B202C200C2020151B4362A9C9CFCFD7D7
DADADAE0DACFCFCFDADADAC4CCC4CCC8CCDACFCFCFDADADACFCFD2C6C9C6C0B8A99B6C55
5050758A99A9A9B2ADA9A9A7A9A4A9A99DA99DA79DA99DA7622C1B24153199896C8180F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F1F7F7F7F7F7F7F7F7F7F7E54820201B201B1B130420202C435A9DC0C9D2D7D7
DAE0E0E0E0E0E0E0E0E8E0E0E0E0E0E0E0DAD7D7CFDAE0D7CFCFCFC9C9C9C0C1C0C6A98A
635D48373B5581A7A9A9A7A7A79D9D9B9B938B9BA6A9A48B481B20153630748A64814BD3
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7393B2C201B20202004201B2C485E9DB2C4D2D7D7
DADAE0DAE0E8E8E0E8E8E0E8E8E8E8E0E0E0E0DAE0DADACFCCCCCFC9C4C9C4C0C6C0BABA
A98A635D43373B435D8B98939B988B816C6C8AA9A4A6A48330202020241B507488755489
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7434A3120201B2020130C203B435E98A9C9D2D7D7
DADAE0E0E0E0E8E8E8E0E8E8E0E0E8E8E0E8E0DAD7DAD7CFD7D7C9C9C4C9C9C6C9C6C6C0
BAB2A683735D483B3B555D6C635D6C756C86A6A9A49D9B752C1320242A1B244B403754A4
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F748483B2C202C20201B042C2C435A8BA7BBD2D7DA
D7E0DAE0DAE0E0E0E8E8E8E8E8E8E8E0E0E0E0DADADACFCFCFCFC9CDC9C6C9C6C9C9C0BB
C0B7B7A99D8A736348485353555563798A9DA69D9D9B935D20201B201B13142B37395AFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DC4F484F311B2C2020202A2A39435E839CB7C4D7D7
D7DADADAE0E0E0E8E8E0E8E8E8E8E8E8E0E8E0DAE0D7D7D7D7CDC9C9C9C4C4C9C9C9C6C1
C0B8B7B7A9A99D9B8B81756C7579939D9DA49B9D9D9B8B3B2C20202C1B1B132C2C2C5489
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B9484B483B312C20202020202C3B4A7398B2C9D2D7
D7DAE0DAE0E0E8E0E8E8E8E8E8E8E8E8E0E0E0DAD7D7CFCFCFC9C9C4C4C9C6CFC4C9C6BB
BBBBB7B7B2A9A9A6A69B9B9B979D9DA49DA49BA09D9383302C201B1B2A1B1513202C2A4B
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78948483B31312A202020312C203B3B5E83A9C4CFD7
D7DADAE0E0E0E8E0E0E0E8E8E8E8E8E8E0E0E0E0D7CFDAD7D2D2C4C9C9C4C9C4C4C0C4C0
BBC0B6B7B2B7A9B7B2B2A9A9A9A4A4A7A6A4A4A49B8B642C2C1B201B2C1B1B2020133B4B
B0F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7633B4B4F4331392C20202020202C3B48628BC0C9D2
DADADADAE0E0E0E0E0E8E8E8E8E8E8E8E0E0E0D7CFD7D7CFC9C9C9C4C4C9C9C4C4C1BBBB
C0C0B8BBB7B2B7B2B2A9A9A6A4A6A9A9A69DA49D8B754831201B15310C15151B200C2A3B
95F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F74F3B434B4331392C201320202C203B484A73A7C9CF
D7DADADAE0E0E8E8E8E8E0E8E8E8E0E8E0E0E0DAD7D7D7C9C9C4C9C4C4C4C4C9C4BBC4C0
BBBBB2B7B2B2B7ADA9A9ADA9A9A99D9D9D9D9D9B835A392013152A0C150C131304132C3B
84FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7F743434B4B4843392C202C1320202C2C4F5E5598B2D2
D7DADADAE0E0E0E8E8E8E8E8E8E8E0E8E0E0E0E0DADACCCFCFC6C4C4C4C4C4C4BBC0BBBB
B2B9B7B7B2B2B2B2A9A9A9A7A9A9A7A4A9A49B8B75482C201B2C1B1515131313131B203B
6CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F1F75A484B434B433131202C13202031314B5A5E8AB2C9
D2D7DAE0DAE0E0E8E8E8E8E8E8E8E0E8E0E0E0DADAD7CFCFC9C4C4C4C4C4C4B9C0C1BBBB
BBB2B2B2B2B2B2ADB2ADA9ADA9A49D9DA49B9886623B2C1B312C0C0C150C040C151B2031
77F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7483B4843434B39392C2C2C202C2C203B4A638AA7C0
C9D7DADADADAE0E8E8E8E0E8E8E8E0E8E0E0DADACFCCD7D2C6C4C4BBBBC4C4BBC1BBC0BB
B2B6B2B2ADA9B2ADA9A7ADA4A9A4A4A49B998B734A433B311B1B15130C0C040C131B133B
E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F74B4B484B4B4B4B43302C2C132C2C3148556C8395BB
C9D7D7E0DAE0DAE0E0E8E8E8E8E0E8E8E0E0E0DADAD7D7C4C9C4C0BBBBBBC1C4BBB6B6B2
B8B8B2B2B2A9ADA9A9A9A9A69B9DA49D9393736C48392C131313150C0C04130C151B2C54
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F14A43434B4A4B5431392C202C2C313B434F628193AD
C4CFDADADADAE0E0E8E0E0E8E8E8E8E0E0E0E0DAD7CFC9C9C9C4C0BBBBC0BBC4BBBBB7B6
ADB2B2ADB2ADA6A9A4A4A9A4A7A49D9D8B83735D3B2C20152015150C0C150C1313132C4F
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7E843433B434B4B4B43432020312C313B39486C8193A9
C0CFD7D7DADAE0E8E0E8E8E0E8E8E8E0E0DAE0DACFCCD2C4C4C4C4C4C4C0BBB9BBBBB6B7
B7B2B2ADA6A6A9A9A9A6A9A4A49D9D98867575483B2C2C1B1B2C1B201B1513151B202C62
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7E84F4B30434F4B544B4330202C312C314A5A75758199
B2C9CFD7D7DADAE0E8E0E8E0E0E0E0E0DADADADACFC9C9CDC4BBBBBBBBBBB8BBBBBBB8B8
B6B7B2A6ADAAA9A99DA4A6A4A49B988B83645A48302C24202A2C150C1B1B150C0C1B39E8
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F1F75A3939484B43544B3B4320313139313B5A6C55758A
ADC9CFCFDADADAE0E0E0E0E0E0E0E0DADAD7CFD7C9C9CFC4C4C4B9BBBBBBB9BBBBBBBBB6
B2B2B2B2ADA9A9A6A49DA4A49D9D8B83755A4A392C2A1B1B132015150C0C00040C204AF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F1F7F76F433948435A4B4B43432C1B3B394331484F5A6C81
A4C9C9D7D7DADADAE0DAE0E0DADAE0D7DADADACFCFD2C9C4BBBBB8B9B8BBB6B6B8BBB6B6
B6B8A6A8A4A9A6A7A7A4A4A49B93866C5D48433B2020201B1B15150C1500040C132C6CF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7774F393B394B434B39394B2C1B3B31433B5A4A5583
93BBCFCFD7D7D7DADADAD7DAD7DAD7CFDAD7D7CCC9C9C4C4B6B9B6B9B8BBBBBBBBB9B1B6
B2B2ADADADA7A9A9A49D9B9B8B83755D4A3B3B2C201B1B1B201B15150C040C132C48FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7775D393B43394F5D3143391B2C20394B314348486C
81A9BBC9D7D7D7CFDAD7D7DADADAD7D2CFCFCCC9CDC9B9B9B6BBB9B9B9B9B2B6B2B1B2AD
ADADA8A9ADA9A6A7A79B93938A755D5543302C2013131B1B1B1B1B151B0C041B3948F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7F79E6F43434B434B4F433B39392031314343394F4B5E
759BA7BBCFC9CFCFD7D7D7D7D7D7CFCFCFCDD7C9C4C4B6BBB9B6ADB6B2ADB2B1B6B1ADA8
ADADAAADA9A4A7A79B9D9886837555483B2C202013131513201B150C04000C312C63F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C4724F3B4B43434F5D314B31312C31394B434B435A
5D8BADBBC0C9C9C9D7D7D7CFD7CCCFC9CFC9C9C6C6BBBBB6B1B6B1A8ADB1A8B9ADADADA7
A0A4A6A9A9A4A49D98988B836C5D4848302C20130C0C0C131304040000001331399EF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F76C4F4B434B39435443432A2A312A39394B393B4A
486C8398A9BBBBC0C9CFC9CFCFCFCFC9C9C6C9C9C0A8ADA8ADADADA8A8ADADA8ADA8ADA0
A4A0A4A49B9898938B8175756C483B30202C1B1313130C0C0C040000000C2C3137F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7FF805A4B484F434554433B31202C2C2A434B4F362C
4A4A5D758B939BA9BAB7C9C9C0C2C0C4C9B9C9C0C0B29DA4A4ADA4A4A4A7A8A8AAA8A4A4
A0A09D9D989B938A8675755D55483B2E201B130C040C0C0C0C04000000152C3172F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C1634F394B43434354393B2C2C1B4B39394B4B4F
314A5A5E5E808198B298A9B2BAB2BAB7B7B2C0B2A999868A8A99959DA495A4999A9DA4A4
A09B9B9393938A86836C5D55433B2C202004130C0C0C0C0C040000000C312020E8F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF6C5D433B4F3B434B432C3B2C2C313154484B43
4B545A636C6375778B86838B8B868B98A79BA9988375756C7575888A8F8A95939B959593
93938A8B8A818173625555483B3020201B0C130C040404000000000C2A2C2062FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78D634B394B4343434B362C2A2C3B43434B5454
4B5D4354545A62736C7272756C7375758BA78B83736C6C626462737D7D88888895888A8A
79817D868179736C5D554330302C202013130C0C040400000000002C1B202CDAF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D3774B43434B48365A392C2C2A313B544B5D47
435D635D5462755A635E6262625D6C5D7575837575635E55555B55646C73797981817975
75756C756C6C6C5555483B302C201B1B0C0C040C0400000000000C202A1B39F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79E4F43434B39484843311B31394B54545454
5D435D6C636263635A4A4F4F485A4A55555E62634F5A4F4F554A5353555B6C6C6C6C645E
6C5B5B64625D555A48302C2C311B1315130C0C00040400000004202C15398DF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DC6F4F43434B3948544331314B435D5D4B63
54434F5A5E635A5A5548394F39434F3B4F485A484354432C3B39393B3B3B484343484848
483B3B3B3B3B3B3B372E20201B150C0C13150C0C000000000C2020153148FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2804F43434B4343434B43394B5D54635D5D
4B434B4A4A5E554848394339313143392C4F4343433639392C31312C2C30303B3B3B3B3B
3B37303B30312C302C311B20131B0C0C0C0C0C0000000004241B203043D0F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B0774B4B3B4B3648435D4B394B6C485D5D
5D5D545A4F484B484F3143433636434B433143433B312A312A20202C2C202030202C312C
2C2C2C202C202C202C20201B131B0C040C0004000000001B1B2C153087F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CAA44B434B43484B43435D5D6F3954544B
39314B4F5E3B4B4A4343433939434F362A2A362C2C2C2C20201B1B2020202C1B2C20201B
202C20202C202013201B130413130C000C04000C00000C1B31152C87F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1C1724B434B4331394831545D5D5D3639
5D6C5A434A3B3939313143432C2424362A242C242C241B1B151B151B1B1B201320202C24
131B1B13201520131520151B0C0C0C04000000000C1B1B1B202062E8F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D3C44A434B4B4B3943483643545D5D54
4848394B48313143392A3939292436432A242C1B241B1B1B1B1513151B151B151B1B132C
0C131313202013130C1B1313150C0C0C00000C151B1531202C55F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D36343394B4B484348435D4843435D
5D6F43313B2C2C39392C43313929362A201B2415152A201515150C0C0C1B1B130C1B1B13
1B150C1B0C1B130C150C040C00000C0000040C151539292C4AE8E8F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7776343394B3943364B36485D4B43
394B3143312C2020392C2A2C2A152015242C151B0C151520150C0C0C150C0C1B150C0C15
15151B04150C0C0C000C0000000000041515131B0C1B1B6CE8E8F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E28463434B434B4843434336434B
43362C43312C1B202A2A20242A39152920151B1515151B1B0C0C0C150C0C0C1B1B0C0C0C
15150C2415150C0400040000000C1520150C24151B2C5595E8F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BB775A394B4348485D484B5454
45362C4B31201B1B202A1B2020360C2A0C1B150C150C0C15150C0C0C15150C152C15000C
15151B0C150C00000000040C15241515151B2C203B4875E2F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B06F4B434B39483948474843
39361B4B2C2A151B1520201513130C15150C150C150C150C150C0C0C0C150C152929290C
0C15151520151B201B1B1B1524130C152A20203B3B6C72F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C47254484B39485454545D
5448364339202415150C201515131B0C1B0C150C0C0C0C0C0C1B0C000C0C1B1515364D43
471524150C1515151B241B151536391B313B2C485D6CF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F77477544B483943485454
54453654392C2C200C151B1B150C130C1B15150415150C150C150C0C000C0C392923475D
2424292936241B1B151B2C30392A2C312C3B3B556CF1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF74725D544839434853
5D4854433B3631201B0C151B0C13131B151B0C150C15150C0C0C150C0C0C0C0047393929
5D5C5D4745455445392C1B1B313131394B48555EF1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78F634B484B39434B
545C6B5D39393B312C15151B201315130C1B0C0C0C0C150C0C0C1515000C1B150C203943
473620151B2A31393939394B4343433B3B4A6C77F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F762545D434B54
5D5D5D6F5D313131312A431B362A20241B0C150C15150C150C1B201515151B2915243623
4345151B1B241B1B152A2036312C3B556C63D3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A76C4B4B4B48
545D6F80744B3031312C2C313939392024202C1515151B241515391B29241B2447292929
201B36362A3936312C433B2C3B48485D5ED3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D06C4B3943
4B5D6F6F746F5D36312C2A2C2C434339365415200C2A292429353636296D4B5320435D47
4543434343393943434B5A4B4355755EF1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7866354
4B5D74748980746F4F5D634339204343544743483923155C45475D6D4747475D5C535448
4B5A4F544F4F4F4B393B485A644A87FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CA77
5D5D4B5454746D746F746F6F745D454B475D6B5D74474524473945476B544B4B434B545A
4F4F4A4348484B555E5D755A48BBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
A75C545D546F80746F6F636F746F6F6F535D546F5C5D6D4739392931395D4B4B4B39393B
3B3B394A555A5E5D5D5E484ACDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7C1745A5D5D5C748974807474637477807477746F8054745D4B45453936435D54434B4B
554F5D5A626C7375554387FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7E55C3E4B536D9574898089776F74847777776C84777763636F6C62636C626372
728083836C4F435EC1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7E2A47D7D9598BC9E9E9E8484775D778487848484777784726C7277808483
6C636C4F4F6CBBFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7E5E8CDBCB5BC9595877772746B747777846F726F726C726C63
5E635E77A4FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7E8E5E8F1E8CDC18F9B8F80777777777784776F6F6C5E54
639BF1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F1F7F7F7F7F7F7F1E2DCC1D3D0E8F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 150},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0000UQP00`40o`000?l0003oooooobgoool0
0?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool0
01[oool6moOg00?gknogmoOgmoL07OOgm`04klJ4mmJmmmJmmmJm0_OFaP03mmk>mmK6mmk>00Kgg/h2
mmK600?ge[g_c[G_c[D00^o6[@04ikFLikfUikFLaZFD2=j]U003gZF<eZF4gYb400;FYH`00mJUQ<J4
Q?Ogm`09moOg00?ginOgmoOgmoL02OOgm`03mno_moOgmoOg00?gmoLOoooo1_Ogm`03lO7amoOgmoOg
01ggmoL01][Jf/o?cmOGemOGem;Bd][JfP;Ph>000m[Jf^3Ph>3Ph005h>3P0][JfP03emOGclo?clo?
00;9bLT01;^k^l30`;^k^k^k^`Rb/[802:f][JVYZJNWYjRXZ:VYZJNWYifMWJVYZ@WgmoL00o7alOOg
moOgm`0:moOg00?alO7gmoOgmoL00oOgma_oool001[oool01?O_koOgmoOgmoO_k`[gmoL00oO_koOg
moOgm`0EmoOg00?gaYCge[gge[d00oOFaP05mmk>mmK6mmk>mmk>mmK600?gg/h2mmK60^o>]@;_aZd3
ikfU00?W]IcN[ICN[I@00]j]U006gZF<gZfDgZfDgZF<gZfDgZF<1=JUS003eZF4eZF<aXB400KgmoL0
0oO_koOgmoOgm`0CmoOg7oooo`04lO7amoOgmoOglO7a2_Ogm`03lO7amoOgmoOg01GgmoL01>SXj=;B
d]OGemOGe`?Jf]X01N3Ph=[Jf^3Ph>3Ph=[JfP03h>3P0][JfP;?cll2bLW90l30`003^k^k/[:b/[:b
00:b/[801Zf][K:b/[:b/[:b/Z2PX:f][@BYZJT01:6QXJVYZIfMWJVYZ@KgmoL00o7alOOgmoOgm`0C
moOg6oooo`006_ooo`;gmoL00oOWioOgmoOgm`02moOg00?ginOgmoOginL03oOgm`03mnOWmoOgmoOg
00[gmoL00oO6Q?OF_OOFQ002mmJ41_OFaP06mmJ4ilJemmJ4kljea/Jea/JU0^N4Y@04a[FUa[F4aZFL
gZFD0]j]U003eZF4eZF<gZF400;FYH@2gZF41mJUS003eZF4aXB4moOg00[gmoL01?OWioOgmoOgmoOW
i`;gmoL00oOWioOgmoOgm`02moOg00CginOgmoOgmoOginL2moOg7oooo`;gmoL00o7alOOgmoOgm`02
moOg00?alO7gmoOalO403oOgm`03lO7amoOgmoOg00[gmoL00n3Ph=;Bd]OGe`02d];B00?Ph>30`<3J
f]X01<30`005d];BalO7d];Bclo?`/;200?0`<02P82000B`/;2b/[:b/[:b/[85X:2P00>][Jfb/[:P
X:001ZVYZ@03YjNWQ8B4`<3000_gmoL00o7alOOgmo7al@03moOg00?alO7gmoOgmoL00_Ogm`04lO7a
moOgmoOglO7a0_Ogma_oool001[oool2moOg00?ginOgknogmoL01oOgm`04mno_moOgmoOgmno_2_Og
m`03mno_moOgmoOg00WgmoL01>o6Q?OF_OOF_OOF_@?ge/H02OONc_OF_OOFa_OFa]K6a^o>]MK6_MK6
]NNmY@02ijfL00?N]IcN[ICN]I`01=jeW003gZF4eZF<eZF<00?FYH`00mjUS=JUS=jUS002eZF41=JU
S003e[FDmoOgmoOg00SgmoL00oOWioO_koOgm`0?moOg7oooo`;gmoL2lO7a2?Ogm`;alO400oOgmo7a
lOOgm`09moOg00?alO7gmoOgmoL02OOgm`05f][Jclo?emOGemOGd];B00?Jf]X02N3Ph=OGem[Jf][J
f/S8b<o?clC4a<;2`/30`002^;Rh00>g]kNb/[:g]kL01;Ng]`03^[ZjX:2PZJVY00FYZJT00jf][JNW
Yk:b/P04ZJVY00>g]kOgmoOgmoL02OOgm`;alO4@moOg6oooo`006_ooo`03mno_moOgmoOg02?gmoL0
1?OFQ?OF_OOFa_OF_@Oge/H02_OF_MK6a_Nm]ONm]NNmYNnm[NnmYNNeW>N]W<J<S0;NW8`2gZfD00?F
U8c6[JGFYH`00mJUS003gZfDgZF<gZF<00KFYH`00mK6]OOgmoOgm`0HmoOg00?gknogmoOoool07_oo
o`03lO7amoOgmoOg02?gmoL01][Jf]OGemOGem[Jf];Bd^3Ph0KJf]X02=OGelS8b<c<c<c<c<C4a<K6
a/C4a;^k^`:h^;P2ZZZZ0[:b/P03]kNgY:BTZJVY00BYZJT01:2PX:f][JVYZJf][@BYZJT00lC4a?Og
moOgm`0ImoOg00?alO7gmoOoool06_ooo`006_ooo`?gmoL00oO_koOgmoOgm`0PmoOg00CgaXCge[gg
e/Kge[d6mmK600KWa[G_c[Gge/Kge[gge/KWa[D2mkfe00S__JgW]IcW[ICNW8cW[Ic_]JGW[IcNU8`2
eZF<00SN]JGFYHcFYHcFYHCFYHcNW8CFYHcFYH@4eZF<00?gimKgmoOgmoL06_Ogmaooool3moOg00?a
lO7gmoOgmoL08?Ogm`05f][Jd];BemOGf][Jd];B00GJf]X01l[:b]OGelo?cm[Jf]OGem[Jf/O7a`02
c<c<00_6a/Jk^k^h^;RRXZ:h^;S1`L6h^;Rg]kNXZ:RYZJVj^[X00jVYZ@05XJ6QZ:RXZJVYZJVY/[:b
00>YZJT00nSXj?OgmoOgm`0KmoOg6oooo`006_ooo`GgmoL00oO_koOgmoOgm`0NmoOg00?ge[gge/Kg
e/H00_OFaP04ilJ4mmJmmmK6mmK60^o>]@Cge/H00nO6Q?OF_ONm]@02kkf]0^NmY@06ijfLkkFUkkf]
ijF4gYb<gZF<0]JLS007eZF<gZfDeZF<eZF<gZF<eZF<eZF400?FYH`MmoOg7oooo`GgmoL00o7alOOg
moOgm`0NmoOg0]OGe`CJf]X01<o?cmOGem[Jf][JfP;?cll4f][J00?:b/[GemO<c<`00/K6aP08a<C4
`<30^;Rh`L71a/K6`L71Z:RX[Jf]0ZJVYP:YZJT01Z2PX:VYZJf][JVYZJf][JNWY`:YZJTNmoOg6ooo
o`006_ooo`_gmoL00oO_koOgmoOgm`0HmoOg00OWa[Gge[gge[gge/Kge[ggeXC_c[D01OOFaP?gg/h2
mmK6017_c[G_aZg__Jg_Q:GW_JG__JG_]JGW[Ic_]JGW[IcNW8cW[ICNW8cFYHCN[ICFYHcN[I@00]jU
S0?FYH`00mjeW?OgmoOgm`0KmoOg7oooo`_gmoL00o7alOOgmoOgm`0HmoOg00S?cloGemOGemOGemOB
d];GemOJf][?cll5f][J0n3Ph0;Jf]X04Lo?clW9bLK6a/W9bL30`<C4a<71`KRh^<71`H20P:ZZZ[Jf
]ZZZZZVYZKZj^Z2PX;:b/P03[Jf]0ZVYZ@03]kNgmoOgmoOg01cgmoLKoooo000Joooo9_Ogm`04ilJe
mmJmmmJmilJe0^O6Q0Gge/H00oONc_OFa_OFaP02mmK600[gg/kge/KWaXCgaZgWaZG_S:G__Jg__JG_
]JGW]H@2ijfL00G6S8CNS8CNQ8CNYICN]H@01=JUQ003eZF<gZfDiiB400[gmoL01OOWioOgmoOgmoOg
moOWi`0>moOg7oooobKgmoL01l;2`]OGemOGemOGel;2`/[:b/O7a`03f][J00?0`<3Ph>3Ph>000/30
`005f][J`<30h>3P`<30b/[:00;5aLD01l30`<K6a/C4a<30`<71`H20P;Rh^003XZ:R00>PX:2b/[:P
X:000Z2PX004ZJVYX:2PX:2Pb<S82_Ogm`03lO7amoOgmoOg00;gmoL00o7alOOgmoOgm`0<moOg6ooo
o`006_ooo`;gmoL00oOWioOgmoOgm`0PmoOg00?ge/Kge[gge[d00^o>]@Cge/H01?OF_OONc_ONc_ON
cP;ge/H3mmk>0oOFaP03ilJemkfemkfe00;__JD01nNeQ>N]U>N]U>N]W>N]U=j4S=jLS002eZF<00KN
]IcFYHcN[ICFYHcN[IC_inL7moOg00?gknogmoOgmoL04oOgmaooool2moOg00?alO7gmoOgmoL08?Og
m`06d];BemOGemOGemOGclo?b/[:1=[JfP04emOGh>3Ph>3Ph>3P0][JfP?Ph>03f][J00?GemO<c<c<
c<`00/C4a00:^k^kP820][Jf^;Rh][JfZZZZ[Jf]Z:RXZJVY]kNg0ZVYZ@03/[:bX:2Pj>SX00SgmoL0
0o7alOOgmoOgm`0CmoOg6oooo`006_ooo`05moOgmno_moOgmoOgmno_01ogmoL01>ONimjeYNO6]No>
]@;ge/H00oOF_OOFQ?OFaP02mmK600Ggg/kge/Kgg/kgg/kge/H00oONcP07mmK6mmk>mmK6mlJeklje
mlJ]klJ]00;__JD2ijfL00cNYHcW[ICNYHCNYHcFYHcN]IcFYHcNYHCN[ICFYHcN[IC_inL;moOg00?g
inOgmoOgmoL01oOgm`03mnOWmno_moOg00GgmoLOoooo00GgmoOalO7gmoOgmoOalO408?Ogm`08XZ:R
clo?emOGclo?f][Jd];Bf][JemOG0m[JfP05h>3Pf][Jh>3Ph>3Pf][J00?Ph>001m[Jf^3Ph=[Jf]OG
el;2`/g=cLW9b@02a<C400j0P82h^;R][Jff][Jb/[:][JfYZJVg]kNYZJVj^[Z][Jfb/[:PX:3Xj>P<
moOg00?alO7gmoOgmoL01_Ogm`03lO7amoOglO7a00KgmoLKoooo000Joooo00?gmoOgknogmoL08OOg
m`03Q6]JklJ]imJ<00oge/H02oONc_OF_OOFa_OFa_OFQ?OF_OO6[No6[NnmYNneYNN]W003ijfD00C6
[ICNYHcFYHcN[I@2eZF<0mj]U0[gmoL00oO_koOgmoOgm`0AmoOg7oooo`03moOglO7amoOg02;gmoL0
0d51@MOGem[JfP08f][J00?0`<3Jf][Jf]X00m[JfP03`<30h>3PemOG00?Jf]X01]OGelg=cLW9bLC4
a<71`H20P0Bf][H00k:b/ZVYZK:b/P02ZJVY00>g]kNb/[:b/[802_Ogm`03lO7amoOgmoOg01;gmoLK
oooo000Joooo8oOgm`04S7=SHdY2kljemmJ40_OFaP03mmk>mmK6mmK600?ge/H00oONc_OFa_OFaP02
mmJm00?gg/kge/Kge[d00_OFaP04mmJmilJemlJ]kkf]0^nmY@08kkFUikFLikFDijfDgZF<aZfDgZfD
gZF<0]JUS004gZFDg[FUgZfDgZfD7_OgmaoooolTmoOg00A/K6a3@d?Jf][GemL2f][J00?0`<3Jf][J
f]X00m[JfP03`<30f][Jf][J00;GemL00n3Ph=[Jf]OGe`02f][J00CGemO?clo5aLG6a/H3a<C400N1
PH6i^KVf][J][Jff][Jb/[:PX:000ZVYZ@04/[:b]kNg^[Zj/[:b7oOgma_oool001[oool01?OgmoOW
ioOWioOWi`;gmoL2mnOW0oOgm`03mnOWmoOgmoOg01?gmoL01]K6aV=2@U8a:Ha2@_OFa_OFQ0;ge/H0
1?ONc_OFa_OFa_ONcPSge/H01oOFQ?OF_NN<]No6[Nn<YNN4Q>n4Y@02kkfU00CW_JGW]HCW]Ic6[I@2
ijfD00W6YHCNYHcFQ8CFYHCFYHcFYHCFYHc6YHcFQ9@07_Ogmaooool01?Ogmo7alO7alO7al@;gmoL0
0o7alOOgmo7al@02moOg00?alO7gmoOgmoL05?Ogm`04`/;2@d=3820P@T920];BdP04f][J`<30`<30
`<300^3Ph0;Jf]X4`<3000KJf][0`<30`<3GemO<c<c9bLT2a<C400B0P834a<C4a<C0`<02P82000Bb
/[:f][Jf][J`/;02X:2P00JQXJ6YZJVQXJ6PX:2YZJV0P80OmoOg6oooo`006_ooob7gmoL01592:G=:
>OOFa^o>]@Cge/H00oONc_OFa_OFaP05mmK61?ONcP0@mmK6mmJmkljekkfUklJ]kkfUikFLkkfUikfU
kkfUikFLijfDgZfDikFDijfDaZF40]jUS003eZF<eZF4eZF400;N[I@00mjeW?OgmoOgm`0LmoOg7ooo
ob7gmoL01O7alCTi>DQ8B=[Jf/[:bP04f][J00?0`<3Jf][Jf]X01M[JfPCPh>002m[Jf]OGelo?clC4
a<W9bLC4a820P<C4a<30`<C4a;^k^`02/[:b00Ji^KVf][Jb/[:a/K6][JfYZJT3YjNW0[:b/QogmoLK
oooo000Joooo1?Ogm`;gknlJmoOg00CooomS@Q3ge/K_c[D2mmJm2oOFaP?gg/h01?OFa^O6]OO6[Nnm
[@;__JD5ikFL00CW]ICW[ICN[ICN[I@4gZF<00CFYHCNYHcFYHcNYH`2gZfD00?_e/kgmoOgmoL06oOg
maooool4moOg0_7alA[gmoL01_oooeeMGC/k>m[Jf/o?cmOGe`cJf]X3h>3P00CJf][7alO=cLg6a/H2
a<C41K^k^`04^KVi/;2`/[:b/[:b1:f][@07YjNW[Jf]ZJVYZJVY[Jf]/[:bf][J01kgmoLKoooo000J
oooo1_Ogm`03mno_mnOWmoOg01OgmoL00iAkLb480>o>]@08mmK60_OF_@05mmK6mmJmmmK6mmK6mmk>
00?ge/H00nO6]ONm]NneY@03ijfL00GW[ICW[IcW[ICW[IC6YH@01=jUS00;eZF<gZF<gZF<eZF4gZF<
gYb4gZF<gZfDgZF<eZF<imK601cgmoLOoooo1_Ogm`03lO7amoOglO7a01OgmoL017MgMd=3@ibLW<o?
c`OJf]X3emOG00?Jf][GemOJf]X00^3Ph0?Jf]X00lO7alc<c<71`@03^;Rh00>`/;2h^;Rf][H00[Jf
]PB][Jd01JVYZJf][Jf][JNWYjf][@02Z:RX00B][JfPX:2YZJWJf]XMmoOg6oooo`006_ooo`?gmoL0
0oO_koOgmoOgm`0JmoOg00AS@S64DT;ge/Kge/H2mmJm00?ge/Kgg/kge/H00_OFaP;ge[d3mmK600Sg
g/kge/Kge/Kgg/kge/KWU8Cg_KG_U8`5ihAk00?WU8CW[ICNYH@00]jUS003eZF<gYb4eXB400;NYH`0
1MJUS=jUS=JUQ=jUS=jLQ002eZF<00?FYHCgmoOgmoL04_Ogm`03mnOWmoOgmoOg00GgmoLOoooo0oOg
m`03lO7amoOgmoOg01[gmoL00c/k>fa/K>3Ph002f][J00CGemOJf][Jf][Ph>02f][J0mOGe`;Jf]X0
2L30`>3Ph=[Jf][Jf^3Ph=[JfX20P<c<c;2`/005XZ:R00>ZZZZf][Jb/[800Zf][@06ZJVYZ:RXY:BT
YjNW[Jf]ZJVY0Zf][@03YjNW[Jf]Z:RX00:YZJTDmoOg00?alO7gmoOgmoL01_Ogma_oool001[oool5
moOg00?ginOgmoOgmoL05_Ogm`03e/K6@P0aHd8000;geX@2mmK600Wge[gge/Kge/Kge/KgeXCgaXCW
a[Gge[gga[D00oOFaP0;miB4mib4e/k6mkfeiiB4ih@8ih@0i`1[aP1JaP08i`1[00;606/01>N4NlJ4
2<J42=J4Q0;FYH@00mJ4Q=jUS=jUS002gZF<00OFYHCNYHcFQ8CFYHcFYHC>YHCginL02OOgm`03mnOW
moOgmoOg00ogmoLOoooo1OOgm`03lO7amoOgmoOg01OgmoL0200001XJ6/30`=[Jf];Bd][Jf];Bd/30
`0?Jf]X2d];B00?2`/;GemOBd]800m[JfP05b<S8`<30`<30c<c<P82000:PX:001820P8:2PX:2PX20
P0:2PX82XZ:R00>0P82PX:2QXJ400ZNWY`0<X:2P[Jf][Jf][Jf]X:2PYJFU[Jf]Z:RXX:2PYJFUPX:2
lO7a2OOgm`03lO7amoOgmoOg00ogmoLKoooo000Joooo00GgmoOgknogmoOgmoOgknl06?Ogm`08mno_
Nf=JS7=SkljemmJmmmK6mmJmmlje1?OFaP08mmJmmljeihbUmlJ]mljemmK6mmk>miB40oNm]@03kkFU
aQ00gV]J00CNJeX03=IcHmi[F]i[F]i[F/H0JmIkJlj<Q=jLS=jLQ=JLQ=JUQ=jLQ0;NYH`00mjUQ=jU
S=jUS002eZF<00?NYHC__Jggknl06_Ogmaooool01OOgmo7alOOgmoOgmo7al@0ImoOg00?alO5<C4c?
cll00]OGe`03f][JemOGd];B00CJf]X01m;Bd/C4a=;Bd/g=cM;Bd][Jf/30`004c<c<00?1`L6:RXZ?
Shl028n?S`05UiNGPX:2Vi^KZZZZZ:RX00:TY:@01:2PX:f][Jf][K:b/P:][Jd2ZJVY00B][Jfb/[;6
a/KalO4JmoOg6oooo`006_ooo`KgmoL00oO_koOgmoOgm`0DmoOg00BLS8aJ@SWgg/k_c[D5mmJm0_OF
aP;ge[d01>o6[NnmYNnmYOOF_@;ge/H04ON4YOO6[NnDS>NDQ>N4LmJ<2>N]W<I[D_Nm]MjeW:DQ6=Ik
JmISD/iJB]ISD]i[B]IkJ`02eXak00CFYHcFQ03FYHCFYH@2gZF<00W6YHcN[ICNYHcFYHcNYHcNYHCN
]Icgimkgknl06OOgmaooool6moOg00?alO7gmoOgmoL05OOgm`03RHV9820Pclo?00GGemL3f][J00?G
emO1`L74a<@00/C4a003emOGf][Jb<S800;=cLd03k2`/:ZZZZ2PX8R8R;Rh^861PLc<c;Ng]gemOI2@
T8N7QgmoOhN7Qhn?Si>CT`02WIfM00BYZJVWYjNPX:2WYjL2[Jf]00Ba/K6][Jfb/[:YZJT2[Jf]00Bb
/[:g]kOXj>SalO4ImoOg6oooo`006_ooo`CgmoL00oO_koOgmoOgm`0EmoOg00K6[Ke[DTYJ<BWge/Kg
e[ggeX@2mmJm00CgaZgge/Kge/Kgg/h2mlje00?_aZgW]IC__JD00_OFaP08mlJ]ihB4ihAceV=B]E8i
aZfUaXB4e/K60/je]@09kkf]U8BLc[Fe[F]BeYb<YF=:aU92eW=SeW][00;FS7/02=JLQ=JUQ=jLQ=jU
S=j]U<JUU=jUS=jLQ0;NYH`00mjUQ=JUS=jeW002imk_6?Ogmaooool4moOg00?alO7gmoOgmoL05_Og
m`03][JfBd];410@00;GemL02M[Jf]OGemOGelS8b>3Ph=[Jf^3Ph=;Bd/30`002^KVi00_4a<CJf][J
f]Z0P82f][JPX:27QhM/K6b][Jf8R8S8b<P00[Vi^@09a/K6Y:BTP820M7AdYZJVK6a/OgmoShn?Ti>C
00:MWId2Y:BT00NPX:2][Jfb/[:i^KVb/[:][JfXZ:P00Zf][@04/[:bZJVY]kNgiNGU6OOgma_oool0
01[oool7moOg00?ginOgmoOgmoL04OOgm`04imKW]IbLFT8iaYb40_OF_@07mmK6mmJmklJ]kkfUmmk>
mmK6mmJm00;gaZd01>NeU=jLQ?OF_ONm]@;WQ7/06H@00=IkJnN]W=i[F^NDQ<ha8OOWioOWg^oFc^Mk
JlJ40<icF[f4HkfUW<JDQ:ES@/iJB]ISD/j<LljDNmJL0=JLLmjLQ=jUS=j]U002ikFD0]jUS006gZfD
gZF<gZfDgZfDe/K6mnON6?Ogmaooool7moOg00?alO7gmoOgmoL04_Ogm`05iNGUWYjN>CTiUIFEemOG
00;Jf]X00mOGelW9bL30`002f][J00?GemO=cLf9RHT00ZRXZ00IemOGc<c<XZ:RP820@d=3Ti>C^;Rh
Shn?ZZZZPH61jn_[j>SXf][JW9bLZZZZPH61R8R8Y:BTVYZJL71`K6a/QhN7UiNGVi^KY:BT00:PX:00
0jf][K:b/[^k^`02^KVi00B][Jfb/[:][Jf][Jd2/[:b00?8b<SgmoOgmoL05oOgma_oool001[oool:
moOg00?gknogmoOgmoL03_Ogm`08YJFUW8b<DS4YkmK>mmJmmmK6mmJmmlje0^nmY@?ge/H02OO6[NNe
W>NUS<J40>neYMi[FY`i:IASB^NLS002mnON0_O_k`05mnO6mno_mnONmmk>klje00;_e/h04]K6a[EB
>KEcFXAcJg=:>KeJ@/I[D]IcHmJL0=JLLmjLQ=jUS>NeW>NeQ>NeU=jUS=j]U=JUS0?N[I@01=K6]OOg
mmK6e^OFiaKgmoLOoooo2_Ogm`03lO7amoOgmoOg00ogmoL01JBTY8V9RB`/;=;Bd][JfP02emOG00?B
d];4a<C0`<000m[JfP09cLg=/K6aXJ6Q/K6a`L71Shn?EUIFA4A4h>3P00;Xj>P2lO7a00GXj>SalO7X
j>SPh>3?cll00][JfP09b<S8K6a/OGemLW9b0000M7AdPH61Shn?Z:RX00:PX:001jf][K^k^l30`;^k
^kVi^J2PX:VYZ@04/[:b00?2`/;=cLgRh^805oOgma_oool001[oool2moOg0_OWi`;gmoL2mnOW0_Og
m`03mnOWmoOgmnOW00SgmoL01>OWioOWioOWinOFi`;ginL02X@0049208@@0>O6]OOFQ?OFa_OF_OO6
YNnmYOOF_@;ge/H05_OFQ>N4S>NUS<j4Hh@08H@060PQ8IAB@/J4W?O6a_OWa_O6W?OWa_O_koO6a_O_
koOWg_O6a^N<U?OWa^oFc^OFaP;6Q8@05XAB00Pa8D8020P@08A24<H00=JL0=JLQ=jUS>NeU>NeQ>Ne
W>NeU=jUQ=JUS=jUQ=j]U=jUQ=jeQ<jDYLJ]c/K6aQKgmoLOoooo0_Ogm`;alO42moOg00KalO7gmoOa
lO7gmoOalO7gmoL2lO7a1oOgm`0<h>3PmoOglO7alO7ahN7QlO7amoOg00000@415ADE`/;2f][J0]OG
e`0:`<30a<C4d];Bf][J`<30d];BRHV9PH61T92@4Q8B0T10@00XHF5QP820b<S8j>SX`<30j>SXlO7a
b<S8lO7aj>SXb<S8R8R8jn_[b<S8f][J`<30R8R8B4Q800000P82410@00006QXJQHF5X:2P[Jf]^KVi
a<C4P820^k^kX:2PZJVY/[:b[Jf]/[:bX:2PT92@`<30b<S8lO7a5_Ogma_oool001[ooolCmoOg00?g
knogmoOgmoL01OOgm`04@T8QDS4YmmK6klje0oOF_@03klJ]mmJmkkfU00;ge/H06_OF_NNUS=jLQ<J<
Hi@8@ZE2<H@Y6>N4LnNDQ<jD8OOF_NneYOONc_OWg^N4U?OWg_OF_NN]U>N]W>nDQ?OFa^N]U>o>]OOF
a/J4Q=jeY@:mW8`037=2<HA24=JLQ=JLQ=jUS>NeU>n4YNNmYNNeW=jUS=j]U=j4Q0;NYH`01Mj]U=K6
]JfDU<J4]MkFi`0:moOg00?gknogmoOgmoL02?OgmaoooolDmoOg00?alO7gmoOgmoL01?Ogm`05g=cL
>c/k;2`/f][JalO700?GemL00lW9bMOGel30`002f][J00OGemNa/K68R8RMWIedM7ANGUi3@d<00Z2P
X00Aa<C4emOG`L71h>3Pj>SXUYJFj>SXemOG][Jf^;Rha<C4f][J][Jfclo?f][Jclo?Z:RX00:LW9`0
3D=3@eiNGX61PJBTY:f][KVi^LC4a<W9bL30`:VYZK:b/Zf][JRXZ002[Jf]00F2PX:EUIFk^k_4a<CL
g=`02_Ogm`03lO7amoOgmoOg00SgmoLKoooo000Joooo00?gmoOgknogmoL05oOgm`04c[g>8@0QLdY2
e/K60oOF_@04ilJ]kkfUmljekkfU0_OFaP04kljeiiB4cXa[gYAc0^N]U006gW][gV]JihAcaXAcijfL
iiB40^NUS003ijF4mkfeeW=S00;NNf/04^N4Q>N]U=IcHnNUS>o>]LJeW=jeYMJUS;fLS:EcFR404<j<
LmJLQ=jUS>NeW>n4YNnmYNNeW0;NYH`02MJ4Q=JUS=jUS=jeW=jeYMkFilJ4a]K6c^ONk`0DmoOg7ooo
o`03moOglO7amoOg01OgmoL01LC4a3/k>aDE5DY:B/S8b003emOG00C9bLW4a<CBd];0`<02f][J00c?
clnZZZZ1PH6f][Jh^;Rf][JGUiN?ShnPX:2QXJ6h^;RZZZX2/K6a00>1PH7<c<b?Shl00YNGU`0NZZZZ
/;2`Shn?/K6aclo?^k^k/[:bZJVYW9bLMGEe?CdmGUiNQ8B4[Jf]^k^ka<C4bLW9a<C4ZJVY[Jf]ZJVY
Y:BTZJVY[Jf]/[:bg=cLcLg=`L71b/[:iNGU5?Ogma_oool001[ooolHmoOg00Kgknn<Lf=2:B528@S6
U8Cge/H3mmJm00cgaZg_aZggaZgW[ICge[ggeXCg_KGWYHc>Q6?W]Ic_Q:Gge/H2mmJm00gg_KG_]JG_
]JGW[Ic_]JGW[IcWQ8c_U8cNW8cNW8CNNf_NJd[>LeX00]IcH`0Bg[FLaXaSklJ]cXb4eZF<[G][H`0@
YE8ieXakeZF4ikFDkhBUkkfUikFDgZfDgZF<eZF4gZF<0]j]U005g[FLmoOge/k6e/KFg]KW01CgmoLO
oooo6OOgm`06H61P820P;2`/6a/KVYZJf][J0]OGe`;=cLd02lW9bLg=cIJFU][Jf]OGelc<c;6a/I2@
T<71`Lo?cm[JfP02emOG00K4a<C1`L71`L6h^;S1`L6h^;P2/;2`00FZZZZXZ:RGUiNGUiN9RHT00Xn?
S`0C]kNgUIFER8R8Vi^KZJVYP820:b/[=SHf10@4YjNW^KVia<C4bLW9a<C4/;2`[Jf]YjNWZJVY[Jf]
00:b/[801OOgmo7alM?Cdlg=cMCDe00DmoOg6oooo`006_ooo`SgmoL00oO_koOgmoOgm`0<moOg00OW
g^OFa]I2:B4a8AQ2:A3ge/Kg_KD00oOF_@0<klJ]mkfeklJ]klJ]mmJmmmJ4mlJ]ijfDcXASijfDiib<
mmK60_ONcP;ge/H4mmk>0_Nm]@;__Jd04>neYNN46=ikJnN4NmIkJmIcHlI[D]JLLlI[D[EcFZE2<D80
48A:>JEB>MJLQ>N]U0;__JD01NNeW=jUS=jUS=J4Q=jLQ002gZF<00KN]IbUQ7^DU8CWg^ONc]K_inLC
moOg7oooo`SgmoL00o7alOOgmoOgm`0=moOg00ORh^80000C4a<i>CTN7QkJf][<c<`00]OGe`;9bLT0
2lc<c<W9bL71`M[Jf]OGelg=cKJf]Y2@T<K6a^3Ph=[JfP02h>3P00?0`<3Jf][Ph>000n3Ph0;<c<`2
a/K60131`L6h^;R2PX:RXZ:CTi>?Shn1PH60P821PH5mOGeNGUhG5aLf=SI0@42TY:Bf][H3a<C400bY
ZJV][JfYZJVTY:BXZ:R][JfUYJF4Q8BNWYkLg=cRh^;0`<0DmoOg6oooo`006_ooo`03mnOWmoOgmoOg
00GgmoL00oOWioOgmoOgm`0<moOg00_6c/HH00P@8A1B40P0003ge/KWa[Gge[ggU;Ggc[GWQ;D00^O6
]@08kljeilJeihBeklJUijfDaXB4cXASihB41_OFaP05mmk>mmK6mmK6mmJ4mlJU00;__JD05^NeQ>N4
Q>NeW>N]U<J4S=j4Q<J40=HH0=H@0<H809@H09@88H@0:H@08LJ<Jmj4Q>NmYNnmYNNeU=jUQ=JUS=J4
Q0;NQ8@01mjUQ=j]U8BUS0124?OWinoWinOWi`0CmoOg7oooo`03lO7amoOgmoOg00GgmoL00o7alOOg
moOgm`0=moOg00_2`/80000T92@P820<30cJf][7alO4a<CBd];?clo4a<@00lO7a`07a<C4c<c<bLW9
][JfP820PX:2b/[:00;0`<001M[Jf/30`=[Jf][Jf^3Ph002`<3001GBd];0`<34a<C4a<B0P830`<20
P82f][JPX:2XZ:R8R8R0P828R8R0P80T92@D51@B4Q80002EUIFXZ:S0`<000/C4a004X:2PZJVYYJFU
Y:BT0ZRXZ0:PX:001410@4Q8B?7alN3Ph1CgmoLKoooo000Joooo5oOgm`05g]KWQ6=BmmJmkljekkfU
00;_c[D2mmJm00Ggc[GWa[Gge[gg_KGge/H00_OF_@07kljeikFLijF<gYb4cX@QkljemmK600;gg/h3
mmK60_ONcP0;miB4kkfUkkfUikFDkkfUikF4ikFLijfDgZF<eZF4eXB400;FYH@2eYb400SFQ8CFW8C>
S8CFW8CFW7?W]HC__JGW]I@2gZF<0]JUQ006gZF<gZfDgZfDaZfUBR52e/Jm5OOgmaoooolHmoOg00?L
g=aFEUK?cll00/C4a0;?cll00mOGem;Bd/o?c`02emOG00_<c<cBd];GemOGemO?clnk^k^PX:2QXJ79
bLW?cloJf]X00^3Ph0?Jf]X2h>3P00C8b<S4a<C4a<Bi^KT2a<C400Nk^k^f][J][JfWYjNYZJVTY:BW
YjL00ZBTY00:YjNWY:BTP820Y:BTX:2P`<30^k^ka<C4ZJVY[Jf]0jNWY`06[Jf]/[:b[Jf]GEeM`L71
a<C45OOgma_oool001[ooolFmoOg00OginNmYIc_c[Gge/Kge[gWaXCFa/H00^o>]@06mkfemmJmmmK6
mmK6mmJmmmK60_OF_@07kljekkfUikFLijF<aYB4kljemmJm00?gg/h3mmK601ggg/kgcXC__JG__JGW
]ICW]IcW]HCW]ICW[ICNYHcFYHC6U03>S6_>U7_>U7?>U7_6Q7_FW8CFW7?FYHCNW8CW]HCW]IcN[ICN
W8CFW8CFW03FYHCNYH`00]JUS003c[F]024QmoOg01GgmoLOoooo5oOgm`0:lO7aY:BTb/[:emOGf][J
clo?b<S8clo?c<c<emOG0m[JfP0;emOGd];BemOGemOGclo?a<C4/K6aZ:RX^KViclo?emOG00?Ph>03
f][J00oPh>30`<34a<C4a<Bi^KVk^k_4a<Bi^KVf][J][JfWYjNTY:BATI6KVi^IVIT00Y^KV`08WIfM
X:2PYjNWZ:RX^KVia<C4^k^kX:2P0ZBTY007X:2PYjNW[Jf]ZJVY][Jf5ADE^k^k01KgmoLKoooo000J
oooo5_Ogm`09e]KWmmJmmmJmmmK6mmJmilj4kljemmJmklje00;ge[d03oOFQ?OFa_OFa_OFa_ONc_OF
a_Nm]No6[NnmYNN]U<J4Q>nmYNo>]OOFa_ONcP03mmK600Gge[ggg/kgeXC_c[G__JD00^NUS008ijFD
gZF<eZF4eYb4aYb4cYAccYAkcXac0/jDL`09cXAccYAccYAceXakgZfDaY@@ikFDijfDgYb400;FW8@2
eZF400GN[ICFYHbmYI`@003Wg^l05OOgmaoooolGmoOg00GLg=cGemOBd];GemOPh>000/o?c`04emOG
alO7emOGemOG0m[JfP0=`<30f][Jf][Jc<c<bLW9Q8B4/K6aZ:RXa<C4clo?f][J`<30h>3P00;Jf]X0
1MOGen3Ph=;Bd/o?clC4a002/K6a00Rf][JYZJVWYjNTY:BMWIfKVi^IVIVGUiL3VIVI00RGUiNIVIVM
WIfb/[:PX:2k^k^i^KVPX:03Y:BT0ZNWY`05X:2PY:BT<C4aP820iNGU01GgmoLKoooo000Joooo5_Og
m`03e/KFmmJmmmK600;ge[d01>O6YOOF_OOF_ONm]@;ge[d00oOFa_ONc_ONcP02mmk>00Wge/Kge[gg
_KG__JGW]Ic6Q03W]IC__JGge/H00_ONcP?ge/H01?OF_NO6Q>nm[NN]U0;W[I`01]j<Q=jLQ=JLLmJL
LljDLlj4L`;>U7<2cYAk00K>U7?>S6_>U7?FYHCNW8C6[I@2gZF<00[NW8CFW8CFW8CFYHCFYHcNYHcF
YHbmYI`Q002DQ8@EmoOg7ooooaOgmoL01]?CdmOGem;Bd]OGelg=cLo?c`;GemL01<C4a=OGem[Jf][J
fPCPh>002M[Jf]OGelc<c820P;6a/J6QXKVi^LC4a=[JfP02h>3P0m[JfP04emOGb/[:a/K6][Jf0[Rh
^008/[:bZ:RXX:2PX:2PVIVIVi^KTI6AVIVI0Y^KV`:IVIT01i6ATJNWYjRXZ;Jf][:b/Zf][JRXZ003
Y:BT00NWYjNYZJVYZJVTY:@C4a=3@d>0P8005OOgma_oool001[ooolFmoOg00[WaZGge[gge/K_aZgg
aZgWU9CFa/Kge[ggc[Gge[d2mmK61OONcP07mmJmmkfeklJ]kkfUijF4ijF<kkfU00;ge/H02?ONc_OF
a_Nm]OO6[No>]OOF_OO6[NNeW0;W[I@01]J<4=JUQ=JUS=JLQ<j<Llj4L`;>U7/2eYac0/jDL`07cXa[
gYb4ijfDijFDijF<gZF<eZF<00;FW8@01mjLQ=JUS=JUS=j]U;fLS00Q8Ljm]@0EmoOg7ooooaKgmoL0
2^SXj=;Bd]OGelS8b<g=cKVi^MOGelS8b=OGem;BdP;Jf]X6h>3P00CGemO<c<c0`<2f][H2/K6a00_4
a<CJf][0`<3Ph>3Jf][<c<c=cLg?cloGemO=cLfk^k/00[Jf]P04/[:bPX:2ZJVYY:BT0YNGU`04VIVI
Vi^KX:2PX:2P0YVIV@07TI6AZ:RX][Jf^KVi][Jf/K6aZJVY00>TY:@01jRXZ:VYZJ2PX9bLW1DE5B@T
9;^k^`0EmoOg6oooo`006_oooaKgmoL2mmJ400Sgg/kWQ9CWYHcFQ9C_c[Gge[ggU;Gge[d2mmK60_ON
cP0;mlK>mmk>mmk>mmK6ilJeilJUihBUijF4aXB4ijF<klJU00;ge/H00oOFQ?OFa_OFS002mmJ401?g
e[g_Q:g__JGW]IcNYHCFQ8BLQ0S>Q7?>S6><Q6?>U7?>U7_FW7?FS036Q03FS136YHCW]HCW]I@00/JU
Q0;NYH`2eXB400WFYHcFQ8CFYHcFYHbUQ0128B5S@T;We^OginL04oOgmaoooolFmoOg00cGemOBd];B
d]:0P82a/K6b/[;4a<C?cloGemO4a<CJf][0`<06h>3P00SJf][7alO0`<20P82a/K6PX:2a/K79bLT2
`<3001OBd];Jf][0`<3Bd];0`<3GemO0`<34a<Bk^k^b/[:PX:28R8RCTi>EUIF2PX:ATI6KVi^PX:24
Q8B0P828R8RPX:20P8000[Vi^@03[Jf]Y:BT[Jf]00>TY:@02:VYZJ2PX:VYZH>3Pb0P824Q8D=3@n7Q
hACgmoLKoooo000Joooo00?gmoOgknogmoL01?Ogm`03mnOWmoOgmoOg00_gmoL02?OWg_O6]OOFa^o>
]MjLQ>NeU>N<YONm]@?ge[d01?OFa_ONc_ONc_ONcP;gimh2mmk>00Sge[g_c[Gg_KGWQ:GW[ICWYHcW
]Icg_KD4mmK600Ogg/kga/kge/K_c[G__JGW]Ic6[I@00mjUS007eZF<W8@0aXaccXa[cYAceXakgZF<
00CW]I`01NNUU>NUS=jUS=jLQ=jUS002eYb400WFYHCFYHcN]IbeS7=B02Ta8AR<Lf_Nc]Kgknl04_Og
maooool00oOgmo7alOOgm`05moOg00?alO7gmoOgmoL02_Ogm`09j>SXd];BemOGf][JR8R8^KVi`<30
clo?c<c<00;GemL00m[Jf^3Ph>3Ph002h>3P00gXj>SPh>3Ph>3Ph>3GemO<c<c=cLg4a<Bf][Ja/K6k
^k_8b<SPh>000m[JfP;Ph>001][Jf/o?clC4a;^k^kRh^:2PX0:][Jd01ZVYZJRXZ8:2PYFEUIVIVIfM
W@:][Jd4^k^k00Bf][Ja/K6XZ:R][Jd3Y:BT00RWYjNQXJ6;Rh]8B4P`<30C4a=3@d?alO4CmoOg6ooo
o`006_oooaGgmoL02>o>]OOFQ>o>]No6[Lj<JmJLS>o>]ONm]@?ge[d01?OFa_ONc_OWg_OWgP?gg/h2
mmK6013_c[Gge[gW]ICW]IcW]IC__Jg_c[Gge/Kgc[Gge[gge/Kgg/kge/Kge[g_aZgW[I@2gZF<0]JU
S0;FW8@01mJL0;f4Jlj<LmJ<NmJLQ<J]U>NeW002kkfU00GW]Ic6]HCN[ICN[ICNYH`00]JUS00:eYb4
eZF<eZF<g[FLeYacQ012Q4XiFT8iHdY2[IBD4_OgmaoooolEmoOg00K?cloGemOJf][?cln1PH6VYZH2
clo?00C<c<cGemOGemOJf]X2h>3P0^SXj0?Ph>02f][J0137alO<c<bk^k^k^k^i^KW6a/K:b/[Jf][B
d];GemOJf][Ph>30`<3GemO9bLVf][H2[Jf]0ZVYZ@:TY:@06ZZZZX20P9NGUifMWJBTY;:b/[Rh^820
P<C4a;^k^l30`;Ng]k:b/Z2PX:VYZJf][JVYZJBTY:VYZJ6QXJ2PX8n?Sfa/K51@D0410IFEUA?gmoLK
oooo000Joooo5?Ogm`08mnOWmlJ]mlJ]ikFDgZF<gYb4g[FLihbe0oOF_@03mmK6mmJmmmk>00;gg/h0
1?OWg_ONc_ONc_OFaP?ge[d01>N4YNnmYNnmYNNeW0;ge/H03>o>]No6[OOF_OOFa^O6Q?Nm]NnmYMj]
U=jUS=JLS=JLQ=JUS0;FW8@02<JD0;f4Hlj<JmJLLmjUS>NUW>NeW>nmY@;W]I`01/JUU=j]U>N]U=j]
U=jUS=JUQ0?NYH`01mjeW=JLQ<J<Lkf4Jf=:@XakLnONi`0BmoOg7ooooaCgmoL02N?Shlg=cMOGelg=
cKVi^JRXZ;Ng]lo?clc<c002emOG00?Bd];GemOPh>001^3Ph005f][JemOGemOGc<c<bLW900;4a<@0
3k^k^m[Jf][Jf/o?clW9bMOGem[Jf/[:b/c<c<C4a;:b/Zf][JJVYZBTY:VYZ@03Y:BT00N8R8REUIFP
X:2][Jfh^;Rk^k^0P8000k^k^`>b/[82[Jf]00ZWYjN][Jf][JfUYJFTY:BPX:2GUiN:RXY0@43Rh^8C
moOg6oooo`006_oooaCgmoL02?OFa_O>]LJ40=IcHmIkJmJLQ>NeW=K6]@?ge[d2mmK61OONcP?ge/H0
4_OF_No>]NN4YNnm[No>]OO6[OOF_OOFQ>o6[Nnm[No>]OOF_OND]NnmYNNeU>N]U=jLQ=JLQ0?>U7/0
1]JLLhb4HlJ<Hlj<LmjLS=j]U0;W]I`2kkfU00?W]Ic6YICW[I@00mjUS003eXB4eYb4gYb400;N]I`3
eYb400>mW8cgmoOgmoL04_OgmaoooolDmoOg0];BdP06/K6aXJ6QShn?P820^k^k`/;20mOGe`03d];B
f][Jh>3P00CPh>004=[Jf^3Ph=[Jf][Jf/O7alc<c<W9bLK6a/o?clg=cM;Bd]OGelW9bLK6a/o?cmOG
e`;4a<@01KVi^KJf]ZRXZ:BTY820P002Vi^K00JPX:2IVIV:RXZGUiNZZZZb/[82^k^k00J0P834a<Bk
^k^k^k^b/[:f][H2[Jf]00FXZ:RWYjNTY:BXZ:Rg]kL01:BTY003U9BDmoOgmoOg01;gmoLKoooo000J
oooo4oOgm`0;imK6mkfemlJUaQ00eW][cXaSeZF<ijf4ilJemmK6mmJm00Cge/H03?O6c_ONc_ONc_ON
c_OFa_NDQ?OF_ONm]No>]NN4[NN4YNo>]@?ge/H02_OFS?OFa_OFa_OFQ>N4YNnmYNNeW=jUQ=JLQ<J4
00;6Q7<03/J<LlJ4Llj4JlJ<0=J<4=jUQ<JUU>NeQ>NmYNNeQ>NeYNNeW<JUU<J]U0;NYH`02]jLQ=J4
S=JLQ=J4Q=JUQ=jeYLj4HlJ40=JL0<JUQ1CgmoLOoooo5?Ogm`;0`<003:ZZZX20P9>CTh61PH20P<o?
cmOGem[Jf]OGel30`=[Jf/30`0CPh>001L30`=[Jf/S8b=OGelc<c002a<C400?8b<S?cloJf]X00l30
`0;Jf]X02];Bd/S8b<C4a;^k^j2PX:BTY9VIVI>CTi6ATI>CT`:ATI403H20P92@T:2PX;:b/[^k^l30
`820P<30`;^k^k:b/[2`/;:b/Zf][@03Z:RX00>TY:BPX:2PX:000Y6AT@:PX:000jFUYOOgmoOgm`0B
moOg6oooo`006_oooa?gmoL01?Nm]OO>]ONm]NN4Q0;>S7<01mj]U>nm[NO6Q?OF_OOFa_ONc_OFaP02
mmk>00cge/Kgg/kge/Kge/KWa[Gge[g_c[Gge[gg_KG_Q:G__JG__Jd7mmK600OWa[GW]IcW[ICNYHcF
W8C6U03>U7<00ljDN`03eXB4gZF<gZfD00;W[I`00nnmYNNeW>nmY@02ikFL00KWYICNYHcNYHcFYHcF
W8cFQ8@2eYb400KFW8cN]JGFS7_FS7?FYHcFW8@DmoOg7ooooaCgmoL03<30`<c<c;6a/JZZZYNGUi:B
T/K6a/o?cm[Jf]OGem[Jf/30`0?Ph>002M[Jf^3Ph=[Jf]OGelo?cmOGelo?clC4a<W9b@02a<C400C6
a/KJf][Jf][Ph>04f][J00O7alNk^k^f][J][JfTY:BMWIfIVIT00i^KV`03YjNWY:BT/[:b00:h^;P2
a<C400Z0P82k^k^k^k^k^k^f][J][JfYZJVVYZJTY:BYZJT2Y:BT00JRXZ:MWIfMWIfPX:2YZJVTY:@D
moOg6oooo`006_oooa;gmoL02_ONc^nmYOO>]OOFa/J4Q<j<JlJ<Lmj]U>o6[OOFQ0;ge/H3mmk>0oOF
aP0=mmJmkljeilJemmJmmkfekljeklJ]khBUkkf]klJ]mmJmmmK6mmJ400Cge/H01_ND]NnmYNNUS=jU
S=JLQ<JD00;>U7/2aYb400?FQ8CN[ICN[I@00^NeW00DkkfUikfUikFLikFLijfDgZfDgZF<gYb4gZF<
gYb4eYb4eYb<eZF4eYb<g[FUeZF<eXB4eZF<eXake/K64oOgmaoooolCmoOg00WPh>30`<3Jf]Za/K6X
Z:REUIFBTY;9bLWGemL00m[JfP;Ph>04f][J00G7alO?cloGemOGemO<c<`00/W9b@06a<C4a/K6bLW9
emOGf][JemOG1=[JfP;4a<@01;6a/Jf][JBTY9fMW@:KVi/2WIfM00>TY:BRXZ:b/[800[^k^`;4a<@0
0h20P;^k^kJf]P02/[:b00>][JfXZ:RXZ:P00ZBTY008YZJVYjNWXZ:RZJVYZ:RXYjNWZJVYR8R85?Og
ma_oool001[ooolBmoOg013ge[gW]ICge[gW_JG6S8BmQ6_6S7?N]Ic_aZg_c[Gge[gge/Kgg/kge/Kg
g/kge/H3mmJm0^o>]@05kkfUkljekljekkf]kkfU00?_c[D00oOFa_OF_OOF_@03mmK600OgeXC__JGW
[ICNYHcFW8C6U03>U7/00/JLQ00:eYb4eXB4gZF<ijfLikFLikfUikF4ikFLikfUikFD0^N]U004gZF<
eZF<eYb4eZF40mJLQ007g[FLijfLcYAceZF4g[FLeXacgZfD01?gmoLOoooo4oOgm`08emOGTI6A`<30
^;RhZ:RXRXZ:Ti>CbLW90/o?c`03emOGf][J`<3000;Ph>001=[Jf]OGemOGelO7a`;?cll00lC4a<o?
clK6aP02a<C40lo?c`03d];BemOGemOG00?Jf]X01=;Bd/C4a;Jf]Zf][@:TY:@059RHV9fMWIfMWJBT
Y:VYZJRXZ;Rh^;^k^l30`;^k^l30`820P;Vi^KJf][Rh^;Jf]Zf][J2PX:NWYjJVYP>TY:@01[2`/9VI
VJNWYjVYZKNg]i:BTQCgmoLKoooo000Joooo4OOgm`0;mnOWikFDijF<cXacgYb<W6]B]G]S_HA[ikfU
kljemmJ400?ge/H02_ONc_OFa_OFQ?OF_OO>]OOF_No>]Nn4[Nnm[NNmY@;__Jd01no6YNo>]No>]No>
]OOF_OOFa_OF_@03mmK600GWa[G__JgW[ICNYHcFW8@00ljDN`08aYb4eYb4eXB4gZfDijfLikfUikFL
ijFD0^NmY@;W]I`01LJ]U=j]U=j]U=jUS=JUS002eYb400KFW8cFYHcN]JF]Je;68@3N]I`2eXac00?_
inOgmoOgmoL04?OgmaoooolBmoOg00CalO6i^KVATI6ZZZX2K6a/00B1PH60P83?cloGemL3f][J00?0
`<3Jf][Jf]X00]OGe`03d];BalO7bLW900;6a/H00l30`<K6a/W9b@04clo?00?Bd];Jf][GemL00m[J
fP05alO7a/K6][Jf[Jf]Y:BT00>KVi/02YfMWJBTY:BTY:2PX;Rh^<30`;^k^kJf][^k^l30`0:k^k/0
1[Jf][:b/[:b/Z2PX:VYZJJVYP:TY:@02:JVYZRXZ7AdM8N7QjNWYkNg]iZJV^SXj1?gmoLKoooo000J
oooo4OOgm`0?mlJUaX@0aXAk@P0QQ1P0Q5924492Q7=2ikfUmmJmmmK6mmJ4mmK6mmJ4mmK600;geX@0
0nOFa^O6Q>O6Q002ilJ400O_S:GW]HcW_JGW[HC6[HCWS9C_aZD00^o>]@0@mmJ4mmJmmmJ4mmK6mmJ4
ihBUikF4aZF4eXacaXb4aXAccYAkaXAcaX`0eYb4eXB40]jUQ005aZfDgZFDaZFDijfDaZF<00;6[I@0
0lJUQ=J<Q=JUQ002eXB<0]J4Q009eXB<aZF4aZF4]G=2aP12aX@0eXB4eXaceZF401;gmoLOoooo4_Og
m`06aLG5XJ6Q00000000FEUIEEEE0T10@005emOGf][Jf][Jd];Bf][J00?Bd]82f][J00K:b/[8b<S:
b/[8b<S6a/J2PX82P82000f2PX:8R8S9bLW?clo2`/;Jf][GemOBd];Jf][Bd];2`/:0P82TY:@00X20
P005VIVITI6ATI6AP820Y:BT00>PX:001K2`/;:b/[:b/[2`/:2PX002/[:b00>TY:BPX:2RXZ800Z2P
X0:TY:@2X:2P00NYZJT10@61PH6ATI69RHV0P82<S8`04oOgma_oool001[oool00oO_koOgmoOgm`0>
moOg017WYHCWU8BULeZeLeYS@S6<@T:4He:4Je[W_JGge[gWaXCge/Kge[g_c[Gge[g_c[G6a[D01?OF
aP0;e/J4mmK6mmK6e/JeikfUaZf4gZF<gZfDg[FLkljeilJ400?ge/H03OOF_NNDYNNmYMjUS=JLQ<jD
NlJ4LlJ<LljDNlJLQ=JLS=JUQ=JUS002gZF<0mj]U005eYb<eZF<gZF<gZF4gZF<00;FYH`03=JUQ=J4
Q=JLQ=JLS<J]YMJUS;EkHjE22:E2<LicD]JLLmJ<La;gmoLOoooo00?alO7gmoOgmoL03_Ogm`0BlO7a
^KViZZZZMGEe>c/kFe]KHV9RGUiN@410emOGf][Jclo?f][JemOGalO7clo?`/;2clo?1=[JfP03a<C4
f][Jf][J00;0`<001K:b/Zf][K:b/[Ng]lo?c`04f][J00GGemO4a<C0`<2][JfTY:@00Y^KV`06Ti>C
Vi^KWIfMYZJVYjNWZJVY0Zf][@>b/[804j:RXZVYZJf][Jf][K:b/Zf][JVYZJNWYjBTY:NWYjBTY:JV
YZVYZH61PFa/K6ATI5iNGX20P9ZJVP0CmoOg6oooo`006_oooa7gmoL03=J4D^N]W:ecF[EcFT8H4580
:G=:@XASD^NmYOOF_NO6]No>]@;ge/H2mmJm00K>Q9C6W8CN]IcFYHC6U7_6Q002aYB400SFW8c>S8CF
Q8cNW8cNYHcN[ICW_JGWaX@4mmK600SWU:gW]IcNYHc>U7_>U7?>Q6?6S7?6U7/2cYAk00?6U03FW8c6
W8@00mJUS003g[FLeZF<gZfD00?N[I@3eZF<00_FQ8C6W8CFW8cN]IcFYHbeQ6^U@T:UDSVmFT;>Q6?F
S7/04_OgmaoooolAmoOg00WXj>RQXJ6h^;QiNGTH61Q8B4P/;2a:BTY0@4000]OGe`;?cll02][Jf];B
d]OGelo?ckNg]ifMWKNg]h20P9^KViRHV0:JVYX01h:2PZJVYZf][JZZZZf][K:b//30`005f][J00C6
a/Jk^k^][JfKVi/2VIVI00>ATI6HV9RKVi/00Y^KV`03Q8B4WIfMZJVY00:YZJT00kNg]j6QXK:b/P04
/[:b0ZVYZ@06YjNWY:BTWIfMYZJVXJ6QQXJ60Va/K003I6AT410@WIfM01?gmoLKoooo000Joooo4OOg
m`0:eY@aijfL_HA[Ld8a<B4H0240Hd8aLdY2klJ]mmK60oOF_@0CmmK6kljeklJ]aX@@]HA[Q58iLdY2
W6]B_HA[YG=JW7=SYF]B]HA[Q11JeXakcXacgZfDikfUilJ]00Cge/H03NND[NNeW=jLQ=JLLljDNlJ<
HlJLLkf4JkF<LlJLQ=JLQ<jDNlJLQ002eYb400K6Q8CN[ICN[ICN]IcN[IC6[I@2eZF<00CFW8cFW8C6
Q8C6W8@3eZF<00J]Q6^UBT:]FT:mFT;>Q6?NW8@BmoOg7ooooa7gmoL01=OGej6QXKRh^0820P8C4a<0
120P83/k>dQ8B=[JfPCGemL01l[:b/W9bKNg]i>CThJ6QU=CDdQ8B002RXZ:00YeMGEcLg<0001mOGfH
V9RMWIfGUiNb/[;0`<3GemL4f][J00g6a/Jk^k^XZ:RPX:2KVi^EUIF@T92:RXZ;Rh^MWIfVYZJ0P82M
WId00ZBTY00;WIfMZJVY/[:b]kNg/[:b^;Rh/[:bZJVYX:2PY:BTZJVY00:MWId2ZJVY00J3Ph=`L71/
K6a/K6`@412XZ:PCmoOg6oooo`006_oooa7gmoL02nM2:NN]W=JLS48H448@448Q8E8i<G]SD^o6[OOF
a^O6]@02mlje0oOF_@0@klJUg[FLaYb4LdXi[HA[BR4H[HA[HdY2:APHQ58i<D8Q[F]B[EY2YE8i[EY2
ihB41?OFaP0:ilJ]ikFLgZF<eYaccYAcQ8ac_HAS_HA[aYb4eZF<1=j]U008gZF<eYb<eYb4aYb4eZF4
gZfDgZFDgZfD0]JUS0;6W8@02]JLQ=JUS=JUS=JUS;F4Jje:@ZeJ@[eJ@/icF]JLQ1;gmoLOoooo4OOg
m`0<bLW9W9bL^;Rh00005aLG820P;2`/<C4aB4Q8f][Jclo?emOG0];BdP;GemL04Lo?clW9bKNg]ifM
W@000;^k^eeMGH>3Pd=3@`000492@X61PGAdM6a/K6ATI2PX:<W9b@04f][J00[1`L6k^k^][JfPX:2I
VIV;Rh^8R8R:RXZMWIfYZJT4/[:b00N][JfVYZJVYZJ4Q8BWYjNb/[:g]kL00[:b/P05ZJVYWIfMY:BT
WIfMY:BT00:YZJT01XJ6QWAdM6a/K6a/K0000:BTY1?gmoLKoooo000Joooo4?Ogm`0<ooooaS4@ijfD
kkFUDS4Y>BTQ@R4QHd8aLe9:kljemmJmilJ40^o>]@0CmmJmmmK6mmJmkljeeZF<gZfDaYAkYHAkFP0Q
U8B4Q7>D:APHLe9:Q00H]IbLS5Y2[EY2eYackhbU00;ge/H2mmk>00WWaXC__JGNYHcFW7?>S6^e04Ze
LeZmQ6?FYH@00mjeW00;gZfDeZF<eZF<g[FLeZF<eYb<eZF4eZF<gZFDgZfDeZF<00;FYH@02lJ4Q<JL
Q<JLQ=JUS<JLQ9acHhASBZESB/I[D/j<JmjLQ00BmoOg7ooooa3gmoL03?oook^k^hN7QkJf]P0001/K
6b@T92`/;3/k>dm?CmOGem[JfP??cll04m;Bd]OGelo?clo?cjVYZK:b/X20P3Ti>Bh^;X20P7YjNP`<
35=CDjBTY9jNWU]KFfa/K820P<o?c`02f][J0^3Ph009b/[:a<C4[Jf]X:2PUIFERXZ:OGemR8R8YjNW
00>g]kL00k:b/ZVYZJVYZ@02]kNg00ZPX:2WYjNYZJVb/[:g]kNb/[:QXJ6WYjNMWIfWYjL2WIfM00>9
RHUcLg=TI6@00Va/K003PH61Z:RXmoOg01;gmoLKoooo000Joooo3_Ogm`0BimKWFS4YDP0QaP00eXB4
ijFD0492<B4Q@R4QDS4YQ6=BklJUmmJmilJekljeiljemmJ4mmK60_OFQ00UilJ]cXbDaZFDcZf4Q240
8@0Q4240<@0802T00000[@12]G=JaR4@aZF4ihBDmmJmmmk>mlK>mnONilJ4kkfUgZF<eXakS8A[_HAS
YF=B8B4@Q4X0aX`QQ8@QQ58Q<@088D80Q492Q112Q100Q1P000:DQ00048B40<J42<J42<JD0<JDNlJD
0=JLQ=JLS<JLQ8B4LhA2@XA:@Xa[D/J4HmJ<LlJ4Ha;gmoLOoooo3_Ogm`08h^;R<30`0P82cLg=Ph>3
R8R800004A4A0b0P8003B4Q8emOGalO700;?cll00l;2`];Bd];BdP02d];B0131`L62PX:2PX:b/[8J
6QX30`</;2`0000E5AEDE5@0001mOGf1PH6YZJW?cloGemL2h>3P017Xj>S8b<S4a<B][JfMWIf0P828
R8P0000a<C5@D52@T920P8010@4410A0@414A4@10@400P000003QXJ6Ph>3RHV900>8R8P039RHV9VI
VIfMWJBTY:JVYX20P4A4A451@E1@D6ATI820P92@T1?gmoLKoooo000Joooo00CgknogmoOginOgknl:
moOg00]S@S5B8AQ:8ASWQ8cW]IcWYHb<FTYB@ST08AQ2:B6<He800^o>]@08ilJemmJmikFLkljemmJm
kljemmK6mmJm0^o>]@0EikFLeZF<g[FLeZF<]Hac_HAS]@12]G=JeZF4gYb4ijfDihBUmmJmmmk>mnON
mmk>klJUikfUgZF<eYaccXa[00:mQ6<07Je[DZE[DZF4NeY2DZF4Nb4@448a>HAB@P1249AJBV=2<Ia[
DYacHhASD[EkHlj<JljDNlJLQ<J4Q<JLQ=JLQ<JDNjf4JhAB@P1248AB@]JLQ=jUS<icDP0BmoOg7ooo
o`04lO7amoOglO7alO7a2_Ogm`0<<c<c92@T820P/K6acLg=^k^k4A4A=SHf:BTY4a<C820P@T920/o?
c`;GemL00k^k^lO7alo?c`02f][J00?GemO?cln;Rh/00ZVYZ@0C]kNgZJVYR8R8OGemR8R8OGemYjNW
Z:RXP820bLW9emOGh>3Pj>SXh>3PbLW9`<30[Jf]X:2PUIFE00:8R8P017AdM71`L8B4Q=?Cd`8410@0
3BTY:EEEEC/k>f=SHb4Q8Fa/K7=cLfa/K7=cLh61PI6ATIfMWJNWY`02WIfM00VTY:B0P81EEEE8B4QN
GUiEEEFTY:B7QhOoool04_Ogma_oool001[oool=moOg00b4JeYJ<BU2:B52611B026eLeZUDSUJ@SU:
<C40:B5B<BV<Lf<2mlje00OWa[Gge/KW_JG6S7?__JG_c[Gge/H00_ONcP0>mmK6kljeihB<ikFLgZfD
gZF<eZF4eXB4gYb4gZF<ikFDikfUilJ]mmK60oONcP0HilJ]kkfUgZfDeYb4aXacS8AS_HA[_HAS]G=J
aXac<DY2[JF]610@FU9BLdY28@0aS7]cDT8iHd8aLdY2<F=2_HAScYAceZF40]JUS0;6W8@02<JDNhaS
DV]BBU88<HAB>MJUS<j<JlicDQ;gmoLOoooo3_Ogm`8P82004APH6492@Z6QXGemOB0P82XZ:R0P81/K
6b`/;410@=;Bd]OGelo?cm[Jf/30`820P<o?c`02f][J0^3Ph007b/[:bLW9^k^k^k^k/[:bYJFUYjNW
00:XZ:P01Jf][KVi^L30`=OGem[JfP03h>3P00_1`L74a<Bb/[:TY:BCTi>8R8R0P828R8QmOGfCTi>1
PH400P00000;AdM7BTY:>c/kQ8B4=3@d>c/kBTY:FUYJPH61R8R8PH6100>YZJT2WIfM00L0001;Bd]8
B4Pa<C5CDe>1PH67QhL04oOgma_oool001[oool00oO_koOgmoOgm`0:moOg01EJ<BUS>BUB<BU2611:
40R4DT9B<BU2:C5B>C4i:B5B<BVULe[_c[Gg_KG_c[Gge/K_c[GNW8cFYHcN[ICWaX@00_ONcP;ge/H0
1nn<YNNeW=jUS=jUS=j]U=jUS=jLQ002ikFD00?__JG_aZgge/H00oONcP0@khbUikFLg[FLeZF<cYAc
aXaSaYaccXa[aYaceZF<Q8acJe9:<B4Q<B4HHcTYDQ080UY2>@0BQ6=BW6]BQ8ASaYaceZF4cYAccYAk
aXB4aYb4eZF4aYAkLdY2LdXi@P0QLd8agYb<cW=JcV=:4_Ogmaooool00o7alOOgmoOgm`0:moOg00Co
ool`<30/;2`H61P26a/K00=EEEDT92@a<C400Q/K6`03;2`/ADE5c<c<00;?cll01][Jf/o?cjRXZ;:b
//o?cm[JfP;Ph>001][Jf/o?clK6a[^k^jf][J2PX0:][Jd01ZRXZ;Vi^KVi^L30`<W9bM[JfP?Ph>00
6/K6a[^k^kNg]jVYZIVIVIFEUIRHV9FEUIRHV:VYZH^;R`<30aDE5A<C4cLg=b`/;4m?CcTi>EiNGVa/
K9RHV8Z:RYRHV861PI^KVjVYZ@:MWId02:NWY`P824Q8B3/k>b`/;4=3@hR8R861PA?gmoLKoooo000J
oooo00?gknogmoOgmoL02OOgm`0GinOWFS4QFS4YHcTY@RTQ@P0@FT8iBS4a>BTQ<B4Q024Q@RTQS7=S
klJ]mljemmJmkljemmK6kljecYAkgZfDaXB<kmK>00;gg/h00noFc^O6Q>o6[@02gZfD00SN]IcFQ03F
S7?FS7?N[ICW_JGWS:Gge/H2mmk>01Wge/K_S:GW]IcN[ICFYHc6W8C>S6_>U7?>U7_>U7>mQ6?FYHbU
LeZLLf>4DT9SBT80436<He:]Q6^]LeZ]Q6^4S7?>U7?6U7_FYH`01<JLQ008[HA[LdXiDSTa@P00HcTY
eZF<cV=:cW=B4_Ogmaooool00o7alOOgmoOgm`0:moOg00SXj>PP820g=cLP820T92@H61Pi>CT:2PX2
5ADE0R0P800@B4Q8d];BemOGemOGclo?f][JRh^;/[:bYZJVbLW9f][Jh>3P`<30f][Jclo?bLW90[:b
/P08[Jf]X:2PVYZJVYZJ/[:b`<30clo?f][J0^3Ph00If][Ja<C4^k^k/[:bZJVYWIfMUIFETI6AVi^K
VIVIR8R8ZJVY8B4QLg=cEEEE@d=3De=C<C4a0P82NGUiPh>3Rh^;Ti>CVIVIR8R800FMWId02000034a
<D=3@c0`<3Lg=h61PHN7Qooooa;gmoLKoooo000Joooo3?Ogm`0?YHBUDS4Y@RTQ@P0Q@R4Q024QDS4Q
@RTQ:@P0<B4H4240DS4YQ6=BklJ]ilje00;Wa[D05?OF_OOFQ>NDQ<j4U8B428@@Jh@@LjF<0:D8HhaS
@XASDXABBYA2@YA2BXA20:E[@Zd0@/JD0<JeW>N<Y@;ge/H2ilJe00W_Q:GW]HCN]IcFYHC>Q024Q6><
Q6>4Q6?6Q7<00/J4000:eZF4aX@8aYAcaYAcQ012S8ASS11JaY`0aYAcaY@00lJLQ0?6Q8@02HB<0012
@T80<D80>D8021120;f4JjeJ@/ISDP0;moOg00?ginOgmoOgmoL01?Ogmaooool=moOg00F0P80P820P
820P820@41000R0P800800004a<C10@40000820P@410`/;2d];B0/O7a`05emOG`/;2QhN7QXJ6PX:2
008@41002820P000061PH492@UEEEF1PH5]KFf1PH0800002P82000??cloJf][Jf]X00/O7a`0=`<30
P820]kNgX:2PVi^KTI6AP820R8R8Ti>CPh>3T92@XJ6QRHV900:HV9P00h20P0P820410@02P82000FI
VIVPX:24Q8B4Q8B5QHD00XV9R@09QHF5RHV92PX::BTY92@T6a/K@4100000PH6100cgmoL00o7alOOg
moOgm`04moOg6oooo`006_ooo`cgmoL00lJU]F<i:DXQ6002@R4H00/88@12:B4Q4112:B4a8AP@:B5S
BT9kHe;N]Ic_aZgga[D00_OF_@?ge/H04>O6]MJUS=JLS=JLS:f<Q<J<Q<JDQ<J<Ljf4NlJDNkf4JljD
NmjUS>nm[No>]OOFQ0;ge/H03oO>]ONm]Nn4YNNmYMjeW=j]U<j<Q9`0@XaJ@YaJ@[EcF/JLLlJ40=jU
S=JUQ002gZF<0]JUQ0;6W8@01=JUQ<JLQ=JUS=JLS0;6W8@02mJ4Q<JLQ:f4Jf=2<CTY8DXa<C4Q0<J<
Lkf4HjeJ@/icDP09moOg00?gknogmoOgmoL01_Ogmaooool=moOg00>f][HP820K6a/00Q/K6`8P8200
200001<C4a/K6c4a<D=3@a8B4/W9bM;BdP?GemL2f][J00[GemO?clnYZJVVYZJ4Q8BKVi^VYZJJVYZC
Ti>0P802RXZ:00BKVi^][Jg6a/K7alL3f][J00oBd];<c<c0`<30`<2g]kNb/[:KVi^:RXY3@d=SHf=m
OGfHV9RKVi^UYJFWYjL00Zf][@:WYjL04hF5QIfMWJNWYjJVYYfMWJVYZHB4Q9fMWJJVYZNWYifMWH>3
Pa/K6bXZ:Q/K6a<C4i>CT`P828N7Q`0:moOg00?alO7gmoOgmoL01_Ogma_oool001[oool2moOg00Cg
inOgmoOgmoOgknl6moOg00SFa]IS>C4a8AQ2:B4i:B528B52:B4Y61P2@RTQ00Ha8B5SBT:<He;FYHc_
aZg_c[D2mmJm1?OFaP?_c[D2mmK600KFa[gg_KGFa[gg_KGFQ8Cge/H3klje0_OFaP;_c[D02?O>]Nn4
[Nnm[NNmYNN]W=JUS8`0DXAB@P:4BST07:EcFXb4HmJUS=JUS=j]U=jUS=JUS=JUQ=JUS=JLQ=JUS<J4
Q=JUS<JLQ=JUQ<JLQ<J4Q=JUQ8aSDU8a:CTY8D8Y<A0Q8LjDLlicFZeJ@/I[DYB4Q17gmoLOoooo0_Og
m`04lO7amoOgmoOglO7a1oOgm`0>dm?C4A4A820P6a/K820P;2`/820P0000820P5ADE6a/K@d=3820P
bLW90/o?c`;GemL2f][J00GPh>3Jf][?clo?clo:b/X00][JfP06a<C4c<c<a<C4b<S8c<c<f][J0/o?
c`03b/[:f][Jf][J00;?cll02=;Bd/30`<K6a/30`;Rh^:VYZI^KVdA4A09@D5001WEeMHZ:RXV9RJVY
ZK:b/Zf][@:YZJT05:6QXJBTY:VYZJVYZIfMWJVYZHF5QIfMWJVYZIfMWJNWYf9RHPP822@T91DE5C4a
<IVIV@P82861PH20P1;gmoLKoooo000Joooo0_Ogm`03mnOWmno_moOg00OgmoL04>OFig=:>D8Y8DXQ
63TY8@0Y8CTY8C4Q624@448Y8D8Q8F=:@W]SD/JLQ>NmYNO6Y@;ge[d00oOFa_ONc_ONcP05mmk>00?g
a/kgg/kgg/h00oONcP06mmK6mmJmmmJmkljemmK6mmJm0no>]@;_aZd03NNmYNneYNNmYLJUS;f4JiAJ
DXaJBW=:>F<08HAB@[EkHmJUQ=JUS003eZF40/JLQ00AcYAkaXac]HaccYAkeYb<eXB4]HacLdXi>BTQ
@RTQ<B4QDP0Y[F]B_HA[YE8i]G]SBT92017gmoLOoooo0_Ogm`;alO49moOg00GUiND0000P820K6a/P
82000Q/K6`090000820P820P;2`/@d=361PH`<30bLW9d];B00;GemL00l30`>3Ph>3Ph004h>3P00?X
j>SPh>3Ph>001>3Ph006f][JemOGemOGb/[:h>3PemOG0lo?c`;9bLT03<30`<71`L30`<K6aXR8R6=S
HeeMGDQ8B3Lg=a4A4H61PJNWY`:YZJT2YjNW0YfMW@:KVi/049>CTh^;RjJVYZVYZJBTY8^;RdQ8B000
01DE5CHf=S0`<7AdM0000861PD];Bm?Cda7gmoLKoooo000Joooo3OOgm`05HcTaHd8aDS4Y@RTQ02TQ
0092:B40224@448Y8A0Q8G=:>HASD/JLQ=j]U>N<Y@;ge[d2mmK600Ogg/kge/Kgimkgimkgg/kgimkg
a/h01?OWgP?gg/h01?OFa_ONc_OFa^o>]@;g_KD06No>]Nn4YNo6[NnmYNNmYNnm[LJeYMjeYMJUS;f4
JiAJDP1206<i:F=2<G=2<HaJBXB<LlJ<LljDNlJDNkF<LiA[@Ya[D[f4JmJUS002eYb400>]Q6]J<BU2
:B400T8Y8@06@R4@Q4Xi[F]B_HASYG=J40P04OOgmaooool>moOg00@i>CT/;2`P820K6a/2820P00T0
000P820K6a//;2a8B4PL71bb/[;4a<CBd]800]OGe`04f][Jh>3Pf][Jh>3P0^SXj003h>3Pj>SXh>3P
00?Xj>P4h>3P00CJf][0`<3Jf][?cll2c<c<01K?clo0`<39bLW4a<C0`<36a/K0`<2j^[ZYZJV:RXYS
Hf=MGEd30`<k>c]3@d=MGEf;Rh^HV9RCTi>HV9R;Rh^1PH42K6a/00J8R8RTY:BVYZJTY:B3Ph<`<302
820P00LT92@K6a]@D500001eMGEDE5B9RHT04OOgma_oool001[oool=moOg00ESBT9cBT9B>C52:B40
:B400T8Y8@08<B4H:APH@P0QHdY2Q6=BaYAkeZF<ilJU0_OF_@;ge/H3mmk>0oOWgP0<mlK>mnONmmk>
mmk>mnONmlK>mnONmmk>mmK6mmJmmmJ4klje0_OF_@0>klJ]khBUklJ]klJ]kkf]klJ]kkf]ikfUg[FU
gZfDeYb<S01SS5Y:LdXi0V=2<@0FQ592W6]BQ6]JS5Y:W6]BQ6=B]HA[eYb<eZF<eYb4aY@0YG=JDS4Y
<B4H@RTQ@RTa@R4@DR4HS34YNc4QHcTY<@004OOgmaooool>moOg00m2@T8a<C4P820P820K6a/P8200
000<30`P820k>c]3@d<H61RYZJW9bLWBd]800]OGe`03f][Jh>3Ph>3P00;Ph>02j>SX00?Ph>3Xj>SX
j>P00^3Ph008j>SXh>3Pj>SXh>3Pf][Jd];BemOGclo?0]OGe`0>bLW9`<30bLW9bLW9a/K6bLW9a/K6
`<30^[Zj/[:bYZJVPh>3DE5AB4Q80S/k>`0GEEEEGEeMH61PGEeMK6a/MGEeK6a/QXJ6X:2PY:BTWIfM
Vi^KMGEe;2`/000092@T:RXZ6a/K92@T@410=cLgE5ADY:BT017gmoLKoooo000Joooo3?Ogm`06e]KW
Ld88LdXiHd80DS4Q024Q0T8Y8@0;02TQ010@@P0QHdY206=BYHASU8B4aXB4mmJmmmJ4mmJm00?ge/H2
mmk>00?ga/kgimkga/h01?OWgP;ga/h01?ONc_OFa_OFa^O6Q0;Wa[D04nO6YNo6[NO6[NnmYNn4YNn4
[No6[NN4YNNeQ>NmYLJUW=jeW<J4Q9B428@@08@@DS48<@1208A24002Q59200B425:40036W8C6S8@2
aYb400b4Q7<0@P128B52:B40:B528B4a8@0000124012<BUB02T@000AmoOg7oooo`ggmoL01mCDe4Q8
B0/;2b0P800002`/;20P800200000RPX:009@d=30P82Q8B4/k>c`<30emOGd];B`<30f][J00;0`<04
h>3P1>SXj0CPh>000m[Jf/30`<O7a`02alO700C=cLg9bLW9bLW4a<@2`<300/W9b@0PP820`<30/;2`
]kNgXJ6QR8R84A4A0`<320P80000DE5A@410DE5A0`<36ATIR8R8Q8B4P820WIfMVi^KPh>36ATI820P
0000820P6a/K4a<C410@820P:2PXD51@RHV94OOgma_oool001[oool<moOg00K6]KEcBSU[DTYcBSUS
@S5B<B44@RTQ00M28B5S@S5cBT:LLf?6U7_>Q8Cgc[D00_OF_@06mmK6mmk>mmK6mmk>mnONmmk>1_OW
gP06mlK>mmk>mmk>mmK6mmJmilJe0^o>]@;_aZd01^nmYNo6[Nnm[No>]NnmYNn4[@?W]I`01=jeW=jU
U=JUS=JUS0;FW8`00ljDNlj<Q<j<L`03aYb400SFW8C>S8CFW7?6W8B4Q6=J<BUB<BU2:B42>BTQ00H8
8B4a8B4a8AQ2:B5B<BU:400AmoOg7oooo`ggmoL01[Vi^DQ8B4Q8B3/k>c4a<B`/;0@P82002b`/;3/k
>d92@YRHV;:b//W9bM;Bd]OGem;Bd^3Ph=[JfP02h>3P00?Xj>SPh>3Xj>P01NSXj0?Ph>000m[Jf]OG
elo?c`02clo?0/W9b@07a<C4bLW9a/K6clo?a<C4bLW9PX:200:k^k/2]kNg00BPX:2YZJVVYZJVYZH2
Vi^K01FCTi>MWIfMWIfTY:BMWIfTY:B0P82MWIfCTi>3Ph<`<30/;2`0000K6a/Z:RXK6a/E5AD0000/
;2`Z:RY;Bd/04OOgma_oool001[oool<moOg00JDQ8AcBSUcBSUS@S5B>C52<C42@RTQ00=:8AQB>C52
8B400V=2<@04Q6=B[HA[aZF4klje0_OF_@;ge/H2mmk>00Cgimkgg/kgg/kga/h4mnON00Oga/kgg/kg
g/kgg/kge[gWaXCge[d00_O>]@04kkfUklJ]kkfUklJ]0^nmY@;W_JD02NNeW>NmYNN]U=jUU=jeW=JU
S=jeW=j]U=JUQ002eZF<0]JLQ006eXB4eYb4eYb4eYb4cYAkU0120U8a:@05>BTQ@RTQ>BTQ424Q>BTQ
0092:B400c4Q66=20<J][@0@moOg7oooo`ggmoL00hV9RDQ8B3/k>`02<C4a00lZ:RXP820P820a<C4/
;2`P820k>c/J6QZ3Ph>YZJW4a<C?cloGemOBd];Jf]X00n3Ph003j>SXh>3Ph>3P00GXj>P4h>3P00?7
alOJf][GemL00];BdP04a<C4bLW9a<C4bLW90/C4a0;0`<001k^k^l30`;Jf][Ng]k:b/ZVYZKNg]`02
/[:b0ZVYZ@:TY:@01jNWYjJVYZBTY:BTY9^KVh^;RfATI002;2`/00<0000K6a//;2`00Q/K6`05820P
4a<C>c/kBd];/;2`013gmoLKoooo000Joooo2_Ogm`09mno_moOgQ6=BHd8aJe9:Le9:HdY2@STaDS4Y
00A2:B401e8a:F=2<G=:>HaSDZF<8No6[OO>]@04mmK61?ONcPGgimh01oO6c_ONc_ONc_OF_No>]OOF
_No>]@03klJ]00?__JG_aZg_aZd00^nmY@08ikF4ikFLikfUikfUijfLa[FLgZfDg[FL0]j]U00GeZF<
eYb<eYb4eYb<eZF<eXB<aYb4eYb4aYb4]Hac8D8HDSTa@RTQ>BTQ<B4QDSTa8@00<B4Q>BTQ@RTQ:APH
@P0a[Ib<013gmoLOoooo2_Ogm`0:lO7amoOgmoOgHf=S2`/;Cdm?@d=3<C4a>CTi;2`/120P8007;2`/
20P8HV9RRh^;`<30bLW9d];B00?Jf]X4h>3P1^SXj0?Ph>001=OGelO7amOGelo?c`?9bLT00lC4a<W9
bLW9b@02a<C400S1`L6k^k_0`<30`<2h^;Rk^k^b/[:g]kL2/[:b0ZVYZ@0?Y:BTYZJVZJVYZJVYYZJV
WIfMQ8B4Rh^;MGEeB4Q8<C4a820P4A4A<C4a30`<008E5AD01@0000`<32XZ:S/k>iFEU@0@moOg6ooo
o`006_ooo`cgmoL04g=B@V=2<F=:@V]BBV=:@U80<E8a:D8Y8C4Q648Y8D8Q8D8Y8F=2<G=:>G=:@X@Q
0>o6[No>]OOF_@03mmK600Ggg/kgimkgimkgimkga/h00oOWgP05mmk>mlK>mmk>mmk>mmK600;ge[d2
klJ]00?__JG_aZg__JD00^nmY@04klJ]kkfUikF4ikfU0^NeW005gZfDgZFDgZfDg[FLgZF<00GFYH`4
aYb400W>U7^]Q6]J@Q12:B4a8APa8B5:<C4Y61PQ00000S4Q60058A0@<B4H@P0QYHAkoooo00ogmoLO
oooo3OOgm`08Cdm?0`<3Bd];@d=3<C4a>CTi;2`/00000R0P8009;2`/820P20P8BTY:Lg=cYjNWbLW9
clo?d];B00;Jf]X2h>3P0nSXj005h>3Pj>SXj>SXh>3Pj>SX00?Ph>000m[Jf]OGemOGe`02bLW900?4
a<C9bLW4a<@00/C4a004bLW9a<C4^k^k`<300[^k^`05/[:b]kNg/[:b]kNg[Jf]00:YZJT00jf][JVY
ZJVYZ@04WIfM016IVIV3Ph=JFUXi>CTP820C4a<0000<30`E5AD<30`C4a<0000C4a</;2`k>c^4Q8Co
ool03oOgma_oool001[oool7moOg013ginOgmoOgmoOgmoOginMS@T9SBP1[DTYS@T9S@PQ2001B<B52
:B5B<BTa8AQ28@02DS4Q00MSDTX0He:404;N[ICWaZGga[GgeX@00_OFaP;gg/h6mnON00Cgg/kga/kg
g/kgg/h2mmK600?WQ8C_c[G_aZD01NnmY@?W]H@00nNeW<JUU<JUU002gZFD0]j]U006gZF4eZF4eZF<
eZF4eZF<eXB40/J4Q009aY@0aYAk]HASQ6=B@P0Q02TQ42TQDS4Y:@P0008Q00001R404240634Q03TY
8D808HAcHa3gmoLOoooo2?Ogm`0;lO7amoOgmoOglO7amoOg@T92@410@d=3B4Q8@d=3<C4a008P8200
31<C4b0P820P820P800005YJFUADE8R8R;:b//30`=;Bd][JfP;0`<02h>3P1NSXj003h>3Pj>SXh>3P
00;Ph>001L30`=;Bd/c<c<o?clW9b@05a<C40X20P004`<30^k^k/[:b/;2`1;:b/P:PX:02ZJVY00FQ
XJ6PX:25QHF4Q8BPX:000X20P008H61P20P8;2`/00004A4A20P810@45ADE0`0000046a/K820P<C4a
I6AT4?Ogma_oool001[oool<moOg00=c@S5S@S5cBST00V=:@P03BT88FT8iDS4Y009B<BT02T8Q8E8a
:D8Y8F=2<G=:@X@0B]JUQ>NmYNo6[OOF_@?ge/H01?ONc_OWg_OWg_O6cP?gimh00oONc_O6c_ONcP02
mmK600C_c[GgU;Ggc[G__Jd2kkfU01;W]Ic__JG__JGW]Ic_]JGW]HCW]IcN[ICW[ICN[ICNYHCFYHcN
[ICNYHcFYHcFYHCFW8CFYH`2eYb400O6U03>U7>eS7>LLf=cBT9S@P1B>C400STY8@09<B4Q<B4H:APH
8A0@:APH<B4H>BTQ8@0@knOW013gmoLOoooo3OOgm`05B4Q820P8@d=3@d=3Bd];008i>CT2;2`/00XP
820/;2`/;2`P821:BTYSHf>:RXZWYjO0`<31`L44f][J00CPh>3Xj>SXj>SPh>02j>SX00CPh>3Xj>SP
h>3Ph>02f][J00C<c<cGemOBd];6a/H2a<C400Vk^k_4a<C4a<Bk^k_1`L6k^k^0P82b/[:f][H00[:b
/P07ZJVY/[:b[Jf]ZJVYYjNW[Jf]X:2P00>TY:@02Y^KViVIV@<30dY:BT=3@c/k>c4a<A/K6a4A4A<C
4`8<30`01P@4100001/K6a<C4c/k>nSXj13gmoLKoooo000Joooo3?Ogm`03He92Je9:LdXi00=[DTX0
3F=:@UXa:E8a:E8a:A0Q258a:E8i<G=:>HAB@X`0@/j<JnNeW>o6[@02mmJm00?ge/Kgg/kge/H00_ON
cP?gimh00oONc_OWg_O6cP02mmk>0_OFaP05mmJmkkfUklJ]kkfUikfU00;W]I`01NneYNnmYNNeW>N]
U=j]U002ijfL0]j]U003eZF<gZF<eZF<00;FYH`02]JLS<jDNlJLQ=JLQ<J<0<J<LiacHhacHg=:>E80
:@<a8AP0234Q8BTH624@434Q62TH634Q8CTY8E8@017gmoLOoooo3OOgm`03Bd];B4Q8Bd];00=;Bd/0
14=3@b0P82`/;1<C4`8/;2`03@0005EEEFa/K8>3PiFEUK^k^l71`MOGen3Ph=[Jf^3Ph=[Jf^3Ph004
j>SX00?Ph>3Xj>SPh>000^3Ph007f][Jd];BemOGa<C4bLW9a<C4`<3000:k^k/01L71`LC4a;^k^kJf
][:b/P02^;Rh0[:b/P03X:2P[Jf]ZJVY00>YZJT018:2PYfMWJBTY9fMW@:CTi<0161PH4Q8B3Ti>B`/
;08C4a<02A4A4@`<30`<30@411<C4`@411/K6b`/;5ADE00AmoOg6oooo`006_ooo`cgmoL057=:@V=:
@V=:@V]BBW=:@V=B@U8i<EY2>E8a:D8Y8E8a:E8i<F=2<F=:@W=BBXAS@/J<LmjUS>nmYNo>]@?ge/H2
mmk>00?gimkgg/kgimh00oOWgP?gg/h00oOFa_OF_No6Y@02klJ]00[__JGW_JGW]IcW_JGW]Ic__JGW
]Ic6]IcW[ICNYH`2gZfD01;NYHCNYHcFW8cFYHcFW8CFQ8CFW8CFYHCFW8C6W8B4S02]Q6^LLf><FTYS
@S528B4a8B4i:C42<B4Q00<Y61PQ000Y61P00c4Q6003DQ08moOgmoOg00ogmoLOoooo3?Ogm`0:lO7a
BTY:@d=3Bd];BTY:Bd];E5AD<C4a:2PX820P0R`/;008<C4a0`<3Cdm?HV9RPH61Ti>C[Jf]a<C41=[J
fPCPh>03j>SX1>3Ph003f][JalO7bLW900;9bLT01/C4a<30`;^k^l30`;^k^lC4a0:k^k/02;Jf]Zf]
[K:b/[:b/Zf][J2PX:JVYZVYZ@:TY:@00jVYZJBTY:BTY002WIfM00V;Rh^3Ph=ADE4k>c//;2`P820E
5ADP820E5AD00P`<30065ADE30`<4a<C4a<C;2`/Cdm?4OOgma_oool001[oool:moOg00KgknogmoMS
@T9SBT9S@S5SBT82Je9:0V=:@P92:B404U8a8E8i<F=2<EY2>G=:>IA[@/J<LmJUS>NmYNo>]OOF_OOF
Q?OFa_ONc_OWg_ONc_OWg_ONcP?gimh01_ONc_OFa_ONc_OFa^o>]ON<]@G__JD01NNmYNNeW>NeU>Ne
W>NUU002g[FL0]j]U003eXB<eYb<eZF<00;FYH`00mJ4S=JLQ=JLQ002aYb400J4Q6^ULeZULeYcBSUS
@S5B<BT2>BTQ00YB<BTi:B52:B4a8B4a8APa8B4i:B52:B408@3oool@moOg7oooo`[gmoL01_7alOOg
mnSXj4=3@`<30d=3@`=;Bd/03D=3@`00020P834a<B`/;34a<CTi>DQ8B6a/K861PI>CTjVYZL30`002
emOG0][JfP;Ph>02j>SX00?Ph>3Xj>SXj>P00^3Ph005f][Jh>3Pf][Jc<c<d];B00G4a<@00l30`;^k
^kVi^@02^k^k00Jf][Jg]kNb/[:b/[:][JfVYZH3ZJVY00>VYZJYZJVTY:@00YfMW@05V9RHQXJ6MGEe
@410>c/k008/;2`26a/K00X820PP820K6a/E5ADC4a<A4A4P820/;2aRHV;oool@moOg6oooo`006_oo
o`OgmoL06oOWioOgmoOgmoOgmoOWif=2@TY225X0:F=:06=BBV=2@V]BBV=20480048Y8E8a8E80:E8i
<F=207]SDXAB@ZEc@Xb4HmjUQ>o6[No>]NO6Q002mmK600?gg/kga/kga/h01?ONcP04mmK6mmJ4ilJ4
mmJ40^o6Y@04ihBUkkfUikF4ikFD0^NeW00<ijFDikFLikFLijFLijfDaZfDgZFDgZfDeXB4eXB<eZF<
eXB<0/JLQ00EeYb4aYb4aY@0Q8AcY@1246=2Ld92DT8iDS4Y024Q02TQ024@@R4Q<B4Q8@00:@P04000
8A0@:APH02TQ@T80017gmoLOoooo2?Ogm`0=lO7amoOgmoOglO7ah>3PBTY:0000@410Bd];@d=3E5AD
Bd];0000008P8200334a<BPX:00005YJFVATI5EEE@410HR8R820P<o?clO7am;BdP;Jf]X6h>3P00G0
`<3Jf][Bd];:b/[Bd]800/W9b@;4a<@01H20P;Vi^K^k^k^k^kRh^003^k^k00R`/;2b/[:b/[:b/[:R
XZ:XZ:RYZJVPX:02Q8B400ZTY:B4Q8BIVIV8R8R3Ph<10@50@40820PP820X:2P2000000<20P800004
10@00PP82005000010@4000020P8h>3P017gmoLKoooo000Joooo1oOgm`0<mnOWmoOgmoOgmno_moOg
Q7=SHdY2FT8iLdXiHdY2Jd92Je9:0V=:@P0:DS4Y8@0QFT8iHdY2DSTaLdXiLd92W6]B]G]SeYb40^o6
[@07mmJmmmK6mmK6mmK6mmk>mmK6mmk>00;ge/H01?ONc_OFQ?OFa_OFaP;_c[D01nO6YNnmYNNeW>Ne
W>N]W>NUU>NeW002ijfD00WW[IcWYICW[ICW[ICW[IcFW8cFW8CFYHcFW8`00]JUQ0;FW8@01ljDNlJ<
LkF4Jha:@W=:>F=:@V=2<@02@RTQ0STY8@8a8B401bTH6100024@42TH634Q658a:HAcH`0AmoOg7ooo
o`SgmoL00o7alOOgmo7al@02moOg00E_Kfl10@58B4Q3@d=JFUX00T];B`0=@d=3;2`/6a/K>c/k>CTi
0@41B4Q8Cdm?FUYJK6a/PH61P820bLW900;GemL2f][J00O0`<3Jf][Ph>3Ph>3Jf][0`<3GemL00m[J
fP04clo?`/;2bLW9a<C40[^k^`:h^;P01K^k^kJf][Jf][Rh^;^k^`02][Jf00Fh^;RVYZJXZ:RPX:2V
YZH00ZNWY`:TY:@01h20P9>CThJ6QVa/K5eMGDQ8B0<30`03820P0Q/K6`085ADE30`<5ADE000010@4
0000;2`/K6a/4_Ogma_oool001[oool<moOg00NDLg=cDTYJ@SUS@S5J@SUS@T9[DTX00UY2>@0=Je9:
424QHd8aDSTaHdY2Hd8aLd92Q592[HA[aXacikFLkljeilJe00;ge[d2mmK600KgeXCge/Kge[gge/Kg
e[gWaX@2mmJm00Sg_KG_aZg_Q:G__JGW[ICW]ICW[ICWYI@4ikFL00CWYHCW[ICN[ICN[I@2gZF<00[F
YHCFYHcFYHcFW8C6U03>U7^eS7>]Q6^ULeX0BT82Hd8a00IB<BU2:B4i:B4i:B52:B4i:B42<B4Q00DQ
410Y61Pa8AQB<BUcBST04_Ogmaooool=moOg01=gMgL92@Tk>c/i>CU;Bd]3@d=;Bd/i>CU;Bd//;2`K
6a/k>c/10@4k>c]JFUY:BTYEEEF3Ph>CTi<00/o?c`?GemL2f][J00KGemOJf][GemOBd];?cloJf]X2
emOG00S<c<c9bLW4a<C4a<Bf][Ji^KVf][Jh^;P4^k^k00Bi^KV`/;2b/[:b/[82[Jf]00jUYJFYZJVY
ZJVTY:BMWIfKVi^;Rh^3Ph=eMGEMGEe:BTXk>c/X:2PP82036a/K00TP820A4A4E5AD<30`410@<30`0
0018B4Soool04_Ogma_oool001[oool<moOg01JDLg=kHeYJ@SUS@S5SBT9B@PQkHeYB>C5SBT9J@SU2
8@Q2:B5J@SU[DTYB>C5SBP1cBSVLJe:eNf?FYHcW]IcWaZd2mmJm00?_c[Gge/Kge[d00oOFaP0:mmJm
iljekljemkfeklJ]mlJ]ihB4ikFDijfDikFL0nNeU004gZfDijfDgZfDaZF40mjUS004gYb4eZF<eZF<
eYb<0]JUQ00;aXAcaXac_HA[YG=JS5Y:0492FS4YDS4Y@RTQ<B4H<B4000@i:B401S4Q8BT8024@43TY
8EY2>G=:>A;gmoLOoooo3OOgm`0?MgMg6ATI>c/k@d=3>CTiCdm?GEeM0@41>CTi6a/K;2`/820P2@T9
<C4a@d=30098B4P016a/K861PK^k^lW9b@?GemL00l[:b]OGemOGe`02f][J0];BdP;?cll00lc<c<W9
bLW9b@02^KVi00>f][Jk^k^i^KT00[Vi^@05/[:b][Jf/[:b/K6aX:2P00:][Jd01:RXZ:VYZJVYZJJV
YP:WYjL02I^KVi>CTh:2PWEeMEeMGEEEED=3@c0`<20P80024a<C11/K6`065ADE6a/K30`<10@46ATI
B4Q84oOgma_oool001[oool7moOg00?ginOgmoOgmoL00_Ogm`0;]IBDS7=[HdY2HdY2Je9:Hd92Le9:
HdY2Hd8aFT8i@P0Q009B>C42HdY200QB@PQ[DTZ4He:ULe[>U7_FYHCWQ9C_aZd2klje1OOF_@;_c[D0
4?O6[OOF_No6[NnmYNN]Q>NeW>NeU>N]U=jUS<J]U=jUS=j]U>NUS>N]U<JUS=jLQ0;NYH`00mjLS=JU
S=JLQ002eZF400S>U7_6U02eQ6^]Q6^ULeZ4DT9S@S5B<BT2@RTQ00`a8APa8@0a8AQ2:B4i:B4a8B4Y
61P0410Y61QB>C5B<BV4JeXBmoOg7oooo`SgmoL00o7alOOgmoOgm`02moOg00RNWYi3@d=3@d=;Bd]3
@d=;Bd]?Cdl30`<2>CTi00lP820a<C410@53@d<i>CU?Cdm;Bd]NGUhA4A6WYjNk^k_?clo9bLW?clo7
alL01=OGe`0CalO7clo?clo?cLg=emOGbLW9a<C4][Jf^k^k^KVi][Jf[Jf]/[:b[Jf]/[:b/K6a][Jf
/K6aZ:RX00:][Jd00jZZZZf][J2PX002YjNW00ZKVi^MWIfHV9R2PX9eMGEEEEE8B4Pk>c//;2`P8202
4a<C00XE5ADC4a<P820A4A4<30`410@0000<30`P821SHf<CmoOg6oooo`006_ooo`cgmoL05]JeaYAc
Jg=BBV=2<F]BBV=:@W=BBW]SFU8i<F]BBU8i<E8a:E8i<EY2>F]BBV=2@V=:@W]SDXaJB[F<LmjUS>Ne
Q0?_aZd2mmJm00G_c[Gge[gg_KG_c[G_aZD00^o6[@;__Jd02NNeW>N]U>NUS>N]U>NUS=j4Q>NUS=jL
Q>NeU002gZF<00GFYHCFW7?FW8CFW8cFYH`00]JLQ00;aYb4aYAkQ8Ac[HA[W6]BS5Y:LdXiDP0YDS4Y
@RTQ<B4H008Y61P2<B4H0R4@408H4100134Q658i<EY2>KFLW1;gmoLOoooo3OOgm`04a<C4@T92>c/k
Bd];0T=3@`03Cdm?4A4ABd];008a<C402b`/;34a<D];Bd=3@d];Bd=3@eYJFPT92Jf][K^k^l30`002
bLW900S1`L7GemOGemO?cloGemO<c<c9bLW?cll2bLW900_6a/J2PX:k^k^f][Ja/K6f][Ja/K6XZ:Ra
/K6XZ:Ri^KT00Zf][@08YJFUX:2PY:BTYZJVZJVYX:2PY:BTWIfM0YRHV003Rh^;0000GEeM0098B4P0
0c0`<2`/;000000330`<0Q<C4`0710@40000000000004a<C<C4aWYjN01?gmoLKoooo000Joooo00?g
moOginOgmoL02_Ogm`0^Q000Ld92Je9:HdX0@T80HdY2LeYBHdY2Hd80@R4QDS4Q@S4QBP0a@T80@T88
@T8aDP00LdX044Y2S01:Q000aX@@aY@HaZF4cXBUcXB4klJUihbUa/JeihbUkhBUikF4klJ]ihBUikfU
aXB4eYb4eXB4gZF<eXB4eYb4eZF4gXB4gYb4gXB<eXB40]JL000BeYaceX`0aX@0aYAkaXAcQ8AS]HAS
YG=2Q59:Q492LdXiHd8a@R4Q424Q<B408@0H8@0@8@0H0RTH60078A0@610@610@0000DS4YDSTa034Y
01?gmoLOoooo00?gmoOalO7gmoL02oOgm`080000Bd];@410Bd];0@41@D51@4100`<30b0P800>:2PX
0@41Bd];2@T9<S8b20P8B4Q80@41410@RHV9Ti>CVi^KP820QhN70/W9b@?0`<003<W9bH20P<W9bL30
`820P8f=SJ2PX:BTY:f][JBTY:2PX:FUY@BXZ:P3X:2P0XB4Q009V9RHT92@PX:2PX:20@41MGEeA4A4
B4Q8>c/k008P820010P820000000000000<<30`3000000<410@/;2``<3005?Ogma_oool001[oool=
moOg00G>_LJ4JeYcDTYJ@SUS@T800V=:@P0MLeYBFT8i@P0QDS4Y>BTQJe9:FT8iBT88Je9:Le9:DSTa
LdY2Nf=BQ6=B[G][]G]SaYAkgZfDaX@8gZfDg[FUgZfDg[FUg[FLgZfDikfUgZfDeZF<Q8AS00:mQ6/0
2/jDLlj<JmJ<0<j<JmJLQ<jDLmJ<LmJ<0=JLQ=JLL`;>U7/2aXac00^mQ6^eQ6^]Q6^<BT:4DT9c@S5S
@S5B<BU2:B4Q410a8AP012TH60058A0@610@610@610@01P@0092:B400noWioOgmoOgm`0AmoOg7ooo
o`kgmoL01451@Dm?CcTi>D];B`93@d<00d10@3Ti>C/k>`02;2`/00<;2`/i>CTi>CT00T];B`03Cdm?
0000FUYJ009NGUh02820P861PI2@T9RHV:VYZK:b/[Zj^[:b/P:g]kL01K:b//30`;:b/XV9RHJ6QP02
RXZ:00ZIVIVEUIF4Q8BEUIFTY:BIVIVJVYZMWIfTY:BPX:02Vi^K0Y>CT`08RXZ:QXJ6Ph>3K6a/GEeM
@D51>c/k;2`/0R0P800310@4000030`<00<<30`01@@41000000000`<334a<@02820P5?Ogma_oool0
01[oool=moOg00[ooon<Lf=kHeYSBT9S@P1S@S5SBT9[DTYSBT920242DS4Y0U8i<@0<He92Je9:HdY2
Je9:LeYBNf=BQ6=2Q6]JYG=JU7]c]HacYHA[0[F<L`09]HA[]HacaX@0cXb4eZF<aYAk[HA[YG=JW6]B
00:ULeX01kf4HhB4Hkf4Jlj<JlJ<LljDNlj<J`03aXac00nmQ6^eQ6>eNf>eNf>LLf><He:4DT9cBSUS
@S5J<BU2:B40:B4Y61Pa8APY61P00R4@40@H41001BTH648a8D8Y8HaSD_ooo`0CmoOg7oooo`kgmoL0
1Va/K5eMGD=3@c/k>dm?Cc/k>`93@d<04R`/;3/k>b`/;20P834a<EADE4Q8B4];Bd=3@d10@5YJFV=S
Hfa/K6=SHgEeM@<30hJ6QX>3P`:;Rh/02H:2PYRHV:NWYi^KVjVYZIRHV0410GEeMFa/K002MGEe00R8
R8R:RXZ:RXZEUIFCTi>KVi^EUIFATI42Ti>C00J:RXZ;Rh^0P821PH5cLg=RHV82EEEE00L820P`<30P
820P820K6a/<30`000000`@410<000001@`<32XZ:R`/;20P869RHP0DmoOg6oooo`006_ooo`kgmoL0
1:f<Q8A[FV]BBTY220=SBT801f]BBU80:DXa<E8a:F=2<F=:@V=2@P02LeYB01Q[DTYkHeYSBT9cFU9k
He:<He:LLf>LJe:DLf^ULeZ<Lf>LLf>ULeZU05;FYHBeS7>]Q6^LLf>LJe:<He:DHdZ<He:ULe:eLeX3
_HAS00c>S6^mQ6>mQ6^]LeZeNf>eLeZe06>]LeZLLf>LJe:<FTX0@P02FS4Y00AB<BU2:B408@0a8AP2
:APH00<Q4100410H41000aP@4004DS4Y02TQDS4YkmK>5?Ogmaooool>moOg00F5QHESHf=;Bd/i>CU;
Bd/00T=3@`05Bd];=SHf;2`/:RXZ:2PX0093@d<01D];BeADE5ADE4U9BD=3@`02E5AD00=JFUYRHV9P
H6000W9bLP0?MGEeK6a/LG5aMGEeRh^;YjNWRh^;Ph>3H61PK6a/HV9RI6ATHV9RLg=cOGem00>8R8P0
3iFEUHR8R8Z:RWUiNH61PGemOHJ6QP410G=cLfa/K5eMGEEEED=3@c0`<2`/;002820P0Q<C4`0330`<
10@410@400@000001B`/;1/K6b0P82`/;=;BdP0DmoOg6oooo`006_ooo`kgmoL06MK>gYAkLf]BBV=:
@V]BBV=BBU92>G]SDU80:E8a:DXa<E8i<F=2<F=B@W]SFUYBDV=:@W]SFXA[FW=2DXaSDZEcFW]SDXA[
FXASDP02S6=B00F<FTZLJe:4DTZULeZ]Q6/00ZEcFP07Q6=BQ592Q592S5Y2Q592U6=2YG=B00:]LeX0
0kEkHjEc@ZEcFP02YG=J00BLJe:4He:LJe:LJe82Q59200YS@S5J<BUB<BU2:B528APY200Y61PQ410Y
61PQ4104610@00@Y61Q2:B488B5S>C4EmoOg7oooo`kgmoL00m?CdgMgMd];B`02@d=300A;Bd/0001J
FUXi>CT2;2`/00hP820k>c]DE5A;Bd]MGEe7AdM1@D5SHf=MGEeDE5ARHV9eMGE2@T9NGUh3HV9R00Q<
C4aMGEeeMGEeMGF3Ph=eMGEQHF5NGUh2EEEE00AKFe]EEEETI6AcLg<2NGUi0X61P@05LG5aMGEeMGEe
K6a/MGEe009/K6`2EEEE00A8B4Pk>c/P820P82026a/K0P`<308410@5000000@P820Z:RXK6a/i>CTE
moOg6oooo`006_ooo`ogmoL058bDY@1BBV=2@V=2@TY2249226=BBT88010Y8E8i<DY226=2@W=2DV=B
@P1:DW=2DV=:@W=2BP1S@XASDP80He802P12@U9207=BBU92>F=2@W=2@P12001240QSDP1:609S@T80
158@201205920012>@80@P001Q1:4112411241120012411:40D0@P001f=246<8:D8Q8D8Q8A0Y8C4Q
8B4060028@0000/Y61P841004100410H410841000012:B4@8B40026]S8@05OOgmaooool?moOg00>L
W9a?Cdm3@d<00T=3@`0720P8B4Q8@4100@414A4A0@41@d=3009DE5@3@41000m=CDe8B4Q2@T9RHV92
@T90@418B4P92@U?Cdl820Q2@T8A4A55ADE8B4Q2@T800T10@004@d=330`<4A4A20P80Q4A4@076a/K
B4Q8@410@410B4Q8@410B4Q8008K6a/01B0P8000014A4AXJ6P000002820P00H0000A4A40000410@C
4a<410@7000000@410@A4A4820R=SHdEmoOg6oooo`006_ooo`ogmoL01NONiiB4Q6=2@V=:@V]BBP02
HdY200IS@T9SBT9J@SU[DTYkHeX0BU82Nf=J00I[DTYSBT9[DTYcBT:4He:4DT82LdXi00M2@P1J@SUB
>C5B>C5SBT9B02UcDTX00f=:@P03DT8iFT8iDS4Y009B>C400e8a:EXa:EXa:@05Hd8a00]S>BUJ<BU2
025B>C5B<BUJ<BUB<BT@:B52:B4a8APi:B4012TH60<H41001R4@448Y<CTY8D8Y8EXa:D92@QKgmoLO
oooo3oOgm`03h^;RP820Cdm?00E3@d<01T];Bd=3@`T92EeMGEADE6=SH`9MGEd03d=3@d];BdY:BTY:
BUiNGUEEEDQ8B3Ti>D=3@cTi>C4a<@410CTi>B`/;4m?C`02@d=300@20P8i>CTi>CT/;2`2<C4a00</
;2``<30`<3001C/k>`0;=cLg<30`>c/k<30`;2`/<30`;2`/<C4a6a/K00006a/K00@<30`4000000H4
10@T92@0000`<313@d?@d=0FmoOg6oooo`006_oooa3gmoL03<J][@1B@V]BBV=2<F]BBU92>F=2@W]S
FV]BBUY2>F]BBP1B@PAkHeX027=JDW=2@W=:>F]BBW=:>G=BBT8806=:@P9B@ST00f=:@V=2@U8i<@02
HdY200AS@S52<C5B>C5:<C42@RTQ00IB<BU2:B52:B5J<BU2:B5B<B44DS4Y00e28B52:B5B<BU2:B5B
<BU2:B4i:B4a8APi:B4Y61PQ410H410Q41000aP@408i:B40158a:C4Q8EXa:JF4LaKgmoLOoooo4?Og
m`0=/;2`MgMgBd];Bd];2`/;=SHfB4Q8@d=3GEeM2@T9Bd];K6a/B4Q800=MGEd01eADE5YJFTm?CdQ8
B4];BdQ8B34a<@02@d=300Df=SH20P9;Bd]3@d<a<C400T=3@`04<C4a:RXZ<C4a:RXZ0R0P8007;2`/
820P820P<30`820P;2`/820P00</;2`2820P00</;2`P820/;2`00R0P80054a<C6a/K30`<10@430`<
00D000026a/K00<410@`<327QhL05oOgma_oool001[oool@moOg00SFa/hQ001SBT9[DTYSBT9SDTYS
@T9SBT82Nf=J00^<Lf]B@Q1cFU9[DTYJ@SUB>C5[DTX0@T9S@S5[DTYcBT800V=:@P9J@ST01F=:@W=B
BT80<DXa<E92>@03DS4Y0T8Y8@8i:B42@RTQ00UB<BTi:B5B<BU2:B4i:B52:B5B<BU2:B528B400T8Y
8@04<B4H@RTQ<B408A0@0S4Q600<:APH210@8A0@610@:APH610@210@>BTQDSTa<B4QDS4YYHB45oOg
maooool@moOg00?:b/ZTY:A;Bd/00T=3@`07B4Q8Bd];@d=3@d=3GEeMKfm_>CTi009DE5@024];Bc4a
<D];Bdm?CeiNGS/k>d];Bd92@P93@d<2>CTi00E3@d<f=SHZ:RXZ:RXf=SH00b`/;08P82026a/K0R0P
8007;2`/6a/K;2`/820P0000820P;2`/00@P82002Q<C4b0P81/K6a<C4`0001<C4``<300000`<30@4
10<000001@`<31/K6c4a<@@418N7Q`0HmoOg6oooo`006_oooa3gmoL02_O_kh@a@V]BBV=:@V]BBV=:
@U80<F=BBU8i<G=JDP9kHeX01e92>EY2>G]SFXacHg]SDV=:@V=2<@02FT8i00AB>C52201SBT9B<BT2
@RTa00Y20352:C5B<BU2:C5B<BT0:B4i:B4a8B4i:B4a8B42>BTQ00I2:B4a8AQ2:B528B52:C4a8AP2
>BTQ00L08@0a8B52:B4a8APa8B408B4i:B400bTH6005010@610@610@610@:APH008i:B42@RTQ00><
He;_inOgmoL05_Ogmaooool@moOg00CalO71`L5bLW9;Bd/2@d=300@a<C4i>CU8B4P@4103GEeM00Pf
=SHi>CU<C4aJFUY3@d=:BTXk>c/i>CT2<C4a0T=3@`06;2`/92@T=SHf:RXZ92@T;2`/0R@T908K6a/0
0aDE5A/K6aDE5@026a/K00HP820C4a<P820P820T92@C4a<26a/K00PC4a<0000P820C4a<E5ADP820E
5AD820P230`<00D410@000000000000<30`00a/K6`8P82000nSXj?OgmoOgm`0FmoOg6oooo`006_oo
oa7gmoL00lj<aW=:@V=:@P02Je9:00Q:@PQSBT9SDTYB@SUSBT9c@U9kHeYcFU82He9:011J@SUS@PQB
>C5B>C5SBT9J@SU:035J@SU2<CU2:C5B@SU20012:C5B<BTi:B52:C43>BTQ00Xa8B4a8APa8B4a8B4i
:B4a8B4i:B4a8@1B<BTY61P2<B4H00P08@12:B4a8APa8APY61Pa8@0a8APa8B42:APH00T8410H410Y
61Pa8B4i:B4@8B52:B5B<BV4DT806OOgmaoooolAmoOg00CCdm?4a<A:BTY3@d<2Bd];00Di>CU3@d<0
0013@d=DE5@00UeMG@05E5ADB4Q8>CTiBd];B4Q8008a<C4030410BXZ:STi>CTi>BTY:B@T94=3@bXZ
:R@T92`/;1/K6`0000<K6a/01QDE5A<C4a4A4ADE5A/K6aDE5@8K6a/00`0000`<31<C4`024a<C00LP
820C4a<C4a<<30`K6a/C4a<A4A400``<308000001`@411/K6aDE5C4a<B0P82`/;5EEE@0ImoOg6ooo
o`006_ooo`03mnOWmoOgmoOg00kgmoL02]K6eXA[DP1:@T9204Y2249226=:@T9226=2@U9260=S@T80
4UY260QBBT880480058a:D8Q8D808EY2>D80058a8DX0<@0Q8D808@0Q8A0Q8@0Q8C4Q8B4000808B40
134Q8B4002TH6240008Y2000134Q024002T8034Q008a8B4022T8024002T8024062TH6100000@40P@
408H41002`P@400002400240634Q8B400000010Q06=2@^oWinOWi`0HmoOg7oooo`03lO7amoOgmoOg
00ogmoL03]?Cdf=SH`410@T92D];B`P824=3@`0001@D54Q8B451@D=3@d51@@T92@810@40234a<B`/
;20P820P82`/;0820R0P82PX:0800000120P80P820@4114A4@<0000011DE5@@410`<30@4108820P0
1a<C4`@410P82000014A4ADE5@P82003000000<<30`0000<30`01P00000810@4000010@46ATI2@T9
;2`/B4Q8h>3P6OOgma_oool001[ooolBmoOg00OWg^NUQ7^4JeYSBT9S@T9[DTYSDTX00V=:@P0C@T80
HdY2Je9:HdY2DT8iDS4Y@PP0DS4Y>BTQ@RTQBS4a@R4Q@RTaBS4aDSU:<B4Q@R4Q<B4Q>BTQ00<a8B40
1CTY8BTH62TH62TH62400002:APH0STY8@8Y61P2<B4Q00LY61P08B4a8B4Y61PQ410H410041000QP@
400::APH<B4Q<B4Q:APH@RTa<B4Q>BTQ0100[Ib<knOW6_OgmaoooolCmoOg00ORh^800013@d=;Bd]3
@d=;Bd]0@4000T=3@`0C=SHf@d=3Bd];0P82;2`/@d=3<C4a;2`/6a/K820P:RXZ820P92@T:RXZ4A4A
:BTY820P5ADE6a/K008E5AD26a/K0``<300310@430`<30`<008K6a/230`<0QDE5@0730`<92@T5ADE
30`<10@4000010@4008000002``<31DE5B0P81DE5@`<30@411/K6b`/;5EEEIFEUNSXj00JmoOg6ooo
o`006_oooa?gmoL01Lje_IAkLg]SDTY226=:@P02He9:00UkHeYSDTYcFU9cFU9SBTYB@SUB<BU24012
:B400STY8@0<@RTQ224Q@RTQ@RTQDT8i:APH210@>BTQ<B4Q:APH<B4Q:APH0S4Q8@8Y61P01b40034Q
8BTH634Q8E8a:A0002TH6002<B4Q00<i:B4Q000Y61P00aP@4004010@:APH<B4Q@RTa0S4Q8@06>BTQ
DS4Y@RTQHd8a8D8HimkW6oOgmaoooolDmoOg00Tc<c=JFUXi>CU;Bd]3@d=8B4QMGEe8B4Q;Bd/00UAD
E00910@4;2`/Bd];<C4a820P6a/K0000:RXZ6a/K008P820020@412XZ:P`<31/K6aDE5@`<30@410`<
308E5AD230`<00L410@E5AD<30`E5AD/;2`E5AD000000QDE5@036a/K30`<10@400@0000210@400XT
92@E5ADE5ADE5ADK6a/P820k>c]8B4QeMGGRh^8KmoOg6oooo`006_oooaCgmoL05<J][HacJf=2@V]B
BUY2>F=BBUY2>D9B@V=BBV=:@UY2>E92>CTY8D8@24Xa<C4Q8CTY8C4Q8D8Y8C4Q8@8a8AP02BTH634Q
8BTH634Q8BTH634Q8B4002TH634Q8@03:APH00<a8B4Y61Pa8B400T8a>@8Y61P4<B4Q00Ti:B4i:C4i
:B4i:B4a8B52:C4a8APY61P08B400T8Y8@9S@S400iAS@_OgmoOgm`0JmoOg7ooooaCgmoL04[2`/6m_
Kd];Bd=3@d];B`P823Ti>DQ8B4M7AdQ8B4=3@c0`<1/K6d];Bb`/;2XZ:QDE5A4A4@8P82000aDE5A<C
4`0000025ADE00L<30`E5AD<30`410@E5AD<30`E5AD00``<30035ADE30`<5ADE008Y:BT00`P820`<
31DE5@025ADE00<0000K6a/P82000a/K6`0510@44a<C30`<5ADE:RXZ008P82000c/k>fa/K79bLP0L
moOg6oooo`006_oooaGgmoL01/jmcQ1B@V=BBV]BBUY2>F=BBP9cFU801g]SFW=JDV=BBU92>D92048Y
8D8Y<@02<B4Q00P0200a8B4a8B4a8APi:B4Y200Y61Pa8B45:APH00Di:B4Y61P8410Y61Pi:B400S4Q
8@06DT8QHdY2FU9B<B4Q@RTa8@000c4Q8@0<>BTQ02TQ<B4Q<B4QDT8iFT8i42TQHd8aDS4YLdXiS5Y:
Q7=S7?OgmaoooolEmoOg00K4a<AbLW9DE5A8B4P92@U8B4P3E5AD00YMGEe0@40f=SI3@d<i>CTP820T
92@E5AD<30`P82025ADE00DC4a<<30`K6a/<30`E5AD01@`<30056a/K30`<000030`<6a/K008E5AD0
1cHf=T51@DM7AaDE5B@T91DE5@@410025ADE00`K6a/T92@K6a/E5ADf=SHi>CTK6a/a<C4k>c/820QM
GEe/K6`MmoOg6oooo`006_oooaKgmoL05hAcLa1B@V]2BV=B@T92249206=B@V=J@W=2DV=2BU924492
0580:E8a8D8Y8BT8024003TY8B400240634Q6240034Q8@058@0000@Y61PQ000Q00084102:APH01L@
4012410@00128AQ28A128B528AQ200Q2200a200Q200@024@8B4H8B5B0352<C5B<B52001S@S40@P24
@T:DJd;ginL07?OgmaoooolFmoOg0WAdM004D51@@41020P80@410T10@00>D51@@41051@D@410>CTi
92@T820P000010@44A4A6a/K10@4000020P80Q4A4@D410@010`<30@410@41000008<30`010000041
0B4Q8@410@8410@01PT92@410@@4110@40410A4A4@8820P0110@420P820P834a<@8820P00a0@461P
H?7al@0MmoOg6oooo`006_oooaOgmoL05Yb<W8A[FV]BBV=BBTY226=:@V]BBW=JDV]SJg][NeY265Y2
>F=2<E8i<E8a:C4Q8CTY8D8Y8C4Q634Q8B4063TY8@<Y61P04R4002TH62TH62TH634Q8A0002TH63TY
8C4Q8BTH610Y06=:@UYBDU92>CTY<C4Q8DXa<E8i<@=J@ST026]BBV=:@V=:@V=:@V=2<G=:@Ya[DYAk
LakgmoLOoooo6?Ogm`0:Shn?@d=3B4Q8Bd];>CTi@d=3Bd];E5ADJf][GEeM0STi>@0:>c/k820P5ADE
5ADE6a/K820P4A4A4a<C30`<6a/K0``<300B5ADE30`<30`<30`<5ADE000030`<6a/K5ADE30`<820P
0@41AdM7=SHf820P5ADE2PX:<C4a13Ti>@=3@d<2>c/k00=:BTYTI6CgmoL07_Ogma_oool001[ooolI
moOg00F<He9cFU9S@T9[DTYcFU800g]SFP0326=:DSTaDSTa009B>C403d8003TY8E92>DXa<D8Y8@0Y
8BTH634Q8BTH634Q8B40034Q8BTH63TY8CTY<@02<B4Q00Xi:B52<CTa8B52034i:CUSBT9SBTXa8B4i
:B52:C42>BTQ00Ta8B528B5B@SUB>C5B<BUS@S64@T:DFU;Nc]H07oOgmaoooolImoOg00IRHV9DE5AM
GEe3@d=;Bd]DE5@2GEeM00=_KfmMGEda<C400S4a<@0@:RXZ@d=36a/K=SHf820P92@T6a/K30`<5ADE
30`<5ADE30`<5ADE30`<6a/K820P0QDE5@0:6a/K:BTY5ADE92@T8R8R@d=3ADE55ADE6a/K00000Q/K
6`0:5ADE:RXZ820P<30`;2`/>c/kEEEEK6a/Hf=Sdm?C7oOgma_oool001[ooolImoOg00^eYJf<Lf=[
DTY[DTYSDTYcFU9kHeZ<Lf^4001[DTYJ<BT00U8i<@03DS4YDSTaFT8i009J@ST00d8Y8CTY<E8a:@03
<B4Q00U2:C4a8B4a8B5B>DX08B52:C4i:B52:C5JDU800T8a>@0;>BTa>BTQDT8i@P0aFT8iDT8iDSTa
DS4YHd80DS4YHd8a009cBST00hA2@]k>e_Ogm`0OmoOg7ooooaWgmoL00jNWYfa/K4];B`02Bd];00Q8
B4QDE5A_Kfn0P81dM7A;Bd/`<30a<C42;2`/00La<C4i>CTi>CTP820T92@P820/;2`00QDE5@0:6a/K
92@T5ADE5ADE>CTi2@T992@T6a/K92@TAdM70RTY:@0;820P6a/K=SHf=SHf:2PX=SHf<C4a;2`/@d=3
>c/k:2PX0098B4P00eeMGEiNG]?Cd`0PmoOg6oooo`006_oooa[gmoL03MK6gPQB@UY2>F=:@V]BBW]S
FXacJhacHhacJg]SFU92>E8i<D8a8@02DS4Y0V=:@P0BDT8iLeYB<B4Q@RTQ:APH@S4a@RTa@S4iBSU:
DT8i@P0iNg=kJe9:HeYS>BTaHd92FU9BHdY:0f=:@P9J@ST2HdY200I[@T9[DTYSBT:4DT:ULeZ4Hd8Q
moOg7ooooa[gmoL01]3@d6a/K4];BcTi>D=3@dU9B@9_Kfl01WAdM6m_KeeMGC0`<2`/;2XZ:P8/;2`0
4T=3@cTi>CHf=UADE1DE5B0P80P822TY:B@T92TY:CDe=CHf=R0P86e]KD];Be=CDb0P84=3@`95ADD3
@d=300/10@4i>CU3@d=3@d=;Bd]JFUY3@d=EEEEeMGENGUkalO408OOgma_oool001[ooolKmoOg02:D
Q9B4@TX@FU9[@TYkHeX8DT8020240008Lg><Lf<0DTX0Hd80@T88@S5:8AQSBT92@T9J@UYSBT9S@TX8
@S4000128B52BTYB449S@TYJ@U9BBU9:DT9[@TYS@T9SDT9S@T9SDTX2Ld9200YS@P1c@PQSDTX0DT80
@Q00@P1kHe8@@PQ2002UQ8@RmoOg7ooooacgmoL01XJ6QT92@UADE4U9BD10@5ADE08000006VATI4A4
A5ADE6=SHd=3@c0`<00004=3@dA4A4E5AD=3@dQ8B00000D51@@414E5A@410DE5AD51@DA4A4=3@dU9
BD10@4=3@d10@4];B`9:BTX01T10@4Q8B4];Bd51@APH61TI6@90@4000`X:2XN7QoOgm`0RmoOg6ooo
o`006_oooakgmoL02kFU[F]SJg=JDW=2DXacJiB4Q8akLhacJhASBXacJhakL`02S7=[00L0DV=kHeYc
FU:<Lf][Hf]kHeYJBUX00U8iBP03@S4iDP0aNf=J00=[DTX025Y2>F=2<F=2<F=2<EY2>@12@W]SDXAS
DP:<FTX00`1247=:@]K6eP0TmoOg7ooooaogmoL02`@415ADE5eMGEADE6m_Kh20P6ATI6m_Kf=SHfm_
KgAdM002Kfm_00MCDe=MGEeDE5A_KfmLG5a]KFe7AdL00STi>@03:BTY<C4aGEeM00=;Bd/2>CTi0S/k
>`04>CTiBTY:D51@GUiN0UeMG@03GUiNB4Q8B4Q802GgmoLKoooo000Joooo7oOgm`08c[g6S7=kNf=B
Nf=JJf=[S7=kW8b<Q0000XakL`0MQ6]JS7]cU000S7]cU7]cS7]cS7=[4000S7]cNf=JJe9:HdY:@T88
DT8iHdY2Nf=JLeYBHd92Je9:Q592Le9:S5Y:26=BS7=SW7=SYG=JQ5928@00oooo02GgmoLOoooo7oOg
m`03`L71M7AdFUYJ009MGEd015aLG00007AdM820P09dM7@07F1PH7MgMh20P7AdM7MgMgAdM00005AD
E7AdM5eMGD];BdE5A@410CHf=T=3@eeMGEADE4=3@d];BeEEEDm?CeeMGEYJFV1PH7=cLgEeMEEEED=3
@hN7Q`0VmoOg6oooo`006_ooob7gmoL03NOFif]SJe92DV]BBV=JHbT@48acNib<S9B4Q9b<S8AcHhak
LjF4N`02U7]c00^4Lf>UQ7^DNg>DNg>4JeZ4HdZ<Lf><He:4JeZLJe:4He800YAcJ`07[G][[HA[S01S
Le9:HdY2Q6=Bc[g602OgmoLOoooo8_Ogm`0=iNGUG5aL?Shn@d=3KFe]UIFEM7AdRHV9P820MgMgKfm_
M7AdQ8B4009gMgL016a/K8B4Q7MgMgMgM`9SHf<016a/K69RHV=SHfa/K09RHV80279bLX20P8>3Ph>3
Pda<C4=3@eiNG/71`BSgmoLKoooo000Joooo00?gknogmoOgmoL08?Ogm`06imkW[IbeS7^<S124YIBU
a[G60[FLW006YH@HYHAkU7]cNf=JU7]cYH@00jF4N`0?U7]cQ01cU7=[S7=SU7=[U7]cY@1[[HA[S7=S
Q6]JS7=SLe9:S7=Sc[Fmoooo02SgmoLOoooo00?alO7gmoOgmoL08OOgm`06h^;R92@TOGemUIFEV9RH
_;bl0YjNWP:4Q8@017MgMeeMG@@418N7Q`>4Q8@01WMgM`@4179bLVa/K79bLWMgM`:0P8001fa/K6=S
Hfa/K4m?Cda<C;^k^oooo`0YmoOg6oooo`006_ooobOgmoL01NONknoWimK6e/JeaXBeQ002[IBD00FU
Q8BDNg>4Lf=kJg^<Ng<00YAkL`0<Q01[U7=[S7=[U7=[S7=SQ7=SQ6]JQ6=BQ6]JQ6=BQ1Paoooo:_Og
maoooolXmoOg00GUiNGXj>R<S8be]KFl_;`00YFEU@05QhN7LW9bM7AdJf][M7Ad009gMgL030@4179b
LVm_Kg9bLVa/K79bLV1PH5iNGV=SHeiNGWMgMjBTY2_gmoLKoooo000Joooo0oOWibKgmoL03nOWinOF
inOWinOWimK6e/JeaYB4U8B4Q9B4Q9A[HhAJHiABHh@8@XB4FXASH`02Q7=S00F4Hd9cDU:4He:UU:Gg
inL0;?Ogmaooool3lO7a9oOgm`;Ph>003O7alN3Ph<G5aL71`H>3PhN7Qh20P75aLF9RHUADE451@H20
P61PH002IfMW00ETI6ADE5ASHf>CTi?alO40;OOgma_oool001[oooldmoOg00?gknogmoOgmoL0=?Og
maoooolemoOg00?alO7gmoOgmoL0=OOgma_oool001[ooom[moOg7oooofggmoLKoooo003ooooo;Ooo
o`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool006Goool30000V?ooo`<0000Y
oooo001Xoooo00<0003oooooool0V?ooo`030000oooooooo02Koool0033oool300000oooo`800003
oooo0`0000Coool200000oooo`@00009oooo0`000008oooo00000000oooo0000oooo0000oooo1@00
00;oool300000oooo`<0000loooo0P000004oooo0000000000000_ooo`800002oooo0P0000;oool2
00000_ooo`800004oooo0`000005oooo000000000000oooo008000000oooo`000000000200000ooo
o`800002oooo0P000004oooo0000oooo00000_ooo`<00009oooo0`000008oooo00000000oooo0000
oooo0000oooo1@0000;oool300000oooo`<0000Roooo000_oooo00<0003oooooool00oooo`040000
oooooooo00000oooo`030000oooooooo00;oool010000?ooooooo`0000?oool00`000?ooooooo`0:
oooo00X0003oooooooooool0003oool0003oool0003oool400000_ooo`040000oooooooo00000_oo
o`030000oooooooo03goool01@000?ooooooooooo`000002oooo00@0003oooooool00002oooo00@0
003oooooool00002oooo00@0003oooooool00002oooo00<0003oooooool00oooo`040000oooooooo
00000oooo`030000oooooooo00;oool010000?ooooooo`0000;oool01`000?ooo`000?ooo`000?oo
o`00000=oooo00X0003oooooooooool0003oool0003oool0003oool400000_ooo`040000oooooooo
00000_ooo`030000oooooooo02?oool002ooool00`000?ooooooo`03oooo00@0003oooooool00003
oooo00<0003oooooool00_ooo`040000oooooooo00000oooo`030000oooooooo00[oool02@000?oo
ooooooooo`000?ooo`000?ooo`000004oooo00@0003oooooool00002oooo00<0003oooooool01000
03coool01@000?ooo`000?ooo`000002oooo00@0003oooooool00002oooo00@0003oooooool00002
oooo00@0003oooooool00002oooo00<0003oooooool00oooo`040000oooooooo00000oooo`030000
oooooooo00;oool010000?ooooooo`0000;oool01P000?ooo`000?ooo`000?ooo`@0000:oooo00T0
003oooooooooool0003oool0003oool000001?ooo`040000oooooooo00000_ooo`030000oooooooo
00@0000Roooo000_oooo00<0003oooooool01?ooo`800004oooo00<0003oooooool00oooo`800003
oooo100000Woool200000_ooo`<000000oooo`000?ooo`02oooo0`0000?oool400000_ooo`80000m
oooo0P000003oooo0000000000?oool200000_ooo`@00004oooo0P0000Coool300000_ooo`<00003
oooo100000?oool200000_ooo`<000000oooo`000?ooo`02oooo0P0000[oool200000_ooo`<00000
0oooo`000?ooo`02oooo0`0000?oool400000_ooo`80000Soooo000_oooo00@0003oooooool00009
oooo00<0003oooooool0K?ooo`8000000oooo`000000000Joooo00<0003oooooool0Goooo`00<?oo
o`<00008oooo0P0001Soool00`000?ooooooo`1Coooo0P000004oooo0000000000006?ooo`80000U
oooo00<0003oooooool0>Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool0
0?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool0
0?ooool]oooo003ooooo;Oooo`00I_ooo`<0000/oooo0`0002Soool30000JOooo`00JOooo`030000
oooooooo02[oool00`000?ooooooo`0Zoooo00<0003oooooool0I_ooo`00F_ooo`<00004oooo0`00
00?oool300000oooo`800004oooo0P0000Coool200002Oooo`<00003oooo1`000005oooo0000oooo
0000oooo00<00003oooo0`0000Coool300002Oooo`<000002?ooo`0000000?ooo`000?ooo`000?oo
o`D00002oooo0`0000?oool300000_ooo`<0001Moooo001Koooo00<0003oooooool01?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`06oooo00@0003oooooool0000>oooo00@0003ooooo
ool00002oooo100000;oool01`000?ooo`000?ooo`000?ooo`000002oooo00D0003oooooooooool0
00001?ooo`030000oooooooo00_oool02P000?ooooooooooo`000?ooo`000?ooo`000?ooo`@00002
oooo00@0003oooooool00002oooo00<0003oooooool01_ooo`030000oooooooo05[oool005_oool0
0`000?ooooooo`04oooo00D0003oooooooooool000000_ooo`030000oooooooo00Soool00`000?oo
ooooo`0@oooo00<0003oooooool00oooo`0:0000oooooooo0000oooo0000oooo0000oooo00000_oo
o`050000oooooooooooo000000Coool400002_ooo`090000oooooooooooo0000oooo0000oooo0000
00Coool010000?ooooooo`0000;oool00`000?ooooooo`0400000_ooo`<0001Moooo001Koooo0P00
00Coool200001?ooo`@0000:oooo00<0003oooooool03Oooo`800004oooo0`000007oooo00000000
0000oooo0000oooo00@00004oooo00<0003oooooool00oooo`80000:oooo0P0000;oool3000000?o
ool0003oool00_ooo`<00003oooo100000;oool200000oooo`@0001Loooo001Koooo00@0003ooooo
ool0000Coooo00@0003oooooool0000>oooo00@0003oooooool0000Eoooo00<0003oooooool0S?oo
o`00F_ooo`D00003oooo00<0003oooooool03_ooo`80000?oooo100001Coool200004_ooo`030000
oooooooo07Woool00?ooool]oooo003ooooo;Oooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {149, 0}} -> {-0.124513, -0.0238147, \
0.00752183, 0.00752183}, {{16.5, 143.125}, {145.813, 19.1875}} -> {-31.2197, \
-7.0035, 1.19304, 1.19304}, {{155.813, 282.438}, {145.813, 19.1875}} -> \
{-194.936, -6.32728, 1.18168, 1.18168}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[
"4.3.2 Principle of wavelet image compression and recovery",
  FontFamily->"Times New Roman",
  FontSize->12]], "Subsection"],

Cell[TextData[{
  "\t",
  StyleBox[
  "In order to show the wavelet image compression and recovery, we apply a \
two-dimensional wavelet transform to the monochrome image shown on the right \
in Fig. 3.\n",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["\t",
    FormatType->InputForm],
  StyleBox[
  "At first, we construct the wavelet transform matrices employing the \
Daubechies 2",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["nd",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" and 4",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[
  " order base functions. Second, we carry out a wavelet transform. Figure 4 \
shows the obtained wavelet spectrum. Surprisingly, major parts of this \
wavelet spectrum are zero, where the zero value is painted in black. Only a \
small number of elements at the bottom on the left side take the non-zero \
values. This means that the small number of non-zero values in Fig. 4 could \
represent the major monochrome image data in a wavelet spectrum domain.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
base={daub2,daub4};
wMat=Table[waveletMatrix[dim[[2]],base[[i]]],{i,2}];
spect=waveletND[monoSample,wMat,2];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
ListDensityPlot[spect,PlotRange->All,
\tMesh->False,Frame->False,AspectRatio->dim[[2]]/dim[[3]],
\tPlotLabel->\"Fig.4. Wavelet spectram\"];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -71 0 ]
[.5 1.0125 71 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.813 moveto
(.4) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Wavelet) show
153.000 12.813 moveto
(spectram) show
201.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
D9FF002F2B272F3E262E292B2920302D2D29272C2C2A2C2C2B2A2A2A2D2C2B2B2B2B2D2A
2C2B292B2C2B2B2B2B2C2B2C2B2B2B2B2B2B2B2C292A2D2B2B2B2B2B2B2B2B2B2B2B2C2A
2B2B2B2B2B2B2C2C2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2A2B2B2C2C2B2B2B2B2B2B2B2B2B2B
4E3A353128262D22322A282B2A3129292A2E2C2A2B2A2C2B2B2B2A2D2D2A2B2B2B2B2A2D
2B2B2B2B2B2B2C2B2B2B2B2C2B2B2B2B2B2B2B2C2B2C2A2B2B2B2B2B2B2B2B2B2B2B2A2C
2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2C2A2B2B2C2B2B2B2B2B2B2B2B2B2B2B
33322F302B2A2E252A282D2D28332A2B2B2B2E292A2D2B2B2B2B292D292B2B2B2B2B2B2B
2B2C2D2B2B2B2B2C2B2B2B2B2B2C2B2B2B2B2B2B2D2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B
3D1D270F33351E30202F2C2C2F1A2F2E2E25292D2C2B2C2C2B2C2D29292C2B2B2B2B2D28
2B2B2A2C2C2B2C2B2B2B2B2B2B2B2B2B2B2B2C2B2A292D2B2B2B2B2B2B2B2B2B2B2B2D2A
2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B
302C2C2A2D2B2B2B2B2F2C2B292B2B2B2B2B2B2C2B2B2B2B2B2C2A2C2B2B2B2B2B2B2B2B
2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2C2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
312D2B2E2B2B2C292F272D2D2B2D2B2B2B2B32292B2B2B2B2B2A2C2B2B2B2B2B2B2B2B2B
2B2C2D2A2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2A2D2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2C2B2C2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2A2C2B2B2B2B2B2B2B2B2B2B2B2B2B
2F2E302C2B252A29262F292C292C2B2B2B2B292E2B2B2C2C2B2A2D29292B2B2B2B2B2B2B
2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2A2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2A
2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
161F1B272A3130342B2C2C2D2A2D2C2B2B2D292C2B2B2B2B2C2C292B2C2B2B2B2B2B2B2C
2B2B2A2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2A2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2A2C2C2B2C2B2B2B2B2B2C2C2B2B2B2B2B2B2D2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2E2C2C2B2B2B2B2A2B2C2E282A2C2B2B2B2B2B302A2B2B2A2B2C2A2C2B2B2B2B2B2B2B2B
2B2B2B2B2B2A2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2A2C2B2B2A2B2C2B2C2B2C2C2A2E2B2B2B2B2D2B2B2A2B2B2B2A2C2A2B2B2B2B2B2B2B2B
2B2B2B2A2C2B2B2B2C2B2B2B2B2B2C2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2C2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2A2C2B2B2B2B2B2B2B2B2B2B2B2B2B
322E2C2C2D2C2C2A2D282E2A2C2D2B2B2B2D2E2B2B2C2B2B2A2C2B2B2B2B2B2B2B2B2B2B
2C2C2B2B2B2B2B2C2B2B2B2B2B2C2B2B2B2B2B2B2C2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B
2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B
282E2C2D29282F2A292C292B2A2D2A2B2B2A2A2C2B2A2C2C2B2B2A2A2E2A2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2A2B2A2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2C2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B
302B2E2A2E2A272A2B2E2B2B2D2A2C2C2D2C2B2C2B2B2C2B2B2B2C2C272C2B2B2B2B2D2B
2C2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2A2D2B2B2B2B2B2B2B2B2B2B2B2C2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2A2C2B2B2B2B2B2B2B2B2B2B
2F2728262D31292C262C2C2B2E272C2B2B2B2C2B2C2B2B2B2B2B2D262D2B2B2B2B2B2B2C
292B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2A2A2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
1928273127282E2D2D292B2D272D2B2B2B2B2C2A2C2B2B2B2C292C2B2B2B2B2B2B2B2B2B
2B2B2C2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2B2B2B2C2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2D2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2C2C2B2A2C2B2B2B2C2B2C2A2B2B2B2B2B2B2B2A2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2D292C2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2C2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2C2B2C2C2A2C2B2B2B2E2A2B2C2B2B2B2B2B2C2B2B2A2C2A2C2B2C2B2B2B2B2B2B2B2B
2B2B2B2E2A2B2B2C2C2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2D2A2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2C2B2B2B2C2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2A2B2B2A2B2B2C2D2D2B2C2B2B2C2B2B2B2B2E2B2B2B2B2B2B2A2C2B2B2B2B2B2B2B2B2B
2B2B2C292C2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2C2A2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2C2B2B2B2B2B2B2B2C2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2A2C2B2B2B2B2B2B2B
2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B292C2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2A2B2C2B2B2B2B2B2B2B2B2B2B2B2B
2C2C2B2C2B2B2C2A2C2B2B2B2B2C2B2B2B2A2D2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B
2C2D2E2C2A2D2B2C2D2C2C2A2D2B2B2B2B2F2B2B2A2C2B2B2A2B2B2C2B2B2B2B2B2B2B2B
2A2B2B2B2B2B2B2B2C2B2B2B2B2C2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
292C2C2C292C2C2B2B2B2A2C2A2C2B2B2B2B2B2C2B2B2C2B2D2A2B2C2C2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B
2B2B2B2C2B2B2A2B2C2B2B2B2B2B2B2B2B2B2B2B
2C2C2A2C2B2A2D2B2A2B2B2C292B2B2A2A2B2B2B2B2B2B2B2C2B2B2B2D2B2B2B2B2B2A2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2A2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2C2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B
2C2B2C2B2C2B2A2B2B2C2B2B2B2B2B2B2B2C2B2C2B2B2B2B2B2B2C2B2A2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B
2E2B2C2A2D2B2A2A2B2C2B2B2C2A2B2C2C2B2B2A2C2B2C2B2B2B2B2C2A2B2B2B2B2B2C2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B292C2B2B2B2B2B2B2B2B2B2B2B2C2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B
2E2A2C282B2E292C2A2B2C2C2B282C2B2B292C2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2C
2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C292C2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B29282A2C2D2C2C292B2B2B2D2C2B2B2B2D2B2B2B2B2B2B2B2B2D2C2B2B2B2B2B2B2B2B
2C2A2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
262A292B2B2C2C2D2E2C2B2B282C2B2B2B2B2D2A2B2B2B2B2B2D2A2C2B2B2B2B2B2B2B2B
2B2B2C2B2C2B2B2B2B2B2B2B2B2B2B2B2B2A2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
232B2A302B282C2B2B2C2A2B2D2B2B2B2B2B2B2C2A2B2B2B2A2C2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2D2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2A2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2A2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2D2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2A2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2C2B2B2B2B2B2D2A2B2B2B2B2B2B2B2C2B2B2C2B2B2B2B2C2B2B2B2B2B2B2B2B
2B2B2B2B2A2B2B2B2A2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2A2B2B2B2B2B2B2B2B2B2C2C2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2B2B2A2A2B2B2B2B2A2D2C2C2B2B2B2B2B2B2B2B2C2B2B2C2B2B2B2B2B2B2B2B2B2B
2B2B2B2D2B2B2B2C2B2C2B2B2B2C2B2C2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2C2B2A2C2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2A2B2C2B2B2B2B2B2B2B2B
2B2B2D2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2C2C2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2C2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2A2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2B2C2B2B2A2B2B2B2B2C2B2A2B2B2B2B2C2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B
2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2A2C2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B
2C2C2B2B2B2B2B2B2C2B2C2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2B2B2B2B2B2B2B2B2D2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2C2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2C2C2D2A2C2B2B2C2C2A2B2C2B2B2B2B2D2B2B2B2A2B2B2B2B2B2B2B2B2B2B2B2B2B2D
2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2C2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2C2C2B2B2C2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2D2B2A2B2D292C2C2B2A2C2C2A2C2B2B2B2B2B2B2C2C2B2B2C2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2A2C2C2C2A2C2B2B2B2C2A292B2B2B2B2B2B2B2B2B2B2C2C2C2B2B2B2C2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2C2B2B2C2B2C2B2B2B2B2B2B2B2B2B2B2B
2B2B2A2B2B2A2C2B2B2B2B2C2A2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2C2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2C2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B
2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2A2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2C2B2C2B2B2B2B2C2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B
2D2B2B2A2C2B2B2B2B2B2B2B2B2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2A
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2C2A2B2B2B2B2B2B2B2B2B2B2B2B
2D2B2C2A2B2C2B2B2B2B2C2B2B2A2B2B2B2A2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2A2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2B2A2B2C2B2B2B2B2B2B2B2A2B2B2B2B2C2C2B2B2B2B2B2B2B2A2C2B2B2B2B2B2B2C
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2A2B2C2C2B2B2A2B2B2B2C2B2B2B2B2C2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B
2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2C2A2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2A2A2A2B2B2B2C2C2B2B2B2B2C2C2B2B2B2C2A2B2B2B2B2C2B2B2B2C2B2B2B2B2B2B2B2B
2B2A2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2A2B2B2B2B2C2B2C2C2C2B2B2B2C2B2B2B2B2B2C2B2B2B2B2B2B292B2B2B2B2B2B2B2B2B
2B2C2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
292B2B2B2A2C2B2C2C2B2A2C2A2B2B2B2B2B2B292C2B2B2B2B2C2C2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2C2B2B2C2B2B2B2B2B2B2B2A2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
282B2B2C292A2C2B2B2B2C2C2B2B2B2B2B2B2B2C2A2B2C2B2D2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
292B2B2D2D2B2B2B2B2B2C2A2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2C2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2C2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2C2C2B2B2B2B2B2C2A2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2C2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2A2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2A2B2B2C2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2C2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2B2B2B2B2B2B2B2B2A2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2C2B2B2B2B2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2C2C2C2C2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B
2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2C2C2B2B2C2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2C2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2C2C2C2B2B2B2B2B2C2B2B2C2B2B2B2B2C2B2B2C2B2B2B2A2C2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2C2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2C
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C
2B2C2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2C2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2A2B2B2C2A2C2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2C2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B
2B2C2C2B2B2B2B2B2B2B2B2A2C2B2B2B2B2B2B2B2B2B2B2B2A2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2A2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2C2B2B2A2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2A2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2C2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B
2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B
2B2C2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2A2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2C2B2B2C2B2B2B2C2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2C2B2B2B2C2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B2C2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2A2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2A2B2B2C2B2B2B2B2B2A2C2B2B2B2B2B2B2B2B2C2C2B2B2B2B2A2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2A2C2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2A2B2B2C2A2B2B2B2B2C2B2C2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2C2B2B2B2B2B2B2B2B2A2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
292B2B2D2D2A2B2B2B2B2C292C2B2B2B2B2B2B2B2B2B2B2C2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
00goool2fMWI0_ooo`800002;bl_0R/[:`8W9bL2;bl_0Shn?P8V9RH2;Rh^0RTY:@8[:b/2:BTY0R0P
808`<305;Bd]0RTY:@8W9bL4;2`/0RXZ:P@/;2`2:b/[1RXZ:P8];Bd2;2`/22/[:`8];Bd2:RXZ0R`/
;08[:b/2:BTY0R/[:`8/;2`8:b/[0R`/;08[:b/3;2`/3R/[:`8/;2`2:BTY0RXZ:P8];BdF:b/[0R`/
;08Z:RX<:b/[1B`/;0X[:b/2;2`/=b/[:`8Z:RX4:b/[12`/;1@[:b/?oooo000=oooo0]WIf@;oool2
00000Rl_;`8[:b/29bLW0Rl_;`8n?Sh29RHV0Rh^;P8Y:BT2:b/[0RTY:@8P8202<30`1Bd];@8Y:BT2
9bLW12`/;08Z:RX4;2`/0R/[:`HZ:RX2;Bd]0R`/;0P[:b/2;Bd]0RXZ:P8/;2`2:b/[0RTY:@8[:b/2
;2`/22/[:`8/;2`2:b/[0b`/;0h[:b/2;2`/0RTY:@8Z:RX2;Bd]5R/[:`8/;2`2:RXZ32/[:`D/;2`:
:b/[0R`/;3L[:b/2:RXZ12/[:`@/;2`D:b/[3oooo`003Oooo`9>CTh2>SXj0SDe=@8a<C42:2PX0RHV
9P8];Bd28R8R0S8b<P8Z:RX2:2PX0R/[:`8Z:RX2<C4a1BTY:@8Z:RX2;Rh^0R`/;08Z:RX2:b/[0RXZ
:P8/;2`6:b/[0RXZ:P@];Bd2:RXZ22/[:`8Z:RX2;Bd]32/[:`8/;2`8:b/[0b`/;0h[:b/2;2`/0R/[
:`8/;2`2:RXZ5R/[:`8Z:RX2;2`/0R/[:`8/;2a>:b/[0R`/;08Z:RX4:b/[0R`/;1H[:b/?oooo000=
oooo0Ti>CP8j>SX2=CDe0S4a<@8X:2P29RHV0Rd];@8R8R82<S8b0RXZ:P8X:2P2:b/[0RXZ:P8a<C45
:BTY0RXZ:P8^;Rh2;2`/0RXZ:P8[:b/2:RXZ0R`/;0H[:b/2:RXZ12d];@8Z:RX8:b/[0RXZ:P8];Bd<
:b/[0R`/;0P[:b/3;2`/3R/[:`8/;2`2:b/[0R`/;08Z:RXF:b/[0RXZ:P8/;2`2:b/[0R`/;4h[:b/2
;2`/0RXZ:P@[:b/2;2`/5R/[:`ooool000goool2<c<c0S8b<P8_;bl2<30`0R/[:`8Z:RX2;Rh^0RDU
9@8Z:RX2:2PX12d];@8X:2P2<c<c0RXZ:PL[:b/2;Rh^0RTY:@8Z:RX2;Bd]22/[:`8Y:BT2;Bd]0RTY
:A0[:b/2;2`/0Rd];@P[:b/2;2`/2b/[:`8/;2`<:b/[0Rd];CT[:b/2;2`/=b/[:`8/;2`L:b/[3ooo
o`003Oooo`8c<c<2<S8b0Rl_;`8`<302:b/[0RXZ:P8^;Rh29BDU0RXZ:P8X:2P4;Bd]0RPX:08c<c<2
:RXZ1b/[:`8^;Rh2:BTY0RXZ:P8];Bd8:b/[0RTY:@8];Bd2:BTY42/[:`8/;2`2;Bd]22/[:`8/;2`;
:b/[0R`/;0`[:b/2;Bd]>B/[:`8/;2`g:b/[0R`/;1`[:b/?oooo000=oooo0Sdm?@8M7Ad29bLW0Pl?
3`8c<c<2=CDe0QhN7P8`<302820P0Rl_;`@/;2`2;bl_0QXJ6P8_;bl5;Rh^0RDU9@8Y:BT2;Bd]0R`/
;08[:b/4;2`/0R/[:`8/;2`2;Bd]12TY:@8/;2`8:b/[0Rd];@8X:2P4:b/[0RXZ:P@/;2`2:b/[0R`/
;1L[:b/2;2`/0R/[:`8Z:RX2:BTY0Rd];AH[:b/2;Bd]0RXZ:P`[:b/2;2`/CR/[:`8/;2`D:b/[3ooo
o`003Oooo`8m?Cd27AdM0RLW9`8?3`l2<c<c0SDe=@8N7Qh2<30`0R0P808_;bl4;2`/0Rl_;`8J6QX2
;bl_1Bh^;P8U9BD2:BTY0Rd];@8/;2`2:b/[12`/;08[:b/2;2`/0Rd];@@Y:BT2;2`/22/[:`8];Bd2
:2PX12/[:`8Z:RX4;2`/0R/[:`8/;2`G:b/[0R`/;08[:b/2:RXZ0RTY:@8];BdF:b/[0Rd];@8Z:RX<
:b/[0R`/;4h[:b/2;2`/52/[:`ooool000goool2<30`12`/;08Z:RX2;Bd]22/[:`8_;bl2;2`/0R/[
:`8Y:BT=:b/[0R`/;0X[:b/2;2`/0RXZ:P8/;2`J:b/[0R`/;4h[:b/2;2`/22/[:`8/;2aE:b/[3ooo
o`003Oooo`8`<304;2`/0RXZ:P8];Bd8:b/[0Rl_;`8/;2`2:b/[0RTY:@d[:b/2;2`/2R/[:`8/;2`2
:RXZ0R`/;1X[:b/2;2`/CR/[:`8/;2`8:b/[0R`/;5D[:b/?oooo000=oooo0S4a<@8];Bd2:b/[0Rh^
;P@[:b/2;2`/0RTY:@8_;bl29bLW12d];@8[:b/2;Bd]2B/[:`8b<S82:BTY2R/[:`8Z:RX2;2`/52/[
:`8/;2`2;Bd]0RXZ:Q<[:b/2;2`/32/[:`8Z:RX2;Bd]8R/[:`8/;2`2:b/[0R`/;08Z:RY6:b/[0RXZ
:P8/;2`J:b/[3oooo`003Oooo`8a<C42;Bd]0R/[:`8^;Rh4:b/[0R`/;08Y:BT2;bl_0RLW9`@];Bd2
:b/[0Rd];@T[:b/2<S8b0RTY:@X[:b/2:RXZ0R`/;1@[:b/2;2`/0Rd];@8Z:RXC:b/[0R`/;0`[:b/2
:RXZ0Rd];B8[:b/2;2`/0R/[:`8/;2`2:RXZAR/[:`8Z:RX2;2`/6R/[:`ooool000goool2;bl_0Rh^
;P8`<302;2`/0R/[:`8U9BD2:RXZ0RTY:@8V9RH2;bl_0RTY:@8/;2`2:BTY0R`/;0T[:b/2:BTY0Rh^
;P@[:b/4;2`/0R/[:`8Z:RX2;Bd]12TY:A@[:b/2;2`/7B/[:`8/;2`4:RXZ72/[:`8Z:RX<:b/[0R`/
;6@[:b/?oooo000=oooo0Rl_;`8^;Rh2<30`0R`/;08[:b/29BDU0RXZ:P8Y:BT29RHV0Rl_;`8Y:BT2
;2`/0RTY:@8/;2`9:b/[0RTY:@8^;Rh4:b/[12`/;08[:b/2:RXZ0Rd];@@Y:BTD:b/[0R`/;1d[:b/2
;2`/12XZ:Q`[:b/2:RXZ32/[:`8/;2aT:b/[3oooo`003Oooo`8F5QH27alO0Q/K6`8W9bL2:RXZ0S4a
<@8`<302=3@d0R/[:`@/;2`2;Bd]0RXZ:P8];Bd2;2`/1B/[:`8];Bd2:BTY0R`/;0P[:b/4;2`/0RTY
:@8[:b/2;2`/32/[:`8/;2`4:b/[0RXZ:P8/;2`M:b/[0RXZ:P@[:b/2;2`/SR/[:`ooool000goool2
5QHF0QlO7`8K6a/29bLW0RXZ:P8a<C42<30`0S@d=08[:b/4;2`/0Rd];@8Z:RX2;Bd]0R`/;0D[:b/2
;Bd]0RTY:@8/;2`8:b/[12`/;08Y:BT2:b/[0R`/;0`[:b/2;2`/12/[:`8Z:RX2;2`/7B/[:`8Z:RX4
:b/[0R`/;8h[:b/?oooo000=oooo12/[:`8Z:RX4;2`/0R/[:`8/;2`::b/[12`/;0d[:b/2;Bd]32/[
:`8/;2`e:b/[0RXZ:Y@[:b/?oooo000=oooo12/[:`8Z:RX4;2`/0R/[:`8/;2`::b/[12`/;0d[:b/2
;Bd]32/[:`8/;2`e:b/[0RXZ:Y@[:b/?oooo000=oooo0Rh^;P@/;2`8:b/[0RXZ:P8[:b/2;2`/0Rh^
;P8X:2P2:RXZ0R`/;0/[:b/2<30`0RXZ:P@[:b/2:RXZ0R/[:`8/;2`2:RXZ0R`/;1X[:b/2:RXZ6b/[
:`8/;2`a:b/[0R`/;5l[:b/?oooo000=oooo0Rh^;P@/;2`8:b/[0RXZ:P8[:b/2;2`/0Rh^;P8X:2P2
:RXZ0R`/;0/[:b/2<30`0RXZ:P@[:b/2:RXZ0R/[:`8/;2`2:RXZ0R`/;1X[:b/2:RXZ6b/[:`8/;2`a
:b/[0R`/;5l[:b/?oooo000=oooo0RXZ:P8/;2`4:b/[0RXZ:P8[:b/2;2`/0R/[:`8/;2`2:b/[12`/
;08Z:RX2;Rh^2B/[:`8];Bd4:b/[0RXZ:PH[:b/2:RXZ0R`/;08Z:RXF:b/[0RXZ:P8/;2`6:b/[0R`/
;0/[:b/2;2`/12/[:`8/;2`^:b/[0R`/;0D[:b/2;2`/@B/[:`8Z:RX2;2`/6R/[:`ooool000goool2
:RXZ0R`/;0@[:b/2:RXZ0R/[:`8/;2`2:b/[0R`/;08[:b/4;2`/0RXZ:P8^;Rh9:b/[0Rd];@@[:b/2
:RXZ1R/[:`8Z:RX2;2`/0RXZ:QH[:b/2:RXZ0R`/;0H[:b/2;2`/2b/[:`8/;2`4:b/[0R`/;2h[:b/2
;2`/1B/[:`8/;2a1:b/[0RXZ:P8/;2`J:b/[3oooo`003Oooo`8b<S82;Rh^12`/;08];Bd4;2`/0RXZ
:P8];Bd2:2PX0Rh^;P8Z:RX2;2`/0Rd];@L[:b/2;Bd]0Rh^;P@[:b/2;2`/12/[:`8Z:RX2;2`/52/[
:`@/;2`::b/[0R`/;0/[:b/2;2`/32/[:`@/;2aI:b/[0R`/;1L[:b/2;2`/6R/[:`ooool000goool2
<S8b0Rh^;P@/;2`2;Bd]12`/;08Z:RX2;Bd]0RPX:08^;Rh2:RXZ0R`/;08];Bd7:b/[0Rd];@8^;Rh4
:b/[0R`/;0@[:b/2:RXZ0R`/;1@[:b/4;2`/2R/[:`8/;2`;:b/[0R`/;0`[:b/4;2`/FB/[:`8/;2`G
:b/[0R`/;1X[:b/?oooo000=oooo0RPX:08^;Rh2;2`/0Rd];@8Y:BT2:2PX0Rl_;`8Z:RX2:BTY0R`/
;08Y:BT2:b/[0RXZ:P8];Bd2:RXZ1B/[:`@Z:RX2;2`/0R/[:`8Z:RX4;2`/12/[:`@Z:RX2;Rh^0RXZ
:S<[:b/2;2`/0RXZ:P8[:b/2:RXZ9R/[:`8/;2a1:b/[0b`/;0P[:b/2;2`/5R/[:`ooool000goool2
:2PX0Rh^;P8/;2`2;Bd]0RTY:@8X:2P2;bl_0RXZ:P8Y:BT2;2`/0RTY:@8[:b/2:RXZ0Rd];@8Z:RX5
:b/[12XZ:P8/;2`2:b/[0RXZ:P@/;2`4:b/[12XZ:P8^;Rh2:RXZ<b/[:`8/;2`2:RXZ0R/[:`8Z:RXV
:b/[0R`/;44[:b/3;2`/22/[:`8/;2`F:b/[3oooo`003Oooo`8`<302:b/[0Rh^;P8Z:RX2;Rh^0RXZ
:P8W9bL2:RXZ0R/[:`8^;Rh4:b/[0Rd];@8Z:RX5;2`/0Rd];@8/;2`2:b/[0R`/;0@[:b/2;2`/1R/[
:`@/;2`29bLW0R`/;0P[:b/2;Bd]0R/[:`8/;2`6:b/[0R`/;1T[:b/2;2`/1R/[:`8Z:RX2;Bd]5R/[
:`8/;2aL:b/[0RXZ:P8/;2`D:b/[3oooo`003Oooo`8`<302:b/[0Rh^;P8Z:RX2;Rh^0RXZ:P8W9bL2
:RXZ0R/[:`8^;Rh4:b/[0Rd];@8Z:RX5;2`/0Rd];@8/;2`2:b/[0R`/;0@[:b/2;2`/1R/[:`@/;2`2
9bLW0R`/;0P[:b/2;Bd]0R/[:`8/;2`6:b/[0R`/;1T[:b/2;2`/1R/[:`8Z:RX2;Bd]5R/[:`8/;2aL
:b/[0RXZ:P8/;2`D:b/[3oooo`003Oooo`8_;bl29bLW0RPX:08V9RH2;Bd]0S4a<@8Y:BT2;2`/0RHV
9P@/;2`2:b/[0Rh^;P8W9bL2;2`/1b/[:`8/;2`2:b/[0R`/;0X[:b/2;Bd]0RHV9P8];Bd<:b/[0R`/
;08Y:BTS:b/[0R`/;0@Z:RX2;2`/72/[:`8/;2`C:b/[0R`/;5/[:b/?oooo000=oooo0Rl_;`8W9bL2
:2PX0RHV9P8];Bd2<C4a0RTY:@8/;2`29RHV12`/;08[:b/2;Rh^0RLW9`8/;2`7:b/[0R`/;08[:b/2
;2`/2R/[:`8];Bd29RHV0Rd];@`[:b/2;2`/0RTY:B<[:b/2;2`/12XZ:P8/;2`L:b/[0R`/;1<[:b/2
;2`/Fb/[:`ooool000goool26ATI0RPX:08W9bL2<C4a0RLW9`8X:2P2;Rh^12d];@8Y:BT2:b/[0Rd]
;@8W9bL2;Bd]2B/[:`8/;2`2:RXZ0R`/;0H[:b/2;2`/0RTY:@8/;2`F:b/[0R`/;1D[:b/2;2`/22/[
:`8/;2bD:b/[3oooo`003Oooo`8I6AT2:2PX0RLW9`8a<C429bLW0RPX:08^;Rh4;Bd]0RTY:@8[:b/2
;Bd]0RLW9`8];Bd9:b/[0R`/;08Z:RX2;2`/1R/[:`8/;2`2:BTY0R`/;1H[:b/2;2`/5B/[:`8/;2`8
:b/[0R`/;9@[:b/?oooo000=oooo0QTI6@8X:2P29bLW0S4a<@8W9bL2:2PX0Rh^;P@];Bd2:BTY0R/[
:`8];Bd29bLW0Rd];@T[:b/2;2`/0RXZ:P8/;2`6:b/[0R`/;08Y:BT2;2`/5R/[:`8/;2`E:b/[0R`/
;0P[:b/2;2`/U2/[:`ooool000goool2;2`/22/[:`8/;2`<:b/[0R`/;<<[:b/2;2`/9B/[:`ooool0
00goool2;2`/22/[:`8/;2`<:b/[0R`/;<<[:b/2;2`/9B/[:`ooool000goool2;2`/1R/[:`8/;2`O
:b/[0Rd];MT[:b/?oooo000=oooo0R`/;0H[:b/2;2`/7b/[:`8];BgI:b/[3oooo`003Oooo`H/;2`2
:b/[0RXZ:P8/;2`6:b/[0R`/;08[:b/2;2`/0RXZ:Pl[:b/2:RXZ12/[:`8/;2`P:b/[0Rd];@8Y:BT2
;2`/5b/[:`8/;2`g:b/[0R`/;08Z:RYI:b/[3oooo`003Oooo`H/;2`2:b/[0RXZ:P8/;2`6:b/[0R`/
;08[:b/2;2`/0RXZ:Pl[:b/2:RXZ12/[:`8/;2`P:b/[0Rd];@8Y:BT2;2`/5b/[:`8/;2`g:b/[0R`/
;08Z:RYI:b/[3oooo`003Oooo`@/;2`2:b/[12`/;08Z:RX2;2`/1R/[:`8^;Rh2:RXZ0R/[:`8/;2`;
:b/[0R`/;0@[:b/2:RXZ0R`/;08Z:RX2;2`/0R/[:`8/;2`F:b/[0Rh^;P8Z:RX4:b/[12`/;0d[:b/2
;2`/>B/[:`8];Bd2:RXZ42/[:`8/;2`<:b/[0R`/;0H[:b/2;2`/=B/[:`ooool000goool4;2`/0R/[
:`@/;2`2:RXZ0R`/;0H[:b/2;Rh^0RXZ:P8[:b/2;2`/2b/[:`8/;2`4:b/[0RXZ:P8/;2`2:RXZ0R`/
;08[:b/2;2`/5R/[:`8^;Rh2:RXZ12/[:`@/;2`=:b/[0R`/;3T[:b/2;Bd]0RXZ:Q0[:b/2;2`/32/[
:`8/;2`6:b/[0R`/;3D[:b/?oooo000=oooo0RXZ:P@[:b/2:RXZ12/[:`8/;2`4;Bd]0R/[:`8/;2`4
:b/[0R`/;0T[:b/2;Rh^32/[:`8Z:RX2;2`/5R/[:`8/;2`2:BTY0R`/;0H[:b/2;2`/5b/[:`8/;2`X
:b/[0R`/;08Z:RX3:b/[0R`/;44[:b/2;2`/72/[:`ooool000goool2:RXZ12/[:`8Z:RX4:b/[0R`/
;0@];Bd2:b/[0R`/;0@[:b/2;2`/2B/[:`8^;Rh<:b/[0RXZ:P8/;2`F:b/[0R`/;08Y:BT2;2`/1R/[
:`8/;2`G:b/[0R`/;2P[:b/2;2`/0RXZ:P<[:b/2;2`/@B/[:`8/;2`L:b/[3oooo`003Oooo`H[:b/2
;2`/3R/[:`8/;2`=:b/[0R`/;10[:b/2:RXZ0R`/;18[:b/2;2`/8b/[:`8Y:BT2;2`/L2/[:`8Z:RX2
:b/[0R`/;1P[:b/?oooo000=oooo1R/[:`8/;2`>:b/[0R`/;0d[:b/2;2`/42/[:`8Z:RX2;2`/4R/[
:`8/;2`S:b/[0RTY:@8/;2a`:b/[0RXZ:P8[:b/2;2`/62/[:`ooool000goool4;2`/0R/[:`8/;2`4
:b/[0R`/;08Z:RX2;2`/22/[:`8/;2`7:b/[0RXZ:P8];BdT:b/[0R`/;2L[:b/2;2`/M2/[:`8/;2`H
:b/[3oooo`003Oooo`@/;2`2:b/[0R`/;0@[:b/2;2`/0RXZ:P8/;2`8:b/[0R`/;0L[:b/2:RXZ0Rd]
;B@[:b/2;2`/9b/[:`8/;2ad:b/[0R`/;1P[:b/?oooo000=oooo0R`/;08];Bd2;Rh^0R`/;08Z:RX2
;Bd]0R/[:`8/;2`2;Bd]12`/;08Z:RX2;Bd]2B/[:`8_;bl4:b/[0RXZ:P8/;2`4:b/[0RXZ:P@[:b/2
;2`/42/[:`8Z:RX>:b/[0R`/;0T[:b/2;2`/32/[:`8/;2`X:b/[0R`/;34[:b/2;2`/<b/[:`ooool0
00goool2;2`/0Rd];@8^;Rh2;2`/0RXZ:P8];Bd2:b/[0R`/;08];Bd4;2`/0RXZ:P8];Bd9:b/[0Rl_
;`@[:b/2:RXZ0R`/;0@[:b/2:RXZ12/[:`8/;2`@:b/[0RXZ:Ph[:b/2;2`/2B/[:`8/;2`<:b/[0R`/
;2P[:b/2;2`/<B/[:`8/;2`c:b/[3oooo`003Oooo`8Y:BT6;2`/0RTY:@@/;2`6:b/[0RXZ:P8/;2`2
:RXZ0R`/;0/[:b/2;2`/12/[:`8/;2`2:b/[0Rd];@8Z:RX2:b/[12`/;2/[:b/2;2`/22/[:`8/;2`/
:b/[0R`/;2d[:b/2;2`/4R/[:`</;2`4:b/[0RXZ:P8[:b/2;2`/5R/[:`ooool000goool2:BTY1R`/
;08Y:BT4;2`/1R/[:`8Z:RX2;2`/0RXZ:P8/;2`;:b/[0R`/;0@[:b/2;2`/0R/[:`8];Bd2:RXZ0R/[
:`@/;2`[:b/[0R`/;0P[:b/2;2`/;2/[:`8/;2`]:b/[0R`/;18[:b/3;2`/12/[:`8Z:RX2:b/[0R`/
;1H[:b/?oooo000=oooo12`/;08Z:RX2;2`/0R/[:`8Z:RX2;Bd]0R/[:`8Z:RX4:b/[0R`/;08Y:BT4
:b/[1BXZ:Ph[:b/2;2`/1R/[:`8];Bd::b/[0RXZ:RL[:b/2;2`/7R/[:`8Z:RY?:b/[0R`/;0d[:b/2
;2`/52/[:`ooool000goool4;2`/0RXZ:P8/;2`2:b/[0RXZ:P8];Bd2:b/[0RXZ:P@[:b/2;2`/0RTY
:@@[:b/5:RXZ3R/[:`8/;2`6:b/[0Rd];@X[:b/2:RXZ9b/[:`8/;2`N:b/[0RXZ:Tl[:b/2;2`/3B/[
:`8/;2`D:b/[3oooo`003Oooo`8/;2`2:b/[0R`/;08[:b/2;2`/0R/[:`8Z:RX4:b/[0R`/;0l[:b/2
;2`/0R/[:`8/;2`<:b/[0R`/;08[:b/2:RXZ>B/[:`8/;2af:b/[0R`/;1H[:b/?oooo000=oooo0R`/
;08[:b/2;2`/0R/[:`8/;2`2:b/[0RXZ:P@[:b/2;2`/3b/[:`8/;2`2:b/[0R`/;0`[:b/2;2`/0R/[
:`8Z:RXi:b/[0R`/;7H[:b/2;2`/5R/[:`ooool000goool2;Rh^0R/[:`8/;2`2:RXZ0Rd];@8[:b/4
:RXZ0R/[:`8/;2`4:b/[0R`/;08Z:RX2:b/[1B`/;0@[:b/2:RXZ0R`/;08[:b/2;2`/22/[:`8/;2`2
:RXZ2R/[:`8/;2`]:b/[0RTY:@8/;2`F:b/[0R`/;5`[:b/2;2`/5R/[:`ooool000goool2;Rh^0R/[
:`8/;2`2:RXZ0Rd];@8[:b/4:RXZ0R/[:`8/;2`4:b/[0R`/;08Z:RX2:b/[1B`/;0@[:b/2:RXZ0R`/
;08[:b/2;2`/22/[:`8/;2`2:RXZ2R/[:`8/;2`]:b/[0RTY:@8/;2`F:b/[0R`/;5`[:b/2;2`/5R/[
:`ooool000goool2;Rh^0RXZ:P8/;2`2:2PX0R/[:`8^;Rh2:BTY0R`/;08Z:RX2:b/[12`/;08[:b/2
:2PX0R`/;0D[:b/2:BTY0R`/;18[:b/2;2`/32/[:`8/;2`2:b/[0R`/;2<[:b/2;2`/0RTY:@8/;2a^
:b/[0R`/;1h[:b/?oooo000=oooo0Rh^;P8Z:RX2;2`/0RPX:08[:b/2;Rh^0RTY:@8/;2`2:RXZ0R/[
:`@/;2`2:b/[0RPX:08/;2`5:b/[0RTY:@8/;2`B:b/[0R`/;0`[:b/2;2`/0R/[:`8/;2`S:b/[0R`/
;08Y:BT2;2`/KR/[:`8/;2`N:b/[3oooo`003Oooo`8[:b/2:BTY0RPX:08Z:RX2;2`/0Rd];@@/;2`2
:BTY1R/[:`8];Bd2;2`/1b/[:`8];Bd@:b/[0Rd];@8/;2`@:b/[0R`/;08Z:RX2;2`/7b/[:`8/;2`Z
:b/[0R`/;4P[:b/2;2`/7R/[:`ooool000goool2:b/[0RTY:@8X:2P2:RXZ0R`/;08];Bd4;2`/0RTY
:@H[:b/2;Bd]0R`/;0L[:b/2;Bd]42/[:`8];Bd2;2`/42/[:`8/;2`2:RXZ0R`/;1l[:b/2;2`/:R/[
:`8/;2a8:b/[0R`/;1h[:b/?oooo000=oooo0RHV9P8Z:RX2:BTY12/[:`@/;2`2;Bd]0Rh^;P8/;2`4
:b/[0RPX:08/;2`9:b/[0Rd];@8Z:RX::b/[0Rd];@8Z:RX2;2`/52/[:`8/;2`2:b/[0R`/;1T[:b/2
:RXZ0R`/;6d[:b/2;2`/9B/[:`ooool000goool29RHV0RXZ:P8Y:BT4:b/[12`/;08];Bd2;Rh^0R`/
;0@[:b/2:2PX0R`/;0T[:b/2;Bd]0RXZ:PX[:b/2;Bd]0RXZ:P8/;2`D:b/[0R`/;08[:b/2;2`/6B/[
:`8Z:RX2;2`/KB/[:`8/;2`U:b/[3oooo`003Oooo`8S8b<2:b/[0RXZ:P8`<302:b/[0RPX:08/;2`4
:b/[0R`/;08Z:RX2:b/[0Rd];@d[:b/2;2`/0RXZ:PH[:b/2:RXZ0R`/;<l[:b/?oooo000=oooo0R<S
8`8[:b/2:RXZ0S0`<08[:b/2:2PX0R`/;0@[:b/2;2`/0RXZ:P8[:b/2;Bd]3B/[:`8/;2`2:RXZ1R/[
:`8Z:RX2;2`/cb/[:`ooool000goool::b/[0R`/;?P[:b/?oooo000=oooo2R/[:`8/;2ch:b/[3ooo
o`003Oooool[:b/5:b/[3oooo`003Oooool[:b/5:b/[3oooo`003Oooool[:b/5:b/[3oooo`003Ooo
ool[:b/5:b/[3oooo`003Oooo`8/;2`6:b/[0R`/;1l[:b/2;Bd]P2/[:`8/;2aG:b/[3oooo`003Ooo
o`8/;2`6:b/[0R`/;1l[:b/2;Bd]P2/[:`8/;2aG:b/[3oooo`003Ooooa8[:b/2;2`/4b/[:`@Z:RXV
:b/[12XZ:U@[:b/2;2`/<R/[:`8/;2`U:b/[3oooo`003Ooooa8[:b/2;2`/4b/[:`@Z:RXV:b/[12XZ
:U@[:b/2;2`/<R/[:`8/;2`U:b/[3oooo`003Oooo`8/;2`U:b/[0R`/;2P[:b/2;Bd]E2/[:`8Z:RX2
;2`/FB/[:`ooool000goool2;2`/9B/[:`8/;2`X:b/[0Rd];E@[:b/2:RXZ0R`/;5T[:b/?oooo000=
oooo22/[:`8/;2`::b/[0Rd];@8Z:RX?:b/[0R`/;0@[:b/2;2`/22/[:`8/;2`H:b/[0RXZ:PH[:b/2
:RXZ2b/[:`8/;2`m:b/[0RXZ:Q8[:b/4;2`/22/[:`8/;2`m:b/[3oooo`003Oooo`P[:b/2;2`/2R/[
:`8];Bd2:RXZ3b/[:`8/;2`4:b/[0R`/;0P[:b/2;2`/62/[:`8Z:RX6:b/[0RXZ:P/[:b/2;2`/?B/[
:`8Z:RXB:b/[12`/;0P[:b/2;2`/?B/[:`ooool000goool2;2`/1R/[:`@Z:RX8:b/[0RXZ:P8];Bd4
;2`/4B/[:`8/;2`4:b/[0R`/;1X[:b/2;Bd]1R/[:`8/;2`2:b/[0R`/;0L[:b/2;2`/0R/[:`8/;2`8
:b/[0R`/;2`[:b/3;2`/9R/[:`8/;2`i:b/[3oooo`003Oooo`8/;2`6:b/[12XZ:PP[:b/2:RXZ0Rd]
;@@/;2`A:b/[0R`/;0@[:b/2;2`/6R/[:`8];Bd6:b/[0R`/;08[:b/2;2`/1b/[:`8/;2`2:b/[0R`/
;0P[:b/2;2`/;2/[:`</;2`V:b/[0R`/;3T[:b/?oooo000=oooo1R/[:`8/;2`2:b/[0RXZ:P8/;2`<
:b/[0R`/;1L[:b/2:RXZ0R/[:`8/;2`D:b/[0Rd];A/[:b/2;2`/1R/[:`8/;2`o:b/[0R`/;34[:b/2
;2`/72/[:`ooool000goool6:b/[0R`/;08[:b/2:RXZ0R`/;0`[:b/2;2`/5b/[:`8Z:RX2:b/[0R`/
;1@[:b/2;Bd]6b/[:`8/;2`6:b/[0R`/;3l[:b/2;2`/<B/[:`8/;2`L:b/[3oooo`003Oooo`8[:b/4
;2`/52/[:`8/;2aF:b/[0R`/;90[:b/?oooo000=oooo0R/[:`@/;2`D:b/[0R`/;5H[:b/2;2`/T2/[
:`ooool000goool<:b/[0R`/;0`[:b/2;2`/6b/[:`8Z:RZ_:b/[0R`/;1X[:b/?oooo000=oooo32/[
:`8/;2`<:b/[0R`/;1/[:b/2:RXZ[b/[:`8/;2`J:b/[3oooo`003Oooo`8/;2`4:b/[0R`/;0@[:b/2
:RXZ22/[:`8/;2`2:b/[0RXZ:PT[:b/2;2`/42/[:`8/;2`D:b/[0R`/;2<[:b/2;2`/0RXZ:W@[:b/2
:RXZ0R`/;1H[:b/?oooo000=oooo0R`/;0@[:b/2;2`/12/[:`8Z:RX8:b/[0R`/;08[:b/2:RXZ2B/[
:`8/;2`@:b/[0R`/;1@[:b/2;2`/8b/[:`8/;2`2:RXZM2/[:`8Z:RX2;2`/5R/[:`ooool000gooooZ
:b/[0R`/;1P[:b/?oooo000=oooojR/[:`8/;2`H:b/[3oooo`003Oooo`@/;2`<:b/[0R`/;08[:b/2
;2`/12/[:`8/;2aF:b/[0R`/;2@[:b/2;2`/CR/[:`8/;2`J:b/[3oooo`003Oooo`@/;2`<:b/[0R`/
;08[:b/2;2`/12/[:`8/;2aF:b/[0R`/;2@[:b/2;2`/CR/[:`8/;2`J:b/[3oooo`003Oooo`8/;2`B
:b/[0Rd];AD[:b/2;2`/72/[:`8/;2`<:b/[0R`/;3l[:b/2;2`/5B/[:`8/;2aC:b/[3oooo`003Ooo
o`8/;2`B:b/[0Rd];AD[:b/2;2`/72/[:`8/;2`<:b/[0R`/;3l[:b/2;2`/5B/[:`8/;2aC:b/[3ooo
o`003Oooo`8[:b/4;2`/0Rd];@8Z:RX2;2`/12/[:`@/;2`2:RXZ0R/[:`8/;2`9:b/[0Rd];@H[:b/2
:RXZ6R/[:`8];Bd<:b/[0R`/;1<[:b/2;2`/1R/[:`8/;2`N:b/[12`/;3D[:b/6;2`/12/[:`8/;2`]
:b/[3oooo`003Oooo`8[:b/4;2`/0Rd];@8Z:RX2;2`/12/[:`@/;2`2:RXZ0R/[:`8/;2`9:b/[0Rd]
;@H[:b/2:RXZ6R/[:`8];Bd<:b/[0R`/;1<[:b/2;2`/1R/[:`8/;2`N:b/[12`/;3D[:b/6;2`/12/[
:`8/;2`]:b/[3oooo`003Oooo`8[:b/4;2`/0Rd];@8Z:RX2;2`/12/[:`@/;2`2:RXZ0R/[:`8/;2`9
:b/[0Rd];@H[:b/2:RXZ6R/[:`8];Bd<:b/[0R`/;1<[:b/2;2`/1R/[:`8/;2`N:b/[12`/;3D[:b/6
;2`/12/[:`8/;2`]:b/[3oooo`003Oooo`8];Bd2:b/[0RXZ:P8[:b/2;Bd]0RTY:@@/;2`2:b/[0RXZ
:P@/;2`2:RXZ0R`/;0d[:b/4;2`/12/[:`8/;2`P:b/[0R`/;1/[:b/2;2`/TR/[:`ooool000goool2
;Bd]0R/[:`8Z:RX2:b/[0Rd];@8Y:BT4;2`/0R/[:`8Z:RX4;2`/0RXZ:P8/;2`=:b/[12`/;0@[:b/2
;2`/82/[:`8/;2`K:b/[0R`/;98[:b/?oooo000=oooo0RXZ:PH/;2`2:RXZ0R`/;0H[:b/2;2`/0RXZ
:P8Y:BTE:b/[1R`/;0H[:b/2;2`/:b/[:`8/;2`4:b/[0R`/;2X[:b/2;2`/Ab/[:`</;2`4:b/[0R`/
;08[:b/2;2`/5R/[:`ooool000goool2:RXZ1R`/;08Z:RX2;2`/1R/[:`8/;2`2:RXZ0RTY:AD[:b/6
;2`/1R/[:`8/;2`[:b/[0R`/;0@[:b/2;2`/:R/[:`8/;2a7:b/[0b`/;0@[:b/2;2`/0R/[:`8/;2`F
:b/[3oooo`003Oooo`@[:b/2:RXZ12/[:`8Z:RX2;2`/22/[:`8/;2`2:RXZ5b/[:`8/;2`6:b/[0R`/
;<T[:b/?oooo000=oooo12/[:`8Z:RX4:b/[0RXZ:P8/;2`8:b/[0R`/;08Z:RXG:b/[0R`/;0H[:b/2
;2`/bB/[:`ooool000goool6;2`/BB/[:`8/;2`M:b/[0R`/;7h[:b/2;2`/52/[:`ooool000goool6
;2`/BB/[:`8/;2`M:b/[0R`/;7h[:b/2;2`/52/[:`ooool000goool4:b/[0R`/;?h[:b/?oooo000=
oooo12/[:`8/;2cn:b/[3oooo`003Oooo`8/;2`2:b/[0R`/;24[:b/2;2`/42/[:`8Z:RXi:b/[0R`/
;8h[:b/?oooo000=oooo0R`/;08[:b/2;2`/8B/[:`8/;2`@:b/[0RXZ:ST[:b/2;2`/SR/[:`ooool0
00goool2;2`/0R/[:`8/;2`2:b/[0R`/;0P[:b/2;2`/3B/[:`8/;2`R:b/[0R`/;4L[:b/2;2`/FR/[
:`8/;2`H:b/[3oooo`003Oooo`8/;2`2:b/[0R`/;08[:b/2;2`/22/[:`8/;2`=:b/[0R`/;28[:b/2
;2`/Ab/[:`8/;2aJ:b/[0R`/;1P[:b/?oooo000=oooo0Rd];@@[:b/2:RXZ0R`/;10[:b/2:RXZM2/[
:`8Z:RYF:b/[0R`/;08Z:RXH:b/[3oooo`003Oooo`8];Bd4:b/[0RXZ:P8/;2`@:b/[0RXZ:W@[:b/2
:RXZER/[:`8/;2`2:RXZ62/[:`ooool000goool2;Bd]0R/[:`8/;2`2:RXZ0R/[:`8/;2`8:b/[0R`/
;0@[:b/2:RXZ1b/[:`8Z:RXB:b/[0R`/;5L[:b/2;2`/ER/[:`8Z:RXJ:b/[3oooo`003Oooo`8];Bd2
:b/[0R`/;08Z:RX2:b/[0R`/;0P[:b/2;2`/12/[:`8Z:RX7:b/[0RXZ:Q8[:b/2;2`/Eb/[:`8/;2aF
:b/[0RXZ:QX[:b/?oooo000=oooo0R`/;0@[:b/2:RXZ0R/[:`8/;2`>:b/[0RXZ:PT[:b/4;2`/3R/[
:`8Z:RX2;2`/32/[:`8/;2`W:b/[0R`/;7@[:b/2:RXZ72/[:`ooool000goool2;2`/12/[:`8Z:RX2
:b/[0R`/;0h[:b/2:RXZ2B/[:`@/;2`>:b/[0RXZ:P8/;2`<:b/[0R`/;2L[:b/2;2`/M2/[:`8Z:RXL
:b/[3oooo`003Oooo`8/;2`2:b/[0RXZ:P8[:b/4;2`/12/[:`8Z:RX6:b/[0R`/;0T[:b/2;2`/42/[
:`8/;2`D:b/[0R`/;24[:b/2;2`/0RXZ:Vd[:b/2;2`/0bXZ:P8/;2`N:b/[3oooo`003Oooo`8/;2`2
:b/[0RXZ:P8[:b/4;2`/12/[:`8Z:RX6:b/[0R`/;0T[:b/2;2`/42/[:`8/;2`D:b/[0R`/;24[:b/2
;2`/0RXZ:Vd[:b/2;2`/0bXZ:P8/;2`N:b/[3oooo`003Oooo`HZ:RX6:b/[12`/;0P[:b/4;2`/1b/[
:`8/;2`2:RXZ22/[:`8/;2`6:b/[0R`/;18[:b/2:RXZ5B/[:`8/;2`<:b/[0R`/;6d[:b/2:RXZ8b/[
:`ooool000goool6:RXZ1R/[:`@/;2`8:b/[12`/;0L[:b/2;2`/0RXZ:PP[:b/2;2`/1R/[:`8/;2`B
:b/[0RXZ:QD[:b/2;2`/32/[:`8/;2a]:b/[0RXZ:R<[:b/?oooo000=oooo0RXZ:PP[:b/2;2`/0R/[
:`H/;2`6:b/[0R`/;0/[:b/2;2`/32/[:`8Y:BTD:b/[0R`/;08Z:RXO:b/[0R`/;2X[:b/2;2`/@B/[
:`8/;2`U:b/[3oooo`003Oooo`8Z:RX8:b/[0R`/;08[:b/6;2`/1R/[:`8/;2`;:b/[0R`/;0`[:b/2
:BTY52/[:`8/;2`2:RXZ7b/[:`8/;2`Z:b/[0R`/;44[:b/2;2`/9B/[:`ooool000goool2:BTY1R/[
:`8Z:RX2;2`/0R/[:`@/;2`2:b/[0RXZ:P8/;2`2:RXZ3B/[:`8Y:BT2;2`/22/[:`@/;2`L:b/[0R`/
;0@[:b/2;2`/3b/[:`8Z:RX2;2`/Jb/[:`8/;2`Y:b/[3oooo`003Oooo`8Y:BT6:b/[0RXZ:P8/;2`2
:b/[12`/;08[:b/2:RXZ0R`/;08Z:RX=:b/[0RTY:@8/;2`8:b/[12`/;1`[:b/2;2`/12/[:`8/;2`?
:b/[0RXZ:P8/;2a[:b/[0R`/;2T[:b/?oooo000=oooo0RPX:0@[:b/2;2`/0RTY:@8Z:RX2;2`/1R/[
:`@/;2`?:b/[0R`/;08Z:RX2:b/[0R`/;08[:b/2;Bd]8R/[:`8/;2aB:b/[0R`/;5T[:b/?oooo000=
oooo0RPX:0@[:b/2;2`/0RTY:@8Z:RX2;2`/1R/[:`@/;2`?:b/[0R`/;08Z:RX2:b/[0R`/;08[:b/2
;Bd]8R/[:`8/;2aB:b/[0R`/;5T[:b/?oooo000=oooo0RTY:@@[:b/4;Bd]2R/[:`8/;2`2:RXZ0R`/
;>X[:b/?oooo000=oooo0RTY:@@[:b/4;Bd]2R/[:`8/;2`2:RXZ0R`/;>X[:b/?oooo000=ooooob/[
:`D[:b/?oooo000=ooooob/[:`D[:b/?oooo000=ooooob/[:`D[:b/?oooo000=ooooob/[:`D[:b/?
oooo000=ooooob/[:`D[:b/?oooo000=ooooob/[:`D[:b/?oooo000=ooooob/[:`D[:b/?oooo000=
ooooob/[:`D[:b/?oooo000=ooooob/[:`D[:b/?oooo000=ooooob/[:`D[:b/?oooo000=ooooob/[
:`D[:b/?oooo000=ooooob/[:`D[:b/?oooo000=oooo:B/[:`8/;2cI:b/[3oooo`003OooobT[:b/2
;2`/fB/[:`ooool000gooolY:b/[0R`/;2P[:b/2;2`/[b/[:`ooool000gooolY:b/[0R`/;2P[:b/2
;2`/[b/[:`ooool000gooomC:b/[0R`/;5@[:b/2;2`/0RXZ:UL[:b/?oooo000=ooooDb/[:`8/;2aD
:b/[0R`/;08Z:RYG:b/[3oooo`003Ooooa8[:b/2;2`/Tb/[:`8/;2`2:RXZFB/[:`ooool000gooolB
:b/[0R`/;9<[:b/2;2`/0RXZ:UT[:b/?oooo000=oooo9b/[:`8/;2`X:b/[0R`/;5@[:b/2;2`/=R/[
:`8/;2`S:b/[3oooo`003OooobL[:b/2;2`/:2/[:`8/;2aD:b/[0R`/;3H[:b/2;2`/8b/[:`ooool0
00goool2;2`/Xb/[:`8/;2aM:b/[3oooo`003Oooo`8/;2bS:b/[0R`/;5d[:b/?oooo000=oooo9b/[
:`8/;2`4:b/[0R`/;2h[:b/2;2`/JR/[:`8/;2`i:b/[3oooo`003OooobL[:b/2;2`/12/[:`8/;2`^
:b/[0R`/;6X[:b/2;2`/>B/[:`ooool000goool6:b/[12`/;0X[:b/2;2`/0RXZ:QL[:b/2;2`/7R/[
:`8/;2`C:b/[0R`/;5<[:b/2;2`/0RXZ:P8/;2a5:b/[3oooo`003Oooo`H[:b/4;2`/2R/[:`8/;2`2
:RXZ5b/[:`8/;2`N:b/[0R`/;1<[:b/2;2`/Db/[:`8/;2`2:RXZ0R`/;4D[:b/?oooo000=oooo<B/[
:`8Z:RX4:b/[0R`/;20[:b/2;2`/2B/[:`8/;2`m:b/[0R`/;2P[:b/2;2`/=B/[:`ooool000gooola
:b/[0RXZ:P@[:b/2;2`/82/[:`8/;2`9:b/[0R`/;3d[:b/2;2`/:2/[:`8/;2`e:b/[3oooo`003Ooo
o`8/;2`B:b/[0RXZ:P8/;2`g:b/[0R`/;0P[:b/2:RXZAB/[:`</;2a1:b/[0R`/;1h[:b/?oooo000=
oooo0R`/;18[:b/2:RXZ0R`/;3L[:b/2;2`/22/[:`8Z:RY5:b/[0b`/;44[:b/2;2`/7R/[:`ooool0
00goool2;2`/4R/[:`8Z:RX2;2`/=b/[:`8/;2`8:b/[0RXZ:TD[:b/3;2`/@B/[:`8/;2`N:b/[3ooo
o`003Oooo`8[:b/8;2`/42/[:`8/;2`K:b/[0R`/;6D[:b/2;2`/=B/[:`8/;2`?:b/[0R`/;1`[:b/?
oooo000=oooo0R/[:`P/;2`@:b/[0R`/;1/[:b/2;2`/IB/[:`8/;2`e:b/[0R`/;0l[:b/2;2`/72/[
:`ooool000goool>:b/[12`/;0@[:b/2;2`/3B/[:`8/;2`V:b/[0R`/;2<[:b/2;2`/LR/[:`8Z:RXL
:b/[3oooo`003Oooo`h[:b/4;2`/12/[:`8/;2`=:b/[0R`/;2H[:b/2;2`/8b/[:`8/;2ab:b/[0RXZ
:Q`[:b/?oooo000=ooooW2/[:`8/;2a8:b/[0R`/;1`[:b/?oooo000=ooooW2/[:`8/;2a8:b/[0R`/
;1`[:b/?oooo000=oooo6R/[:`8/;2aF:b/[0R`/;7@[:b/2;2`/6R/[:`ooool000gooolJ:b/[0R`/
;5H[:b/2;2`/M2/[:`8/;2`J:b/[3oooo`003Oooool[:b/5:b/[3oooo`003Oooool[:b/5:b/[3ooo
o`003OoooaX[:b/2;2`/j2/[:`ooool000gooolJ:b/[0R`/;>P[:b/?oooo000=ooooob/[:`D[:b/?
oooo000=ooooob/[:`D[:b/?oooo000=ooooob/[:`D[:b/?oooo000=ooooob/[:`D[:b/?oooo000=
ooooob/[:`D[:b/?oooo000=ooooob/[:`D[:b/?oooo000=ooooob/[:`D[:b/?oooo000=ooooob/[
:`D[:b/?oooo000=ooooBb/[:`8/;2bg:b/[3oooo`003Ooood/[:b/2;2`/]b/[:`ooool000gooolJ
:b/[0R`/;2l[:b/2;2`/Bb/[:`8Z:RYZ:b/[3oooo`003OoooaX[:b/2;2`/;b/[:`8/;2a;:b/[0RXZ
:VX[:b/?oooo000=oooo0R`/;0H[:b/2;2`/6b/[:`8/;2`2:b/[0R`/;6d[:b/2;2`/JR/[:`ooool0
00goool2;2`/1R/[:`8/;2`K:b/[0R`/;08[:b/2;2`/KB/[:`8/;2aZ:b/[3oooo`003Ooooe<[:b/4
;2`/[B/[:`ooool000gooomC:b/[12`/;:d[:b/?oooo000=oooo0R/[:`H/;2`::b/[0R`/;0@[:b/2
;2`/2B/[:`8/;2`4:b/[0R`/;0H[:b/2:RXZ0R`/;20[:b/2;2`/>b/[:`8/;2a`:b/[3oooo`003Ooo
o`8[:b/6;2`/2R/[:`8/;2`4:b/[0R`/;0T[:b/2;2`/12/[:`8/;2`6:b/[0RXZ:P8/;2`P:b/[0R`/
;3/[:b/2;2`/L2/[:`ooool000goool6:b/[0R`/;0P[:b/2;2`/7b/[:`8/;2`D:b/[0R`/;4L[:b/2
;2`/0R/[:`8/;2`?:b/[0R`/;5d[:b/?oooo000=oooo1R/[:`8/;2`8:b/[0R`/;1l[:b/2;2`/52/[
:`8/;2a7:b/[0R`/;08[:b/2;2`/3b/[:`8/;2aM:b/[3oooo`003OoooaH[:b/2;2`/6B/[:`8/;2bH
:b/[0R`/;0H[:b/2;2`/;b/[:`ooool000gooolF:b/[0R`/;1T[:b/2;2`/V2/[:`8/;2`6:b/[0R`/
;2l[:b/?oooo000=oooo:B/[:`8/;2cI:b/[3oooo`003OooobT[:b/2;2`/fB/[:`ooool000goool2
:RXZ12/[:`8/;2`2:RXZ0R`/;0H[:b/2;2`/7B/[:`8/;2`6:b/[0R`/;;4[:b/2;2`/5R/[:`ooool0
00goool2:RXZ12/[:`8/;2`2:RXZ0R`/;0H[:b/2;2`/7B/[:`8/;2`6:b/[0R`/;;4[:b/2;2`/5R/[
:`ooool000goool2:b/[12`/;10[:b/2:RXZ0R`/;1L[:b/2:RXZ>B/[:`8/;2bF:b/[3oooo`003Ooo
o`8[:b/4;2`/42/[:`8Z:RX2;2`/5b/[:`8Z:RXi:b/[0R`/;9H[:b/?oooo000=oooo5R/[:`8/;2`K
:b/[0R`/;3l[:b/2;2`/SR/[:`ooool000gooolF:b/[0R`/;1/[:b/2;2`/?b/[:`8/;2b>:b/[3ooo
o`003Oooo``[:b/2;2`/:b/[:`8/;2c9:b/[3oooo`003Oooo``[:b/2;2`/:b/[:`8/;2c9:b/[3ooo
o`003Oooool[:b/5:b/[3oooo`003Oooool[:b/5:b/[3oooo`003Oooool[:b/5:b/[3oooo`003Ooo
ool[:b/5:b/[3oooo`003Oooonh[:b/2:RXZ52/[:`ooool000goooo^:b/[0RXZ:Q@[:b/?oooo000=
ooooob/[:`D[:b/?oooo000=ooooob/[:`D[:b/?oooo000=ooooM2/[:`8/;2af:b/[0R`/;1H[:b/?
oooo000=ooooM2/[:`8/;2af:b/[0R`/;1H[:b/?oooo000=ooooob/[:`D[:b/?oooo000=ooooob/[
:`D[:b/?oooo000=ooooob/[:`D[:b/?oooo000=ooooob/[:`D[:b/?oooo000=ooooob/[:`D[:b/?
oooo000=ooooob/[:`D[:b/?oooo000=oooo0R`/;0H[:b/2;2`/nR/[:`ooool000goool2;2`/1R/[
:`8/;2cj:b/[3oooo`003Oooo`8/;2co:b/[0b/[:`ooool000goool2;2`/ob/[:`<[:b/?oooo000=
oooo0R`/;?l[:b/3:b/[3oooo`003Oooo`8/;2co:b/[0b/[:`ooool000goool2;2`/ob/[:`<[:b/?
oooo000=oooo0R`/;0@[:b/2:RXZ0R/[:`8/;2cL:b/[0RXZ:QX[:b/?oooo000=oooo0R`/;0@[:b/2
:RXZ0R/[:`8/;2cL:b/[0RXZ:QX[:b/?oooo000=oooo2R/[:`8/;2ch:b/[3oooo`003Oooo`X[:b/2
;2`/n2/[:`ooool000gooom`:b/[0R`/;98[:b/?oooo000=ooooL2/[:`8/;2bB:b/[3oooo`003Ooo
oaP[:b/2;2`/ER/[:`8Z:RY_:b/[1B`/;1h[:b/?oooo000=oooo62/[:`8/;2aF:b/[0RXZ:Vl[:b/5
;2`/7R/[:`ooool000gooolS:b/[0R`/;2X[:b/2;2`//b/[:`ooool000gooolS:b/[0R`/;2X[:b/2
;2`//b/[:`ooool000gooooo:b/[1B/[:`ooool000gooooo:b/[1B/[:`ooool000gooom^:b/[0RXZ
:UT[:b/2;2`/4R/[:`8/;2`U:b/[3oooo`003Oooofh[:b/2:RXZFB/[:`8/;2`B:b/[0R`/;2D[:b/?
oooo000=oooo2R/[:`8/;2`U:b/[0R`/;1P[:b/2;2`/5B/[:`8/;2`f:b/[0R`/;2T[:b/2;2`/?B/[
:`ooool000goool::b/[0R`/;2D[:b/2;2`/62/[:`8/;2`E:b/[0R`/;3H[:b/2;2`/:B/[:`8/;2`m
:b/[3oooo`003Oooof@[:b/2;2`/Lb/[:`8/;2`Y:b/[3oooo`003Oooof@[:b/2;2`/Lb/[:`8/;2`Y
:b/[3oooo`003Oooo`8Z:RX>:b/[0R`/;1<[:b/2;2`/12/[:`8/;2`6:b/[0R`/;28[:b/2;2`/1R/[
:`</;2`8:b/[0R`/;4l[:b/2;2`/6R/[:`8/;2`[:b/[3oooo`003Oooo`8Z:RX>:b/[0R`/;1<[:b/2
;2`/12/[:`8/;2`6:b/[0R`/;28[:b/2;2`/1R/[:`</;2`8:b/[0R`/;4l[:b/2;2`/6R/[:`8/;2`[
:b/[3oooo`003OoooaH[:b/2;2`/3b/[:`8Z:RXV:b/[0R`/;1T[:b/2:RXZJB/[:`8Z:RX]:b/[3ooo
o`003OoooaH[:b/2;2`/3b/[:`8Z:RXV:b/[0R`/;1T[:b/2:RXZJB/[:`8Z:RX]:b/[3oooo`003Ooo
o`8Z:RX4:b/[0R`/;0X[:b/2:RXZ0R`/;14[:b/4;2`/22/[:`8Z:RXL:b/[0R`/;1D[:b/2:RXZ0R`/
;9P[:b/?oooo000=oooo0RXZ:P@[:b/2;2`/2R/[:`8Z:RX2;2`/4B/[:`@/;2`8:b/[0RXZ:Q`[:b/2
;2`/5B/[:`8Z:RX2;2`/V2/[:`ooool000goool2:RXZ12/[:`8/;2`2:RXZ22/[:`8/;2`2:b/[0R`/
;1D[:b/2;2`/92/[:`8/;2`A:b/[0RXZ:Y`[:b/?oooo000=oooo0RXZ:P@[:b/2;2`/0RXZ:PP[:b/2
;2`/0R/[:`8/;2`E:b/[0R`/;2@[:b/2;2`/4B/[:`8Z:RZL:b/[3oooo`003Oooo`8Y:BT4:b/[12d]
;@8Z:RX8:b/[0R`/;08Y:BT2;2`/5B/[:`8/;2cC:b/[3oooo`003Oooo`8Y:BT4:b/[12d];@8Z:RX8
:b/[0R`/;08Y:BT2;2`/5B/[:`8/;2cC:b/[3oooo`003Oooool[:b/5:b/[3oooo`003Oooool[:b/5
:b/[3oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo001G
oooo0`00053oool30000Loooo`00F_ooo`030000oooooooo04koool00`000?ooooooo`1boooo001;
oooo0`0000Coool300000oooo`<00003oooo0P0000Goool300000_ooo`80000:oooo00<0003oool0
00000_ooo`D00002oooo0P0000Coool300000_ooo`<00004oooo0`0000?oool200002Oooo`<00003
oooo0`0000Coool300000oooo`<00003oooo0P0000?oool400000_ooo`L000001?ooo`000?ooo`00
04coool004coool00`000?ooooooo`04oooo00D0003oooooooooool000000_ooo`030000oooooooo
00Woool00`000?ooooooo`0<oooo00H0003oool0003oool0003oool400000oooo`800003oooo00<0
003oooooool01?ooo`030000oooooooo00;oool00`000?ooooooo`03oooo00@0003oooooool0000;
oooo00@0003oooooool00002oooo00@0003oooooool00005oooo00<0003oooooool00oooo`040000
oooooooo00000oooo`030000oooooooo00;oool400000_ooo`050000oooo0000oooo000004coool0
04coool00`000?ooooooo`04oooo00D0003oooooooooool000000_ooo`030000oooooooo00Koool5
00003Oooo`050000oooo0000oooo000000Coool010000?ooooooo`0000;oool00`000?ooooooo`04
00000oooo`030000oooooooo00;oool400000_ooo`030000oooooooo00Woool300000oooo`040000
oooooooo00000_ooo`@00002oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`05oooo00P0003oooooool0003oool0003oool0001<oooo001<oooo0P0000Coool200001?oo
o`@00007oooo00@0003oooooool0000>oooo00D0003oool0003oool000000_ooo`<000000oooo`00
00000002oooo0P0000;oool200001?ooo`030000oooooooo00?oool200000_ooo`D00008oooo1000
0003oooo0000000000800004oooo0P0000Coool3000000?oool0000000000`0000;oool400000ooo
o`<000001_ooo`00000000000?ooo`0004goool004coool010000?ooooooo`0001Coool00`000?oo
o`00000>oooo00D0003oooooooooool000005?ooo`030000oooooooo00Soool00`000?ooooooo`0Q
oooo00<0003oooooool0H?ooo`00Boooo`D00003oooo00<0003oooooool03oooo`80000=oooo0`00
0003oooo0000000001?oool20000TOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.47761, -2.56068, 0.491133, \
0.491133}}]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "According to the result shown in Fig. 4, we take only 25 percent wavelet \
spectrum into account. Namely, the monochrome image data is compressed into \
the 25 percent data. Apply an inverse wavelet transform to this 25 percent \
spectrum recovers the monochrome image approximately. Figure 5 shows a \
recovered image. It is revealed that the approximately recovered image in \
Fig. 5 is a poor image. This is because the original 128 by 128 resolution \
image has been reduced into a 32 by 32 resolution image.\n",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["\t",
    FormatType->InputForm],
  StyleBox[
  "To evaluate a correlation coefficient between the original and recovered \
image data, we construct an approximate 128 by 128 resolution wavelet \
spectrum. The following steps carry this out.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
partSpect=TakeMatrix[spect,{1,1},{dim[[2]]/4,dim[[3]]/4}];
wMatPrimeTrans=Table[Transpose[waveletMatrix[dim[[2]]/4,
\tbase[[i]]]],{i,2}];
recoverPrime=waveletND[partSpect,wMatPrimeTrans,2];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
ListDensityPlot[recoverPrime,PlotRange->All,
\tMesh->False,Frame->False,AspectRatio->dim[[2]]/dim[[3]],
\tPlotLabel->\"Fig.5.Compressed image\",ImageSize->{200,200}];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 200 200 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0300481 0.0192308 0.0300481 [
[.5 1.0125 -68 0 ]
[.5 1.0125 68 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.813 moveto
(.5) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Compressed) show
165.000 12.813 moveto
(image) show
195.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{200, 200},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000380000b1P00`40o`000?l0003ob?ooo`00b?oo
o`00b?ooo`00b?ooo`00b?ooo`002_ooo`Kclo<6l_;b;??cl`KemOD5fMWI1]OGe`_Jf]X5e=CD1/S8
b0Jm_Kd5/[:b1Zf][@F^[Zh6ZJVY1J6QX@K;bl/Qlo?c1_;blPKclo<;oooo000:oooo1_?cl`Kbl_8/
lo?c1_Gem@GIfMT6emOG2m[JfPGDe=@6b<S81[fm_@Fb/[86[Jf]1Jj^[PJYZJT5XJ6Q1/_;bb7clo<6
l_;b1_?cl`_oool000[oool6lo?c1_;blRcclo<6mOGe1MWIf@KGemL;f][J1MCDe0K8b<P6_Kfm1K:b
/PJ][Jd5[Zj^1ZVYZ@FQXJ46bl_;8O?cl`Kbl_86lo?c2oooo`002_ooo`Kclo<6l_;b;??cl`KemOD5
fMWI1]OGe`_Jf]X5e=CD1/S8b0Jm_Kd5/[:b1Zf][@F^[Zh6ZJVY1J6QX@K;bl/Qlo?c1_;blPKclo<;
oooo000:oooo1_?cl`Kbl_8/lo?c1_Gem@GIfMT6emOG2m[JfPGDe=@6b<S81[fm_@Fb/[86[Jf]1Jj^
[PJYZJT5XJ6Q1/_;bb7clo<6l_;b1_?cl`_oool000[oool6lo?c1_;blRcclo<6mOGe1MWIf@KGemL;
f][J1MCDe0K8b<P6_Kfm1K:b/PJ][Jd5[Zj^1ZVYZ@FQXJ46bl_;8O?cl`Kbl_86lo?c2oooo`002_oo
o`cbl_85lo?c1_;blR7clo<6m?Cd1MSHf0_GemL6d];B1Lg=c@K1`L46];Bd1KJf]Q6YZJT5Xj>S1^CT
i2gclo<;oooo000:oooo3?;blPGclo<6l_;b8O?cl`Kdm?@5f=SH2mOGe`KBd]85cLg=1/71`@Jd];@5
][Jf4JVYZ@FSXj<6i>CT;O?cl`_oool000[oool<l_;b1O?cl`Kbl_8Qlo?c1_Cdm0GHf=P;emOG1];B
dPG=cLd6`L711[Bd]0Ff][HAZJVY1J>SX`KTi>@]lo?c2oooo`002_ooo`cbl_85lo?c1_;blR7clo<6
m?Cd1MSHf0_GemL6d];B1Lg=c@K1`L46];Bd1KJf]Q6YZJT5Xj>S1^CTi2gclo<;oooo000:oooo3?;b
lPGclo<6l_;b8O?cl`Kdm?@5f=SH2mOGe`KBd]85cLg=1/71`@Jd];@5][Jf4JVYZ@FSXj<6i>CT;O?c
l`_oool000[ooolnlo?c1MKFePKCdm<5e]KF1][JfPGKfm/6eMGE1/W9b@G0`<06/k>c1Jj^[PJ/[:`5
[Jf]1^o_kbgclo<;oooo000:oooo?_?cl`GFe]H6dm?C1MKFePKJf]X5fm_K1]GEe@K9bLT5`<301[>c
/`F^[Zh6[:b/1Jf][@K_knl]lo?c2oooo`002_ooockclo<5e]KF1]?Cd`GFe]H6f][J1M_Kf`KEeMD6
bLW91L30`0Jc/k<5[Zj^1Zb/[0F][Jd6kno_;O?cl`_oool000[ooolnlo?c1MKFePKCdm<5e]KF1][J
fPGKfm/6eMGE1/W9b@G0`<06/k>c1Jj^[PJ/[:`5[Jf]1^o_kbgclo<;oooo000:oooo?_?cl`GFe]H6
dm?C1MKFePKJf]X5fm_K1]GEe@K9bLT5`<301[>c/`F^[Zh6[:b/1Jf][@K_knl]lo?c2oooo`002_oo
ockclo<5e]KF1]?Cd`GFe]H6f][J1M_Kf`KEeMD6bLW91L30`0Jc/k<5[Zj^1Zb/[0F][Jd6kno_;O?c
l`_oool000[ooolclo?c1O_kn`JYZJT5dm?C4MSHf0GJf]X6e]KF1/o?c`G2`/86][Jf1Jj^[PJ[Zj/5
]kNg<o?cl`_oool000[ooolclo?c1O_kn`JYZJT5dm?C4MSHf0GJf]X6e]KF1/o?c`G2`/86][Jf1Jj^
[PJ[Zj/5]kNg<o?cl`_oool000[ooolclo?c1O_kn`JYZJT5dm?C4MSHf0GJf]X6e]KF1/o?c`G2`/86
][Jf1Jj^[PJ[Zj/5]kNg<o?cl`_oool000[ooolclo?c1O_kn`JYZJT5dm?C4MSHf0GJf]X6e]KF1/o?
c`G2`/86][Jf1Jj^[PJ[Zj/5]kNg<o?cl`_oool000[ooolclo?c1O_kn`JYZJT5dm?C4MSHf0GJf]X6
e]KF1/o?c`G2`/86][Jf1Jj^[PJ[Zj/5]kNg<o?cl`_oool000[oool6l_;b1_7alB7clo<6n_[j1Kfm
_@J`/;05emOG1]SHf0GGemL6f][J1MWIf@K7alL6^k^k1KZj^PJa/K45[:b/1ZJVYPFb/[86kno_;O?c
l`_oool000[oool6l_;b1_7alB7clo<6n_[j1Kfm_@J`/;05emOG1]SHf0GGemL6f][J1MWIf@K7alL6
^k^k1KZj^PJa/K45[:b/1ZJVYPFb/[86kno_;O?cl`_oool000[oool6l_;b1_7alB7clo<6n_[j1Kfm
_@J`/;05emOG1]SHf0GGemL6f][J1MWIf@K7alL6^k^k1KZj^PJa/K45[:b/1ZJVYPFb/[86kno_;O?c
l`_oool000[oool6l_;b1_7alB7clo<6n_[j1Kfm_@J`/;05emOG1]SHf0GGemL6f][J1MWIf@K7alL6
^k^k1KZj^PJa/K45[:b/1ZJVYPFb/[86kno_;O?cl`_oool000[oool6l_;b1_7alB7clo<6n_[j1Kfm
_@J`/;05emOG1]SHf0GGemL6f][J1MWIf@K7alL6^k^k1KZj^PJa/K45[:b/1ZJVYPFb/[86kno_;O?c
l`_oool000[oool6l_;b1_7alB7clo<6n_[j1Kfm_@J`/;05emOG1]SHf0GGemL6f][J1MWIf@K7alL6
^k^k1KZj^PJa/K45[:b/1ZJVYPFb/[86kno_;O?cl`_oool000[oool6lo?c1_;blR7clo<6k>c/1JZZ
ZPKFe]H5f=SH1];BdPGEeMD6e]KF1LS8b0JQXJ46VYZJ1InOW`JTY:@5YZJV1Z^[Z`FTY:@6c<c<;O?c
l`_oool000[oool6lo?c1_;blR7clo<6k>c/1JZZZPKFe]H5f=SH1];BdPGEeMD6e]KF1LS8b0JQXJ46
VYZJ1InOW`JTY:@5YZJV1Z^[Z`FTY:@6c<c<;O?cl`_oool000[oool6lo?c1_;blR7clo<6k>c/1JZZ
ZPKFe]H5f=SH1];BdPGEeMD6e]KF1LS8b0JQXJ46VYZJ1InOW`JTY:@5YZJV1Z^[Z`FTY:@6c<c<;O?c
l`_oool000[oool6lo?c1_;blR7clo<6k>c/1JZZZPKFe]H5f=SH1];BdPGEeMD6e]KF1LS8b0JQXJ46
VYZJ1InOW`JTY:@5YZJV1Z^[Z`FTY:@6c<c<;O?cl`_oool000[oool6lo?c1_;blR7clo<6k>c/1JZZ
ZPKFe]H5f=SH1];BdPGEeMD6e]KF1LS8b0JQXJ46VYZJ1InOW`JTY:@5YZJV1Z^[Z`FTY:@6c<c<;O?c
l`_oool000[oool6lo?c1_;blQ_clo<6oooo1YRHV0G;bl/6clo?1MWIf@Jm_Kd5]KFe1[2`/0Fc/k<6
b<S81Zf][@F2PX86RXZ:1J2PX0Ja/K4;[Jf]1^7QhBOclo<;oooo000:oooo1_?cl`Kbl_8Klo?c1_oo
o`JHV9P5bl_;1/o?c`GIfMT6_Kfm1KFe]@J`/;05/k>c1/S8b0J][Jd5PX:21XZ:RPFPX:06/K6a2jf]
[@KQhN4Wlo?c2oooo`002_ooo`Kclo<6l_;b6o?cl`Koool6V9RH1L_;b`K?cll5fMWI1[fm_@Fe]KD6
/;2`1K>c/`K8b<P6[Jf]1H:2PPJ:RXX5X:2P1[6a/@^][Jd6hN7Q9o?cl`_oool000[oool6lo?c1_;b
lQ_clo<6oooo1YRHV0G;bl/6clo?1MWIf@Jm_Kd5]KFe1[2`/0Fc/k<6b<S81Zf][@F2PX86RXZ:1J2P
X0Ja/K4;[Jf]1^7QhBOclo<;oooo000:oooo1_?cl`Kbl_8Klo?c1_ooo`JHV9P5bl_;1/o?c`GIfMT6
_Kfm1KFe]@J`/;05/k>c1/S8b0J][Jd5PX:21XZ:RPFPX:06/K6a2jf][@KQhN4Wlo?c2oooo`002_oo
o`Kclo<6l_;b6o?cl`Koool6V9RH1L_;b`K?cll5fMWI1[fm_@Fe]KD6/;2`1K>c/`K8b<P6[Jf]1H:2
PPJ:RXX5X:2P1[6a/@^][Jd6hN7Q9o?cl`_oool000[oool6l_;b2o?cl`Kbl_8;lo?c1O;blPKVi^H6
P8201MCDe0K<c<`5e=CD1YfMW@EgMgL6b<S81MCDe0K;bl/6c<c<1KRh^0I`L705QXJ61[Rh^0Fe]KD6
ZJVY1[fm_@GShn<Rlo?c2oooo`002_ooo`Kbl_8;lo?c1_;blP_clo<5l_;b1^KViPJ0P805e=CD1/c<
c0GDe=@6WIfM1GMgM`K8b<P5e=CD1/_;b`K<c<`5^;Rh1W1`L0F6QXH6^;Rh1KFe]@JYZJT6_Kfm1N?S
hb;clo<;oooo000:oooo1_;blP_clo<6l_;b2o?cl`Gbl_86i^KV1X20P0GDe=@6c<c<1MCDe0JMWId5
MgMg1/S8b0GDe=@6bl_;1/c<c0Fh^;P6L71`1HJ6QPJh^;P5]KFe1ZVYZ@Jm_Kd5hn?S8_?cl`_oool0
00[oool6l_;b2o?cl`Kbl_8;lo?c1O;blPKVi^H6P8201MCDe0K<c<`5e=CD1YfMW@EgMgL6b<S81MCD
e0K;bl/6c<c<1KRh^0I`L705QXJ61[Rh^0Fe]KD6ZJVY1[fm_@GShn<Rlo?c2oooo`002_ooo`Kbl_8;
lo?c1_;blP_clo<5l_;b1^KViPJ0P805e=CD1/c<c0GDe=@6WIfM1GMgM`K8b<P5e=CD1/_;b`K<c<`5
^;Rh1W1`L0F6QXH6^;Rh1KFe]@JYZJT6_Kfm1N?Shb;clo<;oooo000:oooo3??cl`Gbl_8Alo?c1O_k
n`IJFUX6WYjN1Lo?c`K;bl/5b/[:1[>c/`GGemL6e=CD1M3@d0Jo_kl6[:b/1IfMW@JEUID5GemO1Zj^
[PFf][H<Z:RX1M3@d0Kbl_8Llo?c2oooo`002_ooo`cclo<5l_;b4O?cl`Gkno/6FUYJ1YjNWPG?cll6
bl_;1L[:bPJc/k<5emOG1]CDe0G@d=06_kno1Zb/[0FMWId6UIFE1EmOG`J^[Zh5][Jf3:RXZ0G@d=06
l_;b7??cl`_oool000[oool<lo?c1O;blQ7clo<5no_k1UYJFPJNWYh5clo?1/_;b`G:b/X6/k>c1MOG
e`KDe=@5d=3@1[no_`J/[:`5WIfM1YFEU@EOGel6[Zj^1KJf]PbXZ:P5d=3@1_;blQcclo<;oooo000:
oooo3??cl`Gbl_8Alo?c1O_kn`IJFUX6WYjN1Lo?c`K;bl/5b/[:1[>c/`GGemL6e=CD1M3@d0Jo_kl6
[:b/1IfMW@JEUID5GemO1Zj^[PFf][H<Z:RX1M3@d0Kbl_8Llo?c2oooo`002_ooo`cclo<5l_;b4O?c
l`Gkno/6FUYJ1YjNWPG?cll6bl_;1L[:bPJc/k<5emOG1]CDe0G@d=06_kno1Zb/[0FMWId6UIFE1EmO
G`J^[Zh5][Jf3:RXZ0G@d=06l_;b7??cl`_oool000[oool<lo?c1O;blQ7clo<5no_k1UYJFPJNWYh5
clo?1/_;b`G:b/X6/k>c1MOGe`KDe=@5d=3@1[no_`J/[:`5WIfM1YFEU@EOGel6[Zj^1KJf]PbXZ:P5
d=3@1_;blQcclo<;oooo000:oooo7??cl`Kdm?@5j>SX1/c<c0K=cLd5d];B1]SHf0GCdm<6[jn_1Lk>
cP_IfMT6_[jn1[Bd]0FQXJ46Vi^K1IVIV@J[Zj/5[Zj^1ZJVYPJATI45_;bl8_?cl`_oool000[ooolL
lo?c1_Cdm0GXj>P6c<c<1/g=c@GBd]86f=SH1M?Cd`J_[jl5c/k>2mWIf@Jn_[h6];Bd1J6QX@JKVi/5
VIVI1Z^[Z`F^[Zh6YZJV1Y6AT@Fl_;`Rlo?c2oooo`002_oooacclo<6m?Cd1NSXj0K<c<`6cLg=1M;B
dPKHf=P5dm?C1Zn_[`G>c/h;fMWI1[jn_PJd];@5XJ6Q1Y^KV`FIVIT6Zj^[1Jj^[PJVYZH6TI6A1Kbl
_2;clo<;oooo000:oooo7??cl`Kdm?@5j>SX1/c<c0K=cLd5d];B1]SHf0GCdm<6[jn_1Lk>cP_IfMT6
_[jn1[Bd]0FQXJ46Vi^K1IVIV@J[Zj/5[Zj^1ZJVYPJATI45_;bl8_?cl`_oool000[ooolLlo?c1_Cd
m0GXj>P6c<c<1/g=c@GBd]86f=SH1M?Cd`J_[jl5c/k>2mWIf@Jn_[h6];Bd1J6QX@JKVi/5VIVI1Z^[
Z`F^[Zh6YZJV1Y6AT@Fl_;`Rlo?c2oooo`002_oooacclo<6m_Kf1N7Qh@K2`/86c<c<1MOGe`KNg]h5
fm_K1/71`@Fm_Kd6emOG1MWIf@K7alL6[:b/1IVIV@JHV9P5XZ:R1[Fe]@F[Zj/6YjNW1XJ6QPF<S8`6
l_;b7??cl`_oool000[ooolLlo?c1_KfmPGQhN46`/;21/c<c0GGemL6g]kN1M_Kf`K1`L45_Kfm1]OG
e`GIfMT6alO71Zb/[0FIVIT6V9RH1J:RXPJe]KD5Zj^[1ZNWY`J6QXH5S8b<1_;blQcclo<;oooo000:
oooo7??cl`Kfm_H5hN7Q1/;2`PK<c<`5emOG1]kNgPGKfm/6`L711Kfm_@KGemL5fMWI1/O7a`J/[:`5
VIVI1YRHV0FRXZ86]KFe1J^[Z`JWYjL6QXJ61Hb<S0Kbl_8Llo?c2oooo`002_oooacclo<6m_Kf1N7Q
h@K2`/86c<c<1MOGe`KNg]h5fm_K1/71`@Fm_Kd6emOG1MWIf@K7alL6[:b/1IVIV@JHV9P5XZ:R1[Fe
]@F[Zj/6YjNW1XJ6QPF<S8`6l_;b7??cl`_oool000[ooolLlo?c1_KfmPGQhN46`/;21/c<c0GGemL6
g]kN1M_Kf`K1`L45_Kfm1]OGe`GIfMT6alO71Zb/[0FIVIT6V9RH1J:RXPJe]KD5Zj^[1ZNWY`J6QXH5
S8b<1_;blQcclo<;oooo000:oooo7??cl`Kfm_H5hN7Q1/;2`PK<c<`5emOG1]kNgPGKfm/6`L711Kfm
_@KGemL5fMWI1/O7a`J/[:`5VIVI1YRHV0FRXZ86]KFe1J^[Z`JWYjL6QXJ61Hb<S0Kbl_8Llo?c2ooo
o`002_oooacclo<6m?Cd1L30`0J/[:`6dM7A1MSHf0KOgml5f][J1/g=c@G7alL6d];B1MGEe@Jl_;`6
XJ6Q1I^KV`JIVIT5^KVi1[^k^`F^[Zh6YjNW1Z^[Z`F2PX86i>CT7??cl`_oool000[ooolLlo?c1_Cd
m0G0`<06[:b/1]7Ad@GHf=P6gmoO1M[JfPK=cLd5alO71];BdPGEeMD6_;bl1Z6QX@FKVi/6VIVI1KVi
^@Jk^k/5[Zj^1ZNWY`J[Zj/5PX:21^CTi1cclo<;oooo000:oooo7??cl`Kdm?@5`<301Zb/[0KAdM45
f=SH1]oOg`GJf]X6cLg=1LO7a`KBd]85eMGE1[bl_0JQXJ45Vi^K1YVIV@Fi^KT6^k^k1Jj^[PJWYjL6
Zj^[1H:2PPKTi>@Llo?c2oooo`002_oooacclo<6m?Cd1L30`0J/[:`6dM7A1MSHf0KOgml5f][J1/g=
c@G7alL6d];B1MGEe@Jl_;`6XJ6Q1I^KV`JIVIT5^KVi1[^k^`F^[Zh6YjNW1Z^[Z`F2PX86i>CT7??c
l`_oool000[ooolLlo?c1_Cdm0G0`<06[:b/1]7Ad@GHf=P6gmoO1M[JfPK=cLd5alO71];BdPGEeMD6
_;bl1Z6QX@FKVi/6VIVI1KVi^@Jk^k/5[Zj^1ZNWY`J[Zj/5PX:21^CTi1cclo<;oooo000:oooo5o?c
l`GgmoL6hN7Q1Jf][@J_[jl6eMGE1M_Kf`KHf=P5d=3@1/O7a`G=cLd6f=SH1MOGe`Je]KD6VIVI1I^K
V`J`/;05_Kfm1[Ng]`FZZZX6YJFU1ZJVYPFYZJT6l?3`7??cl`_oool000[ooolGlo?c1OOgm`KQhN45
[Jf]1Zn_[`KEeMD5fm_K1]SHf0G@d=06alO71Lg=c@KHf=P5emOG1[Fe]@JIVIT5Vi^K1[2`/0Fm_Kd6
]kNg1JZZZPJUYJD6YZJV1JVYZ@K`l?0Llo?c2oooo`002_oooaOclo<5moOg1^7Qh@F][Jd6[jn_1]GE
e@GKfm/6f=SH1M3@d0K7alL5cLg=1]SHf0GGemL6]KFe1YVIV@FKVi/6/;2`1Kfm_@Jg]kL5ZZZZ1ZFU
Y@JVYZH5ZJVY1_3`l1cclo<;oooo000:oooo5o?cl`GgmoL6hN7Q1Jf][@J_[jl6eMGE1M_Kf`KHf=P5
d=3@1/O7a`G=cLd6f=SH1MOGe`Je]KD6VIVI1I^KV`J`/;05_Kfm1[Ng]`FZZZX6YJFU1ZJVYPFYZJT6
l?3`7??cl`_oool000[ooolGlo?c1OOgm`KQhN45[Jf]1Zn_[`KEeMD5fm_K1]SHf0G@d=06alO71Lg=
c@KHf=P5emOG1[Fe]@JIVIT5Vi^K1[2`/0Fm_Kd6]kNg1JZZZPJUYJD6YZJV1JVYZ@K`l?0Llo?c2ooo
o`002_oooaOclo<5moOg1^7Qh@F][Jd6[jn_1]GEe@GKfm/6f=SH1M3@d0K7alL5cLg=1]SHf0GGemL6
]KFe1YVIV@FKVi/6/;2`1Kfm_@Jg]kL5ZZZZ1ZFUY@JVYZH5ZJVY1_3`l1cclo<;oooo000:oooo5o?c
l`GinOT6/K6a1F5QH@J][Jd6e]KF2mCDe0G<c<`6_[jn1L?3``KEeMD5e]KF1Zn_[`JGUiL5XJ6Q1[2`
/0Fd];@6/K6a1JZZZPJWYjL6UIFE1Hf=S@KNg]hLlo?c2oooo`002_oooaOclo<5nOWi1[6a/@EQHF46
[Jf]1]KFeP_De=@5c<c<1[jn_PG3`l<6eMGE1MKFePJ_[jl6UiNG1J6QX@J`/;05];Bd1[6a/@FZZZX6
YjNW1YFEU@F=SHd6g]kN7??cl`_oool000[ooolGlo?c1OWin@Ja/K45HF5Q1Zf][@KFe]H;e=CD1Lc<
c0Jn_[h5`l?31]GEe@GFe]H6[jn_1YNGU`FQXJ46/;2`1KBd]0Ja/K45ZZZZ1ZNWY`JEUID5SHf=1]kN
gQcclo<;oooo000:oooo5o?cl`GinOT6/K6a1F5QH@J][Jd6e]KF2mCDe0G<c<`6_[jn1L?3``KEeMD5
e]KF1Zn_[`JGUiL5XJ6Q1[2`/0Fd];@6/K6a1JZZZPJWYjL6UIFE1Hf=S@KNg]hLlo?c2oooo`002_oo
oaOclo<5nOWi1[6a/@EQHF46[Jf]1]KFeP_De=@5c<c<1[jn_PG3`l<6eMGE1MKFePJ_[jl6UiNG1J6Q
X@J`/;05];Bd1[6a/@FZZZX6YjNW1YFEU@F=SHd6g]kN7??cl`_oool000[ooolGlo?c1O;blPJMWId5
7alO1ZFUY@KBd]85d=3@1Xj>SPEjNWX6KFe]1H^;R`K;bl/5f=SH1Z^[Z`J<S8`5XJ6Q1ZNWY`FYZJT6
[jn_1JVYZ@JSXj<6Ti>C1FYZJPKGemLLlo?c2oooo`002_oooaOclo<5l_;b1YfMW@DO7al6YJFU1];B
dPG@d=06SXj>1GYjNPI]KFd5Rh^;1/_;b`GHf=P6Zj^[1Xb<S0FQXJ46YjNW1JVYZ@J_[jl5ZJVY1Z>S
X`JCTi<5JVYZ1]OGeacclo<;oooo000:oooo5o?cl`Gbl_86WIfM1AlO7`JUYJD6d];B1M3@d0J>SXh5
NWYj1Ve]K@F;Rh/6bl_;1MSHf0J[Zj/6S8b<1J6QX@JWYjL5ZJVY1Zn_[`FYZJT6Xj>S1Y>CT`EZJVX6
emOG7??cl`_oool000[ooolGlo?c1O;blPJMWId57alO1ZFUY@KBd]85d=3@1Xj>SPEjNWX6KFe]1H^;
R`K;bl/5f=SH1Z^[Z`J<S8`5XJ6Q1ZNWY`FYZJT6[jn_1JVYZ@JSXj<6Ti>C1FYZJPKGemLLlo?c2ooo
o`002_oooaOclo<5l_;b1YfMW@DO7al6YJFU1];BdPG@d=06SXj>1GYjNPI]KFd5Rh^;1/_;b`GHf=P6
Zj^[1Xb<S0FQXJ46YjNW1JVYZ@J_[jl5ZJVY1Z>SX`JCTi<5JVYZ1]OGeacclo<;oooo000:oooo5o?c
l`Gbl_86WIfM1AlO7`JUYJD6d];B1M3@d0J>SXh5NWYj1Ve]K@F;Rh/6bl_;1MSHf0J[Zj/6S8b<1J6Q
X@JWYjL5ZJVY1Zn_[`FYZJT6Xj>S1Y>CT`EZJVX6emOG7??cl`_oool000[oool6l_;b2o?cl`KinOT5
K6a/1YjNWPDM7Ad6YZJV1/[:bPGCdm<6cLg=1IfMW@I]KFd5UIFE1/c<c0GLg=`6[Jf]1WinOPF>SXh6
De=C1FQXJ0IgMgL5UiNG1ZBTY0IbLW85Kfm_1]KFeQcclo<;oooo000:oooo1_;blP_clo<6nOWi1Fa/
K0JNWYh57AdM1ZJVYPK:b/X5dm?C1/g=c@FMWId6KFe]1IFEU@K<c<`5g=cL1Zf][@InOWh5SXj>1U=C
D`EXJ6P6MgMg1INGU`JTY:@6LW9b1Fm_K`KFe]HLlo?c2oooo`002_ooo`Kbl_8;lo?c1_Win@E/K6`6
WYjN1AdM7@JVYZH6b/[:1M?Cd`K=cLd5WIfM1Ve]K@FEUID6c<c<1McLg0J][Jd6OWin1Hj>SPICDe<5
J6QX1WMgM`FGUiL6Y:BT1W9bLPE_Kfl6e]KF7??cl`_oool000[oool6l_;b2o?cl`KinOT5K6a/1YjN
WPDM7Ad6YZJV1/[:bPGCdm<6cLg=1IfMW@I]KFd5UIFE1/c<c0GLg=`6[Jf]1WinOPF>SXh6De=C1FQX
J0IgMgL5UiNG1ZBTY0IbLW85Kfm_1]KFeQcclo<;oooo000:oooo1_;blP_clo<6nOWi1Fa/K0JNWYh5
7AdM1ZJVYPK:b/X5dm?C1/g=c@FMWId6KFe]1IFEU@K<c<`5g=cL1Zf][@InOWh5SXj>1U=CD`EXJ6P6
MgMg1INGU`JTY:@6LW9b1Fm_K`KFe]HLlo?c2oooo`002_ooo`cclo<5moOg1]7Ad@DY:BT6:RXZ1A@D
50JTY:@6d];B1KJf]PJc/k<5VYZJ1XB4Q0FIVIT6c/k>1M;BdPJa/K46TY:B1IjNWPIfMWH5IVIV1XZ:
RPFMWId6Y:BT1TQ8B0EDE5@6clo?7??cl`_oool000[oool<lo?c1OOgm`KAdM45:BTY1RXZ:PDD51@6
Y:BT1];BdPFf][H6/k>c1IZJVPJ4Q8@5VIVI1/k>cPGBd]86/K6a1Y:BTPFNWYh6MWIf1FIVIPJ:RXX5
WIfM1ZBTY0I8B4P5E5AD1/o?cacclo<;oooo000:oooo3??cl`GgmoL6dM7A1BTY:@HZ:RX551@D1ZBT
Y0KBd]85][Jf1[>c/`FJVYX6Q8B41IVIV@K>c/h5d];B1[6a/@JBTY85WYjN1WIfMPEVIVH6RXZ:1IfM
W@JTY:@6B4Q81EADE0K?cllLlo?c2oooo`002_ooo`cclo<5moOg1]7Ad@DY:BT6:RXZ1A@D50JTY:@6
d];B1KJf]PJc/k<5VYZJ1XB4Q0FIVIT6c/k>1M;BdPJa/K46TY:B1IjNWPIfMWH5IVIV1XZ:RPFMWId6
Y:BT1TQ8B0EDE5@6clo?7??cl`_oool000[oool<lo?c1OOgm`KAdM45:BTY1RXZ:PDD51@6Y:BT1];B
dPFf][H6/k>c1IZJVPJ4Q8@5VIVI1/k>cPGBd]86/K6a1Y:BTPFNWYh6MWIf1FIVIPJ:RXX5WIfM1ZBT
Y0I8B4P5E5AD1/o?cacclo<;oooo000:oooo3??cl`GgmoL6dM7A1BTY:@HZ:RX551@D1ZBTY0KBd]85
][Jf1[>c/`FJVYX6Q8B41IVIV@K>c/h5d];B1[6a/@JBTY85WYjN1WIfMPEVIVH6RXZ:1IfMW@JTY:@6
B4Q81EADE0K?cllLlo?c2oooo`002_ooo`Kbl_86lo?c1OKfmPKHf=P59BDU1QTI6@DK6a/6UYJF1];B
dPGIfMT6cLg=1L_;b`K3`l<5bl_;1]GEe@G:b/X6`<301Xj>SPE[Jf/6Q8B41J2PX0^IVIT6V9RH1R4Q
8@EIFET6Y:BT7??cl`_oool000[oool6l_;b1_?cl`Gfm_H6f=SH1BDU9@HI6AT56a/K1YJFUPKBd]85
fMWI1/g=c@G;bl/6`l?31L_;b`KEeMD5b/[:1/30`0J>SXh5Jf][1XB4Q0FPX:0;VIVI1YRHV0HQ8B45
FEUI1ZBTY1cclo<;oooo000:oooo1_;blPKclo<5m_Kf1]SHf0DU9BD66ATI1A/K6`JFUYH6d];B1MWI
f@K=cLd5bl_;1/?3``G;bl/6eMGE1L[:bPK0`<06SXj>1F][J`J4Q8@5X:2P2iVIV@JHV9P68B4Q1EUI
F@JTY:@Llo?c2oooo`002_ooo`Kbl_86lo?c1OKfmPKHf=P59BDU1QTI6@DK6a/6UYJF1];BdPGIfMT6
cLg=1L_;b`K3`l<5bl_;1]GEe@G:b/X6`<301Xj>SPE[Jf/6Q8B41J2PX0^IVIT6V9RH1R4Q8@EIFET6
Y:BT7??cl`_oool000[oool6l_;b1_?cl`Gfm_H6f=SH1BDU9@HI6AT56a/K1YJFUPKBd]85fMWI1/g=
c@G;bl/6`l?31L_;b`KEeMD5b/[:1/30`0J>SXh5Jf][1XB4Q0FPX:0;VIVI1YRHV0HQ8B45FEUI1ZBT
Y1cclo<;oooo000:oooo3??cl`Gfm_H6g=cL1CXj>PHP82058R8R1X20P0K?cll5fMWI1]oOg`GTi>@6
hn?S1McLg0KBd]85b<S81/K6aPK2`/85[jn_1X20P0E]KFd6OWin1J6QX@IcLg<6820P1A/K6`I^KVhL
lo?c2oooo`002_ooo`cclo<5m_Kf1]cLg0Dj>SX6820P1B8R8PJ0P806clo?1MWIf@KOgml5i>CT1^?S
h`GLg=`6d];B1LS8b0K6a/H6`/;21Jn_[`J0P805KFe]1WinOPFQXJ46Lg=c1R0P80DK6a/6KVi^7??c
l`_oool000[oool<lo?c1OKfmPKLg=`5>SXj1R0P80DR8R86P8201/o?c`GIfMT6gmoO1NCTi0KShn<5
g=cL1];BdPG8b<P6a/K61/;2`PF_[jl6P8201Fe]K@InOWh5XJ6Q1W=cL`HP82056a/K1Vi^KQcclo<;
oooo000:oooo3??cl`Gfm_H6g=cL1CXj>PHP82058R8R1X20P0K?cll5fMWI1]oOg`GTi>@6hn?S1McL
g0KBd]85b<S81/K6aPK2`/85[jn_1X20P0E]KFd6OWin1J6QX@IcLg<6820P1A/K6`I^KVhLlo?c2ooo
o`002_ooo`cclo<5m_Kf1]cLg0Dj>SX6820P1B8R8PJ0P806clo?1MWIf@KOgml5i>CT1^?Sh`GLg=`6
d];B1LS8b0K6a/H6`/;21Jn_[`J0P805KFe]1WinOPFQXJ46Lg=c1R0P80DK6a/6KVi^7??cl`_oool0
00[oool<lo?c1OKfmPKLg=`5>SXj1R0P80DR8R86P8201/o?c`GIfMT6gmoO1NCTi0KShn<5g=cL1];B
dPG8b<P6a/K61/;2`PF_[jl6P8201Fe]K@InOWh5XJ6Q1W=cL`HP82056a/K1Vi^KQcclo<;oooo000:
oooo3??cl`Gno_h6/K6a1DA4A0HY:BT5820P1Te=C@Jl_;`5f=SH1]oOg`_Shn<5fm_K1]3@d0G5aLD6
`l?31[bl_0Ff][H6/;2`1JRXZ0JTY:@5XJ6Q1TI6APHM7Ad551@D1S4a<@GXj>PGlo?c2oooo`002_oo
o`cclo<5o_kn1[6a/@E4A4@6:BTY1B0P80I=CDd6_;bl1MSHf0KOgml;hn?S1M_Kf`K@d=05aLG51/?3
``Jl_;`5][Jf1[2`/0FXZ:P6Y:BT1J6QX@I6ATH67AdM1A@D50Ha<C45j>SX5o?cl`_oool000[oool<
lo?c1OknoPJa/K45A4A41RTY:@DP8206CDe=1[bl_0GHf=P6gmoO2n?Sh`GKfm/6d=3@1LG5a@K3`l<6
_;bl1KJf]PJ`/;05Z:RX1ZBTY0FQXJ46ATI61QdM7@DD51@6<C4a1NSXj1Oclo<;oooo000:oooo3??c
l`Gno_h6/K6a1DA4A0HY:BT5820P1Te=C@Jl_;`5f=SH1]oOg`_Shn<5fm_K1]3@d0G5aLD6`l?31[bl
_0Ff][H6/;2`1JRXZ0JTY:@5XJ6Q1TI6APHM7Ad551@D1S4a<@GXj>PGlo?c2oooo`002_ooo`cclo<5
o_kn1[6a/@E4A4@6:BTY1B0P80I=CDd6_;bl1MSHf0KOgml;hn?S1M_Kf`K@d=05aLG51/?3``Jl_;`5
][Jf1[2`/0FXZ:P6Y:BT1J6QX@I6ATH67AdM1A@D50Ha<C45j>SX5o?cl`_oool000[oool<lo?c1Ooo
o`J[Zj/5BDU91SLg=`DT92@6?clo1YjNWPGDe=@6gMgM1N?Sh`KRh^85f][J1/g=c@Fo_kl6_Kfm1[Ng
]`F`/;06Zj^[1JNWY`JQXJ45OWin1Rh^;PHE5AD52PX:1S/k>`G_knlGlo?c2oooo`002_ooo`cclo<5
oooo1Z^[Z`E9BDT6=cLg1B@T90Ho?cl6WYjN1MCDe0KMgMd5hn?S1^;RhPGJf]X6cLg=1Kno_`Jm_Kd6
]kNg1K2`/0J[Zj/5YjNW1Z6QX@EnOWh6;Rh^1QDE5@D:2PX6>c/k1No_kaOclo<;oooo000:oooo3??c
l`Goool6Zj^[1DU9B@Hg=cL592@T1Slo?`JNWYh5e=CD1]gMg@GShn<6h^;R1M[JfPK=cLd5_kno1[fm
_@Jg]kL5/;2`1Z^[Z`FWYjL6XJ6Q1GinOPH^;Rh65ADE1@X:2PHk>c/5kno_5o?cl`_oool000[oool<
lo?c1Oooo`J[Zj/5BDU91SLg=`DT92@6?clo1YjNWPGDe=@6gMgM1N?Sh`KRh^85f][J1/g=c@Fo_kl6
_Kfm1[Ng]`F`/;06Zj^[1JNWY`JQXJ45OWin1Rh^;PHE5AD52PX:1S/k>`G_knlGlo?c2oooo`002_oo
o`cclo<5oooo1Z^[Z`E9BDT6=cLg1B@T90Ho?cl6WYjN1MCDe0KMgMd5hn?S1^;RhPGJf]X6cLg=1Kno
_`Jm_Kd6]kNg1K2`/0J[Zj/5YjNW1Z6QX@EnOWh6;Rh^1QDE5@D:2PX6>c/k1No_kaOclo<;oooo000:
oooo3??cl`Goool6Zj^[1DU9B@Hg=cL592@T1Slo?`JNWYh5e=CD1]gMg@GShn<6h^;R1M[JfPK=cLd5
_kno1[fm_@Jg]kL5/;2`1Z^[Z`FWYjL6XJ6Q1GinOPH^;Rh65ADE1@X:2PHk>c/5kno_5o?cl`_oool0
00[oool<lo?c1OknoPJ[Zj/;ADE51B/[:`I2@T86P8201L[:bPKJf]X5g]kN1]cLg0GEeMD6alO71K^k
^`Jh^;P6][Jf1Jf][@JVYZH5Y:BT1Y2@T0EADE4692@T1QXJ6PD10@46MWIf7??cl`_oool000[oool<
lo?c1OknoPJ[Zj/;ADE51B/[:`I2@T86P8201L[:bPKJf]X5g]kN1]cLg0GEeMD6alO71K^k^`Jh^;P6
][Jf1Jf][@JVYZH5Y:BT1Y2@T0EADE4692@T1QXJ6PD10@46MWIf7??cl`_oool000[oool<lo?c1Okn
oPJ[Zj/;ADE51B/[:`I2@T86P8201L[:bPKJf]X5g]kN1]cLg0GEeMD6alO71K^k^`Jh^;P6][Jf1Jf]
[@JVYZH5Y:BT1Y2@T0EADE4692@T1QXJ6PD10@46MWIf7??cl`_oool000[oool<lo?c1OknoPJ[Zj/;
ADE51B/[:`I2@T86P8201L[:bPKJf]X5g]kN1]cLg0GEeMD6alO71K^k^`Jh^;P6][Jf1Jf][@JVYZH5
Y:BT1Y2@T0EADE4692@T1QXJ6PD10@46MWIf7??cl`_oool000[oool<lo?c1OknoPJ[Zj/;ADE51B/[
:`I2@T86P8201L[:bPKJf]X5g]kN1]cLg0GEeMD6alO71K^k^`Jh^;P6][Jf1Jf][@JVYZH5Y:BT1Y2@
T0EADE4692@T1QXJ6PD10@46MWIf7??cl`_oool000[oool<lo?c1O[jnPK6a/H5ADE51TQ8B0D_;bl6
>SXj1UADE0F`/;06clo?1MGEe@K@d=05bl_;1[bl_0^b/[86[Jf]1JVYZ@JUYJD5U9BD1UmOG`DX:2P6
61PH1Q4A4@D92@T6`<307??cl`_oool000[oool<lo?c1O[jnPK6a/H5ADE51TQ8B0D_;bl6>SXj1UAD
E0F`/;06clo?1MGEe@K@d=05bl_;1[bl_0^b/[86[Jf]1JVYZ@JUYJD5U9BD1UmOG`DX:2P661PH1Q4A
4@D92@T6`<307??cl`_oool000[oool<lo?c1O[jnPK6a/H5ADE51TQ8B0D_;bl6>SXj1UADE0F`/;06
clo?1MGEe@K@d=05bl_;1[bl_0^b/[86[Jf]1JVYZ@JUYJD5U9BD1UmOG`DX:2P661PH1Q4A4@D92@T6
`<307??cl`_oool000[oool<lo?c1O[jnPK6a/H5ADE51TQ8B0D_;bl6>SXj1UADE0F`/;06clo?1MGE
e@K@d=05bl_;1[bl_0^b/[86[Jf]1JVYZ@JUYJD5U9BD1UmOG`DX:2P661PH1Q4A4@D92@T6`<307??c
l`_oool000[oool<lo?c1O[jnPK6a/H5ADE51TQ8B0D_;bl6>SXj1UADE0F`/;06clo?1MGEe@K@d=05
bl_;1[bl_0^b/[86[Jf]1JVYZ@JUYJD5U9BD1UmOG`DX:2P661PH1Q4A4@D92@T6`<307??cl`_oool0
00[oool<lo?c1O[jnPK6a/H5ADE51TQ8B0D_;bl6>SXj1UADE0F`/;06clo?1MGEe@K@d=05bl_;1[bl
_0^b/[86[Jf]1JVYZ@JUYJD5U9BD1UmOG`DX:2P661PH1Q4A4@D92@T6`<307??cl`_oool000[ooolA
lo?c1_7al@EGEeL6B4Q81C<c<`Hf=SH6@D511F9RHPJDU9@5[Zj^1[Bd]0Ff][H6U9BD1IVIV@JNWYh6
WinO1IRHV0J;Rh/5IVIV1S<c<`DD51@62`/;1P820PDb<S86j^[Z7??cl`_oool000[ooolAlo?c1_7a
l@EGEeL6B4Q81C<c<`Hf=SH6@D511F9RHPJDU9@5[Zj^1[Bd]0Ff][H6U9BD1IVIV@JNWYh6WinO1IRH
V0J;Rh/5IVIV1S<c<`DD51@62`/;1P820PDb<S86j^[Z7??cl`_oool000[ooolAlo?c1_7al@EGEeL6
B4Q81C<c<`Hf=SH6@D511F9RHPJDU9@5[Zj^1[Bd]0Ff][H6U9BD1IVIV@JNWYh6WinO1IRHV0J;Rh/5
IVIV1S<c<`DD51@62`/;1P820PDb<S86j^[Z7??cl`_oool000[ooolAlo?c1_7al@EGEeL6B4Q81C<c
<`Hf=SH6@D511F9RHPJDU9@5[Zj^1[Bd]0Ff][H6U9BD1IVIV@JNWYh6WinO1IRHV0J;Rh/5IVIV1S<c
<`DD51@62`/;1P820PDb<S86j^[Z7??cl`_oool000[ooolAlo?c1_7al@EGEeL6B4Q81C<c<`Hf=SH6
@D511F9RHPJDU9@5[Zj^1[Bd]0Ff][H6U9BD1IVIV@JNWYh6WinO1IRHV0J;Rh/5IVIV1S<c<`DD51@6
2`/;1P820PDb<S86j^[Z7??cl`_oool000[ooolAlo?c1_knoPF>SXh6ADE51CXj>PHk>c/6DE5A1EEE
E@IQHF45FEUI1U]KF`E/K6`6E5AD1EEEE@IYJFT6Jf][1FATI0IKFe/5=SHf1Q/K6`D<30`600001PL7
1`FBTY8Rlo?c2oooo`002_oooa7clo<6o_kn1Hj>SPI5ADD5>SXj1S/k>`IADE45EEEE1V5QH@EIFET6
Fe]K1Fa/K0IDE5@5EEEE1VUYJ@I[Jf/5I6AT1U]KF`Df=SH66a/K1@`<30H000061`L71I:BTR;clo<;
oooo000:oooo4O?cl`Kno_h5SXj>1TE5A@Dj>SX6>c/k1U5AD@EEEED6HF5Q1EUIF@IKFe/5K6a/1UAD
E0EEEED6JFUY1V][J`ETI6@6Fe]K1CHf=PHK6a/530`<1P0000H71`L5TY:B8_?cl`_oool000[ooolA
lo?c1_knoPF>SXh6ADE51CXj>PHk>c/6DE5A1EEEE@IQHF45FEUI1U]KF`E/K6`6E5AD1EEEE@IYJFT6
Jf][1FATI0IKFe/5=SHf1Q/K6`D<30`600001PL71`FBTY8Rlo?c2oooo`002_oooa7clo<6o_kn1Hj>
SPI5ADD5>SXj1S/k>`IADE45EEEE1V5QH@EIFET6Fe]K1Fa/K0IDE5@5EEEE1VUYJ@I[Jf/5I6AT1U]K
F`Df=SH66a/K1@`<30H000061`L71I:BTR;clo<;oooo000:oooo4O?cl`Kno_h5SXj>1TE5A@Dj>SX6
>c/k1U5AD@EEEED6HF5Q1EUIF@IKFe/5K6a/1UADE0EEEED6JFUY1V][J`ETI6@6Fe]K1CHf=PHK6a/5
30`<1P0000H71`L5TY:B8_?cl`_oool000[ooolAlo?c1_Ogm`GGemL6D51@1D51@@aADE45Cdm?1TM7
A`Dl?3`6>3Ph1CHf=PH[:b/58b<S1RHV9PH[:b/59bLW1R@T90DL71`63@d=1@<30`H:2PX6Bd];1NWY
jB;clo<;oooo000:oooo4O?cl`KgmoL5emOG1U1@D0E1@D4<DE5A1Dm?C`I7AdL5?3`l1SPh>0Df=SH6
:b/[1B<S8`HV9RH6:b/[1BLW9`HT92@571`L1Pd=3@D30`<62PX:1T];B`GYjNTRlo?c2oooo`002_oo
oa7clo<6moOg1MOGe`I@D505@D51355AD@E?Cdl6AdM71C`l?0Hh>3P5=SHf1R/[:`DS8b<69RHV1R/[
:`DW9bL692@T1A`L70H=3@d50`<31PX:2PI;Bd/5jNWY8_?cl`_oool000[ooolAlo?c1_Ogm`GGemL6
D51@1D51@@aADE45Cdm?1TM7A`Dl?3`6>3Ph1CHf=PH[:b/58b<S1RHV9PH[:b/59bLW1R@T90DL71`6
3@d=1@<30`H:2PX6Bd];1NWYjB;clo<;oooo000:oooo4O?cl`KgmoL5emOG1U1@D0E1@D4<DE5A1Dm?
C`I7AdL5?3`l1SPh>0Df=SH6:b/[1B<S8`HV9RH6:b/[1BLW9`HT92@571`L1Pd=3@D30`<62PX:1T];
B`GYjNTRlo?c2oooo`002_oooaOclo<5oOgm1Xj>SPE5ADD6A4A41Te=C@E1@D46;Rh^1Bl_;`HZ:RX5
7AdM1Q/K6`DA4A4<5ADE1AHF5PHA4A4520P81PX:2PD>3Ph6>c/k1]gMgBOclo<;oooo000:oooo5o?c
l`GmoOd6SXj>1DE5A@I4A4@6CDe=1D51@@H^;Rh5;bl_1RXZ:PDM7Ad66a/K1A4A4@`E5AD55QHF1Q4A
4@D820P62PX:1@h>3PHk>c/6gMgM9o?cl`_oool000[ooolGlo?c1Ogmo@J>SXh5ADE51TA4A0I=CDd5
@D511Rh^;PD_;bl6:RXZ1AdM7@HK6a/54A4A31DE5@DF5QH64A4A1@P820H:2PX53Ph>1S/k>`KMgMdW
lo?c2oooo`002_oooaOclo<5oOgm1Xj>SPE5ADD6A4A41Te=C@E1@D46;Rh^1Bl_;`HZ:RX57AdM1Q/K
6`DA4A4<5ADE1AHF5PHA4A4520P81PX:2PD>3Ph6>c/k1]gMgBOclo<;oooo000:oooo5o?cl`GmoOd6
SXj>1DE5A@I4A4@6CDe=1D51@@H^;Rh5;bl_1RXZ:PDM7Ad66a/K1A4A4@`E5AD55QHF1Q4A4@D820P6
2PX:1@h>3PHk>c/6gMgM9o?cl`_oool000[ooolGlo?c1Ogmo@J>SXh5ADE51TA4A0I=CDd5@D511Rh^
;PD_;bl6:RXZ1AdM7@HK6a/54A4A31DE5@DF5QH64A4A1@P820H:2PX53Ph>1S/k>`KMgMdWlo?c2ooo
o`002_oooaOclo<5m?Cd1_7al@EaLG46ADE51Te=C@Do?cl68B4Q1A/K6`HG5aL54Q8B1Q4A4@D<30`6
5QHF1R/[:`DM7Ad65QHF1AXJ6PHQ8B45:b/[1[Ng]bgclo<;oooo000:oooo5o?cl`Gdm?@6lO7a1G5a
L@I5ADD6CDe=1Clo?`HQ8B456a/K1QLG5`DB4Q864A4A1@`<30HF5QH6:b/[1AdM7@HF5QH56QXJ1R4Q
8@D[:b/6]kNg;O?cl`_oool000[ooolGlo?c1OCdm0KalO45LG5a1TE5A@I=CDd5?clo1R4Q8@DK6a/6
5aLG1A8B4PHA4A4530`<1QHF5PH[:b/57AdM1QHF5PDJ6QX68B4Q1B/[:`Jg]kL]lo?c2oooo`002_oo
oaOclo<5m?Cd1_7al@EaLG46ADE51Te=C@Do?cl68B4Q1A/K6`HG5aL54Q8B1Q4A4@D<30`65QHF1R/[
:`DM7Ad65QHF1AXJ6PHQ8B45:b/[1[Ng]bgclo<;oooo000:oooo5o?cl`Gdm?@6lO7a1G5aL@I5ADD6
CDe=1Clo?`HQ8B456a/K1QLG5`DB4Q864A4A1@`<30HF5QH6:b/[1AdM7@HF5QH56QXJ1R4Q8@D[:b/6
]kNg;O?cl`_oool000[ooolLlo?c1_KfmPG[jn/6M7Ad1TY:BPEOGel6=CDe1B@T90HP82055ADE1Q<C
4`DF5QH66ATI1S8b<PDc<c<6<S8b1C0`<0Hl?3`5Vi^K<o?cl`_oool000[ooolLlo?c1_KfmPG[jn/6
M7Ad1TY:BPEOGel6=CDe1B@T90HP82055ADE1Q<C4`DF5QH66ATI1S8b<PDc<c<6<S8b1C0`<0Hl?3`5
Vi^K<o?cl`_oool000[ooolLlo?c1_KfmPG[jn/6M7Ad1TY:BPEOGel6=CDe1B@T90HP82055ADE1Q<C
4`DF5QH66ATI1S8b<PDc<c<6<S8b1C0`<0Hl?3`5Vi^K<o?cl`_oool000[ooolLlo?c1_KfmPG[jn/6
M7Ad1TY:BPEOGel6=CDe1B@T90HP82055ADE1Q<C4`DF5QH66ATI1S8b<PDc<c<6<S8b1C0`<0Hl?3`5
Vi^K<o?cl`_oool000[ooolLlo?c1_KfmPG[jn/6M7Ad1TY:BPEOGel6=CDe1B@T90HP82055ADE1Q<C
4`DF5QH66ATI1S8b<PDc<c<6<S8b1C0`<0Hl?3`5Vi^K<o?cl`_oool000[ooolLlo?c1_KfmPG[jn/6
M7Ad1TY:BPEOGel6=CDe1B@T90HP82055ADE1Q<C4`DF5QH66ATI1S8b<PDc<c<6<S8b1C0`<0Hl?3`5
Vi^K<o?cl`_oool000[ooolRlo?c1OCdm0Kbl_86UIFE1F=SH`IYJFT5EUIF1Te=C@E;Bd/6?3`l1D51
@@I=CDd6BDU91DM7A`I=CDd5Cdm?1[Fe]CSclo<;oooo000:oooo8_?cl`Gdm?@6l_;b1YFEU@ESHf<6
JFUY1EIFEPI=CDd5Bd];1S`l?0E1@D46CDe=1TU9B@E7AdL6CDe=1Dm?C`Je]KDhlo?c2oooo`002_oo
ob;clo<5m?Cd1_;blPJEUID5Hf=S1VUYJ@EFEUH6CDe=1D];B`Hl?3`5@D511Te=C@I9BDT5AdM71Te=
C@E?Cdl6]KFe>??cl`_oool000[ooolRlo?c1OCdm0Kbl_86UIFE1F=SH`IYJFT5EUIF1Te=C@E;Bd/6
?3`l1D51@@I=CDd6BDU91DM7A`I=CDd5Cdm?1[Fe]CSclo<;oooo000:oooo8_?cl`Gdm?@6l_;b1YFE
U@ESHf<6JFUY1EIFEPI=CDd5Bd];1S`l?0E1@D46CDe=1TU9B@E7AdL6CDe=1Dm?C`Je]KDhlo?c2ooo
o`002_ooobgclo<6mOGe1M[JfPJOWil5W9bL1YBDU0EkNg/6MGEe1FUYJ@ITI6@6IVIV1FATI0JHV9P5
g]kN?_?cl`_oool000[oool]lo?c1_Gem@GJf]X6WinO1IbLW0JDU9@5Ng]k1WEeM@EYJFT6I6AT1VIV
IPETI6@6V9RH1MkNgSkclo<;oooo000:oooo;O?cl`KemOD5f][J1YnOW`FLW9`6U9BD1G]kN`IeMGD5
JFUY1VATI0IVIVH5I6AT1YRHV0GNg]hnlo?c2oooo`002_ooobgclo<6mOGe1M[JfPJOWil5W9bL1YBD
U0EkNg/6MGEe1FUYJ@ITI6@6IVIV1FATI0JHV9P5g]kN?_?cl`_oool000[oool]lo?c1_Gem@GJf]X6
WinO1IbLW0JDU9@5Ng]k1WEeM@EYJFT6I6AT1VIVIPETI6@6V9RH1MkNgSkclo<;oooo000:oooo;O?c
l`KemOD5f][J1YnOW`FLW9`6U9BD1G]kN`IeMGD5JFUY1VATI0IVIVH5I6AT1YRHV0GNg]hnlo?c2ooo
o`002_ooo`Kbl_8mlo?c1_7al@GYjNT6fMWI1L_;b`K@d=06c<c<1N[ZjTWclo<;oooo000:oooo1_;b
lSgclo<6lO7a1NWYj@KIfMT5bl_;1]3@d0K<c<`5j^[ZBO?cl`_oool000[oool6l_;b?O?cl`KalO45
jNWY1]WIf@G;bl/6d=3@1/c<c0GZj^Y9lo?c2oooo`002_ooo`Kbl_8mlo?c1_7al@GYjNT6fMWI1L_;
b`K@d=06c<c<1N[ZjTWclo<;oooo000:oooo1_;blSgclo<6lO7a1NWYj@KIfMT5bl_;1]3@d0K<c<`5
j^[ZBO?cl`_oool00<Soool00<Soool00<Soool00<Soool00<Soool00<Soool00<Soool00<Soool0
0<Soool002koool300009_ooo`<00010oooo0`0002_oool0037oool00`000?ooooooo`0Toooo00<0
003oooooool0@_ooo`030000oooooooo02Soool002;oool300001?ooo`<00003oooo0`0000?oool2
00001?ooo`800004oooo0P0000Coool300000oooo`800002oooo0P000005oooo0000oooo0000oooo
00<00003oooo100000?oool300000_ooo`<00003oooo0`0000Coool300000oooo`@00008oooo0`00
0008oooo00000000oooo0000oooo0000oooo1@0000;oool300000oooo`<0000Toooo000Soooo00<0
003oooooool01?ooo`050000oooooooooooo000000;oool00`000?ooooooo`06oooo00@0003ooooo
ool00008oooo00<0003oooooool00oooo`040000oooooooo00000_ooo`070000oooo0000oooo0000
oooo000000;oool01@000?ooooooooooo`000004oooo00<0003oooooool01_ooo`030000oooooooo
00?oool010000?ooooooo`0000Goool010000?ooooooo`0000[oool02P000?ooooooooooo`000?oo
o`000?ooo`000?ooo`@00002oooo00@0003oooooool00002oooo00<0003oooooool09Oooo`008ooo
o`030000oooooooo00Coool01@000?ooooooooooo`000002oooo00<0003oooooool02Oooo`030000
oooooooo00Koool00`000?ooooooo`03oooo00@0003oooooool00002oooo00L0003oool0003oool0
003oool000000_ooo`050000oooooooooooo000000Coool400000_ooo`<00003oooo0`0000?oool4
00000_ooo`040000oooooooo00002_ooo`090000oooooooooooo0000oooo0000oooo000000Coool0
10000?ooooooo`0000;oool00`000?ooooooo`0400009?ooo`008oooo`800004oooo0P0000Coool4
00002?ooo`800009oooo00<0003oooooool01?ooo`800002oooo0`000003oooo0000oooo00@00003
oooo100000?oool200000oooo`@00002oooo100000?oool200001?ooo`<00009oooo0P0000;oool3
000000?oool0003oool00_ooo`<00003oooo100000;oool200009Oooo`008oooo`040000oooooooo
00005?ooo`030000oooooooo00Soool010000?ooooooo`0003Goool00`000?ooooooo`16oooo000R
oooo1@0000?oool00`000?ooooooo`0>oooo0`0000Woool30000=?ooo`80000:oooo00<0003ooooo
ool0>oooo`00b?ooo`00b?ooo`00\
\>"],
  ImageRangeCache->{{{0, 199}, {199, 0}} -> {-1.98343, -0.640169, 0.180738, \
0.180738}}]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "At first, we construct a 128 by 128 zero-matrix. Second, the 25 percent \
wavelet spectrum is embedded into this zero-matrix. Thus, we have the \
approximate 128 by 128 wavelet spectrum. Apply an inverse wavelet transform \
recovers a 128 by 128 resolution image data. Figure 6 shows an approximately \
recovered 128 by 128 resolution image.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
spectComp=ZeroMatrix[dim[[2]]];
Do[spectComp[[i,j]]=partSpect[[i,j]],{i,dim[[2]]/4},{j,dim[[3]]/4}];
wMatTrans=Table[Transpose[wMat[[i]]],{i,2}];
recover=waveletND[spectComp,wMatTrans,2];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
ListDensityPlot[recover,PlotRange->All,
\tMesh->False,Frame->False,AspectRatio->dim[[2]]/dim[[3]],
\tPlotLabel->\"Fig.6. Recovered image\",ImageSize->{200,200}];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 200 200 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -68 0 ]
[.5 1.0125 68 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.813 moveto
(.6) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Recovered) show
165.000 12.813 moveto
(image) show
195.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
D9D8D8D8D8D8D8D8D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9DADADBCFC7C2BCC0C2C1C1C2C3C4C4C4C3C3C3C1BFBEBDBAB7B4B2AFADAAA8
A6A4A19F9F9F9D9C9E9E9E9E9C9B9A9997949391A3B0B8C1C9D1DAE2DBD8D9D9D9D9D8D8
D8D8D8D8D8D8D8D9D9D9D9D9D9D8D8D8D8D9D9D9
D9D8D8D8D8D8D8D8D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9DADADBCFC7C2BCC0C2C1C1C2C3C4C4C4C3C3C3C1BFBEBDBAB7B4B2AFADAAA8
A6A4A19F9F9F9D9C9E9E9E9E9C9B9A9997949391A3B0B8C1C9D1DAE2DBD8D9D9D9D9D8D8
D8D8D8D8D8D8D8D9D9D9D9D9D9D8D8D8D8D9D9D9
D9D8D8D8D8D8D8D8D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9DADADBCFC7C2BCC0C2C1C1C2C3C4C4C4C3C3C3C1BFBEBDBAB7B4B2AFADAAA8
A6A4A19F9F9F9D9C9E9E9E9E9C9B9A9997949391A3B0B8C1C9D1DAE2DBD8D9D9D9D9D8D8
D8D8D8D8D8D8D8D9D9D9D9D9D9D8D8D8D8D9D9D9
D9D8D8D8D8D8D8D8D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9DADADBCFC7C2BCC0C2C1C1C2C3C4C4C4C3C3C3C1BFBEBDBAB7B4B2AFADAAA8
A6A4A19F9F9F9D9C9E9E9E9E9C9B9A9997949391A3B0B8C1C9D1DAE2DBD8D9D9D9D9D8D8
D8D8D8D8D8D8D8D9D9D9D9D9D9D8D8D8D8D9D9D9
D8D8D8D8D8D8D8D8D9D9D9D9D9D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D8D9D9D9D9
D9D9D9D9D9DADADACFC6C1BBC0C2C1C0C1C1C1C1BFBDBCBBBABAB9B8B4B1AEACA9A6A3A0
A3A5A5A5A09C9A97999A99999A9A9A9A98969593AEC2CDDBD5D5D9DCDAD9D9D9D9D8D8D8
D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D8
D8D8D8D8D8D8D8D8D9D9D9D9D9D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D8D9D9D9D9
D9D9D9D9D9DADADACFC6C1BBC0C2C1C0C1C1C1C1BFBDBCBBBABAB9B8B4B1AEACA9A6A3A0
A3A5A5A5A09C9A97999A99999A9A9A9A98969593AEC2CDDBD5D5D9DCDAD9D9D9D9D8D8D8
D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D8
D8D8D8D8D8D8D8D8D9D9D9D9D9D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D8D9D9D9D9
D9D9D9D9D9DADADACFC6C1BBC0C2C1C0C1C1C1C1BFBDBCBBBABAB9B8B4B1AEACA9A6A3A0
A3A5A5A5A09C9A97999A99999A9A9A9A98969593AEC2CDDBD5D5D9DCDAD9D9D9D9D8D8D8
D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D8
D8D8D8D8D8D8D8D8D9D9D9D9D9D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D8D9D9D9D9
D9D9D9D9D9DADADACFC6C1BBC0C2C1C0C1C1C1C1BFBDBCBBBABAB9B8B4B1AEACA9A6A3A0
A3A5A5A5A09C9A97999A99999A9A9A9A98969593AEC2CDDBD5D5D9DCDAD9D9D9D9D8D8D8
D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D8
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9CDC5BFB9BDBFBDBDBEC0C0C1C2C3C4C5C4C4C4C4C2C1C0BEBBB7B5B2
B1AFADABA8A5A29FA09F9E9D9D9D9C9C9D9D9D9EB7CAD7E5DAD6D9DAD9D8D9D8D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9CDC5BFB9BDBFBDBDBEC0C0C1C2C3C4C5C4C4C4C4C2C1C0BEBBB7B5B2
B1AFADABA8A5A29FA09F9E9D9D9D9C9C9D9D9D9EB7CAD7E5DAD6D9DAD9D8D9D8D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9CDC5BFB9BDBFBDBDBEC0C0C1C2C3C4C5C4C4C4C4C2C1C0BEBBB7B5B2
B1AFADABA8A5A29FA09F9E9D9D9D9C9C9D9D9D9EB7CAD7E5DAD6D9DAD9D8D9D8D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9CDC5BFB9BDBFBDBDBEC0C0C1C2C3C4C5C4C4C4C4C2C1C0BEBBB7B5B2
B1AFADABA8A5A29FA09F9E9D9D9D9C9C9D9D9D9EB7CAD7E5DAD6D9DAD9D8D9D8D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
DCDEDFE1BFA79887A7B9BFC8C2C0C2C3C2C2C2C2C2C2C2C2C3C3C3C4C2C1C0BFBDBBBAB8
B4B1AFACAAA7A4A2A1A09E9C9C9C9C9BA0A4A6A9BECEDAE6DCD7D9D9D9D9D9D9D9D8D8D8
D9D9D9D9D9D9D9D9D9D9D8D8D9D9D9D9D9D9D9D9
D9D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
DCDEDFE1BFA79887A7B9BFC8C2C0C2C3C2C2C2C2C2C2C2C2C3C3C3C4C2C1C0BFBDBBBAB8
B4B1AFACAAA7A4A2A1A09E9C9C9C9C9BA0A4A6A9BECEDAE6DCD7D9D9D9D9D9D9D9D8D8D8
D9D9D9D9D9D9D9D9D9D9D8D8D9D9D9D9D9D9D9D9
D9D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
DCDEDFE1BFA79887A7B9BFC8C2C0C2C3C2C2C2C2C2C2C2C2C3C3C3C4C2C1C0BFBDBBBAB8
B4B1AFACAAA7A4A2A1A09E9C9C9C9C9BA0A4A6A9BECEDAE6DCD7D9D9D9D9D9D9D9D8D8D8
D9D9D9D9D9D9D9D9D9D9D8D8D9D9D9D9D9D9D9D9
D9D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
DCDEDFE1BFA79887A7B9BFC8C2C0C2C3C2C2C2C2C2C2C2C2C3C3C3C4C2C1C0BFBDBBBAB8
B4B1AFACAAA7A4A2A1A09E9C9C9C9C9BA0A4A6A9BECEDAE6DCD7D9D9D9D9D9D9D9D8D8D8
D9D9D9D9D9D9D9D9D9D9D8D8D9D9D9D9D9D9D9D9
D9D8D8D8D8D8D7D7D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DCDEDFE0
C7B5AA9DA3A39F9CAEBBC2CAC3C0C2C2C1C1C1C0C2C3C4C5C3C2C2C2BBB6B3AFAEACA9A7
A8A9A9A8A5A2A19F9E9E9C9B9A9897969C9FA1A4BACBD6E3DAD6D9DAD9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D8D8D8D8D8D7D7D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DCDEDFE0
C7B5AA9DA3A39F9CAEBBC2CAC3C0C2C2C1C1C1C0C2C3C4C5C3C2C2C2BBB6B3AFAEACA9A7
A8A9A9A8A5A2A19F9E9E9C9B9A9897969C9FA1A4BACBD6E3DAD6D9DAD9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D8D8D8D8D8D7D7D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DCDEDFE0
C7B5AA9DA3A39F9CAEBBC2CAC3C0C2C2C1C1C1C0C2C3C4C5C3C2C2C2BBB6B3AFAEACA9A7
A8A9A9A8A5A2A19F9E9E9C9B9A9897969C9FA1A4BACBD6E3DAD6D9DAD9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D8D8D8D8D8D7D7D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DCDEDFE0
C7B5AA9DA3A39F9CAEBBC2CAC3C0C2C2C1C1C1C0C2C3C4C5C3C2C2C2BBB6B3AFAEACA9A7
A8A9A9A8A5A2A19F9E9E9C9B9A9897969C9FA1A4BACBD6E3DAD6D9DAD9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D8D8D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D6D4D3D1
B8A6998BA9BBC1CAC3C0C2C3BFBDBCBBBDBFBFC0C0C0C0C0BBB7B4B1A49A92898E8F8D8B
8E91919294959697979798989A9B9C9D99969594A5B1B9C1C9D1DAE2DBD8D9D9D9D9D9D8
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D8D8D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D6D4D3D1
B8A6998BA9BBC1CAC3C0C2C3BFBDBCBBBDBFBFC0C0C0C0C0BBB7B4B1A49A92898E8F8D8B
8E91919294959697979798989A9B9C9D99969594A5B1B9C1C9D1DAE2DBD8D9D9D9D9D9D8
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D8D8D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D6D4D3D1
B8A6998BA9BBC1CAC3C0C2C3BFBDBCBBBDBFBFC0C0C0C0C0BBB7B4B1A49A92898E8F8D8B
8E91919294959697979798989A9B9C9D99969594A5B1B9C1C9D1DAE2DBD8D9D9D9D9D9D8
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D8D8D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D6D4D3D1
B8A6998BA9BBC1CAC3C0C2C3BFBDBCBBBDBFBFC0C0C0C0C0BBB7B4B1A49A92898E8F8D8B
8E91919294959697979798989A9B9C9D99969594A5B1B9C1C9D1DAE2DBD8D9D9D9D9D9D8
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DEE1E4E6BB9C8973
9AB1B8C2BBB8BABBBEC1C3C5B8AFABA5A6A6A4A2A2A19F9EA1A2A2A3ABB1B5B9ABA19D97
8B80786E7A7F8081888E92979A9DA1A5A09D9D9C9D9D9D9DB2C1CAD5D3D4D9DDDAD8D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DEE1E4E6BB9C8973
9AB1B8C2BBB8BABBBEC1C3C5B8AFABA5A6A6A4A2A2A19F9EA1A2A2A3ABB1B5B9ABA19D97
8B80786E7A7F8081888E92979A9DA1A5A09D9D9C9D9D9D9DB2C1CAD5D3D4D9DDDAD8D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DEE1E4E6BB9C8973
9AB1B8C2BBB8BABBBEC1C3C5B8AFABA5A6A6A4A2A2A19F9EA1A2A2A3ABB1B5B9ABA19D97
8B80786E7A7F8081888E92979A9DA1A5A09D9D9C9D9D9D9DB2C1CAD5D3D4D9DDDAD8D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DEE1E4E6BB9C8973
9AB1B8C2BBB8BABBBEC1C3C5B8AFABA5A6A6A4A2A2A19F9EA1A2A2A3ABB1B5B9ABA19D97
8B80786E7A7F8081888E92979A9DA1A5A09D9D9C9D9D9D9DB2C1CAD5D3D4D9DDDAD8D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D8D8D8D8D8D8D8D8D9D9D9D8D8D8D8D8D9D9D9D9D9D8D8D8D8D8D8D3D0CECBA588755F
93B4C0D2BFB7B8B6BBBDBFC0A9988E837E776E668EA8B6C7BDBABFC1BBB8B6B4B6B7B7B7
AFAAA6A2897668596F7B7D81919EA8B2A8A3A4A39F9C9A97A1A8ABB0BBC5CCD4D4D5D9DD
DAD9D9D9D9D9D9D8D9D9D9D9D9D9D9D9D9D9D9D9
D9D8D8D8D8D8D8D8D8D9D9D9D8D8D8D8D8D9D9D9D9D9D8D8D8D8D8D8D3D0CECBA588755F
93B4C0D2BFB7B8B6BBBDBFC0A9988E837E776E668EA8B6C7BDBABFC1BBB8B6B4B6B7B7B7
AFAAA6A2897668596F7B7D81919EA8B2A8A3A4A39F9C9A97A1A8ABB0BBC5CCD4D4D5D9DD
DAD9D9D9D9D9D9D8D9D9D9D9D9D9D9D9D9D9D9D9
D9D8D8D8D8D8D8D8D8D9D9D9D8D8D8D8D8D9D9D9D9D9D8D8D8D8D8D8D3D0CECBA588755F
93B4C0D2BFB7B8B6BBBDBFC0A9988E837E776E668EA8B6C7BDBABFC1BBB8B6B4B6B7B7B7
AFAAA6A2897668596F7B7D81919EA8B2A8A3A4A39F9C9A97A1A8ABB0BBC5CCD4D4D5D9DD
DAD9D9D9D9D9D9D8D9D9D9D9D9D9D9D9D9D9D9D9
D9D8D8D8D8D8D8D8D8D9D9D9D8D8D8D8D8D9D9D9D9D9D8D8D8D8D8D8D3D0CECBA588755F
93B4C0D2BFB7B8B6BBBDBFC0A9988E837E776E668EA8B6C7BDBABFC1BBB8B6B4B6B7B7B7
AFAAA6A2897668596F7B7D81919EA8B2A8A3A4A39F9C9A97A1A8ABB0BBC5CCD4D4D5D9DD
DAD9D9D9D9D9D9D8D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D8D8D8D9D9D9D9D9D9D9D9D9D9D9D8DCDEE0E2A07154326A8A92A0
A7B0BBC6BBB6B7B6B6B6B6B5ACA6A29DB0BCC2CAC2BEBEBDBCBCBBBAB4AFACA8A4A09C98
9593908D8C8A888673645A4F7893A0B1A5A1A5A7A09B989598999999A9B4BCC4CBD1D9E0
DAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D8D8D8D9D9D9D9D9D9D9D9D9D9D9D8DCDEE0E2A07154326A8A92A0
A7B0BBC6BBB6B7B6B6B6B6B5ACA6A29DB0BCC2CAC2BEBEBDBCBCBBBAB4AFACA8A4A09C98
9593908D8C8A888673645A4F7893A0B1A5A1A5A7A09B989598999999A9B4BCC4CBD1D9E0
DAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D8D8D8D9D9D9D9D9D9D9D9D9D9D9D8DCDEE0E2A07154326A8A92A0
A7B0BBC6BBB6B7B6B6B6B6B5ACA6A29DB0BCC2CAC2BEBEBDBCBCBBBAB4AFACA8A4A09C98
9593908D8C8A888673645A4F7893A0B1A5A1A5A7A09B989598999999A9B4BCC4CBD1D9E0
DAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D8D8D8D9D9D9D9D9D9D9D9D9D9D9D8DCDEE0E2A07154326A8A92A0
A7B0BBC6BBB6B7B6B6B6B6B5ACA6A29DB0BCC2CAC2BEBEBDBCBCBBBAB4AFACA8A4A09C98
9593908D8C8A888673645A4F7893A0B1A5A1A5A7A09B989598999999A9B4BCC4CBD1D9E0
DAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADADAD5D1CFCCC3BCB7B1B6B9B8B9
BBBCBDBEBFC1C2C3C0BEBEBDAFA59F97AAB5BAC1BFC0C3C6C3C3C3C3B8B0ABA5A6A5A3A0
9B96938F908F8D8C8D8D8D8C93989C9F9E9D9F9F9B9897958E89858095A4ABB4C2CFDAE6
DCD7D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADADAD5D1CFCCC3BCB7B1B6B9B8B9
BBBCBDBEBFC1C2C3C0BEBEBDAFA59F97AAB5BAC1BFC0C3C6C3C3C3C3B8B0ABA5A6A5A3A0
9B96938F908F8D8C8D8D8D8C93989C9F9E9D9F9F9B9897958E89858095A4ABB4C2CFDAE6
DCD7D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADADAD5D1CFCCC3BCB7B1B6B9B8B9
BBBCBDBEBFC1C2C3C0BEBEBDAFA59F97AAB5BAC1BFC0C3C6C3C3C3C3B8B0ABA5A6A5A3A0
9B96938F908F8D8C8D8D8D8C93989C9F9E9D9F9F9B9897958E89858095A4ABB4C2CFDAE6
DCD7D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADADAD5D1CFCCC3BCB7B1B6B9B8B9
BBBCBDBEBFC1C2C3C0BEBEBDAFA59F97AAB5BAC1BFC0C3C6C3C3C3C3B8B0ABA5A6A5A3A0
9B96938F908F8D8C8D8D8D8C93989C9F9E9D9F9F9B9897958E89858095A4ABB4C2CFDAE6
DCD7D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADBDBDBD3CCC9C4BCB4AEA8B1B7B8BA
BCBFC1C3C4C6C7C9C6C5C4C4BAB3AEA9ACACABAAB5BDC2C7C3C1C2C3BBB6B3AFA8A19C96
94908C888B8C8C8C909394969CA1A4A8A19D9B99999998978B827B747D818182AAC7DAEF
DDD6D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADBDBDBD3CCC9C4BCB4AEA8B1B7B8BA
BCBFC1C3C4C6C7C9C6C5C4C4BAB3AEA9ACACABAAB5BDC2C7C3C1C2C3BBB6B3AFA8A19C96
94908C888B8C8C8C909394969CA1A4A8A19D9B99999998978B827B747D818182AAC7DAEF
DDD6D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADBDBDBD3CCC9C4BCB4AEA8B1B7B8BA
BCBFC1C3C4C6C7C9C6C5C4C4BAB3AEA9ACACABAAB5BDC2C7C3C1C2C3BBB6B3AFA8A19C96
94908C888B8C8C8C909394969CA1A4A8A19D9B99999998978B827B747D818182AAC7DAEF
DDD6D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADBDBDBD3CCC9C4BCB4AEA8B1B7B8BA
BCBFC1C3C4C6C7C9C6C5C4C4BAB3AEA9ACACABAAB5BDC2C7C3C1C2C3BBB6B3AFA8A19C96
94908C888B8C8C8C909394969CA1A4A8A19D9B99999998978B827B747D818182AAC7DAEF
DDD6D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9C5B6ACA1A3A19C98AAB6BDC5
C1C0C2C4C5C6C8C9C6C4C4C3BEBAB8B5B5B4B3B2B7BBBDC0BFBFBFC0B5AEA9A49E98938D
90908E8D8D8D8C8C99A2A8AEAAA8A9A9A4A09E9C9B9A9897999B9B9C8C8078709EBECEE3
D7D4D9DCDAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9C5B6ACA1A3A19C98AAB6BDC5
C1C0C2C4C5C6C8C9C6C4C4C3BEBAB8B5B5B4B3B2B7BBBDC0BFBFBFC0B5AEA9A49E98938D
90908E8D8D8D8C8C99A2A8AEAAA8A9A9A4A09E9C9B9A9897999B9B9C8C8078709EBECEE3
D7D4D9DCDAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9C5B6ACA1A3A19C98AAB6BDC5
C1C0C2C4C5C6C8C9C6C4C4C3BEBAB8B5B5B4B3B2B7BBBDC0BFBFBFC0B5AEA9A49E98938D
90908E8D8D8D8C8C99A2A8AEAAA8A9A9A4A09E9C9B9A9897999B9B9C8C8078709EBECEE3
D7D4D9DCDAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9C5B6ACA1A3A19C98AAB6BDC5
C1C0C2C4C5C6C8C9C6C4C4C3BEBAB8B5B5B4B3B2B7BBBDC0BFBFBFC0B5AEA9A49E98938D
90908E8D8D8D8C8C99A2A8AEAAA8A9A9A4A09E9C9B9A9897999B9B9C8C8078709EBECEE3
D7D4D9DCDAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADBDCDDD3CDC9C4B4A79D929CA09FA0AEB9C0C8
C4C2C4C6C3C2C2C1BEBCBBB9B7B5B3B1B5B7B8B9BDC0C2C4C2C1C1C1B3AAA39C97928C86
8C8F8E8F979CA0A5A6A8ABAEA9A7A6A5A09D9A98989796959697979898999A9AB6CBD8E7
DBD6D9DAD9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADBDCDDD3CDC9C4B4A79D929CA09FA0AEB9C0C8
C4C2C4C6C3C2C2C1BEBCBBB9B7B5B3B1B5B7B8B9BDC0C2C4C2C1C1C1B3AAA39C97928C86
8C8F8E8F979CA0A5A6A8ABAEA9A7A6A5A09D9A98989796959697979898999A9AB6CBD8E7
DBD6D9DAD9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADBDCDDD3CDC9C4B4A79D929CA09FA0AEB9C0C8
C4C2C4C6C3C2C2C1BEBCBBB9B7B5B3B1B5B7B8B9BDC0C2C4C2C1C1C1B3AAA39C97928C86
8C8F8E8F979CA0A5A6A8ABAEA9A7A6A5A09D9A98989796959697979898999A9AB6CBD8E7
DBD6D9DAD9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADBDCDDD3CDC9C4B4A79D929CA09FA0AEB9C0C8
C4C2C4C6C3C2C2C1BEBCBBB9B7B5B3B1B5B7B8B9BDC0C2C4C2C1C1C1B3AAA39C97928C86
8C8F8E8F979CA0A5A6A8ABAEA9A7A6A5A09D9A98989796959697979898999A9AB6CBD8E7
DBD6D9DAD9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DBDDDEDFC2AC9F907D6C5B4A77939FAFB1B7C1CA
C1BDBEBDBEBEBEBEBBB9B7B5B1AEABA9ADB0B0B1B7BCBFC3C1C0C0C1B1A59E9694908A85
8D929395999DA0A3A2A2A3A4A2A1A09F9E9C9B9999999898918C898585848281A2BAC9DA
D3D3D9DEDAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DBDDDEDFC2AC9F907D6C5B4A77939FAFB1B7C1CA
C1BDBEBDBEBEBEBEBBB9B7B5B1AEABA9ADB0B0B1B7BCBFC3C1C0C0C1B1A59E9694908A85
8D929395999DA0A3A2A2A3A4A2A1A09F9E9C9B9999999898918C898585848281A2BAC9DA
D3D3D9DEDAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DBDDDEDFC2AC9F907D6C5B4A77939FAFB1B7C1CA
C1BDBEBDBEBEBEBEBBB9B7B5B1AEABA9ADB0B0B1B7BCBFC3C1C0C0C1B1A59E9694908A85
8D929395999DA0A3A2A2A3A4A2A1A09F9E9C9B9999999898918C898585848281A2BAC9DA
D3D3D9DEDAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DBDDDEDFC2AC9F907D6C5B4A77939FAFB1B7C1CA
C1BDBEBDBEBEBEBEBBB9B7B5B1AEABA9ADB0B0B1B7BCBFC3C1C0C0C1B1A59E9694908A85
8D929395999DA0A3A2A2A3A4A2A1A09F9E9C9B9999999898918C898585848281A2BAC9DA
D3D3D9DEDAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D8D8D8D8D8B69E8E7C593B2207538499B6AFB2BEC7
BEBABBBAA18E81737777716D6C6A6764727C81889BABB8C5BFBEC2C5B1A39B918D87807A
889093989697989A99999A9A9C9E9FA09D9B9A99979695938E8A8783766C645B8EB0C3DA
D1D1D9DFDAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D8D8D8D8D8B69E8E7C593B2207538499B6AFB2BEC7
BEBABBBAA18E81737777716D6C6A6764727C81889BABB8C5BFBEC2C5B1A39B918D87807A
889093989697989A99999A9A9C9E9FA09D9B9A99979695938E8A8783766C645B8EB0C3DA
D1D1D9DFDAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D8D8D8D8D8B69E8E7C593B2207538499B6AFB2BEC7
BEBABBBAA18E81737777716D6C6A6764727C81889BABB8C5BFBEC2C5B1A39B918D87807A
889093989697989A99999A9A9C9E9FA09D9B9A99979695938E8A8783766C645B8EB0C3DA
D1D1D9DFDAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D8D8D8D8D8B69E8E7C593B2207538499B6AFB2BEC7
BEBABBBAA18E81737777716D6C6A6764727C81889BABB8C5BFBEC2C5B1A39B918D87807A
889093989697989A99999A9A9C9E9FA09D9B9A99979695938E8A8783766C645B8EB0C3DA
D1D1D9DFDAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D8D8D8D8D9D9D9D9D9D9D9DBDDDEDFA67D6345738C919C6037200553859BB8ACACB6BE
BBBBBEC0BCB9B8B7A5978E847A70665C74848992A0ADB9C4C1C1C6C9B3A49C92887F756B
7A8284876C5A4F43566163686A6D70737D858B929293969983736A60676A686891AFC2D8
D1D1DAE0DAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D8D8D8D8D9D9D9D9D9D9D9DBDDDEDFA67D6345738C919C6037200553859BB8ACACB6BE
BBBBBEC0BCB9B8B7A5978E847A70665C74848992A0ADB9C4C1C1C6C9B3A49C92887F756B
7A8284876C5A4F43566163686A6D70737D858B929293969983736A60676A686891AFC2D8
D1D1DAE0DAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D8D8D8D8D9D9D9D9D9D9D9DBDDDEDFA67D6345738C919C6037200553859BB8ACACB6BE
BBBBBEC0BCB9B8B7A5978E847A70665C74848992A0ADB9C4C1C1C6C9B3A49C92887F756B
7A8284876C5A4F43566163686A6D70737D858B929293969983736A60676A686891AFC2D8
D1D1DAE0DAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D8D8D8D8D9D9D9D9D9D9D9DBDDDEDFA67D6345738C919C6037200553859BB8ACACB6BE
BBBBBEC0BCB9B8B7A5978E847A70665C74848992A0ADB9C4C1C1C6C9B3A49C92887F756B
7A8284876C5A4F43566163686A6D70737D858B929293969983736A60676A686891AFC2D8
D1D1DAE0DAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DBDCDDDDCDC2BBB3774A290625322E2E251F1A16537F99B8AFB1BDC7
B4A8A49EA2A3A2A198918D87837F7A76828A8D91A2B0BAC6BDBABCBDB0A6A099938C857F
8A90919481756D656665615D6F7A8088898B909493949697715645324852525583A6BDD7
CECFDAE1DBD8D9D9D9D9D9D9D9D9D9D9D9D9D9D8
D9D9D9D9D9D9D9D9DBDCDDDDCDC2BBB3774A290625322E2E251F1A16537F99B8AFB1BDC7
B4A8A49EA2A3A2A198918D87837F7A76828A8D91A2B0BAC6BDBABCBDB0A6A099938C857F
8A90919481756D656665615D6F7A8088898B909493949697715645324852525583A6BDD7
CECFDAE1DBD8D9D9D9D9D9D9D9D9D9D9D9D9D9D8
D9D9D9D9D9D9D9D9DBDCDDDDCDC2BBB3774A290625322E2E251F1A16537F99B8AFB1BDC7
B4A8A49EA2A3A2A198918D87837F7A76828A8D91A2B0BAC6BDBABCBDB0A6A099938C857F
8A90919481756D656665615D6F7A8088898B909493949697715645324852525583A6BDD7
CECFDAE1DBD8D9D9D9D9D9D9D9D9D9D9D9D9D9D8
D9D9D9D9D9D9D9D9DBDCDDDDCDC2BBB3774A290625322E2E251F1A16537F99B8AFB1BDC7
B4A8A49EA2A3A2A198918D87837F7A76828A8D91A2B0BAC6BDBABCBDB0A6A099938C857F
8A90919481756D656665615D6F7A8088898B909493949697715645324852525583A6BDD7
CECFDAE1DBD8D9D9D9D9D9D9D9D9D9D9D9D9D9D8
D9D8D8D8D8D8D8D9DADBDBDCD0C7C1BB794726001C261F1C1F21212152768CA7A8AFBECB
C3C0C3C5BEBAB8B6B7B7B6B6B3B2B0AFB3B6B7B8BBBDBFC2BBB7B6B3B2B0ADAB998B8177
726C645D6D777B80878D9399918D8C8B8C8D8D8D8C8C8B8B5C3A240B37505763778897A7
B9CADBEBDDD7D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D8D8D8D8D8D8D9DADBDBDCD0C7C1BB794726001C261F1C1F21212152768CA7A8AFBECB
C3C0C3C5BEBAB8B6B7B7B6B6B3B2B0AFB3B6B7B8BBBDBFC2BBB7B6B3B2B0ADAB998B8177
726C645D6D777B80878D9399918D8C8B8C8D8D8D8C8C8B8B5C3A240B37505763778897A7
B9CADBEBDDD7D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D8D8D8D8D8D8D9DADBDBDCD0C7C1BB794726001C261F1C1F21212152768CA7A8AFBECB
C3C0C3C5BEBAB8B6B7B7B6B6B3B2B0AFB3B6B7B8BBBDBFC2BBB7B6B3B2B0ADAB998B8177
726C645D6D777B80878D9399918D8C8B8C8D8D8D8C8C8B8B5C3A240B37505763778897A7
B9CADBEBDDD7D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D8D8D8D8D8D8D9DADBDBDCD0C7C1BB794726001C261F1C1F21212152768CA7A8AFBECB
C3C0C3C5BEBAB8B6B7B7B6B6B3B2B0AFB3B6B7B8BBBDBFC2BBB7B6B3B2B0ADAB998B8177
726C645D6D777B80878D9399918D8C8B8C8D8D8D8C8C8B8B5C3A240B37505763778897A7
B9CADBEBDDD7D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DADBDBDCD1C9C5BF84573916292E251F252827284D68798D9BAABBCC
C2BEC3C5C6C7C8CACACBCCCDCCCBCBCBC8C6C5C3C1BEBCBAB8B6B4B2B3B3B2B2B1B0AFAE
A7A29E9A8B7F766C6D6B66626D737679848D949B82726B61493424121F242120425B6A7C
A1C1DCF8DFD5D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DADBDBDCD1C9C5BF84573916292E251F252827284D68798D9BAABBCC
C2BEC3C5C6C7C8CACACBCCCDCCCBCBCBC8C6C5C3C1BEBCBAB8B6B4B2B3B3B2B2B1B0AFAE
A7A29E9A8B7F766C6D6B66626D737679848D949B82726B61493424121F242120425B6A7C
A1C1DCF8DFD5D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DADBDBDCD1C9C5BF84573916292E251F252827284D68798D9BAABBCC
C2BEC3C5C6C7C8CACACBCCCDCCCBCBCBC8C6C5C3C1BEBCBAB8B6B4B2B3B3B2B2B1B0AFAE
A7A29E9A8B7F766C6D6B66626D737679848D949B82726B61493424121F242120425B6A7C
A1C1DCF8DFD5D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DADBDBDCD1C9C5BF84573916292E251F252827284D68798D9BAABBCC
C2BEC3C5C6C7C8CACACBCCCDCCCBCBCBC8C6C5C3C1BEBCBAB8B6B4B2B3B3B2B2B1B0AFAE
A7A29E9A8B7F766C6D6B66626D737679848D949B82726B61493424121F242120425B6A7C
A1C1DCF8DFD5D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DDE0E2E5C4AD9F8F7258422A34352D272828252337444C567A97ADC4
BBBAC2C8C6C6C8CACACBCCCDCCCBCBCBC8C6C4C2C0BDBBB9B6B4B1AFB0B0B0AFADABAAA9
A7A6A5A3A2A1A09F9C9B999797969595949393926F554431312C221A1D1E1B19262F343A
7EB0D3FADDD2D9DCD9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DDE0E2E5C4AD9F8F7258422A34352D272828252337444C567A97ADC4
BBBAC2C8C6C6C8CACACBCCCDCCCBCBCBC8C6C4C2C0BDBBB9B6B4B1AFB0B0B0AFADABAAA9
A7A6A5A3A2A1A09F9C9B999797969595949393926F554431312C221A1D1E1B19262F343A
7EB0D3FADDD2D9DCD9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DDE0E2E5C4AD9F8F7258422A34352D272828252337444C567A97ADC4
BBBAC2C8C6C6C8CACACBCCCDCCCBCBCBC8C6C4C2C0BDBBB9B6B4B1AFB0B0B0AFADABAAA9
A7A6A5A3A2A1A09F9C9B999797969595949393926F554431312C221A1D1E1B19262F343A
7EB0D3FADDD2D9DCD9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DDE0E2E5C4AD9F8F7258422A34352D272828252337444C567A97ADC4
BBBAC2C8C6C6C8CACACBCCCDCCCBCBCBC8C6C4C2C0BDBBB9B6B4B1AFB0B0B0AFADABAAA9
A7A6A5A3A2A1A09F9C9B999797969595949393926F554431312C221A1D1E1B19262F343A
7EB0D3FADDD2D9DCD9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DEE1E3E6C2A99A88705B46313C3F3935312C2824333C4146678193A7
ABB3C0CBC5C3C6C8C9CACCCDCBCACACAC7C5C3C2BEBBB8B6B2AFACA9ABACABABA9A7A6A4
A3A1A09E9D9C9B9A9999989795949392857B756D543F301E23221B161615131026353D48
86B7D9FFE0D3D9DAD9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DEE1E3E6C2A99A88705B46313C3F3935312C2824333C4146678193A7
ABB3C0CBC5C3C6C8C9CACCCDCBCACACAC7C5C3C2BEBBB8B6B2AFACA9ABACABABA9A7A6A4
A3A1A09E9D9C9B9A9999989795949392857B756D543F301E23221B161615131026353D48
86B7D9FFE0D3D9DAD9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DEE1E3E6C2A99A88705B46313C3F3935312C2824333C4146678193A7
ABB3C0CBC5C3C6C8C9CACCCDCBCACACAC7C5C3C2BEBBB8B6B2AFACA9ABACABABA9A7A6A4
A3A1A09E9D9C9B9A9999989795949392857B756D543F301E23221B161615131026353D48
86B7D9FFE0D3D9DAD9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DEE1E3E6C2A99A88705B46313C3F3935312C2824333C4146678193A7
ABB3C0CBC5C3C6C8C9CACCCDCBCACACAC7C5C3C2BEBBB8B6B2AFACA9ABACABABA9A7A6A4
A3A1A09E9D9C9B9A9999989795949392857B756D543F301E23221B161615131026353D48
86B7D9FFE0D3D9DAD9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DDE0E2E5C2A99A886F58432D404845453B332F29373F43475C6C7885
98A8B8C8C0BFC4C7C6C6C7C8C6C5C5C5C2C0BFBDB9B6B3B0AEACA9A7A8A7A7A6A6A6A5A5
A19F9D9B9A999796969695958D8884806B5A4E413A32281E2323201E16100B05385C718A
A6C1DCF6DFD5D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DDE0E2E5C2A99A886F58432D404845453B332F29373F43475C6C7885
98A8B8C8C0BFC4C7C6C6C7C8C6C5C5C5C2C0BFBDB9B6B3B0AEACA9A7A8A7A7A6A6A6A5A5
A19F9D9B9A999796969695958D8884806B5A4E413A32281E2323201E16100B05385C718A
A6C1DCF6DFD5D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DDE0E2E5C2A99A886F58432D404845453B332F29373F43475C6C7885
98A8B8C8C0BFC4C7C6C6C7C8C6C5C5C5C2C0BFBDB9B6B3B0AEACA9A7A8A7A7A6A6A6A5A5
A19F9D9B9A999796969695958D8884806B5A4E413A32281E2323201E16100B05385C718A
A6C1DCF6DFD5D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DDE0E2E5C2A99A886F58432D404845453B332F29373F43475C6C7885
98A8B8C8C0BFC4C7C6C6C7C8C6C5C5C5C2C0BFBDB9B6B3B0AEACA9A7A8A7A7A6A6A6A5A5
A19F9D9B9A999796969695958D8884806B5A4E413A32281E2323201E16100B05385C718A
A6C1DCF6DFD5D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DCDEDFE0CBBBB1A67D5C4227404B47483E36322D353A3B3E464D5258
7790A2B5B0B2BAC1BEBDBFC1BEBCBBBAB9B8B7B6B1ACA9A6A5A4A19FA1A2A2A2A09E9D9C
9B9B9A9998979696908B888572645A4E42372B1F23231E1B1B1A1817151312105A90B1D8
CBCBDAE5DBD7D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DCDEDFE0CBBBB1A67D5C4227404B47483E36322D353A3B3E464D5258
7790A2B5B0B2BAC1BEBDBFC1BEBCBBBAB9B8B7B6B1ACA9A6A5A4A19FA1A2A2A2A09E9D9C
9B9B9A9998979696908B888572645A4E42372B1F23231E1B1B1A1817151312105A90B1D8
CBCBDAE5DBD7D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DCDEDFE0CBBBB1A67D5C4227404B47483E36322D353A3B3E464D5258
7790A2B5B0B2BAC1BEBDBFC1BEBCBBBAB9B8B7B6B1ACA9A6A5A4A19FA1A2A2A2A09E9D9C
9B9B9A9998979696908B888572645A4E42372B1F23231E1B1B1A1817151312105A90B1D8
CBCBDAE5DBD7D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9DCDEDFE0CBBBB1A67D5C4227404B47483E36322D353A3B3E464D5258
7790A2B5B0B2BAC1BEBDBFC1BEBCBBBAB9B8B7B6B1ACA9A6A5A4A19FA1A2A2A2A09E9D9C
9B9B9A9998979696908B888572645A4E42372B1F23231E1B1B1A1817151312105A90B1D8
CBCBDAE5DBD7D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D8D7D7D79A6D5130474E47443E3A3531363838393D3F4143
4F585F66737F899395989FA4A2A1A3A4A4A4A5A6988D8780888C8C8E8F90919291919191
8F8D8C8A8683807E716860594B3F352A27221A13161613110F0D0B0A1E2D364080B1D5FC
DED2D9DBD9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D8D7D7D79A6D5130474E47443E3A3531363838393D3F4143
4F585F66737F899395989FA4A2A1A3A4A4A4A5A6988D8780888C8C8E8F90919291919191
8F8D8C8A8683807E716860594B3F352A27221A13161613110F0D0B0A1E2D364080B1D5FC
DED2D9DBD9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D8D7D7D79A6D5130474E47443E3A3531363838393D3F4143
4F585F66737F899395989FA4A2A1A3A4A4A4A5A6988D8780888C8C8E8F90919291919191
8F8D8C8A8683807E716860594B3F352A27221A13161613110F0D0B0A1E2D364080B1D5FC
DED2D9DBD9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D8D7D7D79A6D5130474E47443E3A3531363838393D3F4143
4F585F66737F899395989FA4A2A1A3A4A4A4A5A6988D8780888C8C8E8F90919291919191
8F8D8C8A8683807E716860594B3F352A27221A13161613110F0D0B0A1E2D364080B1D5FC
DED2D9DBD9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9DDE1E3E5B7958169615444343D403B393B3D3D3D454C5055
52515354585B5D5F5A575654565858585F63666A5D55514C515353535B60646865646565
62605F5D5B595755483E372F2C27211B1A1814110F0C0A070C101112487089A7B4C5DBF0
DED6D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9DDE1E3E5B7958169615444343D403B393B3D3D3D454C5055
52515354585B5D5F5A575654565858585F63666A5D55514C515353535B60646865646565
62605F5D5B595755483E372F2C27211B1A1814110F0C0A070C101112487089A7B4C5DBF0
DED6D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9DDE1E3E5B7958169615444343D403B393B3D3D3D454C5055
52515354585B5D5F5A575654565858585F63666A5D55514C515353535B60646865646565
62605F5D5B595755483E372F2C27211B1A1814110F0C0A070C101112487089A7B4C5DBF0
DED6D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9DDE1E3E5B7958169615444343D403B393B3D3D3D454C5055
52515354585B5D5F5A575654565858585F63666A5D55514C515353535B60646865646565
62605F5D5B595755483E372F2C27211B1A1814110F0C0A070C101112487089A7B4C5DBF0
DED6D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9DBDCDDDED0C6C0BA8A654C2F4248423E474D4F53504F5050
4F4E4E4D4A48464542403D3B3B3B3A393939383834312F2C2B2A2826292A2B2C2D2E2F30
2E2C2C2B2A292928252322201C181512110F0D0B0F1213142C3F4B598CB5D3F5DCD3D9DB
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9DBDCDDDED0C6C0BA8A654C2F4248423E474D4F53504F5050
4F4E4E4D4A48464542403D3B3B3B3A393939383834312F2C2B2A2826292A2B2C2D2E2F30
2E2C2C2B2A292928252322201C181512110F0D0B0F1213142C3F4B598CB5D3F5DCD3D9DB
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9DBDCDDDED0C6C0BA8A654C2F4248423E474D4F53504F5050
4F4E4E4D4A48464542403D3B3B3B3A393939383834312F2C2B2A2826292A2B2C2D2E2F30
2E2C2C2B2A292928252322201C181512110F0D0B0F1213142C3F4B598CB5D3F5DCD3D9DB
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9DBDCDDDED0C6C0BA8A654C2F4248423E474D4F53504F5050
4F4E4E4D4A48464542403D3B3B3B3A393939383834312F2C2B2A2826292A2B2C2D2E2F30
2E2C2C2B2A292928252322201C181512110F0D0B0F1213142C3F4B598CB5D3F5DCD3D9DB
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DDE0E2E4B69581696154433441464444474A4C4E
4743413E3935312D31333333302F2E2D29252320222221201D1A18161A1C1C1D1D1C1D1D
1D1D1D1D1B1918171513110F111212131416171828353D477FABCAECD7D1D9DEDAD8D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DDE0E2E4B69581696154433441464444474A4C4E
4743413E3935312D31333333302F2E2D29252320222221201D1A18161A1C1C1D1D1C1D1D
1D1D1D1D1B1918171513110F111212131416171828353D477FABCAECD7D1D9DEDAD8D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DDE0E2E4B69581696154433441464444474A4C4E
4743413E3935312D31333333302F2E2D29252320222221201D1A18161A1C1C1D1D1C1D1D
1D1D1D1D1B1918171513110F111212131416171828353D477FABCAECD7D1D9DEDAD8D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DDE0E2E4B69581696154433441464444474A4C4E
4743413E3935312D31333333302F2E2D29252320222221201D1A18161A1C1C1D1D1C1D1D
1D1D1D1D1B1918171513110F111212131416171828353D477FABCAECD7D1D9DEDAD8D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADADAD8D7D7D6A47F684D5350443B464C4C4E
4742403D332C261F222321201F1F1E1D1C1A19181919191917161514181C1D1F262B2F34
2A2523201F1E1C1B1E202122232526282B2D2F31678FA9C7C5CBDAE7DCD7D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADADAD8D7D7D6A47F684D5350443B464C4C4E
4742403D332C261F222321201F1F1E1D1C1A19181919191917161514181C1D1F262B2F34
2A2523201F1E1C1B1E202122232526282B2D2F31678FA9C7C5CBDAE7DCD7D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADADAD8D7D7D6A47F684D5350443B464C4C4E
4742403D332C261F222321201F1F1E1D1C1A19181919191917161514181C1D1F262B2F34
2A2523201F1E1C1B1E202122232526282B2D2F31678FA9C7C5CBDAE7DCD7D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADADAD8D7D7D6A47F684D5350443B464C4C4E
4742403D332C261F222321201F1F1E1D1C1A19181919191917161514181C1D1F262B2F34
2A2523201F1E1C1B1E202122232526282B2D2F31678FA9C7C5CBDAE7DCD7D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADBDBDCD7D3D2CFA2816B525653483F
4F595B604B3E372E2F2D292527272625211E1C1A1B1B1B1A1C1D1D1E1E1F20202A31363B
363535363535353434333333383B3D40637E90A4B6C8DBEDDDD6D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADBDBDCD7D3D2CFA2816B525653483F
4F595B604B3E372E2F2D292527272625211E1C1A1B1B1B1A1C1D1D1E1E1F20202A31363B
363535363535353434333333383B3D40637E90A4B6C8DBEDDDD6D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADBDBDCD7D3D2CFA2816B525653483F
4F595B604B3E372E2F2D292527272625211E1C1A1B1B1B1A1C1D1D1E1E1F20202A31363B
363535363535353434333333383B3D40637E90A4B6C8DBEDDDD6D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADBDBDCD7D3D2CFA2816B525653483F
4F595B604B3E372E2F2D292527272625211E1C1A1B1B1B1A1C1D1D1E1E1F20202A31363B
363535363535353434333333383B3D40637E90A4B6C8DBEDDDD6D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D8D8D7B3988773
70695D525E6463655C56534F4F4E4C4A4B4B4A4A44403D3A3F414243474A4C4F4B484847
47474747494A4B4C4C4D4D4E7694A7BCC2CCDAE7DCD7D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D8D8D7B3988773
70695D525E6463655C56534F4F4E4C4A4B4B4A4A44403D3A3F414243474A4C4F4B484847
47474747494A4B4C4C4D4D4E7694A7BCC2CCDAE7DCD7D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D8D8D7B3988773
70695D525E6463655C56534F4F4E4C4A4B4B4A4A44403D3A3F414243474A4C4F4B484847
47474747494A4B4C4C4D4D4E7694A7BCC2CCDAE7DCD7D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D8D8D7B3988773
70695D525E6463655C56534F4F4E4C4A4B4B4A4A44403D3A3F414243474A4C4F4B484847
47474747494A4B4C4C4D4D4E7694A7BCC2CCDAE7DCD7D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADADBDB
D0C8C3BEAB9C90848D918F8E8C8A88867E77736D70706E6D6966636161605F5E60616162
605F5F5E74838C97AABAC8D7D3D3D9DEDAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADADBDB
D0C8C3BEAB9C90848D918F8E8C8A88867E77736D70706E6D6966636161605F5E60616162
605F5F5E74838C97AABAC8D7D3D3D9DEDAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADADBDB
D0C8C3BEAB9C90848D918F8E8C8A88867E77736D70706E6D6966636161605F5E60616162
605F5F5E74838C97AABAC8D7D3D3D9DEDAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9DADADBDB
D0C8C3BEAB9C90848D918F8E8C8A88867E77736D70706E6D6966636161605F5E60616162
605F5F5E74838C97AABAC8D7D3D3D9DEDAD8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D8D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D8D7D7D6D4D1D0CEC9C6C2BFBCBAB7B4B8BBBBBDBAB8B7B6
C3CCD2D8D6D7D9DBD9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D8D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D8D7D7D6D4D1D0CEC9C6C2BFBCBAB7B4B8BBBBBDBAB8B7B6
C3CCD2D8D6D7D9DBD9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D8D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D8D7D7D6D4D1D0CEC9C6C2BFBCBAB7B4B8BBBBBDBAB8B7B6
C3CCD2D8D6D7D9DBD9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D8D8D8D8D8D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D8D7D7D6D4D1D0CEC9C6C2BFBCBAB7B4B8BBBBBDBAB8B7B6
C3CCD2D8D6D7D9DBD9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{200, 200},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000380000b1P00`40o`000?l0003ob?ooo`00b?oo
o`00b?ooo`00b?ooo`00b?ooo`002_ooo`03fMWIf=SHf=SH00kHf=PXfMWI0m[JfP05fm_Kclo?clo?
alO7`/;200:l_;`00l30`<;2`/;2`P02`L710/;2`P03`l?3a<C4a<C400;4a<@4`l?30/71`@05_kno
_[jn_[jn_Kfm^[Zj00:g]kL01KBd];:b/[:b/Zn_[jf][@02ZZZZ00FXZ:RVYZJVYZJTY:BQXJ4019nO
W`:MWId00ibLW9jNWYjNWP04WYjN00FLW9bKVi^KVi^JVYZIVIT00YNGU`05U9BDTi>CTi>CTI6AXj>S
00:`/;001KRh^<71`L71`LW9bM7Ad@02f][J00CRh^;Kfm_Hf=SHf=P5fMWI3MSHf0SIfMT6f=SH1=WI
f@coool000[oool00mWIfMSHf=SHf00>f=SH:=WIf@?Jf]X01M_Kflo?clo?clO7al;2`P02_;bl00?0
`<32`/;2`/800/71`@;2`/800l?3`lC4a<C4a002a<C41<?3``;1`L401Kno_kjn_[jn_[fm_KZj^P02
]kNg00Fd];Bb/[:b/[:_[jn][Jd00ZZZZP05Z:RXYZJVYZJVY:BTXJ6Q00BOWil2WIfM00>LW9bNWYjN
WYh019jNWP05W9bLVi^KVi^KVYZJVIVI00:GUiL01IBDU9>CTi>CTi6ATJ>SX`02/;2`00Fh^;S1`L71
`L79bLWAdM400][JfP04h^;Rfm_Kf=SHf=SH1MWIf@gHf=P8fMWI1]SHf0CIfMT<oooo000:oooo00?I
fMWHf=SHf=P03]SHf2SIfMT3f][J00GKfm_?clo?clo7alO2`/800[bl_003`<30`/;2`/;200;1`L42
`/;200?3`l?4a<C4a<@00/C4a0C3`l<2`L7100Fo_knn_[jn_[jm_Kfj^[X00[Ng]`05];Bd/[:b/[:b
[jn_[Jf]00:ZZZX01JRXZ:JVYZJVYZBTY:6QX@04WinO0YfMW@03W9bLWYjNWYjN00BNWYh01IbLW9^K
Vi^KViZJVYVIV@02UiNG00FDU9BCTi>CTi>ATI6SXj<00[2`/005^;Rh`L71`L71bLW9dM7A00;Jf]X0
1>;Rh]_KfmSHf=SHf0GIfMT=f=SH2=WIf@KHf=P4fMWI3?ooo`002_ooo`03fMWIf=SHf=SH00kHf=PX
fMWI0m[JfP05fm_Kclo?clo?alO7`/;200:l_;`00l30`<;2`/;2`P02`L710/;2`P03`l?3a<C4a<C4
00;4a<@4`l?30/71`@05_kno_[jn_[jn_Kfm^[Zj00:g]kL01KBd];:b/[:b/Zn_[jf][@02ZZZZ00FX
Z:RVYZJVYZJTY:BQXJ4019nOW`:MWId00ibLW9jNWYjNWP04WYjN00FLW9bKVi^KVi^JVYZIVIT00YNG
U`05U9BDTi>CTi>CTI6AXj>S00:`/;001KRh^<71`L71`LW9bM7Ad@02f][J00CRh^;Kfm_Hf=SHf=P5
fMWI3MSHf0SIfMT6f=SH1=WIf@coool000[oool00mWIfMSHf=SHf00>f=SH:=WIf@?Jf]X01M_Kflo?
clo?clO7al;2`P02_;bl00?0`<32`/;2`/800/71`@;2`/800l?3`lC4a<C4a002a<C41<?3``;1`L40
1Kno_kjn_[jn_[fm_KZj^P02]kNg00Fd];Bb/[:b/[:_[jn][Jd00ZZZZP05Z:RXYZJVYZJVY:BTXJ6Q
00BOWil2WIfM00>LW9bNWYjNWYh019jNWP05W9bLVi^KVi^KVYZJVIVI00:GUiL01IBDU9>CTi>CTi6A
TJ>SX`02/;2`00Fh^;S1`L71`L79bLWAdM400][JfP04h^;Rfm_Kf=SHf=SH1MWIf@gHf=P8fMWI1]SH
f0CIfMT<oooo000:oooo00?IfMWHf=SHf=P03]SHf2SIfMT3f][J00GKfm_?clo?clo7alO2`/800[bl
_003`<30`/;2`/;200;1`L42`/;200?3`l?4a<C4a<@00/C4a0C3`l<2`L7100Fo_knn_[jn_[jm_Kfj
^[X00[Ng]`05];Bd/[:b/[:b[jn_[Jf]00:ZZZX01JRXZ:JVYZJVYZBTY:6QX@04WinO0YfMW@03W9bL
WYjNWYjN00BNWYh01IbLW9^KVi^KViZJVYVIV@02UiNG00FDU9BCTi>CTi>ATI6SXj<00[2`/005^;Rh
`L71`L71bLW9dM7A00;Jf]X01>;Rh]_KfmSHf=SHf0GIfMT=f=SH2=WIf@KHf=P4fMWI3?ooo`002_oo
o`_Hf=P7fMWI1]SHf1?IfMT2f=SH3=WIf@CJf]X2clo?00G6a/K1`L6k^k^k^k_0`<000/;2`P03`L71
`<30`L7100G1`L401Kno_kfm_Kfm_Kbl_;^k^`03^[Zj0[Vi^@05^;Rh];Bd/K6a/K6a[Zj^00:/[:`0
1JVYZJJVYZ>SXj>SXj2PX002Xj>S1:FUY@05X:2PW9bLVYZJVYZJUiNG00:IVIT019ZJVYVIVIVIVIVI
V@FJVYX2V9RH00FFUYJEUIFEUIFCTi>^[Zh00/;2`P03cLg=fm_Kfm_K00;EeMD2fMWI00?Lg=cJf][I
fMT01MWIf@KHf=PIfMWI00?Hf=Soooooool02_ooo`002_ooo`_Hf=P7fMWI1]SHf1?IfMT2f=SH3=WI
f@CJf]X2clo?00G6a/K1`L6k^k^k^k_0`<000/;2`P03`L71`<30`L7100G1`L401Kno_kfm_Kfm_Kbl
_;^k^`03^[Zj0[Vi^@05^;Rh];Bd/K6a/K6a[Zj^00:/[:`01JVYZJJVYZ>SXj>SXj2PX002Xj>S1:FU
Y@05X:2PW9bLVYZJVYZJUiNG00:IVIT019ZJVYVIVIVIVIVIV@FJVYX2V9RH00FFUYJEUIFEUIFCTi>^
[Zh00/;2`P03cLg=fm_Kfm_K00;EeMD2fMWI00?Lg=cJf][IfMT01MWIf@KHf=PIfMWI00?Hf=Sooooo
ool02_ooo`002_ooo`_Hf=P7fMWI1]SHf1?IfMT2f=SH3=WIf@CJf]X2clo?00G6a/K1`L6k^k^k^k_0
`<000/;2`P03`L71`<30`L7100G1`L401Kno_kfm_Kfm_Kbl_;^k^`03^[Zj0[Vi^@05^;Rh];Bd/K6a
/K6a[Zj^00:/[:`01JVYZJJVYZ>SXj>SXj2PX002Xj>S1:FUY@05X:2PW9bLVYZJVYZJUiNG00:IVIT0
19ZJVYVIVIVIVIVIV@FJVYX2V9RH00FFUYJEUIFEUIFCTi>^[Zh00/;2`P03cLg=fm_Kfm_K00;EeMD2
fMWI00?Lg=cJf][IfMT01MWIf@KHf=PIfMWI00?Hf=Soooooool02_ooo`002_ooo`_Hf=P7fMWI1]SH
f1?IfMT2f=SH3=WIf@CJf]X2clo?00G6a/K1`L6k^k^k^k_0`<000/;2`P03`L71`<30`L7100G1`L40
1Kno_kfm_Kfm_Kbl_;^k^`03^[Zj0[Vi^@05^;Rh];Bd/K6a/K6a[Zj^00:/[:`01JVYZJJVYZ>SXj>S
Xj2PX002Xj>S1:FUY@05X:2PW9bLVYZJVYZJUiNG00:IVIT019ZJVYVIVIVIVIVIV@FJVYX2V9RH00FF
UYJEUIFEUIFCTi>^[Zh00/;2`P03cLg=fm_Kfm_K00;EeMD2fMWI00?Lg=cJf][IfMT01MWIf@KHf=PI
fMWI00?Hf=Soooooool02_ooo`002_ooo`_Hf=P7fMWI1]SHf1?IfMT2f=SH3=WIf@CJf]X2clo?00G6
a/K1`L6k^k^k^k_0`<000/;2`P03`L71`<30`L7100G1`L401Kno_kfm_Kfm_Kbl_;^k^`03^[Zj0[Vi
^@05^;Rh];Bd/K6a/K6a[Zj^00:/[:`01JVYZJJVYZ>SXj>SXj2PX002Xj>S1:FUY@05X:2PW9bLVYZJ
VYZJUiNG00:IVIT019ZJVYVIVIVIVIVIV@FJVYX2V9RH00FFUYJEUIFEUIFCTi>^[Zh00/;2`P03cLg=
fm_Kfm_K00;EeMD2fMWI00?Lg=cJf][IfMT01MWIf@KHf=PIfMWI00?Hf=Soooooool02_ooo`002_oo
ocgIfMT2cLg=00G5aLFo_kni^KVi^KVm_Kd00[no_`:m_Kd2_[jn0/30`0;1`L401L;2`/?3`l?3`lC4
a<G5a@06a<C400C2`/;1`L71`L70`<02_[jn00Fk^k^g]kNe]KFe]KFb/[800[6a/@06[jn_[Jf]Zj^[
Zj^[Z:RXYJFU0Z:RXP05WinOX:2PX:2PWinOWYjN00FMWId2W9bL1IfMW@05WYjN]kNgb/[:b/[:emOG
00;UiND01][Jf]KFe]WIfMWIfM[Jf]WIf@;Hf=P00mWIfMSHf=SHf00QfMWI3?ooo`002_ooocgIfMT2
cLg=00G5aLFo_kni^KVi^KVm_Kd00[no_`:m_Kd2_[jn0/30`0;1`L401L;2`/?3`l?3`lC4a<G5a@06
a<C400C2`/;1`L71`L70`<02_[jn00Fk^k^g]kNe]KFe]KFb/[800[6a/@06[jn_[Jf]Zj^[Zj^[Z:RX
YJFU0Z:RXP05WinOX:2PX:2PWinOWYjN00FMWId2W9bL1IfMW@05WYjN]kNgb/[:b/[:emOG00;UiND0
1][Jf]KFe]WIfMWIfM[Jf]WIf@;Hf=P00mWIfMSHf=SHf00QfMWI3?ooo`002_ooocgIfMT2cLg=00G5
aLFo_kni^KVi^KVm_Kd00[no_`:m_Kd2_[jn0/30`0;1`L401L;2`/?3`l?3`lC4a<G5a@06a<C400C2
`/;1`L71`L70`<02_[jn00Fk^k^g]kNe]KFe]KFb/[800[6a/@06[jn_[Jf]Zj^[Zj^[Z:RXYJFU0Z:R
XP05WinOX:2PX:2PWinOWYjN00FMWId2W9bL1IfMW@05WYjN]kNgb/[:b/[:emOG00;UiND01][Jf]KF
e]WIfMWIfM[Jf]WIf@;Hf=P00mWIfMSHf=SHf00QfMWI3?ooo`002_ooocgIfMT2cLg=00G5aLFo_kni
^KVi^KVm_Kd00[no_`:m_Kd2_[jn0/30`0;1`L401L;2`/?3`l?3`lC4a<G5a@06a<C400C2`/;1`L71
`L70`<02_[jn00Fk^k^g]kNe]KFe]KFb/[800[6a/@06[jn_[Jf]Zj^[Zj^[Z:RXYJFU0Z:RXP05WinO
X:2PX:2PWinOWYjN00FMWId2W9bL1IfMW@05WYjN]kNgb/[:b/[:emOG00;UiND01][Jf]KFe]WIfMWI
fM[Jf]WIf@;Hf=P00mWIfMSHf=SHf00QfMWI3?ooo`002_ooocgIfMT2cLg=00G5aLFo_kni^KVi^KVm
_Kd00[no_`:m_Kd2_[jn0/30`0;1`L401L;2`/?3`l?3`lC4a<G5a@06a<C400C2`/;1`L71`L70`<02
_[jn00Fk^k^g]kNe]KFe]KFb/[800[6a/@06[jn_[Jf]Zj^[Zj^[Z:RXYJFU0Z:RXP05WinOX:2PX:2P
WinOWYjN00FMWId2W9bL1IfMW@05WYjN]kNgb/[:b/[:emOG00;UiND01][Jf]KFe]WIfMWIfM[Jf]WI
f@;Hf=P00mWIfMSHf=SHf00QfMWI3?ooo`002_ooocgIfMT2cLg=00G5aLFo_kni^KVi^KVm_Kd00[no
_`:m_Kd2_[jn0/30`0;1`L401L;2`/?3`l?3`lC4a<G5a@06a<C400C2`/;1`L71`L70`<02_[jn00Fk
^k^g]kNe]KFe]KFb/[800[6a/@06[jn_[Jf]Zj^[Zj^[Z:RXYJFU0Z:RXP05WinOX:2PX:2PWinOWYjN
00FMWId2W9bL1IfMW@05WYjN]kNgb/[:b/[:emOG00;UiND01][Jf]KFe]WIfMWIfM[Jf]WIf@;Hf=P0
0mWIfMSHf=SHf00QfMWI3?ooo`002_ooo`03fMWIf=SHf=SH00CHf=P[fMWI00CLg=cNg]kNg]kOgml2
hN7Q00Fo_knWYjNHV9RHV9R7QhL00ZNWY`05^KVi_knob<S8b<S8`/;200;0`<000l;2`/?3`l;2`P0:
`/;21L?3``05a<C4`/;2`L71`L71`<3000:o_kl01Kfm_K^k^kZj^[Zj^[Rh^002];Bd00Ja/K6_[jn/
[:b/[:bZZZZWYjL2Y:BT00FRXZ:QXJ6QXJ6PX:2NWYh01YbLW004Vi^KX:2PX:2PY:BT0ZJVYP05ZJVY
_[jnc/k>c/k>f][J00;Vi^H00mcLg=OGemWIf@09fMWI1=SHf0kIfMT3f=SH2mWIf@coool000[oool0
0mWIfMSHf=SHf004f=SH:mWIf@04g=cLg]kNg]kNgmoO0^7Qh@05_knoYjNWV9RHV9RHQhN700:WYjL0
1KVi^Kno_lS8b<S8b<;2`P02`<3000?2`/;3`l?2`/802/;2`PG3`l<01LC4a<;2`/71`L71`L30`002
_kno00Fm_Kfk^k^j^[Zj^[Zh^;P00[Bd]006/K6a[jn_[:b/[:b/ZZZZYjNW0ZBTY005XZ:RXJ6QXJ6Q
X:2PWYjN00JLW9`019^KVj2PX:2PX:BTY0:VYZH01JVYZKjn_/k>c/k>c][JfP02i^KV00?Lg=cGemOI
fMT02MWIf@CHf=P>fMWI0mSHf0_IfMT<oooo000:oooo00?IfMWHf=SHf=P01=SHf2_IfMT01=cLg=kN
g]kNg]oOg`;QhN401Kno_jNWYiRHV9RHV8N7Q`02YjNW00Fi^KVo_ko8b<S8b<S2`/800/30`003`/;2
`l?3`/;200[2`/85`l?300G4a<C2`/;1`L71`L70`<000[no_`05_Kfm^k^k^[Zj^[Zj^;Rh00:d];@0
1[6a/Jn_[jb/[:b/[:ZZZZNWY`:TY:@01J:RXZ6QXJ6QXJ2PX9jNWP06W9bL00BKVi^PX:2PX:2TY:@2
YZJV00FYZJVn_[k>c/k>c/kJf]X00^KViP03g=cLemOGfMWI00WIfMT4f=SH3]WIf@?Hf=P;fMWI3?oo
o`002_ooo`03fMWIf=SHf=SH00CHf=P[fMWI00CLg=cNg]kNg]kOgml2hN7Q00Fo_knWYjNHV9RHV9R7
QhL00ZNWY`05^KVi_knob<S8b<S8`/;200;0`<000l;2`/?3`l;2`P0:`/;21L?3``05a<C4`/;2`L71
`L71`<3000:o_kl01Kfm_K^k^kZj^[Zj^[Rh^002];Bd00Ja/K6_[jn/[:b/[:bZZZZWYjL2Y:BT00FR
XZ:QXJ6QXJ6PX:2NWYh01YbLW004Vi^KX:2PX:2PY:BT0ZJVYP05ZJVY_[jnc/k>c/k>f][J00;Vi^H0
0mcLg=OGemWIf@09fMWI1=SHf0kIfMT3f=SH2mWIf@coool000[oool00mWIfMSHf=SHf004f=SH:mWI
f@04g=cLg]kNg]kNgmoO0^7Qh@05_knoYjNWV9RHV9RHQhN700:WYjL01KVi^Kno_lS8b<S8b<;2`P02
`<3000?2`/;3`l?2`/802/;2`PG3`l<01LC4a<;2`/71`L71`L30`002_kno00Fm_Kfk^k^j^[Zj^[Zh
^;P00[Bd]006/K6a[jn_[:b/[:b/ZZZZYjNW0ZBTY005XZ:RXJ6QXJ6QX:2PWYjN00JLW9`019^KVj2P
X:2PX:BTY0:VYZH01JVYZKjn_/k>c/k>c][JfP02i^KV00?Lg=cGemOIfMT02MWIf@CHf=P>fMWI0mSH
f0_IfMT<oooo000:oooo00?IfMWHf=SHf=P01MSHf0?GemL3f=SH7mWIf@06g=cLg]kNgmoOgmoOh>3P
alO70[Fe]@03ZZZZWIfMWIfM00:SXj<2WinO00FLW9b^[Zj^[Zjk^k_2`/800/[:bP03`l?3`<30`<30
00;2`/84`L710/30`005`/;2`l?3`l?3a<C4aLG500;3`l<4`/;200Bk^k^f][Jf][Jc/k<2[jn_00F^
[Zj/[:bYZJVYZJVWYjL00ZRXZ0:YZJT2Z:RX00FUYJFRXZ:QXJ6QXJ6OWil00ijNWP04W9bLVi^KVi^K
VYZJ0YRHV005UiNGUYJFW9bLW9bLWinO00:QXJ401JBTY;Zj^/_;bl_;bmKFeP02hn?S00GJf][Fe]KI
fMWIfMWJf]X09mWIf@coool000[oool00mWIfMSHf=SHf005f=SH0mOGe`?Hf=POfMWI00KLg=cNg]kO
gmoOgmoPh>37alL2]KFe00>ZZZZMWIfMWId00Z>SX`:OWil01IbLW:j^[Zj^[[^k^l;2`P02b/[:00?3
`l?0`<30`<000/;2`PC1`L42`<3000G2`/;3`l?3`l?4a<C5aLD00/?3``C2`/801;^k^kJf][Jf][>c
/`:_[jl01Jj^[Zb/[:VYZJVYZJNWY`02Z:RX0ZVYZ@:XZ:P01JFUYJ:RXZ6QXJ6QXInOW`03WYjN00BL
W9bKVi^KVi^JVYX2V9RH00FGUiNFUYJLW9bLW9bOWil00Z6QX@05Y:BT^[Zjbl_;bl_;e]KF00;Shn<0
1M[Jf]KFe]WIfMWIfM[JfP0WfMWI3?ooo`002_ooo`03fMWIf=SHf=SH00GHf=P3emOG0mSHf1oIfMT0
1]cLg=kNg]oOgmoOgn3Ph<O7a`:e]KD00jZZZYfMWIfMW@02Xj>S0YnOW`05W9bL[Zj^[Zj^^k^k`/;2
00;:b/X00l?3`l30`<30`002`/;21<71`@;0`<001L;2`/?3`l?3`lC4a<G5a@02`l?31<;2`P04^k^k
][Jf][Jf/k>c0Zn_[`05[Zj^[:b/ZJVYZJVYYjNW00:XZ:P2ZJVY0ZRXZ005YJFUXZ:RXJ6QXJ6QWinO
00>NWYh019bLW9^KVi^KViZJVP:HV9P01INGUiJFUYbLW9bLW9nOW`02XJ6Q00FTY:Bj^[[;bl_;bl_F
e]H00^?Sh`05f][Je]KFfMWIfMWIf][J02OIfMT<oooo000:oooo00?IfMWHf=SHf=P01MSHf0?GemL3
f=SH7mWIf@06g=cLg]kNgmoOgmoOh>3PalO70[Fe]@03ZZZZWIfMWIfM00:SXj<2WinO00FLW9b^[Zj^
[Zjk^k_2`/800/[:bP03`l?3`<30`<3000;2`/84`L710/30`005`/;2`l?3`l?3a<C4aLG500;3`l<4
`/;200Bk^k^f][Jf][Jc/k<2[jn_00F^[Zj/[:bYZJVYZJVWYjL00ZRXZ0:YZJT2Z:RX00FUYJFRXZ:Q
XJ6QXJ6OWil00ijNWP04W9bLVi^KVi^KVYZJ0YRHV005UiNGUYJFW9bLW9bLWinO00:QXJ401JBTY;Zj
^/_;bl_;bmKFeP02hn?S00GJf][Fe]KIfMWIfMWJf]X09mWIf@coool000[oool00mWIfMSHf=SHf005
f=SH0mOGe`?Hf=POfMWI00KLg=cNg]kOgmoOgmoPh>37alL2]KFe00>ZZZZMWIfMWId00Z>SX`:OWil0
1IbLW:j^[Zj^[[^k^l;2`P02b/[:00?3`l?0`<30`<000/;2`PC1`L42`<3000G2`/;3`l?3`l?4a<C5
aLD00/?3``C2`/801;^k^kJf][Jf][>c/`:_[jl01Jj^[Zb/[:VYZJVYZJNWY`02Z:RX0ZVYZ@:XZ:P0
1JFUYJ:RXZ6QXJ6QXInOW`03WYjN00BLW9bKVi^KVi^JVYX2V9RH00FGUiNFUYJLW9bLW9bOWil00Z6Q
X@05Y:BT^[Zjbl_;bl_;e]KF00;Shn<01M[Jf]KFe]WIfMWIfM[JfP0WfMWI3?ooo`002_ooo`03fMWI
f=SHf=SH00GHf=P3emOG0mSHf1oIfMT01]cLg=kNg]oOgmoOgn3Ph<O7a`:e]KD00jZZZYfMWIfMW@02
Xj>S0YnOW`05W9bL[Zj^[Zj^^k^k`/;200;:b/X00l?3`l30`<30`002`/;21<71`@;0`<001L;2`/?3
`l?3`lC4a<G5a@02`l?31<;2`P04^k^k][Jf][Jf/k>c0Zn_[`05[Zj^[:b/ZJVYZJVYYjNW00:XZ:P2
ZJVY0ZRXZ005YJFUXZ:RXJ6QXJ6QWinO00>NWYh019bLW9^KVi^KViZJVP:HV9P01INGUiJFUYbLW9bL
W9nOW`02XJ6Q00FTY:Bj^[[;bl_;bl_Fe]H00^?Sh`05f][Je]KFfMWIfMWIf][J02OIfMT<oooo000:
oooo0mWIf@SHf=PRfMWI00KFe]KDe=CCdm?Cdm?AdM6h^;P2YZJV00FIVIV;Rh^;Rh^YZJVk^k/00/71
`@05b/[:`l?3`l?3`<30`/;200;3`l<01Kno_kfm_Kfm_Kbl_;^k^`02_Kfm0[no_`O0`<02^k^k00Fg
]kNd];Bd];Ba/K6TY:@00YZJVP05TY:BRHV9RHV9SXj>Shn?00:=SHd00h^;Rhj>SXj>SP02TI6A0Y:B
TP04U9BDUIFEUYJFUYJF19NGU`>HV9P01IZJVY^KVi^KVibLW9fMW@02VIVI00FFUYJEUIFEUIFDU9BU
YJD00[6a/@05^KVi`L71`L71bLW9dM7A00;Jf]X01>;Rh]_KfmSHf=SHf0OIfMT00mSHf=WIfMWIf@0J
fMWI3?ooo`002_ooo`?IfMT8f=SH8]WIf@06e]KFe=CDdm?Cdm?CdM7A^;Rh0ZJVYP05VIVIRh^;Rh^;
ZJVY^k^k00;1`L401L[:b/?3`l?3`l30`<;2`P02`l?300Fo_knm_Kfm_Kfl_;bk^k/00[fm_@:o_kl7
`<300[^k^`05]kNg];Bd];Bd/K6aY:BT00:JVYX01I:BTXV9RHV9RHj>SXn?S`02SHf=00>;Rh^>SXj>
SXh00Y6AT@:BTY8019BDU9FEUIJFUYJFUPBGUiL3V9RH00FJVYZKVi^KVi^LW9bMWId00YVIV@05UYJF
UIFEUIFEU9BDYJFU00:a/K401KVi^L71`L71`LW9bM7Ad@02f][J00CRh^;Kfm_Hf=SHf=P7fMWI00?H
f=SIfMWIfMT06]WIf@coool000[oool3fMWI2=SHf2;IfMT01]KFe]CDe=?Cdm?Cdm7AdKRh^0:VYZH0
1IVIVH^;Rh^;RjVYZK^k^`02`L7100G:b/[3`l?3`l?0`<32`/800/?3``05_kno_Kfm_Kfm_;bl^k^k
00:m_Kd2_kno1l30`0:k^k/01KNg]kBd];Bd];6a/JBTY002VYZJ00FBTY:9RHV9RHV>SXj?Shl00Xf=
S@03Rh^;SXj>SXj>00:ATI42TY:B00BDU9BEUIFFUYJFUYH4UiNG0iRHV005VYZJVi^KVi^KW9bLWIfM
00:IVIT01IJFUYFEUIFEUIBDU:FUY@02/K6a00Fi^KW1`L71`L79bLWAdM400][JfP04h^;Rfm_Kf=SH
f=SH1mWIf@03f=SHfMWIfMWI01[IfMT<oooo000:oooo0mWIf@SHf=PRfMWI00KFe]KDe=CCdm?Cdm?A
dM6h^;P2YZJV00FIVIV;Rh^;Rh^YZJVk^k/00/71`@05b/[:`l?3`l?3`<30`/;200;3`l<01Kno_kfm
_Kfm_Kbl_;^k^`02_Kfm0[no_`O0`<02^k^k00Fg]kNd];Bd];Ba/K6TY:@00YZJVP05TY:BRHV9RHV9
SXj>Shn?00:=SHd00h^;Rhj>SXj>SP02TI6A0Y:BTP04U9BDUIFEUYJFUYJF19NGU`>HV9P01IZJVY^K
Vi^KVibLW9fMW@02VIVI00FFUYJEUIFEUIFDU9BUYJD00[6a/@05^KVi`L71`L71bLW9dM7A00;Jf]X0
1>;Rh]_KfmSHf=SHf0OIfMT00mSHf=WIfMWIf@0JfMWI3?ooo`002_ooo`?IfMT8f=SH8]WIf@06e]KF
e=CDdm?Cdm?CdM7A^;Rh0ZJVYP05VIVIRh^;Rh^;ZJVY^k^k00;1`L401L[:b/?3`l?3`l30`<;2`P02
`l?300Fo_knm_Kfm_Kfl_;bk^k/00[fm_@:o_kl7`<300[^k^`05]kNg];Bd];Bd/K6aY:BT00:JVYX0
1I:BTXV9RHV9RHj>SXn?S`02SHf=00>;Rh^>SXj>SXh00Y6AT@:BTY8019BDU9FEUIJFUYJFUPBGUiL3
V9RH00FJVYZKVi^KVi^LW9bMWId00YVIV@05UYJFUIFEUIFEU9BDYJFU00:a/K401KVi^L71`L71`LW9
bM7Ad@02f][J00CRh^;Kfm_Hf=SHf=P7fMWI00?Hf=SIfMWIfMT06]WIf@coool000[oool7fMWI1]SH
f1[IfMT01=kNg^7QhN7QhNCTi0;Vi^H01[^k^ibLW8V9RHV9RG=cLiZJVP:a/K401KRh^<;2`/;2`[^k
^kRh^002^[Zj00Fk^k^n_[jn_[k1`L73`l<00/G5a@05^;Rh[jn_[jn_Zj^[YJFU00>VYZH01:BTY::R
XZ:RXZ:RXP:QXJ4019nOWijNWZ6QXJ6QX@>RXZ801J>SXj^[Zk6a/K6a/KFe]@02^KVi00F[Zj^QXJ6M
WIfMWIfGUiL00X^;R`06P820N7QhKVi^KVi^NWYjOgmo0X20P005PH61R8R8R8R8SXj>TY:B00:GUiL0
1IZJVYfMWIfMWJ6QXJFUY@02X:2P0ifMW@03W9bLWIfMWIfM00BMWId01[:b//71`L[:b/[:b]GEeM?C
d`;De=@01MWIfMgMgMgMgM[Jf]SHf00OfMWI3?ooo`002_ooo`OIfMT6f=SH6]WIf@04g]kNhN7QhN7Q
i>CT0^KViP06^k^kW9bLRHV9RHV9Lg=cVYZJ0[6a/@05^;Rh`/;2`/;2^k^k^;Rh00:j^[X01K^k^kjn
_[jn_/71`L?3``02aLG500Fh^;R_[jn_[jn[Zj^UYJD00jJVYP04Y:BTXZ:RXZ:RXZ:R0Z6QX@04WinO
WYjNXJ6QXJ6Q0j:RXP05Xj>SZj^[/K6a/K6a]KFe00:i^KT01J^[Zj6QXIfMWIfMWINGU`02Rh^;00J0
P81hN7Q^KVi^KVijNWYoOgl2P82000F1PH68R8R8R8R>SXjBTY800YNGU`05VYZJWIfMWIfMXJ6QYJFU
00:PX:03WIfM00>LW9bMWIfMWId019fMW@06/[:b`L71b/[:b/[:eMGEdm?C0]CDe005fMWIgMgMgMgM
f][Jf=SH01oIfMT<oooo000:oooo1mWIf@KHf=PJfMWI00CNg]kQhN7QhN7Ti>@2i^KV00Jk^k^LW9b9
RHV9RHUcLg>JVYX2/K6a00Fh^;S2`/;2`/:k^k^h^;P00[Zj^P05^k^k_[jn_[jn`L71`l?300;5aLD0
1KRh^:n_[jn_[j^[ZjFUY@03YZJV00BTY:BRXZ:RXZ:RXZ82XJ6Q00BOWinNWYjQXJ6QXJ43XZ:R00FS
Xj>[Zj^a/K6a/K6e]KD00[Vi^@05Zj^[XJ6QWIfMWIfMUiNG00:;Rh/01X20P7QhN6i^KVi^KWYjNWmo
O`:0P8001H61PHR8R8R8R8j>SY:BTP02UiNG00FJVYZMWIfMWIfQXJ6UYJD00Z2PX0>MWId00ibLW9fM
WIfMW@04WIfM00Jb/[;1`L7:b/[:b/[EeMGCdm<2e=CD00GIfMWMgMgMgMgJf][Hf=P07mWIf@coool0
00[oool7fMWI1]SHf1[IfMT01=kNg^7QhN7QhNCTi0;Vi^H01[^k^ibLW8V9RHV9RG=cLiZJVP:a/K40
1KRh^<;2`/;2`[^k^kRh^002^[Zj00Fk^k^n_[jn_[k1`L73`l<00/G5a@05^;Rh[jn_[jn_Zj^[YJFU
00>VYZH01:BTY::RXZ:RXZ:RXP:QXJ4019nOWijNWZ6QXJ6QX@>RXZ801J>SXj^[Zk6a/K6a/KFe]@02
^KVi00F[Zj^QXJ6MWIfMWIfGUiL00X^;R`06P820N7QhKVi^KVi^NWYjOgmo0X20P005PH61R8R8R8R8
SXj>TY:B00:GUiL01IZJVYfMWIfMWJ6QXJFUY@02X:2P0ifMW@03W9bLWIfMWIfM00BMWId01[:b//71
`L[:b/[:b]GEeM?Cd`;De=@01MWIfMgMgMgMgM[Jf]SHf00OfMWI3?ooo`002_ooo`OIfMT6f=SH6]WI
f@04g]kNhN7QhN7Qi>CT0^KViP06^k^kW9bLRHV9RHV9Lg=cVYZJ0[6a/@05^;Rh`/;2`/;2^k^k^;Rh
00:j^[X01K^k^kjn_[jn_/71`L?3``02aLG500Fh^;R_[jn_[jn[Zj^UYJD00jJVYP04Y:BTXZ:RXZ:R
XZ:R0Z6QX@04WinOWYjNXJ6QXJ6Q0j:RXP05Xj>SZj^[/K6a/K6a]KFe00:i^KT01J^[Zj6QXIfMWIfM
WINGU`02Rh^;00J0P81hN7Q^KVi^KVijNWYoOgl2P82000F1PH68R8R8R8R>SXjBTY800YNGU`05VYZJ
WIfMWIfMXJ6QYJFU00:PX:03WIfM00>LW9bMWIfMWId019fMW@06/[:b`L71b/[:b/[:eMGEdm?C0]CD
e005fMWIgMgMgMgMf][Jf=SH01oIfMT<oooo000:oooo1mWIf@KHf=PJfMWI00CNg]kQhN7QhN7Ti>@2
i^KV00Jk^k^LW9b9RHV9RHUcLg>JVYX2/K6a00Fh^;S2`/;2`/:k^k^h^;P00[Zj^P05^k^k_[jn_[jn
`L71`l?300;5aLD01KRh^:n_[jn_[j^[ZjFUY@03YZJV00BTY:BRXZ:RXZ:RXZ82XJ6Q00BOWinNWYjQ
XJ6QXJ43XZ:R00FSXj>[Zj^a/K6a/K6e]KD00[Vi^@05Zj^[XJ6QWIfMWIfMUiNG00:;Rh/01X20P7Qh
N6i^KVi^KWYjNWmoO`:0P8001H61PHR8R8R8R8j>SY:BTP02UiNG00FJVYZMWIfMWIfQXJ6UYJD00Z2P
X0>MWId00ibLW9fMWIfMW@04WIfM00Jb/[;1`L7:b/[:b/[EeMGCdm<2e=CD00GIfMWMgMgMgMgJf][H
f=P07mWIf@coool000[oool00mWIfMSHf=SHf00:f=SH1=WIf@OHf=P7fMWI2=SHf004dm?Cd=3@d=3@
c/k>0/_;b`06YJFUR8R8MGEeMGEeGemOTi>C0[Bd]005`<30d];Bd];B_kno]kNg00:h^;P01KJf][^k
^k^k^kfm_Kno_`02`<3000FYZJVHV9RHV9R>SXj3Ph<00WinOP05MgMgKVi^IVIVIVIVSXj>00:XZ:P0
1KJf]/O7akfm_Kfm_KZj^P02_kno00G1`L6k^k^h^;Rh^;Rf][H00[Bd]003][Jf]kNg]kNg00:g]kL2
[jn_00JZZZZVYZJRXZ:RXZ:9RHUfMWH2J6QX00EIFEU_Kfm_KfmkNg]mOGd00X61P@05TI6AWYjNWYjN
Z:RX/[:b00:XZ:P01J>SXjBTY:BTY:>SXinOW`02W9bL00FJVYZGUiNGUiNQXJ6XZ:P00Z^[Z`05/;2`
^k^kaLG5aLG5c<c<00?De=@01=GEeMWIfMWIfMgMg@;Jf]X8fMWI00?Hf=SIfMWIfMT03mWIf@coool0
00[oool00mWIfMSHf=SHf00:f=SH1=WIf@OHf=P7fMWI2=SHf004dm?Cd=3@d=3@c/k>0/_;b`06YJFU
R8R8MGEeMGEeGemOTi>C0[Bd]005`<30d];Bd];B_kno]kNg00:h^;P01KJf][^k^k^k^kfm_Kno_`02
`<3000FYZJVHV9RHV9R>SXj3Ph<00WinOP05MgMgKVi^IVIVIVIVSXj>00:XZ:P01KJf]/O7akfm_Kfm
_KZj^P02_kno00G1`L6k^k^h^;Rh^;Rf][H00[Bd]003][Jf]kNg]kNg00:g]kL2[jn_00JZZZZVYZJR
XZ:RXZ:9RHUfMWH2J6QX00EIFEU_Kfm_KfmkNg]mOGd00X61P@05TI6AWYjNWYjNZ:RX/[:b00:XZ:P0
1J>SXjBTY:BTY:>SXinOW`02W9bL00FJVYZGUiNGUiNQXJ6XZ:P00Z^[Z`05/;2`^k^kaLG5aLG5c<c<
00?De=@01=GEeMWIfMWIfMgMg@;Jf]X8fMWI00?Hf=SIfMWIfMT03mWIf@coool000[oool00mWIfMSH
f=SHf00:f=SH1=WIf@OHf=P7fMWI2=SHf004dm?Cd=3@d=3@c/k>0/_;b`06YJFUR8R8MGEeMGEeGemO
Ti>C0[Bd]005`<30d];Bd];B_kno]kNg00:h^;P01KJf][^k^k^k^kfm_Kno_`02`<3000FYZJVHV9RH
V9R>SXj3Ph<00WinOP05MgMgKVi^IVIVIVIVSXj>00:XZ:P01KJf]/O7akfm_Kfm_KZj^P02_kno00G1
`L6k^k^h^;Rh^;Rf][H00[Bd]003][Jf]kNg]kNg00:g]kL2[jn_00JZZZZVYZJRXZ:RXZ:9RHUfMWH2
J6QX00EIFEU_Kfm_KfmkNg]mOGd00X61P@05TI6AWYjNWYjNZ:RX/[:b00:XZ:P01J>SXjBTY:BTY:>S
XinOW`02W9bL00FJVYZGUiNGUiNQXJ6XZ:P00Z^[Z`05/;2`^k^kaLG5aLG5c<c<00?De=@01=GEeMWI
fMWIfMgMg@;Jf]X8fMWI00?Hf=SIfMWIfMT03mWIf@coool000[oool00mWIfMSHf=SHf00:f=SH1=WI
f@OHf=P7fMWI2=SHf004dm?Cd=3@d=3@c/k>0/_;b`06YJFUR8R8MGEeMGEeGemOTi>C0[Bd]005`<30
d];Bd];B_kno]kNg00:h^;P01KJf][^k^k^k^kfm_Kno_`02`<3000FYZJVHV9RHV9R>SXj3Ph<00Win
OP05MgMgKVi^IVIVIVIVSXj>00:XZ:P01KJf]/O7akfm_Kfm_KZj^P02_kno00G1`L6k^k^h^;Rh^;Rf
][H00[Bd]003][Jf]kNg]kNg00:g]kL2[jn_00JZZZZVYZJRXZ:RXZ:9RHUfMWH2J6QX00EIFEU_Kfm_
KfmkNg]mOGd00X61P@05TI6AWYjNWYjNZ:RX/[:b00:XZ:P01J>SXjBTY:BTY:>SXinOW`02W9bL00FJ
VYZGUiNGUiNQXJ6XZ:P00Z^[Z`05/;2`^k^kaLG5aLG5c<c<00?De=@01=GEeMWIfMWIfMgMg@;Jf]X8
fMWI00?Hf=SIfMWIfMT03mWIf@coool000[oool00mWIfMSHf=SHf00:f=SH1=WIf@OHf=P7fMWI2=SH
f004dm?Cd=3@d=3@c/k>0/_;b`06YJFUR8R8MGEeMGEeGemOTi>C0[Bd]005`<30d];Bd];B_kno]kNg
00:h^;P01KJf][^k^k^k^kfm_Kno_`02`<3000FYZJVHV9RHV9R>SXj3Ph<00WinOP05MgMgKVi^IVIV
IVIVSXj>00:XZ:P01KJf]/O7akfm_Kfm_KZj^P02_kno00G1`L6k^k^h^;Rh^;Rf][H00[Bd]003][Jf
]kNg]kNg00:g]kL2[jn_00JZZZZVYZJRXZ:RXZ:9RHUfMWH2J6QX00EIFEU_Kfm_KfmkNg]mOGd00X61
P@05TI6AWYjNWYjNZ:RX/[:b00:XZ:P01J>SXjBTY:BTY:>SXinOW`02W9bL00FJVYZGUiNGUiNQXJ6X
Z:P00Z^[Z`05/;2`^k^kaLG5aLG5c<c<00?De=@01=GEeMWIfMWIfMgMg@;Jf]X8fMWI00?Hf=SIfMWI
fMT03mWIf@coool000[oool=fMWI1=SHf0oIfMT01=SHf=cLg=cLg=kNgP;Ph>001N;RhZ2PX75aLG5a
LEADE002<S8b00IZJVZ:RXZBTY:BTY:PX:2WYjL2/;2`00Fk^k_6a/K6a/Jk^k^f][H00[Ng]`Ff][H2
]KFe00F/[:bVYZJVYZJRXZ:MWId00[2`/005_;bl`/;2b/[:b/[:`/;200>n_[h01;fm_Kbl_;bl_;bl
_0:k^k/01KZj^[Bd]:n_[jn_[jb/[002Z:RX00FTY:BPX:2LW9bLW9bHV9P00YFEU@06Ti>CT92@SHf=
SHf=S8b<RXZ:0XR8R005QXJ6Lg=cLg=cI6ATFUYJ009?Cdl01GQhN9>CTi>CTj2PX;6a/@02YJFU00FQ
XJ6UYJFUYJFWYjNPX:000Y^KV`04V9RHUIFEUIFEV9RH19VIV@04ZJVY];Bd];Bd_;bl0/C4a005bl_;
dM7AfMWIfMWIh>3P00;Jf]X00mSHf=WIfMWIf@0GfMWI3?ooo`002_ooo`gIfMT4f=SH3mWIf@04f=SH
g=cLg=cLg]kN0^3Ph005h^;RX:2PLG5aLG5aE5AD008b<S801VYZJXZ:RY:BTY:BTZ2PX:NWY`:`/;00
1K^k^lK6a/K6a[^k^kJf]P02]kNg1KJf]P:e]KD01Jb/[:JVYZJVYZ:RXYfMW@02/;2`00Fl_;c2`/;:
b/[:b/[2`/800kjn_P04_Kfm_;bl_;bl_;bl0[^k^`05^[Zj];Bd[jn_[jn_[:b/00:XZ:P01JBTY:2P
X9bLW9bLW9RHV002UIFE00JCTi>@T92=SHf=SHf<S8b:RXX2R8R800F6QXIcLg=cLg=TI6AJFUX00Tm?
C`05N7QhTi>CTi>CX:2P/K6a00:UYJD01J6QXJFUYJFUYJNWYj2PX002Vi^K00BHV9REUIFEUIFHV9P4
VIVI00BYZJVd];Bd];Bl_;`2a<C400G;bl_AdM7IfMWIfMWPh>000][JfP03f=SHfMWIfMWI01OIfMT<
oooo000:oooo3MWIf@CHf=P?fMWI00CHf=SLg=cLg=cNg]h2h>3P00GRh^:PX:1aLG5aLG5DE5@00S8b
<P06JVYZRXZ:TY:BTY:BX:2PYjNW0[2`/005^k^ka/K6a/K6^k^k][Jf00:g]kL5][Jf0[Fe]@05[:b/
YZJVYZJVXZ:RWIfM00:`/;001Kbl_<;2`/[:b/[:b/;2`P03_[jn00Bm_Kfl_;bl_;bl_;`2^k^k00Fj
^[Zd];B_[jn_[jn/[:`00ZRXZ005Y:BTX:2PW9bLW9bLV9RH00:EUID01Y>CTi2@T8f=SHf=SHb<S8Z:
RP:8R8P01HJ6QW=cLg=cLfATI5YJFP02Cdm?00EhN7RCTi>CTi>PX:2a/K400ZFUY@05XJ6QYJFUYJFU
YjNWX:2P00:KVi/019RHV9FEUIFEUIRHV0BIVIT01:VYZKBd];Bd];bl_0;4a<@01L_;bm7AdMWIfMWI
fN3Ph002f][J00?Hf=SIfMWIfMT05mWIf@coool000[oool=fMWI1=SHf0oIfMT01=SHf=cLg=cLg=kN
gP;Ph>001N;RhZ2PX75aLG5aLEADE002<S8b00IZJVZ:RXZBTY:BTY:PX:2WYjL2/;2`00Fk^k_6a/K6
a/Jk^k^f][H00[Ng]`Ff][H2]KFe00F/[:bVYZJVYZJRXZ:MWId00[2`/005_;bl`/;2b/[:b/[:`/;2
00>n_[h01;fm_Kbl_;bl_;bl_0:k^k/01KZj^[Bd]:n_[jn_[jb/[002Z:RX00FTY:BPX:2LW9bLW9bH
V9P00YFEU@06Ti>CT92@SHf=SHf=S8b<RXZ:0XR8R005QXJ6Lg=cLg=cI6ATFUYJ009?Cdl01GQhN9>C
Ti>CTj2PX;6a/@02YJFU00FQXJ6UYJFUYJFWYjNPX:000Y^KV`04V9RHUIFEUIFEV9RH19VIV@04ZJVY
];Bd];Bd_;bl0/C4a005bl_;dM7AfMWIfMWIh>3P00;Jf]X00mSHf=WIfMWIf@0GfMWI3?ooo`002_oo
o`gIfMT4f=SH3mWIf@04f=SHg=cLg=cLg]kN0^3Ph005h^;RX:2PLG5aLG5aE5AD008b<S801VYZJXZ:
RY:BTY:BTZ2PX:NWY`:`/;001K^k^lK6a/K6a[^k^kJf]P02]kNg1KJf]P:e]KD01Jb/[:JVYZJVYZ:R
XYfMW@02/;2`00Fl_;c2`/;:b/[:b/[2`/800kjn_P04_Kfm_;bl_;bl_;bl0[^k^`05^[Zj];Bd[jn_
[jn_[:b/00:XZ:P01JBTY:2PX9bLW9bLW9RHV002UIFE00JCTi>@T92=SHf=SHf<S8b:RXX2R8R800F6
QXIcLg=cLg=TI6AJFUX00Tm?C`05N7QhTi>CTi>CX:2P/K6a00:UYJD01J6QXJFUYJFUYJNWYj2PX002
Vi^K00BHV9REUIFEUIFHV9P4VIVI00BYZJVd];Bd];Bl_;`2a<C400G;bl_AdM7IfMWIfMWPh>000][J
fP03f=SHfMWIfMWI01OIfMT<oooo000:oooo3MWIf@CHf=P?fMWI00CHf=SLg=cLg=cNg]h2h>3P00GR
h^:PX:1aLG5aLG5DE5@00S8b<P06JVYZRXZ:TY:BTY:BX:2PYjNW0[2`/005^k^ka/K6a/K6^k^k][Jf
00:g]kL5][Jf0[Fe]@05[:b/YZJVYZJVXZ:RWIfM00:`/;001Kbl_<;2`/[:b/[:b/;2`P03_[jn00Bm
_Kfl_;bl_;bl_;`2^k^k00Fj^[Zd];B_[jn_[jn/[:`00ZRXZ005Y:BTX:2PW9bLW9bLV9RH00:EUID0
1Y>CTi2@T8f=SHf=SHb<S8Z:RP:8R8P01HJ6QW=cLg=cLfATI5YJFP02Cdm?00EhN7RCTi>CTi>PX:2a
/K400ZFUY@05XJ6QYJFUYJFUYjNWX:2P00:KVi/019RHV9FEUIFEUIRHV0BIVIT01:VYZKBd];Bd];bl
_0;4a<@01L_;bm7AdMWIfMWIfN3Ph002f][J00?Hf=SIfMWIfMT05mWIf@coool000[ooolMfMWI1=[J
fP;EeMD01M7AdLo?clo?clc<c<?3``02_;bl00Fg]kNa/K6a/K6f][Ji^KT00[Rh^005^KVi^k^k_;bl
_;bl_Kfm00:n_[h01Kno_l71`L;2`/;2`/?3``02`<300[jn_P:m_Kd01Jn_[jFUYJFUYInOWiNGU`02
ZZZZ00Fe]KFj^[[1`L71`L6o_kl00/30`003`l?3a/K6`l?300G3`l<01;Rh^;2`/;2`/:^[Z`:UYJD0
1JJVYZFUYJ>SXj>SXj2PX002Vi^K00JFUYJCTi>?Shn?Shn@T92?Shl2SHf=00><S8b=SHf=SHd00Xf=
S@:<S8`01I>CTiRHV9RHV9bLW9nOW`02WYjN00FMWIfOWinOWinOWinKVi/00YRHV005UiNGUIFEUIFE
SXj>RHV900:5QHD01H20P9FEUJBTY:BTY:^[Z`02];Bd00G2`/;?cloJf][Jf][Vi^H00]cLg003emOG
fMWIfMWI01OIfMT<oooo000:oooo7MWIf@CJf]X2eMGE00GAdM7?clo?clo<c<c3`l<00[bl_005]kNg
/K6a/K6a][Jf^KVi00:h^;P01KVi^K^k^kbl_;bl_;fm_@02_[jn00Fo_ko1`L72`/;2`/;3`l<00/30
`0:n_[h2_Kfm00F_[jnUYJFUYJFOWinGUiL00ZZZZP05]KFe^[Zj`L71`L71_kno00;0`<000l?3`lK6
a/?3``05`l?300Bh^;R`/;2`/;2[Zj/2YJFU00FVYZJUYJFSXj>SXj>PX:000Y^KV`06UYJFTi>CShn?
Shn?T92@Shn?0Xf=S@03S8b<SHf=SHf=00:=SHd2S8b<00FCTi>HV9RHV9RLW9bOWil00YjNWP05WIfM
WinOWinOWinOVi^K00:HV9P01INGUiFEUIFEUHj>SXV9R@02QHF500F0P82EUIFTY:BTY:B[Zj/00[Bd
]005`/;2clo?f][Jf][Ji^KV00;Lg=`00mOGemWIfMWIf@0GfMWI3?ooo`002_oooagIfMT4f][J0]GE
e@05dM7Aclo?clo?c<c<`l?300:l_;`01KNg]k6a/K6a/KJf][Vi^@02^;Rh00Fi^KVk^k^l_;bl_;bm
_Kd00[jn_P05_kno`L71`/;2`/;2`l?300;0`<02_[jn0[fm_@05[jn_YJFUYJFUWinOUiNG00:ZZZX0
1KFe]KZj^/71`L71`Kno_`02`<3000?3`l?6a/K3`l<01L?3``04^;Rh/;2`/;2`Zj^[0ZFUY@05YZJV
YJFUXj>SXj>SX:2P00:KVi/01YJFUY>CThn?Shn?Si2@T8n?S`:=SHd00hb<S8f=SHf=S@02SHf=0Xb<
S005Ti>CV9RHV9RHW9bLWinO00:NWYh01IfMWInOWinOWinOWi^KV`02V9RH00FGUiNEUIFEUIF>SXj9
RHT00XF5Q@05P820UIFEY:BTY:BTZj^[00:d];@01L;2`/o?cm[Jf][Jf^KViP02g=cL00?GemOIfMWI
fMT05mWIf@coool000[ooolMfMWI1=[JfP;EeMD01M7AdLo?clo?clc<c<?3``02_;bl00Fg]kNa/K6a
/K6f][Ji^KT00[Rh^005^KVi^k^k_;bl_;bl_Kfm00:n_[h01Kno_l71`L;2`/;2`/?3``02`<300[jn
_P:m_Kd01Jn_[jFUYJFUYInOWiNGU`02ZZZZ00Fe]KFj^[[1`L71`L6o_kl00/30`003`l?3a/K6`l?3
00G3`l<01;Rh^;2`/;2`/:^[Z`:UYJD01JJVYZFUYJ>SXj>SXj2PX002Vi^K00JFUYJCTi>?Shn?Shn@
T92?Shl2SHf=00><S8b=SHf=SHd00Xf=S@:<S8`01I>CTiRHV9RHV9bLW9nOW`02WYjN00FMWIfOWinO
WinOWinKVi/00YRHV005UiNGUIFEUIFESXj>RHV900:5QHD01H20P9FEUJBTY:BTY:^[Z`02];Bd00G2
`/;?cloJf][Jf][Vi^H00]cLg003emOGfMWIfMWI01OIfMT<oooo000:oooo7MWIf@CJf]X2eMGE00GA
dM7?clo?clo<c<c3`l<00[bl_005]kNg/K6a/K6a][Jf^KVi00:h^;P01KVi^K^k^kbl_;bl_;fm_@02
_[jn00Fo_ko1`L72`/;2`/;3`l<00/30`0:n_[h2_Kfm00F_[jnUYJFUYJFOWinGUiL00ZZZZP05]KFe
^[Zj`L71`L71_kno00;0`<000l?3`lK6a/?3``05`l?300Bh^;R`/;2`/;2[Zj/2YJFU00FVYZJUYJFS
Xj>SXj>PX:000Y^KV`06UYJFTi>CShn?Shn?T92@Shn?0Xf=S@03S8b<SHf=SHf=00:=SHd2S8b<00FC
Ti>HV9RHV9RLW9bOWil00YjNWP05WIfMWinOWinOWinOVi^K00:HV9P01INGUiFEUIFEUHj>SXV9R@02
QHF500F0P82EUIFTY:BTY:B[Zj/00[Bd]005`/;2clo?f][Jf][Ji^KV00;Lg=`00mOGemWIfMWIf@0G
fMWI3?ooo`002_oooacIfMT00m[Jf]_Kfm_Kf`02fm_K0]?Cd`05c<c<bLW9bLW9a<C4_;bl00:d];@0
1Jj^[ZRXZ:RXZ;6a/KNg]`02^;Rh00Fj^[Zl_;bo_kno_ko1`L400/?3``05a<C4a/K6alO7alO7bLW9
00;6a/H01LG5aLC4a<C4a<C4a;Zj^P02/k>c00>^[ZjYZJV/[:`00Zb/[004Zj^[ZZZZZZZZ]KFe0[fm
_@05`/;2alO7`l?3`l?3`L7100;2`/801L?3`k^k^kJf][Jf][>c/`02[jn_00FXZ:RQXJ6LW9bLW9bF
UYH00YBDU005T92@S8b<R8R8R8R8Rh^;00B<S8`2T92@00FCTi>DU9BFUYJFUYJLW9`00Z6QX@05Y:BT
Z:RXXJ6QXJ6QWIfM00:KVi/4VIVI00FHV9RGUiNGUiN;Rh^2PX800W]kN`03M7AdOGemPH6100:1PH42
PX:200FZZZ[7alOJf][Jf][_knl00]gMg@03e]KFfMWIfMWI01OIfMT<oooo000:oooo7=WIf@03f][J
fm_Kfm_K00;Kfm/2dm?C00G<c<c9bLW9bLW4a<Bl_;`00[Bd]005[Zj^Z:RXZ:RX/K6a]kNg00:h^;P0
1KZj^[bl_;no_kno_l71`@02`l?300G4a<C6a/K7alO7alO9bLT00/K6aP05aLG5a<C4a<C4a<C4^[Zj
00:c/k<00jj^[ZVYZJb/[002[:b/00B[Zj^ZZZZZZZZe]KD2_Kfm00G2`/;7alO3`l?3`l?1`L400/;2
`P05`l?3^k^k][Jf][Jf/k>c00:_[jl01JRXZ:6QXIbLW9bLW9JFUP02U9BD00F@T92<S8b8R8R8R8R;
Rh/018b<S0:@T9001I>CTiBDU9JFUYJFUYbLW002XJ6Q00FTY:BXZ:RQXJ6QXJ6MWId00Y^KV`BIVIT0
1IRHV9NGUiNGUh^;Rh:2PP02Ng]k00=dM7AmOGf1PH400X61P@:2PX801JZZZ/O7am[Jf][Jf^o_k`02
gMgM00?Fe]KIfMWIfMT05mWIf@coool000[ooolLfMWI00?Jf][Kfm_Kfm/00]_Kf`;Cdm<01Lc<c<W9
bLW9bLC4a;bl_002];Bd00F^[ZjXZ:RXZ:Ra/K6g]kL00[Rh^005^[Zj_;bl_kno_kno`L7100;3`l<0
1LC4a<K6a/O7alO7alW9b@02a/K600G5aLG4a<C4a<C4a<Bj^[X00[>c/`03[Zj^ZJVY[:b/00:/[:`0
1:^[ZjZZZZZZZ[Fe]@:m_Kd01L;2`/O7al?3`l?3`l71`@02`/;200G3`l>k^k^f][Jf][Jc/k<00Zn_
[`05Z:RXXJ6QW9bLW9bLUYJF00:DU9@01I2@T8b<S8R8R8R8R8^;R`04S8b<0Y2@T005Ti>CU9BDUYJF
UYJFW9bL00:QXJ401JBTY:RXZ:6QXJ6QXIfMW@02Vi^K19VIV@05V9RHUiNGUiNGRh^;PX:2009kNg/0
0gAdM7emOH61P@02PH610X:2PP05ZZZZalO7f][Jf][Jkno_00;MgMd00mKFe]WIfMWIf@0GfMWI3?oo
o`002_oooacIfMT00m[Jf]_Kfm_Kf`02fm_K0]?Cd`05c<c<bLW9bLW9a<C4_;bl00:d];@01Jj^[ZRX
Z:RXZ;6a/KNg]`02^;Rh00Fj^[Zl_;bo_kno_ko1`L400/?3``05a<C4a/K6alO7alO7bLW900;6a/H0
1LG5aLC4a<C4a<C4a;Zj^P02/k>c00>^[ZjYZJV/[:`00Zb/[004Zj^[ZZZZZZZZ]KFe0[fm_@05`/;2
alO7`l?3`l?3`L7100;2`/801L?3`k^k^kJf][Jf][>c/`02[jn_00FXZ:RQXJ6LW9bLW9bFUYH00YBD
U005T92@S8b<R8R8R8R8Rh^;00B<S8`2T92@00FCTi>DU9BFUYJFUYJLW9`00Z6QX@05Y:BTZ:RXXJ6Q
XJ6QWIfM00:KVi/4VIVI00FHV9RGUiNGUiN;Rh^2PX800W]kN`03M7AdOGemPH6100:1PH42PX:200FZ
ZZ[7alOJf][Jf][_knl00]gMg@03e]KFfMWIfMWI01OIfMT<oooo000:oooo7=WIf@03f][Jfm_Kfm_K
00;Kfm/2dm?C00G<c<c9bLW9bLW4a<Bl_;`00[Bd]005[Zj^Z:RXZ:RX/K6a]kNg00:h^;P01KZj^[bl
_;no_kno_l71`@02`l?300G4a<C6a/K7alO7alO9bLT00/K6aP05aLG5a<C4a<C4a<C4^[Zj00:c/k<0
0jj^[ZVYZJb/[002[:b/00B[Zj^ZZZZZZZZe]KD2_Kfm00G2`/;7alO3`l?3`l?1`L400/;2`P05`l?3
^k^k][Jf][Jf/k>c00:_[jl01JRXZ:6QXIbLW9bLW9JFUP02U9BD00F@T92<S8b8R8R8R8R;Rh/018b<
S0:@T9001I>CTiBDU9JFUYJFUYbLW002XJ6Q00FTY:BXZ:RQXJ6QXJ6MWId00Y^KV`BIVIT01IRHV9NG
UiNGUh^;Rh:2PP02Ng]k00=dM7AmOGf1PH400X61P@:2PX801JZZZ/O7am[Jf][Jf^o_k`02gMgM00?F
e]KIfMWIfMT05mWIf@coool000[ooolLfMWI00?Jf][Kfm_Kfm/00]_Kf`;Cdm<01Lc<c<W9bLW9bLC4
a;bl_002];Bd00F^[ZjXZ:RXZ:Ra/K6g]kL00[Rh^005^[Zj_;bl_kno_kno`L7100;3`l<01LC4a<K6
a/O7alO7alW9b@02a/K600G5aLG4a<C4a<C4a<Bj^[X00[>c/`03[Zj^ZJVY[:b/00:/[:`01:^[ZjZZ
ZZZZZ[Fe]@:m_Kd01L;2`/O7al?3`l?3`l71`@02`/;200G3`l>k^k^f][Jf][Jc/k<00Zn_[`05Z:RX
XJ6QW9bLW9bLUYJF00:DU9@01I2@T8b<S8R8R8R8R8^;R`04S8b<0Y2@T005Ti>CU9BDUYJFUYJFW9bL
00:QXJ401JBTY:RXZ:6QXJ6QXIfMW@02Vi^K19VIV@05V9RHUiNGUiNGRh^;PX:2009kNg/00gAdM7em
OH61P@02PH610X:2PP05ZZZZalO7f][Jf][Jkno_00;MgMd00mKFe]WIfMWIf@0GfMWI3?ooo`002_oo
ob7IfMT2aLG500Ff][J/[:b/[:bQXJ6SXj<00Z6QX@05W9bLV9RHV9RHZZZZ][Jf00:m_Kd01LG5aL71
`L30`<30`<;2`P02a<C400G5aLG6a/K8b<S8b<S9bLT00/K6aP;4a<@2`l?300Bn_[jj^[Zj^[Zh^;P3
]KFe00Fd];Bc/k>b/[:b/[:g]kL00[^k^`03_Kfm`<30_kno00Bo_kl01L30`;Fe]Jj^[Zj^[ZVYZ@02
Y:BT00FNWYjHV9RCTi>CTi>=SHd00i2@T003SXj>SHf=SHf=00:=SHd3S8b<0YVIV@05XZ:RZ:RX[Zj^
[Zj^ZZZZ00:XZ:P2ZJVY0ZBTY005X:2PWYjNWYjNW9bLVi^K00:JVYX019RHV9NGUiNGUiVIV@>KVi/0
1IbLW8b<S820P820P7QhN002L71`00FNWYjn_[k>c/k>c/kShn<00]OGe`05e=CDfMWIg=cLg=cLf][J
00;Hf=PCfMWI3?ooo`002_ooob7IfMT2aLG500Ff][J/[:b/[:bQXJ6SXj<00Z6QX@05W9bLV9RHV9RH
ZZZZ][Jf00:m_Kd01LG5aL71`L30`<30`<;2`P02a<C400G5aLG6a/K8b<S8b<S9bLT00/K6aP;4a<@2
`l?300Bn_[jj^[Zj^[Zh^;P3]KFe00Fd];Bc/k>b/[:b/[:g]kL00[^k^`03_Kfm`<30_kno00Bo_kl0
1L30`;Fe]Jj^[Zj^[ZVYZ@02Y:BT00FNWYjHV9RCTi>CTi>=SHd00i2@T003SXj>SHf=SHf=00:=SHd3
S8b<0YVIV@05XZ:RZ:RX[Zj^[Zj^ZZZZ00:XZ:P2ZJVY0ZBTY005X:2PWYjNWYjNW9bLVi^K00:JVYX0
19RHV9NGUiNGUiVIV@>KVi/01IbLW8b<S820P820P7QhN002L71`00FNWYjn_[k>c/k>c/kShn<00]OG
e`05e=CDfMWIg=cLg=cLf][J00;Hf=PCfMWI3?ooo`002_ooob7IfMT2aLG500Ff][J/[:b/[:bQXJ6S
Xj<00Z6QX@05W9bLV9RHV9RHZZZZ][Jf00:m_Kd01LG5aL71`L30`<30`<;2`P02a<C400G5aLG6a/K8
b<S8b<S9bLT00/K6aP;4a<@2`l?300Bn_[jj^[Zj^[Zh^;P3]KFe00Fd];Bc/k>b/[:b/[:g]kL00[^k
^`03_Kfm`<30_kno00Bo_kl01L30`;Fe]Jj^[Zj^[ZVYZ@02Y:BT00FNWYjHV9RCTi>CTi>=SHd00i2@
T003SXj>SHf=SHf=00:=SHd3S8b<0YVIV@05XZ:RZ:RX[Zj^[Zj^ZZZZ00:XZ:P2ZJVY0ZBTY005X:2P
WYjNWYjNW9bLVi^K00:JVYX019RHV9NGUiNGUiVIV@>KVi/01IbLW8b<S820P820P7QhN002L71`00FN
WYjn_[k>c/k>c/kShn<00]OGe`05e=CDfMWIg=cLg=cLf][J00;Hf=PCfMWI3?ooo`002_ooob7IfMT2
aLG500Ff][J/[:b/[:bQXJ6SXj<00Z6QX@05W9bLV9RHV9RHZZZZ][Jf00:m_Kd01LG5aL71`L30`<30
`<;2`P02a<C400G5aLG6a/K8b<S8b<S9bLT00/K6aP;4a<@2`l?300Bn_[jj^[Zj^[Zh^;P3]KFe00Fd
];Bc/k>b/[:b/[:g]kL00[^k^`03_Kfm`<30_kno00Bo_kl01L30`;Fe]Jj^[Zj^[ZVYZ@02Y:BT00FN
WYjHV9RCTi>CTi>=SHd00i2@T003SXj>SHf=SHf=00:=SHd3S8b<0YVIV@05XZ:RZ:RX[Zj^[Zj^ZZZZ
00:XZ:P2ZJVY0ZBTY005X:2PWYjNWYjNW9bLVi^K00:JVYX019RHV9NGUiNGUiVIV@>KVi/01IbLW8b<
S820P820P7QhN002L71`00FNWYjn_[k>c/k>c/kShn<00]OGe`05e=CDfMWIg=cLg=cLf][J00;Hf=PC
fMWI3?ooo`002_ooob7IfMT2aLG500Ff][J/[:b/[:bQXJ6SXj<00Z6QX@05W9bLV9RHV9RHZZZZ][Jf
00:m_Kd01LG5aL71`L30`<30`<;2`P02a<C400G5aLG6a/K8b<S8b<S9bLT00/K6aP;4a<@2`l?300Bn
_[jj^[Zj^[Zh^;P3]KFe00Fd];Bc/k>b/[:b/[:g]kL00[^k^`03_Kfm`<30_kno00Bo_kl01L30`;Fe
]Jj^[Zj^[ZVYZ@02Y:BT00FNWYjHV9RCTi>CTi>=SHd00i2@T003SXj>SHf=SHf=00:=SHd3S8b<0YVI
V@05XZ:RZ:RX[Zj^[Zj^ZZZZ00:XZ:P2ZJVY0ZBTY005X:2PWYjNWYjNW9bLVi^K00:JVYX019RHV9NG
UiNGUiVIV@>KVi/01IbLW8b<S820P820P7QhN002L71`00FNWYjn_[k>c/k>c/kShn<00]OGe`05e=CD
fMWIg=cLg=cLf][J00;Hf=PCfMWI3?ooo`002_oooaKIfMT2f][J00GKfm_Lg=cMgMgMgMgCdm<00/g=
c@05bLW9a<C4];Bd];BdYjNW00:MWId01I:BTYbLW:2PX:2PX9nOW`02X:2P00J^[Zji^KW0`<30`<38
b<S4a<@2`/;200C4a<C6a/K6a/K3`l<3`/;200G1`L6n_[jn_[jl_;bk^k/00[Vi^@05]kNg]KFe]KFe
/k>c/K6a00:e]KD01KNg]kRh^;Vi^KVi^Kfm_@02`<3000C2`/;4a<C2`/;2`/84`L7100Bc/k>ZZZZZ
ZZZSXj<2W9bL00FGUiNBTY:<S8b<S8b6QXH00Xb<S006Shn?SXj>Shn?Shn?UiNGW9bL0Z2PX005YJFU
YZJVYZJVZ:RXZj^[00:^[Zh01JVYZJNWYjNWYjJVYZFUY@02X:2P00>MWIfJVYZJVYX00YRHV0:GUiL0
19JFUYFEUIFEUIJFUP>GUiL2V9RH0YVIV@>JVYX01KJf]/_;bmSHf=SHf>OWi`02fm_K00CFe]KIfMWJ
f][Jf]XFfMWI3?ooo`002_oooaKIfMT2f][J00GKfm_Lg=cMgMgMgMgCdm<00/g=c@05bLW9a<C4];Bd
];BdYjNW00:MWId01I:BTYbLW:2PX:2PX9nOW`02X:2P00J^[Zji^KW0`<30`<38b<S4a<@2`/;200C4
a<C6a/K6a/K3`l<3`/;200G1`L6n_[jn_[jl_;bk^k/00[Vi^@05]kNg]KFe]KFe/k>c/K6a00:e]KD0
1KNg]kRh^;Vi^KVi^Kfm_@02`<3000C2`/;4a<C2`/;2`/84`L7100Bc/k>ZZZZZZZZSXj<2W9bL00FG
UiNBTY:<S8b<S8b6QXH00Xb<S006Shn?SXj>Shn?Shn?UiNGW9bL0Z2PX005YJFUYZJVYZJVZ:RXZj^[
00:^[Zh01JVYZJNWYjNWYjJVYZFUY@02X:2P00>MWIfJVYZJVYX00YRHV0:GUiL019JFUYFEUIFEUIJF
UP>GUiL2V9RH0YVIV@>JVYX01KJf]/_;bmSHf=SHf>OWi`02fm_K00CFe]KIfMWJf][Jf]XFfMWI3?oo
o`002_oooaKIfMT2f][J00GKfm_Lg=cMgMgMgMgCdm<00/g=c@05bLW9a<C4];Bd];BdYjNW00:MWId0
1I:BTYbLW:2PX:2PX9nOW`02X:2P00J^[Zji^KW0`<30`<38b<S4a<@2`/;200C4a<C6a/K6a/K3`l<3
`/;200G1`L6n_[jn_[jl_;bk^k/00[Vi^@05]kNg]KFe]KFe/k>c/K6a00:e]KD01KNg]kRh^;Vi^KVi
^Kfm_@02`<3000C2`/;4a<C2`/;2`/84`L7100Bc/k>ZZZZZZZZSXj<2W9bL00FGUiNBTY:<S8b<S8b6
QXH00Xb<S006Shn?SXj>Shn?Shn?UiNGW9bL0Z2PX005YJFUYZJVYZJVZ:RXZj^[00:^[Zh01JVYZJNW
YjNWYjJVYZFUY@02X:2P00>MWIfJVYZJVYX00YRHV0:GUiL019JFUYFEUIFEUIJFUP>GUiL2V9RH0YVI
V@>JVYX01KJf]/_;bmSHf=SHf>OWi`02fm_K00CFe]KIfMWJf][Jf]XFfMWI3?ooo`002_oooaKIfMT2
f][J00GKfm_Lg=cMgMgMgMgCdm<00/g=c@05bLW9a<C4];Bd];BdYjNW00:MWId01I:BTYbLW:2PX:2P
X9nOW`02X:2P00J^[Zji^KW0`<30`<38b<S4a<@2`/;200C4a<C6a/K6a/K3`l<3`/;200G1`L6n_[jn
_[jl_;bk^k/00[Vi^@05]kNg]KFe]KFe/k>c/K6a00:e]KD01KNg]kRh^;Vi^KVi^Kfm_@02`<3000C2
`/;4a<C2`/;2`/84`L7100Bc/k>ZZZZZZZZSXj<2W9bL00FGUiNBTY:<S8b<S8b6QXH00Xb<S006Shn?
SXj>Shn?Shn?UiNGW9bL0Z2PX005YJFUYZJVYZJVZ:RXZj^[00:^[Zh01JVYZJNWYjNWYjJVYZFUY@02
X:2P00>MWIfJVYZJVYX00YRHV0:GUiL019JFUYFEUIFEUIJFUP>GUiL2V9RH0YVIV@>JVYX01KJf]/_;
bmSHf=SHf>OWi`02fm_K00CFe]KIfMWJf][Jf]XFfMWI3?ooo`002_oooaKIfMT2f][J00GKfm_Lg=cM
gMgMgMgCdm<00/g=c@05bLW9a<C4];Bd];BdYjNW00:MWId01I:BTYbLW:2PX:2PX9nOW`02X:2P00J^
[Zji^KW0`<30`<38b<S4a<@2`/;200C4a<C6a/K6a/K3`l<3`/;200G1`L6n_[jn_[jl_;bk^k/00[Vi
^@05]kNg]KFe]KFe/k>c/K6a00:e]KD01KNg]kRh^;Vi^KVi^Kfm_@02`<3000C2`/;4a<C2`/;2`/84
`L7100Bc/k>ZZZZZZZZSXj<2W9bL00FGUiNBTY:<S8b<S8b6QXH00Xb<S006Shn?SXj>Shn?Shn?UiNG
W9bL0Z2PX005YJFUYZJVYZJVZ:RXZj^[00:^[Zh01JVYZJNWYjNWYjJVYZFUY@02X:2P00>MWIfJVYZJ
VYX00YRHV0:GUiL019JFUYFEUIFEUIJFUP>GUiL2V9RH0YVIV@>JVYX01KJf]/_;bmSHf=SHf>OWi`02
fm_K00CFe]KIfMWJf][Jf]XFfMWI3?ooo`002_oooaKIfMT2f][J00GKfm_Lg=cMgMgMgMgCdm<00/g=
c@05bLW9a<C4];Bd];BdYjNW00:MWId01I:BTYbLW:2PX:2PX9nOW`02X:2P00J^[Zji^KW0`<30`<38
b<S4a<@2`/;200C4a<C6a/K6a/K3`l<3`/;200G1`L6n_[jn_[jl_;bk^k/00[Vi^@05]kNg]KFe]KFe
/k>c/K6a00:e]KD01KNg]kRh^;Vi^KVi^Kfm_@02`<3000C2`/;4a<C2`/;2`/84`L7100Bc/k>ZZZZZ
ZZZSXj<2W9bL00FGUiNBTY:<S8b<S8b6QXH00Xb<S006Shn?SXj>Shn?Shn?UiNGW9bL0Z2PX005YJFU
YZJVYZJVZ:RXZj^[00:^[Zh01JVYZJNWYjNWYjJVYZFUY@02X:2P00>MWIfJVYZJVYX00YRHV0:GUiL0
19JFUYFEUIFEUIJFUP>GUiL2V9RH0YVIV@>JVYX01KJf]/_;bmSHf=SHf>OWi`02fm_K00CFe]KIfMWJ
f][Jf]XFfMWI3?ooo`002_oooaKIfMT2fm_K00GMgMgNg]kOgmoOgmo2`/800Zb/[005WinOT92@OGem
OGemK6a/009KFe/01DY:BWMgMi>CTi>CTinOW`02[jn_00Ja/K6g]kO1`L71`L7:b/[1`L42_Kfm00>n
_[jm_Kfm_Kd01Kjn_P:k^k/01KVi^KNg]kFe]KFe]K6a/@02[Zj^00B[Zj^YZJV][Jf][Jd2/;2`0[6a
/@05]kNg_;bl_;bl_kno`l?300;1`L43`<3000G1`L6a/K6UYJFUYJFNWYh00YJFUP05U9BDT92@RXZ:
RXZ:QHF500:=SHd01Y:BTY>CTiFEUIFEUIVIVIfMW@:PX:001J>SXj:RXZ:RXZ:RXZ>SX`02Y:BT00FR
XZ:QXJ6QXJ6PX:2OWil00YjNWP03W9bLVi^KVi^K00BIVIT3V9RH00BATI6<S8b9RHV9RHT2QHF50XB4
Q005PX:2PH61PH61XZ:R^[Zj00;9bLT01M[Jf]?Cdm?Cdm?CdmWIf@02g]kN00?Jf][Hf=SHf=P04mWI
f@coool000[ooolFfMWI0]_Kf`05gMgMg]kNgmoOgmoO`/;200:/[:`01InOWi2@T7emOGemOFa/K002
Fe]K00E:BTYgMgNCTi>CTi>OWil00Zn_[`06/K6a]kNg`L71`L71b/[:`L710[fm_@03_[jn_Kfm_Kfm
00Fn_[h2^k^k00Fi^KVg]kNe]KFe]KFa/K400Zj^[P04Zj^[ZJVY[Jf][Jf]0[2`/0:a/K401KNg]kbl
_;bl_;no_l?3``02`L710l30`005`L71/K6aYJFUYJFUWYjN00:FUYH01IBDU92@T8Z:RXZ:RXF5Q@02
SHf=00JBTY:CTi>EUIFEUIFIVIVMWId2X:2P00FSXj>RXZ:RXZ:RXZ:SXj<00ZBTY005XZ:RXJ6QXJ6Q
X:2PWinO00:NWYh00ibLW9^KVi^KV`04VIVI0iRHV004TI6AS8b<RHV9RHV90XF5Q@:4Q8@01H:2PX61
PH61PJ:RX[Zj^P02bLW900GJf][Cdm?Cdm?Cdm?IfMT00]kNgP03f][Jf=SHf=SH01?IfMT<oooo000:
oooo5]WIf@;Kfm/01MgMgMkNg]oOgmoOgl;2`P02[:b/00FOWin@T91mOGemOGe/K6`00U]KF`05BTY:
MgMgTi>CTi>CWinO00:_[jl01[6a/KNg]l71`L71`L[:b/71`@:m_Kd00kjn_[fm_Kfm_@05_[jn0[^k
^`05^KVi]kNg]KFe]KFe/K6a00:^[Zh01:^[ZjVYZJf][Jf][@:`/;02/K6a00Fg]kNl_;bl_;bo_ko3
`l<00/71`@?0`<001L71`K6a/JFUYJFUYIjNWP02UYJF00FDU9B@T92:RXZ:RXZ5QHD00Xf=S@06TY:B
Ti>CUIFEUIFEVIVIWIfM0Z2PX005Xj>SXZ:RXZ:RXZ:RXj>S00:TY:@01J:RXZ6QXJ6QXJ2PX9nOW`02
WYjN00>LW9bKVi^KVi/019VIV@>HV9P0196ATHb<S8V9RHV9R@:5QHD2Q8B400F2PX:1PH61PH6RXZ:j
^[X00/W9b@05f][Jdm?Cdm?Cdm?CfMWI00;Ng]h00m[Jf]SHf=SHf00CfMWI3?ooo`002_oooaKIfMT2
fm_K00GMgMgNg]kOgmoOgmo2`/800Zb/[005WinOT92@OGemOGemK6a/009KFe/01DY:BWMgMi>CTi>C
TinOW`02[jn_00Ja/K6g]kO1`L71`L7:b/[1`L42_Kfm00>n_[jm_Kfm_Kd01Kjn_P:k^k/01KVi^KNg
]kFe]KFe]K6a/@02[Zj^00B[Zj^YZJV][Jf][Jd2/;2`0[6a/@05]kNg_;bl_;bl_kno`l?300;1`L43
`<3000G1`L6a/K6UYJFUYJFNWYh00YJFUP05U9BDT92@RXZ:RXZ:QHF500:=SHd01Y:BTY>CTiFEUIFE
UIVIVIfMW@:PX:001J>SXj:RXZ:RXZ:RXZ>SX`02Y:BT00FRXZ:QXJ6QXJ6PX:2OWil00YjNWP03W9bL
Vi^KVi^K00BIVIT3V9RH00BATI6<S8b9RHV9RHT2QHF50XB4Q005PX:2PH61PH61XZ:R^[Zj00;9bLT0
1M[Jf]?Cdm?Cdm?CdmWIf@02g]kN00?Jf][Hf=SHf=P04mWIf@coool000[ooolFfMWI0]_Kf`05gMgM
g]kNgmoOgmoO`/;200:/[:`01InOWi2@T7emOGemOFa/K002Fe]K00E:BTYgMgNCTi>CTi>OWil00Zn_
[`06/K6a]kNg`L71`L71b/[:`L710[fm_@03_[jn_Kfm_Kfm00Fn_[h2^k^k00Fi^KVg]kNe]KFe]KFa
/K400Zj^[P04Zj^[ZJVY[Jf][Jf]0[2`/0:a/K401KNg]kbl_;bl_;no_l?3``02`L710l30`005`L71
/K6aYJFUYJFUWYjN00:FUYH01IBDU92@T8Z:RXZ:RXF5Q@02SHf=00JBTY:CTi>EUIFEUIFIVIVMWId2
X:2P00FSXj>RXZ:RXZ:RXZ:SXj<00ZBTY005XZ:RXJ6QXJ6QX:2PWinO00:NWYh00ibLW9^KVi^KV`04
VIVI0iRHV004TI6AS8b<RHV9RHV90XF5Q@:4Q8@01H:2PX61PH61PJ:RX[Zj^P02bLW900GJf][Cdm?C
dm?Cdm?IfMT00]kNgP03f][Jf=SHf=SH01?IfMT<oooo000:oooo5MWIf@OHf=P01KJf]YjNWYjNWXj>
SWalO002FEUI00Dk>c/R8R8R8R871`MCDe<00XB4Q005VIVI][Jf][Jf[jn_/[:b00:n_[h01LO7akjn
_[Zj^[Zj^[^k^`02^[Zj00FQXJ6>SXj1PH61PH5cLg<00gMgM`04LG5aKFe]KFe]K6a/0VYZJP06IfMW
I6ATLW9bLW9bO7alPH610XR8R005Vi^KZj^[Zj^[^;RhaLG500:o_kl01Kjn_/;2`/;2`/G5aK6a/@02
Xj>S00FKVi^ATI6ATI6=SHf7QhL00X20P005NWYjR8R8R8R8T92@Ti>C00:HV9P01IJFUYNGUiRHV9RH
V9ZJVP03VIVI0iZJVP05W9bLWYjNWYjNWinOX:2P00:MWId01I^KViZJVYZJVYVIVINGU`02UYJF00FE
UIFCTi>CTi>>SXj:RXX00XN7Q`05Ph>3MWIfK6a/K6a/I6AT009KFe/01Hj>S[2`/<?3`l?3`m[JfP03
dM7A00CIfMWOgmoOgmoJf]X2f=SH4mWIf@coool000[ooolEfMWI1mSHf005][JfWYjNWYjNSXj>O7al
009IFET01C/k>b8R8R8R8PL71e=CD`02Q8B400FIVIVf][Jf][J_[jnb/[800[jn_P05alO7_[jn^[Zj
^[Zj^k^k00:j^[X01J6QXHj>SX61PH61PG=cL`03MgMg00AaLG5]KFe]KFe/K6`2JVYZ00IWIfMTI6Ab
LW9bLW9lO7b1PH42R8R800FKVi^[Zj^[Zj^h^;S5aLD00[no_`05_[jn`/;2`/;2aLG5/K6a00:SXj<0
1I^KVi6ATI6ATHf=SHN7Q`02P82000EjNWZ8R8R8R8R@T92CTi<00YRHV005UYJFUiNGV9RHV9RHVYZJ
00>IVIT3VYZJ00FLW9bNWYjNWYjOWinPX:000YfMW@05Vi^KVYZJVYZJVIVIUiNG00:FUYH01IFEUI>C
Ti>CThj>SXZ:RP02QhN700F3Ph=fMWI/K6a/K6aTI6@00U]KF`05SXj>/;2``l?3`l?3f][J00?AdM40
1=WIfMoOgmoOgm[JfP;Hf=PCfMWI3?ooo`002_oooaGIfMT7f=SH00Ff][JNWYjNWYj>SXilO7`00UUI
F@05>c/k8R8R8R8R1`L7De=C00:4Q8@01IVIVKJf][Jf]Zn_[k:b/P02_[jn00G7alNn_[jj^[Zj^[Zk
^k/00[Zj^P05XJ6QSXj>PH61PH61Lg=c00=gMgL0175aLFe]KFe]KFa/K09ZJVX01VMWIfATI79bLW9b
LWalO861P@:8R8P01I^KVj^[Zj^[ZkRh^<G5a@02_kno00Fn_[k2`/;2`/;5aLFa/K400Z>SX`05Vi^K
TI6ATI6ASHf=QhN700:0P8001GYjNXR8R8R8R92@T9>CT`02V9RH00FFUYJGUiNHV9RHV9RJVYX00iVI
V@>JVYX01IbLW9jNWYjNWYnOWj2PX002WIfM00FKVi^JVYZJVYZIVIVGUiL00YJFUP05UIFETi>CTi>C
SXj>RXZ:00:7QhL01H>3PgIfMVa/K6a/K6ATI002Fe]K00F>SXj`/;33`l?3`l?Jf]X00m7Ad@04fMWI
gmoOgmoOf][J0]SHf1?IfMT<oooo000:oooo5MWIf@OHf=P01KJf]YjNWYjNWXj>SWalO002FEUI00Dk
>c/R8R8R8R871`MCDe<00XB4Q005VIVI][Jf][Jf[jn_/[:b00:n_[h01LO7akjn_[Zj^[Zj^[^k^`02
^[Zj00FQXJ6>SXj1PH61PH5cLg<00gMgM`04LG5aKFe]KFe]K6a/0VYZJP06IfMWI6ATLW9bLW9bO7al
PH610XR8R005Vi^KZj^[Zj^[^;RhaLG500:o_kl01Kjn_/;2`/;2`/G5aK6a/@02Xj>S00FKVi^ATI6A
TI6=SHf7QhL00X20P005NWYjR8R8R8R8T92@Ti>C00:HV9P01IJFUYNGUiRHV9RHV9ZJVP03VIVI0iZJ
VP05W9bLWYjNWYjNWinOX:2P00:MWId01I^KViZJVYZJVYVIVINGU`02UYJF00FEUIFCTi>CTi>>SXj:
RXX00XN7Q`05Ph>3MWIfK6a/K6a/I6AT009KFe/01Hj>S[2`/<?3`l?3`m[JfP03dM7A00CIfMWOgmoO
gmoJf]X2f=SH4mWIf@coool000[ooolEfMWI1mSHf005][JfWYjNWYjNSXj>O7al009IFET01C/k>b8R
8R8R8PL71e=CD`02Q8B400FIVIVf][Jf][J_[jnb/[800[jn_P05alO7_[jn^[Zj^[Zj^k^k00:j^[X0
1J6QXHj>SX61PH61PG=cL`03MgMg00AaLG5]KFe]KFe/K6`2JVYZ00IWIfMTI6AbLW9bLW9lO7b1PH42
R8R800FKVi^[Zj^[Zj^h^;S5aLD00[no_`05_[jn`/;2`/;2aLG5/K6a00:SXj<01I^KVi6ATI6ATHf=
SHN7Q`02P82000EjNWZ8R8R8R8R@T92CTi<00YRHV005UYJFUiNGV9RHV9RHVYZJ00>IVIT3VYZJ00FL
W9bNWYjNWYjOWinPX:000YfMW@05Vi^KVYZJVYZJVIVIUiNG00:FUYH01IFEUI>CTi>CThj>SXZ:RP02
QhN700F3Ph=fMWI/K6a/K6aTI6@00U]KF`05SXj>/;2``l?3`l?3f][J00?AdM401=WIfMoOgmoOgm[J
fP;Hf=PCfMWI3?ooo`002_oooaGIfMT7f=SH00Ff][JNWYjNWYj>SXilO7`00UUIF@05>c/k8R8R8R8R
1`L7De=C00:4Q8@01IVIVKJf][Jf]Zn_[k:b/P02_[jn00G7alNn_[jj^[Zj^[Zk^k/00[Zj^P05XJ6Q
SXj>PH61PH61Lg=c00=gMgL0175aLFe]KFe]KFa/K09ZJVX01VMWIfATI79bLW9bLWalO861P@:8R8P0
1I^KVj^[Zj^[ZkRh^<G5a@02_kno00Fn_[k2`/;2`/;5aLFa/K400Z>SX`05Vi^KTI6ATI6ASHf=QhN7
00:0P8001GYjNXR8R8R8R92@T9>CT`02V9RH00FFUYJGUiNHV9RHV9RJVYX00iVIV@>JVYX01IbLW9jN
WYjNWYnOWj2PX002WIfM00FKVi^JVYZJVYZIVIVGUiL00YJFUP05UIFETi>CTi>CSXj>RXZ:00:7QhL0
1H>3PgIfMVa/K6a/K6ATI002Fe]K00F>SXj`/;33`l?3`l?Jf]X00m7Ad@04fMWIgmoOgmoOf][J0]SH
f1?IfMT<oooo000:oooo00?IfMWHf=SHf=P01=SHf0[IfMT01M_KfmgMgMkNg]kNg]oOg`02YZJV00Em
OGeSHf=5ADE5ADEcLg<00Xb<S005TI6AW9bLH61PH61P=cLg008P82001@D51E=CDhF5QHF5QI^KV`02
^;Rh0Zb/[0:f][H01Kjn_[^k^k^k^k^k^kjn_P02`<3000Fl_;bi^KVh^;Rh^;Rg]kL00ZFUY@05UiNG
SXj>Q8B4Q8B4NWYj009`L7001VIVIUaLG7AdM7AdM8B4Q8V9R@:BTY801J2PX:f][Jf][KVi^LC4a003
`L710/K6aP05bLW9/k>cY:BTY:BTW9bL00:BTY801HR8R7moOgEeMGEeMF][J`02NWYj00J2PX:4Q8B7
QhN7QhM/K6aJFUX2Cdm?00E3@d=FEUIFEUIQHF5SHf<00VQXJ005JVYZKFe]KFe]L71`Lg=c009mOGd0
0hF5QH^;Rh^;R`02TY:B0Y>CT`05UYJFVIVIVIVIPh>3Lg=c009ZJVX0161PH6MWIfYZJVYZJP=XJ6P0
1I6ATJn_[l;2`/;2`]SHf003dM7A00CJf][Ph>3Ph>3Jf]X2f=SH4mWIf@coool000[oool00mWIfMSH
f=SHf004f=SH2]WIf@05fm_KgMgMg]kNg]kNgmoO00:VYZH01GemOF=SHdE5ADE5AG=cL`02S8b<00FA
TI6LW9aPH61PH60g=cL00R0P80051@D5De=CQHF5QHF5Vi^K00:h^;P2[:b/0[Jf]P05_[jn^k^k^k^k
^k^k_[jn00;0`<001Kbl_;Vi^KRh^;Rh^;Ng]`02YJFU00FGUiN>SXj4Q8B4Q8AjNWX00W1`L006IVIV
G5aLM7AdM7AdQ8B4RHV90Y:BTP05X:2P[Jf][Jf]^KVia<C400?1`L42a/K600G9bLVc/k>TY:BTY:BL
W9`00Y:BTP05R8R8OgmoMGEeMGEeJf][009jNWX01X:2PXB4Q8N7QhN7Qfa/K5YJFP9?Cdl01D=3@eIF
EUIFEV5QHF=SH`02J6QX00EZJVY]KFe]KFe`L71cLg<00WemO@03QHF5Rh^;Rh^;00:BTY82Ti>C00FF
UYJIVIVIVIV3Ph=cLg<00VYZJP04H61PIfMWJVYZJVYZ0fQXJ005TI6A[jn_`/;2`/;2f=SH00?AdM40
1=[Jf^3Ph>3Ph=[JfP;Hf=PCfMWI3?ooo`002_ooo`03fMWIf=SHf=SH00CHf=P:fMWI00GKfm_MgMgN
g]kNg]kOgml00ZJVYP05OGemHf=SADE5ADE5Lg=c00:<S8`01I6ATIbLW61PH61PH3Lg=`02820P00D5
1@ECDe>5QHF5QHFKVi/00[Rh^0:/[:`2][Jf00Fn_[jk^k^k^k^k^k^n_[h00/30`005_;bl^KVi^;Rh
^;Rh]kNg00:UYJD01INGUhj>SXB4Q8B4Q7YjNP02L71`00IVIVILG5adM7AdM7B4Q8B9RHT2TY:B00FP
X:2][Jf][Jfi^KW4a<@00l71`@;6a/H01LW9bK>c/jBTY:BTY9bLW002TY:B00F8R8QoOgmeMGEeMGE[
Jf/00WYjNP06PX:2Q8B4QhN7QhN7K6a/FUYJ0Tm?C`05@d=3EUIFEUIFHF5QHf=S009XJ6P01FYZJVe]
KFe]KG1`L7=cL`02OGem00>5QHF;Rh^;Rh/00Y:BTP:CTi<01IJFUYVIVIVIVH>3Pg=cL`02JVYZ00AP
H61WIfMZJVYZJVX3J6QX00FATI6_[jo2`/;2`/;Hf=P00m7Ad@04f][Jh>3Ph>3Pf][J0]SHf1?IfMT<
oooo000:oooo00?IfMWHf=SHf=P01=SHf0[IfMT01M_KfmgMgMkNg]kNg]oOg`02YZJV00EmOGeSHf=5
ADE5ADEcLg<00Xb<S005TI6AW9bLH61PH61P=cLg008P82001@D51E=CDhF5QHF5QI^KV`02^;Rh0Zb/
[0:f][H01Kjn_[^k^k^k^k^k^kjn_P02`<3000Fl_;bi^KVh^;Rh^;Rg]kL00ZFUY@05UiNGSXj>Q8B4
Q8B4NWYj009`L7001VIVIUaLG7AdM7AdM8B4Q8V9R@:BTY801J2PX:f][Jf][KVi^LC4a003`L710/K6
aP05bLW9/k>cY:BTY:BTW9bL00:BTY801HR8R7moOgEeMGEeMF][J`02NWYj00J2PX:4Q8B7QhN7QhM/
K6aJFUX2Cdm?00E3@d=FEUIFEUIQHF5SHf<00VQXJ005JVYZKFe]KFe]L71`Lg=c009mOGd00hF5QH^;
Rh^;R`02TY:B0Y>CT`05UYJFVIVIVIVIPh>3Lg=c009ZJVX0161PH6MWIfYZJVYZJP=XJ6P01I6ATJn_
[l;2`/;2`]SHf003dM7A00CJf][Ph>3Ph>3Jf]X2f=SH4mWIf@coool000[oool00mWIfMSHf=SHf004
f=SH2]WIf@05fm_KgMgMg]kNg]kNgmoO00:VYZH01GemOF=SHdE5ADE5AG=cL`02S8b<00FATI6LW9aP
H61PH60g=cL00R0P80051@D5De=CQHF5QHF5Vi^K00:h^;P2[:b/0[Jf]P05_[jn^k^k^k^k^k^k_[jn
00;0`<001Kbl_;Vi^KRh^;Rh^;Ng]`02YJFU00FGUiN>SXj4Q8B4Q8AjNWX00W1`L006IVIVG5aLM7Ad
M7AdQ8B4RHV90Y:BTP05X:2P[Jf][Jf]^KVia<C400?1`L42a/K600G9bLVc/k>TY:BTY:BLW9`00Y:B
TP05R8R8OgmoMGEeMGEeJf][009jNWX01X:2PXB4Q8N7QhN7Qfa/K5YJFP9?Cdl01D=3@eIFEUIFEV5Q
HF=SH`02J6QX00EZJVY]KFe]KFe`L71cLg<00WemO@03QHF5Rh^;Rh^;00:BTY82Ti>C00FFUYJIVIVI
VIV3Ph=cLg<00VYZJP04H61PIfMWJVYZJVYZ0fQXJ005TI6A[jn_`/;2`/;2f=SH00?AdM401=[Jf^3P
h>3Ph=[JfP;Hf=PCfMWI3?ooo`002_ooo`03fMWIf=SHf=SH00CHf=P:fMWI00GKfm_MgMgNg]kNg]kO
gml00ZJVYP05OGemHf=SADE5ADE5Lg=c00:<S8`01I6ATIbLW61PH61PH3Lg=`02820P00D51@ECDe>5
QHF5QHFKVi/00[Rh^0:/[:`2][Jf00Fn_[jk^k^k^k^k^k^n_[h00/30`005_;bl^KVi^;Rh^;Rh]kNg
00:UYJD01INGUhj>SXB4Q8B4Q7YjNP02L71`00IVIVILG5adM7AdM7B4Q8B9RHT2TY:B00FPX:2][Jf]
[Jfi^KW4a<@00l71`@;6a/H01LW9bK>c/jBTY:BTY9bLW002TY:B00F8R8QoOgmeMGEeMGE[Jf/00WYj
NP06PX:2Q8B4QhN7QhN7K6a/FUYJ0Tm?C`05@d=3EUIFEUIFHF5QHf=S009XJ6P01FYZJVe]KFe]KG1`
L7=cL`02OGem00>5QHF;Rh^;Rh/00Y:BTP:CTi<01IJFUYVIVIVIVH>3Pg=cL`02JVYZ00APH61WIfMZ
JVYZJVX3J6QX00FATI6_[jo2`/;2`/;Hf=P00m7Ad@04f][Jh>3Ph>3Pf][J0]SHf1?IfMT<oooo000:
oooo2mWIf@;Kfm/01]cLg=gMgMgMgMgMgLg=cL;2`P:k^k/01K>c/gMgMgMgMdY:BRTY:@021PH600<U
9BDb<S8b<S800Rh^;P8U9BD01AlO7aXJ6QXJ6QHF5U=CD`02Ogmo00FIVIVh^;Rh^;R_[jna/K400[fm
_@05alO7];BdZ:RXZ:RXY:BT00:NWYh01J:RXZ>SXj:RXZ:RXZ6QX@02V9RH00FATI6=SHf7QhN7QhN3
Ph<00WmoO`06NWYjMWIfPX:2PX:2RXZ:SHf=0Y6AT@05XZ:R/;2`/;2`^[Zja/K600:m_Kd01KZj^[bl
_;bl_;fm_K2`/002YZJV00FPX:2IVIVIVIVCTi><S8`00XF5Q@05OgmoRXZ:RXZ:T92@TI6A00:DU9@0
1H61PGEeMFe]KFe]KFEUI@02IVIV00EUIFEQHF5MGEeMGEe_Kfl00WYjNP05P820R8R8RHV9RHV9Rh^;
00:@T9001IBDU9>CTiBDU9BDU9JFUP02UiNG00IaLG5FEUI5ADE5ADDb<S98B4P3DU9B0UEEE@05Ph>3
YZJV_Kfm_KfmemOG00;>c/h01Lo?cm[Jf^7QhN7QhM_Kf`02f=SH4]WIf@03f=SHoooooooo00[oool0
00[oool;fMWI0]_Kf`06g=cLgMgMgMgMgMgMcLg=`/;20[^k^`05/k>cMgMgMgMgBTY::BTY00861PH0
0bDU9C8b<S8b<P02;Rh^0RDU9@057alO6QXJ6QXJ5QHFDe=C009oOgl01IVIVKRh^;Rh^:n_[k6a/@02
_Kfm00G7alNd];BXZ:RXZ:RTY:@00YjNWP05XZ:RXj>SXZ:RXZ:RXJ6Q00:HV9P01I6ATHf=SHN7QhN7
Qh>3P`02Ogmo00IjNWYfMWJ2PX:2PX::RXZ=SHd2TI6A00FRXZ:`/;2`/;2j^[[6a/H00[fm_@05^[Zj
_;bl_;bl_Kfm/;2`00:VYZH01J2PX9VIVIVIVI>CThb<S002QHF500EoOgn:RXZ:RXZ@T92ATI400YBD
U005PH61MGEeKFe]KFe]IFEU009VIVH01FEUIF5QHEeMGEeMGFm_K`02NWYj00F0P828R8R9RHV9RHV;
Rh/00Y2@T005U9BDTi>CU9BDU9BDUYJF00:GUiL01W5aLEIFETE5ADE5AC8b<TQ8B0=BDU82EEEE00F3
Ph>VYZJm_Kfm_KgGemL00/k>cP05clo?f][JhN7QhN7Qfm_K00;Hf=PBfMWI00?Hf=Soooooool02_oo
o`002_ooo`_IfMT2fm_K00KLg=cMgMgMgMgMgMg=cLg2`/82^k^k00Fc/k=gMgMgMgM:BTXY:BT00PH6
1P039BDU<S8b<S8b008^;Rh29BDU00DO7alJ6QXJ6QXF5QICDe<00WmoO`05VIVI^;Rh^;Rh[jn_/K6a
00:m_Kd01LO7akBd]:RXZ:RXZ:BTY002WYjN00FRXZ:SXj>RXZ:RXZ:QXJ400YRHV005TI6ASHf=QhN7
QhN7Ph>3009oOgl01WYjNWIfMX:2PX:2PXZ:RXf=S@:ATI401J:RX[2`/;2`/;Zj^/K6aP02_Kfm00Fj
^[Zl_;bl_;bm_Kf`/;000ZJVYP05X:2PVIVIVIVITi>CS8b<00:5QHD01GmoOhZ:RXZ:RY2@T96AT@02
U9BD00F1PH5eMGE]KFe]KFeUIFD00VIVIP05IFEUHF5QGEeMGEeMKfm_009jNWX01H20P8R8R8V9RHV9
RH^;R`02T92@00FDU9BCTi>DU9BDU9BFUYH00YNGU`06LG5aEUIFADE5ADE5<S8bB4Q80e9BDP9EEED0
1H>3PjJVY[fm_Kfm_MOGe`02c/k>00G?cloJf][QhN7QhN7Kfm/00]SHf1;IfMT00mSHf?ooooooo`0:
oooo000:oooo2mWIf@;Kfm/01]cLg=gMgMgMgMgMgLg=cL;2`P:k^k/01K>c/gMgMgMgMdY:BRTY:@02
1PH600<U9BDb<S8b<S800Rh^;P8U9BD01AlO7aXJ6QXJ6QHF5U=CD`02Ogmo00FIVIVh^;Rh^;R_[jna
/K400[fm_@05alO7];BdZ:RXZ:RXY:BT00:NWYh01J:RXZ>SXj:RXZ:RXZ6QX@02V9RH00FATI6=SHf7
QhN7QhN3Ph<00WmoO`06NWYjMWIfPX:2PX:2RXZ:SHf=0Y6AT@05XZ:R/;2`/;2`^[Zja/K600:m_Kd0
1KZj^[bl_;bl_;fm_K2`/002YZJV00FPX:2IVIVIVIVCTi><S8`00XF5Q@05OgmoRXZ:RXZ:T92@TI6A
00:DU9@01H61PGEeMFe]KFe]KFEUI@02IVIV00EUIFEQHF5MGEeMGEe_Kfl00WYjNP05P820R8R8RHV9
RHV9Rh^;00:@T9001IBDU9>CTiBDU9BDU9JFUP02UiNG00IaLG5FEUI5ADE5ADDb<S98B4P3DU9B0UEE
E@05Ph>3YZJV_Kfm_KfmemOG00;>c/h01Lo?cm[Jf^7QhN7QhM_Kf`02f=SH4]WIf@03f=SHoooooooo
00[oool000[oool;fMWI0]_Kf`06g=cLgMgMgMgMgMgMcLg=`/;20[^k^`05/k>cMgMgMgMgBTY::BTY
00861PH00bDU9C8b<S8b<P02;Rh^0RDU9@057alO6QXJ6QXJ5QHFDe=C009oOgl01IVIVKRh^;Rh^:n_
[k6a/@02_Kfm00G7alNd];BXZ:RXZ:RTY:@00YjNWP05XZ:RXj>SXZ:RXZ:RXJ6Q00:HV9P01I6ATHf=
SHN7QhN7Qh>3P`02Ogmo00IjNWYfMWJ2PX:2PX::RXZ=SHd2TI6A00FRXZ:`/;2`/;2j^[[6a/H00[fm
_@05^[Zj_;bl_;bl_Kfm/;2`00:VYZH01J2PX9VIVIVIVI>CThb<S002QHF500EoOgn:RXZ:RXZ@T92A
TI400YBDU005PH61MGEeKFe]KFe]IFEU009VIVH01FEUIF5QHEeMGEeMGFm_K`02NWYj00F0P828R8R9
RHV9RHV;Rh/00Y2@T005U9BDTi>CU9BDU9BDUYJF00:GUiL01W5aLEIFETE5ADE5AC8b<TQ8B0=BDU82
EEEE00F3Ph>VYZJm_Kfm_KgGemL00/k>cP05clo?f][JhN7QhN7Qfm_K00;Hf=PBfMWI00?Hf=Sooooo
ool02_ooo`002_ooo`03fMWIf=SHf=SH00OHf=P00mWIfM[Jf][JfP02fm_K0]cLg005d=3@alO7`L71
`L71^k^k009iNGT01DM7AbHV9P00000001`L70029RHV00@O7alL71`O7alO7al48B4Q00ABDU9fMWIf
MWJ<S8`2YjNW00JXZ:R_[jnn_[jn_[k;bl_3`l<2`<3000G3`l?5aLG5aLFn_[jj^[X00[Rh^004][Jf
]kNg]kNg]kNg0kJf]P05/k>c/[:b/[:b/;2`[jn_00:c/k<01KJf][Ng]kRh^;Rh^;^k^`02_Kfm00Fo
_ko2`/:k^k^k^k^g]kL00[Jf]P05/k>c/[:b/;2`/;2`[Jf]00:[Zj/01IVIVH^;Rh61PH61PGMgM`02
LW9b00I/K6aTI6AMGEeMGEe]KFegMgL2Ng]k00F0P827QhN7QhN=SHfCTi<00YVIV@05TI6ASHf=SHf=
S8b<Rh^;00:<S8`4SHf=0hb<S0>;Rh/01UaLG3Xj>R@T92@T90/;2cLg=`9@D5001EMGEf=SHf=SHgMg
MhR8R002UiNG00FWYjNi^KVi^KW:b/[Kfm/00^_[j`03gMgMemOGemOG01?IfMT<oooo000:oooo00?I
fMWHf=SHf=P01mSHf003fMWIf][Jf][J00;Kfm/2g=cL00G@d=37alO1`L71`L6k^k/00WUiN@05AdM7
9RHV0000000071`L008V9RH011lO7a`L71lO7alO7`@Q8B40159BDWIfMWIfMXb<S0:WYjL01ZRXZ:n_
[kjn_[jn_/_;bl?3``;0`<001L?3`lG5aLG5aKjn_[Zj^P02^;Rh00Bf][Jg]kNg]kNg]kL3][Jf00Fc
/k>b/[:b/[:`/;2_[jl00[>c/`05][Jf]kNg^;Rh^;Rh^k^k00:m_Kd01Kno_l;2`[^k^k^k^kNg]`02
][Jf00Fc/k>b/[:`/;2`/;2][Jd00Z^[Z`05VIVIRh^;PH61PH61MgMg009bLW801Va/K6ATI5eMGEeM
GFe]KGMgM`9kNg/01H20P8N7QhN7Qhf=SI>CT`02VIVI00FATI6=SHf=SHf<S8b;Rh/00Xb<S0B=SHd3
S8b<0h^;R`06G5aL>SXj92@T92@T2`/;=cLg0U1@D005EeMGHf=SHf=SMgMgR8R800:GUiL01JNWYkVi
^KVi^L[:b]_Kf`02jn_[00?MgMgGemOGemL04mWIf@coool000[oool00mWIfMSHf=SHf007f=SH00?I
fMWJf][Jf]X00]_Kf`;Lg=`01M3@d<O7al71`L71`K^k^`02NGUi00E7AdLV9RH00000000L71`00RHV
9P047alO71`L7alO7alO124Q8@04DU9BMWIfMWIfS8b<0ZNWY`06Z:RX[jn__[jn_[jnbl_;`l?30/30
`005`l?3aLG5aLG5_[jn^[Zj00:h^;P01;Jf][Ng]kNg]kNg]`>f][H01K>c/k:b/[:b/[2`/:n_[`02
/k>c00Ff][Jg]kNh^;Rh^;Rk^k/00[fm_@05_kno`/;2^k^k^k^k]kNg00:f][H01K>c/k:b/[2`/;2`
/:f][@02Zj^[00FIVIV;Rh^1PH61PH5gMgL00W9bLP06K6a/I6ATGEeMGEeMKFe]MgMg0W]kN`05P820
QhN7QhN7SHf=Ti>C00:IVIT01I6ATHf=SHf=SHb<S8^;R`02S8b<18f=S@><S8`3Rh^;00ILG5`j>SXT
92@T92@;2`/g=cL2D51@00EGEeMSHf=SHf=gMgN8R8P00YNGU`05YjNW^KVi^KVib/[:fm_K00;[jn/0
0mgMgMOGemOGe`0CfMWI3?ooo`002_ooo`03fMWIf=SHf=SH00OHf=P00mWIfM[Jf][JfP02fm_K0]cL
g005d=3@alO7`L71`L71^k^k009iNGT01DM7AbHV9P00000001`L70029RHV00@O7alL71`O7alO7al4
8B4Q00ABDU9fMWIfMWJ<S8`2YjNW00JXZ:R_[jnn_[jn_[k;bl_3`l<2`<3000G3`l?5aLG5aLFn_[jj
^[X00[Rh^004][Jf]kNg]kNg]kNg0kJf]P05/k>c/[:b/[:b/;2`[jn_00:c/k<01KJf][Ng]kRh^;Rh
^;^k^`02_Kfm00Fo_ko2`/:k^k^k^k^g]kL00[Jf]P05/k>c/[:b/;2`/;2`[Jf]00:[Zj/01IVIVH^;
Rh61PH61PGMgM`02LW9b00I/K6aTI6AMGEeMGEe]KFegMgL2Ng]k00F0P827QhN7QhN=SHfCTi<00YVI
V@05TI6ASHf=SHf=S8b<Rh^;00:<S8`4SHf=0hb<S0>;Rh/01UaLG3Xj>R@T92@T90/;2cLg=`9@D500
1EMGEf=SHf=SHgMgMhR8R002UiNG00FWYjNi^KVi^KW:b/[Kfm/00^_[j`03gMgMemOGemOG01?IfMT<
oooo000:oooo00?IfMWHf=SHf=P01mSHf003fMWIf][Jf][J00;Kfm/2g=cL00G@d=37alO1`L71`L6k
^k/00WUiN@05AdM79RHV0000000071`L008V9RH011lO7a`L71lO7alO7`@Q8B40159BDWIfMWIfMXb<
S0:WYjL01ZRXZ:n_[kjn_[jn_/_;bl?3``;0`<001L?3`lG5aLG5aKjn_[Zj^P02^;Rh00Bf][Jg]kNg
]kNg]kL3][Jf00Fc/k>b/[:b/[:`/;2_[jl00[>c/`05][Jf]kNg^;Rh^;Rh^k^k00:m_Kd01Kno_l;2
`[^k^k^k^kNg]`02][Jf00Fc/k>b/[:`/;2`/;2][Jd00Z^[Z`05VIVIRh^;PH61PH61MgMg009bLW80
1Va/K6ATI5eMGEeMGFe]KGMgM`9kNg/01H20P8N7QhN7Qhf=SI>CT`02VIVI00FATI6=SHf=SHf<S8b;
Rh/00Xb<S0B=SHd3S8b<0h^;R`06G5aL>SXj92@T92@T2`/;=cLg0U1@D005EeMGHf=SHf=SMgMgR8R8
00:GUiL01JNWYkVi^KVi^L[:b]_Kf`02jn_[00?MgMgGemOGemL04mWIf@coool000[oool00mWIfMSH
f=SHf007f=SH00?IfMWJf][Jf]X00]_Kf`;Lg=`01M3@d<O7al71`L71`K^k^`02NGUi00E7AdLV9RH0
0000000L71`00RHV9P047alO71`L7alO7alO124Q8@04DU9BMWIfMWIfS8b<0ZNWY`06Z:RX[jn__[jn
_[jnbl_;`l?30/30`005`l?3aLG5aLG5_[jn^[Zj00:h^;P01;Jf][Ng]kNg]kNg]`>f][H01K>c/k:b
/[:b/[2`/:n_[`02/k>c00Ff][Jg]kNh^;Rh^;Rk^k/00[fm_@05_kno`/;2^k^k^k^k]kNg00:f][H0
1K>c/k:b/[2`/;2`/:f][@02Zj^[00FIVIV;Rh^1PH61PH5gMgL00W9bLP06K6a/I6ATGEeMGEeMKFe]
MgMg0W]kN`05P820QhN7QhN7SHf=Ti>C00:IVIT01I6ATHf=SHf=SHb<S8^;R`02S8b<18f=S@><S8`3
Rh^;00ILG5`j>SXT92@T92@;2`/g=cL2D51@00EGEeMSHf=SHf=gMgN8R8P00YNGU`05YjNW^KVi^KVi
b/[:fm_K00;[jn/00mgMgMOGemOGe`0CfMWI3?ooo`002_ooo`_IfMT2f][J0]_Kf`;Lg=`01M7AdLW9
bLG5aLG5aKno_`02Q8B400EGEeLi>CTF5QHF5QHY:BT00Rh^;P059BDU7alO9BDU9BDU:2PX008W9bL0
1BPX:4e=CFQXJ6QXJ7UiN@02SHf=00JKVi^ZZZZk^k^k^k_<c<c2`/82_[jn00G3`l?5aLG5aLG6a/K7
alL00/S8b0?:b/X01L_;blc<c<g=cLg=cLc<c004bl_;0/S8b005a/K6aLG5`l?3`l?3`L7100:n_[h0
1Kbl_;Zj^[Rh^;Rh^;Jf]P02];Bd00Bb/[:c/k>c/k>c/k<3/[:b00Fa/K6`/;2_[jn_[jn^[Zh00ZNW
Y`06XZ:RWYjNVYZJVYZJRh^;Ogmo0WIfMP05K6a/KFe]KFe]Jf][IVIV009RHV801Fe]KG=cLg=cLgIf
MWUiN@02Q8B400F=SHfDU9BDU9BKVi^2PX800W9bLP05Jf][HF5QHF5QBDU9=3@d008T92@01A8B4QlO
7b@T92@T924Q8@02820P00E2@T9KFe]ZJVYZJVYlO7`00Z6QX@05`L71g=cLn?Shn?ShgmoO00;EeMDC
fMWI3?ooo`002_ooo`_IfMT2f][J0]_Kf`;Lg=`01M7AdLW9bLG5aLG5aKno_`02Q8B400EGEeLi>CTF
5QHF5QHY:BT00Rh^;P059BDU7alO9BDU9BDU:2PX008W9bL01BPX:4e=CFQXJ6QXJ7UiN@02SHf=00JK
Vi^ZZZZk^k^k^k_<c<c2`/82_[jn00G3`l?5aLG5aLG6a/K7alL00/S8b0?:b/X01L_;blc<c<g=cLg=
cLc<c004bl_;0/S8b005a/K6aLG5`l?3`l?3`L7100:n_[h01Kbl_;Zj^[Rh^;Rh^;Jf]P02];Bd00Bb
/[:c/k>c/k>c/k<3/[:b00Fa/K6`/;2_[jn_[jn^[Zh00ZNWY`06XZ:RWYjNVYZJVYZJRh^;Ogmo0WIf
MP05K6a/KFe]KFe]Jf][IVIV009RHV801Fe]KG=cLg=cLgIfMWUiN@02Q8B400F=SHfDU9BDU9BKVi^2
PX800W9bLP05Jf][HF5QHF5QBDU9=3@d008T92@01A8B4QlO7b@T92@T924Q8@02820P00E2@T9KFe]Z
JVYZJVYlO7`00Z6QX@05`L71g=cLn?Shn?ShgmoO00;EeMDCfMWI3?ooo`002_ooo`_IfMT2f][J0]_K
f`;Lg=`01M7AdLW9bLG5aLG5aKno_`02Q8B400EGEeLi>CTF5QHF5QHY:BT00Rh^;P059BDU7alO9BDU
9BDU:2PX008W9bL01BPX:4e=CFQXJ6QXJ7UiN@02SHf=00JKVi^ZZZZk^k^k^k_<c<c2`/82_[jn00G3
`l?5aLG5aLG6a/K7alL00/S8b0?:b/X01L_;blc<c<g=cLg=cLc<c004bl_;0/S8b005a/K6aLG5`l?3
`l?3`L7100:n_[h01Kbl_;Zj^[Rh^;Rh^;Jf]P02];Bd00Bb/[:c/k>c/k>c/k<3/[:b00Fa/K6`/;2_
[jn_[jn^[Zh00ZNWY`06XZ:RWYjNVYZJVYZJRh^;Ogmo0WIfMP05K6a/KFe]KFe]Jf][IVIV009RHV80
1Fe]KG=cLg=cLgIfMWUiN@02Q8B400F=SHfDU9BDU9BKVi^2PX800W9bLP05Jf][HF5QHF5QBDU9=3@d
008T92@01A8B4QlO7b@T92@T924Q8@02820P00E2@T9KFe]ZJVYZJVYlO7`00Z6QX@05`L71g=cLn?Sh
n?ShgmoO00;EeMDCfMWI3?ooo`002_ooo`_IfMT2f][J0]_Kf`;Lg=`01M7AdLW9bLG5aLG5aKno_`02
Q8B400EGEeLi>CTF5QHF5QHY:BT00Rh^;P059BDU7alO9BDU9BDU:2PX008W9bL01BPX:4e=CFQXJ6QX
J7UiN@02SHf=00JKVi^ZZZZk^k^k^k_<c<c2`/82_[jn00G3`l?5aLG5aLG6a/K7alL00/S8b0?:b/X0
1L_;blc<c<g=cLg=cLc<c004bl_;0/S8b005a/K6aLG5`l?3`l?3`L7100:n_[h01Kbl_;Zj^[Rh^;Rh
^;Jf]P02];Bd00Bb/[:c/k>c/k>c/k<3/[:b00Fa/K6`/;2_[jn_[jn^[Zh00ZNWY`06XZ:RWYjNVYZJ
VYZJRh^;Ogmo0WIfMP05K6a/KFe]KFe]Jf][IVIV009RHV801Fe]KG=cLg=cLgIfMWUiN@02Q8B400F=
SHfDU9BDU9BKVi^2PX800W9bLP05Jf][HF5QHF5QBDU9=3@d008T92@01A8B4QlO7b@T92@T924Q8@02
820P00E2@T9KFe]ZJVYZJVYlO7`00Z6QX@05`L71g=cLn?Shn?ShgmoO00;EeMDCfMWI3?ooo`002_oo
o`_IfMT2f][J0]_Kf`;Lg=`01M7AdLW9bLG5aLG5aKno_`02Q8B400EGEeLi>CTF5QHF5QHY:BT00Rh^
;P059BDU7alO9BDU9BDU:2PX008W9bL01BPX:4e=CFQXJ6QXJ7UiN@02SHf=00JKVi^ZZZZk^k^k^k_<
c<c2`/82_[jn00G3`l?5aLG5aLG6a/K7alL00/S8b0?:b/X01L_;blc<c<g=cLg=cLc<c004bl_;0/S8
b005a/K6aLG5`l?3`l?3`L7100:n_[h01Kbl_;Zj^[Rh^;Rh^;Jf]P02];Bd00Bb/[:c/k>c/k>c/k<3
/[:b00Fa/K6`/;2_[jn_[jn^[Zh00ZNWY`06XZ:RWYjNVYZJVYZJRh^;Ogmo0WIfMP05K6a/KFe]KFe]
Jf][IVIV009RHV801Fe]KG=cLg=cLgIfMWUiN@02Q8B400F=SHfDU9BDU9BKVi^2PX800W9bLP05Jf][
HF5QHF5QBDU9=3@d008T92@01A8B4QlO7b@T92@T924Q8@02820P00E2@T9KFe]ZJVYZJVYlO7`00Z6Q
X@05`L71g=cLn?Shn?ShgmoO00;EeMDCfMWI3?ooo`002_ooo`_IfMT2gMgM00KPh>3Rh^;UiNGUiNG4
a<B][Jd2WinO00F?ShmbLW9bLW9HF5Q2@T800RXZ:P05=3@d=CDe=CDe;Bd]9bLW00<X:2P29BDU00DS
8b<g=cM4A4A4A4A<C4`00UIFEP06NWYjUiNG[Jf][Jf]a<C4^k^k0[Zj^P03`/;2b<S8b<S800;6a/H2
b<S80l[:bP05bl_;c<c<cLg=cLg=c<c<00C;bl/2b<S800G6a/K4a<C2`/;2`/;0`<000[fm_@05^k^k
^KVi][Jf][Jf];Bd00:a/K400jn_[k2`/;2`/002/;2`0Zn_[`05[Jf]Zj^[ZZZZZZZZZJVY00:WYjL0
1ZJVYZFUYJ>SXj>SXj:RXZ6QX@:PX:001InOWibLW9bLW9^KViVIV@03UiNG0YJFUP:EUID2U9BD0i>C
T`05TY:BKfm_EEEEEEEEA4A400<a<C401B`/;28R8R8R8QXJ6QdM7@027QhN00DK6a/I6ATI6ATV9RH_
;bl00S@d=005>SXjOWinOWin/;2`dm?C00;jn_X01MgMgM;Bd];Bd]WIfMcLg00AfMWI3?ooo`002_oo
o`_IfMT2gMgM00KPh>3Rh^;UiNGUiNG4a<B][Jd2WinO00F?ShmbLW9bLW9HF5Q2@T800RXZ:P05=3@d
=CDe=CDe;Bd]9bLW00<X:2P29BDU00DS8b<g=cM4A4A4A4A<C4`00UIFEP06NWYjUiNG[Jf][Jf]a<C4
^k^k0[Zj^P03`/;2b<S8b<S800;6a/H2b<S80l[:bP05bl_;c<c<cLg=cLg=c<c<00C;bl/2b<S800G6
a/K4a<C2`/;2`/;0`<000[fm_@05^k^k^KVi][Jf][Jf];Bd00:a/K400jn_[k2`/;2`/002/;2`0Zn_
[`05[Jf]Zj^[ZZZZZZZZZJVY00:WYjL01ZJVYZFUYJ>SXj>SXj:RXZ6QX@:PX:001InOWibLW9bLW9^K
ViVIV@03UiNG0YJFUP:EUID2U9BD0i>CT`05TY:BKfm_EEEEEEEEA4A400<a<C401B`/;28R8R8R8QXJ
6QdM7@027QhN00DK6a/I6ATI6ATV9RH_;bl00S@d=005>SXjOWinOWin/;2`dm?C00;jn_X01MgMgM;B
d];Bd]WIfMcLg00AfMWI3?ooo`002_ooo`_IfMT2gMgM00KPh>3Rh^;UiNGUiNG4a<B][Jd2WinO00F?
ShmbLW9bLW9HF5Q2@T800RXZ:P05=3@d=CDe=CDe;Bd]9bLW00<X:2P29BDU00DS8b<g=cM4A4A4A4A<
C4`00UIFEP06NWYjUiNG[Jf][Jf]a<C4^k^k0[Zj^P03`/;2b<S8b<S800;6a/H2b<S80l[:bP05bl_;
c<c<cLg=cLg=c<c<00C;bl/2b<S800G6a/K4a<C2`/;2`/;0`<000[fm_@05^k^k^KVi][Jf][Jf];Bd
00:a/K400jn_[k2`/;2`/002/;2`0Zn_[`05[Jf]Zj^[ZZZZZZZZZJVY00:WYjL01ZJVYZFUYJ>SXj>S
Xj:RXZ6QX@:PX:001InOWibLW9bLW9^KViVIV@03UiNG0YJFUP:EUID2U9BD0i>CT`05TY:BKfm_EEEE
EEEEA4A400<a<C401B`/;28R8R8R8QXJ6QdM7@027QhN00DK6a/I6ATI6ATV9RH_;bl00S@d=005>SXj
OWinOWin/;2`dm?C00;jn_X01MgMgM;Bd];Bd]WIfMcLg00AfMWI3?ooo`002_ooo`_IfMT2gMgM00KP
h>3Rh^;UiNGUiNG4a<B][Jd2WinO00F?ShmbLW9bLW9HF5Q2@T800RXZ:P05=3@d=CDe=CDe;Bd]9bLW
00<X:2P29BDU00DS8b<g=cM4A4A4A4A<C4`00UIFEP06NWYjUiNG[Jf][Jf]a<C4^k^k0[Zj^P03`/;2
b<S8b<S800;6a/H2b<S80l[:bP05bl_;c<c<cLg=cLg=c<c<00C;bl/2b<S800G6a/K4a<C2`/;2`/;0
`<000[fm_@05^k^k^KVi][Jf][Jf];Bd00:a/K400jn_[k2`/;2`/002/;2`0Zn_[`05[Jf]Zj^[ZZZZ
ZZZZZJVY00:WYjL01ZJVYZFUYJ>SXj>SXj:RXZ6QX@:PX:001InOWibLW9bLW9^KViVIV@03UiNG0YJF
UP:EUID2U9BD0i>CT`05TY:BKfm_EEEEEEEEA4A400<a<C401B`/;28R8R8R8QXJ6QdM7@027QhN00DK
6a/I6ATI6ATV9RH_;bl00S@d=005>SXjOWinOWin/;2`dm?C00;jn_X01MgMgM;Bd];Bd]WIfMcLg00A
fMWI3?ooo`002_ooo`_IfMT2gMgM00KPh>3Rh^;UiNGUiNG4a<B][Jd2WinO00F?ShmbLW9bLW9HF5Q2
@T800RXZ:P05=3@d=CDe=CDe;Bd]9bLW00<X:2P29BDU00DS8b<g=cM4A4A4A4A<C4`00UIFEP06NWYj
UiNG[Jf][Jf]a<C4^k^k0[Zj^P03`/;2b<S8b<S800;6a/H2b<S80l[:bP05bl_;c<c<cLg=cLg=c<c<
00C;bl/2b<S800G6a/K4a<C2`/;2`/;0`<000[fm_@05^k^k^KVi][Jf][Jf];Bd00:a/K400jn_[k2`
/;2`/002/;2`0Zn_[`05[Jf]Zj^[ZZZZZZZZZJVY00:WYjL01ZJVYZFUYJ>SXj>SXj:RXZ6QX@:PX:00
1InOWibLW9bLW9^KViVIV@03UiNG0YJFUP:EUID2U9BD0i>CT`05TY:BKfm_EEEEEEEEA4A400<a<C40
1B`/;28R8R8R8QXJ6QdM7@027QhN00DK6a/I6ATI6ATV9RH_;bl00S@d=005>SXjOWinOWin/;2`dm?C
00;jn_X01MgMgM;Bd];Bd]WIfMcLg00AfMWI3?ooo`002_ooo`_IfMT2gMgM00KPh>3Rh^;UiNGUiNG4
a<B][Jd2WinO00F?ShmbLW9bLW9HF5Q2@T800RXZ:P05=3@d=CDe=CDe;Bd]9bLW00<X:2P29BDU00DS
8b<g=cM4A4A4A4A<C4`00UIFEP06NWYjUiNG[Jf][Jf]a<C4^k^k0[Zj^P03`/;2b<S8b<S800;6a/H2
b<S80l[:bP05bl_;c<c<cLg=cLg=c<c<00C;bl/2b<S800G6a/K4a<C2`/;2`/;0`<000[fm_@05^k^k
^KVi][Jf][Jf];Bd00:a/K400jn_[k2`/;2`/002/;2`0Zn_[`05[Jf]Zj^[ZZZZZZZZZJVY00:WYjL0
1ZJVYZFUYJ>SXj>SXj:RXZ6QX@:PX:001InOWibLW9bLW9^KViVIV@03UiNG0YJFUP:EUID2U9BD0i>C
T`05TY:BKfm_EEEEEEEEA4A400<a<C401B`/;28R8R8R8QXJ6QdM7@027QhN00DK6a/I6ATI6ATV9RH_
;bl00S@d=005>SXjOWinOWin/;2`dm?C00;jn_X01MgMgM;Bd];Bd]WIfMcLg00AfMWI3?ooo`002_oo
o`_IfMT2g]kN00KQhN7Shn?Vi^KVi^K2`/:YZJT2VYZJ00F8R8Q`L71`L71KFe]6ATH00S4a<@05?3`l
?clo?clo>CTi=CDe008a<C401B`/;2PX:2PX:2@T93<c<`02?3`l00E1@D56ATI6ATIWIfN1PH400Y>C
T`05YjNWZj^[/k>c/k>c`<3000;;bl/01LG5aL?3`lK6a/K6a/S8b002bLW900G:b/[<c<c=cLg=cLg;
bl/01<[:bP;7alL01LG5aL?3`l;2`/;2`[jn_P02^k^k00Fh^;Rf][Jb/[:b/[:_[jl00Zb/[004ZJVY
Zj^[[:b/[:b/0j^[Z`05ZJVYYjNWYZJVYZJVY:BT00:SXj<01Z6QXJ2PX9jNWYjNWYfMWIbLW0:KVi/0
1IZJVYVIVIVIVIVIVIRHV002UiNG00FEUIFDU9BDU9BCTi>BTY800XF5Q@05Ng]kMGEeMGEeKFe]E5AD
008o?cl01C0`<1hN7QhN7R<S8b8R8P026a/K0QHF5P8E5AD01A<C4a0@410@42HV9SDe=@02?Cdm00E8
B4R6QXJ6QXJg]kOIfMT00_ooo`05h>3Pdm?Cdm?CfMWIf][J017IfMT<oooo000:oooo2mWIf@;Ng]h0
1^7QhN?ShnKVi^KVi/;2`ZVYZ@:JVYX01HR8R71`L71`L5]KFdI6AP02<C4a00Dl?3`o?clo?cli>CTe
=CD00S4a<@05;2`/:2PX:2PX92@T<c<c008l?3`01D51@DI6ATI6AVMWIh61P@02Ti>C00FWYjN[Zj^c
/k>c/k?0`<000/_;b`05aLG5`l?3a/K6a/K6b<S800;9bLT01L[:b/c<c<g=cLg=cL_;b`04b/[:0/O7
a`05aLG5`l?3`/;2`/;2_[jn00:k^k/01KRh^;Jf][:b/[:b/Zn_[`02[:b/00BYZJV[Zj^/[:b/[:`3
Zj^[00FYZJVWYjNVYZJVYZJTY:@00Z>SX`06XJ6QX:2PWYjNWYjNWIfMW9bL0Y^KV`05VYZJVIVIVIVI
VIVIV9RH00:GUiL01IFEUIBDU9BDU9>CTi:BTP02QHF500EkNg]eMGEeMGE]KFeDE5@00Slo?`05<30`
7QhN7QhN8b<S8R8R008K6a/25QHF0QDE5@054a<C410@410@9RHV=CDe008m?Cd01DQ8B8J6QXJ6Q[Ng
]mWIf@02oooo00GPh>3Cdm?Cdm?IfMWJf]X04MWIf@coool000[oool;fMWI0]kNgP06hN7Qhn?Si^KV
i^KV`/;2ZJVY0YZJVP05R8R8L71`L71`Fe]KATI6008a<C401C`l?3lo?clo?cTi>CDe=@02<C4a00D/
;2`X:2PX:2PT92@c<c<00S`l?005@D51ATI6ATI6IfMWPH6100:CTi<01JNWYj^[Zk>c/k>c/l30`002
bl_;00G5aLG3`l?6a/K6a/K8b<P00/W9b@05b/[:c<c<cLg=cLg=bl_;00C:b/X2alO700G5aLG3`l?2
`/;2`/:n_[h00[^k^`05^;Rh][Jf/[:b/[:b[jn_00:/[:`01:VYZJ^[Zjb/[:b/[0>[Zj/01JVYZJNW
YjJVYZJVYZBTY002Xj>S00JQXJ6PX:2NWYjNWYjMWIfLW9`2Vi^K00FJVYZIVIVIVIVIVIVHV9P00YNG
U`05UIFEU9BDU9BDTi>CTY:B00:5QHD01G]kNgEeMGEeMFe]KEADE002?clo00D`<30N7QhN7QhS8b<R
8R800Q/K6`8F5QH25ADE00DC4a<@410@410V9RHe=CD00Sdm?@05B4Q8QXJ6QXJ6]kNgfMWI00;oool0
1N3Ph=?Cdm?CdmWIfM[JfP0AfMWI3?ooo`002_ooo`_IfMT2g]kN00KQhN7Shn?Vi^KVi^K2`/:YZJT2
VYZJ00F8R8Q`L71`L71KFe]6ATH00S4a<@05?3`l?clo?clo>CTi=CDe008a<C401B`/;2PX:2PX:2@T
93<c<`02?3`l00E1@D56ATI6ATIWIfN1PH400Y>CT`05YjNWZj^[/k>c/k>c`<3000;;bl/01LG5aL?3
`lK6a/K6a/S8b002bLW900G:b/[<c<c=cLg=cLg;bl/01<[:bP;7alL01LG5aL?3`l;2`/;2`[jn_P02
^k^k00Fh^;Rf][Jb/[:b/[:_[jl00Zb/[004ZJVYZj^[[:b/[:b/0j^[Z`05ZJVYYjNWYZJVYZJVY:BT
00:SXj<01Z6QXJ2PX9jNWYjNWYfMWIbLW0:KVi/01IZJVYVIVIVIVIVIVIRHV002UiNG00FEUIFDU9BD
U9BCTi>BTY800XF5Q@05Ng]kMGEeMGEeKFe]E5AD008o?cl01C0`<1hN7QhN7R<S8b8R8P026a/K0QHF
5P8E5AD01A<C4a0@410@42HV9SDe=@02?Cdm00E8B4R6QXJ6QXJg]kOIfMT00_ooo`05h>3Pdm?Cdm?C
fMWIf][J017IfMT<oooo000:oooo2mWIf@;Ng]h01^7QhN?ShnKVi^KVi/;2`ZVYZ@:JVYX01HR8R71`
L71`L5]KFdI6AP02<C4a00Dl?3`o?clo?cli>CTe=CD00S4a<@05;2`/:2PX:2PX92@T<c<c008l?3`0
1D51@DI6ATI6AVMWIh61P@02Ti>C00FWYjN[Zj^c/k>c/k?0`<000/_;b`05aLG5`l?3a/K6a/K6b<S8
00;9bLT01L[:b/c<c<g=cLg=cL_;b`04b/[:0/O7a`05aLG5`l?3`/;2`/;2_[jn00:k^k/01KRh^;Jf
][:b/[:b/Zn_[`02[:b/00BYZJV[Zj^/[:b/[:`3Zj^[00FYZJVWYjNVYZJVYZJTY:@00Z>SX`06XJ6Q
X:2PWYjNWYjNWIfMW9bL0Y^KV`05VYZJVIVIVIVIVIVIV9RH00:GUiL01IFEUIBDU9BDU9>CTi:BTP02
QHF500EkNg]eMGEeMGE]KFeDE5@00Slo?`05<30`7QhN7QhN8b<S8R8R008K6a/25QHF0QDE5@054a<C
410@410@9RHV=CDe008m?Cd01DQ8B8J6QXJ6Q[Ng]mWIf@02oooo00GPh>3Cdm?Cdm?IfMWJf]X04MWI
f@coool000[oool;fMWI0]gMg@06h>3Ph^;RiNGUiNGU`/;2ZJVY0YZJVP05R8R8Kfm_Kfm_F5QH@d=3
008];Bd00d10@4Q8B4Q8B002ADE50S/k>`05<c<c;bl_;bl_:BTY=cLg008o?cl01D=3@dM7AdM7AeaL
G6a/K002N7Qh00F5QHFHV9RXZ:RXZ:Rh^;P00/S8b005`<30_knoa<C4a<C4alO700?6a/H01<O7alS8
b<S8b<K6aPC5aLD2`/;200G0`<2o_knm_Kfm_Kfi^KT00[Jf]P05/k>c/;2`[Zj^[Zj^[:b/00:YZJT0
0jNWYjRXZ:NWY`02YjNW1:JVYP>UYJD2XJ6Q00JOWinMWIfKVi^KVi^JVYZIVIT2UiNG19JFUP>EUID0
1Hf=SHR8R8R8R8B4Q820P002Jf][00EJFUY>CTi>CTi1@D4j>SX00S8b<P03:2PX7QhN7QhN008S8b<2
820P00DN7QhF5QH@410@410;2`/00PD51@05>3PhG5aLLG5aLG5aRXZ:00:VYZH01L71`McLg?Kfm_Kf
m]oOg`02eMGE4mWIf@coool000[oool;fMWI0]gMg@06h>3Ph^;RiNGUiNGU`/;2ZJVY0YZJVP05R8R8
Kfm_Kfm_F5QH@d=3008];Bd00d10@4Q8B4Q8B002ADE50S/k>`05<c<c;bl_;bl_:BTY=cLg008o?cl0
1D=3@dM7AdM7AeaLG6a/K002N7Qh00F5QHFHV9RXZ:RXZ:Rh^;P00/S8b005`<30_knoa<C4a<C4alO7
00?6a/H01<O7alS8b<S8b<K6aPC5aLD2`/;200G0`<2o_knm_Kfm_Kfi^KT00[Jf]P05/k>c/;2`[Zj^
[Zj^[:b/00:YZJT00jNWYjRXZ:NWY`02YjNW1:JVYP>UYJD2XJ6Q00JOWinMWIfKVi^KVi^JVYZIVIT2
UiNG19JFUP>EUID01Hf=SHR8R8R8R8B4Q820P002Jf][00EJFUY>CTi>CTi1@D4j>SX00S8b<P03:2PX
7QhN7QhN008S8b<2820P00DN7QhF5QH@410@410;2`/00PD51@05>3PhG5aLLG5aLG5aRXZ:00:VYZH0
1L71`McLg?Kfm_Kfm]oOg`02eMGE4mWIf@coool000[oool;fMWI0]gMg@06h>3Ph^;RiNGUiNGU`/;2
ZJVY0YZJVP05R8R8Kfm_Kfm_F5QH@d=3008];Bd00d10@4Q8B4Q8B002ADE50S/k>`05<c<c;bl_;bl_
:BTY=cLg008o?cl01D=3@dM7AdM7AeaLG6a/K002N7Qh00F5QHFHV9RXZ:RXZ:Rh^;P00/S8b005`<30
_knoa<C4a<C4alO700?6a/H01<O7alS8b<S8b<K6aPC5aLD2`/;200G0`<2o_knm_Kfm_Kfi^KT00[Jf
]P05/k>c/;2`[Zj^[Zj^[:b/00:YZJT00jNWYjRXZ:NWY`02YjNW1:JVYP>UYJD2XJ6Q00JOWinMWIfK
Vi^KVi^JVYZIVIT2UiNG19JFUP>EUID01Hf=SHR8R8R8R8B4Q820P002Jf][00EJFUY>CTi>CTi1@D4j
>SX00S8b<P03:2PX7QhN7QhN008S8b<2820P00DN7QhF5QH@410@410;2`/00PD51@05>3PhG5aLLG5a
LG5aRXZ:00:VYZH01L71`McLg?Kfm_Kfm]oOg`02eMGE4mWIf@coool000[oool;fMWI0]gMg@06h>3P
h^;RiNGUiNGU`/;2ZJVY0YZJVP05R8R8Kfm_Kfm_F5QH@d=3008];Bd00d10@4Q8B4Q8B002ADE50S/k
>`05<c<c;bl_;bl_:BTY=cLg008o?cl01D=3@dM7AdM7AeaLG6a/K002N7Qh00F5QHFHV9RXZ:RXZ:Rh
^;P00/S8b005`<30_knoa<C4a<C4alO700?6a/H01<O7alS8b<S8b<K6aPC5aLD2`/;200G0`<2o_knm
_Kfm_Kfi^KT00[Jf]P05/k>c/;2`[Zj^[Zj^[:b/00:YZJT00jNWYjRXZ:NWY`02YjNW1:JVYP>UYJD2
XJ6Q00JOWinMWIfKVi^KVi^JVYZIVIT2UiNG19JFUP>EUID01Hf=SHR8R8R8R8B4Q820P002Jf][00EJ
FUY>CTi>CTi1@D4j>SX00S8b<P03:2PX7QhN7QhN008S8b<2820P00DN7QhF5QH@410@410;2`/00PD5
1@05>3PhG5aLLG5aLG5aRXZ:00:VYZH01L71`McLg?Kfm_Kfm]oOg`02eMGE4mWIf@coool000[oool;
fMWI0]gMg@06h>3Ph^;RiNGUiNGU`/;2ZJVY0YZJVP05R8R8Kfm_Kfm_F5QH@d=3008];Bd00d10@4Q8
B4Q8B002ADE50S/k>`05<c<c;bl_;bl_:BTY=cLg008o?cl01D=3@dM7AdM7AeaLG6a/K002N7Qh00F5
QHFHV9RXZ:RXZ:Rh^;P00/S8b005`<30_knoa<C4a<C4alO700?6a/H01<O7alS8b<S8b<K6aPC5aLD2
`/;200G0`<2o_knm_Kfm_Kfi^KT00[Jf]P05/k>c/;2`[Zj^[Zj^[:b/00:YZJT00jNWYjRXZ:NWY`02
YjNW1:JVYP>UYJD2XJ6Q00JOWinMWIfKVi^KVi^JVYZIVIT2UiNG19JFUP>EUID01Hf=SHR8R8R8R8B4
Q820P002Jf][00EJFUY>CTi>CTi1@D4j>SX00S8b<P03:2PX7QhN7QhN008S8b<2820P00DN7QhF5QH@
410@410;2`/00PD51@05>3PhG5aLLG5aLG5aRXZ:00:VYZH01L71`McLg?Kfm_Kfm]oOg`02eMGE4mWI
f@coool000[oool;fMWI0]gMg@06h>3Ph^;RiNGUiNGU`/;2ZJVY0YZJVP05R8R8Kfm_Kfm_F5QH@d=3
008];Bd00d10@4Q8B4Q8B002ADE50S/k>`05<c<c;bl_;bl_:BTY=cLg008o?cl01D=3@dM7AdM7AeaL
G6a/K002N7Qh00F5QHFHV9RXZ:RXZ:Rh^;P00/S8b005`<30_knoa<C4a<C4alO700?6a/H01<O7alS8
b<S8b<K6aPC5aLD2`/;200G0`<2o_knm_Kfm_Kfi^KT00[Jf]P05/k>c/;2`[Zj^[Zj^[:b/00:YZJT0
0jNWYjRXZ:NWY`02YjNW1:JVYP>UYJD2XJ6Q00JOWinMWIfKVi^KVi^JVYZIVIT2UiNG19JFUP>EUID0
1Hf=SHR8R8R8R8B4Q820P002Jf][00EJFUY>CTi>CTi1@D4j>SX00S8b<P03:2PX7QhN7QhN008S8b<2
820P00DN7QhF5QH@410@410;2`/00PD51@05>3PhG5aLLG5aLG5aRXZ:00:VYZH01L71`McLg?Kfm_Kf
m]oOg`02eMGE4mWIf@coool000[oool;fMWI0]cLg006g]kNgmoOh>3Ph>3Pbl_;^k^k0[6a/@05YZJV
OGemOGemG5aL@T92008W9bL01D10@4];Bd];BdM7AdQ8B002?Shn00Df=SHb<S8b<S8];Bde=CD00SXj
>P05>c/k?Shn?ShnATI6CDe=009BDU801EQHF7MgMi2@T92@T::RXP02]KFe00F`/;2b/[:j^[Zj^[[1
`L400[jn_P05_Kfm_kno`L71`L71_[jn00:l_;`01[^k^kZj^[Vi^KVi^KRh^;Ng]`:f][H01K6a/Jb/
[:b/[:VYZJJVYP02YJFU00FTY:BQXJ6QXJ6OWinQXJ401J:RXP05X:2PWYjNWIfMWIfMW9bL00>KVi/0
1IZJVYVIVIVIVIRHV9NGU`03UYJF0Y2@T005Rh^;R8R8QHF5QHF5LW9b009TI6@01EYJFTi>CT92@T92
@SLg=`02:b/[00DO7alS8b<S8b<S8b<N7Qh00a/K6`056QXJ61PH61PH5aLG5ADE008C4a<01A8B4Q0@
410@45YJFY2@T002/K6a00GHf=S;bl_;bl_;bl_Jf]X00^GUi@03fm_KemOGemOG01?IfMT<oooo000:
oooo2mWIf@;Lg=`01]kNg]oOgn3Ph>3Ph<_;bk^k^`:a/K401JJVYWemOGemOEaLG492@P029bLW00E0
@41;Bd];Bd]7AdM8B4P00Shn?P05=SHf<S8b<S8b;Bd]=CDe008j>SX01C/k>chn?Shn?TI6ATe=C@02
DU9B00EHF5QgMgN@T92@T92RXZ800[Fe]@05/;2`/[:b^[Zj^[Zj`L7100:n_[h01Kfm_Kno_l71`L71
`Kjn_P02_;bl00Jk^k^j^[Zi^KVi^KVh^;Rg]kL2][Jf00Fa/K6/[:b/[:bYZJVVYZH00ZFUY@05Y:BT
XJ6QXJ6QWinOXJ6Q00FRXZ801J2PX9jNWYfMWIfMWIbLW003Vi^K00FJVYZIVIVIVIVHV9RGUiL00iJF
UP:@T9001H^;RhR8R8F5QHF5QG9bLP02I6AT00EJFUY>CTi2@T92@T8g=cL00R/[:`057alO8b<S8b<S
8b<S7QhN00<K6a/01AXJ6QPH61PH61LG5aDE5@024a<C00DB4Q8@410@411JFUZ@T9000[6a/@05f=SH
bl_;bl_;bl_;f][J00;UiND00m_KfmOGemOGe`0CfMWI3?ooo`002_ooo`_IfMT2g=cL00KNg]kOgmoP
h>3Ph>3;bl^k^k/2/K6a00FVYZImOGemOGeLG5a2@T800RLW9`05@410Bd];Bd];AdM7B4Q8008n?Sh0
1CHf=S8b<S8b<Rd];CDe=@02>SXj00Dk>c/n?Shn?Si6ATI=CDd00U9BDP05F5QHMgMgT92@T92@XZ:R
00:e]KD01K2`/;:b/[Zj^[Zj^/71`@02_[jn00Fm_Kfo_ko1`L71`L6n_[h00[bl_006^k^k^[Zj^KVi
^KVi^;Rh]kNg0[Jf]P05/K6a[:b/[:b/ZJVYYZJV00:UYJD01JBTY:6QXJ6QXInOWj6QX@05XZ:R00FP
X:2NWYjMWIfMWIfLW9`00i^KV`05VYZJVIVIVIVIV9RHUiNG00>FUYH2T92@00F;Rh^8R8R5QHF5QHEb
LW800VATI005FUYJCTi>@T92@T92=cLg008[:b/01AlO7b<S8b<S8b<S8ahN7P036a/K00DJ6QXH61PH
61PG5aLE5AD00Q<C4`054Q8B410@410@FUYJT92@00:a/K401MSHf<_;bl_;bl_;bm[JfP02iNGU00?K
fm_GemOGemL04mWIf@coool000[oool;fMWI0]cLg006g]kNgmoOh>3Ph>3Pbl_;^k^k0[6a/@05YZJV
OGemOGemG5aL@T92008W9bL01D10@4];Bd];BdM7AdQ8B002?Shn00Df=SHb<S8b<S8];Bde=CD00SXj
>P05>c/k?Shn?ShnATI6CDe=009BDU801EQHF7MgMi2@T92@T::RXP02]KFe00F`/;2b/[:j^[Zj^[[1
`L400[jn_P05_Kfm_kno`L71`L71_[jn00:l_;`01[^k^kZj^[Vi^KVi^KRh^;Ng]`:f][H01K6a/Jb/
[:b/[:VYZJJVYP02YJFU00FTY:BQXJ6QXJ6OWinQXJ401J:RXP05X:2PWYjNWIfMWIfMW9bL00>KVi/0
1IZJVYVIVIVIVIRHV9NGU`03UYJF0Y2@T005Rh^;R8R8QHF5QHF5LW9b009TI6@01EYJFTi>CT92@T92
@SLg=`02:b/[00DO7alS8b<S8b<S8b<N7Qh00a/K6`056QXJ61PH61PH5aLG5ADE008C4a<01A8B4Q0@
410@45YJFY2@T002/K6a00GHf=S;bl_;bl_;bl_Jf]X00^GUi@03fm_KemOGemOG01?IfMT<oooo000:
oooo2mWIf@;Lg=`01]kNg]oOgn3Ph>3Ph<_;bk^k^`:a/K401JJVYWemOGemOEaLG492@P029bLW00E0
@41;Bd];Bd]7AdM8B4P00Shn?P05=SHf<S8b<S8b;Bd]=CDe008j>SX01C/k>chn?Shn?TI6ATe=C@02
DU9B00EHF5QgMgN@T92@T92RXZ800[Fe]@05/;2`/[:b^[Zj^[Zj`L7100:n_[h01Kfm_Kno_l71`L71
`Kjn_P02_;bl00Jk^k^j^[Zi^KVi^KVh^;Rg]kL2][Jf00Fa/K6/[:b/[:bYZJVVYZH00ZFUY@05Y:BT
XJ6QXJ6QWinOXJ6Q00FRXZ801J2PX9jNWYfMWIfMWIbLW003Vi^K00FJVYZIVIVIVIVHV9RGUiL00iJF
UP:@T9001H^;RhR8R8F5QHF5QG9bLP02I6AT00EJFUY>CTi2@T92@T8g=cL00R/[:`057alO8b<S8b<S
8b<S7QhN00<K6a/01AXJ6QPH61PH61LG5aDE5@024a<C00DB4Q8@410@411JFUZ@T9000[6a/@05f=SH
bl_;bl_;bl_;f][J00;UiND00m_KfmOGemOGe`0CfMWI3?ooo`002_oooa7IfMT00mSHf=OGemOGe`02
emOG0YZJVP05KFe]DE5A<30`<30`AdM7009>CTh01DM7AdA4A3hn?Shn?SXj>P02=CDe00<a<C4f=SHh
>3P00SPh>08i>CT01Sdm?Clo?d51@D51@D=3@dm?C`9HF5P01EmOGfIVIVIVIW=cLgmoO`02RHV900FC
Ti>EUIFEUIFHV9ROWil00ZBTY004XZ:RXJ6QXJ6QXj>S1:BTY004YJFUYZJVYZJVV9RH0Xf=S@04QhN7
P820R8R8R8R80hb<S005SXj>Shn?T92@T92@TI6A00:BTY85TI6A0Xn?S`06SHf=S8b<RXZ:RXZ:QXJ6
Ph>30X20P005OWinLG5aLG5aJ6QXH61P009IFET01D];Bclo?clo?cDe=BXZ:P029bLW00@R8R8J6QXJ
6QXC4a<35QHF00DC4a<A4A4A4A4?3`l=3@d00P/;2`052PX:7QhN;Bd];Bd]=SHf0090@4001H20P;6a
/MGEeMGEeOclo002g]kN00CBd];IfMWKfm_Kfm/FfMWI3?ooo`002_oooa7IfMT00mSHf=OGemOGe`02
emOG0YZJVP05KFe]DE5A<30`<30`AdM7009>CTh01DM7AdA4A3hn?Shn?SXj>P02=CDe00<a<C4f=SHh
>3P00SPh>08i>CT01Sdm?Clo?d51@D51@D=3@dm?C`9HF5P01EmOGfIVIVIVIW=cLgmoO`02RHV900FC
Ti>EUIFEUIFHV9ROWil00ZBTY004XZ:RXJ6QXJ6QXj>S1:BTY004YJFUYZJVYZJVV9RH0Xf=S@04QhN7
P820R8R8R8R80hb<S005SXj>Shn?T92@T92@TI6A00:BTY85TI6A0Xn?S`06SHf=S8b<RXZ:RXZ:QXJ6
Ph>30X20P005OWinLG5aLG5aJ6QXH61P009IFET01D];Bclo?clo?cDe=BXZ:P029bLW00@R8R8J6QXJ
6QXC4a<35QHF00DC4a<A4A4A4A4?3`l=3@d00P/;2`052PX:7QhN;Bd];Bd]=SHf0090@4001H20P;6a
/MGEeMGEeOclo002g]kN00CBd];IfMWKfm_Kfm/FfMWI3?ooo`002_oooa7IfMT00mSHf=OGemOGe`02
emOG0YZJVP05KFe]DE5A<30`<30`AdM7009>CTh01DM7AdA4A3hn?Shn?SXj>P02=CDe00<a<C4f=SHh
>3P00SPh>08i>CT01Sdm?Clo?d51@D51@D=3@dm?C`9HF5P01EmOGfIVIVIVIW=cLgmoO`02RHV900FC
Ti>EUIFEUIFHV9ROWil00ZBTY004XZ:RXJ6QXJ6QXj>S1:BTY004YJFUYZJVYZJVV9RH0Xf=S@04QhN7
P820R8R8R8R80hb<S005SXj>Shn?T92@T92@TI6A00:BTY85TI6A0Xn?S`06SHf=S8b<RXZ:RXZ:QXJ6
Ph>30X20P005OWinLG5aLG5aJ6QXH61P009IFET01D];Bclo?clo?cDe=BXZ:P029bLW00@R8R8J6QXJ
6QXC4a<35QHF00DC4a<A4A4A4A4?3`l=3@d00P/;2`052PX:7QhN;Bd];Bd]=SHf0090@4001H20P;6a
/MGEeMGEeOclo002g]kN00CBd];IfMWKfm_Kfm/FfMWI3?ooo`002_oooa7IfMT00mSHf=OGemOGe`02
emOG0YZJVP05KFe]DE5A<30`<30`AdM7009>CTh01DM7AdA4A3hn?Shn?SXj>P02=CDe00<a<C4f=SHh
>3P00SPh>08i>CT01Sdm?Clo?d51@D51@D=3@dm?C`9HF5P01EmOGfIVIVIVIW=cLgmoO`02RHV900FC
Ti>EUIFEUIFHV9ROWil00ZBTY004XZ:RXJ6QXJ6QXj>S1:BTY004YJFUYZJVYZJVV9RH0Xf=S@04QhN7
P820R8R8R8R80hb<S005SXj>Shn?T92@T92@TI6A00:BTY85TI6A0Xn?S`06SHf=S8b<RXZ:RXZ:QXJ6
Ph>30X20P005OWinLG5aLG5aJ6QXH61P009IFET01D];Bclo?clo?cDe=BXZ:P029bLW00@R8R8J6QXJ
6QXC4a<35QHF00DC4a<A4A4A4A4?3`l=3@d00P/;2`052PX:7QhN;Bd];Bd]=SHf0090@4001H20P;6a
/MGEeMGEeOclo002g]kN00CBd];IfMWKfm_Kfm/FfMWI3?ooo`002_oooa7IfMT00mSHf=OGemOGe`02
emOG0YZJVP05KFe]DE5A<30`<30`AdM7009>CTh01DM7AdA4A3hn?Shn?SXj>P02=CDe00<a<C4f=SHh
>3P00SPh>08i>CT01Sdm?Clo?d51@D51@D=3@dm?C`9HF5P01EmOGfIVIVIVIW=cLgmoO`02RHV900FC
Ti>EUIFEUIFHV9ROWil00ZBTY004XZ:RXJ6QXJ6QXj>S1:BTY004YJFUYZJVYZJVV9RH0Xf=S@04QhN7
P820R8R8R8R80hb<S005SXj>Shn?T92@T92@TI6A00:BTY85TI6A0Xn?S`06SHf=S8b<RXZ:RXZ:QXJ6
Ph>30X20P005OWinLG5aLG5aJ6QXH61P009IFET01D];Bclo?clo?cDe=BXZ:P029bLW00@R8R8J6QXJ
6QXC4a<35QHF00DC4a<A4A4A4A4?3`l=3@d00P/;2`052PX:7QhN;Bd];Bd]=SHf0090@4001H20P;6a
/MGEeMGEeOclo002g]kN00CBd];IfMWKfm_Kfm/FfMWI3?ooo`002_oooa7IfMT00mSHf=OGemOGe`02
emOG0YZJVP05KFe]DE5A<30`<30`AdM7009>CTh01DM7AdA4A3hn?Shn?SXj>P02=CDe00<a<C4f=SHh
>3P00SPh>08i>CT01Sdm?Clo?d51@D51@D=3@dm?C`9HF5P01EmOGfIVIVIVIW=cLgmoO`02RHV900FC
Ti>EUIFEUIFHV9ROWil00ZBTY004XZ:RXJ6QXJ6QXj>S1:BTY004YJFUYZJVYZJVV9RH0Xf=S@04QhN7
P820R8R8R8R80hb<S005SXj>Shn?T92@T92@TI6A00:BTY85TI6A0Xn?S`06SHf=S8b<RXZ:RXZ:QXJ6
Ph>30X20P005OWinLG5aLG5aJ6QXH61P009IFET01D];Bclo?clo?cDe=BXZ:P029bLW00@R8R8J6QXJ
6QXC4a<35QHF00DC4a<A4A4A4A4?3`l=3@d00P/;2`052PX:7QhN;Bd];Bd]=SHf0090@4001H20P;6a
/MGEeMGEeOclo002g]kN00CBd];IfMWKfm_Kfm/FfMWI3?ooo`002_oooa7IfMT01MgMgN7QhN?Shn?S
hnGUi@02]kNg00FEUIF1PH5YJFUYJFUQHF400UADE005A4A4=3@d?Cdm?Cdm@410008k>c/00cTi>C/k
>cdm?@04?Cdm00I5ADE<C4a@D51@D51EEEEBDU82DE5A00ECDe=DE5ADE5AHF5QKFe/00UeMG@05GemO
FUYJFUYJEeMGEUIF009DE5@00eIFEUQHF5QHF002F5QH0UmOG`05Hf=SIVIVJVYZJVYZGEeM009EEED0
155ADDa<C55ADE5AD@ACDe<015]KFf1PH61PH6ATI09XJ6P00fEUIFATI6EUI@02IFEU0V9RHP06H61P
GemOGEeMGEeMFe]KFEUI0UMGE`05EEEEB4Q8B4Q8?Shn=cLg008_;bl01B`/;2LW9bLW9b4Q8A/K6`02
6QXJ00DH61PD51@D51@A4A4?3`l00P`<30052PX:1`L71`L730`<410@008A4A401A8B4TQ8B71`L71`
L8V9R@02YjNW00Fd];C5aLGKfm_Kfm_`l?000]kNgP03e]KFfMWIfMWI01OIfMT<oooo000:oooo4MWI
f@05gMgMhN7Qhn?Shn?SiNGU00:g]kL01IFEUH61PFUYJFUYJF5QH@02E5AD00E4A4@d=3@m?Cdm?Ce0
@4000S/k>`03>CTi>c/k?Cdm00@m?Cd01TE5ADa<C51@D51@D5EEEE9BDP9ADE401E=CDeADE5ADE5QH
F5]KF`02GEeM00EOGemJFUYJFUYGEeMFEUH00UADE003EUIFF5QHF5QH009HF5P2GemO00ESHf=VIVIZ
JVYZJVYMGEd00UEEE@04DE5AC4a<DE5ADE5A15=CD`04Fe]KH61PH61PI6AT0VQXJ003IFEUI6ATIFEU
009UIFD2HV9R00IPH61OGemMGEeMGEeKFe]IFET2EeMG00EEEEE8B4Q8B4Pn?Shg=cL00Rl_;`05;2`/
9bLW9bLW8B4Q6a/K008J6QX01APH61@D51@D514A4@l?3`0230`<00D:2PX71`L71`L<30`@41000Q4A
4@054Q8BB4Q8L71`L71`RHV900:WYjL01KBd]<G5aM_Kfm_Kfo3`l002g]kN00?Fe]KIfMWIfMT05mWI
f@coool000[ooolAfMWI00GMgMgQhN7Shn?Shn?UiND00[Ng]`05UIFEPH61JFUYJFUYHF5Q009DE5@0
1DA4A3@d=3dm?Cdm?D10@002>c/k00<i>CTk>c/m?Cd013dm?@06ADE5C4a<D51@D51@EEEEDU9B0U5A
D@05De=CE5ADE5ADF5QHFe]K009MGEd01EmOGeYJFUYJFUMGEeIFEP02E5AD00=FEUIHF5QHF5P00UQH
F09OGel01F=SHfIVIVYZJVYZJUeMG@02EEEE00AADE5<C4aADE5ADE44De=C00AKFe]PH61PH61TI6@2
J6QX00=UIFETI6AUIFD00VEUI@9RHV801V1PH5mOGeeMGEeMGE]KFeUIF@9GEeL01EEEEDQ8B4Q8B3hn
?SLg=`02;bl_00D/;2`W9bLW9bLQ8B4K6a/00QXJ6P0561PH51@D51@D4A4A3`l?008<30`01@X:2PL7
1`L71``<310@40024A4A00DB4Q98B4Q`L71`L729RHT00ZNWY`05];BdaLG5fm_Kfm_Kl?3`00;Ng]h0
0mKFe]WIfMWIf@0GfMWI3?ooo`002_oooa7IfMT01MgMgN7QhN?Shn?ShnGUi@02]kNg00FEUIF1PH5Y
JFUYJFUQHF400UADE005A4A4=3@d?Cdm?Cdm@410008k>c/00cTi>C/k>cdm?@04?Cdm00I5ADE<C4a@
D51@D51EEEEBDU82DE5A00ECDe=DE5ADE5AHF5QKFe/00UeMG@05GemOFUYJFUYJEeMGEUIF009DE5@0
0eIFEUQHF5QHF002F5QH0UmOG`05Hf=SIVIVJVYZJVYZGEeM009EEED0155ADDa<C55ADE5AD@ACDe<0
15]KFf1PH61PH6ATI09XJ6P00fEUIFATI6EUI@02IFEU0V9RHP06H61PGemOGEeMGEeMFe]KFEUI0UMG
E`05EEEEB4Q8B4Q8?Shn=cLg008_;bl01B`/;2LW9bLW9b4Q8A/K6`026QXJ00DH61PD51@D51@A4A4?
3`l00P`<30052PX:1`L71`L730`<410@008A4A401A8B4TQ8B71`L71`L8V9R@02YjNW00Fd];C5aLGK
fm_Kfm_`l?000]kNgP03e]KFfMWIfMWI01OIfMT<oooo000:oooo4MWIf@05gMgMhN7Qhn?Shn?SiNGU
00:g]kL01IFEUH61PFUYJFUYJF5QH@02E5AD00E4A4@d=3@m?Cdm?Ce0@4000S/k>`03>CTi>c/k?Cdm
00@m?Cd01TE5ADa<C51@D51@D5EEEE9BDP9ADE401E=CDeADE5ADE5QHF5]KF`02GEeM00EOGemJFUYJ
FUYGEeMFEUH00UADE003EUIFF5QHF5QH009HF5P2GemO00ESHf=VIVIZJVYZJVYMGEd00UEEE@04DE5A
C4a<DE5ADE5A15=CD`04Fe]KH61PH61PI6AT0VQXJ003IFEUI6ATIFEU009UIFD2HV9R00IPH61OGemM
GEeMGEeKFe]IFET2EeMG00EEEEE8B4Q8B4Pn?Shg=cL00Rl_;`05;2`/9bLW9bLW8B4Q6a/K008J6QX0
1APH61@D51@D514A4@l?3`0230`<00D:2PX71`L71`L<30`@41000Q4A4@054Q8BB4Q8L71`L71`RHV9
00:WYjL01KBd]<G5aM_Kfm_Kfo3`l002g]kN00?Fe]KIfMWIfMT05mWIf@coool000[ooolAfMWI00GK
fm_Lg=cMgMgMgMgNg]h00]3@d005a/K6`<30^[Zj^[ZjRXZ:009UIFD01Da<C2l_;d92@T92@TQ8B002
@T9200Dn?Si7AdM=CDe=CDe?Cdl00U=CD`03D51@Cdm?D51@009@D50014m?Cdi>CTi>CTi>CP9=CDd0
1DY:BTQ8B4I6ATI6ATE5A@02@T9200=0@40m?Cdk>c/013/k>`03>SXj>CTi>CTi008i>CT3>3Ph00Dd
=3@a<C4a<C4_;bl/;2`00R/[:`05:RXZ:2PX:2PX9RHV:BTY008Z:RX01B/[:b`/;2`/;2d];Bh^;P02
;bl_00<`<30^;Rh^;Rh00R`/;08[:b/01BXZ:RTY:BTY:BTY:BPX:0029BDU00DS8b<R8R8P820P820L
71`00QPH60055ADE4Q8B4A4A4A4A3`l?008=3@d01@/;2`l?3a8B4Q8B4Q<C4`0251@D00H/;2`o?cm;
Bd];Bd]IFEV<S8`2]KFe00GCdm?emOGemOGLg=cCdm<00]WIf@03fm_KfMWIfMWI01[IfMT<oooo000:
oooo4MWIf@05fm_Kg=cLgMgMgMgMg]kN00;@d=001LK6a/30`;Zj^[Zj^XZ:RP02IFEU00E<C4`_;bm2
@T92@T98B4P00T92@P05?ShnAdM7CDe=CDe=Cdm?009CDe<00e1@D4m?Ce1@D002D51@00A?Cdm>CTi>
CTi>CTh2CDe=00E:BTY8B4Q6ATI6ATI5ADD00T92@P03@410?Cdm>c/k00@k>c/00cXj>STi>CTi>@02
>CTi0cPh>005=3@d<C4a<C4a;bl_;2`/008[:b/01BXZ:RPX:2PX:2HV9RTY:@02:RXZ00D[:b//;2`/
;2`];Bd^;Rh00Rl_;`03<30`;Rh^;Rh^008/;2`2:b/[00DZ:RXY:BTY:BTY:BTX:2P00RDU9@058b<S
8R8R820P820P71`L008H61P01ADE5A8B4Q4A4A4A4@l?3`023@d=00D;2`/?3`lB4Q8B4Q8C4a<00Q@D
5006;2`/?cloBd];Bd];FEUIS8b<0[Fe]@05dm?CmOGemOGeg=cLdm?C00;IfMT00m_KfmWIfMWIf@0J
fMWI3?ooo`002_oooa7IfMT01M_KfmcLg=gMgMgMgMkNgP02d=3@00G6a/K0`<2j^[Zj^[Z:RXX00VEU
I@05C4a<;bl_@T92@T92B4Q80092@T801Chn?TM7Ade=CDe=CDm?C`02De=C00=@D51?Cdm@D5000U1@
D004Cdm?CTi>CTi>CTi>0Te=C@05BTY:B4Q8ATI6ATI6ADE50092@T800d10@3dm?C/k>`04>c/k00<j
>SXi>CTi>CT00STi>@<h>3P01C@d=34a<C4a<Bl_;b`/;002:b/[00DZ:RXX:2PX:2PV9RHY:BT00RXZ
:P05:b/[;2`/;2`/;Bd];Rh^008_;bl00c0`<2h^;Rh^;P02;2`/0R/[:`05:RXZ:BTY:BTY:BTY:2PX
008U9BD01B<S8b8R8R0P820P81`L700261PH00DE5ADB4Q8A4A4A4A4?3`l00Pd=3@052`/;3`l?4Q8B
4Q8B4a<C008D51@01R`/;3lo?d];Bd];BeUIFHb<S0:e]KD01M?CdoGemOGemMcLg=?Cd`02fMWI00?K
fm_IfMWIfMT06]WIf@coool000[ooolAfMWI00GKfm_Lg=cMgMgMgMgNg]h00]3@d005a/K6`<30^[Zj
^[ZjRXZ:009UIFD01Da<C2l_;d92@T92@TQ8B002@T9200Dn?Si7AdM=CDe=CDe?Cdl00U=CD`03D51@
Cdm?D51@009@D50014m?Cdi>CTi>CTi>CP9=CDd01DY:BTQ8B4I6ATI6ATE5A@02@T9200=0@40m?Cdk
>c/013/k>`03>SXj>CTi>CTi008i>CT3>3Ph00Dd=3@a<C4a<C4_;bl/;2`00R/[:`05:RXZ:2PX:2PX
9RHV:BTY008Z:RX01B/[:b`/;2`/;2d];Bh^;P02;bl_00<`<30^;Rh^;Rh00R`/;08[:b/01BXZ:RTY
:BTY:BTY:BPX:0029BDU00DS8b<R8R8P820P820L71`00QPH60055ADE4Q8B4A4A4A4A3`l?008=3@d0
1@/;2`l?3a8B4Q8B4Q<C4`0251@D00H/;2`o?cm;Bd];Bd]IFEV<S8`2]KFe00GCdm?emOGemOGLg=cC
dm<00]WIf@03fm_KfMWIfMWI01[IfMT<oooo000:oooo4MWIf@05fm_Kg=cLgMgMgMgMg]kN00;@d=00
1LK6a/30`;Zj^[Zj^XZ:RP02IFEU00E<C4`_;bm2@T92@T98B4P00T92@P05?ShnAdM7CDe=CDe=Cdm?
009CDe<00e1@D4m?Ce1@D002D51@00A?Cdm>CTi>CTi>CTh2CDe=00E:BTY8B4Q6ATI6ATI5ADD00T92
@P03@410?Cdm>c/k00@k>c/00cXj>STi>CTi>@02>CTi0cPh>005=3@d<C4a<C4a;bl_;2`/008[:b/0
1BXZ:RPX:2PX:2HV9RTY:@02:RXZ00D[:b//;2`/;2`];Bd^;Rh00Rl_;`03<30`;Rh^;Rh^008/;2`2
:b/[00DZ:RXY:BTY:BTY:BTX:2P00RDU9@058b<S8R8R820P820P71`L008H61P01ADE5A8B4Q4A4A4A
4@l?3`023@d=00D;2`/?3`lB4Q8B4Q8C4a<00Q@D5006;2`/?cloBd];Bd];FEUIS8b<0[Fe]@05dm?C
mOGemOGeg=cLdm?C00;IfMT00m_KfmWIfMWIf@0JfMWI3?ooo`002_oooa7IfMT01M_KfmcLg=gMgMgM
gMkNgP02d=3@00G6a/K0`<2j^[Zj^[Z:RXX00VEUI@05C4a<;bl_@T92@T92B4Q80092@T801Chn?TM7
Ade=CDe=CDm?C`02De=C00=@D51?Cdm@D5000U1@D004Cdm?CTi>CTi>CTi>0Te=C@05BTY:B4Q8ATI6
ATI6ADE50092@T800d10@3dm?C/k>`04>c/k00<j>SXi>CTi>CT00STi>@<h>3P01C@d=34a<C4a<Bl_
;b`/;002:b/[00DZ:RXX:2PX:2PV9RHY:BT00RXZ:P05:b/[;2`/;2`/;Bd];Rh^008_;bl00c0`<2h^
;Rh^;P02;2`/0R/[:`05:RXZ:BTY:BTY:BTY:2PX008U9BD01B<S8b8R8R0P820P81`L700261PH00DE
5ADB4Q8A4A4A4A4?3`l00Pd=3@052`/;3`l?4Q8B4Q8B4a<C008D51@01R`/;3lo?d];Bd];BeUIFHb<
S0:e]KD01M?CdoGemOGemMcLg=?Cd`02fMWI00?Kfm_IfMWIfMT06]WIf@coool000[ooolFfMWI0]gM
g@05h>3Ph^;Ri>CTi>CT][Jf00:EUID01H61PFUYJF5QHF5QHEADE002@d=300@d=3A1@D56ATI6ATH3
A4A400I7AdM:BTY<C4a<C4a>CTi7AdL2@d=300E1@D4n?Shn?Shi>CTe=CD00S4a<@03;Bd]<C4a<C4a
00@c<c<01C0`<2l_;bl_;bh^;Rd];@02:BTY00@U9BDS8b<P820P82038R8R00DQ8B4P820M7AdM7AdJ
6QX00QPH60035QHF6QXJ71`L008L71`37AdM00<L71`M7AdM7Ad01adM7@056a/K6ATI61PH61PH5aLG
008E5AD01A<C4a4A4@l?3`l?3a4A4@034Q8B00@C4a<D51@D51@F5QH25aLG00DH61PX:2Pe=CDe=CDm
?Cd00TM7A`06OgmoZj^[b/[:b/[:k>c/emOG0]7Ad@05fMWIg]kNg]kNf][Jf=SH01oIfMT<oooo000:
oooo5]WIf@;MgMd01N3Ph>;Rh^CTi>CTi;Jf]P02UIFE00F1PH5YJFUQHF5QHF5DE5@00T=3@`04=3@d
@D51ATI6ATI60dA4A006AdM7BTY:C4a<C4a<CTi>AdM70T=3@`05@D51?Shn?Shn>CTi=CDe008a<C40
0bd];C4a<C4a<@04<c<c00D`<30_;bl_;bl^;Rh];Bd00RTY:@049BDU8b<S820P820P0b8R8P058B4Q
820P7AdM7AdM6QXJ008H61P00aHF5QXJ6Q`L700271`L0adM7@0371`L7AdM7AdM00LM7Ad01A/K6aTI
6APH61PH61LG5`025ADE00DC4a<A4A4?3`l?3`lA4A400a8B4P044a<C51@D51@D5QHF0QLG5`0561PH
:2PX=CDe=CDe?Cdm0097AdL01WmoOj^[Zl[:b/[:b^c/k=OGe`;AdM401MWIfMkNg]kNg][Jf]SHf00O
fMWI3?ooo`002_oooaKIfMT2gMgM00GPh>3Rh^;Ti>CTi>Bf][H00YFEU@05PH61JFUYHF5QHF5QE5AD
0093@d<013@d=451@DI6ATI6AP=4A4@01TM7AdY:BTa<C4a<C4i>CTM7A`93@d<01D51@Chn?Shn?STi
>CDe=@02<C4a00<];Bda<C4a<C4013<c<`05<30`;bl_;bl_;Rh^;Bd]008Y:BT012DU9B<S8b0P820P
80<R8R801B4Q8B0P81dM7AdM7AXJ6P0261PH00<F5QHJ6QXL71`00Q`L70<M7Ad00a`L71dM7AdM7@07
7AdM00DK6a/I6ATH61PH61PG5aL00QDE5@054a<C4A4A3`l?3`l?4A4A00<B4Q8011<C4a@D51@D51HF
5P8G5aL01APH62PX:3De=CDe=Cdm?@02AdM700IoOgn[Zj_:b/[:b/[/k>cGemL2dM7A00GIfMWNg]kN
g]kJf][Hf=P07mWIf@coool000[ooolFfMWI0]gMg@05h>3Ph^;Ri>CTi>CT][Jf00:EUID01H61PFUY
JF5QHF5QHEADE002@d=300@d=3A1@D56ATI6ATH3A4A400I7AdM:BTY<C4a<C4a>CTi7AdL2@d=300E1
@D4n?Shn?Shi>CTe=CD00S4a<@03;Bd]<C4a<C4a00@c<c<01C0`<2l_;bl_;bh^;Rd];@02:BTY00@U
9BDS8b<P820P82038R8R00DQ8B4P820M7AdM7AdJ6QX00QPH60035QHF6QXJ71`L008L71`37AdM00<L
71`M7AdM7Ad01adM7@056a/K6ATI61PH61PH5aLG008E5AD01A<C4a4A4@l?3`l?3a4A4@034Q8B00@C
4a<D51@D51@F5QH25aLG00DH61PX:2Pe=CDe=CDm?Cd00TM7A`06OgmoZj^[b/[:b/[:k>c/emOG0]7A
d@05fMWIg]kNg]kNf][Jf=SH01oIfMT<oooo000:oooo5]WIf@;MgMd01N3Ph>;Rh^CTi>CTi;Jf]P02
UIFE00F1PH5YJFUQHF5QHF5DE5@00T=3@`04=3@d@D51ATI6ATI60dA4A006AdM7BTY:C4a<C4a<CTi>
AdM70T=3@`05@D51?Shn?Shn>CTi=CDe008a<C400bd];C4a<C4a<@04<c<c00D`<30_;bl_;bl^;Rh]
;Bd00RTY:@049BDU8b<S820P820P0b8R8P058B4Q820P7AdM7AdM6QXJ008H61P00aHF5QXJ6Q`L7002
71`L0adM7@0371`L7AdM7AdM00LM7Ad01A/K6aTI6APH61PH61LG5`025ADE00DC4a<A4A4?3`l?3`lA
4A400a8B4P044a<C51@D51@D5QHF0QLG5`0561PH:2PX=CDe=CDe?Cdm0097AdL01WmoOj^[Zl[:b/[:
b^c/k=OGe`;AdM401MWIfMkNg]kNg][Jf]SHf00OfMWI3?ooo`002_oooaSIfMT4f][J00GHf=SGemOG
emOGemOFe]H00ZBTY005OgmoJ6QXJ6QXCDe=De=C009@D50014A4A3/k>c/k>dI6AP=<C4`01Di>CTM7
Ad92@T92@T10@002?Cdm00Dc<c</;2`V9RHV9RHO7al00R8R8P048b<S8B4Q820P820P0alO7`067QhN
7AdM71`L71`L6QXJ6ATI0QPH60DI6AT25aLG00DF5QHE5ADE5ADD51@H61P00Q`L70057AdM7alO7alO
9RHV:b/[008_;bl01C@d=2XZ:RXZ:RDU9B<S8`02820P00DO7alN7QhL71`L71`K6a/00QhN7P05820P
8B4Q8R8R8R8R8b<S008U9BD01BHV9RPX:2/[:b/[:bd];@02;bl_00Da<C5WIfN?Shn?ShnYZJT00/O7
a`06aLG5bl_;f][Jf][JinOWg=cL0]OGebCIfMT<oooo000:oooo6=WIf@CJf]X01MSHf=OGemOGemOG
emKFeP02Y:BT00EoOgmXJ6QXJ6Q=CDeCDe<00U1@D004A4A4>c/k>c/kATI60da<C005CTi>AdM7@T92
@T92@410008m?Cd01C<c<b`/;2HV9RHV9QlO7`028R8R00@S8b<Q8B4P820P82037alO00HN7QhM7AdL
71`L71`J6QXI6AT261PH1ATI6@8G5aL01AHF5QDE5ADE5A@D51PH600271`L00DM7AdO7alO7alV9RH[
:b/00Rl_;`05=3@d:RXZ:RXZ9BDU8b<S008P82001AlO7ahN7Q`L71`L71/K6`027QhN00DP820Q8B4R
8R8R8R8S8b<00RDU9@059RHV:2PX:b/[:b/[;Bd]008_;bl01C4a<FMWIhn?Shn?SjVYZ@02alO700K5
aLG;bl_Jf][Jf][WinOLg=`2emOG9=WIf@coool000[ooolHfMWI1=[JfP05f=SHemOGemOGemOGe]KF
00:TY:@01GmoOfQXJ6QXJ4e=CE=CD`02D51@00A4A4@k>c/k>c]6ATH3C4a<00E>CTi7AdM2@T92@T90
@4000Sdm?@05<c<c;2`/9RHV9RHV7alO008R8R8012<S8b4Q8B0P820P80<O7al01QhN7QdM7A`L71`L
71XJ6QTI6@8H61P56ATI0QLG5`055QHF5ADE5ADE51@D61PH008L71`01AdM7AlO7alO7bHV9R/[:`02
;bl_00Dd=3@Z:RXZ:RXU9BDS8b<00R0P80057alO7QhN71`L71`L6a/K008N7Qh01B0P824Q8B8R8R8R
8R<S8`029BDU00DV9RHX:2P[:b/[:b/];Bd00Rl_;`05<C4aIfMWShn?Shn?ZJVY00;7alL01/G5aL_;
bm[Jf][Jf^OWimcLg0;GemLTfMWI3?ooo`002_oooaSIfMT4f][J00GHf=SGemOGemOGemOFe]H00ZBT
Y005OgmoJ6QXJ6QXCDe=De=C009@D50014A4A3/k>c/k>dI6AP=<C4`01Di>CTM7Ad92@T92@T10@002
?Cdm00Dc<c</;2`V9RHV9RHO7al00R8R8P048b<S8B4Q820P820P0alO7`067QhN7AdM71`L71`L6QXJ
6ATI0QPH60DI6AT25aLG00DF5QHE5ADE5ADD51@H61P00Q`L70057AdM7alO7alO9RHV:b/[008_;bl0
1C@d=2XZ:RXZ:RDU9B<S8`02820P00DO7alN7QhL71`L71`K6a/00QhN7P05820P8B4Q8R8R8R8R8b<S
008U9BD01BHV9RPX:2/[:b/[:bd];@02;bl_00Da<C5WIfN?Shn?ShnYZJT00/O7a`06aLG5bl_;f][J
f][JinOWg=cL0]OGebCIfMT<oooo000:oooo6=WIf@CJf]X01MSHf=OGemOGemOGemKFeP02Y:BT00Eo
OgmXJ6QXJ6Q=CDeCDe<00U1@D004A4A4>c/k>c/kATI60da<C005CTi>AdM7@T92@T92@410008m?Cd0
1C<c<b`/;2HV9RHV9QlO7`028R8R00@S8b<Q8B4P820P82037alO00HN7QhM7AdL71`L71`J6QXI6AT2
61PH1ATI6@8G5aL01AHF5QDE5ADE5A@D51PH600271`L00DM7AdO7alO7alV9RH[:b/00Rl_;`05=3@d
:RXZ:RXZ9BDU8b<S008P82001AlO7ahN7Q`L71`L71/K6`027QhN00DP820Q8B4R8R8R8R8S8b<00RDU
9@059RHV:2PX:b/[:b/[;Bd]008_;bl01C4a<FMWIhn?Shn?SjVYZ@02alO700K5aLG;bl_Jf][Jf][W
inOLg=`2emOG9=WIf@coool000[ooolHfMWI1=[JfP05f=SHemOGemOGemOGe]KF00:TY:@01GmoOfQX
J6QXJ4e=CE=CD`02D51@00A4A4@k>c/k>c]6ATH3C4a<00E>CTi7AdM2@T92@T90@4000Sdm?@05<c<c
;2`/9RHV9RHV7alO008R8R8012<S8b4Q8B0P820P80<O7al01QhN7QdM7A`L71`L71XJ6QTI6@8H61P5
6ATI0QLG5`055QHF5ADE5ADE51@D61PH008L71`01AdM7AlO7alO7bHV9R/[:`02;bl_00Dd=3@Z:RXZ
:RXU9BDS8b<00R0P80057alO7QhN71`L71`L6a/K008N7Qh01B0P824Q8B8R8R8R8R<S8`029BDU00DV
9RHX:2P[:b/[:b/];Bd00Rl_;`05<C4aIfMWShn?Shn?ZJVY00;7alL01/G5aL_;bm[Jf][Jf^OWimcL
g0;GemLTfMWI3?ooo`002_oooacIfMT01M[Jf]_Kfm_Kfm_KfmcLg002emOG00GCdm?Bd];Bd];?clnR
XZ800X61P@05Jf][DU9BDU9BEUIFDe=C0098B4P01Clo?dm?CeUIFEUIFE]KF`02H61P00E;Bd/n?Shg
=cLg=cL^;Rh00Rl_;`04;Bd]:BTY9BDU9BDU0bLW9`069RHV9BDU8B4Q8B4Q7QhN71`L0QXJ6P@K6a/0
0aXJ6Q`L71`L70037AdM0QhN7P8O7al3820P00DZ:RXa<C4f=SHf=SHk>c/00SHf=P8e=CD2=SHf13De
=@<d=3@4<c<c00Dh>3Pk>c/k>c/m?Ce0@4000V=SH`05OWinT92@T92@Y:BT][Jf00;8b<P01M_Kfng]
kNg]kMgMgMKFeP0ZfMWI3?ooo`002_oooacIfMT01M[Jf]_Kfm_Kfm_KfmcLg002emOG00GCdm?Bd];B
d];?clnRXZ800X61P@05Jf][DU9BDU9BEUIFDe=C0098B4P01Clo?dm?CeUIFEUIFE]KF`02H61P00E;
Bd/n?Shg=cLg=cL^;Rh00Rl_;`04;Bd]:BTY9BDU9BDU0bLW9`069RHV9BDU8B4Q8B4Q7QhN71`L0QXJ
6P@K6a/00aXJ6Q`L71`L70037AdM0QhN7P8O7al3820P00DZ:RXa<C4f=SHf=SHk>c/00SHf=P8e=CD2
=SHf13De=@<d=3@4<c<c00Dh>3Pk>c/k>c/m?Ce0@4000V=SH`05OWinT92@T92@Y:BT][Jf00;8b<P0
1M_Kfng]kNg]kMgMgMKFeP0ZfMWI3?ooo`002_oooacIfMT01M[Jf]_Kfm_Kfm_KfmcLg002emOG00GC
dm?Bd];Bd];?clnRXZ800X61P@05Jf][DU9BDU9BEUIFDe=C0098B4P01Clo?dm?CeUIFEUIFE]KF`02
H61P00E;Bd/n?Shg=cLg=cL^;Rh00Rl_;`04;Bd]:BTY9BDU9BDU0bLW9`069RHV9BDU8B4Q8B4Q7QhN
71`L0QXJ6P@K6a/00aXJ6Q`L71`L70037AdM0QhN7P8O7al3820P00DZ:RXa<C4f=SHf=SHk>c/00SHf
=P8e=CD2=SHf13De=@<d=3@4<c<c00Dh>3Pk>c/k>c/m?Ce0@4000V=SH`05OWinT92@T92@Y:BT][Jf
00;8b<P01M_Kfng]kNg]kMgMgMKFeP0ZfMWI3?ooo`002_oooacIfMT01M[Jf]_Kfm_Kfm_KfmcLg002
emOG00GCdm?Bd];Bd];?clnRXZ800X61P@05Jf][DU9BDU9BEUIFDe=C0098B4P01Clo?dm?CeUIFEUI
FE]KF`02H61P00E;Bd/n?Shg=cLg=cL^;Rh00Rl_;`04;Bd]:BTY9BDU9BDU0bLW9`069RHV9BDU8B4Q
8B4Q7QhN71`L0QXJ6P@K6a/00aXJ6Q`L71`L70037AdM0QhN7P8O7al3820P00DZ:RXa<C4f=SHf=SHk
>c/00SHf=P8e=CD2=SHf13De=@<d=3@4<c<c00Dh>3Pk>c/k>c/m?Ce0@4000V=SH`05OWinT92@T92@
Y:BT][Jf00;8b<P01M_Kfng]kNg]kMgMgMKFeP0ZfMWI3?ooo`002_oooacIfMT01M[Jf]_Kfm_Kfm_K
fmcLg002emOG00GCdm?Bd];Bd];?clnRXZ800X61P@05Jf][DU9BDU9BEUIFDe=C0098B4P01Clo?dm?
CeUIFEUIFE]KF`02H61P00E;Bd/n?Shg=cLg=cL^;Rh00Rl_;`04;Bd]:BTY9BDU9BDU0bLW9`069RHV
9BDU8B4Q8B4Q7QhN71`L0QXJ6P@K6a/00aXJ6Q`L71`L70037AdM0QhN7P8O7al3820P00DZ:RXa<C4f
=SHf=SHk>c/00SHf=P8e=CD2=SHf13De=@<d=3@4<c<c00Dh>3Pk>c/k>c/m?Ce0@4000V=SH`05OWin
T92@T92@Y:BT][Jf00;8b<P01M_Kfng]kNg]kMgMgMKFeP0ZfMWI3?ooo`002_ooobSIfMT3f=SH0]OG
e`06/k>cV9RHQhN7QhN7Lg=cL71`0VUYJ@05GEeMDU9BDU9BGUiNI6AT009SHf<01FEUIEaLG5aLG5IF
EU=CD`03Cdm?0Ti>CP03C4a<BTY:Bd];009;Bd/3BTY:00E4A4A0@410@40m?Cdj>SX00Slo?`05@D51
@T92@T92@d=3AdM7009:BTX014a<C4m?Cdm?Cd];B`=8B4P7AdM700A9BDU:BTY;Bd];Bd/3C4a<0Te=
C@9>CTh01GIfMYBDU9BDU:NWYkbl_002`/;200G<c<cJf][Jf][WinOLg=`00]OGeboIfMT<oooo000:
oooo:=WIf@?Hf=P2emOG00Jc/k>HV9R7QhN7QhMcLg=`L702JFUY00EMGEeBDU9BDU9NGUiTI6@00V=S
H`05IFEUG5aLG5aLEUIFDe=C00=?Cdl2CTi>00=<C4a:BTY;Bd/00T];B`=:BTX01DA4A410@410@3dm
?CXj>P02?clo00E1@D52@T92@T93@d=7AdL00TY:BP04C4a<Cdm?Cdm?Bd];0dQ8B0M7AdL014U9BDY:
BT];Bd];B`=<C4`2CDe=0Ti>CP05MWIfU9BDU9BDYjNW_;bl00;2`/801Lc<c=[Jf][Jf^OWimcLg002
emOG;mWIf@coool000[ooolXfMWI0mSHf0;GemL01[>c/iRHV8N7QhN7Qg=cLg1`L09YJFT01EeMGE9B
DU9BDUiNGVATI002Hf=S00EUIFELG5aLG5aFEUICDe<00dm?C`9>CTh00da<C4Y:BT];B`02Bd];0dY:
BP05A4A4@410@410?Cdm>SXj008o?cl01D51@D92@T92@T=3@dM7A`02BTY:00A<C4a?Cdm?Cdm;Bd/3
B4Q81dM7A`04BDU9BTY:Bd];Bd];0da<C09=CDd2CTi>00EfMWJDU9BDU9BWYjNl_;`00/;2`P05c<c<
f][Jf][JinOWg=cL00;GemL_fMWI3?ooo`002_ooobSIfMT3f=SH0]OGe`06/k>cV9RHQhN7QhN7Lg=c
L71`0VUYJ@05GEeMDU9BDU9BGUiNI6AT009SHf<01FEUIEaLG5aLG5IFEU=CD`03Cdm?0Ti>CP03C4a<
BTY:Bd];009;Bd/3BTY:00E4A4A0@410@40m?Cdj>SX00Slo?`05@D51@T92@T92@d=3AdM7009:BTX0
14a<C4m?Cdm?Cd];B`=8B4P7AdM700A9BDU:BTY;Bd];Bd/3C4a<0Te=C@9>CTh01GIfMYBDU9BDU:NW
Ykbl_002`/;200G<c<cJf][Jf][WinOLg=`00]OGeboIfMT<oooo000:oooo:=WIf@?Hf=P2emOG00Jc
/k>HV9R7QhN7QhMcLg=`L702JFUY00EMGEeBDU9BDU9NGUiTI6@00V=SH`05IFEUG5aLG5aLEUIFDe=C
00=?Cdl2CTi>00=<C4a:BTY;Bd/00T];B`=:BTX01DA4A410@410@3dm?CXj>P02?clo00E1@D52@T92
@T93@d=7AdL00TY:BP04C4a<Cdm?Cdm?Bd];0dQ8B0M7AdL014U9BDY:BT];Bd];B`=<C4`2CDe=0Ti>
CP05MWIfU9BDU9BDYjNW_;bl00;2`/801Lc<c=[Jf][Jf^OWimcLg002emOG;mWIf@coool000[ooolX
fMWI0mSHf0;GemL01[>c/iRHV8N7QhN7Qg=cLg1`L09YJFT01EeMGE9BDU9BDUiNGVATI002Hf=S00EU
IFELG5aLG5aFEUICDe<00dm?C`9>CTh00da<C4Y:BT];B`02Bd];0dY:BP05A4A4@410@410?Cdm>SXj
008o?cl01D51@D92@T92@T=3@dM7A`02BTY:00A<C4a?Cdm?Cdm;Bd/3B4Q81dM7A`04BDU9BTY:Bd];
Bd];0da<C09=CDd2CTi>00EfMWJDU9BDU9BWYjNl_;`00/;2`P05c<c<f][Jf][JinOWg=cL00;GemL_
fMWI3?ooo`002_ooobgIfMT2f][J0m_Kf`04d=3@b<S8b<S8`l?30[jn_P05Zj^[W9bLT92@T92@Q8B4
00:=SHd01I6ATHn?Shj>SXj>SXb<S002RXZ:00J8R8R6QXInOWinOWigMgMcLg<2KFe]0g1`L005KVi^
KFe]JFUYJFUYIVIV009SHf<2HF5Q0V1PH004GemOGUiNGUiNH61P0f5QH@03HV9RH61PH61P009OGel2
GUiN00EdM7B3Ph><S8b<S8bGUiL00ZZZZP04^[Zjb<S8emOGemOG0m?Cd`05fMWIg]kNf][Jf][Jf=SH
03GIfMT<oooo000:oooo;MWIf@;Jf]X3fm_K00C@d=38b<S8b<S3`l<2_[jn00F[Zj^LW9b@T92@T924
Q8@00Xf=S@05TI6AShn?SXj>SXj>S8b<00::RXX01XR8R8J6QWinOWinOWMgMg=cL`9]KFd3L71`00E^
KVi]KFeYJFUYJFUVIVH00V=SH`9QHF42H61P00AOGemNGUiNGUiPH603HF5Q00=RHV9PH61PH6000UmO
G`9NGUh01GAdM8>3Phb<S8b<S9NGU`02ZZZZ00Bj^[[8b<SGemOGemL3dm?C00GIfMWNg]kJf][Jf][H
f=P0=MWIf@coool000[oool]fMWI0][JfP?Kfm/01=3@d<S8b<S8b<?3``:n_[h01J^[ZibLW92@T92@
T8B4Q002SHf=00FATI6?Shn>SXj>SXj<S8`00XZ:RP06R8R8QXJ6OWinOWinMgMgLg=c0Ve]K@=`L700
1Fi^KVe]KFUYJFUYJFIVIP02Hf=S0V5QH@9PH60015mOGeiNGUiNGV1PH0=QHF400f9RHV1PH61PH002
GemO0UiNGP05M7AdPh>3S8b<S8b<UiNG00:ZZZX01;Zj^/S8b=OGemOGe`?Cdm<01MWIfMkNg][Jf][J
f]SHf00efMWI3?ooo`002_ooobgIfMT2f][J0m_Kf`04d=3@b<S8b<S8`l?30[jn_P05Zj^[W9bLT92@
T92@Q8B400:=SHd01I6ATHn?Shj>SXj>SXb<S002RXZ:00J8R8R6QXInOWinOWigMgMcLg<2KFe]0g1`
L005KVi^KFe]JFUYJFUYIVIV009SHf<2HF5Q0V1PH004GemOGUiNGUiNH61P0f5QH@03HV9RH61PH61P
009OGel2GUiN00EdM7B3Ph><S8b<S8bGUiL00ZZZZP04^[Zjb<S8emOGemOG0m?Cd`05fMWIg]kNf][J
f][Jf=SH03GIfMT<oooo000:oooo;MWIf@;Jf]X3fm_K00C@d=38b<S8b<S3`l<2_[jn00F[Zj^LW9b@
T92@T924Q8@00Xf=S@05TI6AShn?SXj>SXj>S8b<00::RXX01XR8R8J6QWinOWinOWMgMg=cL`9]KFd3
L71`00E^KVi]KFeYJFUYJFUVIVH00V=SH`9QHF42H61P00AOGemNGUiNGUiPH603HF5Q00=RHV9PH61P
H6000UmOG`9NGUh01GAdM8>3Phb<S8b<S9NGU`02ZZZZ00Bj^[[8b<SGemOGemL3dm?C00GIfMWNg]kJ
f][Jf][Hf=P0=MWIf@coool000[oool7f=SH?=WIf@05f=SHemOGemOGemOGe]KF00;De=@01M7AdM3@
d<k>c/k>c/W9b@02a/K600G2`/:o_knl_;bl_;bj^[X00[Ng]`03];Bd^;Rh^k^k00:k^k/2_Kfm00Fj
^[Zh^;Rg]kNg]kNf][H00/?3``06c<c<d];Bf=SHf=SHe]KFemOG0]WIf@03fm_KfMWIfMWI047IfMT<
oooo000:oooo1mSHf3cIfMT01MSHf=OGemOGemOGemKFeP02e=CD00GAdM7@d=3>c/k>c/k9bLT00/K6
aP05`/;2_kno_;bl_;bl^[Zj00:g]kL00kBd];Rh^;^k^`02^k^k0[fm_@05^[Zj^;Rh]kNg]kNg][Jf
00;3`l<01/c<c=;Bd]SHf=SHf=KFe]OGe`;IfMT00m_KfmWIfMWIf@11fMWI3?ooo`002_ooo`OHf=Pl
fMWI00GHf=SGemOGemOGemOFe]H00]CDe005dM7Ad=3@c/k>c/k>bLW900;6a/H01L;2`[no_kbl_;bl
_;Zj^P02]kNg00>d];Bh^;Rk^k/00[^k^`:m_Kd01KZj^[Rh^;Ng]kNg]kJf]P02`l?300K<c<cBd];H
f=SHf=SFe]KGemL2fMWI00?Kfm_IfMWIfMT0@MWIf@coool000[oool7f=SH?=WIf@05f=SHemOGemOG
emOGe]KF00;De=@01M7AdM3@d<k>c/k>c/W9b@02a/K600G2`/:o_knl_;bl_;bj^[X00[Ng]`03];Bd
^;Rh^k^k00:k^k/2_Kfm00Fj^[Zh^;Rg]kNg]kNf][H00/?3``06c<c<d];Bf=SHf=SHe]KFemOG0]WI
f@03fm_KfMWIfMWI047IfMT<oooo000:oooo1mSHf3cIfMT01MSHf=OGemOGemOGemKFeP02e=CD00GA
dM7@d=3>c/k>c/k9bLT00/K6aP05`/;2_kno_;bl_;bl^[Zj00:g]kL00kBd];Rh^;^k^`02^k^k0[fm
_@05^[Zj^;Rh]kNg]kNg][Jf00;3`l<01/c<c=;Bd]SHf=SHf=KFe]OGe`;IfMT00m_KfmWIfMWIf@11
fMWI3?ooo`002_ooo`OHf=PlfMWI00GHf=SGemOGemOGemOFe]H00]CDe005dM7Ad=3@c/k>c/k>bLW9
00;6a/H01L;2`[no_kbl_;bl_;Zj^P02]kNg00>d];Bh^;Rk^k/00[^k^`:m_Kd01KZj^[Rh^;Ng]kNg
]kJf]P02`l?300K<c<cBd];Hf=SHf=SFe]KGemL2fMWI00?Kfm_IfMWIfMT0@MWIf@coool00<Soool0
0<Soool00<Soool00<Soool00<Soool00<Soool00<Soool00<Soool002koool30000JOooo`<0000[
oooo000aoooo00<0003oooooool0JOooo`030000oooooooo02Soool002;oool300001?ooo`<00003
oooo0`0000?oool200000oooo`<00004oooo0P0000Soool300000_ooo`030000oooooooo00<00003
oooo0`0000?oool200001?ooo`800004oooo0`0000;oool400000oooo`<00003oooo100000Soool3
000000Soool00000003oool0003oool0003oool500000_ooo`<00003oooo0`0002Coool002?oool0
0`000?ooooooo`04oooo00D0003oooooooooool000000_ooo`030000oooooooo00Koool010000?oo
ooooo`0000koool010000?ooooooo`0000;oool00`000?ooooooo`03oooo00<0003oooooool00ooo
o`040000oooooooo00000oooo`800003oooo00<0003oooooool01?ooo`030000oooooooo00;oool0
0`000?ooooooo`03oooo00@0003oooooool0000:oooo00X0003oooooooooool0003oool0003oool0
003oool400000_ooo`040000oooooooo00000_ooo`030000oooooooo02Goool002?oool00`000?oo
ooooo`04oooo00D0003oooooooooool000000_ooo`030000oooooooo00Koool010000?ooooooo`00
00koool300000oooo`@00002oooo00<0003oooooool00oooo`040000oooooooo00000_ooo`040000
oooooooo00000_ooo`@00003oooo00<0003oooooool00_ooo`@00002oooo00@0003oooooool0000:
oooo00T0003oooooooooool0003oool0003oool000001?ooo`040000oooooooo00000_ooo`030000
oooooooo00@0000Toooo000Soooo0P0000Coool200001?ooo`@00007oooo0`0000ooool010000?oo
ooooo`0000?oool200001?ooo`<00003oooo0P0000;oool200000_ooo`800002oooo0P0000?oool4
00000oooo`800004oooo0`0000Woool200000_ooo`<000000oooo`000?ooo`02oooo0`0000?oool4
00000_ooo`80000Uoooo000Soooo00@0003oooooool0000Doooo00<0003oooooool03_ooo`040000
oooooooo0000;oooo`030000oooooooo04Koool002;oool500000oooo`030000oooooooo00koool3
00003Oooo`@0000_oooo0P0000[oool00`000?ooooooo`0koooo0038oooo0038oooo0000\
\>"],
  ImageRangeCache->{{{0, 199}, {199, 0}} -> {-7.93372, -2.56068, 0.722952, \
0.722952}}]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "We compute a correlation coefficient between the image data in Fig. 6 and \
on the right in Fig. 3. Surprisingly, the correlation coefficient is about \
0.97.\n\tThus, from a ",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  "l viewpoint, the wavelet transform is capable of compressing the image \
data.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["corRelation[Flatten[recover],Flatten[monoSample]]", "Input"],

Cell[BoxData[
    \(0.968936591454995`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "At the finishing of this section, we remove the used variables and check \
the used memories.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
Remove[\"base\",\"wMat\",\"spect\",\"partSpect\",\"wMatPrimeTrans\",
\t\"recover\"];memoryUsed\
\>", "Input"],

Cell[BoxData[
    InterpretationBox[\(2845\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ 2845, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4.3.3 RGB color image compression and recoverability",
  
  FontFamily->"Times New Roman",
  FontSize->12]], "Subsection"],

Cell[TextData[{
  "\t",
  StyleBox[
  "The purpose of this section is to examine a nature of wavelet image \
compression as well as recoverability. The nature of wavelet transform may be \
classified into two major categories. One is depended on a selection of the \
base functions, and the other is the order of the selected base function. In \
this section, we employ the Coifman's 6",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[", 12",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[", 18",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[", 24",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" and 30",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[
  " order base functions. A target image to be compressed is the color sample \
shown on the left in Fig. 3.\n",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["\t",
    FormatType->InputForm],
  StyleBox[
  "In order to extract the 25 percent major wavelet spectrum, we construct a \
filter matrix by the following codes.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
filter=ZeroMatrix[dim[[2]]];
Do[filter[[i,j]]=1.,{i,dim[[2]]/4},{j,dim[[3]]}];\
\>", "Input"],

Cell[TextData[{
  "\t",
  StyleBox[
  "The color image data are rearranged to a one-dimensional form for a \
convenience of a correlation coefficient computation. After selecting the \
base functions, we compute the correlation coefficients and approximately \
recovered color image data by the following ",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" codes.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
sampleFl=Flatten[sample];
base={coif6,coif12,coif18,coif24,coif30};\
\>", "Input"],

Cell["\<\
rgbR=Table[ZeroMatrix[dim[[2]],dim[[3]]],{Length[base]},
\t{dim[[1]]}];
corC=Table[
\twMat=waveletMatrix[dim[[2]],base[[i]]];
\twMatTrans=Transpose[wMat];
\tpSpect=Table[filter*waveletND[sample[[j]],{wMat,wMat},2],
\t\t{j,dim[[1]]}];
\trgbR[[i]]=Table[waveletND[pSpect[[j]],{wMatTrans,wMatTrans},2],
\t\t{j,dim[[1]]}];
\tcorRelation[Flatten[rgbR[[i]]],sampleFl],
\t{i,Length[base]}];\
\>", "Input"],

Cell[TextData[{
  "\t",
  StyleBox[
  "The approximately recovered color image data are normalized to the values \
between 0 and 1, because the wavelet compressed color image data do not \
always take the values between the 0 and 1.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
dummy=rgbR;
rgbR=Table[imageNormalize[dummy[[i,j]]],{i,Length[base]},{j,dim[[1]]}];\
\>", "Input"],

Cell[TextData[{
  "\t",
  StyleBox[
  "Figure 7 shows a relationship between the correlation coefficients and the \
order of base function. Obviously, employment of the higher order base \
functions yields the higher correlation coefficients.\n",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["\t",
    FormatType->InputForm],
  StyleBox[
  "Before to finishing this section, we remove the needless variables and \
check the used memories. As a result, it is found that a relatively large \
amount of memories are required to keep the approximately recovered color \
images.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
rgbG=ListPlot[corC,PlotStyle->RGBColor[1,0,0],PlotRange->All,
\tPlotJoined->True,PlotLabel->\"Fig.7.Recoverbility of Coifman\",
\tAxesLabel->{\"\[Times]6 order\",\"Cor.Coe.\"},ImageSize->{450,300}];
Remove[\"corC\",\"wMat\",\"wMatTrans\",\"pSpect\",\"dummy\"];
memoryUsed\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 450 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 -340.597 345.586 [
[.2619 .13878 -3 -9 ]
[.2619 .13878 3 0 ]
[.5 .13878 -3 -9 ]
[.5 .13878 3 0 ]
[.7381 .13878 -3 -9 ]
[.7381 .13878 3 0 ]
[.97619 .13878 -3 -9 ]
[.97619 .13878 3 0 ]
[1.025 .15128 0 -6.28125 ]
[1.025 .15128 52 6.28125 ]
[.01131 .06488 -42 -4.5 ]
[.01131 .06488 0 4.5 ]
[.01131 .23768 -42 -4.5 ]
[.01131 .23768 0 4.5 ]
[.01131 .32407 -36 -4.5 ]
[.01131 .32407 0 4.5 ]
[.01131 .41047 -42 -4.5 ]
[.01131 .41047 0 4.5 ]
[.01131 .49687 -30 -4.5 ]
[.01131 .49687 0 4.5 ]
[.01131 .58326 -42 -4.5 ]
[.01131 .58326 0 4.5 ]
[.02381 .64303 -26 0 ]
[.02381 .64303 26 12.5625 ]
[.5 .63053 -92 0 ]
[.5 .63053 92 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .15128 m
.2619 .15753 L
s
[(2)] .2619 .13878 0 1 Mshowa
.5 .15128 m
.5 .15753 L
s
[(3)] .5 .13878 0 1 Mshowa
.7381 .15128 m
.7381 .15753 L
s
[(4)] .7381 .13878 0 1 Mshowa
.97619 .15128 m
.97619 .15753 L
s
[(5)] .97619 .13878 0 1 Mshowa
.125 Mabswid
.07143 .15128 m
.07143 .15503 L
s
.11905 .15128 m
.11905 .15503 L
s
.16667 .15128 m
.16667 .15503 L
s
.21429 .15128 m
.21429 .15503 L
s
.30952 .15128 m
.30952 .15503 L
s
.35714 .15128 m
.35714 .15503 L
s
.40476 .15128 m
.40476 .15503 L
s
.45238 .15128 m
.45238 .15503 L
s
.54762 .15128 m
.54762 .15503 L
s
.59524 .15128 m
.59524 .15503 L
s
.64286 .15128 m
.64286 .15503 L
s
.69048 .15128 m
.69048 .15503 L
s
.78571 .15128 m
.78571 .15503 L
s
.83333 .15128 m
.83333 .15503 L
s
.88095 .15128 m
.88095 .15503 L
s
.92857 .15128 m
.92857 .15503 L
s
.25 Mabswid
0 .15128 m
1 .15128 L
s
gsave
1.025 .15128 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
81.000 12.813 moveto
(order) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .06488 m
.03006 .06488 L
s
[(0.98575)] .01131 .06488 1 0 Mshowa
.02381 .23768 m
.03006 .23768 L
s
[(0.98625)] .01131 .23768 1 0 Mshowa
.02381 .32407 m
.03006 .32407 L
s
[(0.9865)] .01131 .32407 1 0 Mshowa
.02381 .41047 m
.03006 .41047 L
s
[(0.98675)] .01131 .41047 1 0 Mshowa
.02381 .49687 m
.03006 .49687 L
s
[(0.987)] .01131 .49687 1 0 Mshowa
.02381 .58326 m
.03006 .58326 L
s
[(0.98725)] .01131 .58326 1 0 Mshowa
.125 Mabswid
.02381 .08216 m
.02756 .08216 L
s
.02381 .09944 m
.02756 .09944 L
s
.02381 .11672 m
.02756 .11672 L
s
.02381 .134 m
.02756 .134 L
s
.02381 .16856 m
.02756 .16856 L
s
.02381 .18584 m
.02756 .18584 L
s
.02381 .20312 m
.02756 .20312 L
s
.02381 .2204 m
.02756 .2204 L
s
.02381 .25496 m
.02756 .25496 L
s
.02381 .27223 m
.02756 .27223 L
s
.02381 .28951 m
.02756 .28951 L
s
.02381 .30679 m
.02756 .30679 L
s
.02381 .34135 m
.02756 .34135 L
s
.02381 .35863 m
.02756 .35863 L
s
.02381 .37591 m
.02756 .37591 L
s
.02381 .39319 m
.02756 .39319 L
s
.02381 .42775 m
.02756 .42775 L
s
.02381 .44503 m
.02756 .44503 L
s
.02381 .46231 m
.02756 .46231 L
s
.02381 .47959 m
.02756 .47959 L
s
.02381 .51415 m
.02756 .51415 L
s
.02381 .53142 m
.02756 .53142 L
s
.02381 .5487 m
.02756 .5487 L
s
.02381 .56598 m
.02756 .56598 L
s
.02381 .0476 m
.02756 .0476 L
s
.02381 .03032 m
.02756 .03032 L
s
.02381 .01305 m
.02756 .01305 L
s
.02381 .60054 m
.02756 .60054 L
s
.02381 .61782 m
.02756 .61782 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cor) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coe) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -153 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.813 moveto
(.7) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Recoverbility) show
183.000 12.813 moveto
(of) show
201.000 12.813 moveto
(Coifman) show
243.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.5 Mabswid
.02381 .01472 m
.2619 .41524 L
.5 .52332 L
.7381 .58817 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{450, 300},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000720001;1P00`40o`000?l0003ooooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0
02koool00`000?ooooooo`3oooooT_ooo`00;_ooo`030000oooooooo0?oooonBoooo000^oooo00<0
003oooooool0oooooi;oool002koool00`000?ooooooo`3oooooT_ooo`00;_ooo`030000oooooooo
0?oooonBoooo000^oooo00?o0000003oool0oooooi;oool002koool00`000?l00?ooo`3oooooT_oo
o`00;_ooo`030000o`00oooo0?oooonBoooo000^oooo00<0003ooooo0000oooooi;oool002koool0
0`000?ooool0003oooooT_ooo`00;_ooo`040000ooooooooo`00oooooi7oool002koool200000_oo
o`03o`00oooooooo0?oooon>oooo000^oooo00D0003ooooooooooooo0000oooooi3oool002koool0
0`000?ooooooo`02oooo00?o003oooooool0ooooohgoool002koool00`000?ooooooo`02oooo00?o
003oooooool0ooooohgoool002koool00`000?ooooooo`03oooo00?o003oooooool0ooooohcoool0
02koool00`000?ooooooo`03oooo00?o003oooooool0ooooohcoool002koool200001Oooo`03o`00
oooooooo0?oooon;oooo000^oooo00<0003oooooool01Oooo`03o`00oooooooo0?oooon:oooo000^
oooo00<0003oooooool01Oooo`03o`00oooooooo0?oooon:oooo000^oooo00<0003oooooool01_oo
o`03o`00oooooooo0?oooon9oooo0002oooo0P0000Coool200000oooo`<00004oooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001_ooo`030000oooooooo00Koool00ol00?ooooooo`3o
ooooROooo`0000Goool0003oooooool000002_ooo`050000oooooooooooo000000;oool010000?oo
ooooo`0000;oool00`000?ooooooo`02oooo00D0003oooooooooool000000_ooo`030000oooooooo
00?oool00`000?ooooooo`07oooo00?o003oooooool0ooooohSoool00005oooo0000oooooooo0000
00Woool300000_ooo`040000oooooooo00001Oooo`030000oooooooo00;oool00`000?ooooooo`04
oooo00<0003oooooool00oooo`<00008oooo00?o003oooooool0ooooohOoool00005oooo0000oooo
oooo000000Soool010000?ooooooo`0000?oool200001?ooo`800006oooo00@0003oooooooooool2
00001_ooo`030000oooooooo00Soool00ol00?ooooooo`3oooooQoooo`0000Goool0003oooooool0
00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo00;oool0
10000?ooooooo`0000?oool00`000?ooooooo`05oooo00<0003oooooool02Oooo`03o`00oooooooo
0?oooon6oooo0002oooo0P0000[oool300000oooo`800004oooo0`0000;oool400000oooo`<00005
oooo00<0003oooooool02Oooo`03o`00oooooooo0?oooon6oooo000^oooo00<0003oooooool02_oo
o`03o`00oooooooo0?oooon5oooo000^oooo00<0003oooooool02oooo`03o`00oooooooo0?oooon4
oooo000^oooo0P0000coool00ol00?ooooooo`3oooooQ?ooo`00;_ooo`030000oooooooo00coool0
0ol00?ooooooo`3oooooPoooo`00;_ooo`030000oooooooo00coool00ol00?ooooooo`3oooooPooo
o`00;_ooo`030000oooooooo00goool00ol00?ooooooo`3oooooP_ooo`00;_ooo`030000oooooooo
00goool00ol00?ooooooo`3oooooP_ooo`00;_ooo`030000oooooooo00koool00ol00?ooooooo`3o
ooooPOooo`00;_ooo`80000@oooo00?o003oooooool0oooooh3oool002koool00`000?ooooooo`0?
oooo00?o003oooooool0oooooh3oool002koool00`000?ooooooo`0@oooo00?o003oooooool0oooo
ogooool002koool00`000?ooooooo`0@oooo00?o003oooooool0ooooogooool002koool00`000?oo
ooooo`0Aoooo00?o003oooooool0ooooogkoool002koool00`000?ooooooo`0Boooo00?o003ooooo
ool0oooooggoool002koool200004oooo`03o`00oooooooo03Woool40000DOooo`80001Boooo0`00
04ooool20000A_ooo`00;_ooo`030000oooooooo01?oool00ol00?ooooooo`0hoooo00<0003ooooo
ool0DOooo`040000oooooooo0000D_ooo`030000oooooooo04goool010000?ooooooo`0004Goool0
02koool00`000?ooooooo`0Coooo00?o003oooooool0>Oooo`030000oooooooo05;oool00`000?oo
ooooo`1>oooo1@00057oool00`000?ooooooo`13oooo000^oooo00<0003oooooool05?ooo`03o`00
oooooooo03Woool00`000?ooooooo`1Boooo00<0003oooooool0COooo`040000oooooooo0000D?oo
o`800016oooo000^oooo00<0003oooooool05Oooo`03o`00oooooooo03Koool010000?ooooooo`00
053oool010000?ooooooo`00053oool00`000?ooo`00001@oooo00<0003oooooool0AOooo`00;_oo
o`030000oooooooo01Goool00ol00?ooooooo`0goooo0P0005;oool20000D_ooo`80001@oooo0`00
04Goool002koool200005oooo`03o`00oooooooo0?oooomioooo000^oooo00<0003oooooool05_oo
o`03o`00oooooooo0?oooomioooo000^oooo00<0003oooooool05oooo`03o`00oooooooo0?oooomh
oooo000^oooo00<0003oooooool05oooo`03o`00oooooooo0?oooomhoooo000^oooo00<0003ooooo
ool06?ooo`03o`00oooooooo0?oooomgoooo000^oooo00<0003oooooool06Oooo`03o`00oooooooo
0?oooom4oooo00H0003oooooooooool0003oool300002_ooo`800003oooo100000?oool400000_oo
o`<00002oooo100000Coool002KooolT000000?o000000000000o`0003T0000<oooo00<0003oool0
00000_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00;oool0
10000?ooooooo`0000;oool00`000?ooooooo`04oooo00<0003oooooool01?ooo`00;_ooo`030000
oooooooo00koool00`000?ooooooo`09oooo00Go003oooooooooool000004?ooo`030000oooooooo
00koool00`000?ooooooo`0=oooo00<0003oooooool03_ooo`030000oooooooo00koool00`000?oo
ooooo`0=oooo00<0003oooooool03_ooo`030000oooooooo00koool00`000?ooooooo`0=oooo00<0
003oooooool03_ooo`030000oooooooo00koool00`000?ooooooo`0=oooo00<0003oooooool03_oo
o`030000oooooooo00koool00`000?ooooooo`0=oooo00<0003oooooool03_ooo`030000oooooooo
00koool00`000?ooooooo`0=oooo00<0003oooooool05?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`06oooo00@0003oooooool00003oooo00<0003oooooool00_ooo`040000oooooooo
00000_ooo`@00003oooo00<0003oooooool01?ooo`00;_ooo`030000oooooooo01[oool00ol00?oo
ooooo`0coooo00<0003oooooool0DOooo`030000oooooooo053oool00`000?ooooooo`1@oooo00<0
003oooooool04oooo`030000oooo000000;oool300002_ooo`800003oooo100000?oool300000ooo
o`800003oooo100000Coool002koool00`000?ooooooo`0Koooo00?o003oooooool0oooood;oool0
1@000?ooooooooooo`000002oooo00<0003oooooool05oooo`030000oooooooo00koool002koool0
0`000?ooooooo`0Loooo00?o003oooooool0ooooodSoool300005_ooo`80000@oooo000^oooo00<0
003oooooool07?ooo`03o`00oooooooo0?oooomcoooo000^oooo0P0001koool00ol00?ooooooo`3o
ooooL_ooo`00;_ooo`030000oooooooo01goool00ol00?ooooooo`3oooooL_ooo`00;_ooo`030000
oooooooo01koool00ol00?ooooooo`3oooooLOooo`00;_ooo`030000oooooooo01ooool00ol00?oo
ooooo`3oooooL?ooo`00;_ooo`030000oooooooo01ooool00ol00?ooooooo`3oooooL?ooo`00;_oo
o`030000oooooooo023oool00ol00?ooooooo`3oooooKoooo`00;_ooo`80000Qoooo00?o003ooooo
ool0ooooofooool002koool00`000?ooooooo`0Qoooo00?o003oooooool0ooooofkoool002koool0
0`000?ooooooo`0Qoooo00?o003oooooool0ooooofkoool002koool00`000?ooooooo`0Roooo00?o
003oooooool0ooooofgoool002koool00`000?ooooooo`0Soooo00?o003oooooool0ooooofcoool0
02koool00`000?ooooooo`0Soooo00?o003oooooool0ooooofcoool002koool200009Oooo`03o`00
oooooooo0?oooom[oooo000^oooo00<0003oooooool09?ooo`03o`00oooooooo0?oooom[oooo000^
oooo00<0003oooooool09Oooo`03o`00oooooooo0?oooomZoooo000^oooo00<0003oooooool09_oo
o`03o`00oooooooo0?oooomYoooo000^oooo00<0003oooooool09_ooo`03o`00oooooooo0?oooomY
oooo000^oooo00<0003oooooool09oooo`03o`00oooooooo0?oooomXoooo000^oooo0P0002Soool0
0ol00?ooooooo`3oooooJ?ooo`00;_ooo`030000oooooooo02Soool00ol00?ooooooo`3oooooIooo
o`00;_ooo`030000oooooooo02Woool00ol00?ooooooo`3oooooI_ooo`00;_ooo`030000oooooooo
02Woool00ol00?ooooooo`3oooooI_ooo`000_ooo`800004oooo0P0000?oool300001?ooo`800003
oooo0`0000?oool400000oooo`800006oooo00<0003oooooool0:_ooo`03o`00oooooooo0?oooomU
oooo00001Oooo`000?ooooooo`00000:oooo00D0003oooooooooool000000_ooo`040000oooooooo
00000_ooo`040000oooooooo00001Oooo`040000oooooooo00001Oooo`030000oooooooo02[oool0
0ol00?ooooooo`3oooooIOooo`0000Goool0003oooooool000002Oooo`<00002oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool01Oooo`030000oooooooo00?oool3
0000:oooo`03o`00oooooooo0?oooomToooo00001Oooo`000?ooooooo`000008oooo00@0003ooooo
ool00003oooo0P0000?oool300001Oooo`030000oooooooo00;oool200001_ooo`030000oooooooo
02coool00ol00?ooooooo`3oooooHoooo`0000Goool0003oooooool000002?ooo`040000oooooooo
00000_ooo`040000oooooooo00000oooo`030000oooooooo00;oool010000?ooooooo`0000?oool0
0`000?ooooooo`05oooo00<0003oooooool0;?ooo`03o`00oooooooo0?oooomSoooo0002oooo0P00
00[oool300000oooo`800004oooo0`0000?oool200001?ooo`<00005oooo00<0003oooooool0;Ooo
o`03o`00oooooooo0?oooomRoooo000^oooo00<0003oooooool0;Oooo`03o`00oooooooo0?oooomR
oooo000^oooo00<0003oooooool0;_ooo`03o`00oooooooo0?oooomQoooo000^oooo0P0002ooool0
0ol00?ooooooo`3oooooHOooo`00;_ooo`030000oooooooo02ooool00ol00?ooooooo`3oooooH?oo
o`00;_ooo`030000oooooooo033oool00ol00?ooooooo`3oooooGoooo`00;_ooo`030000oooooooo
033oool00ol00?ooooooo`3oooooGoooo`00;_ooo`030000oooooooo037oool00ol00?ooooooo`3o
ooooG_ooo`00;_ooo`030000oooooooo037oool00ol00?ooooooo`3oooooG_ooo`00;_ooo`80000c
oooo00?o003oooooool0oooooegoool002koool00`000?ooooooo`0coooo00?o003oooooool0oooo
oecoool002koool00`000?ooooooo`0coooo00?o003oooooool0oooooecoool002koool00`000?oo
ooooo`0doooo00?o003oooooool0oooooe_oool002koool00`000?ooooooo`0doooo00?o003ooooo
ool0oooooe_oool002koool00`000?ooooooo`0eoooo00?o003oooooool0oooooe[oool002koool0
0`000?ooooooo`0foooo00?o003oooooool0oooooeWoool002koool20000=oooo`03o`00oooooooo
0?oooomIoooo000^oooo00<0003oooooool0=oooo`03o`00oooooooo0?oooomHoooo000^oooo00<0
003oooooool0=oooo`03o`00oooooooo0?oooomHoooo000^oooo00<0003oooooool0>?ooo`03o`00
oooooooo0?oooomGoooo000^oooo00<0003oooooool0>?ooo`03o`00oooooooo0?oooomGoooo000^
oooo00<0003oooooool0>Oooo`03o`00oooooooo0?oooomFoooo000^oooo0P0003_oool00ol00?oo
ooooo`3oooooEOooo`00;_ooo`030000oooooooo03[oool00ol00?ooooooo`3oooooEOooo`00;_oo
o`030000oooooooo03_oool00ol00?ooooooo`3oooooE?ooo`00;_ooo`030000oooooooo03_oool0
0ol00?ooooooo`3oooooE?ooo`002?ooo`800004oooo0P0000?oool300001?ooo`800003oooo0`00
00Coool200001_ooo`030000oooooooo03coool00ol00?ooooooo`3oooooDoooo`001oooo`040000
oooooooo00002_ooo`050000oooooooooooo000000;oool010000?ooooooo`0000;oool010000?oo
ooooo`0000;oool00`000?ooooooo`03oooo00<0003oooooool0?Oooo`03o`00oooooooo0?oooomB
oooo0007oooo00@0003oooooool00009oooo0`0000;oool010000?ooooooo`0000;oool010000?oo
ooooo`0000Goool00`000?ooooooo`03oooo0`0003goool00ol00?ooooooo`3oooooD_ooo`001ooo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`800003oooo0`0000Coool200001_oo
o`030000oooooooo03koool00ol00?ooooooo`3oooooDOooo`001oooo`040000oooooooo00002?oo
o`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo00?oool00`000?oo
ooooo`05oooo00<0003oooooool0?_ooo`03o`00oooooooo0?oooomAoooo0008oooo0P0000[oool3
00000oooo`800004oooo0`0000?oool300001Oooo`030000oooooooo03ooool00ol00?ooooooo`3o
ooooD?ooo`00;_ooo`030000oooooooo043oool00ol00?ooooooo`3oooooCoooo`00;_ooo`030000
oooooooo043oool00ol00?ooooooo`3oooooCoooo`00;_ooo`800012oooo00?o003oooooool0oooo
odkoool002koool00`000?ooooooo`11oooo00?o003oooooool0ooooodkoool002koool00`000?oo
ooooo`12oooo00?o003oooooool0ooooodgoool002koool00`000?ooooooo`12oooo00?o003ooooo
ool0ooooodgoool002koool00`000?ooooooo`13oooo00?o003oooooool0ooooodcoool002koool0
0`000?ooooooo`14oooo00?o003oooooool0oooood_oool002koool20000AOooo`03o`00oooooooo
0?oooom;oooo000^oooo00<0003oooooool0AOooo`03o`00oooooooo0?oooom:oooo000^oooo00<0
003oooooool0AOooo`03o`00oooooooo0?oooom:oooo000^oooo00<0003oooooool0A_ooo`03o`00
oooooooo0?oooom9oooo000^oooo00<0003oooooool0Aoooo`03o`00oooooooo0?oooom8oooo000^
oooo00<0003oooooool0Aoooo`03o`00oooooooo0?oooom8oooo000^oooo0P0004Woool00ol00?oo
ooooo`3oooooAoooo`00;_ooo`030000oooooooo04Soool00ol00?ooooooo`3oooooAoooo`00;_oo
o`030000oooooooo04Woool00ol00?ooooooo`3oooooA_ooo`00;_ooo`030000oooooooo04[oool0
0ol00?ooooooo`3oooooAOooo`00;_ooo`030000oooooooo04[oool00ol00?ooooooo`3oooooAOoo
o`00;_ooo`030000oooooooo04_oool00ol00?ooooooo`3oooooA?ooo`00;_ooo`80001<oooo00?o
003oooooool0ooooodCoool002koool00`000?ooooooo`1<oooo00?o003oooooool0oooood?oool0
02koool00`000?ooooooo`1<oooo00?o003oooooool0oooood?oool002koool00`000?ooooooo`1=
oooo00?o003oooooool0oooood;oool000;oool200001?ooo`800003oooo0`0000Coool200000ooo
o`<00005oooo00<0003oooooool00_ooo`800006oooo00<0003oooooool0C_ooo`03o`00oooooooo
0?oooom1oooo00001Oooo`000?ooooooo`00000:oooo00D0003oooooooooool000000_ooo`040000
oooooooo00000_ooo`030000oooooooo00;oool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00oooo`030000oooooooo04koool00ol00?ooooooo`3ooooo@Oooo`0000Goool0003oooooool0
00002Oooo`<00002oooo00@0003oooooool00002oooo00@0003oooooool00004oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool30000Coooo`03o`00oooooooo0?oooom0oooo00001Oooo`00
0?ooooooo`000008oooo00@0003oooooool00003oooo0P0000?oool300001_ooo`040000oooooooo
oooo0P0000Koool00`000?ooooooo`1?oooo00?o003oooooool0oooood3oool00005oooo0000oooo
oooo000000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`02
oooo00@0003oooooool00003oooo00<0003oooooool01Oooo`030000oooooooo053oool2o`00oooo
od3oool000;oool200002_ooo`<00003oooo0P0000Coool300000_ooo`@00003oooo0`0000Goool0
0`000?ooooooo`1Boooo0_l00?oooolnoooo000^oooo00<0003oooooool0E?ooo`;o003ooooo??oo
o`00;_ooo`030000oooooooo05Koool2o`00oooooc[oool002koool20000FOooo`?o003ooooo=ooo
o`00;_ooo`030000oooooooo05_oool2o`00ooooocGoool002koool00`000?ooooooo`1Moooo0_l0
0?oooolcoooo000^oooo00<0003oooooool0Goooo`?o003ooooo<?ooo`00;_ooo`030000oooooooo
06;oool2o`00ooooobkoool002koool00`000?ooooooo`1Toooo0_l00?ooool/oooo000^oooo0P00
06Ooool2o`00ooooob[oool002koool00`000?ooooooo`1Xoooo0ol00?oooolWoooo000^oooo00<0
003oooooool0Joooo`;o003ooooo9Oooo`00;_ooo`030000oooooooo06goool2o`00ooooob?oool0
02koool00`000?ooooooo`1_oooo0_l00?oooolQoooo000^oooo00<0003oooooool0LOooo`?o003o
oooo7_ooo`00;_ooo`80001eoooo0_l00?oooolLoooo000^oooo00<0003oooooool0M_ooo`;o003o
oooo6_ooo`00;_ooo`030000oooooooo07Soool2o`00oooooaSoool002koool00`000?ooooooo`1j
oooo0ol00?oooolEoooo000^oooo00<0003oooooool0OOooo`;o003ooooo4oooo`00;_ooo`030000
oooooooo07ooool2o`00oooooa7oool002koool20000P_ooo`?o003ooooo3_ooo`00;_ooo`030000
oooooooo08Coool2o`00ooooo`coool002koool00`000?ooooooo`26oooo0_l00?ooool:oooo000^
oooo00<0003oooooool0R?ooo`;o003ooooo2?ooo`003_ooo`800004oooo0P0000?oool300001?oo
o`800005oooo00<0003oooooool01?ooo`030000oooooooo08[oool3o`00ooooo`Goool000goool0
10000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Coool00`000?ooooooo`2=oooo0_l00?ooool3oooo000=oooo00@0003oooooool00009
oooo0`0000;oool010000?ooooooo`0000Coool00`000?ooooooo`04oooo0`0008ooool2o`00oooo
o`7oool000goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool200001_ooo`030000
oooooooo00?oool00`000?ooooooo`2Aoooo0_l00?koool000goool010000?ooooooo`0000Soool0
10000?ooooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`0000Goool00`000?oo
ooooo`2Coooo0ol00?_oool000koool200002_ooo`<00003oooo0P0000?oool400001Oooo`030000
oooooooo09Koool2o`00nOooo`00;_ooo`030000oooooooo09Soool2o`00moooo`00;_ooo`030000
oooooooo09[oool3o`00m?ooo`00;_ooo`80002Noooo0_l00?;oool002koool00`000?ooooooo`2O
oooo0_l00?3oool002koool00`000?ooooooo`2Qoooo0_l00>koool002koool00`000?ooooooo`2S
oooo0ol00>_oool002koool00`000?ooooooo`2Voooo1?l00>Ooool002koool00`000?ooooooo`2Z
oooo1?l00>?oool002koool20000[oooo`?o003Poooo000^oooo00<0003oooooool0/Oooo`Co003L
oooo000^oooo00<0003oooooool0]Oooo`?o003Ioooo000^oooo00<0003oooooool0^?ooo`Co003E
oooo000^oooo00<0003oooooool0_?ooo`Co003Aoooo000^oooo00<0003oooooool0`?ooo`?o003>
oooo000^oooo0P000<Coool4o`00b_ooo`00;_ooo`030000oooooooo0<Ooool3o`00aoooo`00;_oo
o`030000oooooooo0<[oool4o`00`oooo`00;_ooo`030000oooooooo0<koool4o`00_oooo`00;_oo
o`030000oooooooo0=;oool3o`00_?ooo`00;_ooo`030000oooooooo0=Goool4o`00^?ooo`00;_oo
o`80003Joooo0ol00;Goool002koool00`000?ooooooo`3Loooo1?l00;7oool002koool00`000?oo
ooooo`3Poooo1?l00:goool002koool00`000?ooooooo`3Toooo0ol00:[oool000;oool200001?oo
o`800003oooo0`0000Coool200001Oooo`040000oooooooooooo100000?oool200001_ooo`030000
oooooooo0>Ooool4o`00Y_ooo`0000Goool0003oooooool000002_ooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00D0003oooooooooool000001Oooo`040000oooooooo00001Ooo
o`030000oooooooo0>_oool3o`00Xoooo`0000Goool0003oooooool000002Oooo`<00002oooo00@0
003oooooool00004oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`03
oooo0`000>koool4o`00Woooo`0000Goool0003oooooool000002?ooo`040000oooooooo00000ooo
o`800006oooo00<0003oooooool00_ooo`030000oooooooo00;oool200001_ooo`030000oooooooo
0?;oool4o`00Voooo`0000Goool0003oooooool000002?ooo`040000oooooooo00000_ooo`040000
oooooooo00000_ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo
00Goool00`000?ooooooo`3foooo2_l0097oool000;oool200002_ooo`<00003oooo0P0000?oool4
00000oooo`800004oooo0`0000Goool00`000?ooooooo`3ooooo0Ooooa3o0021oooo000^oooo00<0
003oooooool0oooooa7ooolAo`00L?ooo`00;_ooo`030000oooooooo0?oooolRoooo4Ol005ooool0
02koool20000ooooocCoool@o`00Coooo`00;_ooo`030000oooooooo0?oooom3oooo2Ol004Koool0
02koool00`000?ooooooo`3oooooT_ooo`00;_ooo`030000oooooooo0?oooonBoooo000^oooo00<0
003oooooool0oooooi;oool002koool00`000?ooooooo`3oooooT_ooo`00;_ooo`80003oooooTooo
o`00;_ooo`030000oooooooo0?oooonBoooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003o
oooo`oooo`00oooool?oool00?ooooo3oooo0028oooo0`0005goool20000f?ooo`00Roooo`030000
oooooooo05_oool00`000?ooooooo`3Foooo001loooo0`0000Coool300000oooo`<00003oooo0P00
00Goool00`000?ooooooo`02oooo0P0000;oool300000_ooo`030000oooooooo00<00003oooo0`00
00?oool200001?ooo`800004oooo0`0000;oool4000000?oool0000000000P0000Coool300000_oo
o`<00004oooo0`0000?oool200001Oooo`030000oooooooo00Soool200000oooo`@00009oooo0`00
00?oool200001?ooo`<00002oooo10000008oooo00000000oooo0000oooo0000oooo1`0000;oool2
0000Toooo`00OOooo`030000oooooooo00Coool01@000?ooooooooooo`000002oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool010000?ooooooo`0000;oool00`000?ooooooo`03oooo00<0
003oooooool00oooo`040000oooooooo00000oooo`800003oooo00<0003oooooool01?ooo`030000
oooooooo00;oool010000?ooooooo`0000Coool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`050000oooooooooooo000000;oool01`000?ooooooooooo`000?ooo`000008oooo00@0003ooooo
ool00003oooo00<0003oooooool02?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool0
0`000?ooooooo`02oooo00<0003oooooool00_ooo`060000oooo0000oooo0000oooo100000;oool0
10000?ooooooo`0009Coool007goool00`000?ooooooo`04oooo00D0003oooooooooool000000_oo
o`030000oooooooo00Soool00`000?ooooooo`07oooo0`0000?oool400000_ooo`030000oooooooo
00?oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool400000oooo`030000oooooooo
00;oool010000?ooooooo`0000Coool00`000?ooooooo`02oooo00<0003oooooool01?ooo`050000
oooooooooooo000000Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`08oooo00<0003oooooool00oooo`040000oooooooo00001?ooo`030000oooooooo00;oool0
0`000?ooooooo`02oooo00D0003oool0003oool000001?ooo`040000oooooooo00000_ooo`030000
oooooooo09;oool007goool200001?ooo`800004oooo100000[oool00`000?ooooooo`06oooo00@0
003oooooool00003oooo0P0000Coool300000oooo`800002oooo0P0000;oool200000_ooo`800003
oooo100000;oool300001?ooo`800004oooo00<0003oooooool00oooo`800002oooo1@000005oooo
000000000000oooo00800008oooo0P0000?oool400002?ooo`030000oooooooo00Coool200001?oo
o`800003oooo10000006oooo000000000000oooo00000oooo`<000000oooo`00000000020000UOoo
o`006?ooo`<00003oooo0P0000?oool400000oooo`800004oooo0`0000?oool200001?ooo`<00003
oooo0P0003Woool010000?ooooooo`0001?oool010000?ooooooo`0000Soool010000?ooooooo`00
02Koool00`000?ooooooo`0:oooo00<0003oooooool02?ooo`030000oooooooo01Koool00`000?oo
ooooo`08oooo00@0003oooooool0000?oooo00<0003oooooool0Y_ooo`005oooo`030000oooooooo
00?oool010000?ooooooo`0000?oool00`000?ooooooo`08oooo00<0003oooooool00oooo`040000
oooooooo00000_ooo`030000oooooooo03koool500000oooo`030000oooooooo00goool400001ooo
o`@0000Voooo0P0000Ooool010000?ooooooooooo`800006oooo00<0003oooooool06oooo`800009
oooo0`0000[oool00`000?ooooooo`03oooo0P000:Koool001Ooool00`000?ooooooo`03oooo00@0
003oooooool00003oooo00<0003oooooool02?ooo`030000oooooooo00?oool010000?ooooooo`00
00;oool40000ooooohCoool001Ooool00`000?ooooooo`04oooo0P0000?oool400002?ooo`030000
oooooooo00Coool200001?ooo`80003oooooQOooo`005oooo`040000oooooooo00005?ooo`040000
oooooooo0000oooooi3oool001Soool300005Oooo`<0003oooooT?ooo`00oooool?oool00?ooooo3
oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3
oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3
oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3
oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3
oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3
oooo003ooooo`oooo`00\
\>"],
  ImageRangeCache->{{{0, 449}, {299, 0}} -> {0.443773, 0.985311, 0.0119931, \
8.26276*^-06}}],

Cell[BoxData[
    InterpretationBox[\(4771\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ 4771, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["4.3.4 ",
    FontFamily->"Times New Roman",
    FontSize->12],
  StyleBox["Orthogonal image data decomposing and composing",
    FontFamily->"Times New Roman",
    FontSize->12]
}], "Subsection"],

Cell[TextData[{
  "\t",
  StyleBox[
  "This section proposes a methodology, which converts a color image data \
into the spherical coordinate components. ",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  FormatType->InputForm],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontFamily->"Century",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" function colorDecode",
    FontFamily->"Century",
    FontSize->10.5]
}], "Subsubsection"],

Cell[TextData[{
  "\t",
  StyleBox[
  "The magnitude of color image characteristic vector corresponds to a \
radius. The attitude and longitude are represented in terms of their \
directional co-sinusoidal components. A following function \"colorDecomp\" \
decomposes a color image data \"vector3D\" into the spherical coordinate \
components.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
colorDecomp=Compile[{{vector3D,_Real,3}},
\tModule[{vec={0.},out={{{0.}}},dim={0},
\t\tvn=0.,i=0,j=0,k=0},
\t\tdim=Dimensions[vector3D];
\t\tout=Table[
\t\t\tvec=Table[vector3D[[k,i,j]],{k,dim[[1]]}];
\t\t\tvn=Sqrt[vec.vec];
\t\t\tIf[vn=!=0.,vec={vn,vec[[1]]/vn,vec[[2]]/vn},
\t\t\t\tvec={0.,0.,0.}];vec,
\t\t{i,dim[[2]]},{j,dim[[3]]}];
\t\tTable[out[[i,j,k]],{k,dim[[1]]},{i,dim[[2]]},{j,dim[[3]]}]
\t]];\
\>", "Input"],

Cell[TextData[{
  "\t",
  StyleBox[
  "Apply this function to the sample color image data yields a set of \
decomposed results as shown in Fig. 8. It is revealed that the color sample \
image data can be decomposed into a set of quite different quantities instead \
of the red, green and blue components. One of the merits of this spherical \
coordinate representation is that the radius component is corresponding to \
the magnitude distribution of color image characteristic vectors, and is a \
monochrome image.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["colorD=colorDecomp[sample];", "Input"],

Cell[CellGroupData[{

Cell["\<\
label={\"Mag.\",\"Cos(x)\",\"Cos(y)\"};
colorDG=Table[ListDensityPlot[colorD[[i]],
\tPlotRange->All,Mesh->False,Frame->False,
\tPlotLabel->StringForm[\"``\",label[[i]]],
\tDisplayFunction->Identity],{i,3}];
Show[GraphicsArray[colorDG],ImageSize->{450,150},
\tPlotLabel->\"Fig.8.Decomposed images\"];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
%%ImageSize: 450 150 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[.5 .325 -71 0 ]
[.5 .325 71 12.5625 ]
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .325 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.813 moveto
(.8) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Decomposed) show
165.000 12.813 moveto
(images) show
201.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -14 0 ]
[.5 1.0125 14 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Mag) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
87.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7DACFD7D7D7DADAE0E0DAE0E0E0E0E0E0E0E0DADADAD7CFCFC9C9C9
BBC0BBBBB2B2B2B2B2B2B2B2B2B2ADA9A7A8A9A9A79DA9F7F7F7F7F7F7F7F7F7F7F7F1F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7
F1F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7E8D2D7D7DADADADAE0DAE0E0E0DAE0E0E0DADADACFCFC9C9C0C0C0
C0BBB2B2B2B2B2ADB2B2B2ADB2ADA9A9A9A9A9A7A99DA9F7F7F7F7F7F7F7F1F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7
F7F7F7F7F7F7F7F7F7E8D7D7DAD7D7E0E0DADAE0E0DAE0DAD7DACFCFCFC9C9C9C0C0B7B8
B2B2B2A9A9ADB2B2B2ADB2B2ADA9ADADA9ADA9A9A79DC4F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7E0D2D7D7DADAE0DADAE0DADADADAD7CFD7CFCFC2C2C0C0BAB7B7B7
B7B2B2B2B2A9ADA9A9ADB2ADA9ADA9A9ADA9A9A9A7A4F1F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F7F1F7F7F7F7F7F1F7F7F1F7F7F7
F7F7F7F1F1F7F7F7F7F7F7F7F7F7F1F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7
F7F7F7F7F7F7F7F7F7DACFD7D7D7DADADADAE0D7DADADAC8CFC4C2C0C0B8B8B7B2B7B7B7
B7B7B7BAB2A9A9A9A9A9A9ADA9ADA7B2A9A9A9A9A9B7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7DAD7D7DAD7DAE0DADADADADADADAD7C8CCCCCCC6C6C4BBB8B8AAAA
AAB2B2B7A6ADA9A9A9A9A9B2ADADA9ADA9A9A9A9A9C4F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7
F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7DAD2D7DAD7DADADADADADADACFD7CFDAD7DAD7CFCCCCC6BBB8B6AA
B8C1B8B7AAA9A9BAA9A9A9A7A9A8A9A9B2A9A9A9A9E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7D7D7DADADADADACFD7DADACFCFCFDADADADADACFD7CCC6C6C4C0C0
B8C1C6C1B8AAADA6A6A9A9B2A9A9ADA9ADA7A9A9A9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7CFD7D7D7DAD7D7DACFDADADADADADAE0E0E0DADADACFC9C6C9C4C0
C4C1B8C1C4B8AAB6AAA9BAB2A9B2ADADADA9A9A9B7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7CFD7D7D7D7CFDACFDADADADADAE0E0E0E0DADAE0E0E0CFCDCDCFC6
C6C6C1C1C1B8B8AAAAB2B2B7B7A9B2B2ADB2A9B2CCF7F7F7F7F7F7F7F7F7F7F7F7F1F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7D2D7D7D7CFDACFD7DADADADAE0E0E0DADADAE0E0E0DADAD7D7C9CF
C6C4C4C1BBB8B8B6B2AAADB2BAB2A9ADA9A9A9B2DAF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7DAD7D7D7CFCFDADADADADAD7E0E0E0E0DADAE0E0E0E0DADADAD7CFCC
CCC4C4BBC1B6B6B8B6AAADAAA9A9B7A9A9B2A9B2E8F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7E2BACFD7CFDADAD7DAD7DADADAE0E0DAE0E0DAE0E0E0E0DAE0DAD7D2CF
CDC9C4C4C4B8B8ADB6B2ADADA9B7A9BAADB2A9B2E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F7F7F7F7F7F7F7F7F1F7F1F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F763C9D7DADADADADADADADADADADAE0DADADADADAE0DAE0D7DADADAD7D7
CDC9C4C1C1B8B6B6B6B6B2ADA9B2A9A9B7B2B2B2F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F76C43CFDAD7DADAE0DADADADADADAE0DADADAD7D7E0DADAD7DADAD7CFD7CD
C6C4C4C4C1BBB9B6ADB6B2B2ADA9A9B2B7BAB2B2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F74B2C62DADADADADAE0DAE0E0E0DADADAE0DADADADAE0E0DAD7CFC9CFCFC9C9
C4C4C0BBC4BBB6B6B6B8ADADA8A9A9A9B2A9C6B2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F1F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7CA4330DADAD7D7DAE0E0DADAE0E0DADADADAE0E0E0DADADAD7D7CCC9C4C4BBC4
C4C4C4C4C0BBB2B6B6B2B2ADA7A7A9A7A9A9A9C4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F13948DACFDADADADADAE0DADADADADADADADADAE0E0E0E0DADAD7CFC4C9C4C4BB
C4C0C4BBBBB6B2B9B6B2B1ADADA9A7A7A7B2B2B7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FF5D3BDACFD7D7DADADADADADADADADADADADADADAE0E0E0DAD7CFCDC6C4C4BBBBBB
BBBBBBB9B9B6B2B2ADADADADADA7ADA9A9ADB2B2DAF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F777439CCFDADADADADADADADADAD7D7D7DAD7DADAE0E0DADADAD7CFCCC1B8B8B8B8B6
B8B6B6B6ADADADADADA9ADADADA7ADA8A8ADB2ADA9DAF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F73B6CE0DADAD7D7DADAE0DADADAD7D7D7DADADAE0E0DADAE0DACCB0CCB0A2A2A2A2A2
A2AAB6B2ADADADA9A8A4A7ADADA9ADADA7ADA8A9A9A9F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7B93BE0DAD7DADAD7DADADADADADAD7CFD7D7DADADADADAE0E0CCCCCCB0B0A2A2A2B0A2
A2A2A2A2AAADA9A9A7A7A9ADADADADADA7ADA9A9A9B7C6F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
C83BDAD7DADADADAD7E0DADADAD7D2D2D2D7D2DADADADACCCCD3CCCCB0A2A09C8F8FA29C
9797A2A29DA2A4A7A7A7A4ADADADADB2ADADA8A9B2ADB2F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
5D6CCFD7D7DAD7D2DADADADADAD7D2C4D2CDD2DAE0DACCCCCCCCC1AA8F8F8F8F8F8F8F8F
8F8F8F97A2939BAAA8A4A4A7A8ADADB2ADADADA9A9ADB2C6F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F789
39E0CFD7D7D7D7D7D7DADADAD7D7C9C4C4C4D7DADACCCDCDB0AAA09DAAB881CCB77DB893
877F878F97939D9DA9A7A0A7A7ADADB1ADB2ADA9ADADB2B7E8F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B64B
30DAD7D7DAD7D7CDDAE0DAE0D2D2C9B9B9C4DADACDB0B6A0876CADB8C8C8B9B9C6A4C4B9
74A66C7F8F8F939D9DA4A4A7A8ADB2B9B2ADA8ADADADB2A9B7E5E5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E59E39
9DD7D7DADAD7C9C4E0DADAD7CDCDB9A8A8D7CCA2A2904393B88FAA97C1EBE8DA9CAA9789
88A49A706C7F87979BA4A0A0A8ADB2BBB9B9ADADB2ADADB2B2C8E8F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A4892C
DAD7DAD7D7D2C4C4DADADADACDBBB1A1B1C18F5664C6E0E8E8F1F1E8EBF1E8E0CFDADADA
C86C7D72804874818FA8A0A0A8ADBBC0BBB9ADB2A9B2B2B2B2C2F7CDE2F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F1F7F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7744355
CFD7DAD7D7D2C4D7DADADADACDB1A1909A6C4963C4E0E8E8E8EBF1E8EBF1E8E8CFEBE8DA
DAC0AD6C612E4274819AA7A0A8ADBBC4BBBBB9ADADB2ADB2B2BADCF1E8F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F1F1F7F7F7F7F7F7F7F7F7E8F7F1F1E5F1F1F780399D
D7DADAD7D7CDC4D7DADAE0D7BBB195955643407DBBE8DAEBD7E8F1DAE8F1E8DAB8EBE8DA
DAC8C8DA64801B1B6C7F9DA4A4ADB9C4C4BBB9B2A9B2ADB2ADB7BBC4CDF1F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7DC3B2CDA
CFD7D7D7D7C9D7C4DADADAD7B1A88F9D745E43A0AAA1C4D7C1E0E8B6D7E8D7B6B8C4DADA
B6CFDACFA9BA9C9C435E81A4A4ADB9C4C9C0BBADB2ADA8ADADB2C295BBC4DCF7F7F7F7F7
F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C43B154AC8
D7D7D7D7C9C4D2C4DADADACFAA95A1B6B8B6978FA0A0A1B8AAB1B1B1C1CC8F9797AAB1B6
8FB1CFBBB7BAA99C753D5E97A4ADBBC4C9C4BBADADA9A4A9ADB7BADCCDC1CAE5F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F16C202C1B9ADA
D7D7D7CDCDC9CDB6D7DAD7CCB190BBC1CFDAD7D7CCC6C1C1B8C1B8B8B0B0AAA897978F89
8F8FB7959AC99BA9802B36649DA7B9C4C9C4B9B2ADA7A9ADB2B2B7F7F1D3CDDCF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2CD2013391EDACC
D7D7D7C9C9CCC9C9D7DAD7CDB690B6C6E0DAE0E0DAE0DAE0E0E0E0CCCCCCC6C6C1B8A297
A2938F8181A0817D5E17365064A4B6C4C4C4BBADADA9A4A8ADADB7849EDCE2D3E8F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D389132C202EDACF
D7CCD2CFCCCFCFCFD7CCCCC9B6A895C6DAE0E0DADAE0DADAE0E0DADAD7D2C4C4C4C9B9BB
B6AAA89DA2938F817456566C5E9DADC4C4C4B9B2ADA7A4A8ADADB2A448E8F1E8E8F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2396CA67D5DDAD7
D7D7D2CFD7D7D7CFCFD7CFCFB6B1A1BBCFDADADADAE0DADAE0DAE0DAD7CDC4C4BBC4C4BB
B6B1ADA8A4A8A8AAA49D9A959095A8C0C4C4BBADA9ADA7ADA8B2B2B0745EF7E8F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DC5ED7CFC4C4CFCF
D7D7D2CFD7D7CCDAD7D7D7CFBBB1A8A1C9CFDAE0E0E0DADADAE0E0DACCC4C4B9C4C4BBBB
B6ADA7A9A4A7A7A4A4A7A4A49BA4A0C0BBC4B9ADADA7A7A7ADB2B2AD5DC1C4F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1A4CFDAD7DACFC8CF
CFCCD7DADADAD7DAD7D7D7CFC4BBB1A8B9CFD7E0E0E0E0DADADAE0E0D2C4C4B9BBC4B9B9
B6ADA7A49B959B999B9B9DA4A0A7A8B9C4BBB2A8A4A4A0A7ADA9A9B615BBF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DCD7D7DAD7E0CFCFD7
CFD7D7D7DADADADAE0DADACCC9C4B6B1A8C4CFDAE0DAE0DADAD7E0DAD7CFC4B1B1B6B9AD
A7A49D9B999B979999999799999DB2A0BBB9B6A8A4A4A4A7A7B2A9A43180E5F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D3D7DAD7D7CDCFD7D7
CCD7D7DADAE0E0E0E0E0DAD7CCC4BBB1A1B9C4DAE0E0E0DADADAD7DACFC6B6B8B8B2A8A8
A0A0999B9799999B9B99999599A7A8B6B2ADADA8A4A4A4A7A9ADA9A4134380F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8D2D7DAC9CDB9D7C8D7
D2D7DADAE0E0E0E0E0E0E0D7CCC9C4B6B1B1C4DADAE0E0DACCCDCFD7D7CDBBB6B6B29AA7
A9A49797999B9BA0A099999995A8B6B9B6B1ADA9A4A4A4A8A9A9B29C1524BBF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D7DAD7E0CFB1B2D7CFD7
D7D7DADAE0E0E0E0E0E0E0DACFC9C4B9B1A8B1CFE0E0DAD7DAD7D7D7DAD7C9C4BBB2B2A4
8A9795979B999BA09DA099A0ADBBB9B9ADADADADA4A4A4A9A8A9A9872A6DF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D7D7DAE0BBBBB2CCCFD7
CCD7DAE0E0E0E0E8E0E0E0DAD7D2CDC4B9B1B1C9DADAE0DADAE0DAE0DAD7C6C6BBB7ADAD
AD9B978A97999BA0A49DA8B2B6C0BBBBADB6ADADADA7A4A9A7A9A983203143E5F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8D2D7DACFA8B9C0CFCCD7
D7D7DAE0E0E0E0E8E8E0E0E0D7CFCCCDC4B6B1BBCCDAE0DADADAE0E8E0DACFC4BBB8B2AD
ADADA9A88A9395999DADADBBBBBBBBBBB6B1ADA8ADA4A4A4A7A9B78B4830136FD3F1F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CFD7DACFC995A6CFCFCCD7
D7D7DAE0E0E8E8E0E0E0E0DADACFD7CCBBBBB9C6CFDADAD2D7DAE0E0DAD7C9B6ADADADA9
A9A4A4AAA08A979DA4B2B8BBC4C4BBC0B7B2B2ADA9ADA9A4A9A9B7A08F6C50394395F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EBCDD7CDB9ADA8B7CFCCD7D7
D7DAD7E0E0E0E0E8E0E0E0DAD7D7D7CCC9C4C4BBDADADACFC9D7DADACFCCC4B2ADA6A6A4
A9A4A4A4998895A0ADB8BBBBC4BBBBBBB2B2B6B2ADADA7ADADADB7A4A0978A4374E2F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DAD2B1A18F93A4BBC2D7D7D7
D7DADAE0E0E0E0E0E0DAE0DADAD7CFCCC9C6CFCDD7DAD7C9C6CFD7D7CCC4B9B6A8A4A49B
9B9BA0998A8F97AAB2BBBBBBC4C4BBBBB2B6ADADADA8A7A4A8B7B7A4A4A4A49CF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CCD2AA9C9395ADB8CFD7DAD7
DADADADAE0E8E0E0E0E0DADAD7CCCFCDC6C9CFDADAE0DAD7DADAD7CCC9C4BBB2A49D939B
9993999595959DADB2BBC4C4BBC1BBBBB9B6ADADA8A9A9A4A9B2BA9999A0A0ADF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DACCCDAAA19397A9C4CFD7DAD7
E0E0DAE0E0E0E0E0E0DADACCD7CCCFC6CDCCCFDADAE0E0E0DADADACFCDC4BBADA49B9B93
9393939B9BA4B2B2BBBBC0C0C4C0BBB6B2B2ADADAAAAAAA4A4A9BA9595A4A4B7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CCD2CCB1AA9797B2C6CFDAD7DA
E0DAE0E0E0DAE0DADAD7CFD7CFD7CCC9C4C4C6DADADAE0DADADADAD7CFBBB6ADA49D9B99
9B9B9BA7A4ADB2B8B8C4C4BBC4BBBBBBB6ADADA9A6A4A9A4A4A6BA9D9DA0A9A4F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E0C4D2DAB1A89593B2C9D7DADADA
E0E0E0DADADADAD7CFCFD7D7CCCFC9C9C4C6C9D7DADAD7DADADADAD7CCC4B1ADA49D9B9B
9B9D9DA4A7B2B2BBBBC4C4C0BBBBB6B2B2ADA8ADA8A4A4A6A7A6BAA9A8A7A99DC8F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D7B9D7C0B8A88A93B7C9CFCFD7DA
E0DAE0E0DAD7D7D7CFCFCFC4CFCFC6C4C4CFCFCFDAD7D7D7DADADADAD7C4B6ADA4A4989B
9D9DA4A9A8ADB8BBC0BBC0BBC0B9B6B8B6ADA9A4A7A6A4A4A4B7B899A7A9B79AB2F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1B9B197AA6C6C818AC0CFD7DADADA
DAE0DADAD7D7D2D7CFC9C6C6C0C6C6C9CFCFCFCFD7DADAD7DADADAD7CFC6B6ADA49B9B9B
9B9DA4A4A9B2B8C0BBB6BBC0C0BBBBB6B2B2B2ADA9A6A4A4A6A9BA7487A7B79A9AE8F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D7B19D975B795D6473C0D7DADAD7DA
DADADAD7DADACFCFC9CFC9C6BBC0C0C0C6CFCFCFCFDADAD7D7DADAD2CFC4B6A0A49B939B
999BA6A4A9B2B2B8B7B2B6B6B8B6B6B6B2A6B2A9A6A4A4A9A9A9AD7D819BA9A4A0CCF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CDA19B42A45D554A75C0D7DADADADA
D7DAD7DADADADADADADADACFC6C4B8B8B2B8C9CFCFD7DAD7DADAD7D7C6BBAD9D9B99999B
93A0A4A9B2ADADB2B2BBB8B6ADB2B2ADA9B2A9A6A9A7A4A4A6ADA9818F9599AD9DADF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1B9AA757D3B5B625E63C0D7DACFDAD7
CFD7CFC2CFDADADADADAC4DADAC2C0C0B2ADB2B7CFCFDADADADAD7D7C4C0ADA49B9B9393
9B9DA6A7ADA9ADADB2B2B2B2A6A9ADADB2ADA9A9A7A4A7A4A6ADA9816C645E87A09AF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8A1B8797D18482C4A5EC0D7D7CFCFDA
DAD7D7CFB79DB7A7989B989A9AA69BA6ADAAADB2C0CFDADADADADAD7C6BBAD9B99999593
989B9B9B9DA69DA9A9A9B7B7A9B2B2B2B2B2A9A9A9A7A49DA6B7A9866C6C6474909DF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D7A1B88A431313203B4AC9DAD7D7D7D7
DACFC9B79386534A6C8A8A757370867D989D97B2C0C9D7DADADADAD7C6BBA8A09B959398
8A8B9DA6A49B9DA4A49DA9B2B2B7B2B8B2A9A9A6A4A99D9DA9A9A983706C6C7490A8F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C99CB8A61817202C315AC9DACFD7D2D2
D7D7D7CFC9B79D4883BB5D83430C534281746C646CB9C9DADADADAD7C9BBADA0998B9888
8A9DA9B2B2B2B2B2ADA6A6A49DA7B2B7B2B2A9A99DA49DA4A9A9A986746C6C7489A4F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFBB87B6C12C1B242C3B4FCFD7DACFCFCF
D7DAD7CFCFA9B29884392E807A0C4F53A49E5B6CA0C4CFDADAE0E0DACFC4ADA0958A7D7D
88A7B7B7B7B7B2A9A9B7B7A9A6A7A9B2B7B2A9A7A79DA79D9DA99D73646C6C8195A8F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF42CD87A8B64A15202C305ECFD7D7CFCFCF
D7DAD7D7DAC9B2B2C6B75E3B2C1337375D747D81ADBBCFD7E0E0E8DACFC4AD9D8A888874
3D50939B8F8186706C81989A9DA7A79DA9A9A99D989D9DA4A6A6986C617074909D9DFFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2302ECDBBCDBB551B2C202C5EC9D7CFCFCFD2
DADADADAD7D7CFBBB2B2BA836C4F6C5574887DB9B9B9CFD7E0E8E8DAC9C4AD9D95888A7D
735BB0C4B5533D425573635B81868B8B989898989B9B9DA4A69D8B555D5D6C9AA090F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F1F7F7F7F7F7F7F7F7F7F7F7F73B2420B1CDBBB15D3629132062CFCFCFD7D7BB
CFD7CFDADAD7CFCFBBA9A9B7A98B887D887DA7A8B6C0C9D7E0E8E0CFC9C0ADA095888A88
747084D35D840429553B63613B6C736C7381959B9DA79D9DA4988355485E55A4AD87FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F76330201842A17D64392A201B2C6CD2D2D7CFDAC0
93C4CFDADAE0E0DACFC9BBBBB2ADA7A7A8A8ADB9C0C9D7DAE0E0E0D7C9C4B2A49388958A
887D93814AA400474A3B8474363B4A5A818899A7A9A9A99D9D98624B483153A99587F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF30372C181B1B552C24311B1B2C75CFCCCFCFDACF
AAA9B2CFDAE0E0DADACFC6BBADADB2ADADA8B9B9C4C9C9DAE0E0E0CFC6BBB7A999959898
9598A98B934B1513372C4F39395E6C988A98A7999BA99D9DA7984A483B2C43AA8981F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7E82E3037202418392A1B151520206CC9D2D7D7CFDA
CF9BB2A6C9DAE0E0DADACFC9B2B2B7ADA09A9AB2C0C0CFDAE0E0DACFC4BBB2A99D959599
9B9988A9A9757355435331628379838B939998A99D9D9D9D9D834831433037A98187FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79B30313B30302C31310C132C13305EC9D2D2D7CFD7
DAC6B7878A98988B8B6C735E5D64645B7074749BB7C0CFDADAD7D7C9C4BBB7A99B999595
989BA799A9A7A9989883798379989B9BA0A49DA4A7A9A9A79D5E3B392C1B438A7487F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A42C2020201B202C201B13152C2C62C9CFD7CFD7D7
D7DACFC6A672778D80806C627563615B61818AA4BBCCCFDADACFCFC9C4C4B7B29B938888
88939BB2ADA79B9998988A999BA4A09DA69DA49D9D9D9D9D8B4A2A29361B648A6C81F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B637201B1B1B20200420131B31435AB7C9D2D7D7D7
DADADAD7CFA9A6A68D9BA69A9387988A8A9BADC6CFD7DADADAD2CCC4C9C0B7B29B8A635B
637D989BA7ADA7ADADA7A7A79D9DA7A69DA9A69D9DA6A79D833B1B2A1B1393886C87F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F1F7F7F7F7F7F7F7F7D33913201B202C200C2020151B4362A9C9CFCFD7D7
DADADAE0DACFCFCFDADADAC4CCC4CCC8CCDACFCFCFDADADACFCFD2C6C9C6C0B8A99B6C55
5050758A99A9A9B2ADA9A9A7A9A4A9A99DA99DA79DA99DA7622C1B24153199896C8180F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F1F7F7F7F7F7F7F7F7F7F7E54820201B201B1B130420202C435A9DC0C9D2D7D7
DAE0E0E0E0E0E0E0E0E8E0E0E0E0E0E0E0DAD7D7CFDAE0D7CFCFCFC9C9C9C0C1C0C6A98A
635D48373B5581A7A9A9A7A7A79D9D9B9B938B9BA6A9A48B481B20153630748A64814BD3
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7393B2C201B20202004201B2C485E9DB2C4D2D7D7
DADAE0DAE0E8E8E0E8E8E0E8E8E8E8E0E0E0E0DAE0DADACFCCCCCFC9C4C9C4C0C6C0BABA
A98A635D43373B435D8B98939B988B816C6C8AA9A4A6A48330202020241B507488755489
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7434A3120201B2020130C203B435E98A9C9D2D7D7
DADAE0E0E0E0E8E8E8E0E8E8E0E0E8E8E0E8E0DAD7DAD7CFD7D7C9C9C4C9C9C6C9C6C6C0
BAB2A683735D483B3B555D6C635D6C756C86A6A9A49D9B752C1320242A1B244B403754A4
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F748483B2C202C20201B042C2C435A8BA7BBD2D7DA
D7E0DAE0DAE0E0E0E8E8E8E8E8E8E8E0E0E0E0DADADACFCFCFCFC9CDC9C6C9C6C9C9C0BB
C0B7B7A99D8A736348485353555563798A9DA69D9D9B935D20201B201B13142B37395AFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DC4F484F311B2C2020202A2A39435E839CB7C4D7D7
D7DADADAE0E0E0E8E8E0E8E8E8E8E8E8E0E8E0DAE0D7D7D7D7CDC9C9C9C4C4C9C9C9C6C1
C0B8B7B7A9A99D9B8B81756C7579939D9DA49B9D9D9B8B3B2C20202C1B1B132C2C2C5489
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B9484B483B312C20202020202C3B4A7398B2C9D2D7
D7DAE0DAE0E0E8E0E8E8E8E8E8E8E8E8E0E0E0DAD7D7CFCFCFC9C9C4C4C9C6CFC4C9C6BB
BBBBB7B7B2A9A9A6A69B9B9B979D9DA49DA49BA09D9383302C201B1B2A1B1513202C2A4B
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78948483B31312A202020312C203B3B5E83A9C4CFD7
D7DADAE0E0E0E8E0E0E0E8E8E8E8E8E8E0E0E0E0D7CFDAD7D2D2C4C9C9C4C9C4C4C0C4C0
BBC0B6B7B2B7A9B7B2B2A9A9A9A4A4A7A6A4A4A49B8B642C2C1B201B2C1B1B2020133B4B
B0F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7633B4B4F4331392C20202020202C3B48628BC0C9D2
DADADADAE0E0E0E0E0E8E8E8E8E8E8E8E0E0E0D7CFD7D7CFC9C9C9C4C4C9C9C4C4C1BBBB
C0C0B8BBB7B2B7B2B2A9A9A6A4A6A9A9A69DA49D8B754831201B15310C15151B200C2A3B
95F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F74F3B434B4331392C201320202C203B484A73A7C9CF
D7DADADAE0E0E8E8E8E8E0E8E8E8E0E8E0E0E0DAD7D7D7C9C9C4C9C4C4C4C4C9C4BBC4C0
BBBBB2B7B2B2B7ADA9A9ADA9A9A99D9D9D9D9D9B835A392013152A0C150C131304132C3B
84FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7F743434B4B4843392C202C1320202C2C4F5E5598B2D2
D7DADADAE0E0E0E8E8E8E8E8E8E8E0E8E0E0E0E0DADACCCFCFC6C4C4C4C4C4C4BBC0BBBB
B2B9B7B7B2B2B2B2A9A9A9A7A9A9A7A4A9A49B8B75482C201B2C1B1515131313131B203B
6CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F1F75A484B434B433131202C13202031314B5A5E8AB2C9
D2D7DAE0DAE0E0E8E8E8E8E8E8E8E0E8E0E0E0DADAD7CFCFC9C4C4C4C4C4C4B9C0C1BBBB
BBB2B2B2B2B2B2ADB2ADA9ADA9A49D9DA49B9886623B2C1B312C0C0C150C040C151B2031
77F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7483B4843434B39392C2C2C202C2C203B4A638AA7C0
C9D7DADADADAE0E8E8E8E0E8E8E8E0E8E0E0DADACFCCD7D2C6C4C4BBBBC4C4BBC1BBC0BB
B2B6B2B2ADA9B2ADA9A7ADA4A9A4A4A49B998B734A433B311B1B15130C0C040C131B133B
E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F74B4B484B4B4B4B43302C2C132C2C3148556C8395BB
C9D7D7E0DAE0DAE0E0E8E8E8E8E0E8E8E0E0E0DADAD7D7C4C9C4C0BBBBBBC1C4BBB6B6B2
B8B8B2B2B2A9ADA9A9A9A9A69B9DA49D9393736C48392C131313150C0C04130C151B2C54
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F14A43434B4A4B5431392C202C2C313B434F628193AD
C4CFDADADADAE0E0E8E0E0E8E8E8E8E0E0E0E0DAD7CFC9C9C9C4C0BBBBC0BBC4BBBBB7B6
ADB2B2ADB2ADA6A9A4A4A9A4A7A49D9D8B83735D3B2C20152015150C0C150C1313132C4F
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7E843433B434B4B4B43432020312C313B39486C8193A9
C0CFD7D7DADAE0E8E0E8E8E0E8E8E8E0E0DAE0DACFCCD2C4C4C4C4C4C4C0BBB9BBBBB6B7
B7B2B2ADA6A6A9A9A9A6A9A4A49D9D98867575483B2C2C1B1B2C1B201B1513151B202C62
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7E84F4B30434F4B544B4330202C312C314A5A75758199
B2C9CFD7D7DADAE0E8E0E8E0E0E0E0E0DADADADACFC9C9CDC4BBBBBBBBBBB8BBBBBBB8B8
B6B7B2A6ADAAA9A99DA4A6A4A49B988B83645A48302C24202A2C150C1B1B150C0C1B39E8
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F1F75A3939484B43544B3B4320313139313B5A6C55758A
ADC9CFCFDADADAE0E0E0E0E0E0E0E0DADAD7CFD7C9C9CFC4C4C4B9BBBBBBB9BBBBBBBBB6
B2B2B2B2ADA9A9A6A49DA4A49D9D8B83755A4A392C2A1B1B132015150C0C00040C204AF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F1F7F76F433948435A4B4B43432C1B3B394331484F5A6C81
A4C9C9D7D7DADADAE0DAE0E0DADAE0D7DADADACFCFD2C9C4BBBBB8B9B8BBB6B6B8BBB6B6
B6B8A6A8A4A9A6A7A7A4A4A49B93866C5D48433B2020201B1B15150C1500040C132C6CF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7774F393B394B434B39394B2C1B3B31433B5A4A5583
93BBCFCFD7D7D7DADADAD7DAD7DAD7CFDAD7D7CCC9C9C4C4B6B9B6B9B8BBBBBBBBB9B1B6
B2B2ADADADA7A9A9A49D9B9B8B83755D4A3B3B2C201B1B1B201B15150C040C132C48FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7775D393B43394F5D3143391B2C20394B314348486C
81A9BBC9D7D7D7CFDAD7D7DADADAD7D2CFCFCCC9CDC9B9B9B6BBB9B9B9B9B2B6B2B1B2AD
ADADA8A9ADA9A6A7A79B93938A755D5543302C2013131B1B1B1B1B151B0C041B3948F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7F79E6F43434B434B4F433B39392031314343394F4B5E
759BA7BBCFC9CFCFD7D7D7D7D7D7CFCFCFCDD7C9C4C4B6BBB9B6ADB6B2ADB2B1B6B1ADA8
ADADAAADA9A4A7A79B9D9886837555483B2C202013131513201B150C04000C312C63F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C4724F3B4B43434F5D314B31312C31394B434B435A
5D8BADBBC0C9C9C9D7D7D7CFD7CCCFC9CFC9C9C6C6BBBBB6B1B6B1A8ADB1A8B9ADADADA7
A0A4A6A9A9A4A49D98988B836C5D4848302C20130C0C0C131304040000001331399EF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F76C4F4B434B39435443432A2A312A39394B393B4A
486C8398A9BBBBC0C9CFC9CFCFCFCFC9C9C6C9C9C0A8ADA8ADADADA8A8ADADA8ADA8ADA0
A4A0A4A49B9898938B8175756C483B30202C1B1313130C0C0C040000000C2C3137F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7FF805A4B484F434554433B31202C2C2A434B4F362C
4A4A5D758B939BA9BAB7C9C9C0C2C0C4C9B9C9C0C0B29DA4A4ADA4A4A4A7A8A8AAA8A4A4
A0A09D9D989B938A8675755D55483B2E201B130C040C0C0C0C04000000152C3172F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C1634F394B43434354393B2C2C1B4B39394B4B4F
314A5A5E5E808198B298A9B2BAB2BAB7B7B2C0B2A999868A8A99959DA495A4999A9DA4A4
A09B9B9393938A86836C5D55433B2C202004130C0C0C0C0C040000000C312020E8F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF6C5D433B4F3B434B432C3B2C2C313154484B43
4B545A636C6375778B86838B8B868B98A79BA9988375756C7575888A8F8A95939B959593
93938A8B8A818173625555483B3020201B0C130C040404000000000C2A2C2062FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78D634B394B4343434B362C2A2C3B43434B5454
4B5D4354545A62736C7272756C7375758BA78B83736C6C626462737D7D88888895888A8A
79817D868179736C5D554330302C202013130C0C040400000000002C1B202CDAF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D3774B43434B48365A392C2C2A313B544B5D47
435D635D5462755A635E6262625D6C5D7575837575635E55555B55646C73797981817975
75756C756C6C6C5555483B302C201B1B0C0C040C0400000000000C202A1B39F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79E4F43434B39484843311B31394B54545454
5D435D6C636263635A4A4F4F485A4A55555E62634F5A4F4F554A5353555B6C6C6C6C645E
6C5B5B64625D555A48302C2C311B1315130C0C00040400000004202C15398DF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DC6F4F43434B3948544331314B435D5D4B63
54434F5A5E635A5A5548394F39434F3B4F485A484354432C3B39393B3B3B484343484848
483B3B3B3B3B3B3B372E20201B150C0C13150C0C000000000C2020153148FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2804F43434B4343434B43394B5D54635D5D
4B434B4A4A5E554848394339313143392C4F4343433639392C31312C2C30303B3B3B3B3B
3B37303B30312C302C311B20131B0C0C0C0C0C0000000004241B203043D0F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B0774B4B3B4B3648435D4B394B6C485D5D
5D5D545A4F484B484F3143433636434B433143433B312A312A20202C2C202030202C312C
2C2C2C202C202C202C20201B131B0C040C0004000000001B1B2C153087F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CAA44B434B43484B43435D5D6F3954544B
39314B4F5E3B4B4A4343433939434F362A2A362C2C2C2C20201B1B2020202C1B2C20201B
202C20202C202013201B130413130C000C04000C00000C1B31152C87F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1C1724B434B4331394831545D5D5D3639
5D6C5A434A3B3939313143432C2424362A242C242C241B1B151B151B1B1B201320202C24
131B1B13201520131520151B0C0C0C04000000000C1B1B1B202062E8F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D3C44A434B4B4B3943483643545D5D54
4848394B48313143392A3939292436432A242C1B241B1B1B1B1513151B151B151B1B132C
0C131313202013130C1B1313150C0C0C00000C151B1531202C55F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D36343394B4B484348435D4843435D
5D6F43313B2C2C39392C43313929362A201B2415152A201515150C0C0C1B1B130C1B1B13
1B150C1B0C1B130C150C040C00000C0000040C151539292C4AE8E8F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7776343394B3943364B36485D4B43
394B3143312C2020392C2A2C2A152015242C151B0C151520150C0C0C150C0C1B150C0C15
15151B04150C0C0C000C0000000000041515131B0C1B1B6CE8E8F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E28463434B434B4843434336434B
43362C43312C1B202A2A20242A39152920151B1515151B1B0C0C0C150C0C0C1B1B0C0C0C
15150C2415150C0400040000000C1520150C24151B2C5595E8F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BB775A394B4348485D484B5454
45362C4B31201B1B202A1B2020360C2A0C1B150C150C0C15150C0C0C15150C152C15000C
15151B0C150C00000000040C15241515151B2C203B4875E2F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B06F4B434B39483948474843
39361B4B2C2A151B1520201513130C15150C150C150C150C150C0C0C0C150C152929290C
0C15151520151B201B1B1B1524130C152A20203B3B6C72F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C47254484B39485454545D
5448364339202415150C201515131B0C1B0C150C0C0C0C0C0C1B0C000C0C1B1515364D43
471524150C1515151B241B151536391B313B2C485D6CF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F77477544B483943485454
54453654392C2C200C151B1B150C130C1B15150415150C150C150C0C000C0C392923475D
2424292936241B1B151B2C30392A2C312C3B3B556CF1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF74725D544839434853
5D4854433B3631201B0C151B0C13131B151B0C150C15150C0C0C150C0C0C0C0047393929
5D5C5D4745455445392C1B1B313131394B48555EF1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78F634B484B39434B
545C6B5D39393B312C15151B201315130C1B0C0C0C0C150C0C0C1515000C1B150C203943
473620151B2A31393939394B4343433B3B4A6C77F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F762545D434B54
5D5D5D6F5D313131312A431B362A20241B0C150C15150C150C1B201515151B2915243623
4345151B1B241B1B152A2036312C3B556C63D3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A76C4B4B4B48
545D6F80744B3031312C2C313939392024202C1515151B241515391B29241B2447292929
201B36362A3936312C433B2C3B48485D5ED3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D06C4B3943
4B5D6F6F746F5D36312C2A2C2C434339365415200C2A292429353636296D4B5320435D47
4543434343393943434B5A4B4355755EF1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7866354
4B5D74748980746F4F5D634339204343544743483923155C45475D6D4747475D5C535448
4B5A4F544F4F4F4B393B485A644A87FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CA77
5D5D4B5454746D746F746F6F745D454B475D6B5D74474524473945476B544B4B434B545A
4F4F4A4348484B555E5D755A48BBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
A75C545D546F80746F6F636F746F6F6F535D546F5C5D6D4739392931395D4B4B4B39393B
3B3B394A555A5E5D5D5E484ACDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7C1745A5D5D5C748974807474637477807477746F8054745D4B45453936435D54434B4B
554F5D5A626C7375554387FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7E55C3E4B536D9574898089776F74847777776C84777763636F6C62636C626372
728083836C4F435EC1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7E2A47D7D9598BC9E9E9E8484775D778487848484777784726C7277808483
6C636C4F4F6CBBFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7E5E8CDBCB5BC9595877772746B747777846F726F726C726C63
5E635E77A4FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7E8E5E8F1E8CDC18F9B8F80777777777784776F6F6C5E54
639BF1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F1F7F7F7F7F7F7F1E2DCC1D3D0E8F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cos) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 12.813 moveto
(H) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 12.813 moveto
(L) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
020202020202020A02020202020202020202020202020202020202020202020202020202
02020202020202020220323131312C2C23232C23232323232323232C2C2C3132323C3C3C
4A3F4A4A4C4C4C4C4C4C4C4C4C4C574F54634F4F544A4F02020202020202020202020A02
020202020202020202020202020A020202020202
0A0202020A0202020202020202020202020A020202020202020202020202020202020202
020202020202020202163A31312C2C2C2C232C2323232C2323232C2C2C32323C3C3F3F3F
3F4A4C4C4C4C4C574C4C4C574C574F4F4F4F4F544F4A4F020202020202020A0202020202
0202020202020202020202020202020202020202
02020A02020202020A02020A0202020202020202020202020202020202020A0202020202
0202020202020202021631312C313123232C2C23232C232C312C3232323C3C3C3F3F414F
4C4C4C4F4F574C4C4C574C4C574F57574F574F4F544A1902020202020202020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020202
020202020202020202233A31312C2C232C2C232C2C2C2C31323132321E1E3F3F3B414141
414C4C4C4C4F574F4F574C574F574F4F574F4F4F545B0A02020202020202020202020202
0A02020A0202020A02020202020A02020A020202
0202020A0A0202020202020202020A0A02020A0202020202020202020202020A02020202
02020202020202020220323131312C2C2C2C23312C2C2C1432191E3F3F4F4F414C414141
4141413B4C4F4F4F4F4F4F574F57544C4F4F4F4F4F41020202020202020202020202020A
0A02020202020202020202020202020202020202
0A0202020202020202020202020202020202020202020202020202020202020202020202
0202020202020202022C31312C312C232C2C2C2C2C2C2C31144444444242464A4F4F5D5D
5D4C4C4156274F4F4F4F4F4C57574F574F4F4F4F4F190202020202020202020202020202
0202020202020202020202020202020202020A02
020202020A02020202020202020202020202020202020202020202020202020202020202
0202020202020202022C3A312C312C2C2C2C2C2C2C3231322C312C31324444424A4F545D
4F4C4F415D4F4F3B4F4F4F544F634F4F4C4F4F4F4F160202020202020202020202020202
0202020202020202020202020202020202020202
0202020202020A0202020202020202020202020202020202020202020202020202020202
02020202020202020231312C2C2C2C2C32312C2C3232322C2C2C2C2C3231444242463F3F
4F4C424C4F5D5756564F4F4C4F4F574F57544F4F4F020202020202020202020202020202
0202020202020202020202020202020202020202
020202020202020202020202020A02020202020202020202020202020202020202020202
020202020202020202323131312C31312C322C2C2C2C2C2C2323232C2C2C323C423C463F
464C4F4C464F5D545D4F3B4C4F4C5757574F4F4F41020202020202020202020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020202
0202020202020202023231313131322C322C2C2C2C2C232323232C2C2323233243433242
42424C4C4C4F4F5D5D4C4C41414F4C4C574C4F4C440202020202020202020202020A0202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020202
0202020202020202023A313131322C32312C2C2C2C2323232C2C2C2323232C2C31313C32
4246464C4A4F4F544C5D574C3B4C4F574F4F4F4C20020202020202020202020202020202
02020A0202020202020202020202020202020202
02020A020202020202020202020202020202020202020202020202020202020202020202
02020202020202022C31313132322C2C2C2C2C31232323232C2C232323232C2C2C313244
4446464A4C54544F545D575D4F4F414F4F4C4F4C0A0202020202020202020A0202020202
0202020202020202020202020202020202020202
020A0202020A020202020202020202020202020202020202020202020202020202020202
02020202020202063B3231322C2C312C312C2C2C23232C23232C232323232C232C313A32
433C4646464F4F57544C57574F414F3B574C4F4C0A02020202020202020202020202020A
020202020202020202020A020A02020202020202
020A02020202020202020202020202020202020202020202020202020202020202020202
02020202020202443C31202C2C2C2C2C2C2C2C2C2C232C2C2C2C2C232C23312C2C2C3131
433C464C4C4F545454544C574F4C4F4F414C4C4C0202020202020202020202020A020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020202
0202020202023F51322C312C2C232C2C2C2C2C2C232C2C2C3131232C2C312C2C31323143
424646464C4A4E5457544C4C574F4F4C413B4C4C02020202020202020202020202020202
0202020202020202020202020202020202020202
0202020202020202020A0202020A02020202020202020202020202020202020202020202
02020202024A83632C2C2C2C2C232C2323232C2C2C232C2C2C2C23232C31323C32323C3C
46463F4A464A5454544F5757634F4F4F4C4F424C02020202020202020202020202020202
0202020202020202020202020202020202020202
020A020A0A02020A02020202020202020202020202020202020202020202020202020202
020202020F5193202C31312C23232C2C23232C2C2C2C2323232C2C2C3131443C46464A46
464646463F4A4C54544C4C5754544F544F4F4F1902020202020202020202020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020202
0202020A587B2C322C2C2C2C2C232C2C2C2C2C2C2C2C2C232323232C2C3132463C46464A
463F464A4A544C4E544C5F57574F5454544C4C4102020202020202020202020202020202
0202020202020202020202020202020202020202
02020202020A0A0202020202020202020202020202020202020202020202020202020202
0202023F772C3231312C2C2C2C2C2C2C2C2C2C2C2C2C2C2323232C3132434246464A4A4A
4A4A4A4E4E544C4C575757575754574F4F574C4C20020202020202020202020202020202
0202020202020202020202020202020202020202
020202020202020A020A0202020202020202020202020202020202020202020202020202
020234513A322C2C2C2C2C2C2C2C2C3131312C312C2C23232C2C2C3132444C4F4F4F4F54
4F54545457575757574F57575754576363574C574F200202020202020202020202020202
0202020202020202020202020202020202020202
020202020A02020202020202020202020202020202020202020202020202020202020202
0202773F232C2C31312C2C232C2C2C3131312C2C2C23232C2C232C447244728383838383
8371544C5757574F635B5457574F57575457634F4F4F0202020202020202020202020202
020202020202020202020A020202020202020202
0202020202020A0202020202020202020202020202020202020202020202020202020202
022077232C312C2C312C2C2C2C2C2C313231312C2C2C2C2C232344444472728383837283
838383835D574F4F54544F575757575754574F4F4F41420202020202020202020202020A
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020202
147720312C2C2C2C31232C2C2C313A3A3A313A2C2C2C2C44440F444472838894A6A68394
8D8D83836E835B5454545B575757574C5757634F4C574C0A020202020202020202020202
0202020202020202020202020202020202020202
020A0202020A02020202020202020202020202020202020202020202020202020202020A
3F3F3231312C313A2C2C2C2C2C313A463A433A2C232C444444444C7193A6A6A6A6A6A693
A6A6A68D8387605D635B5B546357574C5757574F4F574C420A0202020202020202020202
0202020202020202020202020202020202020202
020202020202020A0202020202020202020202020202020202020202020202020202021B
5823323131313131312C2C2C31313C464646312C2C4443437271886E5D4F9A44417D4F87
ADB5ADA68D876E6E4F5466545457575F574C574F57574C41160A02020202020202020202
0202020202020202020202020202020202020202
02020202020A02020202020202020202020202020202020202020202020202020202174A
932C31312C3131432C232C233A3A3C4E4E462C2C43725488ADB8274F1414202042281920
83568AB59393876E6E5B5B5463574C4E4C57635757574C4F410202020202020202020202
0202020202020202020202020202020202020202
02020202020202020A020202020202020202020202020202020202020202020202022558
4A31312C2C313C46232C2C3143434E6363314483837EE0874FA6718D4C12162094716C93
6D28517A8AB5AD6C605B666663574C4A4E4E57574C57574C4C1416020202020202020202
0202020202020202020202020202020202020202
0202020202020202020202020A0202020202020202020202020202020202020202071B83
20312C31313A46462C2C2C2C434A5F745F4CA6CE76422316160A0A16120A162332202020
14B87D445E7BAF9A9363666663574A3F4A4E574C4F4C4C4C4C1E020B0602020202020202
0202020202020202020202020202020202020202
0202020A0A02020A020A020202020202020202020202020202020202020202020228517F
32312C31313A46312C2C2C2C435F747E73B8DD921923161616120A16120A161632121620
203F27A281A09BAF9A73546663574A464A4A4E57574C574C4C3B010A0A02020202020202
0202020202020202020202020202020202020202
0202020202020202020202020A020A0A0202020202020202020A020A0A020A0A021D584A
312C2C31314346312C2C23314A5F7171CEE0C87D4A162C1231160A2C160A162C4F121620
2C141420AC5EF3F3B8B56E5B5B574E46464A4E4C4F4C574C57411B0C0B0A020202020202
0202020202020202020202020202020202020202
02020202020202020202020202020202020202020202020A02020202020202020177832C
32313131313C31462C2C2C315F636F6EAFC4E088717446314C231654311631544F46202C
54322C324F3B3A3A92C49A5B5B574E463C3F4A574C576357574C1E261B19010202020202
020202020202020A020202020202020202020202
020A02020202020202020202020202020202020202020202020202020202020C775B7014
313131313C463A462C2C2C32717174544F548DA68888744F715F5F5F4C44938D8D715F54
935F324A413B4F3A6BDBC46C5B574A463C464A57574F5B4F57413B010B100F0202020202
0202020202020202020202020202020202020202
02020202020202020202020202020202020202020202020202020202020A3F7F83A9512C
31313143433C4354312C31445F7E4A4C322C313144424C4C4F4C4F4F72725D638D8DA693
93934171733C604F5EECE7AC6E544E463C464E4C57544F574C4C41020A0F0B0102020202
0202020202020202020202020202020202020202
020202020202020202020A0202020202020202020202020202020202060B7F7788912C44
3131313C3C443C3C312C3143547E5442232C23232C232C2323232344444442424C4F838D
8387939A9A669A7DC4E3E794AC5B544646464A57574F5B635757413D2501060F0A020202
0202020202020202020202020202020202020202
020202020202020202020A02020202020202020202020202020202020F1B77837FA02C32
31443A32443232323144443C546371422C23232C2C232C2C23232C2C313A4646463C4E4A
545D636E8387939AAFCECEB8C46E574646464E4C57545B6357574C287B160A0A0A020202
0202020202020202020202020202020202020202
0A02020202020202020202020202020202020202020202020202020206586F567D772C31
31313A323131313232313232545F744A322C2C2C2C232C2C232C232C314346464A46464A
545F57635B63635D5B6E73717E71633F46464A574F575457634C4C212857020A02020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020157313246463232
31313A323131442C313131324A5F63743C322C2323232C2C2C23232C4446464E46464A4A
5457544F5B54545B5B545B5B605B663F4A464E5757545454574C4C273F10190202020202
0202020202020202020202020202020202020202
0202020202020202020202020202020202020202020202020202020A28322C312C321432
3244312C2C2C312C31313132464A5F634E3231232323232C2C2C23233A46464E4A464E4E
5457545B6071606560606E5B6654634E464A4C635B5B6654574F4F255B1B020202020202
0202020202020202020202020202020202020202
0202020202020202020202020202020202020202020202020202020131312C3123323231
323131312C2C2C2C232C2C443C46545F6346322C232C232C2C31232C3132465F5F544E57
545B4A6065606C6565656C65656E4C664A4E54635B5B5B54544C4F28631D020202020202
0202020202020202020202020202020202020202
0202020202020202020202020202020202020202020202020202020F312C313143323131
4431312C2C23232323232C3144464A5F744E462C2323232C2C2C312C3242544F4F4C6363
666665606C65656060656571655463544C5757635B5B5B544F574F2877511D0202020202
0202020202020202020202020202020202020202
02020202020202020202020202020202020202020202020202020A3A312C3C434E311431
3A312C2C2323232323232331443C46545F5F462C2C23232C4443323131434A54544C7354
4F5B6C6C65606066666565657163544E545F574F5B5B5B634F4F4C3A5B581B0202020202
0202020202020202020202020202020202020202
0202020202020202020202020202020202020202020202020202312C3123325F4C313231
31312C2C232323232323232C323C464E5F635F3223232C312C3131312C313C464A4C4C5B
676C716C606560666E666566574A4E4E575757575B5B5B4F634F4F365F09020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020231312C234A4A4C443231
44312C23232323162323232C313A43464E5F5F3C2C2C232C2C232C232C3142424A415757
57606C676C6560665B6E634C543F4A4A5754575757545B4F544F4F557F6351020A020202
0202020202020202020202020202020202020202
020A020202020202020A020202020202020202020202020202163A312C32634E3F324431
31312C2323232316162323233132444346545F4A442C232C2C2C2316232C32464A4F4C57
57574F63676471656E57574A4A4A4A4A545F5763575B5B5B544F41517B9377380F0A0202
0202020202020202020202020202020202020202
0202020202020202020202020202020202020202020202020232312C323C715632324431
31312C23231616232323232C2C3231444A4A4E42322C2C3A312C23232C313C545757574F
4F5B5B5D66676C6E5B4C4F4A46464A3F414C4C574F574F5B4F4F41666F8A945851260202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202124331434E57634132443131
312C3123232323162323232C313131443C46464A2C2C2C323C312C2C3244464C5756565B
4F5B5B5B656D7166574F4A4A464A4A4A4C4C544C575754575757415B666C675128060202
0202020202020202020202020202020202020202
0202020202020202020202020202020202020202020202022C3A5F7493875B4A1E313131
312C2C2323232323232C232C2C3132443C423243312C313C4232313144464E54635B5B60
60606665676F6C5D4C4A4A4A46464A4A4C5457575763545B6341415B5B5B5B3A02020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202443A71948771574F32312C31
2C2C2C2C2316232323232C2C31443243423C322C2C232C312C2C31443C464A4C5B4A6460
6564657171716E574C4A46464A4C4A4A4E545757634F4F5B4F4C3B656566662702020202
0202020202020202020202020202020202020202
02020202020202020202020202020202020202020202022044437174876C4F4632312C31
23232C2323232323232C2C44314432424344322C2C2323232C2C2C3243464A575B606064
64646460605B4C4C4A4A3F3F463F4A544C4C57575D5D5D5B5B4F3B71715B5B4102020202
0202020202020202020202020202020202020202
0202020202020202020202020202020202020202020202443A445F716C6C4C42322C312C
232C2323232C232C2C3132313231443C4646422C2C2C232C2C2C2C31324A54575B4A6065
606060545B574C4F4F46464A464A4A4A5457574F565B4F5B5B563B6E6E664F5B02020202
0202020202020202020202020202020202020202
0202020202020202020202020202020202020202020223463A2C5F6371644C3C312C2C2C
2323232C2C2C2C313232313144323C3C46423C312C2C312C2C2C2C3144465F575B4A6060
604A4A5B544C4C4A4A46463F4A4A544C4C576357635B5B5654563B4F63544F6E14020202
0202020202020202020202020202020202020202
02020202020202020202020202020202020202020202314E313F4F636764413C3232312C
232C23232C3131313232324632324246463232322C3131312C2C2C2C314654575B5B5760
4A4A5B4F63574F4A3F4A3F4A3F4E544F54574F5B54565B5B5B414F65544F41734C020202
0202020202020202020202020202020202020202
0202020202020202020202020202020202020202020A4E5F6C5D6F6F6D673F32312C2C2C
2C232C2C31313A31323C42423F42423C32323232312C2C312C2C2C31324254575B606060
604A5B5B4F4C4F3F4A544A3F3F4A4A544C4C4C574F565B5B564F3B8399544173730A0202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202315F6E6C7F747776573F312C2C312C
2C2C2C312C2C32323C323C424A3F3F3F42323232322C2C31312C2C3A324654665B606460
6560565B4F4C4C4F414C54544F5454544C564C4F565B5B4F4F4F277D9A604F5B66440202
0202020202020202020202020202020202020202
0202020202020202020202020202020202020202024374609B5B777F706B3F312C2C2C2C
312C312C2C202C2C2C2C2C3242464F4F4C4F3C3232312C312C2C3131424A576E60656560
64665B4F4C57574C4C4A4F54574C4C574F4C4F564F545B5B56274F6D6F7165576E570202
0202020202020202020202020202020202020202
0A020202020202020202020202020202020202020A4E716B7D777F6357443F312C322C31
3231321E322C2C2C2C2C192C2C1E3F3F4C574C4132322C2C2C2C3131463F575B60606464
604A5654574F57574C4C4C4C564F57574C574F4F545B545B56274F6D8AACC49966730202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020216744F747DD17B8370573F313132322C
2C313132414A41545760575151566056575D574C3F322C2C2C2C2C31424A576065657164
576060604A564A4F4F4F41414F4C4C4C4C4C4F4F4F545B4A56414F5E8AA2ACAF7E6E0202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020231744F679277777F77703C2C31313131
2C323C41645E88706F67676B577A5E7D576E6C4C3F3C312C2C2C2C31424A636660716456
67514A565B604A5B5B4A4F4C4C414C4F4C4F4F565B4F4A4A4F4F4F557AA2A2AF7E630202
0202020202020202020202020202020202020202
02020202020202020202020202020202020202023C944F56D1E37F8363473C2C32313A3A
313131323C414A7B551B3F555178889B6D83A2ACA24E3C2C2C2C2C313C4A57666551566D
674A4F4C4C4C4C4C5756565B4A544C414C4C4F4F4A5B4A5B4F4F4F5E83A2A2AF935B0202
0202020202020202020202020202020202020202
02020202020202020202020202020202020202024A99544C83625883775A32312C323232
312C3132324F4C573D58A01D01785A8828257FA26646322C2C23232C3246576671677D7D
6D54414141414C4F4F41414F56544F4C414C4F54544A544A4A4F4A57768A8A9A71630202
0202020202020202020202020202020202020202
020202020202020202020202020202020202029B43996354705B7F839357323131323232
312C31312C3C4C4C42415777837793933F837D9A574A32312323162C3246576E676D6D83
DB9464606F6D5E7A6F6D57514A54544A4F4F4F4A574A4A5B5656576F817A837E6E6E0202
0202020202020202020202020202020202020202
02020202020202020202020202020202020693A0434A434A7F62837F83573C313232323A
2C2C2C2C3131324A4C4C3B556F5A6F7F836D7D4E4E4E32312316162C3C46576E716D677D
717F21190788DB9B7F57797F6D5E51515657575760604A5B564A517F77776F73667E0202
0202020202020202020202020202020202020202
0A02020A0A02020202020202020202020277C4B85F434A5F774434777F6332323231314A
3231322C2C3132324A4F4F414F516D7D6D7D5463543F3C31231623323C3F5766716D676D
837A3D0F3F3D99347F774481776F576F716D71604A544A4A5B57557F7B577F5B57990202
0202020202020202020202020202020202020202
0202020202020202020202020202020244937FD19B747DAC585F7F62833F3A3A31322C3F
6446322C2C23232C323C4A4A4C5754546363574E3F3C312C232323313C464C5B646D7167
6D7D646D70075E1870773D28447770476D6D65544F4F4F4A4A57634A7B63884F71990202
0202020202020202020202020202020202020202
0A020202020202020202020202020202939383D1F3F37F8358636262836B324432322C32
5D4F4C322C23232C2C32424A57574C5757634E4E463C3C2C23232332424A414F65715656
71564F51644A5B7793835A5858576F5667565465604F4A4A5457707B7783925D93AD0202
0202020202020202020202020202020202020202
0A02020202020202020202020202020AA093937FC4D1585F625B5B7F7F3F3C3A3131322C
32604C563C202323202C323C4C4C41576673734C3F3F322C23232C32464A4C4F4A717165
60656D4F4F6B577F51886363557455516465574F4A4A4A4A4A557B635193934FAD990202
0202020202020202020202020202020202020202
0202020202020202020202020202021993637793938363637877837793573C3A3A313231
2C42414867575751516F57577776767F7A838360413F322C2C31313C464A414F60657171
566054654F544F575755745574566060665B4A5B544F4F544A57775883A99267AF990202
0202020202020202020202020202020202020202
02020202020202020202020202020218837F7F7F627F837F62775B8383633C3231323131
312C32425644343A5E5E6F636B79819B816D675B4A44322C2C32323C4646414C60646D6D
6D64604C5754606556566765605B664A564A5B4A4A4A4A4A51705F3444A97667A29A0202
0202020202020202020202020A02020202020202
0202020202020202020202020202021793B8A9A962B87F997F7762635147413C3A313131
2C2C2C31324F56563A605651644857676760574232312C2C2C3A44463C3F414C6067927F
927D566054575457575454544A4A54564A4F564A4A56544A5577625F6277646DA2990202
0202020202020202020A02020202020202020202
02020A0202020A02020202020202020288777F627F837F787F7F5B6251634F3C32323131
2C2C2C232C3232322C2C2C1944194414442C3232322C2C2C32323A423C423F4F4F606F7F
94946B67654F4F4C574F4F544F5B4F4F4A4F4A544A4F4A54638362585B636593A29A1D02
0202020202020202020202020202020202020202
0202020A0A02020202020202020202027B7FB8627F626277997F7F8351474A3F3C3A3131
2C232323232323232316232323232323232C3131322C23313232323C3C3C3F4C3F424F67
79777B93777F6D544F4F5454544A4A6060645160564F5B517B627F5B44938367AC6D4A0F
0202020202020202020202020202020202020202
020202020202020202020202020202028877837F627F7F7F997F62837B574A4C463A3131
2C2C232C2316162316162316161616232323232C232C2C324444323C463C463F423F3B3B
4F67797792937792775156646057516D6F6F674F5B565B55937F7F7F58A994836D6B451B
0202020202020202020202020202020202020202
020202020202020202020202020202025170637F7F627F7F77787F775157574F3C3A3131
2C2C23232323161616231616232316162316232C312C313231313C3C463C3C423C42423F
3B4C565557777B77777F776F44776F6B6F5E564F5B4A606B83777F585FA9C4CDC8934518
0202020202020202020202020202020202020202
020202020202020202020202020202027B7B77837F837F7F62998383514751544A3A312C
31232C232C23232316161616161616232323232C2C2C323232323C433C423C423C3C3F4A
3F41414F4A6757797B7B88887F7F7974674A564A4A6064777F7F627F6277FFEC93584702
0202020202020202020202020202020202020202
020202020202020202020202020202015A7B5A6362837F7F7F5F5F585157553A41463131
312C2C2C2323231616231616161616162316232C2331313131433C3C3C46463C3C3C424C
3F4F41414F4F4A60516D6B6F6B74644A4A5B604A4A605177837F7F83626277838383451B
0202020202020202020202020202020202020202
020202020202020202020202020202207B4A7B7763837F7F7F7F7F83777057574C3C3A31
312C232C2323162316161616161616162323232C31313232323C3C46463C4232463C424A
4A4A41414C4F4F56566060606C4A4A5B4A5B60664A645593837F62625F625B777F835F4A
0202020202020202020202020202020202020202
0202020202020202020202020202021B7B7B7763635F7F7FB863837F777757554F463231
312C2C232323162323231616161616162323232331322C313A3A463C3C463C46463F463F
4A3F54414C414F414C4C4F4F4F5B5B54565B5B5B6051768383627F628362627F7F77774A
2102020202020202020202020202020202020202
0202020202020202020202020A020244774A5A516388837F7F7F7F7F83777B63513F3C3A
2C2C2C2C23232323231616161616161623232331323131323C3C3C46463C3C46464C4A4A
3F3F4F4A414C414C4C4F4F565B564F4F564A5B4A516B7B637F625B63785B5B627F785F77
2602020202020202020202020202020202020202
0202020202020202020202020202025A77514A516358837F777F7F837F777B7071543C32
312C2C2C2323161616162316161623162323232C3131313C3C463C464646463C464A463F
4A4A4C414C4C41574F4F574F4F4F4A4A4A4A4A605547587F775B5F785B78777799778377
3D02020202020202020202020202020202020202
0202020202020202020A020202020251514A4A7B5158837F8377B87F83835A577F574C3A
312C2C2C232323161616161616162316232323232C2C443232424646464646464A3F4A4A
4C4E41414C4C4C4C4F4F4F544F4F545B4F5B60516B7B837F6283625B5B77777777627F77
3F02020202020202020202020202020202020202
0202020202020202020A0202020A02477B4A514A5163637F83777F7F63634A4757674C3C
3A312C232C23231616161616161623162323232C2C3132323C4646464646464E3F4C4A4A
4A4C4C4C4C4C4C574C574F574F5B4A4A5B60575E63778362638378785B7899785B627F63
3402020202020202020202020202020202020202
0202020202020202020202020202027B777B51514A58588383837F83837F77704467543F
3C312C2C2C2C2316161623161616231623232C2C3244313A4246464A4A46464A4C4A3F4A
4C544C4C574F4C574F54575B4F5B5B5B606551577051776362625B777878997877627777
0A02020202020202020202020202020202020202
0202020202020202020202020202024A4A7B4A4A4A4A51938383778383637B7F6F55714A
3C3131232C232C2323161616162316162323232C2C3131463C463F4A4A4A4C464A54544C
4F4F4C4C4C4F574F4F4F4F56604A5B4A6464573F7B58837777775B78789977785B628345
0202020202020202020202020202020202020202
02020202020202020202020202020A7051514A704A456358837F83836377515A636D6457
46322C2C2C2C232316232316161616232323232C31323C3C3C463F4A4A3F4A464A4A4154
574C4C574C57564F5B5B4F5B545B4A4A5155577777837F5B385B5B78785B78777777835A
0202020202020202020202020202020202020202
0202020202020202020202020A020A515177514A4A4A51517F7F63836377587B6F6D644F
3F3231312C2C23162316162316161623232C232C32443A4646464646463F4A4E4A4A5441
414C4C5756564F4F4F564F5B5B4A4A575E6B6B7B778383626283627F625B775B627F8363
0202020202020202020202020202020202020202
0202020202020202020A020202020A5A4A93515A4A454A51937F8363836370476B6B6D65
4C3C3231312C2C2316231623232323232C2C2C2C323C3C43464A4A4A4A4A4F4A4A4A4F4F
54414C56575D4F4F4A5B565B5B6057515576477B9383587F5F835B7862625B787862580A
0202020202020202020202020202020202020202
020202020202020202020202020A024758587B4A51454A77517F6363586377473F7F6B67
573C32322C2C2C23232323232323232C2C3132313C3C324646464E4A4A4A4E4A4A4A4A54
4C4C4C4C574F4F565B4A5B5B4A4A51556B477058835F6262777F5B5B78785E99787F7002
0202020202020202020202020202020202020202
0202020202020202020A02020A02023851587B51474A4A51518362775851637B5A476F6D
5B3C3C31312C2C2C232C23232C2C23312C2C2C32323A3C464A4A4F4E4F4A54544F4A5454
544F56635B4F5654545B5B5B60645E6F777B51777F7F7F62625B5B785B5E997877833F02
0202020202020202020202020202020202020202
020202020202020202020202020202345A5877584A514A58584A83627763517747707F55
644A32323131312C2C2C312C312C31322C3131443C3C4646544E544E4F4A4A4A4A4E5F54
4C4C575757544F4F5B4A606051556B77707777837F6262627F625B5B78997877837B0202
0202020202020202020202020202020202020202
020202020202020202020202020202343F587751585A3F635158A9837F584A63517B7B6F
6D4F4A3C313131322C31312C2C2C313A3232443C433C4E4E544A4E4E4E4E4C544C5F4C57
5757634F574F565454606464676B777F5193837F777762626262625B62789962587B0202
0202020202020202020202020202020202020202
0202020202020202020A0202020202253851514A514A5A517758587F63635151585A4A57
6B60544A323C323231313131313132323243313C4646544A4E5457544C574C5F545F5763
57575D574F5B5454604A575E556B7F7B77837F7F77775B777F625B78995E786383440202
0202020202020202020202020202020202020202
02020202020202020202020202020219445A774A51515A3F634A63638363584A514A5147
7751574A3F3C3C3C313131323144323C323C3C42424A4A545F545F63575F634E57575754
665B564F4F5B5B4A575751556F777B7B93837F77787878777799995E5E5E776358250202
0202020202020202020202020202020202020202
020202020202020202020202020202023F5A4A514A58514551515F5F635F58584A587770
7B6F55574F4A4A3F3C323C323232323C3C423C3C3F635763575757636357576357635766
5B665B5B60575764516D6B6B6F7B77937F8362777777787878995E5E5E78836393020202
0202020202020202020202020202020202020202
020A02020202020202020202020202021D474A7B5A5145455177637F83835F514A5A4483
7070776B5164604F3B413C3C3F1E3F463C4E3C3F3F4C4A5B5B575B5B5B5463635D635B5B
66666E6E566064675E6B6B777F7B77A07F6277789978787878995E5E5E5B836344020202
0202020202020202020202020202020202020202
0202020202020202020202020202020210445A584A5151514558778383624A58584A4A5A
63704757575E6D574C574F4C3B4C3B41414C3F4C4F655E676765716E5B715B65736E5B5B
666060646464675E556F777F9277837F7F99777878787878995E5E5E78637F7F0A020202
0202020202020202020202020202020202020202
02020202020202020202020202020202023F3F51775A77514A5183778383636345394A51
4A4547443F446B34515E5551515E515754604F57556B6B6F6B6B6D676F67716460717164
64646751676D6D57637F7F7B77937F7F627877789999995E5E5E5E785F837F6302020202
0202020202020202020202020202020202020202
02020202020202020202020202020202023A444A584A5151514A44835F837751514A4545
4A3F5145454763576F44446B3F576B6B51545155576F6F637663717D7D6D6D6D716D6767
746D7D5E6D74576F777F929393837F7F7777787899995E5E5E5E5E83627F832002020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202344A51514A3944475883835F6377454A3F18
513F443F45636B474457636363776F776B6B556B6B44577F7F7F7F766F7174746D6D746B
6B6B6F6B6F6F6F7F7F7B7793837FA96278789978995E5E5E5E5E787F5F62880202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202135A51514A58393951636263584A45454545
3F513F3F4463444447705A5A7B47707F7F5763445A475A5A7F7088887F7F6F6F6F6F7657
6F7F7F7663777F477B9383836362775B7778785E99995E5E5E997F835B883A0202020202
0202020202020202020202020202020202020202
02020202020202020202020202020202020201385A51514A5839455163634A513F3F4A44
45515A47574447477F7B585A58515A775A7B477B514551837758587777777B92927B7B7B
7B7777777777777793A07F7F625B7878775B78785E5E5E5E787F7F5B637B020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202061D5A51514A5151514A51584A3F45443F3F
4A514A7070577F7B7B58515863635158835A515151445858836363838393937777777777
77939377936383938363627F776278787878785E5E5E5E9958627F935106020202020202
0202020202020202020202020202020202020202
0202020202020202020202020202020202020221344A4A774A4439513F4A584A3F393F3F
3F3F45475A7B4A7B5A6351514444514A5163515177635F635F7F7F83837F7F937F836383
8383837F837F837F837F7F6277627899785E995E5E5E5E6262835B934802020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020F184A514A51394A51513F3F385845454A
58634A5A57774A705151515858515A445F5F44838383837F7F62627F7F7F8362837F7F62
7F837F7F837F7F777F6277997777785E78995E785E5E7862635B83360202020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020A10444A514A5163583963453F3F3F4458
3F3F47517077585863635151835858445F588358835862625B625B6262627F777F7F8358
776262777F5B7F775B7F5B62787878995E5E5E5E786262627F7F630A0202020202020202
0202020202020202020202020202020202020202
02020202020202020202020202020202020202020F0C70514A4A4A5851394451453F3F45
3939584A7B636351585F5858345844515F58836258626262625B775B625B625B62627783
787777777F7F7777786277775B7878785E5E785B625B637F837F02020202020202020202
0202020202020202020202020202020202020202
0A02020202020202020202020202020202020202020F4451584A4A395139513F3951513F
3F38516377838358588351635834445F7F62585B5B5F385B5B5B78787862627778626277
625B7862786277785B7899785E5E785E5E99785B5B583483700A0A020202020202020202
0202020202020202020202020202020202020202
02020202020202020202020202020202020202020202344451584A5851444A44393F4A51
584A635163837F7F58835F835F5B7F5B58835B62785B5B7F5B7878785B7878625B78785B
5B5B62995B7878785E785E5E5E5E5E995B5B77627862A96F0A0A02020202020202020202
0202020202020202020202020202020202020202
02020202020202020202020202020202020202020202063D44514A514A3951515144514A
514483516383627F5F5F7F585F345B347F5B625B5B5B62627878785B7878786262787878
5B5B78585B5B78995E995E5E5E785B385B78585B62837F260A0202020202020202020202
0202020202020202020202020202020202020202
02020202020202020202020202020202020202020202021B3447584A5139393F394A4545
4544834A637F62627F5F627F7F44785F78625B785B78785B5B7878785B5B785B835B5E78
5B5B62785B785E5E5E5E99785B585B5B5B62837F777B6B06020202020202020202020202
0202020202020202020202020202020202020202
02020202020202020202020202020202020202020202020221384A514A58395839183951
5844624A835F5B625B7F7F5B7777785B5B785B785B785B785B787878785B785B34343478
785B5B5B385B62386262625B5877785B5F7F7F77776F4402020202020202020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020C4445394A58394545453F
45394451587F585B5B787F5B5B77627862785B78787878787862785E7878625B5B440051
185B585B785B5B5B6258625B5B4458626377837B773F0202020202020202020202020202
0202020202020202020202020202020202020202
02020202020202020202020202020202020202020202020202022834454A395851394545
454544455883837F785B62625B787778625B5B995B5B785B785B78785E7878343422183F
58583434445862625B628393585F83638377777F6F0A0202020202020202020202020202
0202020202020202020202020202020202020202
02020202020202020202020202020202020202020202020202020228443F45395851390C
3F3945517744637F62785B62787777625B62785B785B5B7878785B787878785E18343434
3F0B3F174545454558836262636363584A7B7F570A020202020202020202020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020E444A394A58514A
450B113F58587763835B5B627F775B777862787878785B7878785B5B5E78625B78383451
1844385B625F63585858584A5151517777706F3402020202020202020202020202020202
0202020202020202020202020202020202020202
02020202020202020202020202020202020202020202020202020202020263453F514A45
3F3F3F383F636363635F5162445F7F5862785B785B5B785B7862385B5B5B62345B584422
51455B62625862625B5F7F446383777F6F790F0202020202020202020202020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020202123F4A4A4A39
453F381D284A9363638383635858587F5838835B5B5B62585B5B34623458625818343434
386244445F58446383517783777B7B77570F020202020202020202020202020202020202
0202020202020202020202020202020202020202
02020202020202020202020202020202020202020202020202020202020202063F4A5851
4A3F383828383F4463835F838351515844455B7F785F3458341C444434094A0C38513F18
4551515151585851514A474A517F6B570A02020202020202020202020202020202020202
0202020202020202020202020202020202020202
0202020202020202020202020202020202020202020202020202020202020202020F4445
4A3F28281B1D28385A3F445158B851514517513958225B0B45183F091717183F0B0C4539
4A475A455A5A5A4A58777B47767036020202020202020202020202020202020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020F34
3F3F4A454528092838283838283F454A183F113F281845581734451811454A4A514A4547
5A5A70517B7B4A7F57776B477B1B02020202020202020202020202020202020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020202
120B453F45381D2838384438283838380C3F45380B3F091734343463583F4A4A4A585877
777758707F47577777577B700B0202020202020202020202020202020202020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020202
021028473F3F0B281B281D28284428341D283428381D45283F4A45455844513F45514A4A
7F5A7747633F576B7F513602020202020202020202020202020202020202020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020202
02020202020B194A0C0926281B1D1B3438283D3434343F3D34344444383F63446F634444
445E55553F5A515710020202020202020202020202020202020202020202020202020202
0202020202020202020202020202020202020202
0A0202020202020202020202020202020202020202020202020202020202020202020202
02020202020206071010260E0C2525253D3D343F343D363D3D3D34343D443F44345E3D55
3F443F5A5A3F1B0202020202020202020202020202020202020202020202020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020202
0202020202020202020202020A0B0C070C262636344428112834343D384438443F443F44
574457340702020202020202020202020202020202020202020202020202020202020202
0202020202020202020202020202020202020202
020A02020202020202020202020202020202020202020202020202020202020202020202
020202020202020202020202020A020A0A0A0B100E190E1D34343434343D3438383F5745
44190A020202020202020202020202020202020202020202020202020202020202020202
0202020202020202020202020202020202020202
0A02020A0202020202020202020202020202020202020202020202020202020202020202
020202020202020202020202020202020A0A0202020202020A0601100F060A0202020202
020202020202020202020202020202020202020202020202020202020202020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020202
02020202020202020202020202020202020202020202020202020A020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020202
0202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020202
0202020202020202020202020202020202020202
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cos) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 12.813 moveto
(H) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 12.813 moveto
(L) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F9FAFAFAF6F6FAFAF6FAFAFAFAFAFAFAFAF6F6F6FAF9F9F4F4F4
EDF3EDEDEDEDEDEDEDEDEDEDEDEDE6ECEFDEECECEFEFECFFFFFFFFFFFFFFFFFFFFFFFCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFF
FCFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCF5FAFAF6F6F6F6FAF6FAFAFAF6FAFAFAF6F6F6F9F9F4F4F3F3F3
F3EDEDEDEDEDEDE6EDEDEDE6EDE6ECECECECECEFECEFECFFFFFFFFFFFFFFFCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFCFFFFFFFFFFFCFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCFAFAF6FAFAFAFAF6F6FAFAF6FAF6FAF6F9F9F9F4F4F4F3F3F3E3
EDEDEDECECE6EDEDEDE6EDEDE6ECE6E6ECE6ECECEFEFFBFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAF5FAFAF6F6FAF6F6FAF6F6F6F6FAF9FAF9F9FFFFF3F3EFF3F3F3
F3EDEDEDEDECE6ECECE6EDE6ECE6ECECE6ECECECEFE3FCFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFFFFFCFFFFFFFCFFFFFFFFFFFCFFFFFCFFFFFF
FFFFFFFCFCFFFFFFFFFFFFFFFFFFFCFCFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F9FAFAFAF6F6F6F6FAFAF6F6F6F7F9FBFFF3F3E3E3F3EDF3F3F3
F3F3F3EFEDECECECECECECE6ECE6EFEDECECECECECF3FFFFFFFFFFFFFFFFFFFFFFFFFFFC
FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF6FAFAF6FAF6FAF6F6F6F6F6F6F6FAF7E2E2E2EAEAEEEDE3E3DADA
DAEDEDF3E0F4ECECECECECEDE6E6ECE6ECECECECECFBFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFF
FFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF6F5FAF6FAF6F6F6F6F6F6F6F9FAF9F6FAF6FAF9E2E2EAEDE3E7DA
E3E4E3F3DAECECEFECECECEFECDEECECEDECECECECFCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAF6F6F6F6F6F9FAF6F6F9F9F9F6F6F6F6F6F9FAE2EAEAEEF3F3
E3E4EAE4E3DAE6E0E0ECECEDECECE6ECE6EFECECECFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF9FAFAFAF6FAFAF6F9F6F6F6F6F6F6FAFAFAF6F6F6F9F4EAF4EEF3
EEE4E3E4EEE3DAE7DAECEFEDECEDE6E6E6ECECECF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF9FAFAFAFAF9F6F9F6F6F6F6F6FAFAFAFAF6F6FAFAFAF9F0F0F9EA
EAEAE4E4E4E3E3DADAEDEDF3F3ECEDEDE6EDECEDE2FFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF5FAFAFAF9F6F9FAF6F6F6F6FAFAFAF6F6F6FAFAFAF6F6FAFAF4F9
EAEEEEE4EDE3E3E7EDDAE6EDEFEDECE6ECECECEDF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF6FAFAFAF9F9F6F6F6F6F6FAFAFAFAFAF6F6FAFAFAFAF6F6F6FAF9E2
E2EEEEEDE4E7E7E3E7DAE6DAECECF3ECECEDECEDFCFFFFFFFFFFFFFFFFFFFCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7EFF9FAF9F6F6FAF6FAF6F6F6FAFAF6FAFAF6FAFAFAFAF6FAF6FAF5F9
F0F4EEEEEEE3E3E6E7EDE6E6ECF3ECEFE6EDECEDFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFCFFFCFFFFFFFFFFFFFF
FFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF4F4FAF7F6F6F6F6F6F6F6F6F6F6FAF6F6F6F6F6FAF6FAFAF6F6F6FAFA
F0F4EEE4E4E3E7E7E7E7EDE6ECEDECECF3EDEDEDFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF4E4F9F6FAF6F6FAF6F6F6F6F6F6FAF6F6F6FAFAFAF6F6FAF6F6FAF9FAF0
EAEEEEEEE4EDF1E7E6E7EDEDE6ECECEDF3EFEDEDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE7C4E0F6F6F6F6F6FAF6FAFAFAF6F6F6FAF6F6F6F6FAFAF6FAF9F4F9F9F4F4
EEEEF3EDEEEDE7E7E7E3E6E6DEECECECEDECEAEDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCFFFCFCFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF3E4B5F7F6FAFAF6FAFAF6F6FAFAF6F6F6F6FAFAFAF6F6F6FAFAE2F4EEEEEDEE
EEEEEEEEF3EDEDE7E7EDEDE6EFEFECEFECECECFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCE3D4F6F9F6F6F6F6F6FAF6F6F6F6F6F6F6F6F6FAFAFAFAF6F6FAF9EEF4EEEEED
EEF3EEEDEDE7EDF1E7EDE0E6E6ECEFEFEFEDEDF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFEDDBF6F9FAFAF6F6F6F6F6F6F6F6F6F6F6F6F6F6FAFAFAF6FAF9F0EAEEEEEDEDED
EDEDEDF1F1E7EDEDE6E6E6E6E6EFE6ECECE6EDEDF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFCFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFEFE4F2F9F6F6F6F6F6F6F6F6F6FAFAFAF6FAF6F6FAFAF6F6F6FAF9E2E4E3E3E3E3E7
E3E7E7E7E6E6E6E6E6ECE6E6E6EFE6DEDEE6EDE6ECF7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFDBF4FAF6F6FAFAF6F6FAF6F6F6FAFAFAF6F6F6FAFAF6F6FAF6E2C4E2C4B8B8B8B8B8
B8CCE7EDE6E6E6ECDEE3EFE6E6ECE6E6EFE6DEECECECFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF1DBFAF6FAF6F6FAF6F6F6F6F6F6FAF9FAFAF6F6F6F6F6FAFAE2E2E2C4C4B8B8B8C4B8
B8B8B8B8DAE6ECECEFEFECE6E6E6E6E6EFE6ECECECF3EAFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7DBF7FAF6F6F6F6FAFAF6F6F6FAF5F5F5FAF5F6F6F6F6E2E2F3E2E2C4B8BBB0A1A1B8B0
B6B6B8B8D0B8E3EFEFEFE3E6E6E6E6EDE6E6DEECEDE6EDFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
EDF4F9FAFAF6FAF5F6F6F6F6F6FAF5EEF5F0F5F6FAF6E2E2E2E2E4CCB2A1A1A1A1A1A1B2
A1A1A1B6B8BCD2DADEE3E3EFDEE6E6EDE6E6E6ECECE6EDEAFCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3
E3FAF9FAFAFAFAFAFAF6F6F6FAFAF4EEEEEEFAF6F6E2F0F0C4CCBBD0DAE3B6E2F3D1E3BC
9A919AA1B6BCD0D0ECEFEBEFEFE6E6E0E6EDE6ECE6E6EDF3FCFCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7E7
B5F6FAFAF6FAFAF0F6FAF6FAF5F5F4F1F1EEF6F6F0C4E7BB9A9AF4E3F7F7F1F1EAF5FBF1
CDE0C991B2B2BCD0D0E3E3EFDEE6EDF1EDE6DEE6E6E6EDECF3F3F3FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3EEE3
EFFAFAF6F6FAF4EEFAF6F6FAF0F0F1DEDEFAE2B8B8D460BCE3A1CCB6E4F8FCF7B0CCDABB
E3F5E4D5C9919ADAE2E3EBEBDEE6EDEDF1F1E6E6EDE6E6EDEDF7FCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F3C4
F7FAF6FAFAF5EEEEF6F6F6F6F0EDE0D9E0E4A177DCEAFAFCFCFCFCFCF8FCFCFAF9F7F7F7
F79AD1E7DED4A2B6B2DEEBEBDEE6EDF3EDF1E6EDECEDEDEDEDFFFFEFF7FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFFFFFCFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7E4CC
F9FAF6FAFAF5EEFAF6F6F6F6F0E0D9D4D49A56C3FBFAFCFCFCF8FCFCF8FCFCFCF9F8FCF7
F7F3F4B1C8BBC6A2B6D4EFEBDEE6EDEEEDEDF1E6E6EDE6EDEDEFF3FCFCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFFFCFCFFFFFFFFFFFFFFFFFFFCFFFCFCF3FCFCFFF2E3EF
FAF6F6FAFAF0EEFAF6F6FAFAEDE0DDDD776085D1EDFCF6F8FAFCFCF6FCFCFCF6E3F8FCF7
F6F7F7F7AADE32329A91D0E3E3E6F1EEEEEDF1EDECEDE6EDE6F3FAEDEFFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFF3DBC4F6
F9FAFAFAFAF4FAEEF6F6F6FAE0DEE7D0A28560BBCCD9EEFAE4FAFCE7FAFCFAE7E3EEF7F6
E7F9F6F9ECEFF2F2C285B6E3E3E6F1EEF4F3EDE6EDE6DEE6E6EDFFEDFAFBF3FFFFFFFFFF
FFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEDDBCDCDF7
FAFAFAFAF4EEF5EEF6F6F6F9CCDDD9E7E3E7B6A1BBBBD9E3CCE0E0E0E4E2B2B6B6CCE0E7
B2E0F9EDF3EFECF2E06A85DAE3E6EDEEF4EEEDE6E6ECE3ECE6F3EFF3EFF1F3F3FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF4CCC4AAE4F6
FAFAFAF0F0F4F0E7FAF6FAE2E0D4EDE4F9F6FAFAE2EAE4E4E3E4E3E3C4C4DADEB6B6A1BB
B2B2F3DDD4F4D2ECDE3E55AAD0EFF1EEF4EEF1EDE6EFECE6EDEDF3FFFCF3EFF3FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7EFCCDEBDD7F6E2
FAFAFAF4F4E2F4F4FAF6FAF0E7D4E7EAFAF6FAFAF6FAF6FAFAFAFAE2E2E2EAEAE4E3B8B6
B8BCB2B6B6EBB6D1853D55BCAAE3E7EEEEEEEDE6E6ECE3DEE6E6F3EBEEF3F7F3FCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3DEC4CCBBF6F9
FAE2F5F9E2F9F9F9FAE2E2F4E7DEDDEAF6FAFAF6F6FAF6F6FAFAF6F6FAF5EEEEEEF4F1ED
E7DADED0B8BCB2B6A277779A85D0E6EEEEEEF1EDE6EFE3DEE6E6EDF5D4FCFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7E3DFE0D1D1F6FA
FAFAF5F9FAFAFAF9F9FAF9F9E7E0D9EDF9F6F6F6F6FAF6F6FAF6FAF6FAF0EEEEEDEEEEED
E7E0E6DEE3DEDEDAE3D0D4DDD4DDDEF3EEEEEDE6ECE6EFE6DEEDEDF0F7E9FFFCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3E9FAF9EEEEF9F9
FAFAF5F9FAFAE2F6FAFAFAF9EDE0DED9F4F9F6FAFAFAF6F6F6FAFAF6E2EEEEF1EEEEEDED
E7E6EFECE3EFEFE3E3EFE3E3D2E3EBF3EDEEF1E6E6EFEFEFE6EDEDF4EDF1FBFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF5F9F6FAF6F9F7F9
F9E2FAF6F6F6FAF6FAFAFAF9EEEDE0DEF1F9FAFAFAFAFAF6F6F6FAFAF5EEEEF1EDEEF1F1
E7E6EFE3E2DDE2E6E2E2D0E3EBEFDEF1EEEDEDDEE3E3EBEFE6ECECF5CDFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FAFAF6FAFAF9F9FA
F9FAFAFAF6F6F6F6FAF6F6E2F4EEE7E0DEEEF9F6FAF6FAF6F6FAFAF6FAF9EEE0E0E7F1E6
EFE3EFE2E6E2DAE6E6E6DAE6E6D0EDEBEDF1E7DEE3E3E3EFEFEDECF5DBF2F3FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FAF6FAFAF0F9FAFA
E2FAFAF6F6FAFAFAFAFAF6FAE2EEEDE0D9F1EEF6FAFAFAF6F6F6FAF6F9EAE7E3E3EDDEDE
EBEBE6E2DAE6E6E2E2E6E6DDE6EFDEE7EDE6E6DEE3E3E3EFECE6ECF5DEE4F2FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF5FAF6F4F0F1FAF7FA
F5FAF6F6FAFAFAFAFAFAFAFAE2F4EEE7E0E0EEF6F6FAFAF6E2F0F9FAFAF0EDE7E7EDD4EF
ECE3DADAE6E2E2EBEBE6E6E6DDDEE7F1E7E0E6ECE3E3E3DEECECEDF2CDB6FAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAF6FAFAF9E0EDFAF9FA
FAFAF6F6FAFAFAFAFAFAFAF6F9F4EEF1E0DEE0F9FAFAF6FAF6FAFAFAF6FAF4EEEDEDEDE3
DFDADDDAE2E6E2EBD0EBE6EBE6EDF1F1E6E6E6E6E3E3E3ECDEECECE5CBF1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAF6FAEDEDEDE2F9FA
E2FAF6FAFAFAFAFCFAFAFAF6FAF5F0EEF1E0E0F4F6F6FAF6F6FAF6FAF6FAEAEAEDF3E6E6
E6E2DADFDAE6E2EBE3D0DEEDE7F3EDEDE6E7E6E6E6EFE3ECEFECECEDCCDBE4F3FCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF5FAF6F9DEF1F3F9E2FA
FAFAF6FAFAFAFAFCFCFAFAFAFAF9E2F0EEE7E0EDE2F6FAF6F6F6FAFCFAF6F9EEEDE3EDE6
E6E6ECDEDFE0DDE6D0E6E6EDEDEDEDEDE7E0E6DEE6E3E3E3EFECF3EED4B5DEEEF3FCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FAF6F9F4DDE0F9F9E2FA
FAFAF6FAFAFCFCFAFAFAFAF6F6F9FAE2EDEDF1EAF9F6F6F5FAF6FAFAF6FAF4E7E6E6E6EC
ECE3E3DAEBDFDAD0E3EDE3EDEEEEEDF3F3EDEDE6ECE6ECE3ECECF3EBE7C9BCE3E4EDFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F0FAF0F1E6DEF3F9E2FAFA
FAF6FAFAFAFAFAFCFAFAFAF6FAFAFAE2F4EEEEEDF6F6F6F9F4FAF6F6F9E2EEEDE6E0E0E3
ECE3E3E3E6E3DDEBE6E3EDEDEEEDEDEDEDEDE7EDE6E6EFE6E6E6F3E3EBDADFE4F7F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F5E0D9B2BCE3EDFFFAFAFA
FAF6F6FAFAFAFAFAFAF6FAF6F6FAF9E2F4EAF9F0FAF6FAF4EAF9FAFAE2EEF1E7DEE3E3E2
E2E2EBE6DFE7DADAEDEDEDEDEEEEEDEDEDE7E6E6E6DEEFE3DEF3F3E3E3E3E3F2FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2F5CCB0BCDDE6E3F9FAF6FA
F6F6F6F6FAFCFAFAFAFAF6F6FAE2F9F0EAF4F9F6F6FAF6FAF6F6FAE2F4EEEDEDE3EFE0E2
E6E0E6DDDDDDD0E6EDEDEEEEEDE4EDEDF1E7E6E6DEECECE3ECEDEFE6E6EBEBF4FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7E2F0CCD9BCDAECEEF9FAF6FA
FAFAF6FAFAFAFAFAFAF6F6E2FAE2F9EAF0E2F9F6F6FAFAFAF6F6F6F9F0EEEDE6E3E2E2E0
E0E0E0E2E2E3EDEDEDEDF3F3EEF3EDE7EDEDE6E6DADADAE3E3ECEFDDDDE3E3F3FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2F5E2E0CCDADAEDEAF9F6FAF6
FAF6FAFAFAF6FAF6F6FAF9FAF9FAE2F4EEEEEAF6F6F6FAF6F6F6F6FAF9EDE7E6E3EFE2E6
E2E2E2EFE3E6EDE3E3EEEEEDEEEDEDEDE7E6E6ECE0E3ECE3E3E0EFD0D0EBECE3FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAEEF5F6E0DEDDE0EDF4FAF6F6F6
FAFAFAF6F6F6F6FAF9F9FAFAE2F9F4F4EEEAF4FAF6F6FAF6F6F6F6FAE2EEE0E6E3EFE2E2
E2EFEFE3EFEDEDEDEDEEEEF3EDEDE7EDEDE6DEE6DEE3E3E0EFE0EFECDEEFECD0F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAF1FAF3E3DEDFE0F3F4F9F9FAF6
FAF6FAFAF6FAFAFAF9F9F9EEF9F9EAEEEEF9F9F9F6FAFAFAF6F6F6F6FAEEE7E6E3E3E8E2
EFEFE3ECDEE6E3EDF3EDF3EDF3F1E7E3E7E6ECE3EFE0E3E3E3F3E3E6EFECF3D4EDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF1E0DADADFDFDBDFF3F9FAF6F6F6
F6FAF6F6FAFAF5FAF9F4EAEAF3EAEAF4F9F9F9F9FAF6F6FAF6F6F6FAF9EAE7E6E3E2E2E2
E2EFE3E3ECEDE3F3EDE7EDF3F3EDEDE7EDEDEDE6ECE0E3E3E0ECEFCDBEEFF3D4D4FCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAE0D0DAD6D9D1DCE4F3FAF6F6FAF6
F6F6F6FAF6F6F9F9F4F9F4EAEDF3F3F3EAF9F9F9F9F6F6FAFAF6F6F5F9EEE7EBE3E2E0E2
E6D2E0E3ECEDEDE3F3EDE7E7E3E7E7E7EDE0EDECE0E3E3ECECECF4D1B6E2ECE3EBE2FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0D9E2C6E3D1CCCDE0F3FAF6F6F6F6
FAF6FAF6F6F7F6F6F6F6F6F9EAEEE3E3EDE3F4F9F9FAF6FAF6F6FAFAEAEDE6D0D2E6E6E2
E0EBE3ECEDE6E6EDEDEDE3E7E6EDEDE6ECEDECE0ECEFE3E3E0F4ECDBE7DDE6E6D0E6FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF1CCE0D1DBD6E0E9F4F3FAF6F9F6FA
F9FAF9FFF9F6F6F6F6F6FBF6F6FFF3F3EDE6EDF3F9F9F6F6F6F6FAFAEEF3E6E3E2E2E0E0
E2EFE0EFE6ECE6E6EDEDEDEDE0ECE6E6EDE6ECECEFE3EFE3E0F4ECDBC9AA85BEEBD4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCD9E3D9D177D4C4CDE9F3FAFAF9F9F6
F6FAFAF9F3EFF3EFE8D2E8E4E4E0D2E0E6DAE6EDF3F9F6F6F6F6F6FAEAEDE6E2E6E6DDE0
E8E2E2E2EFE0EFECECECF3F3ECEDEDEDEDEDECECECEFE3EFE0F3ECE6C9B1AAA2D4D0FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAD9E3DFC2DEDECCDBCDF4F6FAFAFAFA
F6F9F4F3E0E6D2CDDFDFDFE0E4D5E6D1E8D0DAEDF3F4FAF6F6F6F6FAEAEDDEEBE2DDE0F7
DFEEEFE0E3E2EFE3E3EFECEDEDF3EDE3EDECECE0E3ECEFEFECECECEDD5B1B1A2D4DEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4B0E3E0773DCCC4DBF4F4F6F9FAF5F5
FAFAFAF9F4F3EFD4EDEDEDEDE4B9D2C6DBCDB1AAB1F1F4F6F6F6F6FAF4EDE6EBE6EEF7E3
DFEFECEDEDEDEDEDE6E0E0E3EFEFEDF3EDEDECECEFE3EFE3ECECECE6CDB1B1A2BBE3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEDBEE7E4C4E4B6C4DBDCF9FAF6F9F9F9
FAF6FAF9F9ECEDE8EBE3BBF2D5B9DCD2F5EED6B1EBEEF9F6F6FAFAF6F9EEE6EBDDDFD1D1
E3EFF3F3F3F3EDECECF3F3ECE0EFECEDF3EDECEFEFEFEFEFEFECEFE4DCC9C9B6DDDEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC6F0BEDEE7CDCDCCC4B5E9F9FAFAF9F9F9
FAF6FAFAF6F4EDEDEAF3E9DBC4DEC3C3EDCDD1B6E6EDF9FAFAFAFCF6F9EEE6D0DFE3E3CD
6ABCE0E2E7DBE6D5DFDBE8E4EFEFEFEFECECECEFE8EFEFE3E0E0E8DFC8D5CDD4D0D0FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7B5BBF0EDF0EDCCE4C4CCC4E9F4FAF9F9F9F5
F6F6F6F6FAFAF9EDEDEDEFEDDFDCDFCCCDE3D1F1F1F1F9FAFAFCFCF6F4EEE6D0DDE3DFD1
E5D6F0FBF6D26AC6CCE4C3D6DBE6EEEEF7E8E8E8E2E2EFE3E0EFEECCD1D1DFD4EBD4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFFFFFCFCFFFFFFFFFFFFFFFFFFFFFFFFDB8697E0F0EDE0D1F1CEDECCE0F9F9F9FAFAED
F9FAF9F6F6FAF9F9EDECECF3ECEEE3D1E3D1EFDEE7F3F4FAFAFCFAF9F4F3E6EBDDE3DFE3
CDD5EBF3EDEB9CCECCDBF4C8DBDFE4DFE5DBDDE2EFEFEFEFE3E8EDCCD4E9CCE3E6BEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4B5CC77C6D9D1AAE3CBCCE4C4F4F5F5FAF9F6F3
E0EEF9F6F6FAFAF6F9F4EDEDEDE6EFEFDEDEE6F1F3F4FAF6FAFAFAFAF4EEEDE3E0E3DDDF
E3D1E0DBCDF5CCF5CDDBEBF7F1DBCDF4DBE3E6EFECECECEFEFE8E0E7D4DBD2ECDDBEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB5C3C4773232CCC4B6DBE4E4C4E0F9E2F9F9F6F9
DAECEDF9F6FAFAF6F6F9EAEDE6E6EDE6E6DEF1F1EEF4F4F6FAFAFAF9EAEDF3ECE6DDF7F7
DDF7ECEEE0E7CDDEC3C4DCE3E3E9DFF7DFF7EFE6E2ECEFEFEFE8CDD4DBC4C2DABBA3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCBBB5C3CC8677E3CBE4CDCDCCCCF4F4F5FAFAF9F6
F9E2EDE0F4F7FAFAF7F6F9F4EDEDF3E6EBD4D4EDF3F3F9F6FAFAF6F9EEEDEDECEFDDDDE6
E2E6E3ECECE0E4CCE4D2DBE0EDD9EDEEE0E6E8ECEFEFEFEFEFEDD4DBE4B5C3ECA3BEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3B5DBDBB5B5C4DBDBB9DEC4DEB5E9F4F5F5FAF9FA
F6EAF3E4DFE8E8EEEEDFE4E9D1DCDCD6D5CDCDE2F3F3F9F6F6FAFAF4EEEDF3ECE2E6DDDD
F7E2EFE6ECEFECE8E8EDD9EDD9F7E2E2EBE3EFE3EFECECEFEFE9DBE3C4AAC2DFA2BEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5C4CCCCCCE4CCC4CCE4DECDC4C4E0F4F9FAF9FAFA
FAF6F9EAE0E7EFEBDEDEDFE0E0C3C8BDC8DBDFE3EDE2F9F6F6F9F9F4EEEEF3EDD2E0E3E3
E3E0E2EDE6EFE2E6F7F7DFE6E2E3EBEFE0EFE3EFEFEFEFEFEECDCBCEF1AADCDFB1B6FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7C397AAAAE497CC9CCCDEE4DBE4F4F3F4F5FAFAFA
F6F6F6FAF9ECE0E0EBD2E0E4E0E4E8DFDFE2E6EAF9FAF6F6F6F5E2EEF4F3F3EDD2DFC3D6
C3D1F7E2EFE6EFE6E6EFEFEFEFEFEFE0EFECE0EFEFE0EFEFEDDBE4CBE4DEE0E3B1BEFFFF
FFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFF
FFFFFCFFFFFFFCFFFFFFFFFFFFFFFFF3BDDECCE4CCC4CCB9CCCCCDE4E4E0ECF4F9F9FAFA
F6F6F6FAF6F9F9F9F6F6F6FBE2FBE2F7E2F6F9F9F9F6F6F6F9F9F5EAF4EAF3E3ECE2DFCC
BCBCE0DFE6ECECEDE6ECECEFECE3ECECEFECEFEFEFECEFEFE0C4E4B6CDDBE6BBB1B6F2FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFFFFFFFFFFFFFFFFFFFFF3D4CC97E4CCE4E4DE9CCCCCC4E4F4EFF3F4F5FAFA
F6FAFAFAFAFAFAFAFAFCFAFAFAFAFAFAFAF6FAFAF9F6FAFAF9F9F9F4F4F4F3E4F3EAECDF
C3D1D4C3DBCCDBEFECECEFEFEFEFEFE2E2E0EEE2E0ECE3EED4E4CCCDF1B5CDDFAADBE7F3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBDDBC4CCE4CCCCCC9CCCE4C4D4E9EFEDEEF5FAFA
F6F6FAF6FAFCFCFAFCFCFAFCFCFCFCFAFAFAFAF6FAF6F6F9E2E2F9F4EEF4EEF3EAF3EFEF
ECDFC3D1C2C3DBC2D1EEF7E0E2E8EEDBDFDFDFECE3E0E3EDB5CCCCCCB6AABCCDE3E0E9F3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE4CDDBCCCCE4CCCCDEB9CCDBE4E9E8ECF4F5FAFA
F6F6FAFAFAFAFCFCFCFAFCFCFAFAFCFCFAFCFAF6FAF6FAF9FAFAF4F4EEF4F4EAF4EAEAF3
EFEDE0EDE4D1D4DBDBCCD1DFF4D1DFE0DFE6E0ECE3EFE2E0C4DECCB6CBAA866E85C3E9F5
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD4D4DBC4CCC4CCCCE49CC4C4E4F4EEEFEDF5FAF6
FAFAF6FAF6FAFAFAFCFCFCFCFCFCFCFAFAFAFAF6F6F6F9F9F9F9F4F0F4EAF4EAF4F4F3ED
F3F3F3ECEFDFE4C3D4D4D2D2CCCCC3D9DFEFE0EFEFE2E0D1CCCCE4CCE4DE003EC3E3F4FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3DCD4DCDBE4C4CCCCCCCBCBE3E4E9EDF2F3EEFAFA
FAF6F6F6FAFAFAFCFCFAFCFCFCFCFCFCFAFCFAF6FAFAFAFAFAF0F4F4F4EEEEF4F4F4EAE4
F3E3F3F3ECECEFE2EEDBE0DFE0D9E0EFEFE3D2EFEFE2EEDBC4CCCCC4E4E4DEC4C4C4E9F3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1D4E7D4DBDBC4CCCCCCCCCCC4DBCDE4E8EDF4F5FA
FAF6FAF6FAFAFCFAFCFCFCFCFCFCFCFCFAFAFAF6FAFAF9F9F9F4F4EEEEF4EAF9EEF4EAED
EDEDF3F3EDECECE0E0E2E2D2DAEFEFE3EFE3D2EBEFE0EDB5C4CCE4E4CBE4CDDECCC4CBE7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3D4D4DBDBDBCBCCCC97DBC4CCDBDBE9EDECEEF9FA
FAF6F6FAFAFAFCFAFAFAFCFCFCFCFCFCFAFAFAFAFAF9F6FAF5F5EEF4F4EEF4EEEEF3EEF3
EDF3E7F3EDF3ECF3EDEDECECECE3E3EFE0E3E3E3E2EEDCC4C4E4CCE4C4E4E4CCCCDEDBE7
F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFFFFF4DBE7DCE4DBBDC4CCCCCCCCCCC4DBD4E0EEF3F4F5
F6F6F6F6FAFAFAFAFAFCFCFCFCFCFCFCFAFAFAFAF9FAFAF9F4F4F4EEEEF4F4EEEEE4EDED
F3F3E3EDF3EDF3EDEDECECE0E3E0ECECE0EFE3EFEEE0D4DBCCE4CDDBB9CDCDE4CCB9CBDB
FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDCDBE4E7E4DBE3C4CCDECCCCC4CCDBD4CDE5EFF4F9
FAF6F6F6FAFAFCFCFCFCFAFCFCFCFAFCFAFAFAF6FAFAFAF4F4EEF4EEEEEEEEF4EEEDEEF3
EDEDEDF3EDEDF3E6ECECE6ECECECEFEFEFEFEFE2EDF4E3CCDECDCBB9CDB9DEDE9CDEC4DB
EBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCFFFFFFFFFFE4E4E7E7D4E4E3C4CCC4DE97CCC4C4DCE9CCE8EDF5
FAF6F6F6FAFAFAFCFCFCFCFCFCFCFAFCFAFAFAFAF6F6E2F9F9EAEEEEEEEEEEEEEDF3EDED
EDF1F3F3EDEDEDEDECECECEFECECEFE3ECE3E2EEE0D4C4CCE4C4E4CDCDDEDEDEDEE4CCDB
F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCFFFFFFFCFFF4D4E7E4E7E4DBDBCCC4DECCCCDBDBE7F4E9DFEDF4
F5FAF6FAF6FAFAFCFCFCFCFCFCFCFAFCFAFAFAF6F6FAF9F9F4EEEEEEEEEEEEF1F3E4EDED
EDEDEDEDEDEDEDE6EDE6ECE6ECE3EFEFE3E2E8E6E0DBC4E4DBC4B9B9CDB99CB9CDE4CCDB
EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD4DBD4E4E4E7E3E3C4C4C4CCC4C4CCDBCDF4DFEFF3
F4FAF6F6F6F6FAFCFCFCFAFCFCFCFAFCFAFAF6F6F9E2FAF5EAEEEEEDEDEEEEEDE4EDF3ED
EDE7EDEDE6ECEDE6ECEFE6E3ECE3E3E3E2E6EEE4CDE4DBDBE4E4CDDEB9B99CB9DEE4DEDB
FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7E7D4E7E7E7E7E4B5C4C4DEC4C4DBD4CCDFEDDDED
F4FAFAFAF6FAF6FAFAFCFCFCFCFAFCFCFAFAFAF6F6FAFAEEF4EEF3EDEDEDE4EEEDE7E7ED
E3E3EDEDEDECE6ECECECECE0E2EFE3EFE0E0E4F4D4E3C4DEDEDECDB9B99CDEB9CDE4C4E9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCDE4E4E7CDE7E9DBE3C4CCC4C4DBDBE4DCE0DBE0E6
EEF9F6F6F6F6FAFAFCFAFAFCFCFCFCFAFAFAFAF6FAF9F4F4F4EEF3EDEDF3EDEEEDEDF3E7
E6EDEDE6EDE6E0ECE3E3ECE3EFE3EFEFEEEDE4D1DBC4CCCDC8CDCDB9B9CDB9DEDEDEC4DC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFFFCE4E4DBE4E7E7E7E4E4CCCCDBC4DBDBE3D4DFDBE0EC
F3F9FAFAF6F6FAFCFAFCFCFAFCFCFCFAFAF6FAF6F9E2F5EEEEEEEEEEEEF3EDF1EDEDE7F3
F3EDEDE6E0E0ECECECE0ECE3E3EFEFE8E6E0E0D4DBC4C4E4E4C4E4CCE4CDDECDE4CCC4E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCFFFFFFFFFCDCE7B5E4DCE7E9E7E4B5CCC4DBC4DBCDF4E0E0DBE6
EDF4F9FAFAF6F6FAFCFAFCFAFAFAFAFAF6F6F6F6F9F4F4F0EEEDEDEDEDEDE3EDEDEDE3E3
E7F3EDE0E6DAECECEFE3E0E3E3E2E8EEEDDCF4D4B5C4B6CCCBC4CDB9E4E4CDB9B9E4E3FC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFCFFF4E3E3D4E7E4E9E7DBE4CCDBDBE3DBDBF4F4CCE0DF
E6F4F9F9F6F6F6FAFAFAFAFAFAFAFAF6F6FAF9FAF4F4F9EEEEEEF1EDEDEDF1EDEDEDEDE7
EDEDEDEDE6ECECE0E3EFE3E3EFEFEEEDE0F4CDE3C4CBE4E4DECCCDCDB9B9CC9CB9CCCDFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCFFFFFCFFFFEEE4E3D4E4F4E7E7E4E4C4E4DBE3E4DBD4DCF4DFDB
E3F4F4FAFAF6F6F6FAF6FAFAF6F6FAFAF6F6F6F9F9F5F4EEEDEDE3F1E3EDE7E7E3EDE7E7
E7E3E0DEE3ECE0EFEFE3E3E3E2E0E6DFD1D4E4DBCCCCCCE4E4CDCDB9CDCC9CB9DEC4F4FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFDCE3DBE3E7E4E7E3E3E7C4E4DBDBE4DBF4CDCCED
E0EDF9F9FAFAFAF6F6F6FAF6FAF6FAF9F6FAFAE2F4F4EEEEE7F1E7F1E3EDEDEDEDF1E0E7
EDEDE6E6E6EFECECE3EFE2E2EEEDE0D1CDDBDBC4CCE4E4E4CCE4CDCDB99CB9DEC4D4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEDE3DBE4E3DCEDDBE4E3AAC4CCE3E7DBE4D4D4DF
DBECEDF4FAFAFAF9F6FAFAF6F6F6FAF5F9F9E2F4F0F4F1F1E7EDF1F1F1F1EDE7EDE0EDE6
E6E6DEECE6ECE0EFEFE2E0E0DFE0D1CCE4B5C4CCDEDEE4E4E4E4E4CDE4B99CE4E3D4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCFFFFFFFFFFEEEEE4E4E7E4E7DCE4DBE3E3CCDBDBE4E4E3DCE7E9
E0E2EFEDF9F4F9F9FAFAFAFAFAFAF9F9F9F0FAF4EEEEE7EDF1E7E6E7EDE6EDE0E7E0E6DE
E6E6DAE6ECE3EFEFE2EFE8E6EDE0CCD4DBC4CCCCDEDECDDECCE4CDB99CCCB9DBC4F4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEDE7DCDBE7E4E4DCEDDBE7DBDBC4DBE3E7E4E7E4F4
D1EEE6EDF3F4F4F4FAFAFAF9FAE2F9F4F9F4F4EAEAEDEDE7E0E7E0DEE6E0DEF1E6E6E6EF
EBE3E0ECECE3E3EFE8E8EEEDDFD1D4D4B5C4CCDEB9B9B9DEDE9C9CCCCCCCDEDBE3EEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4DCE7E4E7E3E4E9E4E4CBCBDBCBE3E3E7E3DBCD
D4DFEDE8ECEDEDF3F4F9F4F9F9F9F9F4F4EAF4F4F3DEE6DEE6E6E6DEDEE6E6DEE6DEE6EB
E3EBE3E3E2E8E8E0EEDBE0E0DFD4DBB5CCC4E4DEDEDEB9B9B99CCCCCCCB9C4DBC3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2F4E7D4DCE4DCE9E4DBDBCCC4C4CBE4E7DCF1C4
CDCDD1E0EEE0E2ECEFF3F4F4F3FFF3EEF4F1F4F3F3EDEFE3E3E6E3E3E3EFDEDEDADEE3E3
EBEBD0D0F7E2E0DFE6E0E0D1CCD4DBBBCCE4DEB99CB9B9B9B99CCCCCCCCDC4DBE7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F4DCE3E7E4E4E4E9E3DBC4C4E4E7E3E3E7E7DC
DBCDF4E9E9DEDBE8EDE8ECEDEFEDEFF3F3EDF3EDECE6E6DFDFE6DDD0E3DDE3E6D4D0E3E3
EBE2E2E0E0E0DFE6EDDFD1CCC2DBC4CCCC9CDEB9B9B9B9B99CCCCCCCB9DBCCCCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4EDE4DBDCDBE4E7E4C4DBC4C4DBDBE9F2E7E4
E7E9F4F4F4F4E0EFEEE6EDEEEEE6EEE8EFD2ECE8EDE0E0DFE0E0E3DFE7DFDDE0E2DDDDE0
E0E0DFEEDFDBDBE4E0CCCCD4DBB5CCCCE4B9DEB99C9C9CCCCCCCCCB9CBC4CCE0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBF4E7E3E7E4E4E4E7F1C4CBC4DBE4E4E7E9E9
E7EDE4E9E9F4E0E4DFE7E7E0F4E4E0E0EEEFEEEDE4DFDFE0DCE0E5D1D1E3E3E3DDE3DFDF
D9DBD1E6DBD9E4DFD1CCC2B5B5C4CCCCDEDEB9B99C9CCCCCCCCCCCC4E4CCC4F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3EFE7E4E4E7F2F1F4E3C4C4CBDBDBE9E7EDF5
E4EDF4EDE9E0E0F4F4E9E0E0E0D1DFD1E0E0EDE0E0F4E9CCCCD6CCDCDFE5D9D9DBDBD9E0
E0E0DFE0DFDFDFCCCCD4DBB5C4CCAAE4B9B99CB99CCCCCCCCCCCB9CCCBE4BDFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEDCE4E4E7E3F2F2E4DBE4DBE3E7E9E9E9E9
EDE4EDF4F4E0F4F4F4CDDCDCD4F4CDCCCCE9E0F4DCF4DCDCCCCDD2D2CCD6DFDFDFDFDCE9
DFD6D6DCE0D1CCF4D4B5C4C4DBE4DECDDEB9B9CC9C9CCCCCCC9CCCC4CDBDEBFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3EEDCE4E4E7E3F2E9E4DBDBE7E4EDEDE7F4
E9E4DCF4E9F4F4F4CCD4E3DCE3E4DCDBDCD4F4D4E4E9E4C4DBE3E3DBDBDBD4C2C2D4D4D4
D4DBDBDBDBDBDBDBC3BBCCCCE4CDB9B9DECDB9B9CCCCCCCCB9CCCCCDDBD4FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F2DCE4E4E7E4E4E4E7E4E3E7EDE9F4EDED
E7E4E7CDCDE9CCD4D4E3E4E3DBDBE4E3C4DCE4E4E4F1E3E3C4DBDBC4C4B5B5DBDBDBDBDB
DBC3B5DBB5DBC4B5C4DBE4CCDEE4B9B9B9B9B9CCCCCCCC9CB6E4CCB5E4EBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0EFE7E7DBE7F1F2E4EDE7E3E7F4F2EDED
EDEDE9F4DCD4E7D4DCDBE4E4F1F1E4E7E4DBE4E4DBDBCBDBCBCCCCC4C4CCCCB5CCC4DBC4
C4C4C4CCC4CCC4CCC4CCCCE4DEE4B99CB9CC9CCCCCCCCCE4E4C4CDB5E4FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F5E7E4E7E4F2E7E4E4EDEDEEE3E9E9E7
E3DBE7DCE9DBE7CDE4E4E4E3E3E4DCF1CBCBF1C4C4C4C4CCCCE4E4CCCCCCC4E4C4CCCCE4
CCC4CCCCC4CCCCDECCE4DE9CDEDEB9CCB99CCCB9CCCCB9E4DBCDC4E5FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF1E7E7E4E7E4DBE3F2DBE9EDEDEDF1E3
EDF4F4E4CDDBE3E3DBDBE4E4C4B6B6F1CBB6C4B6C4B6E4E4CDE4CDE4E4E4CCDECCCCC4B6
DEE4E4DECCCDCCDECDCCCDE4B9B9B99CCCCCCCCCB9E4E4E4CCCCE0FCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3EDCDE4E7E7E7E3E4F2F1E4E9EDEDE9
F2F2E3E7D4DBDBE4E3CBE3E3CEB6F1E4CBB6C4E4B6E4E4E4E4CDDECDE4CDE4CDE4E4DEC4
B9DEDEDECCCCDEDEB9E4DEDECDB9B9B9CCCCB9CDE4CDDBCCC4CCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F4E4E3E7E7F2E4F2E4EDF2E4E4ED
EDEEE4DBDBC4C4E3E3C4E4DBE3CEF1CBCCE4B6CDCDCBC8CDCDCDB9B9B9E4E4DEB9E4E4DE
E4CDB9E4B9E4DEB9CDB99CB9CCCCB9CCCC9CB9CDCDE3CEC4CDFCFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF4E4E3E7E3E4F1E7F1F2EDE7E4
E3E7DBE4DBC4CCCCE3C4CBC4CBCDCCCDB6C4CDE4B9CDCDCCCDB9B9B9CDB9B9E4CDB9B9CD
CDCDE49CCDB9B9B9CCB9CCCCCCCCCC9CCDCDDEE4B9E4AADFFCFCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7EBF4E4E7E4E7F2E4E4E4F1E4E7
E4F1C4E4DBC4E4CCCBCBCCB6CBBDCDCECCCDE4CDCDCDE4E4B9B9B9CDB9B9B9E4E4B9B9B9
CDCDB9B6CDCDB99CCC9CCCCCCCB9CDC8CDB9B6CDE4C4CCFEFCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEDEFF4E3E7E4F2F2EDF2E7E9E9
DCF1C4E7DBCCE4E4CCCBE4CCCCF1B9CBB9E4CDB9CDB9B9CDCDB9B9B9CDCDB9CDC4CDCCB9
CDCDE4B9CDB9CCCCCCCC9CB9CDB6CDCDCDE4C4CCDBD4E0F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0EEE7E4E7E3F2E3F2F5F2E4
E3F1E4E7C4CBCDE4CDCCCCCDDEDEB9CDCDB9CDB9CDB9CDB9CDB9B9B9B9CDB9CDCECECEB9
B9CDCDCDC8CDE4C8E4E4E4CDB6DEB9CDCBCCCCDBDBDFE7FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEDE7E9F2E7E3F2E9E9E9ED
E9F2F1E4E3CCB6CDCDB9CCCDCDDEE4B9E4B9CDB9B9B9B9B9B9E4B9CCB9B9E4CDCDF1E1E4
F5CDB6CDB9CDCDCDE4B6E4CDCDF1E3E4DBDBC4D4D1F4FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2EFE9E7F2E3E4F2E9E9
E9DCF1E9E3C4C4CCB9CDE4E4CDB9DEB9E4CDCD9CCDCDB9CDB9CDB9B9CCB9B9BDCEBAF5ED
B6B6CECEF1B6E4E4CDE4C4B5E3CBC4DBC4DBDBCCDFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2E7EDE9F2E3E4F2EB
EDF2E9E4DBF1DBCCE4B9CDE4B9DEDEE4CDE4B9CDB9CDCDB9B9B9CDB9B9B9B9CCF5BDBDCE
EDEFEDD6DCDCE9DCE3C4E4E4DBDBDBE3E7D4CCE9FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE8F4E7F2E7E3E4E7
E9EFE2EDE3E3DBDBC4CDCDE4CCDECDDEB9E4B9B9B9B9CDB9B9B9CDCDCCB9E4CDB9C8BDE4
F5F1C8CDE4CBDBE3E3E3E3E7E4E4E4DBDBCDDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0E9EDE4E7E9
EDEDEDEEEDDBDBDBDBCBE4E4F1CBCCB6E4B9CDB9CDCDB9CDB9E4C8CDCDCDE4CECDB6F1BA
E4DCCDE4E4B6E4E4CDCBCCF1DBC4DBCCDFC3F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0F4E7E7E7F2
E9EDEEF2E2E7B5DBDBC4C4DBE3E3E3CCB6C8C4CDCDCDE4B6CDCDBDE4CEB6E4B6F5CECECE
C8E4F1F1CBE3F1DBC4E4DBC4DBD4D4D1E9F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBF4E7E3E4
E7EDEEEEF7EEEDF1DBC4CBC4C4E4E4E3F1E9CDCCB9CBCEB6CEC8F1F1CEF1E7EBC8E4EDF5
DCE4E4E4E4E3E3E4E4E7F4E7E4CCE0E9FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7F4E9
E7EDF7F7F3F2F7EEDCEDF4E4E397E4E4E9D6E4F2E3BACDEFDCF5EDF1D6D6F5EDEFEBE9F2
E7F4DCE9DCDCDCE7E3DBD4F4DCCDE5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3EF
EDEDE7E9E9E2F1F7EEF7EEEEF7EDDCE7F5EDE2EDF7F5DCB6D6BDDCF5E2E9E7E7E4E7E9F4
DCDCCDE4D4D4E7CCE9D1E0F4D4EDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F0EFE9EDE9EEF2F7EEEEF4EEF7EEEEEEEBEDE9EEEFEDF1D6BDBDCEDBE3EDE7E7E7E3E3DB
DBDBE3CDCCF4E9D1D1E9D4CDEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF1E2F4EDEDEFE2F3F7F2F7F7F4F7EFF2F7EFF7EEF2E9F7EDE7DCDCE3F1E4EDE9E4E7E7
CCDCD1F4E0F4E4E0CCE4E5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF3EFD1E7EBF1EDE2F3F2F3EFEEF7EBEFEFEFF4EBEFEFF4F4EEF4E0F4DFE0F4E7
E7DEEDEDF4DCE4E9F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7E4E4E4EDE8ECEEEEEEEBEBEFEDEFEBE5EBEBEBEFEFEBE7F4E7EFDEEBED
F4F4F4DCDCF4EDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF3FCEFECF6ECEDEDE5EFE7F7E2F7EFEFEBEEE7EEE7F4E7F4F4
E9F4E9EFE4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFCF3FCFCFCEFF1E8E3E8F2EFEFEFEFEFEBEFEEEEF4E9E9
F4E3FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFFFFFFFFFFFFFCF7F3F1F3EBFCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{450, 150},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000720000UQP00`40o`000?l0003ooooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0
027oool6moOg00?alO7gmoOgmoL07OOgm`08b/[:emOGemOGemOGf][J`<30h>3Pf][J1n3Ph0;Jf]X0
0mOGelo?clo?c`02bLW900>k^k_0`<2k^k/02K:b/P03[Jf]XJ6QZ:RX00:YZJT00jNWYhV9ROOgm`09
moOg00?alO7gmoOgmoL02OOgm`03lO7amoOgmoOg00?gmoLOoooo1P820P032PX:0P820P8201`20P80
120P838b<S4a<C4a<@8/;2`28b<S00<P820S8b<S8b<012<S8`</;2`00c0`<38b<S`l?002?3`l00<:
2PY:BTY:BTX024a<C008EeMGCdm?E5AD@d=3Cdm?E5ADBTY:Cdm?2@820P032PX:0P820P8200T20P80
0`X:2P820P820P030P829Oooo`03o?cloooooooo01goool02?7alO[jn_[jn_[jn_Kfm_;bl_[jn_Kf
mPOjn_X2m_Kf00?jn_[inOWinOT00_Cdm003kNg]lo?ckNg]00W]kNd00nKVi^c/k=kNgP02k>c/00?_
kno/k>coool02Oooo`03o?cloooooooo00Woool00oclo?ooooooo`0Voooo000Qoooo00CalO7gmoOg
moOalO4:moOg00?alO7gmoOgmoL05OOgm`03`<30emOGemOG00?Jf]X01N3Ph=[Jf^3Ph>3Ph<30`003
h>3P0][JfP;?cll2bLW90l30`003^k^k/[:b/[:b00:b/[801Zf][K:b/[:b/Zf][K:b/Zf][@BYZJT0
0jNWYjVYZHV9R@06moOg00?alO7gmoOgmoL04oOgmaooool010X:2P820P820PX:2PX20P800`X:2P82
0P820P0D0P8200@F5QHj>SXa<C4P8203;2`/00DS8b<P820S8b<S8b</;2`00R<S8`</;2`00c8b<S0`
<3`l?003?clo00<:2PY<C4a<C4`00Ta<C006A4A4C4a<C4a<C4a<A4A4EeMG14m?C`04E5ADCdm?BTY:
Cdm?6`820Qooool01?clo?ooooooooclo0[oool00oclo?ooooooo`0Eoooo00?dm?Cjn_[jn_X00oKf
mP05n_[jm_Kfn_[jn_[jl_;b00?jn_X2m_Kf0_Win@;dm?@3lo?c1Ng]k@06i^KVkNg]kNg]i^KVkNg]
i^KV1>c/k003kno_k>c/k>c/00Koool00oclo?ooooooo`0foooo000Qoooo0_Ogm`03lO7amoOgmoOg
00;gmoL00o7alOOgmo7al@0?moOg00?alO7gmoOgmoL02_Ogm`03`<30emOGd];B00;Bd]800l30`=[J
f/30`003`<3000GBd];7alOBd];?clo2`/800l30`0:0P8001[2`/;:b/[:b/[:b/Z2PX:VYZ@FPX:07
ZJVY00>WYjN0P83gmoL02_Ogm`04lO7amoOgmoOglO7a0_Ogm`03lO7amoOgmoOg00;gmoL01?7alOOg
moOgmo7al@;gmoLOoooo9P820P07<30`<C4a820P820P8b<S820P;2`/008P820012`/;20P820P820P
808b<S801A8B4Q`L73`l?3/k>`410@02@D5100Y0@41<C4a<C4a<C4a7AdM4A4A<C4aGEeM<C4a4A4@5
AdM700A?CdmDE5A:BTX820PK0P828Oooo`03o?cloooooooo00;oool00oclo?ooooclo00?oooo00?l
o?coooooool02_ooo`03l?3`n_[jl_;b00?bl_800oKfm_;bl_;blP03l_;b00Ghn?Sbl_;inOWinOWd
m?@00_3`l004hn?Slo?chn?ShN7Q0^g]k@03k>c/i>CTi>CT00;/k>`7i>CT0^c/k003kno_h>3Poooo
00[oool01?clo?ooooooooclo0;oool00oclo?ooooooo`02oooo00Clo?coooooooolo?`Uoooo000Q
oooo0_Ogm`;alO48moOg00CalO7gmoOgmoOalO4:moOg00?alO7gmoOgmoL02OOgm`04b/[:emOGemOG
emOG0m[JfP09h>3PemOGf][Jf][Jb<S8clo?a<C4`/;2`<3000:h^;P00kNg]k:b/[Ng]`04]kNg00>b
/[:YZJVYZJT00jVYZ@05[Jf]ZJVY[Jf]YjNWX:2P00BYZJT00kNg]oOgmoOgm`08moOg0_7alA3gmoLO
oooo0`820P032PX:0P820P8200H20P8010X:2P820P820PX:2QD20P80120P838b<S4a<C4a<@@/;2`0
1b4Q8B`/;2`/;2`/;1@D510@41hN7P02?clo00=?Cdm1@D5<C4`01D51@@03>c/kC4a<Cdm?00A?Cdl0
14M7AeMGEeADE4a<C0A?Cdl00d51@@820P820P090P8200<:2PX20P820P803P820R7oool2o?cl2?oo
o`04o?clooooooooo?cl2_ooo`03o?cloooooooo00Woool01?7alO[jn_[jn_[jnP?fm_H2n_[j0_Kf
mP05moOgnOWino_koooolo?c00;Shn<00o?clng]kO?cl`04lo?c00?]kNg/k>c/k>`00nc/k004i^KV
k>c/i^KVkno_1Nc/k003lo?coooooooo00Soool2o?cl<oooo`008Oooo`03lO7amoOgmoOg02?gmoL0
1];Bd]OGem[Jf]OGem[Jf/30`0GJf]X02]OGelS8b<c<c<c<c<C4a<K6a/C4a;^k^kRh^:RXZ0:ZZZX2
/[:b00>VYZJ][JfYZJT00jVYZ@03/[:b[Jf][Jf]00JYZJT00lC4a?OgmoOgm`0HmoOg00?alO7gmoOo
ool07_ooo`032PX:0P820P8202820P801R`/;34a<C4a<B0P82`/;2<S8`H/;2`0134a<@@414A4A4A4
A0=2@T82Cdm?0UeMG@9<C4`00d51@EIFERLW9`04Cdm?00A4A4AGEeM?CdmGEeL4Cdm?00<I6AT20P82
0P8060820P032PX:0P82oooo01koool00oclo?ooooooo`0Soooo00Kbl_;jn_[fm_Kjn_[fm_Kbl_85
m_Kf00?jn_[gmoORh^800^;RhP05j^[Zk^k^kNg]hn?S`/;200;Jf]X2kNg]00?Ph>3dm?C/k>`00nc/
k005kNg]i^KVi^KVk>c/i>CT00C/k>`00o_knoooooooo`0Hoooo00?lo?coooooool08_ooo`008Ooo
o`?gmoL00o7alOOgmoOgm`0PmoOg00CBd];GemOJf][GemL6f][J00K7alO?cloJf][GemOJf][7alL2
c<c<00S6a/Jk^k^`/;2ZZZZh^;S1`L6h^;RRXZ82ZJVY00Rj^[ZYZJVYZJVWYjNYZJVXZ:RYZJVPX:04
ZJVY00?Ph>3gmoOgmoL06_Ogmaooool30P8200<:2PX20P820P807`820P04;2`/>SXj<C4a820P1R`/
;00C<S8b<C4a<S8b820P;2`/<C4a<S8bA4A4@410BTY:Cdm?E5ADGEeMC4a<Cdm?@D51GEeMCdm?2`/;
00=?Cdl01DA4A6=SHdm?Cdm?Cda<C003Cdm?00<F5QH20P820P806P820R;oool00oclo?ooooooo`0P
oooo00Cdm?Cjn_[fm_Kjn_X6m_Kf00Khn?SinOWfm_Kjn_[fm_Khn?P2h^;R00SZj^[]kNgShn?Jf][S
hn?Ti>CShn?Bd]82k>c/00K_kno/k>c/k>c_kno/k>cNg]h6k>c/00?lo?coooooool0?Oooo`008Ooo
o`GgmoL00o7alOOgmoOgm`0NmoOg00?GemOJf][Jf]X00][JfP04b/[:emOGf][Jf][J0/o?c`CJf]X0
0l[:b]OGelc<c002a/K60/30`006^;Rh`L71a/K6P820ZZZZ[Jf]0ZJVYP07ZJVY/[:bZJVYZJVY[Jf]
ZJVYYjNW00>YZJTMmoOg7oooo`D20P800`X:2P820P820P0M0P820S4a<@@/;2`00c8b<S4a<B`/;003
<S8b12`/;005<S8b<C4a@410@T92ATI6008o?cl01Da<C492@Ta<C4m?CeeMG@02EUIF0Tm?C`06C4a<
Cdm?EeMGCdm?EeMGA4A40Tm?Cad20P8Toooo00?lo?coooooool07_ooo`03n_[jm_Kfm_Kf00;fm_H0
1?3`l?[jn_Kfm_KfmP;inOT4m_Kf00?`l?3jn_[Rh^800^[ZjP08h^;Rlo?chn?Si>CTj^[Zh>3Pf][J
i^KV0^3Ph007k>c/kNg]k>c/k>c/i^KVi>CTkno_00?/k>a0oooo000Qoooo2oOgm`03lO7amoOgmoOg
01SgmoL01lO7amOGemOGem;Bd/O7al;2`/[:bP03f][J0/30`0;Ph>04`<3000o9bLW4a<C0`<30`<34
a<C0`<20P830`<2h^;RXZ:RRXZ:ZZZZPX:2b/[:QXJ401:2PX003ZJVYX:2PQ8B400[gmoL00o7alOOg
moOgm`0@moOg7oooobD20P801C8b<S4a<C4a<B0P830`<003820P0b`/;08P82000b<S8b0P82`/;003
820P00E2@T8000020P820P90@4000Ta<C008A4A4Cdm?A4A4GEeMC4a<20P8@410C4a<0TA4A004EeMG
C4a<C4a<@4107@820R[oool00oclo?ooooooo`0Hoooo00Ghn?Sjn_[jn_[bl_;hn?P00_3`l0?fm_H2
l_;b0_[jnP?bl_801_Shn?3`l>3Ph>3Ph>;Rh^[ZjP;Ph>002NCTi>?Shl;2`/;2`][Jf^c/k>7QhN3P
h>c/k002i>CT0nc/k003h^;Roooooooo00Soool00oclo?ooooooo`0coooo000Qoooo9_Ogm`06d];B
emOGemOGclo?f][JalO71=[JfP;Ph>03f][J0^3Ph0;Jf]X01=OGel71`Lo?clK6aP;4a<@02H61PKRh
^;Rh^;Jf][:b/ZRXZ;:b/[Zj^[:b/P04ZJVY00>b/[;Jf][gmoL03OOgm`03lO7amoOgmoOg00cgmoLO
oooo9@820P07>SXj<C4a<C4a<30`;2`/<S8b<C4a00</;2`38b<S0R`/;0<S8b<04R`/;34a<C4a<C`l
?38b<T92@TI6ATa<C4Y:BTm?CdA4A4a<C5eMGEMGE`P824a<C4m?CeMGE`9?Cdl00da<C20P80820P0=
0P8200<:2PX20P820P8030820TGoool01_3`l?[jn_[jn_WinOKfm_Shn0Cfm_H2n_[j0oKfmP;jn_X2
m_Kf00Cjn_[`l?3inOWZj^X2k^k^00_Ti>CShn?Shn?WinO]kNg2`/;]kNg_kno]kNg/k>cTi>@00^c/
k003kNg]moOgoooo00goool00oclo?ooooooo`0_oooo000Qoooo0_Ogm`03lO7amoOgmoOg023gmoL0
0m[Jf]OGemOGe`02clo?1=[JfP04emOGh>3Ph>3Ph>3P0][JfP?Ph>03f][J00?7alO<c<c<c<`00/C4
a007PH61][Jf][Jf^;Rh][JfZ:RXZZZZ00:YZJT01[Ng]jVYZK:b/ZVYZK:b/^SXj0OgmoL00o7alOOg
moOgm`0CmoOg7oooob@20P801@00034a<C4a<C4a<C8b<P04;2`/00<P820S8b<S8b<00R<S8`03;2`/
8b<S8b<S008S8b<2;2`/00la<C4b<S94A4A4A4A6ATI:BTY<C4aDE5A4A4ADE5AMGEeGEeM=CDe?Cdm1
@D400Tm?C`9<C4`00`X:2P820P820P0K0P828Oooo`03o?cloooooooo023oool00oKfm_[jn_[jnP02
nOWi1?KfmPCjn_X2m_Kf0o[jnP?fm_H00oShn>;Rh^;RhP02k^k^00OTi>CWinOWinOShn?WinO2`/;J
f]X00^c/k006lo?ck>c/kNg]k>c/kNg]o?cl1oooo`03o?cloooooooo03Koool0027oool01OOgmo7a
lOOgmoOgmo7al@0OmoOg00CRh^:j^[[7alO?cll2f][J00?GemOBd];Jf]X00][JfP05h>3P`<30h>3P
h>3Pf][J00?Ph>001m[Jf^3Ph=[Jf];Bd/o?clg=cLW9b@02a<C40[Rh^00<[Jf]][JfX:2P[Jf]ZJVY
]kNgZJVYZ:RX/[:bZJVY/[:bj>SX2oOgm`03lO7amoOgmoOg00OgmoL2lO7a1_Ogmaooool01@820PX:
2P820P820PX:2P0P0P8200Lb<S8a<C4b<S8/;2`a<C4/;2`a<C400R`/;08S8b<00b`/;2<S8b0P8004
8b<S00HP820/;2`a<C4j>SXb<S800003ATI600Y?Cdm7AdMDE5A<C4aGEeM7AdM1@D5?Cdlk>c]GEeL2
C4a<00<:2PX20P820P8050820P032PX:0P820P8200@20P8Poooo00Clo?coooooooolo?`Ooooo00Cg
moO_knohn?SinOT2m_Kf00?jn_[bl_;fm_H00_KfmP05n_[jl_;bn_[jn_[jm_Kf00?jn_X01oKfm_[j
n_Kfm_3`l?WinO3`l?Cdm002k^k^0^?Sh`0<i^KVinOWi>CTi^KVk>c/lo?ck>c/i^KVkNg]k>c/kNg]
o?cl2oooo`03o?cloooooooo00Ooool2o?cl:Oooo`008Oooo`03moOglO7amoOg027gmoL00f=SHlW9
bM;BdP09f][J00?0`<3Jf][Jf]X00][JfP03`<30h>3PemOG00;Jf]X01m;Bd]OGelg=cLW9bLC4a<71
`KRh^003][Jf00Jb/[:][JfYZJVb/[:YZJVQXJ43/[:b2_Ogm`03lO7amoOgmoOg017gmoLOoooo00<2
0P8:2PX20P808@820P0310@4<C4a820P00P/;2`00b<S8b`/;2`/;002;2`/00@S8b</;2`S8b<P8202
;2`/0S4a<@050000ATI6C4a<C4a<Cdm?00=DE5@00da<C4M7Ada<C002Cdm?00=1@D5<C4a<C4`02P82
0P032PX:0P820P8201420P8Poooo00?lo?coooooool08?ooo`;dm?@00o;bl_Kfm_KfmP07m_Kf00?b
l_;fm_Kfm_H00_KfmP03l_;bn_[jn_[j00;fm_H01o;bl_[jn_3`l?Cdm>k^k^CTi>?Sh`03inOW00KU
iNGVi^K/k>c]kNg/k>cPh>03kNg]2_ooo`03o?cloooooooo03Coool0027oool7moOg00GalO7gmoOg
moOgmoOalO405_Ogm`05@d=3;2`/@T92b/[:d];B00;Jf]X01>3Ph=[Jf/30`<30`0;Jf]X2`<3000_J
f][Bd];Bd];Ph>30`<3GemO:b/[8b<S7alO1`L79bLT00/C4a006`<30P820^k^k/;2`][JfY:BT0Z2P
X007Z:RXZJVYZJVYX:2PZ:RXPX:2/[:b01kgmoLOoooo8`820P070`<30000;2`/820P;2`/820P;2`/
00<P82000b`/;20P820P8002;2`/014P820S8b<P820/;2`a<C4P820`<30b<S8`<3000012@T861PI2
@T94A4A:BTY4A4ADE5@00TA4A007@410Cdm?Cdm?C4a<@4100000C4a<01h20P8Voooo00Glo?cooooo
ooooooolo?`05_ooo`05inOWa<C4h>3Pl?3`l_;b00;fm_H01?[jn_Kfm_;bl_;blP;fm_H2l_;b00Wf
m_Kbl_;bl_;jn_[bl_;jn_[`l?3dm?Chn?P00_3`l00;j^[Zk^k^h^;Ri>CTkNg]hN7QinOWi^KVh>3P
i>CTa/K600;/k>`01>3Ph>c/k>SXj>g]kD7oool0027oool01?Ogmo7alO7alO7al@;gmoL00o7alOOg
moOgm`0HmoOg00?2`/93@d<`<3000][JfP07emOGf][Jh>3Ph>3Pf][J`<30h>3P00?Jf]X00l30`>3P
h>3Ph002f][J00KBd];GemO<c<c9bLW4a<B0P804a<C400?0`<2k^k^b/[800[Jf]P06/[:b[Jf]YjNW
YjNWZJVYXJ6Q0ZVYZ@03a<C4moOgmoOg01cgmoLOoooo00@20P8:2PX20P8:2PX20P8200<:2PX20P82
0P8060820P043`l?DE5ATi>C820P0S4a<@04;2`/8b<S;2`/;2`/0R<S8`</;2`28b<S00<P820/;2`/
;2`00S4a<@0410@4ATI6ATI6BTY:14I6AP04?cloBTY:A4A4E5AD0Ta<C09DE5@01Dm?CeADE4m?Cdm?
CaTI6@0N0P828?ooo`?lo?`2oooo00?lo?coooooool06?ooo`07lo?ci>CT]KFemoOgm_Kfn_[jm_Kf
00;jn_X00oKfm_;bl_[jnP03m_Kf00?bl_;jn_[jn_X00_KfmP06l_;bn_[jh^;Rm?Cdk^k^k>c/1>k^
kP03h^;RkNg]kNg]00;WinL01>g]kNKVi^o_kno_k`C/k>`00o_knoooooooo`0ooooo000Qoooo8OOg
m`04<C4aB4Q8f][Jclo?1=[JfP03h>3Pf][Jf][J00GJf]X4h>3P013Jf][GemO?clo4a<C9bLW4a<Bk
^k_4a<C0`<34a<Bk^k^f][Jb/[:i^KVf][J`/;02[Jf]00>YZJVWYjNWYjL00[:b/P03]kNgmoOgmoOg
01cgmoLOoooo80820P052PX:F5QHNg]k;2`/820P00</;2`00b0P82`/;2`/;006;2`/0b<S8`8/;2`0
0c4a<@820S`l?002ATI600=:BTX61PI6ATH00TY:BP07E5ADC4a<E5ADC4a<GemOEeMGCdm?00=DE5@0
0da<C451@@820P0M0P82@?ooo`04h>3Pe=CDm_KfnOWi1?KfmP03n_[jm_Kfm_Kf00Gfm_H4n_[j013f
m_Kjn_[inOW^k^kdm?C^k^k]kNg^k^kclo?^k^k]kNgWinO]kNgalO7WinOPh>02i^KV00?/k>c_kno_
knl00^g]k@03lo?coooooooo03ooool0027oool4moOg0_7alA[gmoL01?oooaTI6M[Jf/o?c`;GemL;
f][J0n3Ph004f][JalO7cLg=a/K60/C4a0Fk^k/01;Vi^KJf][:b/[:b/PB][Jd01:NWYjf][JVYZJf]
[@:b/[800m[Jf_OgmoOgm`0KmoOg7oooo`@20P822PX:6P820P05?cloMgMg;2`/<S8b<C4a00`/;2`2
8b<S00H/;2`a<C4b<S93@d=2@T96ATH5BTY:0Ti>CP03E5ADC4a<EeMG00=GEeL01eADE5MGEdm?Cdm?
CdA4A4a<C20P800M0P828oooo`;lo?`Koooo00?9bLWfm_KinOT00_[jnP_fm_H3n_[j00Cfm_Khn?S`
l?3Zj^X2k^k^1Ng]k@04lO7ainOWkNg]kNg]1>KViP04kno_i^KVk>c/i^KV0^g]k@03moOgoooooooo
03koool0027oool6moOg0_7alASgmoL00gMgM`000<o?c`08f][J0]OGe`05f][JemOGf][J`<30h>3P
00?Jf]X00lO7alc<c<71`@03^;Rh00Ff][Jh^;Rf][Jf][JTY:@01:f][@0;ZJVY[Jf][Jf]YjNW[Jf]
Z:RX[Jf]/[:b[Jf]ZJVYd];B01cgmoLOoooo1P820P032PX:0P820P8201H20P801000055ADCXj>S8b
<PL/;2`3<C4a00<P820/;2`/;2`00R<S8`8/;2`0134a<C8b<TA4A4a<C0=?Cdl015ADE4A4A5ADE5AD
E0AGEeL01Dm?CeMGEeMGEeADE5MGE`02Hf=S00A4A4AGEeM?CdlP820L0P829Oooo`;lo?`Hoooo00?_
knoPh>3inOT02?KfmP;jn_X01OKfm_[jn_Kfm_;bl_[jnP03m_Kf00?hn?SRh^;Ti>@00n?Sh`04inOW
hn?SinOWinOW1NKViP0;i>CTi^KVi^KVkno_i^KVg]kNi^KVkNg]i^KVk>c/moOg03ooool0027oool3
moOg00?alO7gmoOalO406OOgm`09/K6a>c/k@410d];Bf][Jd];BemOGf][J`<3000?Jf]X00lO7amOG
em;BdP02f][J00G0`<3Jf][0`<3Ph>38b<P00X20P004/;2`XZ:RXZ:RX:2P1::RXP04X:2P[Jf]ZJVY
ZJVY0Z2PX0:][Jd01JVYZJf][JFUYJf][JRXZ002ZJVY00>0P83gmoOgmoL02?Ogm`03lO7amoOgmoOg
00OgmoL00o7alOOgmoOgm`05moOg7ooooal20P801P0002<S8b0P820P82`/;20P808/;2`0220P82`/
;2`/;34a<C0`<34a<B0P82`/;08P820012`/;20P80@414A4A090@4001P820X>3Ph>3P`820X>3P`41
0@80000025EEEEMGEdM7Ad10@51@D4A4A5MGEdM7A`9GEeL01EADE4=3@dm?Cdm?Cd51@@0L0P828_oo
o`03o?clooooo?cl01Woool02O7alM_Kfo3`l?;bl_Kfm_;bl_[jn_Kfm_;blP03m_Kf00?hn?Sjn_[b
l_800_KfmP05l_;bm_Kfl_;bn_[jh^;R00;0`<001<C4a;Rh^;Rh^820P0:h^;P028R8R:2PX820P>KV
i^CTi>c/k<k>c^3Ph0;Vi^H01NCTi>KVi^KVi^KVi/c<c002k>c/00?Ph>3oooooool02?ooo`03o?cl
oooooooo00Ooool00oclo?ooooooo`0Xoooo000Qoooo7_Ogm`04b<S8>c/kf][Jd];B0m[JfP05emOG
`<30f][Jf][JemOG00;Bd]800mOGem;Bd][JfP02f][J0/c<c009dm?Cc<c<P820XZ:RX:2PW9bLShn?
PX:2W9bL00:GUiL01::RXX20P::RXZBTY0:WYjL00jBTY:f][Jf][@02[Jf]00NPX:2][JfXZ:RYZJVb
/[:PX:3alO406oOgmaoooolN0P8200<D51@P820a<C400b`/;005820P8b<S;2`/;2`/820P00<j>SX0
0c4a<BPX:2`/;002;2`/00M4A4@410A4A4A4A4AbLW:3Ph>0P8000ZJVYP03Ph>3U9BDSHf=00:3Ph<0
0fi^KX>3Pe1@D002E5AD00]KFe]GEeMGEeMGEeM<C4aGEeM3@d=?Cdm<C4aGEeM<C4`06`820Sgoool0
1?Ogmm_KfoOgmo;blP?fm_H01O[jn_;bl_Kfm_Kfm_[jnP02mOGe00?jn_[emOGfm_H00_KfmP;Rh^80
2O?cln;Rh/30`;Rh^;^k^k2`/:6QXJ2PX;2`/002][Jf00Bh^;R@T92h^;SShn<2kno_00?Shn?Vi^KV
i^H00^KViP07i>CTi^KVg]kNk>c/kNg]i>CTo?cl03koool0027oool01OOgmo7alOOgmoOgmo7al@0H
moOg00SalO5MGEe/K6c?cloGemOJf][GemOBd]84f][J00SGemOBd];0`<3=cLgBd];Jf][Ph>38b<P3
c<c<00?1`L6:RXZ?Shl028n?S`08PX:2Ti>CVi^KZZZZZ:RXY:BTYjNWZ:RX0Zf][@03X:2P[Jf][Jf]
00:YZJT00j2PX<K6a_7al@0JmoOg7oooo`050P822PX:0P820P822PX:01P20P800`X:2Slo?c8b<P02
<C4a00</;2`a<C4X:2P00b`/;008820P>SXjATI6>SXj@d=3:2PX8b<S;2`/0dA4A003C4a<LG5aTi>C
00FVYZH029>CTjJVYZJVYXf=SH>3PhN7Qd10@6=SH`9KFe/01410@5MGEeMGEda<C09GEeL2Cdm?00=G
EeM<C4`20P806P820R3oool01?clo?ooooooooclo1Soool02?clo>g]kOCdm?WinO[jn_Kfm_[jn_Ge
m@Cfm_H01o[jn_GemNCTi?3`l?GemOKfm_[jnP04h^;R00?Ti>B0P82QXJ401:6QX@0</[:bXJ6QXJ6Q
XJ6Q/;2`_;bld];Bf][Jg]kNhn?Skno_g]kN0^KViP03i>CTi^KVi^KV00;/k>`00nCTi>[Zj_clo00m
oooo000Qoooo1_Ogm`03lO7amoOgmoOg01CgmoL018V9RCTi>N3Ph<o?c`GGemL2f][J0]OGe`04bLW9
a<C4a<C4emOG0][JfP0>c<c<cLg=/;2`ZZZZX:2PR8R8^;RhPH61c<c<]kNg>3PhTi>CQhN7Ogmo0XN7
Q`05Ti>CWIfMWIfMZJVYX:2P00:WYjL2[Jf]00VQXJ6b/[:][JfYZJV][JfPX:2g]kOXj>SalO406OOg
maooool60P8200<:2PX20P820P8050820P036a/KF5QH8R8R00Da<C43;2`/00<a<C4l?3a6ATH00TI6
AP03820P;2`/A4A40093@d<0571`L8R8R6i^KUeMGDm?C`000451@GemODm?ChN7QjFUYJf][JJVYXf=
SHN7Qfi^KTm?CeADE6IVIUADE09GEeL015mOGeMGEdA4A4m?C`9GEeL00da<C00000X:2P0I0P829Ooo
o`03o?cloooooooo01Coool01??cln?Sho[jn_Win@Gjn_X2m_Kf0_[jnP04m?Cdk^k^k^k^n_[j0_Kf
mP0Ah>3Pl?3`a<C4c<c<^k^kd=3@hn?S][Jfh^;Rlo?c`L71_;blVYZJTI6AVYZJX:2P_;bl00;@d=00
1>c/k>_[jno_kno_k`;Vi^H01n3Ph>g]kNKVi^c/k>KVi^CTi??cl`02o?cl??ooo`008Oooo`CgmoL0
0o7alOOgmoOgm`0EmoOg00Jf][I;Bd/`<33Jf][GemOBd]82emOG00C=cLgJf][0`<3Ph>02d];B00?9
bLVi^KW4a<@00][JfP08cLg=/;2`X:2PQhN7K6a/[Jf]R8R8b<S80[Vi^@09a/K6Q8B4^KViM7AdYZJV
K6a/3`l?Shn?Ti>C00:MWId02:BTY:NWYjRXZ:f][K:b/[2`/:f][JRXZ0:][Jd00j2PX:VYZKNg]`02
iNGU6?Ogmaooool40P8200<:2PX20P820P805@820P065aLGBTY:Ti>C820P<C4a;2`/0S4a<@060000
8b<S;2`/8b<S>SXj?3`l0Ti>CP09ATI6;2`/@d=3LW9bE5ADR8R8Z:RX9bLWCdm?008D51@0220P8492
@RPX:1TI6B0P80820XZ:R[Fe]@:CTi<02PH61Vi^KU]KFe]KFd10@5MGEda<C4i>CTa<C4=3@`=GEeL0
0da<C451@@820P0I0P828oooo`03o?cloooooooo01Goool2inOW00Be]KGfm_Kjn_[bl_82n_[j00C`
l?3fm_Kbl_;jn_X2mOGe00?dm?CalO7^k^h00_KfmP03l?3`a<C4^k^k00:JVYX00oCdm>?ShoOgm`02
lO7a00WZj^[alO7alO7=cLgPh>39bLV@T92b/[:l_;`00]3@d008hn?Skno_g]kNi^KVkNg]hN7Qi^KV
g]kN0^KViP03i>CTk>c/lo?c00;clo<koooo000Qoooo1oOgm`04lO7amoOgmoOglO7a4?Ogm`05Y:BT
R8R8:2PXV9RHemOG00?Bd]806<30`<C4a<30`=[Jf];Bd/g=cHV9RK6a/J2PX<71`Hb<S0820R0P8000
0820P:RXZ861PJ2PX820P>7QhNSXj<30`8b<S8:2PP:8R8P01b@T91PH600004Q8B0@41861PH^;R`02
X:2P00JXZ:R][Jfb/[:0P82i^KV][Jd3X:2P0[:b/P04`<30h>3PaLG5h^;R5_OgmaoooolL0P8200<1
0@40000000000b0P8003<30`10@40000008/;2`01B0P8492@Ti>CV1PH4=3@`02000000/20P92@T8P
82061PH20P80000410@000020P80000@41000R0P80800000455ADD10@0X:2S4a<@P8200004=3@fIV
IV9RHUMGEdQ8B0X:2TY:BTI6ATA4A4a<C094A4@00da<C1@D50820P0H0P829_ooo`04o?cloooooooo
o?cl4?ooo`05lO7ah^;R`<30inOWn_[j00;bl_801o3`l>CTi>k^k_;bl_Kfm_;bl_3`l002h>3P01?0
`<3Ph>2PX:0`<32HV9Q0@42l_;cPh>2PX:3<c<bPX:3hn?Slo?cbl_:`/;30`<2c/k?Shn>@T9000/30
`00?T92@PX:2TY:BXZ:R`/;2jn_[g]kNi^KVkNg]hN7QlO7ai^KVi>CTk>c/i>CT00;]kNd01?Ogmocl
o>o_koOgmcWoool0027oool2moOg0_7al@;gmoL2lO7a4oOgm`0:M7Ad@d=3EEEEclo?emOGf][JemOG
d];Ba<C4emOG0m[JfP09cLg=/K6aXJ6QT92@K6a/BDU9Hf=Sa<C4h>3P00;Xj>P01>_[jo7alNSXj?7a
l@;Xj>P04lo?cnSXj=[Jf][Jf/30`:f][F1PH2h^;T92@WAdM861PH:2PZ2PX:RXZ:f][K^k^h20P;^k
^kVi^@02[Jf]00NPX:2b/[:b/[:j^[[Lg=calO7Ph>005_Ogmaooool30P8200@:2PX20P820P8:2PXD
0P8200DX:2QADE5oOglb<S8P82000S4a<@03>SXjATI6820P00</;2`024=3@gAdM7inOW=cLkRh^92@
T1TI6B<S8`8F5QH02A8B4PX:2QHF5Q8B4PX:2QHF5S8b<Q8B4QHF5P02820P00`W9bNRXZ:1PH6PX:2;
Rh^JVYYcLg=DE5ARHV9GEeM:BTY6ATH2BTY:0UMGE`05C4a<EeMGC4a<>c/k0@41008:2PXF0P828Ooo
o`;lo?`2oooo0_clo1?oool02_OgmnCTi<c<c?WinO[jn_Kfm_[jn_GemNk^k_[jnP?fm_H02O3`l>3P
h=WIfMCDe9ZJVUIFE/?3`o_knoShn002o?cl00?hn?Slo?chn?P00oclo00CnOWin?ShmoOgmoOglo?c
m?CdP820^k^ka/K6XZ:R][Jfa<C4jn_[g]kNi^KVkNg]k>c/kNg]lO7a00;Vi^H01NCTi>g]kNg]kNo_
ko?cl`02o?cl>Oooo`008Oooo`[gmoL00o7alOOgmo7al@08moOg00CXj>SalO7alO7UiND2lO7a00B0
P80i>CVMWIgGemL2f][J01[GemO=cLg4a<CGemOJf][0`<3GemNk^k^a/K6EUIDD51A3@d=0@41mOGfk
^k_8b<S[jn_GemOXj>SalO78b<SalO7Xj>SJf]Zh^;SXj>P2f][J0/S8b006@410P8206a/K6a/KK6a/
7AdM0ZBTY00>[Jf]^KVia<C4^k^k^KVi/[:bZJVYX:2P/[:b[Jf]]kNg^k^ka<C4`L715_Ogmaooool:
0P8200<:2PX20P8:2PX02@820P8:2PX020820PX:2P820QdM7EQHF4Y:BS4a<B`/;08a<C401d=3@dI6
AR0P82`/;2<S8c4a<DY:BP02LG5a01g>c/kPh>18B4Q:BTXF5QH/;2`B4Q8@410:2PX/;2`F5QH:2PX4
10A?CdlB4Q8F5QHP820410@D51@P822/[:aNGUkclo>h^;Re]KE^KViKFe]GEeM>CTh00TI6AP0:BTY:
C4a<Cdm?C4a<EeMGA4A4@D516a/K30`<2`/;5P820RWoool00oclo?ooooclo008oooo0oclo007lo?c
o?clo?cll_;bhn?Skno_n_[j00;fm_H04_[jn_3`l>k^k_[jn_Kfm_;bl_[jn^g]kN3Ph=gMgEEEEF1P
H8F5QM7AdNg]kOCdm?Shn?[jnP;lo?`02?Cdm?clo?clo?Kfm^?ShoShn?OgmoKfmP;gmoL01Z:RX]kN
gS8b<S8b<YZJVY2@T0;Shn<03^KVi_7alNk^k^g]kO7alNg]kNc/k>CTi>g]kNKVi_?clo[jn^g]kNc/
k3Woool0027ooolCmoOg00?alO7gmoOgmoL01OOgm`0461PH;2`/f][Jclo?0mOGe`03bLW9emOGa<C4
00;Jf]X06]OGek6a/JRXZ8n?Sa@D55iNGT=3@j2PX:ZZZX20P=OGel71`N3Ph>SXj9JFU^SXj=OGekJf
][Rh^<30`=[Jf[Jf]/o?cm[JfXV9RKZj^P:LW9`01T=3@`000:BTY:BTY:f][KVi^@;0`<001;^k^jf]
[K:b/ZRXZ0:][Jd01K:b//;2`YFEUH20P=cLg00:moOg00?alO7gmoOgmoL02?OgmaoooolC0P8200<:
2PX20P820P8010820P050000MgMgPh>3;2`/<S8b00<a<C400c`l?34a<@@41002;2`/02ha<C53@d=_
Kfm^KVj_[jo4a<B0P81aLG5dM7A6ATHa<C40000F5QIDE5@a<C4F5QH@411?Cdm6ATHP820/;2`@410/
;2`b<S9?Cdlk>c/j>SZBTY;4a<BJVYYKFe]GEeM>CTi6ATHl?3`:2PYGEeM<C4aGEeMSHf=GEeM<C4`N
7QhV9RHK6a/10@4:0P8200<:2PX20P820P8020820S;oool00oclo?ooooooo`05oooo00CCdm?4a<Cf
m_KinOT3n_[j00?dm?Cjn_[^k^h00_KfmP0Jn_[jh>3Pg]kNinOWP820QHF5H61P^k^kc<c<b<S8n_[j
i>CTn_[jo?clh^;Ro?cln_[jinOWhn?Si^KVm_KfinOWnOWim_Kfj>SXkno_0_;blP0<`/;2Q8B4hn?S
hn?Si^KVlO7ai>CTlo?ckNg]i^KVkNg]a/K60^KViP05kNg]ooookNg]n_[jlo?c00[oool00oclo?oo
ooooo`0[oooo000Qoooo00?gmoOalO7gmoL05oOgm`04a<C44A4ABTY:b<S80mOGe`04`L71a<C4d];B
a<C40][JfP08clo?ZZZZUIFEXJ6Q/;2`][JfUiNGShn?0Z2PX007^;RhZZZZ/K6a/K6aPH61c<c<Shn?
00:GUiL04Z2PX;Jf]Xn?Sk6a/Lo?ck>c/kZj^ZVYZIbLW7EeMA`L79NGUjBTY:f][K^k^l30`<C4a;^k
^`:][Jd02J2PX:VYZJf][KNg]kZj^]cLg<71`L[:b^GUi@0DmoOg7oooo`030P822PX:0P8201L20P80
10@415]KFg1`L1@D50<a<C4013`l?4I6ASXj>P@4108/;2`01c8b<W5aLGAdM5ADE4m?CeADE8B4Q002
R8R800=dM7A?CdmADE400UmOG`0FC4a<A4A4PH61SHf=LG5aGemOE5AD4a<C<S8bBTY:@D51>c/k2PX:
Jf][fm_Ka<C4B4Q8EeMGBTY:ATI6?3`l@T920UMGE`08Cdm?Fe]KAdM7@D51>c/k0@412`/;00005@82
0R3oool00oclo?ooooooo`0Foooo00C]kNg9bLW=cLggmoL3n_[j00C`l?3^k^kemOG^k^h2m_Kf00ci
nOW<c<cMgMgIfMWShn?WinNf][JQXJ6k^k^IVIWShn?<c<`3h>3P01KRh^:b/[:f][Jf][K0`<3WinNb
/[;Ph>3inOWQhN7_kno/k>cbl_;Ph>00003Jf][Shn?Vi^K]kNgTi>C^k^k]kNd2i^KV00OPh>3/k>cV
i^Kclo?_knoclo?QhN400_?clcOoool0027ooolHmoOg00KalO5/K6`P820820RJVY[Jf]X3emOG00c=
cLg9bLW=cLff][KGemOBd];<c<ba/K6@T92k^k_1`L7Jf]X2emOG00K<c<c0`<31`L6h^;S1`L6h^;P2
/;2`00FZZZZXZ:RGUiN7QhN9RHT00Xn?S`0B]kNgT92@bLW9Vi^KZJVYP8208R8RI6ATWIfMYjNW^KVi
`<30a<C4^KVi/[:b[Jf]XJ6Q[Jf]0[:b/P05]kNgmoOgdM7AcLg=g=cL01CgmoLOoooo60820P062PX:
?clo0`<3ZJVYDE5A;2`/0S4a<@93@d<03S`l?4=3@a0@42`/;34a<DA4A5iNGTY:BTa<C38b<R`/;34a
<DA4A492@P=<C4`2Cdm?0W9bLP04@D51SHf=SHf=YZJV0Y>CT`0I@D51LG5aLg=c?3`l@410GUiNk>c/
inOW;2`/E5ADCTi>ATI6?3`lATI6C4a<EeMGE5ADCdm?A4A4C4a<@D510P822PX:2`/;0@4101@20P8g
oooo00Klo?cdm?C<c<b0P83Ti>Cfm_H3n_[j00c`l?3dm?C`l?3WinOjn_[bl_;Rh^;Ph>3De=C]kNgP
h>3fm_H2n_[j00gRh^;Ph>3Ti>CShn?Ti>CShn?0`<34a<CJf][Ng]jf][JPX:2k^k/00[:b/P0Blo?c
e=CDm?Cdd];Bk>c/g]kN51@DZZZZd=3@kno_lO7ai>CTk^k^lO7akNg]i^KVk>c/i^KV0^g]k@05lo?c
ooool?3`kno_lo?c03Ooool0027oool8moOg00?alO7gmoOgmoL03?Ogm`03`/;2RHV9000000800000
1m[Jf/c<c=OGelC4a=;Bd/S8b<c<c002bLW900KGemO0`<39bLVf][J0P82DU9@2`<3000?Ph>30`<3J
f]X00/30`0;Ph>03`<300/C4a006`<30P820Ti>CXZ:RPX:2R8R80X20P008PH610@41E5AD5QHF@410
A4A4Q8B4Y:BT0/C4a005^KViX:2P[Jf]X:2PZ:RX00:][Jd01[:b/XB4Q0P82>3Ph<30`>SXj1?gmoLO
oooo20820P032PX:0P820P8200`20P8030H61P/;2gMgM`000820P2`/;000034a<@00030`<0@41000
008`<3001P@4100000000410@51@D492@P<P82001b`/;2<S8b`/;20P82<S8b0P80@4100200000152
@T94A4@<30`20P8820P000030`<:2PZ2PX861PH@4124Q8C2`/;6a/J0P81:BTYDE5@00TI6AP0;@T92
A4A4EeMGA4A4Fe]K@d=3EeMG@410:2PX8B4Q0000008:2PXC0P829oooo`03o?cloooooooo00coool0
2_?cln?Shlc<c<C4a820P?Kfm^3Ph?[jn^;Rh_3`l0;Ph>02l?3`00_jn_[Rh^;`l?3WinODe=C5aLGR
h^;bl_;jn_[bl_;fm_H00_;blP;jn_X00o;bl^;Rh^3Ph002j^[Z013Ti>BPX:2TY:BPX:2HV9RBTY:@
T92XZ:Rb/[:@T920P80E5AFHV9R0P830`<3Vi^H2k^k^00GQhN7Ti>CVi^KPh>3Ng]h00^KViP;QhN40
1<30`?Cdm?3`l?clo3Koool0027oool00o7alOOgmoOgm`0DmoOg00KRh^8i>CU/K6bVYZIMGEgJf]X3
emOG00CBd];7alOGemOGemL2clo?00K7alO?clnf][Ja/K6QXJ6;Rh/4f][J00O0`<3Jf][Ph>3Jf][P
h>3Bd];=cLd00/C4a007^k^ka<C4^k^k][Jf/K6a[Jf]X:2P00:XZ:P03jZZZZBTY9RHV9FEUI2@T9FE
UJRXZ<30`<C4a;^k^jf][JVYZJFUYJf][JRXZ002/[:b00B`/;1DE5CgmoOXj>PDmoOg7oooo`032PX:
0P820P8201@20P801PH61UQHF6m_KeADE7MgMb`/;08a<C400c0`<38b<S4a<@02<C4a00Pb<S8a<C4b
<S8b<S9DE5AdM7A:BTXb<S83;2`/00XS8b</;2`/;2`P820S8b</;2`a<C53@d=6ATI:BTX2ATI601E:
BTYDE5AGEeMSHf=KFe]SHf=1@D5KFe]^KVicLg=`L71aLG5SHf<o?cm6ATI2@T9GEeM?CdmGEeMDE5A3
@d<00Ta<C0048B4Q:2PX0P822PX:50820Qooool00oclo?ooooooo`0Doooo00KgmoOShn?OgmoPh>3A
dM7fm_H3n_[j00CemOGhn?Sjn_[jn_X2nOWi00Khn?SinOWWinOPh>3IfMWYjNT4m_Kf00Obl_;fm_Kj
n_[fm_Kjn_[bl_;`l?000^k^kP07kNg]k^k^kNg]inOWh>3Pi^KV`/;200;Ng]h03=[Jf^?Shm3@d=gM
gMCDe=gMgMkNg^;Rh^k^k^g]kNKVi^c/k0;Vi^H01mkNg^g]kNg]kO3`l>7QhOooooclo00goooo000Q
oooo5oOgm`05g=cLGUiNemOGclo?a<C400;?cll2emOG00GBd];7alOGemO<c<cJf]X00]OGe`07clo?
^k^k/K6aZ:RXPH61clo?f][J00;Ph>000l30`=[Jf][JfP02h>3P00_8b<S4a<C4a<Bi^KW4a<B0P82k
^k^f][J][JfWYjNPX:000ZNWY`BTY:@01Y^KVjBTY:2PX820P<C4a;Vi^@:][Jd2YjNW00J][Jfb/[:b
/[:][Je1@D74a<@EmoOg7ooooaL20P801@410EMGEc4a<@820TI6AP02<S8b00<a<C4`<30b<S800S4a
<@0;A4A4820P<C4a<C4a<S8bBTY:Hf=SM7Ad?3`l<S8b820P008S8b<2;2`/00@P820S8b</;2a4A4@4
ATI60TY:BP9DE5@03Dm?Ce]KFeADE51@D5]KFeADE5]KFd10@5]KFfIVISlo?dY:BTI6AP02EeMG0eAD
E09<C4`00bLW9clo?a0@400E0P82=_ooo`05lo?cjNWYn_[jnOWik^k^00;inOT2n_[j00GemOGhn?Sj
n_[Rh^;fm_H00_[jnP07nOWikNg]h>3Pg]kNd=3@nOWim_Kf00;jn_X00o;bl_Kfm_KfmP02n_[j00_R
h^;^k^k^k^kalO7^k^k/k>c]kNgWinOVi^K_knoPh>000^o_k`CShn<01];Bd^?Shn_[jn7QhNk^k_7a
l@;Vi^H2kno_00KVi^K]kNg]kNgdm?CQhN7kno/hoooo000Qoooo5_Ogm`07lO7aY:BTclo?f][JemOG
b/[:b<S800;?cll01/c<c=OGem[Jf][Jf]OGem[JfP;GemL01lo?clC4a;^k^k6a/JRXZ<o?cmOGe`03
h>3P0m[JfP0Mh>3P`<30a<C4a<C4^KVi^k^kP820^KVi][Jf[Jf]YjNWP820UIFEVi^KVIVIVi^KVIVI
Y:BTX:2PYjNWZ:RXP820^k^k/[:bZ:RXY:BTX:2PYjNW[Jf]00:YZJT00kJf]Q4A4OOgm`0EmoOg7ooo
oaH20P801`X:2RPX:38b<R`/;20P838b<Q@D5002<S8b00H0000/;2`/;2`/;2`a<C4P8202<C4a00Lb
<S92@T9OGemSHf=>CThb<S8Q8B400b<S8`8/;2`28b<S00Dj>SY6ATI6ATI:BTY6ATH00Ti>CP9DE5@0
0e]KFf1PH75aL@03H61P00Q^KVi2@T9DE5ASHf=>CTi6ATI8B4QSHf<2Fe]K00IVIVIDE5A?Cdm?CdlU
9BEKFe/F0P82=Oooo`07o?clmOGenOWim_Kfn_[jl?3`moOg00;inOT01^;Rh_[jn_Kfm_Kfm_[jn_Kf
mP;jn_X01_WinNk^k^g]kN3Ph=3@d?Win@Cjn_X3m_Kf01Kjn_[`l?3^k^k^k^kalO7]kNgPh>3alO7W
inOVi^K_knoRh^;MgMgRh^;Vi^KRh^;0`<3Shn?[jn__knoNg]kPh>02kNg]00GNg]kShn?Shn?_knoV
i^H00^c/k003mOGeb<S8oooo03Soool0027ooolFmoOg00WDe=CGemOGemOJf][GemO0`<3?cloGemO?
cll00]OGe`0@d];Bf][Jf][Jf][Jh>3Pf][Jc<c<bLW9a<C4][JfX:2Pa<C4clo?f][Jh>3P`<300][J
fP05emOGh>3Pd];Bclo?a<C400:a/K402;2`/:f][JNWYjBTY9fMWIVIVI^KViNGU`:IVIT02I6ATIVI
VIVIVIfMWK:b/Z2PX;Vi^KJf]ZRXZ002Y:BT0ZNWY`05/[:bZJVYY:BT0000iNGU01GgmoLOoooo5P82
0P050@41<C4a<C4a;2`/8B4Q008b<S80134a<C8b<S4a<C4a<@</;2`07R0P82`/;2`/;4A4A0@415AD
E5mOGf=SHdI6AR0P82<S8b`/;2<S8b`/;20P82<S8b`/;34a<C8b<TI6AUmOGeADE4i>CUMGEe1@D4Y:
BV1PH6EUIF1PH6ATI09UIFD026a/K6EUIFi^KTa<C6IVITY:BTA4A6=SH`=KFe/01UADE4a<C4m?CbPX
:6=SH`0001D20P8eoooo00Wclo?jn_[jn_[fm_Kjn_[hn?SinOWjn_[inOT00_[jnP0@l_;bm_Kfm_Kf
m_Kfn_[jm_Kfh^;Rm?Cdk^k^inOW`<30k^k^nOWim_Kfn_[jl_;b0_KfmP;jn_X00o;bl_WinNk^kP02
h>3P00GQhN7Vi^K_knoShn?_knl00^;RhP04f][Ji^KVi^KV`/;20^KViP06d=3@kNg]jNWYlO7ainOW
g]kN0^?Sh`;_knl01Ng]kNc/k?GemM;Bd_?cl`0hoooo000Qoooo5_Ogm`0<`<30emOGf][J`L71aLG5
PH61`<30emOG`<30emOGd];B`<301>3Ph00<`<30emOGc<c<`<30P820X:2P/K6aa<C4f][J`<30h>3P
f][J0/S8b004alO7`/;2a<C4/[:b0[2`/004P820X:2PX:2PX:2P0Y6AT@:IVIT2P82000>IVIVATI6A
TI400Z2PX004/;2`XJ6Q[Jf]Z:RX0ZBTY007X:2PZJVYZJVYX:2PQ8B40000P82001GgmoLOoooo5P82
0P0<2PX:<C4a;2`/<30`0000<30`410@<C4a0000820P;2`/820P12<S8`04820P<C4a10@4@T920UAD
E003CTi>10@4820P008S8b<03b`/;000030`<20P830`<492@T10@4A4A4a<C6=SHd10@492@VATI61P
H6ATI003H61P0VEUI@03HF5Q@410@4100094A4@00eMGEd=3@e]KF`02Fe]K00I0@417AdM<C4`X:2QC
De<@410E0P82=Oooo`03l?3`n_[jm_Kf00?`l?001?;bl_[jn^3Ph?[jnP;bl_84n_[j01;bl_;jn_[R
h^;Ti>C/k>c0`<3Ph>3^k^kfm_Kbl_;jn_[fm_KRh^;`l?3hn?S`l?3Ph>3UiND2hn?S00C4a<C>c/kX
j>SShn<2`/;21>;RhP09i^KVa<C4a<C4c/k>a/K6hN7Qh>3Pi^KVc<c<00;Shn<01lk>c^c/k>CTi>c/
k?3`l8B4Q?;blP0hoooo000Qoooo5_Ogm`07d];BemOGh>3Pclo?/K6aTY:Bclo?00?GemL00m[Jf/30
`>3Ph004h>3P00cJf][?clo9bLW4a<Ba/K6XZ:Ra/K7?cloPh>30`<3GemOJf]X2emOG01GBd];GemO9
bLW4a<Bk^k^b/[:TY:B:RXZGUiNEUIFCTi>IVIVKVi^PX:2MWIf0P82PX:2][Jfk^k^i^KVYZJT00jf]
[@:TY:@01ZVYZJRXZ:VYZJVYZHN7QbPX:1KgmoLOoooo5@820P080000;2`/<C4a8b<S<S8bC4a<<C4a
<S8b0S4a<@03820P;2`/8b<S00DS8b<01b`/;30`<4I6ATi>CUmOGf=SHa8B4P028b<S00</;2`a<C4P
82000S4a<@04;2`/<C4a10@4BTY:0Ta<C00<Fe]KI6ATLG5aK6a/H61PIFEUH61PKVi^IVIVIFEUATI6
BTY:0Ti>CP=GEeL3Fe]K00I3@d=?Cdm?Cdlf=SIOGel0000E0P82=Oooo`07l_;bn_[jn_[jnOWih>3P
j>SXnOWi00?jn_X00oKfm_;bl_[jnP04n_[j00cfm_KinOWdm?C^k^kPh>3Ng]kPh>3inOWjn_[bl_;j
n_[fm_H2n_[j00Cbl_;jn_[dm?C^k^h2kNg]00oShn?OgmoJf][MgMg2`/;Vi^KRh^;[jn_@d=3Rh^;[
jn_Vi^K]kNgalO7Ph>000nKViP;Shn<01^c/k=kNg^c/k>c/k>GUiL71`CWoool0027ooolFmoOg00?G
emOJf][Ph>000[^k^`06P820clo?emOGc<c<emOGf][J0n3Ph008j>SXh>3Ph>3Pf][JemOGd];BcLg=
P8200[6a/@03bLW9f][J`<3000;Jf]X01>3Ph=[Jf/30`=OGe`;6a/H04[^k^jFUYJf][Jf][I^KViNG
Uh:2PYVIVI^KVj2PX:BTY8R8R;:b/[Jf]/30`;^k^jVYZKJf]P>][Jd00jBTY:VYZJNWY`02ZJVY00F3
Ph<P8213@d?UiNGalO404oOgmaoooolE0P8200/0000a<C4/;2`S8b=:BTY8B4Q4A4@b<S8a<C54A4@P
820012<S8`0:0P828b<S8b<S;2`/<30`@d=3ATI6CTi>GemO71`L0R`/;00:8b<S;2`/820P;2`/8b<S
;2`/<C4a@T92BTY:@D510UMGE`0;@410K6a/IfMWK6a/IFEUH61PFe]KKVi^Hf=SA4A4?clo009:BTX0
1eMGEeADE5MGEeMGEeADE5]KFdA4A002Cdm?00EEEEEoOgm1@D420P8:2PX04`820SGoool00o[jn_Kf
m_[jnP02kNg]00KPh>3inOWjn_[Rh^;jn_[fm_H3n_[j00Olo?cjn_[jn_[fm_Kjn_[emOG`l?000n3P
h003m?Cdm_Kfl_;b00;fm_H01?[jn_Kfm_;bl_[jnP;Zj^X01Ng]kN;Rh^KVi^KVi^;RhP02f][J00_V
i^KRh^;[jn_Shn?@d=3]kNgWinOclo?]kNgTi>CWinL00nKViP03hn?Sk>c/kno_00;/k>`01Ng]kLS8
b>CTi??cloclo00foooo000Qoooo00?gmoOalO7gmoL01?Ogm`03lO7amoOgmoOg00_gmoL02>SXj=;B
d][Jf/o?cjRXZ;Vi^L30`<c<c0?GemL01=[Jf^3Ph>3Ph>3Ph0;Xj>P2h>3P00WGemO?clo<c<c4a<Bf
][Ja/K6k^k_<c<c0`<000m[JfP;Ph>001M[Jf/o?clC4a;^k^k2`/003[Jf]00NYZJV8R8RCTi>EUIFI
VIVMWIf][Jd01;^k^`05/[:b/K6a[Jf]Z:RX[Jf]00:TY:@02JNWYjVYZKNg]h^;R`0001<C4fm_Km?C
do7al@0BmoOg7oooo`030P822PX:0P8201820P80218B4S4a<B`/;38b<V=SH`h>3S8b<TA4A08a<C40
0b0P82<S8b<S8`028b<S00dF5QHS8b<S8b<S8b<`<314A4A3@d=6ATIDE5A:BTY4A4@/;2`S8b<00R`/
;0088b<S5QHF8b<S;2`/0P82BTY:Cdm?C4a<0UMGE`06Cdm?Hf=SIfMWI6ATHF5QKVi^0UMGE`A:BTX0
15ADE5MGEf=SHeMGE`9KFe/02E1@D4m?Cd51@E5ADG]kNa<C4cPh>0l?3`X:2P0B0P828?ooo`03o?cl
oooooooo00?oool00oclo?ooooooo`0;oooo00Glo?c`l?3fm_KinOWNg]h00_7al@05h^;Rn_[jn_[j
n_[jm_Kf00?jn_X2o?cl0o[jnP08nOWih^;Rh>3PinOWh>3PkNg]h^;Rl_;b0oKfmP07n_[jn?Shm_Kf
nOWik^k^kNg]hN7Q00?Vi^H01nc/k=kNg^3Ph=gMgNKVi]3@d>KViP04kNg]00GUiNGPh>3Vi^KNg]kV
i^H00^?Sh`09kno_k>c/lo?ck^k^U9BDg]kNk^k^lo?co?cl03Goool0027ooolEmoOg00S?cloBd];?
clo9bLVEUIFVYZK?clo<c<`3emOG00CJf][Ph>3Xj>SXj>P3h>3P0][JfP0@clo?emOGR8R8^k^k^KVi
a/K6clo?f][Jd];BemOGf][Jh>3P`<30emOGbLW9][Jf0Zf][@:YZJT2Y:BT00NPX:2:RXZGUiNMWIfT
Y:B`/;2k^k/00/C4a005^k^kP820/[:b/[:b[Jf]00:YZJT02ZBTY:VYZJVYZKNg]j2PX0`<351@D3Ti
>D=3@iFEUA;gmoLOoooo5@820P08<30`;2`/<S8b?3`lLG5a4Q8B<S8bA4A40S4a<@03820P8b<S8b<S
008F5QH38b<S00@/;2`P820a<C54A4@2BTY:00I2@T8b<S8/;2`/;2`j>SXP82028b<S00</;2`a<C4D
51@00eMGE`0MCdm?Bd];Fe]KGEeMIVIVIfMWK6a/Fe]KC4a<Cdm?@T92ATI6BTY:?clo@D51C4a<EeMG
Cdm?EeMGCdm?Bd];Cdm?@D51IVIVKfm_P820F5QHDE5A9RHV01820P8doooo00SinOWbl_;inOWdm?CM
gMgPh>3inOWRh^83n_[j00Cfm_Kjn_[lo?clo?`3n_[j0_KfmP0@nOWin_[jh>3PkNg]lO7aj^[ZnOWi
m_KfmOGen_[jm_Kfn_[jl_;bn_[jm?CdinOW0^KViP;/k>`2hn?S00O:b/[OgmoJf][@d=3Shn?QhN7]
kNd00^k^kP08kNg]lo?ckNg]kNg]i^KVk>c/i>CThn?S0^c/k007lo?cjn_[`L71_;blhn?Si>CTkNg]
03Goool0027ooolDmoOg00S:b/[0`<21PH69RHV1PH6PX:2c/k?0`<03emOG00?Jf][Bd];Ph>001>3P
h006`<30f][Jd];BemOGalO7b<S80/C4a00DRHV9d];Bd];BbLW9`<30alO7d];B`<30a<C4P820/[:b
Z:RXY:BTP820RHV9P820X:2PP820R8R8UIFE0Z2PX005^;Rh^k^ka<C4P820^k^k00:b/[802JBTY:2P
X:f][J2PX:BTY:RXZ:FUYKNg]jBTY002P82000<0001dM7CRh^804_OgmaoooolD0P820P000004@410
0P821`L7@d=30P0000<a<C400b0P82<S8b<S8`028b<S00l20P8P820S8b</;2`P820`<314A4@l?3a2
@T820P8P820/;2`P820`<30000000R0P80040000A4A4A4A4@d=30U9BDP90@4001T92@T51@FEUIFe]
KD10@4A4A09:BTX2@T920TY:BP07C4a<A4A4A4A4EeMG@d=3E5AD@d=30091@D401E]KFd92@T10@10@
4000000C0P82<oooo`;`l?001/30`;2`/:BTY<;2`^7QhN3Ph0?jn_X00oKfm_;bl_[jnP02n_[j00_h
n?Sjn_[bl_;fm_Kbl_;jn_[hn?SPh>3Zj^[Xj>SPh>000_;blP0Gl?3`h>3Pn?Shl_;bh>3Ph^;Rh>3P
iNGUa/K6h>3Ph^;Rh>3Ph^;Rhn?S`/;2hn?Sf=SHb/[:i>CThN7QkNg]k^k^k>c/00;]kNd03NGUiNKV
i^CTi>KVi/K6a^;Rh/K6a^;Rh_?cln?Shl;2`/?3`n3Ph002moOg=Oooo`008OoooaCgmoL02/c<c=;B
dXR8R9>CTiFEUJf][KRh^<O7am[Jf]OGe`?Jf]X00l30`>SXj>3Ph002h>3P00S0`<3Jf][GemO<c<c?
clo4a<C9bLW?cll2f][J00o0`<3GemOJf][Jf][GemO8b<S4a<Bk^k^b/[:TY:BATI6KVi^IVIVCTi>I
VIT00YFEU@0:WIfM[Jf]/[:bP820a<C4^k^k`L71^k^k^KVi][Jf0Zf][@0:Z:RXZJVYY:BTZJVY/[:b
^[ZjVIVIP820X:2P[Jf]5?OgmaoooolD0P8200Y4A4@`<32DU9B7QhMaLG5GEeL20P8a<C4/;2`a<C43
;2`/00<S8b<F5QHS8b<00R<S8`8/;2`05P00038b<T=3@d92@S`l?20P82`/;2<S8b`/;34a<B`/;34a
<DA4A3`l?4I6ATQ8B5]KFdY:BVATI61PH6ATI6EUI@=aLG401TI6ATa<C4Y:BTI6AT92@Ta<C09:BTX0
14i>CUADE5MGEf=SH`9?Cdl00d];Bda<C3/k>`02IFEU00=VIVHW9bL20P804`820S?oool02^;Rh_Ge
mH20P;bl_=gMgNKVi^?ShoShn?Kfm_[jnP?fm_H00o;bl_clo?[jnP02n_[j00Sbl_;fm_Kjn_[Rh^;i
nOWPh>3dm?CinOT2m_Kf00Obl_;jn_[fm_Kfm_Kjn_[Ph>3^k^h00^g]k@06hn?Sh>3Ph^;Ri^KVh>3P
i^KV0]gMg@0:d=3@i^KVkNg]k>c/k^k^kNg]i>CTkNg]hN7QinOW0^KViP0:g]kNk>c/hn?Sk>c/kNg]
kno_i^KVh^;Rjn_[m?Cd=oooo`008Ooooa?gmoL02m[Jf/c<c<g=cJ2PX9>CTiNGUjVYZLC4a<O7am[J
f]OGe`02h>3P00?Jf][Ph>3Ph>000n3Ph008f][Jc<c<emOGc<c<clo?a<C4c<c<clo?0][JfP;Ph>03
f][J00K=cLg4a<Bk^k^][JfTY:BKVi/4Ti>C00ZKVi^TY:Bb/[:b/[:k^k^0P830`<34a<C0`<2k^k/2
/[:b0Zf][@:ZZZX2Y:BT00NYZJVj^[ZEUIF4Q8BTY:Bg]kOoool04oOgmaoooolC0P8200dP8214A4A1
@D5dM7B7QhM/K6a?Cdl20P8a<C4/;2`a<C4S8b<P82001B<S8`8/;2`024A4A000038b<T92@T=3@dA4
A20P82`/;0<S8b<2;2`/00Db<S93@d=6ATI2@T9KFe/00V1PH0=TI6@2H61P00aKFe]<C4a:BTY:BTXo
?cl61PHo?cm:BTYDE5A<C4a4A4AGEeL3GEeM00=KFe]?Cdlk>c/00W5aL@03Fe]K@D510P8201<20P8b
oooo00[gmoORh^;`l?38b<Rl_;cJf][/k>c^k^khn?Sfm_H3n_[j00?fm_Kjn_[jn_X00o[jnP08m_Kf
h^;Rn_[jh^;RnOWih>3Ph^;RnOWi0_KfmP;jn_X3m_Kf00K`l?3^k^k]kNgVi^KShn?Rh^84h>3P00?R
h^;Shn?]kNd00^g]k@07hN7Qlo?ck^k^lo?ckNg]iNGUkNg]00;Vi^H2f][J0^?Sh`06k>c/kno_gMgM
`L71hn?Slo?c=oooo`008Ooooa?gmoL01<c<c=;Bd/c<c:2PX0:GUiL01k:b//K6a/[:b]OGem[Jf^3P
h=[JfP02h>3P00cJf][Ph>3Jf][Jf][7alOGemO?cloGemO<c<c0`<34a<C6a/H2f][J00?0`<3Jf][J
f]X00][JfP05alO7^k^k][Jf[Jf]Y:BT00:IVIT3Vi^K00>TY:B][Jfb/[800[Rh^003a<C4^k^ka<C4
00:k^k/01[:b/Zf][Jf][JVYZJJVYZ2PX0:TY:@01ZJVY[Zj^YfMWH20P:VYZJBTY1CgmoLOoooo4`82
0P04A4A4>SXjA4A4LG5a0Va/K007C4a<0P82;2`/<C4a;2`/8b<S820P008S8b<02B`/;2<S8b`/;34a
<C8b<S4a<C0`<4A4A3`l?002ATI600@0000/;2`/;2`S8b<3;2`/00Pa<C4b<S9:BTYDE5AKFe]:BTYP
H61UIFD2H61P00EDE5AKFe]GEeM<C4a?Cdl00TI6AP0=@T92BTY:BTY:BTY:E5ADEeMGCdm?EUIFFe]K
Cdm?Fe]KEUIF>c/k009^KVh00dI6AU]KF`820P0C0P82<_ooo`04h^;RmOGeh^;R`<300][JfP07kNg]
j^[Zl?3`n_[jm_Kfn_[jm_Kf00;jn_X03?Kfm_[jn_Kfm_Kfm_Shn?[jn_WinO[jn^;Rh^CTi>k^k^[Z
jP;fm_H00o;bl_Kfm_KfmP02m_Kf00Ohn?S]kNgWinOVi^KShn?Rh^;Vi^H00n;RhP03hn?Si^KVkNg]
00;Shn<00nk^k^g]kNk^kP02kNg]00CUiNGVi^KVi^K/k>`2h>3P0^?Sh`06h>3Pkno_d=3@`<30k>c/
hn?S=oooo`008Ooooa;gmoL02^3Ph<C4a=;Bd][JfZ2PX9FEUI>CTk:b//W9bM;BdP;Jf]X3h>3P0m[J
fP0=emOGclo?alO7emOGc<c<clo?bLW9`<30a/K6bLW9emOGf][Jd];B00CJf]X2a<C400Ba/K6][JfT
Y:BIVIT2Vi^K0YfMW@03Y:BT/[:b/[:b00:k^k/05<C4a<30`;^k^k^k^kJf][:b/Zf][JRXZ:f][JRX
Z:BTY:JVYZNWYjJVY[Zj^ZVYZJ2PX:VYZIfMWLS8b1?gmoLOoooo4P820P098b<SATI6>SXj30`<Hf=S
LG5aI6ATC4a<<30`00</;2`28b<S12`/;005<30`<S8b<C4a<C4a0000008l?3`00dI6AT92@S0`<002
;2`/00Xa<C4/;2`/;2`/;2`a<C54A4A6ATIGEeMKFe]:BTX2H61P00M0@41:BTYKFe]DE5A<C4a8B4Q:
BTX00TI6AP032PX:BTY:E5AD009<C4`00d=3@eMGEf=SH`02Fe]K00QDE5AFEUHk>c]?CdmSHf=4A4A^
KVhD51@C0P82<Oooo`0:n_[jk^k^mOGem_Kf`<30gMgMh>3PkNg]m?Cdl_;b0_KfmP?jn_X3m_Kf00gj
n_[inOWhn?Sjn_[Rh^;inOWdm?CTi>CZj^[dm?Cjn_[fm_Kbl_801?KfmP05h^;Rk^k^h>3Pi^KVhn?S
00?Rh^82kno_00?Shn?]kNg]kNd00^g]k@0Dk^k^lo?ckNg]kNg]inOWkNg]i^KVg]kNi^KVg]kNhn?S
h>3Pkno_h>3Pkno_k>c/c/k>k>c/d=3@moOg=_ooo`008Ooooa7gmoL03O7alI6ATK6a/INGUh20P2PX
:820P8:2PX20P<W9bL;2`];Bd][JfP04`<3000OGemOBd];GemO?clo0`<34a<C0`<000/K6aP04`<30
clo?clo?clo?0];BdP0>emOGf][Jf][Jf][J`/;2a<C4][Jf[Jf]Y:BTP820Vi^KVIVIWIfMY:BT0Z2P
X003^;RhP820P82000:0P8001<30`;Vi^K:b/[2`/0:PX:000jBTY:6QXJBTY002Y:BT00RQXJ6h^;P@
4121PH6g]kNJVYZBTY;Ph>0BmoOg7ooooa820P802@0004i>CR0P80d=3F=SHfEUIFATI0410C0`<002
820P00</;2`P820P82000R0P800:<C4a<30`<30`<30`0P82@T920P82@T9210@40P820S8b<P<P8200
234a<B`/;2`/;20P830`<492@UADE5]KF`90@4001V1PH410@5]KFd];Bd=3@dA4A08:2PX01D10@0X:
2PX:2TY:BT10@003A4A400aCDe=4A4AFEUIKFe]BDU91@D4;2`/10@4@4110@41cLg=0@40C0P82<?oo
o`09o?cll?3`h>3Pf][Jd];B`/;2fm_K`<30lo?c00;`l?000o;bl_Kfm_;blP03l_;b00[jn_[`l?3j
n_[inOWPh>3Zj^[alO7Xj>SZj^[Ph>03nOWi0_;blP0:n_[jm_Kfm_Kfm_Kfl?3`j^[ZinOWi^KVhn?S
h>3P0^;RhP05kno_hn?S`<30i>CThn?S00CQhN402_?cln7QhNGUiN7QhNCTi>c/k>;Rh^c/k>3Ph>?S
h`;Ph>001n?ShlC4a:b/[??clmCDe<C4a?clo00eoooo000Qoooo4OOgm`0<emOG/K6aWIfMUiNGFe]K
FEUII6ATLg=c`<30emOGf][JemOG1=[JfP04d];Bf][Jclo?clo?0/W9b@03a/K6^k^k`<3000;0`<04
clo?00?Jf][GemOGemL00][JfP0;`/;2a<C4][JfX:2PY:BTTi>CVi^KVIVIVi^KYZJVX:2P00:b/[80
1KRh^;Ng]k:b/[Jf][Rh^002][Jf00Jb/[:VYZJb/[:YZJVVYZJTY:@3ZJVY00N][JemOGf1PH6YZJVT
Y:BPX:3<c<`04_OgmaoooolA0P8200`a<C5OGem^KVi/K6adM7AgMgMfMWIGEeLo?clP820/;2`a<C43
;2`/00Ta<C4/;2`/;2`b<S8`<30b<S8l?3a2@T8:2PX00Slo?`04@T92<S8b<S8b<S8b0R`/;00:<C4a
820P;2`/>SXj<S8bATI6A4A4Fe]KH61PI6AT0V1PH003EUIFFe]KCdm?009<C4`01451@Da<C5ADE4A4
A0=DE5@014a<C4A4A4m?CeIFEP9KFe/2Cdm?00LW9bMmOGfJVYY0@41KFe]VIVI4A4@04P820S3oool0
3?[jn^3Ph=3@d=[Jf]KFe]7AdMcLg>CTi??clo[jn_Kfm_[jnPCfm_H02?;bl_Kfm_WinOWinOCdm?3`
l>[Zj^g]k@;clo<00n;Rh_WinOWin@02nOWi00?fm_Kjn_[jn_X00_KfmP09lO7ak^k^inOWjn_[hn?S
h>3Ph^;Ri^KVd];B00;Ph>02kNg]00GShn?clo?UiNGWinOShn<00^OWi`06iNGUh>3PkNg]k>c/h>3P
hn?S0nc/k007m?CddM7AXZ:Rk>c/hn?Sjn_[h^;R03Goool0027ooolAmoOg00[5aLFQXJ6KVi]2@T:T
Y:AEEEE:BTYeMGG0`<3GemL3f][J00?GemOJf][GemL01][JfP07clo?a/K6a<C4^;Rh/;2`^;RhbLW9
00;?cll04=;Bd]OGem[Jf][Jf]OGelK6a[^k^jf][IfMWI^KViVIVI^KVi>CTj2PX:BTY:2PX0:][Jd2
/[:b00>h^;Rf][J][Jd00[:b/P05ZJVY/[:bZJVYYZJVZJVY00:TY:@02JJVYZf][JVYZH61PHF5QIVI
VJf][IfMWJf][@0BmoOg7ooooa420P802T=3@gAdM61PH9^KVe=CDgmoOg1`L6][Jclo?b0P80</;2`0
1C4a<B0P82`/;2`/;20P8004;2`/00`b<S92@T9?Cdm?Cdm<C4a?Cdl`<30b<S8a<C4/;2`a<C4/;2`2
<C4a00A2@T9:BTY6ATIPH602IFEU00]PH61TI6AKFe]?Cdm<C4aGEeM4A4A<C4a:BTY?CdmDE5@00Ta<
C00@EeMGCdm?C4a<EUIFCdm?E5ADFe]KDU9B9bLWCdm?KFe]Kfm_HF5QEeMGKVi^EeMG4P820S3oool0
2_3`l=WIfN;Rh/K6a^?Shl30`<g=cN3Ph??clo[jnP?fm_H01O[jn_Kfm_[jn_Kfm_Ogm`04m_Kf00Oi
nOWZj^[^k^kShn?QhN7Shn?dm?@00_Win@0@l_;bn_[jm_Kfm_Kfn_[jj^[ZkNg]i^KVd=3@d];Bi^KV
h^;Rh>3Pjn_[hn?Sk>c/0^KViP;]kNd00n7QhNOWinKViP02kNg]00GTi>C]kNg/k>cPh>3/k>`00^?S
h`05h>3Pm?Cdk>c/fm_KaLG500;Vi^H00m3@d>KVi_ooo`0doooo000Qoooo00?alO7gmoOgmoL03_Og
m`0A/K6aZZZZMGEeOGem>c/k@T92GUiNHf=S`<30emOGb/[:f][JemOGclo?emOGclo?`/;200CJf]X0
2l30`=[Jf][Jf/;2`/30`820P:f][K:b/[Ng]lo?cl[:bP03f][J00KGemO4a<C0`<2][JfTY:BKVi/2
Ti>C00FKVi^MWIfVYZJUYJFYZJT00Zf][@>b/[801JJVYZVYZJf][J2PX:f][@02ZJVY00bWYjNTY:BT
Y:BVYZJ][JfYZJV1PH5TI6ANGUj7QhNPX:2JVYXBmoOg7oooo`032PX:0P820P8200h20P804Di>CW5a
LF][JgemOGMgMf=SHeMGEdA4A3lo?b0P838b<R`/;34a<C8b<S0`<1hN7S8b<P04;2`/00<I6AT/;2`<
30`00Slo?`03C4a<EeMG@410008b<S83;2`/0S4a<@03ATI6?cloDe=C009PH602I6AT00I0@41FEUID
E5AGEeM?CdmGEeL3C4a<01=4A4A?CdmGEeMGEeM<C4a7AdM?CdmDE5AKFe]DE5ABDU8W9bM?Cdm]KFf:
RXZ4Q8BIVIUVIVIcLg<04P820Qooool00oclo?ooooooo`0>oooo00o`l?3<c<cPh>3AdM7Kfm_0`<3Y
jNWdm?Cclo?jn_[`l?3fm_Kjn_[inOWjn_X00_Win@Cfm_H02o;bl_Kfm_Kfm_oooo?cln7QhNKVi^g]
kO?cloWinO3`l003m_Kf00Kjn_[Zj^[clo?Vi^KShn?Rh^82h>3P00GRh^;_knoPh>3Vi^K/k>`00^KV
iP?]kNd01N3Ph>c/k>KVi^CTi>KViP02k>c/00c_knoShn?Shn?Ph>3dm?C/k>cKfm^8R8R5QHFn_[k[
jn_De=@eoooo000Qoooo4OOgm`0<X:2P^;RhNGUiOGem61PH20P8BTY:GUiN`<30emOGalO7clo?0][J
fP;GemL018N7QifMWKNg]jNWY`:HV9P2VYZJ00RVYZJKVi^TY:BZZZZ][Jfb/[;0`<3:b/X4f][J00S6
a/Jk^k^][JfKVi^IVIVATI6CTi>HV9P2Vi^K00>IVIVVYZJMWId00ZVYZ@03XJ6Q]kNgZJVY00Bb/[83
ZJVY00^TY:BMWIfVYZJg]kNYZJV6QXI/K6aTI6AdM7B@T92MWId04_OgmaoooolA0P8200YdM7A?Cdmd
M7AmOGeADE63Ph=`L71GEeLo?cla<C42<S8b0R`/;00A<C4a<S8b@D51BTY:@D51E5ADH61PEeMGDE5A
D51@H61PEUIFEeMGGEeMA4A4?clo<S8b00@/;2`0134a<D92@TY:BT10@09UIFD00g5aLFATI410@002
H61P00=:BTYFEUI:BTX00Tm?C`91@D45C4a<0Tm?C`0;E5ADFe]K@T92@D51Cdm?GUiNRXZ:X:2P[jn_
OWinKVi^01820P8`oooo00cHf=SShn?IfMWAdM5gMgO4a<C=cLgYjNWclo?jn_[hn?SinOT2m_Kf0_[j
nP06lO7akno_lo?ckno_j>SX`<300^CTi008h>3Pd];Bh>3Pf][Ji^KVkNg]lo?cl?3`1?KfmP08j^[Z
kNg]i^KVh^;Ri^KVa<C4h>3Pj>SX0n;RhP07h>3Pkno_k>c/k>c/h>3Plo?ck>c/00C]kNd3k>c/00_S
hn?_knoPh>3clo?/k>cVi^J1PH6ZZZZRXZ;De=C@d=00=Oooo`008Ooooa7gmoL02h20P;Rh^8:2PP00
01<C4`00034a<DY:B/W9bM[Jf/O7a`03d];B01;7alO1`L61PH66QXHA4A58B4P0000820P10@53@d<0
00020P80000D51@410@P8210@421PH44f][J00S0`<2k^k^XZ:RPX:2IVIV0P828R8R:RXX2RHV9016P
X:2BTY:@T92PX:2TY:B0P82PX:2@T92WYjNb/[:`/;2PX:2YZJVPX:24Q8B0P824Q8@00jVYZ@06PX:2
H61PK6a/M7AdP820X:2P4_Ogmaooool@0P8200`0000D51A?Cdm6ATJ@T91SHf<30`=SHf=0@40l?3`P
820a<C42<30`01<P820`<300000T92A0@40820Q0@4030`<W9bM1@D5@D50820PI6AU5ADD20P80000R
8R8<30``<3000b`/;006<C4a0000BTY:@T92H61PDE5A0TA4A00=@410BTY:A4A4B4Q8@410B4Q8De=C
@T92ATI6B4Q8@410C4a<@D51009<C4`00dI6ATY:BT];B`02BTY:0Tm?C`06E5AD0P82XZ:R[jn_4Q8B
@d=34P820S3oool02i2@T>?Shl30`492@Q`L7<C4a=_KflC4a?Cdm?Kfm_Shn002l?3`00Obl_;hn?S`
l?3Ph>3Rh^;2`/;4a<@00/g=c@04h>3Pi>CTTI6A`/;20/30`004T92@Z:RX/K6al?3`1?KfmP0:h>3P
kNg]a/K6jn_[h^;R`<30hn?SgmoOk^k^k>c/0^3Ph009kNg]hN7Qh^;Rh>3PhN7QkNg]hn?SkNg]hN7Q
00;/k>`01>3Ph>?Shn3Ph>?Sh`?/k>`01^CTi861PK6a/J:RXY2@T<;2`SGoool0027oool@moOg00co
oon3Ph>f][K1`L4/;2`K6a/T92@k>c]?Cdo?cloGemO:b/X2clo?01?GemOJf][GemO?clnYZJVb/[:H
V9R4Q8@X:2R0P81jNWX<30a?Cdl0002NWYiKFe]/K6bPX:34a<@00][JfP;Ph>002L[:b/C4a:f][J2P
X9FEU@P827emOHR8R:NWY`03]kNg00Rb/[:YZJVYZJVg]kNYZJVVYZJWYjNYZJT2/[:b00BYZJVWYjNW
YjN5QHD2WIfM00RYZJVMWIecLg=TI6A/K6b1PH6EUIFXZ:PBmoOg7ooooa420P802YVIVEADE4a<C8>3
Pd10@8>3PgMgMeYJFS8b<R0P80<b<S80634a<B0P838b<S8b<Tm?Cda<C1DE5EQHF:2PX1dM7@0005YJ
FXR8R2PX:2DU9B8R8VIVITI6AS8b<R`/;20P82<S8b`/;38b<P96ATH01G5aLFMWIgemOGemODA4A004
@D5100Y<C4a?Cdm1@D51@D56ATIDE5A?Cdm<C4a1@D5<C4`2E5AD00]:BTYDE5A:BTY?Cdm:BTYGEeMf
MWJ:RXZJVYYaLG5SHf<04P820S3oool02jb/[>OWinCTi<C4a>CTi8B4Q=_KfmcLg?WinO[jn_3`l002
nOWi01?jn_[fm_Kjn_[inOW/k>c]kNgXj>S[jn^SXj?bl_;EeMFi^KWLg=c@d=3^k^kFe]Ja/K7[jn_X
j>P00_KfmP;jn_X01O3`l>k^k^KVi^_[jmgMg@02dM7A00?Shn?_knoclo<00_?cl`0;kNg]k>c/k>c/
lo?ck>c/h>3Pkno_k>c/hN7QkNg]k>c/00G_knl02>c/k>o_knCTi<S8b<W9bKJf]]gMgMkNgSGoool0
027oool?moOg00gooom2@T:5QHFXZ:Rf][I:BTXE5ADP820`<31NGUk?cloGemO7alL00/o?c`05emOG
f][JemOGd];BbLW900:b/[803LK6aQHF5S/k>b`/;1<C4cLg=aDE5GAdM7emOH61PJf][H^;RmOGe`02
h>3P01?Xj>S:b/[4a<B][JfMWIf:RXZ8R8QdM7@m?Ce@D52CTi>;Rh^1PH66QXI`L71/K6b0P82JVYZM
WId00ZNWY`07RHV9ZJVYZJVYWIfMV9RHWIfMY:BT00:VYZH01IRHV6a/K61PH7AdM92@T002WIfM4_Og
maooool@0P8200/30`>IVIUSHf=DE5A`L71KFe^3Ph>CTi=GEeLb<S8a<C400c8b<P0;<C4a820P<C4a
;2`/?3`lC4a<@410@D51EeMGMgMg0`<300:CTi<02clo?h>3PaPH65MGEdY:BS8b<S4a<B<S8aHF5R`/
;38b<P02ATI600iWIfM]KFe]KFf3Ph>@T91TI6APH61_Kfm]KFeJFUY_Kfm]KFeGEeM0@402E5AD00E:
BTY?Cdm?Cdm:BTYGEeL00TY:BP07DU9BEUIFEeMGKfm_PH610P82OWin009^KVhB0P82;oooo`04a/K6
/;2`g]kNinOW0/g=c@06a<C4]KFejNWYnOWin_[jn?Sh0_Win@05n_[jm_Kfn_[jl_;bm?Cd00;]kNd0
3>[Zj^7QhM_KflC4a=kNg/?3`l71`Lg=cM7AdKJf]^KVi^WYj@?jn_X04_clo?3`l>k^k^KVi]3@d=oO
gn?Shlg=cFYZJ[bl_>3Ph>;Rh]_KfnKVi]GEeMoOglS8b>CTi0?_knl3k>c/00C_knoXj>S_knoShn<2
h>3P00GXj>SOgmo0`<3=cLgDe=@00]3@d3Goool0027oool>moOg00gRh^8`<30^;Rj9RHW=cLfk^k]E
EEDK6a/P820/;2aNGUk9bLWGemL00/o?c`08d];Bf][Jf][Jf][Jd];BemOGclo?^k^k0[:b/P07Ph>3
K6a/Cdm?K6a/E5ADR8R8OGem00:i^KT00hV9RMOGen3Ph002j>SX01G8b<S4a<B][JfMWIfEUIF8R8Qm
OGecLg=KFe^`/;24Q8ACDe<m?Ce2@T9EEEESHf=KFe^1PH66QXJ;Rh^8R8P00iRHV00<Vi^KVIVIY:BT
YZJVWIfMRh^;EEEEGEeMK6a/VYZJX:2PT92@4_Ogmaooool>0P8200d61PJCTi<0001:BTY3@d=:BTYo
Ogl20P9oOgn3Ph=GEeLl?3``<3000S8b<P04>SXj;2`/;2`/;2`/0S4a<@0;<S8bB4Q8C4a<>c/kEEEE
BTY:Kfm_OgmoPh>3KFe]C4a<009>CTh01S8b<S4a<@820QHF5R`/;3`l?096ATH03g5aLFe]KFMWIgem
OG5aLB4Q8ATI6@L71hR8R9^KVgmoOeMGEgUiNFe]KEiNGP02DE5A00=FEUIGEeMGEeL00V1PH00:BTY:
DU9BBTY:DE5AOgmoMgMgIfMWLg=cIVIVOWin4P820Rgoool02?OgmkFe]K^k^n3Ph?3`l>g]kLc<c>CT
i0;4a<@00nWYjOCdm?[jnP02nOWi00OemOGfm_Kfm_Kfm_Kbl_;jn_[inOT01>g]k@06gmoOg=cLgmoO
c<c<hn?SdM7A0o7al@;jn_X2o?cl01Gdm?C^k^kVi^K@d=3MgMg3`l?AdM7UiNGFe]K`l?3bl_;Bd]9Z
JV[6a/K<c<c0`<3Fe]KKfm_Vi^K^k^kVi^H00nSXj0;Rh^802^?Shn3Ph>o_knk^k/c<c=7AdMoOgmCD
e>_[jmCDe3Goool0027oool01?7alOOgmo7alO7al@[gmoL02c/k>b@T920P8861PK^k^k6a/EeMGCHf
=P410B0P869RHP02clo?00S7alOGemNk^k_?cloGemO?cloJf][GemL2clo?01Fk^k^YZJVg]kNYZJV;
Rh^8R8P820QmOGfWYjNXZ:Rf][K0`<3GemOPh>3Xj>SPh>39bLW0`<2][JfPX:2EUID00XR8R00MM7Ad
L71`Q8B4DE5AQ8B410@4:BTYEEEE8b<SHF5Q>c/kK6a/Lg=cH61PPH61UIFEVi^KWIfMQHF5WIfMY:BT
V9RHPh>3EEEEB4Q8EEEEY:BT[Jf]QhN701;gmoLOoooo00@:2PX20P820P8:2PX:0P8200]gMgO4a<@H
61Q3@d=:BTYOGemgMgL410AgMgMoOgmSHf<00S8b<P8a<C400dY:BS8b<S0`<002;2`/00<a<C4b<S82
0P800Tm?C`91@D409Fe]KGemOFe]KGemOD10@5ADE3lo?c`l?34a<@820R<S8c8b<S`l?3lo?dI6AW5a
LFe]KFMWIfe]K@820Sdm?@l?3clo?cdm?A0@47moOgMgMdA4A0410Fm_KeMGEfm_Kg5aLF5QHF1PH4Y:
BUADE002BTY:00QGEeMEEEEoOgmkNg]GEeMKFe]GEeNIVITB0P827oooo`04o?clooooo?clo?cl2_oo
o`0;fm_KQXJ6UiNGh>3PkNg]h>3PdM7AlO7ac/k>c<c<h>3P00;inOT02?Shn?[jn^g]kOWinO[jn_Wi
nOKfm_[jnP;inOT03>g]kNc/k??clnc/k>k^k^?Shl71`M7AdNo_kmkNg^OWio3`l0;jn_X06_clo?[j
n_3`l??clnKVi^_[jmgMgL?3`n?Shlg=cMGEeN_[jn7QhN_[jibLW<k>c/c<c=3@d<S8b=_KfmoOgnCT
i<G5aM_KfmgMgN;RhP?_knl02N?ShnSXj>g]kLc<c<30`<c<c>?ShnKVi[jn_P0eoooo000Qoooo00?a
lO7gmoOgmoL02_Ogm`07820P<30`820P61PH0000EEEE92@T008P8200300002`/;6ATI<;2`/30`<O7
am[Jf/30`8:2PX20P8:2P/[:bP;Ph>003][Jf/[:bX20P;^k^j2PX:f][J:RXZ2PX:RXZ:VYZKVi^L30
`<71`M[JfP?Ph>002/30`820P;:b/Z2PX96ATH20P8R8R820P1PH6861P@<000000`<30`820P000002
<30`00@J6QY8B4P00028R8P2PH610XV9R@08WIfMQHF5V9RH@T92B4Q80000@d=3Z:RX0X61PA;gmoLO
oooo3@820P0E0000Ti>C0`<3TI6AL71`OGemP820F5QH@T92HV9RPh>3:b/[<S8b0000<S8b;2`/<S8b
A4A40000820P;2`/008S8b<0120P830`<492@TY:BP94A4@025ADE4=3@f=SHdI6APH61S`l?30`<2`/
;08S8b<03C0`<0000492@T10@6ATI65QHE1@D4I6AT10@4A4A451@F1PH0820P02410@00L30`<H61P0
001GEeMPH616ATIUIFD00TA4A00<@410Cdm?BTY:@410EeMGH61PBTY:Lg=c0000CDe=4A4ARHV94P82
0Qooool00oclo?ooooooo`0:oooo00Vd];B1PH74a<AgMgL00030`<20P82RXZ;;bl/00/C4a00:h>3P
lO7ah>3Pn?Shm_KflO7a`<30k>c/jNWYl?3`0_[jnP0>m_Kfl?3`h>3PkNg]i>CTi^KVkNg]a/K6g]kN
h>3PlO7ah^;Rl?3`m_Kf0o[jnP03h>3Pk>c/hN7Q00;Ph>004L71`MOGel71`M7AdN3Ph<30`>GUiLc<
c=CDe<71`L30`>?Shn7QhLW9bLg=cM3@d>?Sh`02i^KV00cPh>3/k>c_kno_knoXj>S0`<34a<C0`<32
`/;8b<RIVIVRXZ8eoooo000Qoooo00?alO7gmoOgmoL02OOgm`0Gh>3P;Rh^<30`=cLg820P0000>CTi
:RXZ6a/K5ADE0000820PK6a/bLW9d];BemOGclo?f][Jclo?Vi^K/[:bP820f][J00;Ph>000m[Jf/[:
b/W9b@02/[:b00Fg]kNPX:2JVYZJVYZb/[800/30`00Gf][Jh>3Ph>3Pf][Ja<C4^k^k/[:bZJVYWIfM
UIFEVIVIVi^KVIVIR8R8ZJVYMGEeLg=cEEEE@d=34A4AHV9RPh>3NGUi00:3Ph<00iVIVIRHV:VYZ@04
WIfM00R3Ph=8B4Pa<C40000g=cNYZJV1PH67QhLBmoOg7oooo`032PX:0P820P8200X20P802J2PX9>C
Ti>CTdA4A=7AdEQHF5mOGf9RHU]KF`02Ogmo01Ho?cll?3``<30a<C4b<S8/;2`b<S90@41FEUHl?3`P
820S8b<P820/;2`b<S8l?3a<C4a1@D5GEeMVIVIcLg=0@402?clo00Tb<S8/;2`S8b</;2`b<S96ATI:
BTY<C4a:BTX00W5aL@03IFEUH61PKFe]009?Cdl036][JeMGEe5ADHR8R6=SHd51@GAdM5EEEE5ADFAT
I4E5ADm?C`A:BTX025EEEG]kNf=SHe5ADI>CTdm?Cjf][IVIVA820P8Ooooo00?lo?coooooool02Ooo
o`0:o?cl^k^k]KFe`l?3c<c<1PH6hn?Sbl_;i>CTcLg=0/c<c0;dm?@02OGemO[jn_WinOKfm_WinN;R
h^g]kN3Ph?Ogm`02n_[j00?gmoO`l?3dm?@00^g]k@08lo?ch^;Re=CDe=CDkNg]lo?clO7am_Kf0_[j
nP0Im_Kfj>SXkNg]kNg]k>c/kno_gMgMi^KVh^;Ri^KVhn?Sk>c/h>3Pi>CTc<c<i>CTd];Bh>3PkNg]
fMWIkNg]h>3Pi^KVj>SXk>c/00C_knl02>g]kMCDe=_KfjBTY<?3`nc/k:>SXkjn_SGoool0027oool<
moOg00JCTi<`<30a<C4k>c/`<30P8202<C4a00H<30`C4a<0000`<31NGUk9bLT2d];B00K?cloGemOJ
f][6a/Jg]kN2PX82V9RH0X^;R`03H61PGUiNGEeM009TI6@01U1@D7AdM7AdM9^KVkNg]l30`0;Jf]X2
emOG00g0`<2k^k^g]kNYZJVKVi^ATI6EUIFHV9RKVi^WYjN9RHVWYjNYZJT00YRHV00E0@41Ph>3NGUi
V9RHVi^KP820Y:BTWIfMY:BTYjNWZJVYYjNWWIfMGUiN>c/k>CTi20P8@d=3RXZ:M7AdQhN701;gmoLO
oooo30820P060000Ti>CHf=SMgMgTi>CPh>30V=SH`0>N7Qh0`<3MgMgTi>CEeMG?3`l>SXj<C4a<S8b
<C4a;2`/@410B4Q8IfMW0UMGE`04DE5AKfm_EeMGEeMG0WIfMP0@OgmoNWYjPh>30000@D51?clo<S8b
;2`/820P<C4a?3`lATI6BTY:@D51H61PIFEU0W5aL@0;@410E5ADIFEUCdm?E5ADAdM7EeMGEEEEM7Ad
E5ADEUIF009PH60016IVITY:BU]KFeADE09?Cdl02D10@5MGEgMgMeQHF8>3Ph20P6MWIjn_[iVIV@0B
0P82:oooo`06hn?S]KFefm_Kfm_K]KFeQ8B40]_Kf`0>^KVig]kNa<C4]KFejNWYm?CdmOGel?3`nOWi
n_[jm_Kfj^[Zlo?ca<C40^SXj0;^k^h00lC4a>WYjM7Ad@02g=cL00KDe=C=cLg=cLgRh^;clo?alO42
m_Kf0_[jnP0=i>CTkNg]lo?ck>c/h^;Ra<C4gMgMmoOgh^;Rkno_i>CTkno_k>c/00;Xj>P01<W9bNg]
kMWIfOOgm`;Rh^801N?Shno_kn?Shno_knc/k002kno_00SYjNWKfm_Shn>0P832`/;OgmnRXZ:n_[he
oooo000Qoooo3?Ogm`03Y:BT;2`/820P008P82002`0002`/;20P81/K6a<C4`@412`/;69RH/W9bLo?
clO7a`03emOG01;Jf][?cln6QXIbLW9gMgN=SHf0P800001RHV9eMGESHf=QHF51@D61PH6:RXZTY:Bk
^k_<c<`2f][J0/o?c`06`<30a<C4]kNg/[:bVi^KP8200XR8R00?Ti>CVi^KX:2PYjNWVi^KVIVIV9RH
R8R8VIVIVi^KY:BTX:2PQ8B4WIfMY:BT00BMWId02H^;RdY:BRXZ:RTY:A8B4VATI8Z:RVa/K861P@0;
moOg00?alO7gmoOgmoL01?Ogmaooool<0P8200X00023Ph=oOgmoOgmRHV9oOgn3Ph=oOgmRHV9CDe<2
Ph>300ASHf<l?3``<30b<S83<C4a01HP8212@T9FEUI4A4@d=3@J6QYNGUi_KfmSHf=YJFV1PH6KVi^1
PH5]KFe3@d=:BTY4A4@b<S8/;2`P820b<S8l?3`2ATI600=0@41PH61TI6@00Ve]K@06I6ATH61PC4a<
EeMGE5ADH61P0UIFEP06IfMWH61PFe]KIVIVBTY:EUIF1DY:BP09@410L71`GemO=3@dA4A4820PIfMW
XZ:RVYZJ00/20P800`X:2P820P820P040P82:oooo`03mOGea<C4c<c<00;<c<`2a<C400?<c<cTi>CN
g]h00/C4a004h>3Pm?CdnOWin?Sh0o[jnP06m_KfnOWih>3PinOWkno_jn_[0]kNgP;Ph>002<?3`lS8
b8R8R=_KfmoOgn?Shng]kN3Ph0;fm_H2nOWi00KTi>C^k^kclo?]kNgBd];Ph>02hn?S00oPh>3Rh^;T
i>C_knoRh^;Vi^KgmoOGemOVi^KRh^;Shn?[jn_Ph>3_knoShn<01>o_k`09k^k^cLg=bl_;c/k>X:2P
g=cLgmoO/K6a][Jf00_oool00oclo?ooooooo`0Woooo000Qoooo3?Ogm`03][Jf=cLg820P008K6a/0
2`00020P80@4120P81<C4a4A4D=3@eYJF[Ng]lW9bM;BdP02emOG0m[JfP0@alO7ZJVYYZJVYZJVSHf=
PX:2VYZJTi>CQhN7V9RHRXZ:Vi^K[Jf]a/K6clo?d];B0][JfP0?d];Bc<c<`<30`<30]kNg/[:bVi^K
0P82Fe]KHf=SOGemV9RHPh>3[Jf]YjNW00:][Jd2YjNW0YfMW@04YjNWQ8B4ZJVYYZJV0YfMW@0;YZJV
WIfMPh>3>c/k6a/K:RXZ4a<CTi>CR8R8K6a/QhN700WgmoL00o7alOOgmoOgm`06moOg7oooo`d20P80
3Y>CTkRh^:VYZB0P8;Rh^7moOiVIVGmoOf9RHV=SHe5ADDM7Ad51@CPh>0<a<C42;2`/00Xa<C4b<S9?
CdmFEUHB4Q9PH61FEUIADE50@41GEeL2IfMW00APH612@T8b<S8a<C42;2`/014X:2Q4A4A6ATHl?3`o
?cm0@41PH61WIfNBTY9oOgl@411FEUIPH61DE5AGEeMDE5AGEeL00UADE006@410BTY:E5ADEUIFBTY:
ATI60TY:BP0;EUIFE5AD@410MgMgHV9RGemOHV9RI6ATKFe]XZ:RVIVI00T20P800`X:2P820P820P06
0P82:oooo`03inOW`l?3UiNG00:ZZZX02hB4Q<c<c9bLW<c<c=kNg/30`>CTi?Cdm??cloCdm?3`l002
n_[j0oKfmP0@n?Shk>c/h>3Ph>3Pjn_[`<30i>CTh>3Pi>CTj>SXgmoOh^;Ri^KVj^[ZnOWil_;b0_Kf
mP03mOGeh^;Ri>CT00;clo<02^g]kM;Bd/?3`mKFe/?3`m7AdOOgmn;Rh^KVi^o_k`;Vi^H5kno_00?P
h>3/k>cPh>000^o_k`0;h>3Pkno_kNg]fm_Ki>CTbl_;a<C4h>3Phn?S/K6a_[jn00Woool00oclo?oo
ooooo`0Yoooo000Qoooo0_Ogm`;alO400oOgmo7alOOgm`05moOg00G1`L4820P0000P820K6a/01000
0005820P0000@d=3@T92RHV900;0`<02emOG00?Jf][0`<30`<002l30`006f][JalO7alO7clo?`<30
d];B0/o?c`04`/;2`<30`<30`<300X20P08000003410@51@D410@00000410H61PJ:RXZVYZJ6QXJNW
Yj6QXHB4Q0:9RHT02X61PHV9RH>3PhB4Q820P8>3Pd10@0P8200000@4108@410018R8R6ATI861P@00
017gmoLOoooo3@820P0?20P8MgMg>3PhHV9R0P82HV9RL71`6ATIFe]K0P82DE5A@d=3BTY:<30`<S8b
008a<C4012`/;20P82<S8b0P808R8R80120P80@4120P80410@@0000012`/;30`<38b<R`/;08P8202
<S8b0100000l?3`0000<30`?3`m0@41?CdmWIfL@411[Jf/30`=UIFE?Cdm4A4A7AdM?Cdl2A4A40TY:
BPA0@4002d92@Tm?CdY:BT10@0820V9RHUQHF410@0410@<30j2PX00220P84@820R7oool2o?cl00?o
ooolo?coool01Oooo`05lo?cU9BDc<c<Q8B4i>CT00;4a<@01iRHV8b<S<c<c<C4a>CTi>3Ph>c/k002
l?3`0_[jnP04m_Kfl_;bl_;bl_;b0oShn005l_;bl?3`n_[jh^;Rn_[j00;Rh^801?Kfm_Shn?Shn?Wi
n@;bl_82nOWi00CalO7Ph>3Ph>3clo<2h>3P00o0`<3<c<b0P82@T930`<32`/;<c<c8b<S]kNgTi>C/
k>c_kno/k>cShn?/k>`00^3Ph006k^k^h^;Rh>3Ph>3Pk^k^`<300/C4a007Q8B4PH61a<C4Vi^KX:2P
TY:Bh^;R03Coool0027oool=moOg00Di>CTk>c//;2`P820000000R0P800810@4820P20P8B4Q8GUiN
WIfM/[:b`<300]OGe`;Jf]X01n3Ph<30`>SXj>SXj>3Ph>SXj>3Ph004j>SX0n3Ph004f][Jh>3Pf][J
clo?0/c<c00Iclo?`<30bLW9a<C4`<30a/K6P820^[ZjZJVYRXZ:Hf=S@D51=cLg>c/k@d=3GEeMR8R8
Ti>CVi^KV9RHRh^;0000K6a/RXZ:ZJVY00:TY:@00h>3Pc0`<20P8002820P00H0001@D51dM7B8R8Qe
MGD0000AmoOg7oooo`d20P8018R8R7MgMh>3Pf9RHP=oOgl029VIVF9RHX>3Pg]kNeMGEdY:BTA4A3Xj
>P8a<C4012`/;20P82`/;2<S8`8F5QH00`820QHF5R<S8`035QHF0b<S8`0=820P8b<S;2`/;2`/<S8b
A4A4<S8b?3`lATI6?3`l1PH6@T92?clo008k>c/054M7AgUiNGMgMi:BTY>CTa8B4WMgMe5ADEIFEV1P
H5MGEe5ADFe]KFm_KfMWIdm?Ce]KFeIFEU]KFa4A4@=oOgl01UQHF820P8>3Pfe]KF][JdE5AA420P8/
oooo00Fm_KgKfm_4a<C<c<c4a<@00/c<c008W9bLc<c<a<C4e=CDjNWYkno_kNg]i>CT0_[jnP;fm_H0
1o[jn_;bl_clo?clo?[jn_clo?Shn004o?cl0o[jnP04m_Kfn_[jm_KfnOWi0^;RhP0FnOWii>CTm?Cd
k^k^lo?cj^[Zhn?Skno_k>c/gmoO`l?3`<30`l?3fm_K`/;2dM7Ai^KVh>3Ph^;Rj>SXk^k^fm_K0]oO
g`05k>c/hn?Sh>3PkNg]]KFe00?<c<`01Z:RX[bl_<g=cN?Shn3Ph>7QhCCoool0027oool=moOg00E3
@d=:BTXa<C4P820000000R0P80084a<C30`<820P@d=3GUiNV9RHZJVY`<300]OGe`;Jf]X3h>3P0nSX
j00<h>3Pj>SXh>3Ph>3Pj>SXh>3Pj>SXh>3Pf][JemOGd];Bclo?0]OGe`0>bLW9`<30bLW9bLW9a/K6
bLW9a/K6`<30^[Zj/[:bYZJV0`<3GEeMB4Q80S/k>`0FEEEEK6a/Hf=SGEeMK6a/I6ATQXJ6YZJVZJVY
Y:BTVIVIMGEe;2`/4a<C820P92@T2PX:92@TBd];@410=cLg10@44OOgmaooool=0P8200EADE5`L71S
Hf=oOgmRHV800WmoO`04MgMgN7QhMgMgDE5A0UMGE`0630`<>SXj<C4a<C4a;2`/820P0b<S8`8F5QH0
12<S8aHF5QHF5R<S8`8F5QH022<S8aHF5R0P834a<B`/;34a<C8b<S4a<@8l?3`014I6AS`l?00003`l
?092@T807clo?`P825IFEUEEEEMGEgMgMg=cLgMgMgmoOgMgMdA4A7MgMfm_Kf][Jfm_KeIFETm?Ce]K
FdY:BV1PH0<30gMgMgmoOeQHF5mOGh20P<g=cLS8b9>CTdE5A@00000@0P82;?ooo`05i>CTcLg=fm_K
c<c<a<C400;<c<`02=kNg[Vi^LS8b>CTi>WYjNSXj>c/k?Cdm0;jn_X2m_Kf0o[jnP?lo?`03?Shn?cl
o?[jn_[jn_clo?Shn?clo?[jn_Kfm_[jn_;bl_Win@;jn_X03_Cdm>CTi?Cdm?Cdm>[Zj_Cdm>[Zj_?c
lno_kng]kN3Ph>CTi=7AdMCDe0;Kfm/05/30`=oOgoCdm=7AdMoOgl30`>KVi^3Ph>c/k>?Shn;Rh^3P
h<C4a=kNg/c<c;Jf]XZ:RXJ6QVi^KXF5QL?3`n7QhCCoool0027oool=moOg0TQ8B003>c/k;2`/820P
008P82003Q/K6`@412`/;4=3@eYJFX^;RjNWYi:BT]OGem[Jf]OGen3Ph=[Jf/30`0?Ph>06j>SX0n3P
h0;Jf]X01<[:b/o?clo?clo?c`;9bLT01lK6a/W9bLK6a/W9bL30`;^k^l30`002]kNg00N9RHV:RXYc
Lg=SHf=8B4Q0@41CDe<00UEEE@04Hf=S20P8WIfMYZJV0YfMW@0<Ti>CGEeM820P820P6a/K820P4a<C
51@D:b/[=cLg>CTiFUYJ4OOgmaooool=0P820W]kN`03MgMg0`<3Ph>3009oOgl03V9RHX61PH>3Pe5A
DDM7Ae5ADD10@3Xj>S4a<B`/;34a<B0P82<S8b`/;08S8b<00`820QHF5QHF5P035QHF0b<S8`03820P
;2`/;2`/00<b<S801C`l?4=3@c`l?492@P000002?3`l00Po?cm:BTX10@51@D5?Cdm:BTYWIfMADE42
Ng]k00N8R8P820QoOgmiNGUdM7AWIfM2@T800TY:BP0<H61PI6ATMgMgOgmoHV9ROgmoHV9RMgMgk>c/
Ti>CF5QHAdM74@820Rcoool2e=CD00?Kfm_4a<C4a<@00/c<c00:i>CTW9bLa<C4i>CTm?Cdk^k^kno_
iNGUn_[jm_Kf0_[jnP03m_Kfl_;bn_[j00;jn_X6o?cl0o[jnP;fm_H03?3`l?WinOWinOWinOCdm?3`
l>[Zj_Cdm>[Zj_Cdm?3`l>g]k@?clo<01nc/k=oOgnCTi<?3`mCDe=3@d=;BdP02c<c<00C3`l?IfMW_
knoPh>02kno_00cPh>3AdM7<c<c<c<cTi>C<c<c4a<@0000n?Sk3`l?Shn?dm?@doooo000Qoooo3?Og
m`06e=CDCdm?B4Q8Cdm?<C4a20P80b0P8007:RXZ:2PX@d=3GUiNPh>3W9bLQ8B400?GemL2f][J00?0
`<3Ph>3Ph>000^SXj003h>3Pj>SXj>SX00;Xj>P01N3Ph>SXj>3Ph=[Jf^3Ph003emOG00?=cLg9bLW9
bLT00/C4a0;9bLT04/30`<71`L30`;Rh^;Ng]j6QXJVYZIfMWI^KVh^;R`410Fa/K7EeMGUiNI>CTifM
WJBTY9^KV`:MWId00h^;Rc/k>b`/;002820P00</;2`K6a/C4a<00b`/;0030000moOgmoOg00ogmoLO
oooo30820P060000FUYJNg]kFUYJHV9RPh>30gmoO`07GemOF5QHDE5AEeMGEEEE0000ATI600<a<C42
;2`/0b<S8`035QHF8b<S5QHF00@F5QH012<S8aHF5R0P82<S8`<a<C401P410C`l?3`l?3`l?4I6AP@4
108l?3`00d92@Ta<C0l?3`02@D510Tm?C`03@410DE5AKFe]009[Jf/01GAdM6ATI4Y:BTY:BT10@002
BTY:00=PH61ADE430`<00WmoO`03Ph>3HV9RHV9R00>3Ph<00dE5A@820P820P0?0P82:oooo`06lo?c
g=cLe=CDg=cLfm_Ka<C40lc<c007bl_;`l?3i>CTjNWYkNg]l_;bh^;R00?jn_X2m_Kf00?bl_;jn_[j
n_X00_clo003n?Sho?clo?cl00;lo?`01?Shn?clo?[jn_KfmPCjn_X00o3`l?Cdm?Cdm002k^k^0_Cd
m00Bh>3Pi>CTlo?chn?Slo?ch>3Pk>c/kno_h^;Rk^k^`<30gmoOh>3PfMWIh>3Pkno_hn?Sd];B0^o_
k`03h^;Rfm_Ka<C400;<c<`00lC4a>CTi=kNgP03a<C400?QhN7oooooool0<_ooo`008Oooo`cgmoL0
1H61PDQ8B4Q8B0P8234a<@06820P00<k>c/:2PYBDU800X20P004`/;2emOGemOGf][J0/30`003h>3P
j>SXh>3P00;Ph>04j>SX0n3Ph005`<30emOG`/;2alO7`/;200G0`<02a<C400g0`<20P82k^k^0P82f
][Jb/[:QXJ6YZJVVYZJRXZ:0P829RHV1PH400hB4Q007Y:BTP820X:2PVIVI0000820P;2`/00800000
21/K6`P8214A4@00020P800000X:2[2`/13gmoLOoooo30820P060000Ng]kBTY:Lg=cHf=S0`<30Wmo
O`09>3Ph0`<30`<3MgMgL71`EeMGA4A410@4<S8b008a<C42820P0R<S8`035QHF0P820P8200DF5QH2
8b<S00@P820a<C4`<30P8202<30`10@410040000ATI6?3`l@T920PX:2P06@410@D51C4a<@D51@410
A4A40d10@09:BTX0151@D492@T10@492@P90@4000eADE8>3Pf9RHP02HV9R00L30`=2@T9gMgMoOgl3
0`=GEeL0000040820R_oool01_7alMCDe<C4a=3@d=_Kfl30`0;<c<`02HB4Q<S8b<C4a=_KflW9bN3P
h>SXj>CTi?7al@02n_[j00Kfm_Kbl_;bl_;jn_[lo?cjn_X2n?Sh1?clo009n?Shn_[jn_[jl_;bn_[j
l?3`n?ShlO7am?Cd00?Ti>@02n3Ph>SXj>k^k^3Ph>7QhNg]kN7QhN?Shn7QhN3Ph>c/k003h>3P00_0
`<38b<SShn?Shn?Ph>3Shn?2`/;Shn?Rh^;0`<24Q8@00lC4a003i>CT`<30a<C400;<c<`00lC4a<?3
`o3`l00coooo000Qoooo2_Ogm`09lO7amoOgHf=S>c/kBd];Cdm?@d=3<C4a;2`/00@P82001b`/;3/k
>dQ8B69RHX20P<W9bM;BdP03f][J00?0`<3Ph>3Ph>000^3Ph0GXj>P3h>3P00CGemO?cloGemO?cll3
bLW900?4a<C9bLW9bLT00/C4a008PH61^k^k`<30`<30^;Rh/k>c/[:b]kNg0[:b/P0GZJVYYZJVY:BT
YZJVZJVYX:2PWIfMY:BTWIfMRh^;@410<C4a820P6a/K5ADE<C4a10@45ADE6a/K820P30`<:RXZUIFE
013gmoLOoooo2P820P092PX:0P820000MgMgBTY:FUYJ@D51R8R8Ph>300AoOgl01h>3PgMgMg]kNd51
@Clo?c`l?3Xj>P03;2`/12<S8`HF5QH28b<S00DQ8B4b<S8a<C4a<C4b<S800S`l?096ATH013`l?0@4
14I6ATa<C09:BTX01clo?dm?CdY:BT51@Da<C410@4a<C002Cdm?00EBDU9FEUI?Cdm?CdmFEUH00TY:
BP0>DE5AJf][Ng]kHf=SHV9RFe]KHf=SN7QhFe]KHV9ROgmoN7QhGemO9RHV40820RWoool02Oclo?oo
ooCdm=_KfnOWimcLg>CTi9VIVLC4a004c<c<00O4a<CKfm_De=CPh>3Rh^;dm?CemOD00oKfmP03l_;b
n_[jn_[j00;jn_X5o?cl00Ohn?Sjn_[jn_[jn_[inOWjn_[inOT00oCdm003k^k^m?Cdm?Cd00;^k^h0
2>CTi>g]kO?clo?cln?Shn7QhNg]kO?cl`;]kNd05nc/k>3Ph>?Shn3Ph>c/k>3Ph>o_kn?Shno_knk^
k/30`=_Kflc<c>CTi<g=cM_KfhV9RLg=cNCTi<c<c;Vi^L_;boknoP0coooo000Qoooo3?Ogm`09AdM7
>c/k@d=3Bd];@d=3<C4a;2`/820P4a<C00<P82001c/k>dQ8B4Y:BR<S8lW9bLo?cmOGe`02f][J00?0
`<3Ph>3Xj>P00^SXj004h>3Pj>SXj>SXj>SX1>3Ph003f][JemOGemOG00;9bLT00lC4a<W9bLC4a002
a<C400C9bLW4a<B0P830`<02^k^k0k:b/P03]kNg[Jf]ZJVY00BYZJT4WIfM00VKVi^3Ph<H61PP820C
4a<E5ADZ:RX<30`410@00Q<C4`0510@44a<C:2PXQ8B4oooo00ogmoLOoooo3@820P0BMgMgDE5ABTY:
@D51F5QHPh>3OgmoMgMgOgmoPh>3OgmoMgMgNg]kL71`E5AD?3`l<S8b<C4a0R`/;08S8b<35QHF00DS
8b<F5QHF5QHS8b<F5QH00R<S8`07820P<C4a<C4a<C4a?3`l10@4?3`l00=6ATH020@414I6ATY:BTI6
ASlo?dY:BTa<C451@@9<C4`01451@Dm?Cdm?CeMGE`9?Cdl4BTY:00mPH61EEEE7AdMHF5QgMgMKFe]O
GemhN7QKFe]`L71gMgNIVIUgMgN3Ph<e=CD040820R_oool04mcLg=_KfnCTi>OWinCTi<?3`lC4a<c<
c=kNg/c<c<C4a<c<c=_KfmCDe<g=cNGUiOCdm?WinO[jnP02m_Kf00?bl_;jn_[lo?`00_clo006n?Sh
o?clo?clo?cln_[jn?Sh0_[jnP03m_Kfn_[jn_[j00;dm?@00nk^k_Cdm>k^kP02k^k^00Cdm?C^k^k/
k>cclo<3kNg]00KQhN7]kNgclo?Vi^K/k>cTi>@3k>c/1>o_k`09h^;RkNg]h>3Pc<c<g]kNcLg=bl_;
^KViRHV900;Ng]h019bLW=kNg/30`>_[jc?oool0027oool7moOg00?alO7gmoOgmoL00_Ogm`93@d<2
Bd];00M8B4P10@4/;2`P820/;2`C4a<P82000R`/;006Cdm?GUiN410@/[:bd];BemOG0][JfP03`<30
h>3Ph>3P00KXj>P5h>3P00GJf][8b<S?clo?clo6a/H01LC4a006^k^kP820^k^k/[:b^KVi]kNg1;:b
/P:YZJT04:NWYjVYZJVYZJNWYj2PX:BTY9^KVh^;RgEeM@P8220P81/K6b`/;1/K6aDE5A4A4@<C4a<0
0a/K6b0P86a/K00@moOg7oooo``20P802`00055ADDY:BTY:BU5ADEQHF8>3PgmoOh>3Pc0`<7moO`02
Ph>300IJFUYGEeMGEeM<C4`j>SXa<C42;2`/0b<S8`DF5QH00b<S8aHF5R<S8`028b<S0R`/;003A4A4
<S8b0P8200E6ATH01DY:BSlo?dY:BTY:BTa<C002@D510da<C0=?Cdl03DA4A4m?CeADE5]KFdm?Cd10
@55ADF][Jg]kNh>3Pf9RHX>3Pf9RHP02Fe]K0gMgM`03HV9ROgmo=cLg01020P8Voooo00?lo?cooooo
ool00_ooo`;Ti>@2inOW00ODe=CPh>34a<C<c<c4a<CNg]j4Q8@00/C4a006g=cLjNWYb<S8kNg]mOGe
n_[j0_KfmP03l_;bn_[jn_[j00Klo?`00o[jn_Shn?[jnP02n_[j00Gfm_KRh^;inOWinOWZj^X01Nk^
kP07kNg]hN7QkNg]kNg]lO7alo?chN7Q00?]kNd2k>c/013_kno/k>c/k>c_knoPh>3Shn?Rh^;^k^kP
h>34a<C<c<cTi>C4a<CTi>C=cLg<c<`3g]kN00?Ti>C8b<Sdm?@0<oooo`008Oooo`OgmoL04?7alOOg
moOgmoOgmo7alE9BDTQ8B4];Bd=3@d];B`410C4a<B0P82`/;1<C4b0P808a<C402D];BeYJFPX:2[:b
//W9bM;Bd]OGem[Jf/30`002h>3P1^SXj0CPh>02f][J00?7alO?clo9bLT01LC4a003^KVi`<30PH61
00:k^k/5/[:b012][Jfb/[:YZJV][JfYZJVTY:BMWIf4Q8BKVi^HV9R6QXIRHV8X:2PK6a/a<C4/;2`2
30`<0P@4100530`<5ADE6a/K820PMgMg013gmoLOoooo2`820P062PX:0P82Ng]kBTY:DE5A@4100V=S
H`04OgmoPh>3MgMgOgmo0V=SH`09BTY:AdM7IfMWC4a<?3`l>SXj820P8b<S;2`/008S8b<55QHF00LS
8b<F5QHS8b<S8b<P820/;2`a<C400S8b<P0310@4ATI6ATI600=6ATH01Clo?da<C4Y:BTY:BTQ8B004
C4a<00I4A4A<C4aGEeM?Cdm7AdMKFe/2BTY:00QKFe]0@41NGUiSHf=gMgN3Ph=RHV:3Ph<2N7Qh00MK
Fe/H61QhN7QKFe]RHV9oOglP820040820RKoool04?clo?ooooooooooooclo?Cdm=CDe>OWinCTi>OW
il30`=_Kflc<c<C4a=kNg/c<c0;Kfm/02NOWioCdm<W9bNg]kOCdm?GemO[jn_Kfm_;blP02n_[j1_cl
o004n_[jn?Shn_[jn_[j0_KfmP03n?ShnOWim?Cd00G^k^h00o7alO?clnCTi007kNg]013Vi^K]kNgT
i>CVi^K/k>cShn?_knoShn?Rh^;Xj>SVi^KPh>30`<3Ti>CKfm_4a<@2^KVi00N9RHVLW9bi^KW=cLgT
i>C8b<S_knl0<oooo`008Oooo`cgmoL00d10@0/;2dQ8B002@d=300<92@T10@4P82000R`/;00;0000
;2`/820P20P8@4100000QHF5P820bLW9emOGd];B00?0`<03h>3P0^SXj0CPh>001<30`=[Jf/[:b/C4
a0;0`<002LC4a<30`;^k^h20P<30`820P861PH20P;:b/P02/;2`00Bb/[:PX:2YZJVPX:02ZJVY00bQ
XJ6TY:B9RHV4Q8BTY:B0P82ATI430`=PH618B4P0000A4A424a<C00TE5AD0000410@0000<30`A4A4K
6a/0003Ph>004?Ogmaooool=0P8200I2@T9kNg]0@410@418B4Q@D502Ph>300X30`>3Ph>3Ph=SHf=c
Lg=0@415ADE@D50:2PXl?3`2820P00L/;2`P820P82020P8F5QH20P8F5QH00P820P035QHF8b<S8b<S
008P82001@00034a<@820P0000H61P02BTY:00M2@T90@418B4Q0@40D51A8B4Q4A4@00Ta<C00@A4A4
Cdm?A4A4Cdm?A4A4AdM7@410BTY:Fe]KBTY:H61P@4105aLGL71`D51@0`<30V9RHP09Fe]KL71`N7Qh
410@N7QhDe=CHV9R0`<3000001020P8[oooo00?4a<C3`l?De=@00^CTi003hn?Sh>3PQ8B400C4a<@0
2<S8b=3@d<c<c<C4a<g=cN7QhOCdm?[jnPCbl_83n?Sh0_clo0?hn?P05O[jn_;bl_Kfm_3`l>;Rh^CT
i>3Ph>k^k^;Rh^g]kNc/k>CTi>c/k>CTi>7QhNg]kN7QhN?Shng]kNCTi>c/k002i>CT00C/k>cTi>CP
h>3Ph>02hn?S0^3Ph0;Ti>@00lC4a<30`=[JfP02a<C400W=cLfHV9RHV9RLW9bi^KW<c<cTi>C0`<3l
o?`0<oooo`008Oooo`cgmoL05410@4=3@d=3@d];BdY:BT10@34a<CTi>B`/;20P82`/;34a<C/k>d=3
@dm?C`0009>CTjf][LC4a<o?c`?Jf]X2h>3P00?Xj>SPh>3Xj>P00nSXj0?Ph>000m[Jf]OGelW9b@02
bLW900[4a<C0`<2k^k_0`<2k^k_4a<Bk^k^c/k>f][J][Jd2/[:b01:PX:2][JfVYZJYZJVTY:BPX:2T
Y:BWYjNTY:BMWIf9RHV3Ph=cLg=MGEdk>c/P820E5ADP82025ADE00<<30`410@<30`00a<C4`0330`<
moOgmoOg00ogmoLOoooo30820P0D0000DE5ADE5ABTY:@410ADE5Hf=SF5QHPh>30`<3Ph>3Hf=SMgMg
DE5A@T92KFe]I6ATEeMGATI6820P0b`/;0048b<S0P828b<S8b<S0aHF5P<S8b<00b0P834a<C8b<P02
?3`l00H410@o?cm:BTY:BTXo?cm2@T82BTY:00Q1@D5DE5A4A4A<C4aGEeM<C4aGEeM6ATH2Fe]K00=?
Cdm@D51KFe/00TY:BP07DE5AEEEEMgMgMgMgPh>3Ogmo61PH009KFe/2N7Qh00EHF5QgMgMgMgMgMgN3
Ph<04@820R_oool02lc<c>CTi>CTi>OWilg=cN7QhM_Kfn?ShlC4a<c<c<C4a002fm_K00OTi>CLg=c0
`<3Ph>3Vi^K^k^kinOT00oKfmP;jn_X00oclo?[jn_clo003o?cl0o[jnP03m_Kfn_[jl?3`00;dm?@0
2^k^k_?clng]kO?clng]kNk^k^g]kN7QhNOWinKViP;]kNd04^CTi>KVi^3Ph>c/k>?Shn3Ph>?Shno_
kn?Shno_knk^k^g]kNCTi=7AdM_KflC4a<g=cLS8b0;=cLd00kVi^HV9RKVi^@03g]kN00?4a<Cooooo
ool0<_ooo`008Oooo`[gmoL01_7alOOgmd10@4=3@c/k>d=3@`9;Bd/2@d=30b0P800A<C4a>c/k>CTi
B4Q80000Ti>CZJVY`<30clo?emOGd];Bf][Jh>3Pj>SXh>3Pj>SXh>3P00?Xj>P01^3Ph=[Jf^3Ph=[J
f/o?cl30`0G4a<@01L30`;^k^kVi^K^k^k:b/P02]kNg0[:b/P03Y:BTYZJVZJVY00:YZJT00j2PX:BT
Y:BTY002WIfM00J0P81eMGEeMGE8B4Pk>c//;2`26a/K00L/;2`K6a/P820A4A4C4a<E5ADK6a/00R0P
8003oooomoOgmoOg00kgmoLOoooo2P820P062PX:0P820000DE5AMgMgDE5A0TY:BP9ADE403GmoOf=S
Hh>3Pf=SHgMgMeQHF6][Jfe]KFATI4m?Cclo?c0`<34a<@02;2`/00DS8b<20P8F5QHF5QHS8b<00QHF
5P8S8b<01B`/;20P838b<TA4A3Xj>P05ATI600To?cm:BTY:BTY:BTYDE5A1@D50@41<C4aGEeL00UIF
EP9?Cdl00eIFETm?Ce]KF`02BTY:00EGEeMNGUi[Jf]kNg]gMgL00X>3P`0:HV9RPh>3HV9ROgmoHV9R
De=CFe]KHV9ROgmoPh>34@820RWoool01_clo?ooonCTi>CTi=_KfnCTi0;WinL2i>CT0/c<c00B`<30
fm_Kfm_Khn?Se=CDfm_Kh>3Pk>c/lo?cnOWin_[jl_;bm_Kfn_[jo?cln_[jo?cln_[j0oclo006n_[j
m_Kfn_[jm_KfnOWih>3P1Nk^kP05lo?ckNg]lO7akNg]iNGU00;clo<2kNg]0^3Ph0?/k>`00n3Ph>?S
hn?Sh`02kno_0n3Ph003e=CDfm_Ka<C400;Ti>@02LC4a>CTi<c<c<C4a=kNg/g=cNCTi<c<c<30`00d
oooo000Qoooo1oOgm`03lO7amoOgmoOg00;gmoL02DQ8B4];Bc0`<4=3@dm?Cd10@4];Bd=3@c0`<002
820P00//;2`a<C5:BTYJFUYeMGF1PH6IVIVb/[;9bLW?cloGemL00][JfP03h>3Pj>SXh>3P00CPh>00
2<30`=[Jf][Jf][Jf/o?clW9bLg=cLC4a0Bk^k/00kRh^;^k^k^k^`02^;Rh00Ff][Jg]kNb/[:TY:BZ
ZZX00ZVYZ@0CWIfMY:BTY:BTY:BTVi^KV9RHPh>3I6ATFUYJB4Q8<30`92@T820P:RXZ;2`/5ADE30`<
6a/K5ADE008<30`00a/K6bPX:?Ogm`0@moOg7oooo``20P8050X:2TY:BY>CTe5ADDY:BTE5ADY:BU5A
DI>CT`<30f=SHh>3Pf=SHg1`L4=3@f][Jfe]KFEUIDa<C30`<08a<C42;2`/00<20P8S8b<F5QH012<S
8`</;2`01C8b<S`l?3`l?4=3@d92@P07BTY:0Tm?C`0I@410C4a<EUIFEeMGGEeMCdm?BTY:Fe]KEUIF
Fe]KH61PEeMGDE5AEEEEATI6Ng]kTi>CPh>3F5QHGemOPh>3Fe]KN7QhHV9R@T92009hN7P00f9RHUQH
F0820P0@0P829_ooo`03o?cloooooooo00;oool05]cLg>OWikFe]NCTi=cLg>7QhNOWinCTi;Fe]Lc<
c<30`<C4a=_Kflg=cOCdm>3Ph=_KfnKVi^g]kOCdm?WinO[jnP;fm_H00o[jn_clo?Shn004n_[j00Sb
l_;fm_Kfm_Kfm_KinOWdm?C`l?3^k^h4kNg]00[Shn?]kNg]kNgQhN7Shn?WinOclo?]kNgPh>3Jf]X2
k>c/01?_knoPh>3Shn?Shn?Rh^;Xj>S/k>cLg=cdm?CDe=Be]KF4Q8C<c<c;bl_4a<C=cLfi^KWTi>C=
cLd00[Vi^@03i>CTh>3Poooo03?oool0027oool;moOg01OalO5BDU8i>CTi>CU8B4Q;Bd]0@41;Bd/k
>c]3@d<P820a<C4i>CTa<C4k>c]JFUY4A4AeMGF:RXZ][Jg9bLW?clo:b/X00][JfPOPh>001=[Jf]OG
elo?cmOGe`;9bLT3a<C400Bi^KVk^k^k^k^i^KT3^k^k00Ff][Jb/[:b/[:b/[:PX:000ZVYZ@04YZJV
Y:BTQ8B4Y:BT0YfMW@0:Rh^;0@41FUYJBTY:>CTi;2`/2PX:6a/K4a<C820P0QDE5@0630`<000010@4
30`<820P@T924OOgmaooool;0P8200X:2PX20P9HF5QHF5QkNg]0@415ADE:BTYgMgMADE42Hf=S00YH
F5QSHf=gMgL71`MoOgm[Jf]WIfMGEeL`<30b<S83;2`/1R<S8`8/;2`01C4a<C0`<3`l?3`l?38b<P02
ATI600=>CTi:BTY:BTX01DY:BP0:E5ADC4a<C4a<C4a<EeMGCdm?ATI6Fe]KBTY:Fe]K0TY:BP07DE5A
EEEEJf][@410F5QHPh>3GemO009RHV802GmoOe]KFe]KFgQhN5QHF9VIVGQhN7moOg1`L00A0P82:_oo
o`0=o?clm?Cdhn?Shn?Se=CDinOWh>3PinOWfm_Ki>CTc<c<fm_Khn?S00;Kfm/02?Cdm<C4a>3Ph=oO
gnKVi_Cdm?WinO3`l0;fm_H7n_[j00Kfm_Kjn_[inOWjn_[dm?C`l?03k^k^00CalO7]kNg]kNgalO43
kNg]00GWinO]kNg]kNg]kNgTi>@00^c/k004h>3Phn?Shn?Shn?S0^o_k`0:k^k^h>3Pm?CdcLg=hn?S
a<C4`<30i>CTg]kNc<c<0/g=c@06^KVic<c<W9bL^KVic<c<cLg==?ooo`008Oooo`OgmoL03?7alOOg
moOgmo7alOOgmfMWId=3@cTi>@P820410D92@T];B`810@4220P800/i>CT10@410@4820Q:BTY4A4B1
PH60P829RHW9bLW7alL00];BdP08f][J`<30`<30`<30d];Bf][J`<30`/;20];BdP09c<c<bLW9`<30
a<C4/[:b^KVi/;2`^;Rh^k^k00:b/[802kRh^;2`/;Jf][:b/[2`/:BTY:2PX:6QXJ2PX:6QXJBTY002
P820012;Rh^3Ph<410A8B4P820P30`<X:2PP8200000K6a/0000A4A4E5AD410@0000410@2000000<8
20QTI6CgmoL04?Ogmaooool<0P8200@0001@D51HF5QcLg<2@41000I:BTY@D51@D5020P9RHV9@D502
@D5100Q2@T90@41_Kfm5ADE0@400000`<30a<C43820P01</;2`Q8B4P820P820Q8B4`<30/;2`P8200
000`<30h>3P410A6ATI0@414A4A>CTi?Cdm:BTY0@4000TY:BP9DE5@014A4A5IFET=3@e=CD`94A4@0
2e1@D4Y:BT10@410@4A4A4Y:BVMWIg1`L55AD@<30gmoO`03HV9R00I2@T9KFe]HF5QHF5PH61Q`L702
0`<34P820RKoool03?clo?ooooooooclo?ooonk^k/C4a>?Shm3@d>3Ph>CTi>OWi`;Ph>000lC4a<30
`<?3``02`<3000S@d=34a<C<c<c9bLWPh>3Ti>C`l?3hn?P2l_;b00?fm_Kbl_;bl_800_;blP03m_Kf
n_[jl?3`00;bl_802N3Ph?3`l>CTi>k^k^GUiN7QhN?Shn7QhNg]k@02iNGU00_QhN7Ph>3WinOUiNGQ
hN7Ph>32`/;/k>cPh>3/k>cShn<00n;RhP;Ph>001l71`M3@d<30`<30`<c<c<C4a>CTi002a<C400?=
cLf9RHV8R8P00YRHV0;4a<@00oCdm?ooooooo`0boooo000Qoooo3?Ogm`0FMgMgGEeM>CTi>c/k@d=3
2@T9GEeM<C4a@d=3>CTi20P8820P>CTiBd];<C4a@410B4Q8K6a/PH61ZJVY^k^k`L710]OGe`03clo?
f][JemOG00?Jf]X02]OGel;2`/o?clc<c<W9bLg=cHV9RKVi^KJf][^k^`>i^KT01;:b/[Jf][:b/[2`
/0>][Jd01:RXZ:VYZJVYZJJVYP:WYjL2Ti>C00N:RXYeMGEMGEe1@D4`<30/;2`P82000Q<C4`@K6a/0
1QDE5@P820@411/K6cTi>DQ8B1;gmoLOoooo30820P0?0000?cloF5QHMgMgD51@FUYJ?cloHf=SDE5A
20P8Ph>3OgmoF5QHBTY:@D51009kNg/016m_Kfe]KDY:BS`l?0<a<C400b0P834a<C4a<@02;2`/00La
<C4j>SXb<S8b<S8410A3@d<l?3`00Ti>CP03@410CTi>CTi>009>CTh014A4A4a<C5mOGda<C09GEeL0
16=SHdm?CeMGEdm?C`9DE5@02F1PH6ATI6ATI6][JgMgMgmoOe5ADH>3PgmoO`02MgMg169RHP06Fe]K
HV9R61PHHV9RF5QHNg]k4P820R_oool05^o_kng]kN?Shm_KfnCTi<30`>g]kM_KfnCTi>?Shh20P<c<
c>?ShnOWim_KflC4a=CDe=oOgm_Kfnc/k>g]kO3`l0;jn_X00oWinOKfm_[jnP03m_Kf00Gjn_[alO7i
nOWRh^;dm?@00_3`l003lO7ainOWkNg]00?alO401>g]kNOWing]kN3Ph0?Vi^H01=kNg^CTi>c/k>3P
h0;_knl2h>3P00WOgmoPh>3AdM74a<Be]KG4a<C<c<cNg]k4a<@01>CTi006cLg=X:2PW9bLi>CThn?S
e=CD=Oooo`008Oooo`OgmoL00o7alOOgmoOgm`02moOg00^FUYI_Kfm3@d=3@d=;Bd]3@d=?Cdm3@d<k
>c/i>CTP82000S4a<@93@d<020T92D];BeiNGWEeMI^KVjNWYh^;RlW9b@;?cll5emOG0/o?c`0@cLg=
emOGbLW9a<C4Q8B4^k^k^KVi][Jf[Jf]/[:b[Jf]/[:b/K6a][JfXJ6QZ:RX0Zf][@03ZZZZZJVYY:BT
00:WYjL029^KViRHV8J6QX>3PgEeMEEEE@P822`/;08P820031<C4a4A4A<C4b0P81/K6aDE5@`<3000
00`<334a<B`/;6=SHa;gmoLOoooo30820P0;0000>3PhDE5ADE5A@410BTY:FUYJDE5AMgMgF5QHOgmo
009SHf<0355ADE1@D5YJFTY:BUMGEf][Jd10@4Y:BS8b<S`l?38b<S0`<0@a<C43<S8b0213@d<`<316
ATI6ATIDE5A:BTY4A4AGEeMDE5A<C4aGEeM<C4aDE5AOGemGEeMSHf=GEeMMGEeGEeM?CdmKFe]DE5AP
H61:BTYGEeMDE5A[Jf]oOgmkNg]gMgL30`=oOgl2MgMg00YKFe]gMgMRHV9KFe]hN7RIVIUHF5QSHf>3
Ph=4A4@B0P829_ooo`03o?cloooooooo00;oool2k^k^0^CTi007inOWi>CTg=cLi>CTfm_Khn?S`<30
00;Kfm/2i>CT00S0`<3WinOYjNWPh>3Rh^;_knoYjNWdm?@2nOWi1O[jnP;inOT04?3`l?[jn_Cdm>k^
k^KVi^g]kO7alNOWinKVi^GUiNKVi^g]kN3Ph>OWin3Ph=kNgP;Vi^H00m[Jf^CTi>?Sh`02kno_00SR
h^;Xj>SVi^K]kNgPh>3<c<c@d=34a<@2c<c<00cNg]k<c<cNg]k<c<cTi>C=cLfi^KV<S8bi^KWKfm_4
a<Cdm?@eoooo000Qoooo3?Ogm`0?a<C4LW9bCdm?>c/kBd];@d=3Cdm?GEeM<C4aBd];<C4a;2`/<C4a
>CTiBd];0093@d<01EYJFUeMGH^;Rjf][H20P003bLW90]OGe`04clo?emOGc<c<clo?0lW9b@;6a/H0
2K^k^kJf][6a/KJf][6a/JRXZ;6a/JRXZ;Vi^@02[Jf]00FWYjNPX:2TY:BVYZJYZJT00ZBTY00;WIfM
V9RHR8R8Ph>3K6a/GEeMB4Q80000;2`/820P4a<C008<30`24a<C0P@41080000011<C4c4a<CTi>IjN
WQ;gmoLOoooo30820P0F0000A4A4FUYJMgMg@410DE5AFUYJ?cloHf=S@T92Hf=SPh>3Hf=SF5QH@410
BTY:DE5AAdM7MgMgDE5ABTY:?clo0S`l?00;<30`<C4a<C4a<S8b0000<S8b?3`l<S8b?3`l0000@T92
009:BTX2E5AD00EOGemSHf=GEeMOGem2@T800eMGE`03E5AD@T92EUIF009?Cdl01e]KFdY:BUMGEeMG
Ee5ADDE5AGMgM`02Ng]k00>CTi<30`=gMgL00gQhN003MgMgVIVIVIVI009NGUh015IFEV=SHeQHF2DU
9A820P8[oooo00o]kNgWinOLg=cKfm_WinOTi>CLg=c]kNgKfm_WinOKfm_4a<CKfm_Shn?WinL00^CT
i005m?CddM7Ak^k^i^KVhN7Q00?dm?@2n_[j00GinOWjn_[Rh^;inOW`l?000_Cdm0;Zj^X02Ng]kNOW
in3Ph>OWin3Ph<K6a^3Ph=kNg_7al@02i^KV00G_kno[jn_Shn?Ph>3/k>`00^?Sh`0;kno_j>SXj>SX
kNg]gmoOdM7Ae=CDU9BDa<C4c<c<g]kN00:i^KT2g]kN0YbLW0;<c<`01=kNg]_Kfn?Shnk^kSGoool0
027oool=moOg00M/K6a?Cdm;Bd]3@d<92@U3@d=DE5@00T=3@`03:RXZ<C4a:RXZ008i>CT01`T92C/k
>dY:BTQ8B6a/K8>3PhR8R002^k^k00?0`<39bLW9bLT01<o?c`05bLW9a/K6bLW9bLW9`<3000:XZ:P3
[Jf]00^XZ:R][Jf][JfXZ:R][JfXZ:RPX:2TY:BPX:2TY:B0P8000YRHV00:Ti>CRh^;0@41MGEeK6a/
B4Q8>c/k820P;2`/6a/K0Q<C4`04000030`<30`<10@40`000003;2`/<C4a=cLg01?gmoLOoooo3@82
0P07?cloFUYJBTY:@410F5QHDE5AADE5009ADE4035mOGf=SHemOGeQHF4Q8B5QHF7MgMg1`L7]kNdE5
AEMGEdm?C`9:BTX00c`l?38b<S`l?003<S8b0S`l?006@T92?3`l?cloHf=SEeMGHf=S0UMGE`9SHf<0
1eMGEd=3@eMGEf=SHeMGEfIVIT92@P02Fe]K00EPH61GEeM4A4AADE5]KFd00V][J`05Ng]kMgMgTi>C
Ogmo0P8200=gMgL2N7Qh00NIVIUNGUiNGUiNGUh0001SHf>CTi<04`820Rcoool01oCdm=cLg>OWinCT
i>?ShnCTi>WYj@02i>CT00?;bl_Kfm_;bl/00n?Sh`06fm_KcLg=e=CDgmoOkNg]j>SX0^g]k@03lo?c
m?Cdl?3`00CinOT01oCdm>[Zj_Cdm?Cdm??cllK6a]kNgP03i^KV00_Ng]kVi^KVi^KNg]kVi^K6a/K[
jn_Shn?[jn_Shn?Rh^800^SXj00:h>3Pk^k^`<30h>3PgmoOe=CDfm_KQ8B4a<C4i>CT0]kNgP04V9RH
^KVi^KViW9bL0/c<c004R8R8a<C4fm_K`l?3=_ooo`008Oooo`03moOglO7amoOg00[gmoL01X20P492
@T];B`P824=3@d51@@90@4004CTi>B0P82`/;0P820X:2P410@T92@820P`<300004Y:BUQHF0000820
P861PHR8R;:b/P03P82000F2PX:0P820P82`/;30`<001H20P00>RHV9Q8B4Q8B4QHF5X:2PR8R8RXZ:
P820Y:BTX:2PP820VIVIT92@Ti>C0h:2PP0:A4A4EEEE@D5120P8:2PX820P00004a<C30`<10@40P`<
300310@40000000000800002820P00=PH63gmoOgmoL04OOgmaooool=0P8200D@4114A4A:BTY8B4QA
DE400d51@@0A@4100`<3Ph>30P82BTY:@410BTY:@4100P82H61P@410@d=3DE5AA4A4H61P0000@D51
008<30`04PP823/k>d10@00004a<C0`<30l?3dA4A4Y:BT=3@d51@E5ADDY:BU]KFe1@D451@E5ADF9R
HP9KFe/2H61P00mTI6A4A4APH614A4ADE5A[Jf]SHf<B4Q9cLg<30`<P821oOgl0001hN7PH61P00WQh
N08H61P2GUiN00AHF5P30`=SHf<0000C0P828?ooo`03o?cloooooooo00Woool01?3`l?Cdm<C4a<30
`0;4a<@2h>3P01c3`l?0`<34a<C4a<C3`l?Ph>30`<3QhN74a<C9bLW=cLg@d=3Ph>30`<32`/;Xj>S]
kNgPh>3Ti>CShn?]kNgShn?Ph>3QhN7`l?3QhN7Ph>3Ti>@2`l?300_Vi^K1`L70`<3=cLg2`/;6a/K@
d=30`<3Shn?[jn_Rh^800/30`004h>3P`<30a/K6i>CT0l30`007d=3@`<30R8R8Q8B4g]kN^KViV9RH
00:i^KT029RHV8b<S<c<c<c<c8R8R<C4a<S8b>CTi3Koool0027oool=moOg00[ooom/K6aMGEe3@d<;
2`/k>c]3@d=;Bd]3@d<X:2P2;2`/0S4a<@0<@410Bd];@d=3Bd];E5ADFUYJH61PHf=SMGEeMgMgRh^;
PX:20X^;R`09QXJ6Rh^;P820Vi^KZJVYV9RHPh>3MGEeK6a/009eMGD01hR8R8Z:RXZ:RYFEUI>CTi^K
ViFEU@03Ti>C0XZ:RP:1PH402g=cLf9RHUEEEDQ8B3/k>c0`<20P800000`<31<C4``<300210@41000
000530`<:2PX820PHV9Roooo01?gmoLOoooo3P820P8o?cl01e5ADEYJFWMgMe5ADDY:BP410GMgM`02
Ph>301ISHf=1@D4i>CU:BTYADE5:BTY5ADE4A4@o?cm4A4A[Jf/@411NGUiEEEEADE5@D51ADE5GEeMD
E5APH617AdMEEED2Jf][00I_Kfm[Jf]]KFeWIfM_KfmWIfL2H61P0W5aL@9TI6@01VMWIe5ADFMWIfe]
KDE5AF=SH`9oOgl01g=cLi>CTgmoOgmoOf9RHW1`L7QhN003VIVI0eiNGP04N7QhGemO0`<3Hf=S5082
0Rgoool02OCdm>g]kNCTi=SHf=_KfnCTi>OWinCTi<30`002a<C40]_Kf`05h>3PinOWi>CTinOWjNWY
00?dm?@01>3Ph>o_knk^k^CTi0;^k^h02NKVi^k^k^SXj=;Bd^c/k>SXj>g]kN3Ph=oOg`02h>3P00OS
hn?7alOOgmoMgMgPh>3Rh^;MgMd00n3Ph00?gmoOc/k>fm_Kfm_Ki>CTh>3Pc<c<e=CDfm_K]KFec<c<
a<C4^KVig]kN^KVi00:LW9`4c<c<00Bi^KW0`<3<c<cPh>0goooo000Qoooo3_Ogm`04SHf=Hf=SBd];
2@T90d=3@`05Bd];92@T:RXZ;2`/>c/k0093@d<2E5AD01Q;Bd]MGEe3@d=DE5AJFUYRHV9cLg=/K6ab
LW9eMGE/K6acLg=eMGD10@6WYjN;Rh^3Ph=cLg=/K6aRHV9TI6ARHV9cLg=mOGd3R8R800bEUIF8R8R:
RXYiNGV1PH5mOGf0P81iNGUcLg=/K6aMGEe1@D42<30`00@/;2`P8200000C4a<230`<00<410@00000
00000`000004;2`/0000;2`/f][J5?Ogmaooool>0P8200@j>SY4A4A8B4Q:BTX3DE5A00M0@423Ph=O
Gen3Ph=gMgMADE5:BTX00TE5A@07BTY:4A4AADE5ADE5AdM7Hf=SAdM70094A4@026][JaLG5f][Jf][
Je5ADEADE55ADEMGE`9_Kfl00f=SHf9RHW5aL@02OGem0Ve]K@0?LG5aKFe]IfMWIfMWI6ATOGemGUiN
KFe]M7AdAdM7MgMgOgmoTY:BTi>CPh>3009oOgl00gMgMg1`L7QhN002VIVI15iNGP04Ph>3HV9R0`<3
820P50820Rgoool01>_[joCdm>OWin?Sh`?Ti>@01NOWil30`<_;blC4a=_Kf`02i>CT0^WYj@0<inOW
kNg]i>CTjNWYm?Cdh>3Pi>CTgmoOinOWh>3Pm?Cdi>CT0^3Ph00:kno_k^k^kNg]i>CTgmoOh>3Pg=cL
h>3PiNGUdM7A0n?Sh`0<gMgM`l?3gmoOfMWIfm_KdM7A`/;2fMWIi>CTgmoOdM7A`<300[Fe]@04a<C4
c<c<c<c<g]kN0[Vi^@03W9bLS8b<c<c<00?<c<`3a<C400?gmoOoooooool0=Oooo`008Oooo`kgmoL0
6M?CdgMgMd];Bd=3@d];BdQ8B3Hf=UYJFRPX:2`/;2XZ:S4a<C/k>d10@5eMGDM7Ad=3@eeMGF=SHeAD
E69RHWEeMEYJFV=SHd92@P02HV9R00EMGEe/K6aEEEEeMGF3Ph<00WEeM@07@T92EEEEEEEEFe]KEEEE
I6ATLg=c009iNGT00h61P@410GEeM@02MGEe00A/K6aTI6A/K6a/K6`2EEEE00X820P`<30/;2`P820K
6a/820P<30`410@<30`410@4000000@<30`P820:2PXi>CTEmoOg7oooo`l20P801c@d=410@55ADDY:
BSTi>DA4A410@002Ph>300iOGemSHf=5ADE:BTXo?clH61QADE4410@o?cm5ADESHf=[Jf]4A4AGEeL3
Hf=S00Q_KfmgMgM[Jf][Jf]1@D5[Jf]4A4AGEeL3Ogmo00AfMWI_KfmaLG5dM7@2KFe]00EdM7A[Jf][
Jf]_Kfm[Jf/00fm_K`0;OgmoNg]kMgMgPh>3OgmoZJVYHV9RN7Qh61PHN7QhVIVI00ANGUh017QhN7mo
OemOG`0001D20P8]oooo00_clo?_knoWinOTi>CWinObl_;alO7dm?C0`<34a<C;bl/00]_Kf`07hN7Q
kNg]mOGei>CTkNg]m?CdjNWY00;Ph>02m?Cd0n3Ph005dM7AgmoO`<30h>3PkNg]00?Ph>02c<c<00CF
e]K<c<cLg=cUiND2fMWI00?Kfm_IfMWPh>000^3Ph004gmoO`<30gmoOgmoO0/c<c00:d=3@]KFea<C4
c<c<ZZZZX:2P^KViW9bL^KViW9bL1<c<c004^KVic<c<`<30_Kfm>?ooo`008Oooo`ogmoL01IjNWTm?
Cd=3@d];BcTi>@02B4Q800D10@4K6a/a<C4i>CU;Bd/00eADE005GEeM@d=3GEeMH61PHV9R009SHf<0
4UYJFTY:BTm?CdQ8B5YJFTY:BUEEEEiNGV9RHV=SHdm?CdY:BTm?CeEEEDY:BU=CDe5ADE]KF`=/K6`0
0fATI5iNGVa/K002Fe]K00]PH61MGEeEEEEJFUY8B4PP820/;2`a<C4K6a/C4a<A4A400P`<30030000
10@40000008000001@@4120P82`/;14A4Hf=S@0EmoOg7oooo`l20P8031<C4e1@D55ADDY:BUQHF3Ti
>A4A4F=SHf9RHV=SHeQHF410@0=5ADD01Clo?a4A4Clo?dA4A6=SH`02A4A400E`L71JFUYJFUY3@d=`
L7000WmoO`04EeMG@410FUYJAdM70UYJFP03L71`R8R8R8R8009oOgl3Kfm_019fMWIGEeM_KfmoOgmf
MWISHf=gMgM7AdMkNg^CTi>3Ph<30`=RHV9gMgMKFe]gMgMhN7QNGUh2VIVI0UiNGP05VIVIOgmoPh>3
Fe]K20P801D20P8^oooo00G^k^kLg=cTi>CWinOShn<00_;blP05`<30i>CTfm_Khn?SinOW00?YjNT0
1Ng]kNCTi>g]kOCdm>3Ph003m?Cd017<c<cLg=cDe=Cdm?C=cLg<c<cYjNWPh>3dm?CLg=cDe=CLg=c<
c<c=cLgBd];0`<3Fe]H00moOg`03g=cLjNWYgmoO00;Fe]H02l30`=7AdLc<c?Cdm=CDe8B4Q<C4a=_K
fnCTi=kNg/c<c002^KVi00?<c<bLW9b<S8`00/c<c005W9bLc<c<a<C4SHf=jn_[03Soool0027oool?
moOg00SLg=a_Kfm3@d=3@d=;Bd/i>CU8B4Q0@402<C4a00Y;Bd]3@d=MGEe;Bd]SHf=DE5A3@d=?CdmJ
FUYSHf<2FUYJ00iEEED820Q?Cdli>CU3@d=?Cdl;2`]8B4QJFUY8B4Q3@d=0@40/;2`k>c/2>CTi0S/k
>`03B4Q8@d=3@d=300=8B4P6>c/k00Pg=cLP820P820K6a/E5AD<30`0000E5AD230`<0`00000630`<
820P820P5ADE0000oooo5OOgmaooool?0P8200P10@4H61QADE5ADE5:BTYHF5P10@5ADE42Hf=S00Y:
BTXA4A4o?cm:BTY4A4A5ADE@D517AdMGEeM4A4@2AdM700mkNg]HF5QJFUY@D51JFUYgMgMJFUYkNg]3
@d=ADE55ADEADE63Ph=@D51HF5P00gMgM`034Q8BTY:BNg]k009kNg/00g=cLgMgMgMgM`03MgMg00FC
Ti>PX:1oOgmRHV9KFe/00WQhN003MgMgF5QHN7Qh00=NGUh01EQHF7moOgmoOe]KFf=SH`0F0P82;_oo
o`08lo?ck^k^a<C4i>CTinOWhn?Sl_;bh>3P0]_Kf`09inOWi>CTkNg]inOWm?CdjNWYi>CTg=cLh>3P
00?dm?@03/c<c<30`=cLg>?ShnCTi=cLg=SHf=CDe?Cdm=CDe>CTi>3Ph<C4a=_Kf`;Shn<2fm_K00?D
e=C2`/;2`/800mCDe0KKfm/02<?3`hR8R<c<c>CTi<g=cKVi^IRHV<g=c@:i^KT3c<c<00Fi^KW<c<c<
c<c=cLg@d=00>Oooo`008Oooo`ogmoL02N;RhX20P4=3@d=3@`/;2d=3@`820T10@451@@022@T900Y9
BDU0@41MGEeMGEe9BDU1@D50@41:BTY8B4Q1@D42B4Q80P410@8`<3000d=3@`0000410@02@d=300@3
0`<P820a<C4X:2P2820P00@/;2`P820P820`<302820P0RPX:00792@T820P820P820P;2`/820P;2`/
008000001Q<C4a/K6``<30@4100000@410D0000010P82000030`<00001KgmoLOoooo40820P080000
@410@410@T92@4100000@4104A4A0TQ8B0800002?clo00l:2PX00010@41@D51CDe=:BTYJFUY0@41A
DE5@D510@41ADE58B4P10@52@T800U5AD@05@410F5QH@4100`<3Hf=S00:3Ph<24a<C00=gMgL30`=S
Hf<00P<30`07Ph>3MgMgPh>3Hf=S0`<3Ph>3Hf=S00=RHV8017QhN1PH67QhN1PH60ANGUh01@000082
0U]KFi>CTd10@00F0P82;_ooo`06moOgl?3`a<C4i>CT`l?3i>CT0^3Ph005i>CThn?Shn?SiNGUh>3P
00;]kNd01^GUiNCTi>7QhLC4a<30`<C4a0;De=@01l30`>3Ph=7AdM7AdNCTi<30`=SHf002i>CT00C0
`<31`L73`l?0`<02b<S800G4a<B4Q8B4Q8BATI78b<P01<30`00>Q8B4P820b<S8a<C4Q8B4a<C4`<30
a<C4g]kNi>CT^KViV9RHR8R8V9RH0lc<c006Q8B4Y:BTa<C4c<c<]KFeh>3P>Oooo`008Ooooa3gmoL0
1/[:bP0004=3@d];Bd=3@dQ8B093@d<2GEeM00]_Kfl@411DE5A;Bd/i>CTa<C5;Bd]>CThk>c];Bd]:
BTX00T=3@`8i>CT01D=3@dm?Cb8R8RXZ:SHf=P03;2`/0R0P808K6a/2820P00L/;2`K6a//;2`P820K
6a/P820/;2`0120P80044a<C820P4a<C10@40Q<C4`0530`<000010@4000030`<008000001A/K6c4a
<ADE5B`/;8N7Q`0GmoOg7ooooa020P801PP824Y:BU5ADDY:BU5AD@P8209ADE42?clo00/H61Q5ADE5
ADE:BTYHF5Q2@T9JFUYGEeMgMgM:BTY@D5000U5AD@04F5QHD51@FUYJA4A40UmOG`050000Ph>3Ph>3
Ph>3Ogmo009RHV83Ogmo00H20P:3Ph=oOgmoOgmRHV830`<2Ogmo00f3Ph=oOgmgMgMoOgmRHV9gMgLA
4A5gMgMhN7QNGUihN7PH61QhN7P00UiNGP05N7QhHV9RFe]KPh>3=SHf01L20P8_oooo00Kclo?UiNGT
i>CWinOTi>Cbl_82i>CT0^g]k@0;k^k^hN7QjNWYinOWhn?Sfm_KinOWb<S8fm_KinOWcLg=00;Ti>@2
hn?S00GTi>CLg=c1`L7;bl_alO400lC4a0;<c<`2i>CT0/c<c009a<C4i>CTa<C4c<c<i>CTc<c<a<C4
c<c<a<C400;<c<`01=kNg/c<c<C4a9bLW0;Ng]h03;Vi^HR8R9bLW<c<c;Vi^Lc<c8R8R>CTi=_Kflg=
cLC4a>GUiC[oool0027oool@moOg00[alO50@41;Bd]3@d=;Bd]3@d<a<C58B4Pa<C5DE5@2GEeM00Lf
=SHi>CUMGEe/K6aJFUY2@T8k>c/00STi>@04<C4a0@41@d=3;2`/0R@T900:8R8R92@T;2`/92@T;2`/
00006a/K5ADE6a/K5ADE0Q/K6`06820P4a<C820P820P92@T4a<C0Q/K6`0700005ADE820P4a<C5ADE
00006a/K00<<30`4000000<<30`K6a/K6a/00R0P8003HV9Rj>SXmoOg01KgmoLOoooo40820P0:0000
A4A4BTY:DE5ABTY:@D51F5QH>CTiHf=SADE50Slo?`0:A4A4F5QH?clo1`L7DE5AL71`MgMgF5QH@410
Hf=S0U5AD@080000F5QHA4A4GemOF5QH0000Ph>3F5QH0V9RHP03@T92Fe]KHV9R009RHV801GMgMgmo
OgmoOh>3PeQHF002HV9R00QgMgMoOgmKFe]gMgMKFe]oOgmKFe]PH602N7Qh00FIVIUNGUiNGUiNGUih
N7P00f9RHP03OgmoHf=S2PX:01L20P8_oooo00[lo?cQhN7WinOTi>CWinOTi>C3`l?bl_;Kfm_YjNT2
kNg]00?alO7Shn?]kNd00_Cdm008a<C4fm_Khn?Shn?Sfm_K`<30i>CTa<C40[Jf]P0:`L71][Jfa<C4
][Jfa<C4Y:BTi>CTcLg=i>CTcLg=0^CTi006c<c<g]kNc<c<a<C4][Jfg]kN0^CTi007c<c<cLg=c<c<
g]kNcLg=c<c<i>CT00>i^KT01Hb<S<c<c<c<c<c<c;Vi^@02i>CT0/c<c003h>3Po?cloooo03Woool0
027ooolAmoOg00?0`<1:BTY3@d<00T];B`082@T9@d=3B4Q8=SHf@d=3E5ADGEeME5AD0TQ8B00@>CTi
B4Q8<C4a<C4a@d=3>CTi:2PX>CTi:BTY92@T=SHf0P8292@T;2`/6a/K92@T0a/K6`0:5ADE4a<C4A4A
5ADE6a/K5ADE6a/K4a<C;2`/30`<0Q<C4`050000820P4a<C4a<C30`<008C4a<00aDE5@`<30`<3002
000000L<30`E5ADK6a/A4A4P820/;2aEEED06OOgmaoooolA0P8200<<30a`L71ADE400TY:BP05F5QH
DE5A>CTiA4A4@D51008o?cl01DE5ACTi>APH64Y:BW]kN`02Hf=S00]@D51OGemHF5QHF5P@4114A4AA
DE5OGemHF5P20P9HF5P00f9RHP06@T92MgMgFe]KHV9RFe]K@T920V9RHP03MgMgPh>3L71`009gMgL2
Ogmo00EgMgMhN7QRHV9gMgMCDe<00gQhN008GUiNF5QHFe]KHV9RFe]KHf=S0`<3Ogmo6@820S3oool0
0n7QhLg=cNCTi002inOW00SShn?Ti>Cbl_;alO7Ti>CYjNW]kNgYjNT2l_;b013Shn?4a<CKfm_Kfm_T
i>CShn?3`l?Shn?>c/jf][KalO70`<2f][K4a<CTi>Bf][H3i>CT00O=cLgNg]k4a<C=cLgTi>C=cLgT
i>@00/C4a003^KVig]kNg]kN00;<c<`2g]kN00Bi^KW4a<CNg]k=cLd2^KVi00V8R8S<c<bi^KW=cLgT
i>C9bLW<c<c4a<C<c<`0??ooo`008Oooo`03lO7amoOgmoOg00kgmoL03=?Cdf=SHd=3@cTi>D];BdQ8
B4=3@dQ8B4=3@eeMGD10@4=3@`9MGEd00fm_Kd=3@c4a<@02;2`/0STi>@080000<C4a>CTi:BTY=SHf
820P6a/K92@T0QDE5@04820P5ADE5ADE5ADE0P`<308K6a/03Q<C4``<31/K6a<C4a/K6aDE5@`<30P8
21/K6a<C4``<31DE5@@410`<3080000010`<300000@410`<308E5AD00bTY:B`/;4Y:BP02j>SX6?Og
maooool00`X:2P820P820P0>0P8200X?3`m4A4AADE5HF5Q:BTXi>CUADE4i>CUADE4i>CT2DE5A0Slo
?`03410@Hf=SMgMg00:3Ph<03EQHF8>3Pe5ADF=SHa0@44A4A5mOGgmoOf9RHUQHF5]KFemOGcPh>002
Fe]K0gQhN09RHV8047QhN69RHV9RHWMgMd92@WQhN69RHWQhN69RHW1`L5]KFgQhN9VIVEQHF5iNGWQh
N09NGUh01QPH65]KFe]KFeQHF3@d=000008:2PXH0P827oooo`03o?cloooooooo00koool03??cloCd
m>CTi>?ShnOWin;Rh^CTi?;bl^CTi>g]kN3Ph>CTi0;]kNd00nk^k^CTi=_Kf`02a<C40^?Sh`08a<C4
fm_Khn?Sc/k>lO7ab<S8i>CT][Jf0/g=c@04b<S8cLg=cLg=cLg=0[Vi^@;Ti>@03]kNg[Vi^NCTi=kN
g^CTi<g=cKVi^J2PX>CTi=kNg[Vi^Lg=cIRHV;Vi^@;<c<`01;Vi^Lc<c9bLW;Vi^@;=cLd00l;2`/C4
a<g=c@02o?cl>oooo`008Ooooa;gmoL00f9RHP0004=3@`020@4100E3@d<00013@d<20P8000000T=3
@`0<0@410P82820P0@41;2`/0000820P:2PX820P92@T:RXZ4A4A0P00000710@44A4A4A4A10@44A4A
000010@4008<30`01`@410`<30`<31/K6a4A4@`<30@410025ADE00D820P410@410@<30`410@01`00
000810@400004A4A20P8000010@4j>SXh>3P6OOgmaoooolB0P820P@41090@4001U1@D410@0000410
@00000@41090@4005U1@D000055ADF=SHh>3Pf9RHUQHF0<30emOG`00010@45]KFa0@45QHF0<30d92
@UQHF5]KFd92@V9RHUQHF7QhN09HF5P00gQhN61PH492@P02N7Qh00UHF5QKFe]PH60H61QKFe]HF5PH
61QNGUhH61P00UiNGP09F5QHFUYJ61PHFe]KD51@@T92H61P0P82:BTY01/20P8aoooo00?WinOPh>3T
i>@00^3Ph003i>CTl?3`i>CT00;Ph>02i>CT00CPh>3QhN70`<30`<02a<C400S<c<c3`l?0`<24Q8C;
bl^=SHg<c<b4Q8@3a<C400B9RHW4a<C4a<B9RHT2^KVi00N9RHVi^KVi^KWTi>C4a<Bi^KV9RHT00/g=
c@07X:2PQ8B4RHV9^KViV9RHc<c<R8R800;<c<`02HR8R<c<c8R8R8V9RIJFU/C4a:2PX820P=kNgP02
o?cl??ooo`008Ooooa?gmoL01K^k^gMgMeYJFPT92D=3@`02B4Q800UMGEe8B4QDE5ADE5A5ADDf=SH/
;2`10@4P82000Q/K6`0<820P2PX:820P820P=SHf30`<20P86a/K5ADE30`<5ADE30`<0QDE5@8<30`0
1`@411DE5@`<31DE5B`/;00000`<30025ADE00<K6a/410@<30`01000000330`<5ADE92@T008E5AD0
1Q/K6b`/;20P83/k>d10@>;RhQ_gmoLOoooo4`820P056a/K=3@d@410BTY:DE5A00<i>CT024Y:BTE5
ADE5ADE5A@0004Y:BV=SHgmoO`9RHV802UmOGf9RHWmoOdA4A7QhN5mOGgQhN69RHUQHF5]KF`9hN7P0
15]KFeQHF7QhN7QhN09KFe/02UQHF8>3Pe]KFeiNGWQhN5]KFf9RHWQhN5]KFgQhN0=NGUh00iVIVEQH
F5QHF003Fe]K00D20P9oOgmgMgMkNg][Jf/06`820S;oool01Ng]kNo_koCdm>?ShnCTi002l_;b00W]
kNgRh^;YjNWYjNWLg=calO74a<C3`l?<c<`00^CTi00<c<c<`<30c<c<c<c<lO7a^KViRHV9i>CTcLg=
^KVicLg=^KVi0/g=c@:i^KT01hV9RLg=cKVi^Lg=cLC4a<c<c;Vi^@02cLg=00?Ti>B9RHVi^KT00lc<
c004S8b<^KVicLg=][Jf0/g=c@06i>CTa<C4c<c<fm_K`<30moOg?_ooo`008OoooaCgmoL05;2`/6m_
Kd=3@d];BcTi>DQ8B3Ti>D10@4Q8B4=3@cTi>CHf=Q/K6`P822XZ:QDE5A/K6aDE5B0P81DE5@8C4a<0
2@`<31DE5@`<31DE5@`<31DE5@@410`<31DE5@0330`<00<E5AD<30`E5AD00RTY:@8<30`25ADE00@0
000E5ADK6a/P82026a/K00DE5ADT92@C4a<<30`000000R0P808k>c/00f1PH?OgmoOgm`0JmoOg7ooo
oa@20P801R4Q8@P8255ADDY:BUQHF3Ti>@8H61P02CTi>E5ADEQHF410@4Y:BX>3PemOGe]KFd92@P02
Ogmo00=KFe]gMgMhN7P00U]KF`07N7QhF5QHFe]KN7QhFe]KN7QhF5QH00=hN7P00e]KFeQHF3@d=002
=3@d00MhN7QHF5QKFe]KFe/h>3QKFe/P82000f9RHP06F5QHMgMgN7QhFe]KGemOOgmo0WMgM`03Kfm_
A4A40P8201X20P8coooo01C`l?3^k^kTi>CWinOShn?bl_;Shn?`l?3bl_;Ti>CShn?alO7Ti>C4a<C;
bl_=cLgTi>C=cLg<c<c=cLd2g]kN00Vi^KW=cLfi^KW=cLfi^KW=cLf9RHVi^KW=cLd00kVi^@03cLg=
^KVicLg=00;>c/h2^KVi0/g=c@04b<S8cLg=i>CTb<S80^CTi005cLg=][Jfg]kN^KVibLW900;<c<`2
fm_K00?7alOoooooool0?Oooo`008OoooaGgmoL01/C4a51@D4Q8B4];BcTi>DQ8B09DE5@01eeMGEAD
E4Q8B3Hf=P410B0P82@T90025ADE00P0000E5ADE5ADC4a<K6a/820P<30`E5AD530`<00DK6a/<30`0
000<30`K6a/00QDE5@0610@4@d=3AdM75ADE92@T10@40aDE5@0<6a/K00005ADE5ADE=SHf>CTi4A4A
>c/k;2`/B4Q8GEeMI6AT7?OgmaoooolE0P8200H410A5ADDi>CU:BTYHF5P10@42ADE5014o?cm5ADD0
001ADE5HF5QoOgmHF5QKFe]hN7QoOgmKFe]CDe=RHV9hN7QRHV9hN7QHF5P017QhN003H61PN7QhGUiN
009hN7P02D92@U]KFdA4A000055ADAPH65QHF5]KFgQhN002Fe]K00aRHV9HF5QRHV9KFe]4A4AHF5QR
HV9SHf<30`=kNg]gMgLo?clL0P82=?ooo`06kNg]hN7Ql_;binOWhn?Sl_;b0^WYj@07kNg]jNWYl_;b
lO7ah>3Pc<c<][Jf00;=cLd028R8R<g=cLg=cMkNg^CTi:2PX;Vi^Lg=c@Fi^KT01NCTi;Vi^HR8R;Vi
^NCTi002cLg=00KQhN7Ti>CemOG=cLff][J9RHT3cLg=00cTi>BTY:C=cLg=cLgalO7Shn?0`<3Kfm_4
a<CDe=CAdM7dm?@ooooo000Qoooo5_Ogm`06M7AdE5ADBd];B4Q8>CTi@4100eADE003ADE5=SHf410@
008/;2`0220P80`<314A4A/K6aDE5@`<31<C4`P8208E5AD020@411DE5@@411DE5@`<31DE5@`<3000
008<30`013Ti>BTY:@<30eeMG@8T92@00bTY:B0P82@T90026a/K00LE5AD820P`<30i>CTZ:RX/;2`P
82000S/k>`03EEEEK6a/lO7a01cgmoLOoooo5@820P070000=3@dADE5BTY:>CTiD51@>CTi00=5ADD0
0dA4A4E5AEQHF002Ph>300YhN7QKFe]RHV9RHV9HF5QgMgMhN7QRHV9KFe/I6AT2Fe]K00=hN7QKFe]H
F5P00WQhN008GUiNN7Qh<30`=3@d8R8R61PH?cloF5QH0S@d=00?A4A4F5QHHV9RFe]KHV9RPh>3410@
GemOPh>3Hf=SPh>3MgMgOgmoKfm_2PX:01`20P8eoooo00KRh^;YjNWWinObl_;Shn?Ph>03jNWY00?L
g=calO7QhN400/C4a008c<c<^KVia<C4i>CTcLg=^KVig]kNX:2P0/g=c@08W9bLcLg=RHV9cLg=^KVi
cLg=^KViR8R80[Vi^@04_Kfmc/k>/;2`kNg]0[Jf]P03c/k>`<30][Jf00;Ti>@01lg=cLC4a;Fe]N?S
hl_;blC4a<30`002fm_K00?<c<cOgmolo?`0?oooo`008OoooaKgmoL06gAdM0820T51@D10@4Q8B041
0D10@4=3@eADE4Q8B410@0410C0`<34a<B0P80P820@411/K6`0001<C4a4A4@0001/K6``<30@410`<
30@4100330`<018E5AD0000<30`820P0000410@P82010@55ADDD51@000010@40000@41010@4i>CT8
20P;2`/30@4100D92@U8B4Q4A4AFEUKalO407OOgmaoooolF0P8201/0000410@410A0@40820Q@D50A
4A4820P51@D10@4A4A5@D510@41SHf<20P9HF5QKFe]RHV9`L71CDe=RHV9HF5QRHV9HF5QhN7QHF5QK
Fe/00WQhN00AFe]KF5QHF5QHN7Qh@41061PH<30`=3@d410@0000>3Ph4a<C@410ADE5@410F5QH0000
0090@402@D5100A@D512@T9PH60D51@N0P82=Oooo`05h^;Rh>3Pi>CThN7Ql_;b00;Ph>005>?ShnWY
jN;Rh^3Ph<30`>7QhM_KflS8b<C4a8V9RNCTi8R8R=kNg/c<c820P>CTi;Vi^HV9RKVi^HV9R@>i^KT0
4/g=cHR8R;Vi^J2PX<c<c;6a/HR8R<C4a>GUiN7QhLS8b<C4a<S8b<W9bL30`>?Shl30`>CTi0?0`<00
1L?3`lC4a<c<c>WYjOclo010oooo000Qoooo6OOgm`05HV9RE5AD@D51Bd];E5AD00=MGEd00de=CC4a
<C4a<@02<C4a00l20P8K6a/f=SHZ:RXP8200000<30`E5AD<30`E5AD410@E5AD<30`K6a/P82000QDE
5@0:6a/K:BTY5ADE92@T8b<S@d=3ADE55ADE6a/K92@T0Q/K6`095ADE820P=SHf<C4a;2`/>c/kA4A4
Hf=Sdm?C01ogmoLOoooo6@820P05Hf=S1@D5DE5ABTY:ADE5008o?cl00cPh>3lo?f=SH`02Hf=S00UO
GemADE5RHV94A4AoOgmHF5QRHV9hN7QHF5P00U]KF`04N7QhFe]KH61P>3Ph0e]KF`07820PFe]KF5QH
A4A48R8R@D51Fe]K009RHV802eQHF69RHU]KFemOGgmoOd10@8>3PgMgMgmoOfm_K`T92@0O0P82>?oo
o`05h>3PjNWYi>CTinOWjNWY00?]kNd00nc/k=_Kfm_Kf`02fm_K00o0`<3Ti>CalO7;bl_<c<bTY:Bi
^KW=cLfi^KW=cLf9RHW=cLfi^KWTi>C8b<P00/g=c@0:i>CTc/k>cLg=/;2`^[Zji>CTg=cLcLg=i>CT
][Jf0^CTi009cLg=b<S8lO7afm_Ka<C4fm_Kc<c<`l?3lo?c04;oool0027ooolImoOg00^WYjM/K6a;
Bd];Bd]8B4QDE5AMGEe_Kfl0001;Bd/`<3000S4a<@03;2`/<C4a>CTi008i>CT2820P00D/;2`E5ADE
5ADA4A4T92@00QDE5@06>CTi2@T992@T6a/K92@TAdM70RTY:@0;820P6a/K=SHf8R8R>CTi=SHf<C4a
;2`/0`<3;2`/>c/k0098B4P00eaLG=?CdoOgm`0OmoOg7ooooaT20P80318B4PX:2TY:BTY:BSTi>DE5
ACPh>1dM7BPX:4Y:BY>CTf=SH`:3Ph<01f=SHeQHF5QHF7moOeQHF3Ph>0<30`02Fe]K00URHV9HF5QK
Fe/d=3ARHV8d=3AHF5Q0@40H61P00c@d=00:820PA4A4A4A4GemOF5QH@410Ph>3DE5AMgMg0`<30W]k
N`03MgMgEeMG0P8201l20P8hoooo00_`l?3dm?CWinOWinObl_;YjNW]kNg^k^kRh^;WinNe]KD00]_K
f`03a<C4fm_Khn?S00;Shn<00hB4Q<S8b<C4a002cLg=00[4a<Bf][K=cLg=cLfm_Kg4a<Bf][KTi>Bf
][KemOD2c/k>00_8b<STi>CalO71`L7Shn?alO7Kfm_4a<C0`<34a<CKfm/00]CDe003`L71lo?coooo
04;oool0027ooolJmoOg00g@d=18B4Pi>CU3@d=;Bd]MGEe_KfmTI6A_KfmMGEdf=SHa<C4X:2P00R`/
;093@d<04S0`<5ADE1DE5B0P80`<32PX:2@T92TY:CDe=CHf=R0P86e]KD];Be=CDb0P8451@DM7AdE5
A@=3@d<2>CTi0T=3@`06BTY:Bd];@d=3EEEEMGEeD51@8OOgmaoooolJ0P8200D61PI:BTYHF5QADE5:
BTX00SPh>00B:2PX>3Ph?clo@410Ph>3GemOPh>30@41DE5AF5QHA4A4ADE5Fe]KN7QhGemO=3@dF5QH
51@D0TA4A008=3@d2@T920P8>3PhDE5A?clo61PH@D510e5AD@0:F5QHD51@DE5ABTY:AdM7@410Ogmo
Jf][EeMG2PX:80820SWoool03N_[jnCTi>?ShnCTi>OWing]kNk^k^KVi^k^k^g]kO7alM_Kfl30`002
a<C40^CTi00BhN7QjNWYcLg=c<c<^KVib/[:][Jfc/k>b<S8lO7a`<30lO7ainOWjn_[b<S8i>CTmOGe
g=cL0nCTi0;Shn<3i>CT00GWinOTi>C<c<cPh>3Xj>P0A?ooo`008Ooooa_gmoL06hJ6QV=SHeADE4];
BeeMGGAdM0000820P7AdM6m_Kdm?Cd51@D=3@cTi>B0P84=3@d10@4M7Ad=3@dQ8B3Ti>@410EaLG4E5
ADM7AeeMGDE5A@02AdM700QMGEeLG5a@D518B4Q;Bd]JFUY?Cdm4A4@2Cdm?00M;Bd/i>CT820QJFUYT
I6A:BTZ7QhL08_OgmaoooolK0P8200@?3`m4A4A5ADE:BTX2:2PX00PK6a/M7AdX:2PH61Po?cm4A4AA
DE4H61P2DE5A00Y5ADDG5aLA4A5HF5PR8R9KFe/;2`/0000o?cl92@T25aLG00PH61P;2`/<30a5ADDi
>CU2@T9JFUY5ADD2FUYJ00M:BTYHF5QgMgMkNg]6ATI`L70f=SH08P820S[oool02nOWioCdm>WYjNOW
ing]kOOgmo?clo;bl_Ogmnk^k]cLg002i>CT01SShn>GUiOTi>CPh>3Fe]KTi>Cbl_;Shn>8R8S_knoL
g=cemOG]kNg@d=3Fe]KemOG]kNg_knoYjNWbl_;WinOdm?CLg=c8b<P2g=cL00OWinOShn?@d=3dm?CL
g=c=cLgUiND0AOooo`008OoooacgmoL06<;2`WMgM`D51EaLG410@5ADE6ATI00007AdM6m_Kf1PH6m_
KgAdM4e=CDE5AD=3@eeMGD10@4e=CEADE4E5A@@410410CTi>@810@401UADE4];Bd];Bd=3@`0001XJ
6P8;2`/02PP82410@4Q8B4Y:BUEEEEaLG410@4Y:BTQ8B;>c/b?gmoLOoooo7@820P0700004Q8B0000
1@D5ADE5:2PX2@T9008X:2P0100003Ph>2PX:000008820P04Clo?`0000P821PH60410A0@41@D50@4
1000010@40D51DY:BT10@4Q8B410@4M7Ae9BDP02D51@00=kNg]3@d=2@T800UMGE`03Jf][00000P82
02<20P8koooo01_clo?_knoPh>3]kNgQhN7YjNWRh^;`l?3gmoO^k^kTi>C^k^kgmoO/k>c<c<cPh>3]
kNgPh>3/k>cWinO0`<2FUYJDU9Bm_Kg<c<c0`<3YjNT00^OWi`03i>CThN7Qd=3@00;Hf=P01l71`LC4
a=CDe>7QhL30`<71`L30`002a<C400?]kNgoooooool0A?ooo`008OoooaogmoL02<71`GAdM5QHF5eM
GEaLG7AdM8V9R@00009dM7@07F=SHgAdM00007AdM7MgMgAdM6m_K`0007AdM5eMGD];BdE5A@410CHf
=T=3@eeMGEADE4=3@d];BeEEEDm?CeeMGD92@Va/K7=cLgEeMEEEE@<30oooo`0UmoOg7ooooal20P80
500004M7Aclo?clo?`/;2`P822PX:1dM7BPX:00002PX:3@d=1dM7BPX:20P83Ph>1dM7DE5ABPX:0X:
2P95ADD01EQHF4A4A14A4DE5AE5AD@02BTY:00UJFUYgMgM7AdMSHf<o?cm3@d=oOgmADE4f=SH09@82
0Skoool02?7alN;Rh^CTi>g]kNo_kn;Rh_?clo;blP;gmoL07?Cdm?Ogmn;Rh_Ogmno_koOgmnk^k^3P
h?Ogmng]kNOWimcLg<30`?7alNCTi>g]kNWYjNCTi>OWilc<c=cLg=7AdN3Ph?Cdm>CTi>3Ph<c<c>CT
i4Woool0027ooolQmoOg00gUiNELG5`n?Si;Bd]CDe<51@EdM7B9RHV0P829RHUWIfMdM7B4Q8@00WMg
M`04I6ATQ8B4MgMgMgMg0V=SH`05K6a/HV9RHf=SK6a/HV9R009bLW801h20P8>3P`0004m?Cd=3@eiN
G/71`@0WmoOg7oooob820P802`/;2aTI6@P820T92BHV9RPX:1TI6A/K6c@d=3Ph>2PX:003=3@d00<o
?clm?Cdd=3@00TA4A005>3Ph?clo@410Kfm_Hf=S00=4A4@2EEEE00@o?cmJFUYADE4@410W0P82@?oo
o`0=lo?ckno_dM7AinOWjn_[hN7Qh^;Rlo?cl_;blo?ck^k^moOgjn_[00;_knl02nCTi>_[jno_kno_
koCdm>CTi?Cdm>3Ph?Cdm=oOgn3Ph002inOW00ONg]k]kNgTi>CLg=cTi>CYjNWalO40B_ooo`008Ooo
o`03lO7amoOgmoOg023gmoL01^;RhZBTY7emOADE5IRHV;bl_0:NWYh2Q8B400=gMgMMGEegMgL018B4
Q00?MgMg10@4LW9bK6a/LW9bMgMgP820Ph>3K6a/Hf=SK6a/Cdm?K6a/^k^koooo02SgmoLOoooo00<:
2PX20P820P8080820P061PH60000410@9RHV3Ph>10@40RDU9@8m?Cd2=3@d00@m?Cdf=SHm?Cdm?Cd2
=3@d00Tm?Ce4A4@410@d=3ANGUhm?CeEEED410@o?cl00UYJFP03?clo0P820P8202L20P8Ooooo00?l
o?coooooool08?ooo`06moOgi>CTi>CTi>CTj>SXk>c/0^k^kP06j^[Zjn_[kno_kNg]kno_hN7Q0n_[
j`08kno_jn_[inOWm?CdinOWkno_b/[:kNg]0oCdm003g=cLm?CdkNg]04coool0027ooolWmoOg00GU
iNGXj>S=cLfl_;bd];@00YFEU@05QhN7MgMgL71`Jf][M7Ad009gMgL030@4179bLVm_Kg9bLVa/K61P
H6=SHeiNGV=SHeiNGR@T9?ooob[gmoLOoooo:0820P042PX:30`<1`L730`<0RHV9P0==3@dA4A4:2PX
4A4A820P=3@d?Cdm>3PhA4A40000?cloA4A4?clo0094A4@00eMGEc@d=0L71`0Z0P82A_ooo`05lo?c
o?clkno_k>c/i>CT00;]kNd01NGUiNo_knOWin;Rh_Ogm`02kno_00_Zj^[WinO^k^kWinOdm?CTi>Cd
m?CYjNWdm?CYjNWTi>@0C_ooo`008Oooo`?alO4VmoOg00oPh>3UiNGPh>3Ph>35aLG1`L67QhN3Ph>0
P81aLG5RHV9DE5A1@D60P81PH6000VMWI`05A4A4E5ADHf=STi>ClO7a02cgmoLOoooo:`820P8:2PX0
100000820P0000820P<000000a0@40@410@4100200000P820P80000]0P827oooo`?lo?`Voooo00ol
o?cclo?lo?clo?c_knoalO7Xj>SPh>3bl_;/k>cWinOShn?QhN7[jn_/k>`00^k^kP05h>3PjNWYm?Cd
hn?So?cl04ooool0027oooldmoOg00?alO7gmoOgmoL0=?Ogmaoooolc0P8200<:2PX20P820P80=082
0U?oool00oclo?ooooooo`1Goooo000QooooJoOgmaoooomZ0P82[Oooo`00oooool?oool00?ooooo3
oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo001Hoooo0`0008Woool00`000?ooooooo`06
oooo00<0003oooooool0OOooo`030000oooooooo00800004oooo00<0003oooooool0BOooo`00Fooo
o`030000oooooooo08Goool00`000?ooooooo`08oooo00<0003oooooool0Noooo`030000oooooooo
00;oool00`000?ooooooo`03oooo00<0003oooooool0B?ooo`00Boooo`8000001Oooo`0000000000
0?ooo`0500000_ooo`<00003oooo0P0006ooool300000oooo`800003oooo0`0000Coool010000?oo
ooooooooo`8000000oooo`0000000004oooo00<0003oooooool0Ioooo`<00003oooo0P0000?oool3
00001?ooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool0Aoooo`00Booo
o`050000oooooooooooo000000;oool400000_ooo`040000oooooooo0000Loooo`030000oooooooo
00?oool010000?ooooooo`0000Goool01@000?ooooooooooo`000004oooo00<0003oool000001Ooo
o`030000oooooooo06Koool00`000?ooooooo`03oooo00@0003oooooool00005oooo00D0003ooooo
ooooool000001Oooo`030000oooo000000Coool00`000?ooooooo`17oooo001;oooo00D0003oool0
003oool000001Oooo`040000oooooooo00000_ooo`030000oooooooo077oool00`000?ooooooo`03
oooo00@0003oooooool00002oooo0`0000Coool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo06Koool00`000?ooooooo`03oooo00@0003oooooool00002oooo0`0000Coool0
0`000?ooooooo`02oooo00@0003oooooool00004oooo00<0003oooooool0Aoooo`00Boooo`800000
0oooo`0000000003oooo0`0000?oool40000L_ooo`030000oooooooo00Coool200000oooo`@00003
oooo00@0003oooooooooool2000000?oool0000000001?ooo`030000oooooooo06Koool00`000?oo
ooooo`04oooo0P0000?oool400000oooo`040000oooooooooooo0`000003oooo0000000000?oool0
0`000?ooooooo`17oooo001;oooo0P000003oooo0000000007ooool010000?ooooooo`00013oool0
0`000?ooooooo`08oooo00<0003oooooool0Ioooo`040000oooooooo00004?ooo`030000oooooooo
00Soool00`000?ooooooo`18oooo001;oooo0P000004oooo000000000000Ooooo`<0000Aoooo00<0
003oooooool01_ooo`030000oooooooo06Woool300004Oooo`030000oooooooo00Koool00`000?oo
ooooo`19oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0
0?ooooo3oooo003ooooo`oooo`00Z?ooo`<0000boooo0`0003Coool30000Zoooo`00Zoooo`030000
oooooooo033oool00`000?ooooooo`0foooo00<0003oooooool0Z?ooo`00W?ooo`<00004oooo0`00
00?oool300000oooo`800004oooo0P0000Coool200000_ooo`@00004oooo0`0000?oool300000ooo
o`800002oooo0P000005oooo0000oooo0000oooo00<00004oooo0P0000?oool300001?ooo`<00003
oooo100000Soool3000000Soool00000003oool0003oool0003oool500000_ooo`<00003oooo0`00
00;oool30000Woooo`00WOooo`030000oooooooo00Coool01@000?ooooooooooo`000002oooo00<0
003oooooool01_ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000oooooooo
00?oool00`000?ooooooo`03oooo00@0003oooooool00002oooo00L0003oool0003oool0003oool0
00000_ooo`040000oooooooo00000_ooo`030000oooooooo00?oool010000?ooooooo`0000Goool0
10000?ooooooo`0000[oool02P000?ooooooooooo`000?ooo`000?ooo`000?ooo`@00002oooo00@0
003oooooool00002oooo00<0003oooooool01_ooo`030000oooooooo09coool009goool00`000?oo
ooooo`04oooo00D0003oooooooooool000000_ooo`030000oooooooo00Koool010000?ooooooo`00
00Soool010000?ooooooo`0000;oool400000_ooo`030000oooooooo00?oool010000?ooooooo`00
00;oool01`000?ooo`000?ooo`000?ooo`000002oooo00@0003oooooool00002oooo00<0003ooooo
ool00`0000?oool400000_ooo`040000oooooooo00002_ooo`090000oooooooooooo0000oooo0000
oooo000000Coool010000?ooooooo`0000;oool00`000?ooooooo`0400000_ooo`<0002Ooooo002M
oooo0P0000Coool200001?ooo`@00008oooo0P0000Woool010000?ooooooo`0000?oool200001?oo
o`<00003oooo0P0000;oool3000000?oool0003oool0100000Coool200000oooo`@00003oooo0P00
00Coool300002Oooo`800002oooo0`000003oooo0000oooo00;oool300000oooo`@00002oooo0P00
00?oool40000W_ooo`00WOooo`040000oooooooo00004oooo`040000oooooooo00002?ooo`040000
oooooooo0000=Oooo`030000oooooooo0<Koool009coool500000oooo`030000oooooooo00koool2
00002?ooo`@0000eoooo0P0000[oool00`000?ooooooo`2koooo003ooooo`oooo`00oooool?oool0
0001\
\>"],
  ImageRangeCache->{{{0, 449}, {149, 0}} -> {-0.184538, -0.0234427, \
0.00750352, 0.00750352}, {{24.5625, 149.5}, {145.875, 20.875}} -> {-40.3294, \
-6.3068, 1.19876, 1.19876}, {{162, 286.938}, {145.875, 20.875}} -> {-205.084, \
-6.3068, 1.19876, 1.19876}, {{299.438, 424.375}, {145.875, 20.875}} -> \
{-369.838, -6.3068, 1.19876, 1.19876}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontFamily->"Century",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" function colorDecode",
    FontFamily->"Century",
    FontSize->10.5]
}], "Subsubsection"],

Cell[TextData[{
  "\t",
  StyleBox[
  "To draw a color image, we have to convert the decomposed components in \
Fig. 8 into the original RGB components. This is carried out by a following ",
    
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " function \"colorComp\". A parameter \"colorD\" of this function are a \
three dimensional array housing the color image components in term of the \
spherical coordinate system.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
colorComp=Compile[{{colorD,_Real,3}},
\tModule[{r={{0.}},g={{0.}},p={{0.}},out={{{0.}}},
\t\ti=0,min=0.,max=0.},
\t\tr=colorD[[1]] colorD[[2]];
\t\tg=colorD[[1]] colorD[[3]];
\t\tp=r^2+g^2;
\t\tout={r,g,Sqrt[Abs[colorD[[1]]^2-p]]};
\t\tTable[min=Min[out[[i]]];
\t\t\t(out[[i]]-min)/Max[out[[i]]-min],{i,3}]
\t\t]];\
\>", "Input"],

Cell[TextData[{
  "\t",
  StyleBox[
  "Using this function, we compose the color image red, green and blue \
components. Figure 9 shows the recovered color, red, green and blue \
components images. Because of the orthogonal decomposition and composition, \
the original color image as well as its components is exactly recovered in \
Fig. 9.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["colorC=colorComp[colorD];", "Input"],

Cell[CellGroupData[{

Cell["\<\
label={\"Red\",\"Green\",\"Blue\"};
colorCG=Table[ListDensityPlot[colorC[[i]],
\tPlotRange->All,Mesh->False,Frame->False,
\tPlotLabel->StringForm[\"``\",label[[i]]],
\tDisplayFunction->Identity],{i,3}];
composedG=Show[convertRGB[colorC],PlotLabel->\"Encoded\",
\tAspectRatio->dim[[2]]/dim[[3]],DisplayFunction->Identity];
Show[GraphicsArray[{{composedG,colorCG[[1]]},
\t{colorCG[[2]],colorCG[[3]]}}],ImageSize->{300,300},
\tPlotLabel->\"Fig.9. Composed and componets images\"];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 300 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[.5 1.0125 -110 0 ]
[.5 1.0125 110 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -171 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.813 moveto
(.9) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Composed) show
159.000 12.813 moveto
(and) show
183.000 12.813 moveto
(componets) show
243.000 12.813 moveto
(images) show
279.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Green) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7D5CDD5D5D5D5D5DDDDD5DDDDDDDDDDDDDDDDD5D5D5D5CDCDC4C4C4
B3BBB3B3ABABABABABABABABABABA2A2A299A2A2A299A2F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7
EFF7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7E7CDD5D5D5D5D5D5DDD5DDDDDDD5DDDDDDD5D5D5CDCDC4C4BBBBBB
BBB3ABABABABABA2ABABABA2ABA2A2A2A2A2A2A2A299A2F7F7F7F7F7F7F7EFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7E7D5D5D5D5D5DDDDD5D5DDDDD5DDD5D5D5CDCDCDC4C4C4BBBBB3AB
ABABABA2A2A2ABABABA2ABABA2A2A2A2A2A2A2A2A299C4F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7DDCDD5D5D5D5DDD5D5DDD5D5D5D5D5CDD5CDCDC4C4BBBBB3B3B3B3
B3ABABABABA2A2A2A2A2ABA2A2A2A2A2A2A2A2A2A299EFF7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7EFF7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7
F7F7F7EFEFF7F7F7F7F7F7F7F7F7EFEFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7D5CDD5D5D5D5D5D5D5DDD5D5D5D5C4CDC4C4BBBBABABB3ABB3B3B3
B3B3B3B3ABA2A2A2A2A2A2A2A2A2A2ABA2A2A2A2A2B3F7F7F7F7F7F7F7F7F7F7F7F7F7EF
EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7D5D5D5D5D5D5DDD5D5D5D5D5D5D5D5C4BBBBBBBBBBBBB3ABAB9999
99ABABB399ABA2A2A2A2A2ABA2A2A2A2A2A2A2A2A2C4F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7D5CDD5D5D5D5D5D5D5D5D5D5CDD5CDD5D5D5D5CDBBBBBBB3ABAB99
ABB3ABB399A2A2B3A2A2A2A2A299A2A2ABA2A2A2A2E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7D5D5D5D5D5D5D5CDD5D5D5CDCDCDD5D5D5D5D5CDD5BBBBBBBBBBBB
ABB3BBB3AB99A29999A2A2ABA2A2A2A2A2A2A2A2A2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7CDD5D5D5D5D5D5D5CDD5D5D5D5D5D5DDDDDDD5D5D5CDC4BBC4BBBB
BBB3ABB3BBAB99AB99A2B3ABA2ABA2A2A2A2A2A2B3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7CDD5D5D5D5CDD5CDD5D5D5D5D5DDDDDDDDD5D5DDDDDDCDC4C4CDBB
BBBBB3B3B3ABAB9999ABABB3B3A2ABABA2ABA2ABBBF7F7F7F7F7F7F7F7F7F7F7F7EFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7CDD5D5D5CDD5CDD5D5D5D5D5DDDDDDD5D5D5DDDDDDD5D5D5D5C4CD
BBBBBBB3B3ABABABAB99A2ABB3ABA2A2A2A2A2ABD5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7D5D5D5D5CDCDD5D5D5D5D5D5DDDDDDDDD5D5DDDDDDDDD5D5D5D5CDBB
BBBBBBB3B3ABABABAB99A299A2A2B3A2A2ABA2ABE7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7DDB3CDD5CDD5D5D5D5D5D5D5D5DDDDD5DDDDD5DDDDDDDDD5DDD5D5CDCD
C4C4BBBBBBABABA2ABABA2A2A2B3A2B3A2ABA2ABE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EF
F7F7F7F7F7F7F7F7F7F7EFF7EFF7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F766C4D5D5D5D5D5D5D5D5D5D5D5D5DDD5D5D5D5D5DDD5DDD5D5D5D5D5D5
C4C4BBB3B3ABABABABABABA2A2ABA2A2B3ABABABF7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F76E44CDD5D5D5D5DDD5D5D5D5D5D5DDD5D5D5D5D5DDD5D5D5D5D5D5CDD5C4
BBBBBBBBB3B3B3ABA2ABABABA2A2A2ABB3B3ABABF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFF7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F74C2A5ED5D5D5D5D5DDD5DDDDDDD5D5D5DDD5D5D5D5DDDDD5D5CDC4CDCDC4C4
BBBBBBB3BBB3ABABABABA2A299A2A2A2ABA2BBABF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7EFEFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7C4442AD5D5D5D5D5DDDDD5D5DDDDD5D5D5D5DDDDDDD5D5D5D5D5BBC4BBBBB3BB
BBBBBBBBBBB3ABABABABABA2A2A2A2A2A2A2A2C4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7EF3C44D5CDD5D5D5D5D5DDD5D5D5D5D5D5D5D5D5DDDDDDDDD5D5D5CDBBC4BBBBB3
BBBBBBB3B3ABABB3ABABA2A2A2A2A2A2A2ABABB3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FF5E3CD5CDD5D5D5D5D5D5D5D5D5D5D5D5D5D5D5D5DDDDDDD5D5CDC4BBBBBBB3B3B3
B3B3B3B3B3ABABABA2A2A2A2A2A2A2A2A2A2ABABD5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7774499CDD5D5D5D5D5D5D5D5D5D5D5D5D5D5D5D5DDDDD5D5D5D5CDBBB3ABABABABAB
ABABABABA2A2A2A2A2A2A2A2A2A2A29999A2ABA2A2D5F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F73C6EDDD5D5D5D5D5D5DDD5D5D5D5D5D5D5D5D5DDDDD5D5DDD5BB91BB918080808080
8091ABABA2A2A2A29999A2A2A2A2A2A2A2A299A2A2A2F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7B33CDDD5D5D5D5D5D5D5D5D5D5D5D5CDD5D5D5D5D5D5D5DDDDBBBBBB91918080809180
8080808099A2A2A2A2A2A2A2A2A2A2A2A2A2A2A2A2B3BBF7F7F7F7F7F7F7F7F7F7F7F7EF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
C43CD5D5D5D5D5D5D5DDD5D5D5D5CDCDCDD5CDD5D5D5D5BBBBCDBBBB9180807766668077
77778080888099A2A2A299A2A2A2A2ABA2A299A2ABA2ABEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EF
5E6ECDD5D5D5D5CDD5D5D5D5D5D5CDBBCDC4CDD5DDD5BBBBBBBBB3916E6666666666666E
6666667780778899999999A299A2A2ABA2A2A2A2A2A2ABBBEFF7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F788
3CDDCDD5D5D5D5D5D5D5D5D5D5D5C4BBBBBBD5D5D5BBC4C49191808899AB66BBB36EAB77
5E545E6677778888A2A299A2A2A2A2A2A2ABA2A2A2A2ABB3E7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AB4C
2AD5D5D5D5D5D5C4D5DDD5DDCDCDC4B3B3BBD5D5C491AB805E4CABABC4C4B3B3BBA2C4B3
66995E546E6E7788889999A299A2ABB3ABA299A2A2A2ABA2B3DDDDF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DD993C
99D5D5D5D5D5C4BBDDD5D5D5C4C4B39999D5BB8080802277AB669177B3E7E7D57791886E
80A291665E545E889199999999A2ABB3B3B3A2A2ABA2A2ABABC4E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A2882A
D5D5D5D5D5CDBBBBD5D5D5D5C4B3A291A2B366325EBBDDE7E7EFEFE7E7EFE7DDCDD5D5D5
C44C6E6E774454666E99999999A2B3BBB3B3A2ABA2ABABABABC4F7C4DDF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7EFEFF7F7EFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F777444C
CDD5D5D5D5CDBBD5D5D5D5D5C4A29180884C2254C4DDE7E7E7E7EFE7E7EFE7E7CDE7E7D5
D5BBAB54542A3C546688A29999A2B3BBB3B3B3A2A2ABA2ABABB3D5EFE7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFF7EFEFF7F7F7F7F7F7F7F7F7E7F7EFEFDDEFEFF7803C99
D5D5D5D5D5C4BBD5D5D5DDD5B3A2888832222A6EB3E7D5E7D5E7EFD5E7EFE7D5ABE7E7D5
D5C4C4D54C7708084C54889999A2B3BBBBB3B3ABA2ABA2ABA2B3BBBBC4EFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7D53C2AD5
CDD5D5D5D5C4D5BBD5D5D5D5A2998888543C22809191BBD5B3DDE7ABD5E7D5ABABBBD5D5
ABCDD5CDA2B399993C3C669999A2B3BBC4BBB3A2ABA299A2A2ABC491BBC4D5F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BB3C1944C4
D5D5D5D5C4BBCDBBD5D5D5CD918891ABABAB7766808091AB91A2A2A2B3BB6E777791A2AB
6EA2CDB3B3B3A2996E223C8899A2B3BBC4BBB3A2A2A299A2A2B3B3D5C4BBC4DDF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EF6E222A1991D5
D5D5D5C4C4C4C4ABD5D5D5BBA280B3B3CDD5D5D5BBBBB3B3ABB3ABAB919199997777666E
6E6EB38888C488A27710194C88A2B3BBC4BBB3ABA2A2A2A2ABABB3F7EFCDC4D5F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DDC422193222D5BB
D5D5D5C4C4BBC4C4D5D5D5C4AB80ABBBDDD5DDDDD5DDD5DDDDDDDDBBBBBBBBBBB3AB8077
80776E666699666E3C0819444C99ABBBBBBBB3A2A2A29999A2A2B38099D5DDCDE7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CD88192A222AD5CD
D5BBCDCDBBCDCDCDD5BBBBC4AB9988BBD5DDDDD5D5DDD5D5DDDDD5D5D5CDBBBBBBC4B3B3
AB99998880776E665432324C3C88A2BBBBBBB3ABA2A29999A2A2ABA244E7EFE7E7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DD3C66996E54D5D5
D5D5CDCDD5D5D5CDCDD5CDCDABA291B3CDD5D5D5D5DDD5D5DDD5DDD5D5C4BBBBB3BBBBB3
ABA2A2999999999999888888808899BBBBBBB3A2A2A2A2A299ABABAB775EF7E7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D55ED5CDBBBBCDCD
D5D5CDCDD5D5BBD5D5D5D5CDB3A29991C4CDD5DDDDDDD5D5D5DDDDD5BBBBBBB3BBBBB3B3
ABA2A2A299A2A29999A29999889999BBB3BBB3A2A2A2A2A2A2ABABAB5EBBC4F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFA2CDD5D5D5CDC4CD
CDBBD5D5D5D5D5D5D5D5D5CDBBB3A299B3CDD5DDDDDDDDD5D5D5DDDDCDBBBBB3B3BBB3B3
ABA2A299918891919191889999A299B3BBB3AB99999999A2A2A2A2B319BBF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D5D5D5D5D5DDCDCDD5
CDD5D5D5D5D5D5D5DDD5D5BBC4BBABA299BBCDD5DDD5DDD5D5D5DDD5D5CDBBA2A2ABB3A2
A299999191918891919188919188AB99B3B3AB99999999A2A2ABA2A23280DDF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CDD5D5D5D5C4CDD5D5
BBD5D5D5D5DDDDDDDDDDD5D5BBBBB3A291B3BBD5DDDDDDD5D5D5D5D5CDBBABABABAB9999
99999191889191919191918891A299ABABA2A299999999A2A2A2A2A2194480F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7CDD5D5C4C4B3D5C4D5
CDD5D5D5DDDDDDDDDDDDDDD5BBC4BBABA2A2BBD5D5DDDDD5BBC4CDD5D5C4B3ABABAB88A2
A299888891919199999191918899ABB3ABA2A2A299999999A2A2AB991922BBF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D5D5D5DDCDA2ABD5CDD5
D5D5D5D5DDDDDDDDDDDDDDD5CDC4BBB3A299A2CDDDDDD5D5D5D5D5D5D5D5C4BBB3ABAB99
808888889191919988999199A2B3B3B3A2A2A2A2999999A299A2A2802A6EF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D5D5D5DDB3B3ABBBCDD5
BBD5D5DDDDDDDDE7DDDDDDD5D5CDC4BBB3A2A2C4D5D5DDD5D5DDD5DDD5D5BBBBB3B3A2A2
A291888088919199998899ABABBBB3B3A2ABA2A2A2A299A2A2A2A280223244DDEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7CDD5D5CD99B3BBCDBBD5
D5D5D5DDDDDDDDE7E7DDDDDDD5CDBBC4BBABA2B3BBD5DDD5D5D5DDE7DDD5CDBBB3ABABA2
A2A2A2998088889188A2A2B3B3B3B3B3ABA2A299A2999999A2A2B388442A196ECDEFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CDD5D5CDC48899CDCDBBD5
D5D5D5DDDDE7E7DDDDDDDDD5D5CDD5BBB3B3B3BBCDD5D5CDD5D5DDDDD5D5C4ABA2A2A2A2
A29999999980888899ABABB3BBBBB3BBB3ABABA2A2A2A299A2A2B399885E443C4491F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7C4D5C4B3A299B3CDBBD5D5
D5D5D5DDDDDDDDE7DDDDDDD5D5D5D5BBC4BBBBB3D5D5D5CDC4D5D5D5CDBBBBABA2999999
A299999991808899A2ABB3B3BBB3B3B3ABABABABA2A2A2A2A2A2B3999988804477DDF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D5CDA2916E7799B3C4D5D5D5
D5D5D5DDDDDDDDDDDDD5DDD5D5D5CDBBC4BBCDC4D5D5D5C4BBCDD5D5BBBBB3AB99999991
9191999180888899ABB3B3B3BBBBB3B3ABABA2A2A299A29999B3B39999999999F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BBCD91777788A2ABCDD5D5D5
D5D5D5D5DDE7DDDDDDDDD5D5D5BBCDC4BBC4CDD5D5DDD5D5D5D5D5BBC4BBB3AB99998891
91889188888888A2ABB3BBBBB3B3B3B3B3ABA2A299A2A299A2ABB391919999ABF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D5BBC491917788A2BBCDD5D5D5
DDDDD5DDDDDDDDDDDDD5D5BBD5BBCDBBC4BBCDD5D5DDDDDDD5D5D5CDC4BBB3A299919188
888888919199ABABB3B3BBBBBBBBB3ABABABA2A29999999999A2B388889999B3FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BBCDBBA2918888ABBBCDD5D5D5
DDD5DDDDDDD5DDD5D5D5CDD5CDD5BBC4BBBBBBD5D5D5DDD5D5D5D5D5CDB3ABA299999191
919191A299A2ABABABBBBBB3BBB3B3B3ABA2A2A29999A2999999B3888899A299F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DDBBCDD5A2998888ABC4D5D5D5D5
DDDDDDD5D5D5D5D5CDCDD5D5BBCDC4C4BBBBC4D5D5D5D5D5D5D5D5D5BBBBA2A299999191
91999999A2ABABB3B3BBBBBBB3B3ABABABA299A299999999A299B3A299A2A288C4F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D5B3D5BBAB998088B3C4CDCDD5D5
DDD5DDDDD5D5D5D5CDCDCDBBCDCDBBBBBBCDCDCDD5D5D5D5D5D5D5D5D5BBABA299999191
999999A299A2ABB3BBB3BBB3BBB3ABABABA2A299A299999999B3AB91A2A2B388ABF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFB3A2889966667780BBCDD5D5D5D5
D5DDD5D5D5D5CDD5CDC4BBBBBBBBBBC4CDCDCDCDD5D5D5D5D5D5D5D5CDBBABA299919191
91999999A2ABABBBB3ABB3BBBBB3B3ABABABABA2A299999999A2B3666EA2B38888E7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D5A28888546E545E6EBBD5D5D5D5D5
D5D5D5D5D5D5CDCDC4CDC4BBB3BBBBBBBBCDCDCDCDD5D5D5D5D5D5CDCDBBAB9999918891
91889999A2ABABABB3ABABABABABABABAB99ABA2999999A2A2A2AB6E6691A29999BBF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C491913C99544C446EBBD5D5D5D5D5
D5D5D5D5D5D5D5D5D5D5D5CDBBBBABABABABC4CDCDD5D5D5D5D5D5D5BBB3A28888919191
889999A2ABA2A2ABABB3ABABA2ABABA2A2ABA299A2A2999999ABA277888891A288A2F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFB3916E6E3C545E5E66BBD5D5CDD5D5
CDD5CDC4CDD5D5D5D5D5C4D5D5C4BBBBABA2ABB3CDCDD5D5D5D5D5D5BBBBA29991918888
919999A2A2A2A2A2ABABABAB99A2A2A2ABA2A2A2A299A29999ABA2775E4C3C6E9988F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E791AB6E6E10442A445EBBD5D5CDCDD5
D5D5D5CDB399B3A29188919191998899A299A2ABBBCDD5D5D5D5D5D5BBB3A29191918888
91919191999999A2A2A2B3B3A2ABABABABABA2A2A2A2999999B3A2805E544C548088F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D591AB803C1919223C44C4D5D5D5D5D5
D5CDC4B388804C446680806E6E66806E918888ABBBC4D5D5D5D5D5D5BBB3999991888899
80889999999199999999A2ABABB3ABABABA2A29999A29999A2A2A280665454548099F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C477AB991008222A325EC4D5CDD5CDCD
D5D5D5CDC4B3994480B35E8044104C3C7766544C54B3C4D5D5D5D5D5C4B3A29991889980
8099A2ABABABABABA299999999A2ABB3ABABA2A299999999A2A2A280665454546E99F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFB36EABB32A22222A3C4CCDD5D5CDCDCD
D5D5D5CDCDA2AB91803C2A806E104C4CA299545499BBCDD5D5DDDDD5CDBBA29988806E6E
80A2B3B3B3B3ABA2A2B3B3A299A2A2ABB3ABA2A2A299A29999A2996E5E5E5E668899F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF3CC46E99AB4419222A2A5ECDD5D5CDCDCD
D5D5D5D5D5C4ABABBBB35E3C2A1932325E666E66A2B3CDD5DDDDE7D5CDBBA28880808066
22448891887780666677919199A2A299A2A2A2999199999999999166546666808888FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DD2A2AC4B3C4B34C222A222A5EC4D5CDCDCDCD
D5D5D5D5D5D5CDB3ABABB380664C664C66806EB3B3B3CDD5DDE7E7D5C4BBA2888880806E
6E54ABC4B34C223C4C6E54547780888899919191919199999999884C545466889980F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F73C1919A2C4B3A2543C2A19225ECDCDCDD5D5B3
CDD5CDD5D5D5CDCDB3A2A2B3A288806E806EA299ABBBC4D5DDE7DDCDC4BBA29988808080
666680CD5E80082A4C3C66543C666E666E77889199A299999991804C445E4C99A26EFFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7662A22103C916E4C3C2A22222A6ECDCDD5CDD5BB
88BBCDD5D5DDDDD5CDC4B3B3ABA2A2A29999A2B3BBC4D5D5DDDDDDD5C4BBAB9988808880
806E887744A2084C443C80773C3C445E778091A2A2A2A29999915E4C44324CA2886EF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7FF2A322A1008084C2A223222222A6ECDBBCDCDD5CD
99A2ABCDD5DDDDD5D5CDBBB3A2A2ABA2A299B3B3BBC4C4D5DDDDDDCDBBB3B3A291889999
8899A288884C1919322A4C3C3C5E66998099A29191A29999A29144443C2A3C996E5EF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7E72A2A322219103C2A22191922226EC4CDD5D5CDD5
CD91AB99C4D5DDDDD5D5CDC4ABABB3A2998888ABBBBBCDD5DDDDD5CDBBB3ABA299888891
919180A2A26E6E4C444C325E806E8088889191A29999999999804432442A32A25E6EFFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7912A323C2A2A2A323210192A192A5EC4CDCDD5CDD5
D5BBB3808091918888666E5E545E5E5466666691B3BBCDD5D5D5D5C4BBB3B3A291918888
9991A291A2A2A29191806E806E99919199999999A2A2A2A2995E3C3C2A193C80546EF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A22A22222222222A222219192A2A5EC4CDD5CDD5D5
D5D5CDBB996E77887777665E6E54544C54778099B3BBCDD5D5CDCDC4BBBBB3AB88888080
808891ABA2A291919999809191999999999999999999999988442A2A3C195E805466F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AB321919192219220822192232445EB3C4CDD5D5D5
D5D5D5D5CDA2999988889991888091808091A2BBCDD5D5D5D5CDBBBBC4BBB3AB88805454
546E9991A2A2A2A2A2A2A2A29999A29999A299999999A299803C222A22198880546EF7F7
F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7EFF7F7F7EFF7F7F7F7F7F7F7F7CD32192222222A221022221922445EA2C4CDCDD5D5
D5D5D5DDD5CDCDCDD5D5D5C4BBC4BBC4BBD5CDCDCDD5D5D5CDCDCDBBC4BBBBABA291664C
44446E8091A2A2ABA2A2A2A2A299A2A299A299A299A299A25E2A22221932916E546680F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7DD44221922222222190822222A445E99BBC4CDD5D5
D5DDDDDDDDDDDDDDDDE7DDDDDDDDDDDDDDD5D5D5CDD5DDD5CDCDCDC4C4C4BBB3BBBBA280
545444323C4C77A2A2A2A2A2A29999919188889199A29988442222193C2A66804C774CCD
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7323C2A22222222220822222A445E99ABBBCDD5D5
D5D5DDD5DDE7E7DDE7E7DDE7E7E7E7DDDDDDDDD5DDD5D5CDBBBBCDC4BBC4BBBBBBBBB3B3
A28054543C323C3C5488998891918877666680A2999999802A22222222194466806E5488
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F744443222222222221910223C445E91A2C4CDD5D5
D5D5DDDDDDDDE7E7E7DDE7E7DDDDE7E7DDE7DDD5D5D5D5CDD5D5C4C4BBC4C4BBC4BBBBBB
B3AB99806E54443C3C4C54666654666E668099A29999916E2A1922222A19192A2A3254A2
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F744443C2A222A222222082A2A445E88A2B3CDD5D5
D5DDD5DDD5DDDDDDE7E7E7E7E7E7E7DDDDDDDDD5D5D5CDCDCDCDC4C4C4BBC4BBC4C4BBB3
BBB3B3A299806E5444444C4C4C4C546E80999999999188542222222222190010323C5EFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D54C444C32222A2222222A2A3C445E8099B3BBD5D5
D5D5D5D5DDDDDDE7E7DDE7E7E7E7E7E7DDE7DDD5DDD5D5D5D5C4C4C4C4BBBBC4C4C4BBB3
BBABB3B3A2A2999188776E666E6E8899999988999991883C2A22222A2222192A2A2A5488
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B3444C443C322A22222222222A3C446E91ABC4CDD5
D5D5DDD5DDDDE7DDE7E7E7E7E7E7E7E7DDDDDDD5D5D5CDCDCDC4C4BBBBC4BBCDBBC4BBB3
B3B3B3B3ABA2A2999991918888999999999988999988802A2A2222222A221919222A2A4C
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78844443C32322A222219322A223C3C5E80A2BBCDD5
D5D5D5DDDDDDE7DDDDDDE7E7E7E7E7E7DDDDDDDDD5CDD5D5CDCDBBC4C4BBC4BBBBBBBBBB
B3BBABB3ABB3A2B3ABABA2A2A29999A29999999991885E2A2A2222222A22222222193C4C
ABF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7663C4C4C4432322A22222222222A3C445E88BBC4CD
D5D5D5D5DDDDDDDDDDE7E7E7E7E7E7E7DDDDDDD5CDD5D5CDC4C4C4BBBBC4C4BBBBB3B3B3
BBBBABB3B3ABB3ABABA2A2999999A2A299999999886E4432222219321019192222102A3C
99F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F74C3C444C44323C2A221922222A223C44446EA2C4CD
D5D5D5D5DDDDE7E7E7E7DDE7E7E7DDE7DDDDDDD5D5D5D5C4C4BBC4BBBBBBBBC4BBB3BBBB
B3B3ABB3ABABB3A2A2A2A2A2A2A2999999999991805E3C2219192A101910191908192A3C
80FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFF7F7F7F7F744444C4C44443C2A222A1919222A2A4C5E4C91ABCD
D5D5D5D5DDDDDDE7E7E7E7E7E7E7DDE7DDDDDDDDD5D5BBCDCDBBBBBBBBBBBBBBB3BBB3B3
ABB3B3B3ABABABABA2A2A2A2A2A2A299A29991886E442A22222A2219191919191922223C
6EF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFF7F7F7EFF75E444C444C443232222A19222232324C5E5E80ABC4
CDD5D5DDD5DDDDE7E7E7E7E7E7E7DDE7DDDDDDD5D5D5CDCDC4BBBBBBBBBBBBB3BBB3B3B3
B3ABABABABABABA2ABA2A2A2A2999999999191805E3C2A22322A10101910081019222232
77F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7443C4444444C3C3C2A2A2A222A2A223C446680A2BB
C4D5D5D5D5D5DDE7E7E7DDE7E7E7DDE7DDDDD5D5CDBBD5CDBBBBBBB3B3BBBBB3B3B3BBB3
ABABABABA2A2ABA2A2A2A299A29999999191886E44443C3222221919101008101922193C
E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F74C4C444C4C4C4C442A2A2A192A2A32444C668088B3
C4D5D5DDD5DDD5DDDDE7E7E7E7DDE7E7DDDDDDD5D5D5D5BBC4BBBBB3B3B3B3BBB3ABABAB
ABABABABABA2A2A2A2A2A2999199999988886E6E443C2A19191919101008191019222A54
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7EF4444444C444C54323C2A222A2A323C444C5E7788A2
BBCDD5D5D5D5DDDDE7DDDDE7E7E7E7DDDDDDDDD5D5CDC4C4C4BBBBB3B3BBB3BBB3B3B3AB
A2ABABA2ABA299A29999A299A299999988806E543C2A2219221919101019101919192A4C
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFF7E744443C444C4C4C44442222322A323C3C44667788A2
BBCDD5D5D5D5DDE7DDE7E7DDE7E7E7DDDDD5DDD5CDBBCDBBBBBBBBBBBBBBB3B3B3B3ABB3
B3ABABA29999A2A2A299A29999999991806E6E443C2A2A22222A22222219191922222A5E
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFF7F7F7F7E74C4C2A444C4C544C442A222A322A32445E6E6E7791
ABC4CDD5D5D5D5DDE7DDE7DDDDDDDDDDD5D5D5D5CDC4C4C4BBB3B3B3B3B3ABB3B3B3ABAB
ABB3AB99A299A2A29999999999919188805E5E442A2A22222A2A19102222191010223CE7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF75E3C3C444C44544C3C442232323C323C5E6E4C6E80
A2C4CDCDD5D5D5DDDDDDDDDDDDDDDDD5D5D5CDD5C4C4CDBBBBBBB3B3B3B3B3B3B3B3B3AB
ABABABABA2A2A29999999999999988806E5E443C2A2A22221922191910100808102244F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFF7F7EFF7F76E443C44445E4C4C44442A223C3C4432444C5E6677
99C4C4D5D5D5D5D5DDD5DDDDD5D5DDD5D5D5D5CDCDCDC4BBB3B3ABB3ABB3ABABABB3ABAB
ABAB999999A299A2A2999999918880665444443C222222222219191019080810192A6EF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7774C3C3C3C4C444C3C3C4C2A223C32443C5E444C80
88B3CDCDD5D5D5D5D5D5D5D5D5D5D5CDD5D5D5BBC4C4BBBBABB3ABB3ABB3B3B3B3B3A2AB
ABABA2A2A2A2A2A29999919188806E54443C3C2A2222222222221919100810192A44FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7775E3C3C443C4C5E32443C192A223C4C3244444466
77A2B3C4D5D5D5CDD5D5D5D5D5D5D5CDCDCDBBC4C4C4B3B3ABB3B3B3B3B3ABABABA2ABA2
A2A299A2A2A299A2A2918888806E544C442A2A221919222222222219221008223C44F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7996E44444C444C4C443C3C3C22323244443C4C4C5E
6E91A2B3CDC4CDCDD5D5D5D5D5D5CDCDCDC4D5C4BBBBABB3B3ABA2ABABA2ABA2ABA2A299
A2A299A2A299A2A291999180806E4C443C2A22221919191922221910080810322A66F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BB6E4C3C4C44444C5E324C32322A323C4C444C445E
5488A2B3BBC4C4C4D5D5D5CDD5BBCDC4CDC4C4BBBBB3B3ABA2ABA299A2A299B3A2A2A2A2
999999A2A299999991918880665444442A2A22191010101919080808080819323C99F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F76E4C4C444C3C445444442A2A322A3C3C4C3C3C44
44668091A2B3B3BBC4CDC4CDCDCDCDC4C4BBC4C4BB99A299A2A2A29999A2A299A299A299
999999999191918888776E6E66443C2A222A2219191910101008080808102A3232F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7FF805E4C444C444454443C32222A2A2A444C4C3C2A
4444546E888891A2B3B3C4C4BBC4BBBBC4B3C4BBBBAB999999A2999999A2999999999999
9999888899918880806E6E544C443C2A22221910081010101008080808192A326EF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BB664C3C4C444444543C3C2A2A224C3C3C4C4C4C
32445E5E5E777791AB91A2ABB3ABB3B3B3ABBBABA2918080809188889988999188889999
99919188888880808066544C3C3C2A2222081910101010100808080810322222E7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF6E5E443C4C3C444C442A3C2A2A3232544C4C44
4C545E666E666E778880808888808891A288A291806E6E666E6E80808880888891888888
888880888077776E5E4C4C443C2A22222210191008080808080808102A2A225EFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F788664C3C4C4444444C3C2A2A2A3C44444C5454
4C5E4454545E5E6E666E6E6E6E6E6E6E88A288806E66665E5E5E6E6E6E80808088808080
6E776E80776E6E66544C3C2A2A2A222219191010080808080808082A22222AD5F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CD774C44444C4C3C5E3C2A2A2A323C544C5E4C
445E665E545E6E5E665E5E5E5E5466546E6E806E6E665E4C4C544C5E666E6E6E77776E6E
6E6E666E6666664C4C443C2A2A2219221010081008080808080810222A2232F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7994C44444C3C4C4C443222323C4C54545454
5E445E6E665E66665E444C4C445E444C4C5E5E664C5E4C4C4C444C4C4C54666666665E5E
6654545E5E544C5E442A2A2A3222191919101008080808080808222A193288F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D56E4C44444C3C4C544432324C445E5E4C66
54444C5E5E665E5E4C443C4C3C444C3C4C445E444454442A3C3C3C3C3C3C443C3C444444
443C3C3C3C3C3C3C322A2222221910101919101008080808102222193244FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DD804C44444C4444444C443C4C5E54665E5E
4C444C44445E4C44443C443C3232443C2A4C4444443C3C3C2A32322A2A2A2A3C3C3C3C3C
3C322A3C2A322A2A2A3222221922101010101008080808082222222A44C4F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AB774C4C3C4C3C4C445E4C3C4C6E4C5E5E
5E5E545E4C444C444C3244443C3C444C443244443C322A322A22222A2A22222A222A322A
2A2A2A222A222A222A222222192210081008080808080822222A192A80F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C4A24C444C444C4C44445E5E6E3C54544C
3C324C4C5E3C4C444444443C3C444C3C2A2A3C2A2A2A2A222222222222222A222A222222
222A22222A2222192222190819191008100808100808102232192A80F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFBB6E4C444C44323C4C32545E5E5E3C3C
5E6E5E44443C3C3C323244442A22223C2A222A222A222222192219222222221922222A22
19222219221922191922192210101008080808081022222222225EE7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CDBB44444C4C4C3C444C3C44545E5E54
4C4C3C4C443232443C2A3C3C2A223C442A222A222222222222191919221922192222192A
1019191922221919102219191910101008081019221932222A4CF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CD66443C4C4C4C444C445E4C44445E
5E6E44323C2A2A3C3C2A44323C2A3C2A22222219192A2219191910101022221910222219
2219102210221910191008100808100808081019193C2A2A44E7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F77766443C4C3C443C4C3C4C5E4C44
3C4C3244322A22223C2A2A2A2A192219222A192210191922191010101910102219101019
191922081910101008100808080808081919192210221966E7E7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DD8066444C444C4C4444443C444C
443C2A44322A22222A2A22222A32192A2219221919192222101010191010102222101010
1919102219191008080808080810192219102219222A4C99E7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B3775E3C4C444C4C5E4C4C5454
443C2A4C32222222222A2222223C102A102219101910101919101010191910192A190810
1919221019100808080808101922191919222A223C446EDDF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AB6E4C444C3C4C3C4C4C4C44
3C3C224C2A2A19221922221919191019191019101910191019101010101910192A2A2A10
101919192219222222222219221910192A22223C3C666EF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BB6E544C4C3C4C5454545E
544C3C443C222219191022191919221022101910101010101022100810102219193C4C44
4C1922191019191922222219193C3C22323C2A44546EF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F76E77544C4C3C444C5454
54443C543C2A2A221019222219101910221919081919101910191010081010322A224C5E
22222A2A3C22222219222A2A3C2A2A322A3C3C4C66EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF6E6E5E544C3C444C54
5E4C54443C3C32222210192210191922192210191019191010101910101010084C32322A
5E5E5E44444454443C2A22223232323C4C444C5EEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F788664C4C4C3C444C
545E665E3C3C3C322A191922221919191022101010101910101019190810221910223244
4C3C2219222A323C3C3C3C4C4444443C3C446677F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F75E545E444C54
5E5E5E6E5E323232322A44223C2A22222210191019191019102222191919222A19223C22
4444192222222222192A223C322A3C4C6654CDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A26E4C4C4C4C
545E6E806E4C2A32322A2A323C3C3C2222222A1919192222191932222A2222224C2A2A2A
22223C3C2A3C3C322A443C2A3C4444545ECDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C46E4C3C44
4C5E6E6E776E5E3C322A2A2A2A44443C3C541922102A2A222A323C3C2A6E4C5422445E4C
44444444443C3C44444C5E4C444C6E5EEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7806654
4C5E77778880776E4C5E66443C1944445444444C3C22195E444C5E6E44444C5E5E54544C
4C5E4C544C4C4C4C3C3C445E5E4480FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C477
5E5E4C54546E6E776E776E6E775E444C4C5E665E774C44224432444C66544C4C444C545E
4C4C444444444C4C5E546E5E44B3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
A25E545E546E80776E6E666E776E6E6E545E546E5E5E6E4432322A323C5E4C4C4C3C3C3C
3C3C3C444C5E5E54545E4444C4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7BB6E5E5E5E5E6E8877807777667777807777776E8054775E4C44443C3C445E54444C4C
4C4C545E5E6E6E6E4C4480FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7DD5E3C4C546E916E888088776E77807777776E80777766666E6E5E66665E666E
6E7780806E4C445EBBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7DD9977779191B39999998080775E7780808080807777806E6E6E77778080
6E666E4C4C6EB3FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7DDE7C4B3B3B3919180776E7766777777806E6E6E6E6E6E6E66
5E665E7799FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7E7DDE7EFE7C4BB88918880777777777780776E6E6E5E54
6691EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7EFDDD5BBCDC4E7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -14 0 ]
[.5 1.0125 14 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Blue) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7CEB5BDBDBDC6C6CECEC6CECECECECECECECEC6C6C6BDB5B5ADADAD
9CA59C9C949494949494949494948C8C84848C8C84848CF7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7
EFF7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7DEB5BDBDC6C6C6C6CEC6CECECEC6CECECEC6C6C6B5B5ADADA5A5A5
A59C94949494948C9494948C948C8C8C8C8C8C848C848CF7F7F7F7F7F7F7EFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7DEBDBDC6BDBDCECEC6C6CECEC6CEC6BDC6B5B5B5ADADADA5A59C9C
9494948C8C8C9494948C94948C8C8C8C8C8C8C8C8484BDF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7CEB5BDBDC6C6CEC6C6CEC6C6C6C6BDB5BDB5B5B5B5A5A5A59C9C9C
9C949494948C8C8C8C8C948C8C8C8C8C8C8C8C8C8484EFF7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7EFF7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7
F7F7F7EFEFF7F7F7F7F7F7F7F7F7EFEFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7CEB5BDBDBDC6C6C6C6CEBDC6C6C6C6B5BDB5A5A59C9C9C949C9C9C
9C9C9CA5948C8C8C8C8C8C8C8C8C84948C8C8C8C8C9CF7F7F7F7F7F7F7F7F7F7F7F7F7EF
EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7C6BDBDC6BDC6CEC6C6C6C6C6C6C6BDC6B5B5B5ADADA59C9C9C8C8C
8C94949C8CA58C8C8C8C8C948C8C8C8C8C8C8C8C8CBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7C6B5BDC6BDC6C6C6C6C6C6C6B5BDB5C6BDC6BDB5B5B5AD9C9C948C
9CA59C9C8C8C8CA58C8C8C848C848C8C948C8C8C8CDEF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7BDBDC6C6C6C6C6B5BDC6C6B5B5B5C6C6C6C6C6B5BDB5ADADA5A5A5
9CA5ADA59C8C8C8C8C8C8C948C8C8C8C8C848C8C8CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7B5BDBDBDC6BDBDC6B5C6C6C6C6C6C6CECECEC6C6C6B5ADADADA5A5
A5A59CA5A59C8C948C8CA5948C948C8C8C8C8C8C9CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7B5BDBDBDBDB5C6B5C6C6C6C6C6CECECECEC6C6CECECEB5ADADB5AD
ADADA5A5A59C9C8C8C94949C9C8C94948C948C94B5F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7B5BDBDBDB5C6B5BDC6C6C6C6CECECEC6C6C6CECECEC6C6BDBDADB5
ADA5A5A59C9C9C94948C8C94A5948C8C8C8C8C94CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7C6BDBDBDB5B5C6C6C6C6C6BDCECECECEC6C6CECECECEC6C6C6BDB5B5
B5A5A59CA594949C948C8C8C8C8C9C8C8C948C94E7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7E7A5B5BDB5C6C6BDC6BDC6C6C6CECEC6CECEC6CECECECEC6CEC6BDB5B5
ADADA5A5A59C9C8C94948C8C8C9C8CA58C948C94E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EF
F7F7F7F7F7F7F7F7F7F7EFF7EFF7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F75AADBDCEC6C6C6C6C6C6C6C6C6C6CEC6C6C6C6C6CEC6CEBDC6C6C6BDBD
ADADA5A5A59C94949494948C8C948C8C9C949494F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F76342B5C6BDC6C6CEC6C6C6C6C6C6CEC6C6C6BDBDCEC6C6BDC6C6BDB5BDAD
ADA5A5A5A59C94948C9494948C8C8C949CA59494F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFF7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F74A2952C6C6C6C6C6CEC6CECECEC6C6C6CEC6C6C6C6CECEC6BDB5ADB5B5ADAD
A5A5A59CA59C9494949C8C8C848C8C8C948CAD94F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7EFEFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7CE4229CEC6BDBDC6CECEC6C6CECEC6C6C6C6CECECEC6C6C6BDBDB5ADA5A59CA5
A5A5A5A5A59C94949494948C84848C848C8C8CBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7EF3939C6B5C6C6C6C6C6CEC6C6C6C6C6C6C6C6C6CECECECEC6C6BDB5A5ADA5A59C
A5A5A59C9C94949494948C8C8C8C84848494949CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FF5A31C6B5BDBDC6C6C6C6C6C6C6C6C6C6C6C6C6C6CECECEC6BDB5ADADA5A59C9C9C
9C9C9C94949494948C8C8C8C8C848C8C8C8C9494CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F773428CB5C6C6C6C6C6C6C6C6C6BDBDBDC6BDC6C6CECEC6C6C6BDB5B5A59C9C9C9C94
9C9494948C8C8C8C8C8C8C8C8C848C84848C948C8CCEF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F73163CEC6C6BDBDC6C6CEC6C6C6BDBDBDC6C6C6CECEC6C6CEC6B58CB58C7B7B7B7B7B
7B8494948C8C8C8C8484848C8C8C8C8C848C848C8C8CF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7B531CEC6BDC6C6BDC6C6C6C6C6C6BDB5BDBDC6C6C6C6C6CECEB5B5B58C8C7B7B7B8C7B
7B7B7B7B8C8C8C8C84848C8C8C8C8C8C848C8C8C8C9CADF7F7F7F7F7F7F7F7F7F7F7F7EF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
C631CEBDC6C6C6C6BDCEC6C6C6BDB5B5B5BDB5C6C6C6C6B5B5D6B5B58C7B736B5A5A7B6B
6B6B7B7B7B7B84848484848C8C8C8C948C8C848C948C94EFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EF
5A63B5BDBDC6BDB5C6C6C6C6C6BDB5A5B5ADB5C6CEC6B5B5B5B5A584635A5A5A5A5A5A63
5A5A5A6B7B6B848C84848484848C8C948C8C8C8C8C8C94ADEFF7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78C
39CEB5BDBDBDBDBDBDC6C6C6BDBDADA5A5A5BDC6C6B5ADAD8C84737B8C9C52B59C5A9C6B
524A525A6B6B7B7B8C847384848C8C8C8C948C8C8C8C949CDEEFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BD4A
29C6BDBDC6BDBDADC6CEC6CEB5B5AD9494A5C6C6AD8C94735239A59CC6C6B5B5AD9CBDB5
528C4A4A63636B7B7B848484848C9494948C848C8C8C948C9CEFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EF9C39
84BDBDC6C6BDADA5CEC6C6BDADAD948484BDB57B7B63186B9C5A846BA5E7DECE6B84735A
639C84524A4A52737B847373848C949C94948C8C948C8C9494C6DEF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD8C29
CEBDC6BDBDB5A5A5C6C6C6C6AD9C8C738CA55A294AADCEDEDEEFEFDEE7EFDECEB5CECECE
C6395A6B6B39425263847373848C9CA59C948C948C94949494B5F7D6E7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7EFEFF7F7EFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7734242
B5BDC6BDBDB5A5BDC6C6C6C6AD8C736373392142BDCEDEDEDEE7EFDEE7EFDEDEB5E7DECE
CEA5A5424A21294252738473848C9CA59C9C948C8C948C9494A5E7EFE7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFF7EFEFF7F7F7F7F7F7F7F7F7E7F7EFEFEFEFEFF7843984
BDC6C6BDBDADA5BDC6C6CEBD9C8C6B6B2918215A9CDEC6E7BDDEEFC6DEEFDEC69CE7DECE
C6C6C6CE396B0808394A7B84848C94A5A59C94948C948C948C9CB5CED6EFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7E73129C6
B5BDBDBDBDADBDA5C6C6C6BD8C84637B423118738473A5BDA5CEDE94BDDEBD949CA5CEC6
94B5C6B58CA58C8C31315284848C94A5ADA59C8C948C848C8C94B594B5BDE7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CE312142C6
BDBDBDBDADA5B5A5C6C6C6B5846B73949C946B5A7373739C848C8C8CA5B5636B6B848C94
638CB59C9CA58C8C5A183173848C9CA5ADA59C8C8C8C848C8C9CA5E7D6C6CEEFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EF6321291884C6
BDBDBDADADADAD94BDC6BDB58C639CA5B5C6BDBDB5ADA5A59CA59C9C8C8C8C846B6B5A5A
63639C6B73AD848C6B1010397B8494A5ADA594948C848C8C94949CF7EFD6D6E7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7D621183118C6B5
BDBDBDADADB5ADADBDC6BDAD946394ADCEC6CECEC6CEC6CECECECEB5B5B5ADADA59C7B6B
7B6B63525273525A31101039398494A5A5A59C8C8C8C84848C8C9C7B9CE7E7D6E7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D68C18292121C6B5
BDB5B5B5B5B5B5B5BDB5B5AD94846BADC6CECEC6C6CEC6C6CECEC6C6BDB5A5A5A5AD949C
948C847B7B6B635242292939317B8CA5A5A594948C8484848C8C949C39DEEFE7E7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E739528C5A4AC6BD
BDBDB5B5BDBDBDB5B5BDB5B5948C739CB5C6C6C6C6CEC6C6CEC6CEC6BDADA5A59CA5A59C
948C8C848484848C847B736B636B84A5A5A59C8C8C8C848C849494AD7352F7E7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E752BDB5A5A5B5B5
BDBDB5B5BDBDB5C6BDBDBDB59C8C8473ADB5C6CECECEC6C6C6CECEC6B5A5A594A5A59C9C
948C848C8484848484848484848473A59CA5948C8C8484848C9494A55AC6BDF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EF9CB5C6BDC6B5C6B5
B5B5BDC6C6C6BDC6BDBDBDB5A59C8C8494B5BDCECECECEC6C6C6CECEB5A5A5949CA59494
948C84847B6B7B737B7B7B8473848494A59C9484848473848C8C8CAD21B5F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7BDBDC6BDCEB5B5BD
B5BDBDBDC6C6C6C6CEC6C6B5ADA5948C84A5B5C6CEC6CEC6C6BDCEC6BDB5A58C8C94948C
8484847B737B737373737373737B94739C9494848484848484948C9C3184EFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDC6BDBDADB5BDBD
B5BDBDC6C6CECECECECEC6BDB5A59C8C7394A5C6CECECEC6C6C6BDC6B5AD949C9C948484
7373737B7373737B7B73736B73848494948C8C84848484848C8C8C9C184284F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7B5BDC6ADAD94BDC6BD
B5BDC6C6CECECECECECECEBDB5ADA5948C8CA5C6C6CECEC6B5ADB5BDBDAD9C9494947384
8C847373737B7B73737373736B849494948C8C8C848484848C8C948C2131B5F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BDC6BDCEB58C94BDB5BD
BDBDC6C6CECECECECECECEC6B5ADA5948C848CB5CECEC6BDC6BDBDBDC6BDADA59C949484
6B736B737B737B737B7373738C9C94948C8C8C8C8484848C848C8C84317BF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BDBDC6CE9C9C94B5B5BD
B5BDC6CECECECEDECECECEC6BDB5ADA5948C8CADC6C6CEC6C6CEC6CEC6BDADAD9C9C8C8C
8C7B736B73737B73847B849494A59C9C8C948C8C8C84848C848C8C6B213142EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DEB5BDC6B58494A5B5B5BD
BDBDC6CECECECEDEDECECECEBDB5B5ADA5948C9CB5C6CEC6C6C6CEDECEC6B5A59C9C948C
8C8C8C846B736B737B8C8C9C9C9C9C9C948C8C848C848484848C9C733929186BD6EFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5BDC6B5AD6B8CB5B5B5BD
BDBDC6CECEDEDECECECECEC6C6B5BDB59C9C94ADB5C6C6B5BDC6CECEC6BDAD948C8C8C8C
8C84848C736B737B84949C9CA5A59CA59C94948C8C8C8C848C8C9C73634A39394294F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7ADBDAD948C849CB5B5BDBD
BDC6BDCECECECEDECECECEC6BDBDBDB5ADA5A59CC6C6C6B5ADBDC6C6B5B5A5948C8C8C84
8C84848473636B738C9C9C9CA59C9C9C949494948C8C848C8C8C9C8473736B4273E7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6B58C73636B849CB5BDBDBD
BDC6C6CECECECECECEC6CEC6C6BDB5B5ADADB5ADBDC6BDADADB5BDBDB5A594948484847B
7B7B73736B63738C949C9C9CA5A59C9C94948C8C8C848484849C9C848484848CF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5B5846B6B6B8C9CB5BDC6BD
C6C6C6C6CEDECECECECEC6C6BDB5B5ADADADB5C6C6CEC6BDC6C6BDB5ADA59C948484737B
7373736B6B6B7B8C949CA5A59CA59C9C94948C8C848C8C848C94A573737373A5F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEB5AD84736B738CA5B5BDC6BD
CECEC6CECECECECECEC6C6B5BDB5B5ADADB5B5C6C6CECECEC6C6C6B5ADA59C8C847B7B73
7373737B7B8494949C9CA5A5A5A59C9494948C8C8C8C8C84848CA56B6B84849CFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5B5B58C84737394ADB5C6BDC6
CEC6CECECEC6CEC6C6BDB5BDB5BDB5ADA5A5ADC6C6C6CEC6C6C6C6BDB59C948C84847B73
7B7B7B84848C949C9CA5A59CA59C9C9C948C8C8C8C848C84848CA57B7B738C84F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEA5B5C68C846B7394ADBDC6C6C6
CECECEC6C6C6C6BDB5B5BDBDB5B5ADADA5ADADBDC6C6BDC6C6C6C6BDB5A58C8C84847B7B
7B8484848494949C9CA5A5A59C9C9494948C848C8484848C848CA58C84848C7BC6F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BD94BDA59C846B739CADB5B5BDC6
CEC6CECEC6BDBDBDB5B5B5A5B5B5ADA5A5B5B5B5C6BDBDBDC6C6C6C6BDA5948C84847B7B
8484848C848C9C9CA59CA59CA594949C948C8C84848C8484849C9C73848C9C7394F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EF948C738C5252636BA5B5BDC6C6C6
C6CEC6C6BDBDB5BDB5ADADADA5ADADADB5B5B5B5BDC6C6BDC6C6C6BDB5AD948C847B7B7B
7B8484848C949CA59C949CA5A59C9C949494948C8C8C84848C8CA55252849C7373E7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BD8C7B73425A4A4A63A5BDC6C6BDC6
C6C6C6BDC6C6B5B5ADB5ADAD9CA5A5A5ADB5B5B5B5C6C6BDBDC6C6B5B5A59473847B737B
73848C848C94949C9C9494949C949494948C948C8C84848C8C8CA55A527B8C8473B5F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD737B29844A42425AA5BDC6C6C6C6
BDC6BDC6C6CEC6C6C6C6C6B5ADA59C9C949CADB5B5BDC6BDC6C6BDBDAD9C8C7B8473737B
7373848C948C8C94949C9C948C94948C8C948C8C8C8484848CA58C63636B738C7B8CF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EF94845A5A314252525AA5BDC6B5C6BD
B5BDB5B5B5C6C6C6C6C6BDC6C6B5A5A5948C949CB5B5C6C6C6C6BDBDA5A58C847B7B7373
7B848C848C8C8C8C949494948C8C8C8C948C8C8C848484848CA58C634A3931527373F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DE739C5A5A1039294252A5BDBDB5B5C6
C6BDBDB59C849C847B847B84848C848C8C8C8C94A5B5C6C6C6C6C6BDAD9C8C7B73736B73
7B7B7B7B848C848C8C8C9C9C8C94949494948C8C8C8484848C9C8C6B4A423942637BF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BD739C6B311818213142ADC6BDBDBDBD
C6B5AD9C736B3942526B6B5A63526B5A7B7B7394A5ADBDC6C6C6C6BDAD9C84737B6B7373
6B73848C847B848484848C94949C949C948C8C8C848C84848C8C8C6B524242426384F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD6B9C8C101021293152ADC6B5BDB5B5
BDBDBDB5AD9C84396BBD5A6B42183929635242394294ADC6C6C6C6BDAD9C8C7373737363
6B848C94949494948C8C8C848484949C94948C8C848484848C8C8C6B524242425A84F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF9C5294A529213129314AB5BDC6B5B5B5
BDC6BDB5B58C947B7B39218494184A399C9C424273A5B5C6C6CECEC6B5A58C736B6B5A5A
63849C9C9C9C948C8C9C9C8C8C848C949C948C8484848484848C84634A4A4A526B84F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF29AD528494422121292952B5BDBDB5B5B5
BDC6BDBDC6AD9494AD9C5231291829295A525A528C9CB5BDCECEDEC6B5A58C7B6B636352
1839737B63636B5252637B84848484848C8C8C847B8484848C8C7B524A5252637B7BFFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E72921AD9CAD9C422129212952ADBDB5B5B5B5
C6C6C6C6BDBDB59C9494A56B524A524252635A949494B5BDCEDEDEC6ADA58C7B6B636B5A
5242ADBDBD39182942635242636B7373737B7B7B7B7B84848C8473424A4A52737363F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F73118188CAD9C8C4A3939182152B5B5B5BDBD9C
B5BDB5C6C6BDB5B59C8C8C9C8C73635A635A848494A5ADBDCEDECEB5ADA58C736B636B63
52527BD65A7B103942315A4A3152635252636B7B84848484847B6B42395242848C52FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F75A29211029735A39393121212963B5B5BDB5C6A5
73A5B5C6C6CECEC6B5AD9C9C948C848484848C94A5ADBDC6CECECEBDADA5948473636B6B
635A736342AD105242317B7339314252636373848C8C8C84847B524A3931398C6B52F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7FF292929100808422931312121295AB5B5B5B5C6B5
8C8C94B5C6CECEC6C6B5AD9C8C8C948C8C849494A5ADADC6CECECEB5AD9C9C8C736B7373
6B738C73734A211829294A39395252736B7384737B8C8484847B42393129318C5A4AF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7E72129292118103931212121212163ADB5BDBDB5C6
B57B948CADCECECECEC6B5AD94949C8C73737394A5A5B5C6CECEC6B5A59C948C846B6B73
7B73638C8C5A6342423931526B5A6B7373737B8C84848484846B39314229298C4A52FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A52931312929293131181829182952ADB5B5BDB5BD
C6AD9C7B6B7B7B73735263524A4A4A425252527B9CA5B5C6C6BDBDADA59C9C8C7B736B6B
737B84738C848C7B7B6B5A6B5A737B7B73848484848C8C84845231392918316B4252F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A52921212121212921211821292952ADB5BDB5BDBD
BDC6B5AD8C6B73846B6B52525A524A394A636B849CB5B5C6C6B5B5ADA5A59C9484736363
63737B948C847B7373736B737B8473848C848484848484847342313939184A6B4252F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BD29181818211821102118213142529CADB5BDBDBD
C6C6C6BDB58C8C8C84848C84737B7B6B6B7B8CADB5BDC6C6C6B5B5A5ADA59C94846B4242
425A737B848C848C8C8484848484848C848C8C84848C84846B312131211873634252F7F7
F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7EFF7F7F7EFF7F7F7F7F7F7F7F7DE31182121212921182121212142528CADB5B5BDBD
C6C6C6CEC6B5B5B5C6C6C6BDB5BDB5C6B5C6B5B5B5C6C6C6B5B5B5ADADADA59C8C7B5242
39395A6B738C8C948C8C8C848C848C8C848C8484848C8484522921312131735A425284F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EF392118212121211810212129425284A5ADB5BDBD
C6CECECECECECECECEDECECECECECECECEC6BDBDB5C6CEBDB5B5B5ADADADA5A5A5AD8C6B
524A3929314263848C8C84848484847B7B73737B8C8C8473392121213929526B39634AD6
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F731312921212121211021212939528494A5B5BDBD
C6C6CEC6CEDEDECEDEDECEDEDEDEDECECECECEC6CEC6C6B5B5B5B5ADA5ADA5A5ADA5A5A5
8C6B524A312931314A7373737B7B736352526B8C848C846B2921212131183952635A528C
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F742423121212121211818213142527B8CADB5BDBD
C6C6CECECECEDEDEDECEDEDECECEDEDECEDECEC6BDC6BDB5BDBDADADA5ADADADADADADA5
A5948C6B634A393131424A525A4A525A526B8C8C84847B5A2918213131181829212952A5
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7393931292129212121102929425273849CB5BDC6
BDCEC6CEC6CECECEDEDEDEDEDEDEDECECECECEC6C6C6B5B5B5B5ADADADADADADADADA59C
A59C9C8C846B6352393939394242525A6B848C84847B734A2121212121180010293952FF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E74A394A31212921212131313942526B8C9CA5BDBD
BDC6C6C6CECECEDEDECEDEDEDEDEDEDECEDECEC6CEBDBDBDBDADADADADA5A5ADADADADA5
A59C9C9C8C8C847B73635A525A5A738484848484847B733129212129212118292929528C
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5394A393131292121212121293142637B94ADB5BD
BDC6CEC6CECEDECEDEDEDEDEDEDEDEDECECECEC6BDBDB5B5B5ADADA5A5ADADB5A5ADAD9C
9C9C9C9C948C8C8C8C7B7B84738484848484847384736B2929212121312121182129314A
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78C3939313131312121183129213131526B8CA5B5BD
BDC6C6CECECEDECECECEDEDEDEDEDEDECECECECEBDB5C6BDB5B5A5ADADA5ADA5A5A5A5A5
9CA5949C949C8C9C94948C8C8C8484848C8484847B734A2929212121292121212118314A
ADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFF7F75A314A4A4231312921212121212931395273A5ADB5
C6C6C6C6CECECECECEDEDEDEDEDEDEDECECECEBDB5BDBDB5ADADADA5A5ADADA5A5A59C9C
A5A59C9C9C949C94948C8C8C848C8C8C8C848484735A3931212121311821212121183131
8CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F74A31424A423139292118212129213139425284ADB5
BDC6C6C6CECEDEDEDEDECEDEDEDECEDECECECEC6BDBDBDADADA5ADA5A5A5A5ADA59CA5A5
9C9C949C94949C8C8C8C8C8C8C8C84848484847B6B523921182131182118181810182931
7BFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFF7F7F7F7F742424A4A39423929212918182129294A52427B94B5
BDC6C6C6CECECEDEDEDEDEDEDEDECEDECECECECEC6C6B5B5B5ADA5A5A5A5A5A59CA59C9C
94949C9C949494948C8C8C848C8C84848C847B735A392921212921212118181818212131
63F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFF7F7F7EFF752394A424A423131212918212131314A52526B94AD
B5BDC6CEC6CECEDEDEDEDEDEDEDECEDECECECEC6C6BDB5B5ADA5A5A5A5A5A594A5A59C9C
9C9494949494948C948C8C8C8C848484847B7B6B52312921312918182118101821212131
73F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F739313942424A39392929292129292131425A6B84A5
ADBDC6C6C6C6CEDEDEDECEDEDEDECEDECECEC6C6B5B5BDB5ADA5A59C9CA5A59CA59CA59C
949494948C8C948C8C848C848C8484847B73736342423131212121181818101818211831
E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F74A4A394A4A4A4A42292929182929313942526B6B9C
ADBDBDCEC6CEC6CECEDEDEDEDECEDEDECECECEC6C6BDBDA5ADA5A59C9C9CA5A59C949494
9C9C9494948C8C8C8C8C8C8C7B8484847373636339392918181821181810181821212952
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7EF4242424A424A523139292129293131424A5263738C
A5B5C6C6C6C6CECEDECECEDEDEDEDECECECECEC6BDB5ADADADA5A59C9CA59CA59C9C9C94
8C94948C948C8C8C84848C8484848484736B634A3129212131212118182118181818294A
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFF7E7424231424A4A4A424221213129313139395263738C
A5B5BDBDC6C6CEDECEDEDECEDEDEDECECEC6CEC6B5B5B5A5A5A5A5A5A5A59C949C9C949C
9C94948C8C8C8C8C8C8C8C848484847B6B5A5A3931292921212921212121182121212952
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFF7F7F7F7E74A4A29424A4A524A4229212931293142525A5A6373
94ADB5BDBDC6C6CEDECEDECECECECECEC6C6C6C6B5ADADADA59C9C9C9C9C9C9C9C9C9C9C
949C948C8C8C8C8C84848C84847B7B736B4A5239292931213129211821212118182139E7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7523939394A42524A31422131313931315263425A6B
8CADB5B5C6C6C6CECECECECECECECEC6C6BDB5BDADADB5A5A5A5949C9C9C949C9C9C9C94
949494948C8C8C8C848484848484736B5A524239293121211821212118181010182142F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFF7F7EFF7F76B42393942524A4A4242292131394231394A525263
84ADADBDBDC6C6C6CEC6CECEC6C6CEBDC6C6C6B5B5B5ADA59C9C9C949C9C94949C9C9494
949C8C84848C8C84848484847B736B524A394231212121212121211821101018182963F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7734A3931394A424A39394A2921313142315242426B
739CB5B5BDBDBDC6C6C6BDC6BDC6BDB5C6BDBDB5ADADA5A5949494949C9C9C9C9C948C94
94948C8C8C848C8C84847B7B736B5A4A423131292121212121212121181018182939FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7735A393142394A5A314239182921394A3142393952
638C9CADBDBDBDB5C6BDBDC6C6C6BDB5B5B5B5ADADAD9494949C949494949494948C948C
8C8C848C8C8C8C84847B73736B5A4A42422929211818212121212121211810213939F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFF7F7F7F7F79C6B42424A424A4A423139392131314242394A4A52
5A7B849CB5ADB5B5BDBDBDBDBDBDB5B5B5ADBDADA5A5949C94948C94948C948C948C8C84
8C8C8C8C8C8484847B847B6B6B5A423931292121181821182121211810101831295AF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C66B4A314A42424A5A314A31312931394A424A4252
4A738C9CA5ADADADBDBDBDB5BDB5B5ADB5ADADADAD9C9C948C948C848C8C84948C8C8C84
73848C8C8C8484847B7B736B524A393929292118181818181810101010101831399CF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7634A4A424A39425242423131313139394A393142
39526B7B8C9C9CA5ADB5ADB5B5B5B5ADADADADADA5848C848C8C8C84848C8C848C848C73
847384847B7B7B7373635A5A523931292129211818181818181010101018293129F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7FF84524A394A424A5242313121292931424A4A3929
42424A5A73737B8CA59CADADA5B5A5A5AD94ADA5A5948484848C8484848484848C848484
73737B7B737B736B6B5A5A4A42393121212118181018181818101010102129316BF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C65A4A394A4242425239312929214A39394A4A4A
31425252526B637B947B8C94A594A59C9C94A5948C736B6B6B736B7B846B8473737B8484
737B7B7373736B6B6B524A423131292121101818181818181010101018312121E7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF635A42314A31424A42293129293131524A4A42
4A52525A635A5A73736B6B73736B737B84848C7B6B5A5A525A5A636B636B6B737B6B6B73
73736B736B636363524242393129212121181818101010101010101831292152FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7845A4A394A4242424A392931293142424A5252
4A5A425252525263526B6B5A63635A5A7384736B635252524A52525A5A6363636B636B6B
5A635A6B635A63524A42312929292121181818181010101010101029212129CEF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DE734A42424A4A3952392929313131524A5A52
425A5A5A52525A525A525252524A524A5A5A6B5A5A5A52424242424A52525A5A63635A5A
5A5A525A525252424239312929211821181810181010101010101821312131F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A54A42424A394A4A42312131394A52525252
5A425A635A525A5A52424A4A395242424252525A4A524A4A424239394242525252524A52
5242424A524A42523929292931211821181818101010101010102129213184F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E76B4A42424A394A524231314A425A5A4A5A
52424A52525A52524239394A39424A314A39523942524229313939313131393131393939
393131313131313129212121212118181821181810101010182121213139FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7844A42424A4242424A42394A5A525A5A5A
4A424A42425242393939423931314239294A424242393939293131292929293131313131
3129293129312929293121211821181818181810101010103121212942DEF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD734A4A314A394A425A4A394A634A5A5A
5A5A52524A394A394A3142423939424A4231424231313131312121292921212921293129
292929212921292129212121182118101810101010101021212921297BF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEA54A424A424A4A42425A5A6B3952524A
39314A4A52314A424242423939424A393131392929292921212121212121292129212121
21292121292121182121181018181810181010181010182131212984F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFC66B4A424A4231394A31525A5A5A3939
5A6352424231393931314242293131393131293129312121212121212121211821212931
182121182121211821212121181818101010101018212121212152E7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6CE42424A4A4A39424A3942525A5A52
4A4A394A3931314239313939393139423131292131212121212118212121212121211829
1818181821211818182118182118181810101821212131212942F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D65A42394A4A4A424A425A4A42425A
5A6B42313129293939294231393939312121312121313121212118181821211818212118
21211821182118182118101810101810101018212139392942E7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7735A42394A3942394A394A5A4A42
394A31423129212139293129312121213129212118212121211818182118182121181821
212121102118181810181010101010102121182118211852E7E7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E77B5A424A424A4A42424239424A
423929423129212131312131314A21392121212121212121181818211818182121181818
21211831212118101010101010182131211831212129428CE7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BD7352394A424A4A5A4A4A5252
4A39294A3121212121312121213918311821211821181821211818182121182129211018
212121182118101010101018213121212121292131395AE7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD6B4A424A394A394A524A42
3939214A2931212121212121181818212118211821182118211818181821182139393918
182121213121213121212121311818213121213131526BF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CE6B524A4A394A5252525A
524A39423921312121182121211821182118211818181818182118101818212121396342
52213121182121212131212121393921313129394A63F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F77B73524A4A39424A5252
524A39523929292118212121211818182121211021211821182118181018184A3939525A
313139393931212121212929393129312931314252EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF7B6B5A524A39424A63
5A4A524231393121211821211818182121211821182121181818211818181810524A4A39
5A6B5A5A4A4A524A39292121313131394A394252EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79C5A4A4A4A39424A
526B7B5A3939313129212121211821181821181818182118181821211018212118314A42
52393121213131393939394A4242423131425273F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F752525A424A52
5A5A5A6B5A31313131314221393121312118211821211821182131212121213921313939
424A21212131212121312139312931425252D6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD634A4A4A4A
525A6B847B4A29313129293139393921313129212121213121214A213931213152393939
3121393931393931294231293139394A52D6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DE634A3942
4A5A6B6B736B5A3931293129294242393952212118313931394A3939397B4A6331425A52
4A42424242393942424A524A42425A52EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7945A52
4A5A73738C84736B4A5A5A4239184242525A424A3939216B4A525A7B5A5A525A6B63524A
4A524A524A4A4A4A393139524A4284FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CE73
5A5A4A52527B7B736B736B6B735A4A4A525A7B5A73524A315A4A4A527B524A4A424A5252
4A4A424239394A42524A5A5239BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
AD6B525A526B84736B6B5A6B736B6B6B635A526B6B5A7B5A4A4A3931395A4A4A4A393931
313139424252524A4A523942D6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7C67B525A5A6B7B8C738473735A7373847373736B8452735A4A4A4A3939425A52424A4A
424A4A525263635A424284FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EF6B524A637B947B8C848C736B737B737373637B73735A5A6B63525A52525A6B
6B6B6B6B634A4252C6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7E7B58C8C94A5C69C9C9C7B7B735A737B847B7B7B73737B6B636B736B7B6B
635A634A4A63BDFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7EFE7D6C6BDC6949484736B737B7373737B6B6B6B6B636B635A
525A5273B5FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7E7EFE7EFE7D6C69CA59C8473737373737B736B6B635252
5AA5EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7EFE7E7C6D6DEE7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Encoded) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EED5CEEECDB5F7D5BD
F7D5BDF7D5BDF7D5C6F7D5C6F7DDCEF7DDCEF7D5C6F7DDCEF7DDCEF7DDCEF7DDCEF7DDCE
F7DDCEF7DDCEF7DDCEF7D5C6F7D5C6F7D5C6F7D5BDEECDB5EECDB5EEC4ADEEC4ADEEC4AD
E5B39CE5BBA5E5B39CE5B39CDBAB94DBAB94DBAB94DBAB94DBAB94DBAB94DBAB94DBAB94
DBAB94DBAB94DBA28CD2A28CD2A284DB9984D2A28CD2A28CD2A284C09984D2A28CF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEF7CDB5F7D5BD
F7D5BDF7D5C6F7D5C6F7D5C6F7D5C6F7DDCEF7D5C6F7DDCEF7DDCEF7DDCEF7D5C6F7DDCE
F7DDCEF7DDCEF7D5C6F7D5C6F7D5C6EECDB5EECDB5EEC4ADEEC4ADE5BBA5E5BBA5E5BBA5
E5BBA5E5B39CDBAB94DBAB94DBAB94DBAB94DBAB94DBA28CDBAB94DBAB94DBAB94DBA28C
DBAB94DBA28CD2A28CD2A28CD2A28CD2A28CD2A28CD2A284D2A28CC09984D2A28CF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEF7D5BDF7D5BD
F7D5C6F7D5BDF7D5BDF7DDCEF7DDCEF7D5C6F7D5C6F7DDCEF7DDCEF7D5C6F7DDCEF7D5C6
F7D5BDF7D5C6EECDB5EECDB5EECDB5EEC4ADEEC4ADEEC4ADE5BBA5E5BBA5DBB39CE5AB9C
DBAB94DBAB94DBAB94D2A28CD2A28CDBA28CDBAB94DBAB94DBAB94DBA28CDBAB94DBAB94
DBA28CD2A28CDBA28CDBA28CD2A28CDBA28CD2A28CD2A28CD2A284C09984D2C4BDF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DDCEF7CDB5F7D5BD
F7D5BDF7D5C6F7D5C6F7DDCEF7D5C6F7D5C6F7DDCEF7D5C6F7D5C6F7D5C6F7D5C6F7D5BD
EECDB5F7D5BDEECDB5EECDB5D2C4B5D2C4B5E5BBA5E5BBA5DBB3A5DBB39CDBB39CDBB39C
DBB39CDBAB94DBAB94DBAB94DBAB94D2A28CDBA28CD2A28CD2A28CDBA28CDBAB94DBA28C
D2A28CDBA28CD2A28CD2A28CDBA28CD2A28CD2A28CD2A28CD2A284D29984F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EED5CEEECDB5F7D5BD
F7D5BDF7D5BDF7D5C6F7D5C6F7D5C6F7D5C6F7DDCEF7D5BDF7D5C6F7D5C6F7D5C6D2C4C6
EECDB5D2C4BDD2C4B5E5BBA5E5BBA5E5AB9CE5AB9CDBB39CDBAB94DBB39CDBB39CDBB39C
DBB39CDBB39CDBB39CDBB3A5DBAB94D2A28CD2A28CD2A28CD2A28CD2A28CD2A28CDBA28C
D2A28CDBA28CD2A284DBAB94D2A28CD2A28CD2A28CD2A28CD2A28CDBB39CF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D5C6F7D5BDF7D5BD
F7D5C6F7D5BDF7D5C6F7DDCEF7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5BD
D2C4C6F7BBB5F7BBB5F7BBB5EEBBADEEBBADEEBBA5E5B39CE5AB9CE5AB9CDB998CDB998C
DB998CDBAB94DBAB94DBB39CD2998CC0ABA5D2A28CD2A28CD2A28CD2A28CD2A28CDBAB94
DBA28CDBA28CD2A28CDBA28CD2A28CD2A28CD2A28CD2A28CD2A28CD2C4BDF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D5C6F7CDB5F7D5BD
F7D5C6F7D5BDF7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6EECDB5F7D5BDEECDB5
F7D5C6F7D5BDF7D5C6F7D5BDEECDB5F7BBB5F7BBB5EEBBADE5B39CE5AB9CE5AB94DB998C
E5AB9CEEB3A5E5AB9CDBB39CDB998CD2A28CD2A28CDBB3A5D2A28CD2A28CD2A28CD2A284
D2A28CDB9984D2A28CD2A28CDBAB94D2A28CD2A28CD2A28CD2A28CF7E7DEF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D5BDF7D5BDF7D5C6
F7D5C6F7D5C6F7D5C6F7D5C6EECDB5F7D5BDF7D5C6F7D5C6EECDB5EECDB5EECDB5F7D5C6
F7D5C6F7D5C6F7D5C6F7D5C6EECDB5F7D5BDF7BBB5EEBBADEEBBADEEBBA5E5BBA5E5BBA5
E5AB9CEEB3A5EEBBADEEB3A5E5AB9CDB998CDBA28CD2998CD2998CD2A28CD2A28CDBAB94
D2A28CD2A28CDBA28CD2A28CDBA28CD2A284D2A28CD2A28CD2A28CF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EECDB5F7D5BDF7D5BD
F7D5BDF7D5C6F7D5BDF7D5BDF7D5C6EECDB5F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6
F7DDCEF7DDCEF7DDCEF7D5C6F7D5C6F7D5C6EECDB5EEC4ADEEBBADEEC4ADEEBBA5E5BBA5
EEBBA5EEB3A5E5AB9CEEB3A5EEBBA5E5AB9CDB998CE5AB94DB998CD2A28CDBB3A5DBAB94
D2A28CDBAB94DBA28CDBA28CDBA28CD2A28CD2A28CD2A28CDBB39CF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EECDB5F7D5BDF7D5BD
F7D5BDF7D5BDEECDB5F7D5C6EECDB5F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7DDCEF7DDCE
F7DDCEF7DDCEF7D5C6F7D5C6F7DDCEF7DDCEF7DDCEEECDB5F7C4ADF7C4ADEECDB5EEBBAD
EEBBADEEBBADEEB3A5EEB3A5EEB3A5E5AB9CE5AB9CDB998CDB998CDBAB94DBAB94DBB39C
DBB39CD2A28CDBAB94DBAB94DBA28CDBAB94D2A28CDBAB94F7BBB5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CDB5F7D5BDF7D5BD
F7D5BDEECDB5F7D5C6EECDB5F7D5BDF7D5C6F7D5C6F7D5C6F7D5C6F7DDCEF7DDCEF7DDCE
F7D5C6F7D5C6F7D5C6F7DDCEF7DDCEF7DDCEF7D5C6F7D5C6F7D5BDF7D5BDEEC4ADEECDB5
EEBBADEEBBA5EEBBA5EEB3A5E5B39CE5AB9CE5AB9CE5AB94DBAB94DB998CDBA28CDBAB94
DBB3A5DBAB94D2A28CDBA28CD2A28CD2A28CD2A28CDBAB94EED5CEF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D5C6F7D5BDF7D5BDF7D5BD
EECDB5EECDB5F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5BDF7DDCEF7DDCEF7DDCEF7DDCE
F7D5C6F7D5C6F7DDCEF7DDCEF7DDCEF7DDCEF7D5C6F7D5C6F7D5C6F7D5BDEECDB5F7BBB5
F7BBB5EEBBA5EEBBA5E5B39CEEB3A5E5AB94E5AB94E5AB9CE5AB94DB998CDBA28CDB998C
D2A28CD2A28CDBB39CD2A28CD2A28CDBAB94D2A28CDBAB94EEE7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5DDE7DBB3A5EECDB5F7D5BDEECDB5
F7D5C6F7D5C6F7D5BDF7D5C6F7D5BDF7D5C6F7D5C6F7D5C6F7DDCEF7DDCEF7D5C6F7DDCE
F7DDCEF7D5C6F7DDCEF7DDCEF7DDCEF7DDCEF7D5C6F7DDCEF7D5C6F7D5BDF7CDB5EECDB5
F7C4ADEEC4ADEEBBA5EEBBA5EEBBA5E5AB9CE5AB9CDBA28CE5AB94DBAB94DBA28CDBA28C
D2A28CDBB39CD2A28CDBB3A5DBA28CDBAB94D2A28CDBAB94EEE7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F777665AEEC4ADF7D5BDEED5CEF7D5C6
F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7DDCEF7D5C6F7D5C6
F7D5C6F7D5C6F7D5C6F7DDCEF7D5C6F7DDCEF7D5BDF7D5C6F7D5C6F7D5C6F7D5BDF7D5BD
F7C4ADEEC4ADEEBBA5EEB3A5EEB3A5E5AB9CE5AB94E5AB94E5AB94E5AB94DBAB94DBA28C
D2A28CDBAB94D2A28CD2A28CDBB39CDBAB94DBAB94DBAB94F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7806E63534442EECDB5F7D5C6F7D5BDF7D5C6
F7D5C6F7DDCEF7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7DDCEF7D5C6F7D5C6F7D5C6
F7D5BDF7D5BDF7DDCEF7D5C6F7D5C6F7D5BDF7D5C6F7D5C6F7D5BDEECDB5F7D5BDF7C4AD
EEBBADEEBBA5EEBBA5EEBBA5EEB3A5E5B39CE5B394E5AB94DBA28CE5AB94DBAB94DBAB94
DBA28CD2A28CD2A28CDBAB94DBB39CDBB3A5DBAB94DBAB94F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F75B4C4A402A29805E52F7D5C6F7D5C6F7D5C6F7D5C6
F7D5C6F7DDCEF7D5C6F7DDCEF7DDCEF7DDCEF7D5C6F7D5C6F7D5C6F7DDCEF7D5C6F7D5C6
F7D5C6F7D5C6F7DDCEF7DDCEF7D5C6F7D5BDEECDB5EEC4ADEECDB5EECDB5EEC4ADEEC4AD
EEBBA5EEBBA5E5BBA5E5B39CEEBBA5E5B39CE5AB94E5AB94E5AB94E5AB9CDBA28CDBA28C
DB9984D2A28CD2A28CD2A28CDBAB94D2A28CEEBBADDBAB94F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7D2C4CE534442492A29EED5CEF7D5C6F7D5BDF7D5BDF7D5C6
F7DDCEF7DDCEF7D5C6F7D5C6F7DDCEF7DDCEF7D5C6F7D5C6F7D5C6F7D5C6F7DDCEF7DDCE
F7DDCEF7D5C6F7D5C6F7D5C6F7D5BDF7D5BDF7BBB5EEC4ADEEBBA5EEBBA5E5B39CEEBBA5
EEBBA5EEBBA5EEBBA5EEBBA5E5BBA5E5B39CDBAB94E5AB94E5AB94DBAB94DBAB94DBA28C
D2A284D2A284D2A28CD2A284D2A28CD2A28CD2A28CD2C4BDF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEF493C39644439F7D5C6EECDB5F7D5C6F7D5C6F7D5C6F7D5C6
F7D5C6F7DDCEF7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7DDCE
F7DDCEF7DDCEF7DDCEF7D5C6F7D5C6F7D5BDEECDB5EEBBA5EEC4ADEEBBA5EEBBA5E5B39C
EEBBA5E5BBA5EEBBA5E5B39CE5B39CE5AB94DBAB94E5B394E5AB94DBAB94E5A28CDBA28C
DBA28CD2A28CD2A284D2A284D2A284DBAB94DBAB94DBB39CF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFF6D5E5A533C31F7D5C6EECDB5F7D5BDF7D5BDF7D5C6F7D5C6F7D5C6
F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7DDCE
F7DDCEF7DDCEF7D5C6F7D5BDEECDB5F7C4ADEEBBADEEBBA5EEBBA5E5B39CE5B39CE5B39C
E5B39CE5B39CE5B39CE5B394E5B394E5AB94DBAB94DBAB94DBA28CDBA28CDBA28CDBA28C
DBA28CD2A284DBA28CD2A28CD2A28CDBA28CDBAB94DBAB94EED5CEF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7897773534442B6998CEECDB5F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6
F7D5C6F7D5C6F7D5C6F7D5BDF7D5BDF7D5BDF7D5C6F7D5BDF7D5C6F7D5C6F7DDCEF7DDCE
F7D5C6F7D5C6F7D5C6F7D5BDEECDB5F7BBB5EEB3A5E5AB9CE5AB9CE5AB9CE5AB9CE5AB94
E5AB9CE5AB94E5AB94E5AB94DBA28CDBA28CDBA28CDBA28CDBA28CD2A28CDBA28CDBA28C
DBA28CD2A284DBA28CDB9984DB9984DBA28CDBAB94DBA28CD2A28CEED5CEF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7533C31806E63F7DDCEF7D5C6F7D5C6F7D5BDF7D5BDF7D5C6F7D5C6F7DDCE
F7D5C6F7D5C6F7D5C6F7D5BDF7D5BDF7D5BDF7D5C6F7D5C6F7D5C6F7DDCEF7DDCEF7D5C6
F7D5C6F7DDCEF7D5C6F7BBB5EE918CF7BBB5EE918CE5807BE5807BE5807BE5807BE5807B
E5807BE59184E5AB94DBAB94DBA28CDBA28CDBA28CD2A28CDB9984D29984D2A284DBA28C
DBA28CD2A28CDBA28CDBA28CD2A284DBA28CDB9984D2A28CD2A28CD2A28CF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7C9B3B5533C31F7DDCEF7D5C6F7D5BDF7D5C6F7D5C6F7D5BDF7D5C6F7D5C6F7D5C6
F7D5C6F7D5C6F7D5C6F7D5BDEECDB5F7D5BDF7D5BDF7D5C6F7D5C6F7D5C6F7D5C6F7D5C6
F7DDCEF7DDCEF7BBB5F7BBB5F7BBB5EE918CEE918CE5807BE5807BE5807BEE918CE5807B
E5807BE5807BE5807BE5807BDB998CDBA28CD2A28CD2A28CD2A284D2A284D2A28CDBA28C
DBA28CDBA28CDBA28CDBA28CD2A284DBA28CD2A28CD2A28CD2A28CDBB39CEEBBADF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
D2C4C6533C31EED5CEF7D5BDF7D5C6F7D5C6F7D5C6F7D5C6F7D5BDF7DDCEF7D5C6F7D5C6
F7D5C6F7D5BDF7CDB5F7CDB5F7CDB5F7D5BDF7CDB5F7D5C6F7D5C6F7D5C6F7D5C6F7BBB5
F7BBB5DBCDD6F7BBB5F7BBB5EE918CE5807BE58073E5776BDB665ADB665AE5807BE5776B
DB776BDB776BE5807BE5807BD2887BE5807BD29984D2A284D2A284D2A284D29984DBA28C
DBA28CDBA28CDBA28CDBAB94DBA28CDBA28CDB9984D2A28CDBAB94DBA28CDBAB94F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
6D5E5A806E63EECDB5F7D5BDF7D5BDF7D5C6F7D5BDF7CDB5F7D5C6F7D5C6F7D5C6F7D5C6
F7D5C6F7D5BDF7CDB5EEBBA5F7CDB5F7C4ADF7CDB5F7D5C6F7DDCEF7D5C6F7BBB5F7BBB5
F7BBB5F7BBB5EEB3A5E59184D26E63DB665ADB665ADB665ADB665ADB665ADB665AD26E63
DB665ADB665ADB665ADB776BE5807BD2776BC98884DB998CDB9984D29984D29984D2A284
DB9984DBA28CDBA28CDBAB94DBA28CDBA28CDBA28CD2A28CD2A28CDBA28CDBAB94EEBBAD
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F792888C
493C39F7DDCEEECDB5F7D5BDF7D5BDF7D5BDF7D5BDF7D5BDF7D5BDF7D5C6F7D5C6F7D5C6
F7D5BDF7D5BDEEC4ADEEBBA5EEBBA5EEBBA5F7D5BDF7D5C6F7D5C6F7BBB5F7C4ADF7C4AD
EE918CE59184E58073D2887BDB998CE5AB9CC06652F7BBB5DBB39CAD6E5AE5AB9CD2776B
D25E52C9544AD25E52DB665ADB776BD2776BD2887BD2887BD2A28CD2A284D29973D2A284
D2A284DBA28CDBA28CE5A28CDBA28CDBAB94DBA28CD2A28CDBA28CDBA28CDBAB94DBB39C
F7E7DEF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C0ABBD5B4C4A
492A29F7D5C6F7D5BDF7D5BDF7D5C6F7D5BDF7D5BDF7C4ADF7D5C6F7DDCEF7D5C6F7DDCE
F7CDB5F7CDB5EEC4ADE5B394E5B394EEBBA5F7D5C6F7D5C6F7C4ADEE918CE5AB94E58073
D25E52AD4C39C0ABA5E5AB9CD2C4C6D2C4C6C9B3B5C9B3B5EEBBADB6A29CD2C4BDC9B3B5
A56652D2998C9C5E4AC9544AD26E63D26E63D2776BD2887BD2887BD29984D29984D2A284
DB9984DBA28CDBAB94E5B394DBAB94DBA28CDB9984DBA28CDBA28CDBA28CDBAB94D2A28C
DBB39CE5DDEFE5DDEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5DDEFAD999C493C39
C09984F7D5BDF7D5BDF7D5C6F7D5C6F7D5BDEEC4ADEEBBA5F7DDCEF7D5C6F7D5C6F7D5BD
F7C4ADF7C4ADE5B394DB9984DB9984F7D5BDF7BBB5E5807BE5807BC98063772218D2776B
E5AB9CDB665AE59184DB776BEEB3A5F7E7E7F7E7DEEED5CEE5776BE59184C98873C96E5A
B68063B6A29CC091849C66529C5E4AC9544AD25E52C98873C9917BD29984D29973D29973
DB9984DBA28CDBAB94E5B39CE5B394E5B394DBA28CDBA28CDBAB94DBA28CDBA28CDBAB94
DBAB94D2C4C6F7E7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A5A2AD92888C402A29
EED5CEF7D5BDF7D5C6F7D5BDF7D5BDF7CDB5EEBBA5EEBBA5F7D5C6F7D5C6F7D5C6F7D5C6
F7C4ADE5B39CE5A28CDB9173E5A28CEEB3A5DB665A923229895E4AEEBBADF7DDCEF7E7DE
F7E7DEF7EFEFF7EFEFF7E7DEF7E7E7F7EFEFF7E7DEF7DDCEEECDB5EED5CEEED5CEEED5CE
D2C4C6AD4C39AD6E5A896E6BA5776B644439B65442C06652D26E63DB9984D29973D29973
DB9984DBA28CE5B39CE5BBA5E5B39CE5B394DBA28CDBAB94D2A28CDBAB94DBAB94DBAB94
DBAB94D2C4B5F7F7F7D2C4D6E5DDE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7807773534442774C42
EECDB5F7D5BDF7D5C6F7D5BDF7D5BDF7CDB5EEBBA5F7D5BDF7D5C6F7D5C6F7D5C6F7D5C6
F7C4ADE5A28CDB9173C98063D28873AD4C39802221925442D2C4BDF7DDCEF7E7DEF7E7DE
F7E7DEF7E7E7F7EFEFF7E7DEF7E7E7F7EFEFF7E7DEF7E7DEEECDB5F7E7E7F7E7DEEED5CE
EED5CEE5BBA5C0ABA5A5544289544A492A21643C29B65442C06652D28873D2A284D29973
DB9984DBA28CE5B39CEEBBA5E5B39CE5B39CE5B394DBA28CDBA28CDBAB94DBA28CDBAB94
DBAB94DBB3A5DBD5E7F7EFEFEEE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7EEE7E7F7F7F7F7EFEFF7EFEFE5DDEFF7EFEFF7EFEFF7F7F7898084493C39C09984
F7D5BDF7D5C6F7D5C6F7D5BDF7D5BDF7C4ADEEBBA5F7D5BDF7D5C6F7D5C6F7DDCEF7D5BD
E5B39CE5A28CC9886BC9886B9232297722186D2A21AD6E5AE5B39CF7E7DEF7D5C6F7E7E7
F7D5BDF7E7DEF7EFEFF7D5C6F7E7DEF7EFEFF7E7DEF7D5C6E5AB9CF7E7E7F7E7DEEED5CE
F7D5C6D2C4C6D2C4C6EED5CE9C4C39A5776B370808370808AD4C39C9544AD2887BD29984
D29984DBA28CE5B394EEBBA5EEBBA5E5B39CE5B394DBAB94D2A28CDBAB94DBA28CDBAB94
DBA28CDBB39CC9BBB5C9BBCED2C4D6F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DBD5E7533C31402A29F7D5C6
EECDB5F7D5BDF7D5BDF7D5BDF7D5BDEEC4ADF7D5BDEEBBA5F7D5C6F7D5C6F7D5C6F7D5BD
E5A28CDB9984C08863D2887BB654429C3C31772218E58073E59184DB9173EEBBA5F7D5BD
EEB3A5F7DDCEF7E7DEE5AB94F7D5BDF7E7DEF7D5BDE5AB94E5AB9CEEBBA5EED5CEF7D5C6
E5AB94EECDB5F7D5C6EECDB5D2A28CDBB3A5B6998CB6998C643C319C3C31C06652D29984
D29984DBA28CE5B394EEBBA5EEC4ADE5BBA5E5B39CDBA28CDBAB94DBA28CDB9984DBA28C
DBA28CDBAB94D2C4B5A59194C9BBB5D2C4BDDBD5E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C9BBCE533C311B1921644442D2C4C6
F7D5BDF7D5BDF7D5BDF7D5BDEEC4ADEEBBA5F7CDB5EEBBA5F7D5C6F7D5C6F7D5C6EECDB5
E59184C9886BDB9173E5AB94E5AB9CE5AB94DB776BDB665AE58073E58073DB9173E5AB9C
E59184E5A28CE5A28CE5A28CEEB3A5F7BBB5D26E63DB776BDB776BE59184E5A28CE5AB94
D26E63E5A28CEECDB5E5B39CDBB39CDBB3A5D2A28CB6998C9C6E5A6D22189C3C31C98873
D29984DBA28CE5B39CEEBBA5EEC4ADEEBBA5E5B39CDBA28CDBA28CD2A28CD29984D2A28C
DBA28CDBB39CDBB3A5DBD5E7D2C4D6C9BBC6D2C4CEE5DDEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF806E632E2221402A292E1918C09184F7D5C6
F7D5BDF7D5BDF7D5BDF7C4ADF7C4ADEEC4ADF7C4ADE5AB94F7D5BDF7D5C6F7D5BDF7BBB5
E5A28CC98063E5B39CEEB3A5EECDB5F7D5C6F7D5BDF7D5BDF7BBB5EEBBADEEB3A5EEB3A5
E5AB9CEEB3A5E5AB9CE5AB9CEE918CEE918CDB998CDB9984DB776BDB776BDB665AC96E5A
D26E63D26E63DBB39CC9886BD28873EEC4ADC98884D2A28CA5776B5310106419109C4C39
D2887BD2A284E5B394EEBBA5EEC4ADEEBBA5E5B394DBAB94DBA28CD2A284D2A28CDBA28C
DBAB94DBAB94DBB39CF7F7F7F7EFEFDBCDD6D2C4D6DBD5E7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7E5DDE7D2C4D62E22211B19185332312E2218F7D5C6F7BBB5
F7D5BDF7D5BDF7D5BDEEC4ADEEC4ADF7BBB5EEC4ADEEC4ADF7D5BDF7D5C6F7D5BDF7C4AD
E5AB94C98063E5AB94EEBBADF7DDCEF7D5C6F7DDCEF7DDCEF7D5C6F7DDCEF7D5C6F7DDCE
F7DDCEF7DDCEF7DDCEF7BBB5F7BBB5F7BBB5EEBBADEEBBADEEB3A5E5AB9CE5807BDB776B
E5807BD2776BD26E63C06652C06652D29973C06652AD6E5A9C3C312E0810641910774439
9C4C39D29984E5AB94EEBBA5EEBBA5EEBBA5E5B39CDBA28CDBA28CD2A28CD29984DB9984
DBA28CDBA28CDBB39C9C807BAD999CDBD5E7E5DDE7DBCDD6EEE7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7DBCDD692888C1B1918402A292E2221492A21F7D5C6EECDB5
F7D5BDF7BBB5F7CDB5EECDB5F7BBB5EECDB5EECDB5EECDB5F7D5BDF7BBB5F7BBB5EEC4AD
E5AB94DB9984C9886BEEBBADF7D5C6F7DDCEF7DDCEF7D5C6F7D5C6F7DDCEF7D5C6F7D5C6
F7DDCEF7DDCEF7D5C6F7D5C6F7D5BDF7CDB5EEBBA5EEBBA5EEBBA5EEC4ADE5B394E5B39C
E5AB94DB998CDB9984D2887BE5807BD2776BD26E63C06652B65442923229923229AD4C39
9C3C31D2887BDBA28CEEBBA5EEBBA5EEBBA5E5B394DBAB94DBA28CD2A284D29984DB9984
DBA28CDBA28CDBAB94B6A29C644439F7E7DEF7EFEFEEE7E7EEE7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7E5DDE7493C39926652D2998CAD6E5A80544AF7D5C6F7D5BD
F7D5BDF7D5BDF7CDB5EECDB5F7D5BDF7D5BDF7D5BDEECDB5EECDB5F7D5BDEECDB5EECDB5
E5AB94E5A28CDB9173E5B39CEECDB5F7D5C6F7D5C6F7D5C6F7D5C6F7DDCEF7D5C6F7D5C6
F7DDCEF7D5C6F7DDCEF7D5C6F7D5BDF7C4ADEEBBA5EEBBA5E5B39CEEBBA5EEBBA5E5B39C
E5AB94E5A28CDBA28CDB9984D29984DB9984DB9984DB998CD29984D2887BD28873C9886B
C98063C9886BDB9984E5BBA5EEBBA5EEBBA5E5B39CDBA28CD2A28CDBA28CD2A284DBA28C
DB9984DBAB94DBAB94C0ABAD807773775E52F7F7F7EEE7E7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7DBD5E7775E52F7D5BDEECDB5EEBBA5EEBBA5EECDB5EECDB5
F7D5BDF7D5BDF7CDB5EECDB5F7D5BDF7D5BDF7BBB5F7D5C6F7D5BDF7D5BDF7D5BDEECDB5
E5B39CE5A28CDB9984DB9173EEC4ADEECDB5F7D5C6F7DDCEF7DDCEF7DDCEF7D5C6F7D5C6
F7D5C6F7DDCEF7DDCEF7D5C6F7BBB5EEBBA5EEBBA5E5B394EEBBA5EEBBA5E5B39CE5B39C
E5AB94DBA28CD2A284D2A28CD29984D2A284D2A284D29984D29984D2A284D29984D29984
C98884D29984D29973E5BBA5E5B39CEEBBA5E5B394DBA28CDBA28CD2A284D2A284D2A284
DBA28CDBAB94DBAB94C0ABA56D5E5AC9BBC6D2C4BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFB6A29CEECDB5F7D5C6F7D5BDF7D5C6EECDB5D2C4C6EECDB5
EECDB5F7BBB5F7D5BDF7D5C6F7D5C6F7D5C6F7D5BDF7D5C6F7D5BDF7D5BDF7D5BDEECDB5
EEBBA5E5B39CE5A28CDB9984E5B394EECDB5F7D5BDF7DDCEF7DDCEF7DDCEF7DDCEF7D5C6
F7D5C6F7D5C6F7DDCEF7DDCEF7CDB5EEBBA5EEBBA5E5B394E5B39CEEBBA5E5B394E5B394
E5AB94DBA28CD2A284D29984C9917BC9886BC9917BC99173C9917BC9917BD2887BD29984
D29973D2A284DB9984E5B394EEBBA5E5B39CDBAB94DB9984D29984D29984D29973D2A284
DBA28CD2A28CD2A28CC9B3AD1B1921C9BBB5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7DBD5E7F7D5BDF7D5BDF7D5C6F7D5BDF7DDCEEECDB5EECDB5F7D5BD
EECDB5F7D5BDF7D5BDF7D5BDF7D5C6F7D5C6F7D5C6F7D5C6F7DDCEF7D5C6F7D5C6F7BBB5
EEC4ADEEBBA5E5AB94E5A28CDB9984EEBBA5EECDB5F7D5C6F7DDCEF7D5C6F7DDCEF7D5C6
F7D5C6F7D5BDF7DDCEF7D5C6F7D5BDEECDB5EEBBA5E5A28CE5A28CE5AB94E5B394DBA28C
D2A284D29984C09984C9917BC99173C9917BC98873C99173C99173C99173C98873C99173
C99173D2887BDBAB94D29973E5B39CE5B394E5AB94DB9984D29984D29984D29984D2A284
D2A284DBAB94D2A28CB6A29C403231898084E5DDEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7DBCDD6F7D5BDF7D5C6F7D5BDF7D5BDF7C4ADEECDB5F7D5BDF7D5BD
F7BBB5F7D5BDF7D5BDF7D5C6F7D5C6F7DDCEF7DDCEF7DDCEF7DDCEF7DDCEF7D5C6F7D5BD
F7BBB5EEBBA5E5B39CE5A28CDB9173E5B394EEBBA5F7D5C6F7DDCEF7DDCEF7DDCEF7D5C6
F7D5C6F7D5C6F7D5BDF7D5C6EECDB5EEBBADE5AB94E5AB9CE5AB9CDBAB94DB9984DB9984
D29973D29973C99173C9917BC98873C99173C99173C9917BC9917BC99173C99173C9886B
C99173D2A284DB9984E5AB94DBAB94DBA28CDBA28CDB9984D29984D29984D29984D2A284
D2A28CDBA28CD2A28CB6A29C1B1918534442898084F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7EEE7E7F7CDB5F7D5BDF7D5C6EEC4ADF7C4ADE5B394F7D5BDD2C4C6F7D5BD
F7CDB5F7D5BDF7D5C6F7D5C6F7DDCEF7DDCEF7DDCEF7DDCEF7DDCEF7DDCEF7DDCEF7D5BD
F7BBB5EEC4ADEEBBA5E5AB94E5A28CE5A28CEEBBA5F7D5C6F7D5C6F7DDCEF7DDCEF7D5C6
F7BBB5F7C4ADEECDB5F7D5BDF7D5BDF7C4ADE5B39CE5AB94E5AB94DBAB94D28873D2A284
D2A28CD29984C98873C98873C99173C9917BC9917BD29973D29973C99173C99173C99173
C9886BDB9984E5AB94E5B394E5AB94E5A28CDBA28CD2A28CD29984D29984D29984DB9984
D2A28CD2A28CDBAB94B6998C1B19212E2231C9BBB5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7D5BDF7D5C6F7D5BDF7DDCEEECDB5E5A28CDBAB94F7D5BDEECDB5F7D5BD
F7D5BDF7D5BDF7D5C6F7D5C6F7DDCEF7DDCEF7DDCEF7DDCEF7DDCEF7DDCEF7DDCEF7D5C6
EECDB5EEC4ADEEBBA5E5B394E5A28CDB9984E5A28CEECDB5F7DDCEF7DDCEF7D5C6F7D5BD
F7D5C6F7D5BDF7D5BDF7D5BDF7D5C6F7D5BDEEC4ADEEBBA5E5B39CDBAB94DBAB94D29984
B6806BC98873C9886BC98873C9917BC99173C9917BD29973D2887BD29973C99173D29973
DBA28CE5B39CE5B394E5B394DBA28CDBA28CDBA28CDBA28CD29984D29984D29984D2A28C
DB9984D2A28CD2A28C9C8084372A316D6E7BF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7D5BDF7D5BDF7D5C6F7DDCEE5B39CE5B39CDBAB94F7BBB5EECDB5F7D5BD
F7BBB5F7D5BDF7D5C6F7DDCEF7DDCEF7DDCEF7DDCEF7E7DEF7DDCEF7DDCEF7DDCEF7D5C6
F7D5BDF7CDB5F7C4ADEEBBA5E5B394E5A28CE5A28CEEC4ADF7D5C6F7D5C6F7DDCEF7D5C6
F7D5C6F7DDCEF7D5C6F7DDCEF7D5C6F7D5BDEEBBADEEBBADE5B39CDBB39CDBA28CDBA28C
DBA28CC9917BC98873B6806BC98873C99173C9917BD29973D29984D2887BDB9984DBAB94
E5AB94E5BBA5E5B39CE5B39CDBA28CE5AB94DBA28CDBA28CDBA28CD2A284D29984D2A28C
D2A284D2A28CD2A28CA5806B2E2221403231534442E5DDEFF7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7E7DEF7CDB5F7D5BDF7D5C6EECDB5DB9984E5B394E5BBA5EECDB5F7BBB5F7D5BD
F7D5BDF7D5BDF7D5C6F7DDCEF7DDCEF7DDCEF7DDCEF7E7DEF7E7DEF7DDCEF7DDCEF7DDCE
F7D5BDEECDB5F7BBB5F7C4ADEEBBA5E5AB94E5A28CE5B39CF7BBB5F7D5C6F7DDCEF7D5C6
F7D5C6F7D5C6F7DDCEF7E7DEF7DDCEF7D5C6EECDB5EEBBA5E5B39CE5AB9CDBAB94DBA28C
DBA28CDBA28CD2A28CDB9984B6806BC08873C9886BC99173D2887BDBA28CDBA28CE5B39C
E5B39CE5B39CE5B39CE5B39CE5AB94E5A28CDBA28CDB9984DBA28CD29984D29984D29984
D2A284D2A28CDBB39CAD8873644439492A291B1918806E6BDBCDD6F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7EECDB5F7D5BDF7D5C6EECDB5EEC4ADC9886BD2998CEECDB5EECDB5F7BBB5F7D5BD
F7D5BDF7D5BDF7D5C6F7DDCEF7DDCEF7E7DEF7E7DEF7DDCEF7DDCEF7DDCEF7DDCEF7D5C6
F7D5C6EECDB5F7D5BDF7BBB5E5B39CE5B39CE5B394EEBBADEECDB5F7D5C6F7D5C6F7CDB5
F7D5BDF7D5C6F7DDCEF7DDCEF7D5C6F7D5BDEEC4ADE5AB94DBA28CDBA28CDBA28CD2A28C
D2A28CD29984D29984DB998CD29973B6806BC98873D2887BD29984DBAB94E5AB9CE5B39C
EEBBA5EEBBA5E5B39CE5BBA5DBB39CDBAB94DBAB94DBA28CD2A28CDBA28CD2A28CD29984
D2A28CD2A28CDBB39CD29973C088639C5E4A774439493C39534442A59194F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7E7E7F7C4ADF7D5BDF7C4ADE5B394DBA28CDB9984DBB39CEECDB5F7BBB5F7D5BDF7D5BD
F7D5BDF7D5C6F7D5BDF7DDCEF7DDCEF7DDCEF7DDCEF7E7DEF7DDCEF7DDCEF7DDCEF7D5C6
F7D5BDF7D5BDF7D5BDF7BBB5EEC4ADEEBBA5EEBBA5E5B39CF7D5C6F7D5C6F7D5C6EECDB5
EEC4ADF7D5BDF7D5C6F7D5C6EECDB5F7BBB5EEBBA5DBAB94DBA28CD2998CD2998CD29984
D2A28CD29984D29984D29984C99173B68063C9886BD29973DBA28CE5AB9CE5B39CE5B39C
EEBBA5E5B39CE5B39CE5B39CDBAB94DBAB94E5AB94DBAB94DBA28CDBA28CD2A284DBA28C
DBA28CDBA28CDBB39CD29984D29973C98873B6806B534442807773E5DDE7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7D5C6F7CDB5E5A28CDB9173D26E63D2776BD29984E5B39CD2C4B5F7D5BDF7D5BDF7D5BD
F7D5BDF7D5C6F7D5C6F7DDCEF7DDCEF7DDCEF7DDCEF7DDCEF7DDCEF7D5C6F7DDCEF7D5C6
F7D5C6F7D5BDEECDB5F7BBB5EEC4ADEEBBADEECDB5F7C4ADF7D5BDF7D5C6F7D5BDEEC4AD
EEBBADEECDB5F7D5BDF7D5BDF7BBB5EEBBA5E5B394E5AB94DB9984D29984D29984C9917B
C9917BC9917BD29973C99173B6806BC08863C98873DB998CDBAB94E5B39CE5B39CE5B39C
EEBBA5EEBBA5E5B39CE5B39CDBAB94E5AB94DBA28CDBA28CDBA28CDB9984D2A284D29984
DB9984DBB39CDBB39CD29984D29984D29984D29984B6998CF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7BBB5F7CDB5E59184E5776BD2776BC9886BDBA28CE5AB9CEECDB5F7D5BDF7D5C6F7D5BD
F7D5C6F7D5C6F7D5C6F7D5C6F7DDCEF7E7DEF7DDCEF7DDCEF7DDCEF7DDCEF7D5C6F7D5C6
F7D5BDF7BBB5EECDB5F7C4ADEEBBADEEC4ADEECDB5F7D5C6F7D5C6F7DDCEF7D5C6F7D5BD
F7D5C6F7D5C6F7D5BDF7BBB5EEC4ADEEBBA5E5B39CDBAB94D29984C09984C08873C9917B
C99173C08873C99173C9886BC9886BC9886BD2887BDBA28CDBAB94E5B39CEEBBA5EEBBA5
E5B39CEEB3A5E5B39CE5B39CE5B394E5AB94DBA28CDBA28CDB9984D2A28CD2A28CD29984
D2A28CDBAB94DBB3A5C99173C99173D29973D29973C0ABA5F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EED5CE
F7BBB5F7C4ADE59184DB9173D2776BC98873D2A28CEEBBA5EECDB5F7D5BDF7D5C6F7D5BD
F7DDCEF7DDCEF7D5C6F7DDCEF7DDCEF7DDCEF7DDCEF7DDCEF7DDCEF7D5C6F7D5C6F7BBB5
F7D5BDF7BBB5EECDB5EEBBADF7C4ADF7BBB5EECDB5F7D5C6F7D5C6F7DDCEF7DDCEF7DDCE
F7D5C6F7D5C6F7D5C6EECDB5F7C4ADEEBBA5E5B39CDBA28CD29984C9917BC9917BC08873
C08873C08873C08873C9917BC9917BD29984DBAB94DBAB94E5B39CE5B39CE5BBA5E5BBA5
EEBBA5E5BBA5E5B39CE5AB94DBAB94DBAB94DBA28CDBA28CDB998CDB998CDB998CD29984
D29984D2A28CDBB3A5C9886BC9886BD29984D29984DBB39CFFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BBB5
F7CDB5F7BBB5E5A28CE59184C98873C98873DBAB94EEBBADEECDB5F7D5C6F7D5BDF7D5C6
F7DDCEF7D5C6F7DDCEF7DDCEF7DDCEF7D5C6F7DDCEF7D5C6F7D5C6F7D5BDEECDB5F7D5BD
EECDB5F7D5BDF7BBB5EEC4ADEEBBA5EEBBA5EEBBADF7D5C6F7D5C6F7D5C6F7DDCEF7D5C6
F7D5C6F7D5C6F7D5C6F7D5BDEECDB5E5B39CE5AB94DBA28CD29984C09984C9917BC99173
C9917BC9917BC9917BD2A284D29984DBA28CDBAB94E5AB9CE5AB9CEEBBA5EEBBA5E5B39C
EEBBA5E5B39CE5B39CE5B39CE5AB94DBA28CDBA28CD2A28CD2998CD29984D2A28CD29984
D29984D2998CDBB3A5D2887BD2887BD29973D2A28CD29984F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DDCEEEBBA5
F7CDB5F7D5C6E5A28CDB9984C9886BC08873DBAB94EEC4ADF7D5BDF7D5C6F7D5C6F7D5C6
F7DDCEF7DDCEF7DDCEF7D5C6F7D5C6F7D5C6F7D5C6F7D5BDEECDB5EECDB5F7D5BDF7D5BD
F7BBB5EECDB5EEC4ADEEC4ADEEBBA5EEBBADEEC4ADF7D5BDF7D5C6F7D5C6F7D5BDF7D5C6
F7D5C6F7D5C6F7D5C6F7D5BDF7BBB5EEBBA5E5A28CDBA28CD29984C09984C9917BC9917B
C9917BC09984C09984D29984D2A284DBAB94DBAB94E5B39CE5B39CEEBBA5EEBBA5E5BBA5
E5B39CE5B39CE5AB94DBAB94DBAB94DBA28CDB9984DBA28CDB9984D29984D29984D2998C
D2A284D2998CDBB3A5D2A28CDB9984D2A284D2A28CD2887BD2C4C6F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D5BDE5B394
F7D5BDE5BBA5E5AB9CDB9984B6806BC08873DBB39CEEC4ADEECDB5EECDB5F7D5BDF7D5C6
F7DDCEF7D5C6F7DDCEF7DDCEF7D5C6F7D5BDF7D5BDF7D5BDEECDB5EECDB5EECDB5EEBBA5
EECDB5EECDB5EEBBADEEBBA5EEBBA5EECDB5EECDB5EECDB5F7D5C6F7D5BDF7D5BDF7D5BD
F7D5C6F7D5C6F7D5C6F7D5C6F7D5BDEEBBA5E5AB94DBA28CD29984D29984C0917BC9917B
C09984C09984D29984D2A28CDB9984DBA28CE5AB9CE5B39CE5BBA5E5B39CE5BBA5E5B39C
E5BBA5E5B394E5AB94E5AB9CE5AB94DBA28CD2A28CD29984D2A284D2998CD29984D29984
D29984DBB39CE5AB9CC99173D2A284D2A28CDBB39CD28873DBAB94F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFE5B394E5A28C
C98873DB998C926652926652AD7763B6806BE5BBA5EECDB5F7D5BDF7D5C6F7D5C6F7D5C6
F7D5C6F7DDCEF7D5C6F7D5C6F7D5BDF7D5BDF7CDB5F7D5BDEECDB5EEC4ADEEBBADEEBBAD
E5BBA5EEBBADEEBBADEEC4ADEECDB5EECDB5EECDB5EECDB5F7D5BDF7D5C6F7D5C6F7D5BD
F7D5C6F7D5C6F7D5C6F7D5BDEECDB5EEBBADE5AB94DBA28CD29984C9917BC9917BC9917B
C9917BC09984D29984D29984D2A28CDBAB94E5AB9CE5BBA5E5B39CE5AB94E5B39CE5BBA5
E5BBA5E5B39CE5B39CE5AB94DBAB94DBAB94DBAB94DBA28CD2A28CD2998CD29984D29984
D2998CD2A28CDBB3A5A56652C96E52D2A284DBB39CD28873D28873EEE7E7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D5BDE5A28CD2887B
C98873805442A56E5A80544A895E4A926E63E5BBA5F7D5BDF7D5C6F7D5C6F7D5BDF7D5C6
F7D5C6F7D5C6F7D5C6F7D5BDF7D5C6F7D5C6EECDB5EECDB5EEC4ADEECDB5EEC4ADEEBBAD
E5B39CE5BBA5E5BBA5E5BBA5EEBBADEECDB5EECDB5EECDB5EECDB5F7D5C6F7D5C6F7D5BD
F7D5BDF7D5C6F7D5C6F7CDB5EECDB5EEBBA5E5AB94D29973D29984C9917BC08873C9917B
C99173C98884D2998CD29984D2A28CDBAB94DBAB94E5AB9CDBB39CDBAB94E5AB94E5AB94
E5AB9CE5AB94E5AB94E5AB94DBAB94D2998CDBAB94D2A28CD2998CD29984D29984D2A28C
D2A28CD2A28CC0ABA5AD6E5AC06652C9917BD2A28CD29984D29973F7BBB5F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C4ADDB9173C9917B
643C29D2998480544A774C426444429C6E5AE5BBA5F7D5BDF7D5C6F7D5C6F7D5C6F7D5C6
F7D5BDF7D5C6F7D5BDF7D5C6F7D5C6EED5CEF7D5C6F7D5C6F7D5C6F7D5C6F7D5C6EECDB5
EEBBADEEBBA5E5AB9CE5AB9CDBAB94E5AB9CEEC4ADEECDB5EECDB5F7D5BDF7D5C6F7D5BD
F7D5C6F7D5C6F7D5BDF7D5BDEEBBADE5B39CDBA28CD2887BC98884C99173C99173C9917B
C08873D29973D29984D2A28CDBAB94DBA28CDBA28CDBAB94DBAB94E5B39CE5AB9CE5AB94
DBA28CDBAB94DBAB94DBA28CD2A28CDBAB94D2A28CD2998CD2A28CD2A284D29984D29984
D2998CC0ABA5D2A28CAD7763C08863C9886BC99173DBA28CD2887BDBA28CF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFE5B394E591849C6E5A
AD6E5A533C31805442805E52775E5277665AE5BBA5F7D5BDF7D5C6EECDB5F7D5C6F7D5BD
EECDB5F7D5BDEECDB5D2C4B5EECDB5F7D5C6F7D5C6F7D5C6F7D5C6F7D5C6D2C4BDF7D5C6
F7D5C6D2C4B5E5BBA5E5BBA5DBAB94DBA28CDBAB94DBB39CEECDB5EECDB5F7D5C6F7D5C6
F7D5C6F7D5C6F7D5BDF7D5BDEEBBA5E5BBA5DBA28CD29984C9917BC9917BC08873C08873
C9917BC09984D2998CD2A284DBA28CD2A28CDBA28CDBA28CDBAB94DBAB94DBAB94DBAB94
D2998CD2A28CDBA28CDBA28CDBAB94DBA28CD2A28CD2A28CD2A284D29984D2A284D29984
D2998CC0ABA5D2A28CAD77639C5E4A9C4C399C3C31C96E52D29973D28873F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEDB9173E5AB9CA56E5A
AD6E5A2E1010644439402A29644442775E52E5BBA5F7D5BDF7D5BDEECDB5EECDB5F7D5C6
F7D5C6F7D5BDF7D5BDEECDB5DBB39CC09984DBB39CD2A284C0917BC98884C0917BC09184
C09184D2998CC98884D2998CDBA28CDB998CDBA28CDBAB94E5BBA5EECDB5F7D5C6F7D5C6
F7D5C6F7D5C6F7D5C6F7D5BDEEBBADE5B39CDBA28CC9917BC99173C99173C9886BC08873
C0917BC9917BC9917BC9917BC09984D2998CC09984D2A28CD2A28CD2A28CDBB39CDBB39C
D2A28CDBAB94DBAB94DBAB94DBAB94DBAB94D2A28CD2A28CD2A28CD2A284D29984C09984
D2998CDBB39CD2A28CAD806B9C5E4AA554429C4C39B65442C98063D2887BF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D5BDDB9173E5AB9CB6806B
643C311B19181B19182E2221533C31644442EEC4ADF7D5C6F7D5BDF7D5BDF7D5BDF7D5BD
F7D5C6EECDB5EEC4ADDBB39CC08873AD806B774C39644442926652B6806BB6806B9C6E5A
926E639C6652AD806BAD6E5AC0917BD2887BC98873DBAB94E5BBA5EEC4ADF7D5BDF7D5C6
F7D5C6F7D5C6F7D5C6F7D5BDEEBBADE5B39CDB9984D29973C9917BC9886BC08873C09973
B6806BAD8873C09984D2998CD29984C9917BC09984D29984D29984C09984D2A28CDBAB94
DBAB94DBB39CDBAB94E5AB9CDBAB94D2A28CD2A28CD2998CD29984D2A28CC09984C09984
D2A28CD2A28CD2A28CA5806B9C6652A55442A55442B65442C98063DB9984F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEC4ADE5776BE5AB9CD2998C
2E10102E08102E2221402A294032316D5E52EEC4ADF7D5C6EECDB5F7D5BDF7CDB5F7CDB5
F7D5BDF7D5BDF7D5BDEECDB5EEC4ADDBB39CC09984644439A5806BC9B3BD6D5E5AA5806B
534442121018774C39643C29AD7763A56652A554429C4C39A55442E5B394EEC4ADF7D5C6
F7D5C6F7D5C6F7D5C6F7D5BDEEC4ADE5B39CDBA28CD29973C99173AD8873C09973B68063
B6806BC09984D2A28CDBAB94DBAB94DBAB94DBAB94DBAB94DBA28CD2998CD2998CD29984
C09984D2A284DBAB94DBB39CDBAB94DBAB94D2A28CD2A28CC09984D29984C09984D29984
D2A28CD2A28CD2A28CAD806BA56652A55442A55442B65442C96E5AD29984F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFE5B39CC96E52E5AB94EEB3A5
402A292422212E2231402A29533C31644C4AEECDB5F7D5BDF7D5C6EECDB5EECDB5EECDB5
F7D5BDF7D5C6F7D5BDEECDB5EECDB5D2A28CDBAB94C0917B9C807B493C39492A21898084
776E94121018644C4A774C39B6A29CAD999C805442A55442D29973EEBBA5EECDB5F7D5C6
F7D5C6F7DDCEF7DDCEF7D5C6EECDB5EEBBA5DBA28CD29973C9886BB6806BAD6E5AAD6E5A
B68063D2A284DBB39CDBB39CDBB39CDBB39CDBAB94D2A28CD2A28CDBB39CDBB39CD2A28C
D2998CD2A284D2A28CDBAB94DBB39CDBAB94D2A28CD2A284D2A284C09984D2A284C09984
C09984D2A28CC09984926E63895E4A9C5E4A9C5E4AC06652C9886BDB9984F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF643C29F7C4ADC96E52DB9984E5AB94
6444421B19212E2221402A29492A29775E52EECDB5F7D5BDF7D5BDEECDB5EECDB5EECDB5
F7D5BDF7D5C6F7D5BDF7D5BDF7D5C6EEC4ADDBAB94DBAB94EEBBADDBB39C775E52533C31
402A291B19185332295332296D5E5AA56652AD6E5AC06652DBA28CE5B39CEECDB5F7D5BD
F7DDCEF7DDCEF7E7DEF7D5C6EECDB5EEBBA5DBA28CD2887BB6806BB68063B68063A56652
6D2218774439C08873C9917BC08863AD7763AD806B9C6652926652AD7763C0917BC09184
C09984D2A284D2A284C09984D2A28CD2A28CD2A28CC09984C0917BC09984C09984D29984
D2998CD2998CC0917B92665289544A9C6652A56652C98063D2887BD2887BFFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5DDE7492A29492A21F7C4ADE5B39CF7C4ADE5B39C
774C42242221402A292E2221402A29775E52EEC4ADF7D5BDEECDB5EECDB5EECDB5F7CDB5
F7D5C6F7D5C6F7D5C6F7D5C6F7D5BDF7D5BDEECDB5E5B39CDBAB94DBAB94DBB3A5A5806B
926652644C4A926652774C42A56652B68063AD6E5AE5B394E5B394E5B394EECDB5F7D5BD
F7DDCEF7E7DEF7E7DEF7D5C6EEC4ADEEBBA5DBA28CD2887BC9886BB68063B6806BAD6E5A
9C6E52805442C0ABADD2C4BDB6B3BD774C396D2218643C29774C42926E63895452805442
AD7763AD806BAD8873AD8873C09973C0917BC0917BC0917BC9917BC9917BC09984D29984
D2998CC09984AD8873774C4280544A80544A926652D28873D29973C98063F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7533C31401918371918E5A28CF7C4ADE5B39CE5A28C
80544A403C392E2A391B19182E2221805E52EECDB5EECDB5EECDB5F7D5BDF7D5BDE5B39C
EECDB5F7D5BDEECDB5F7D5C6F7D5C6F7D5BDEECDB5EECDB5E5B39CD2A28CD2A28CDBB39C
D2A28CAD8873B68063AD6E5AB68063AD6E5AD2A284DB9984E5AB94E5BBA5EEC4ADF7D5BD
F7DDCEF7E7DEF7DDCEEECDB5EEC4ADE5BBA5DBA28CD29973C9886BB68063B6806BB68063
A566529C66529C807BDBCDD66D5E5A9C807B0908102E2A39774C42533C3177665A89544A
533C31926652926E639266529C6E52AD7763C9886BC9917BC09984D2A284C09984C09984
D29984C0917BA5806B774C42644439775E52774C42D29984DBA28CC96E52FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F777665A492A292E22212E1010643C29DB9173AD6E5A9C4C39
493C39372A312E2221242221402A29806E63F7CDB5F7CDB5F7D5BDEECDB5F7D5C6E5BBA5
C08873EEBBA5EECDB5F7D5C6F7D5C6F7DDCEF7DDCEF7D5C6EECDB5EEC4ADE5B39CE5B39C
DBAB94DBA28CD2A284D2A284DB9984DB9984DBA28CE5B394E5BBA5EEC4ADF7D5BDF7D5C6
F7DDCEF7DDCEF7DDCEF7D5BDEEC4ADEEBBA5DBAB94D29984C08873B68063C9886BB6806B
B68063AD6E5AC08873AD7763644442A5A2AD000810494C52644442533C319C807B807773
403C39533C316444426D5E52AD7763B68063C99173D2A284D2A28CD2A28CD2A28CC09984
C09984C0917B805E525B4C4A644439403231774C39D2A28CC9886BC96E52F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7FFFFFF492A29533229402A292E1010370808370808774C42402A29
2E2231403231242221242221402A299C6E5AEECDB5F7BBB5EECDB5EECDB5F7D5C6EECDB5
DB998CD2A28CDBAB94EECDB5F7D5C6F7DDCEF7DDCEF7D5C6F7D5C6EECDB5EEBBADE5B39C
DBA28CDBA28CDBAB94DBA28CDBA28CDB9984E5B394E5B394EEBBA5EEC4ADEEC4ADF7D5C6
F7DDCEF7DDCEF7DDCEEECDB5EEBBADE5B39CDBB39CD2A28CC99173C9886BC09973C09973
C9886BC09973D2A28CAD8873C088735B4C4A1B19211B1918533229402A29644C4A493C39
493C39775E52926652C09973B6806BC09973D2A284C99173C9917BD2A28CC09984C09984
D2A284C0917B644442644439533C31402A29643C31DB998CC96E5AC95E4AF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EEE7E7492A21492A295332292E22214019182E1010493C39372A31
2422211B19211B19212E22212E2221806E63EEC4ADF7CDB5F7D5BDF7D5BDEECDB5F7D5C6
EECDB5C9917BDBAB94D2998CEEC4ADEED5CEF7DDCEF7DDCEEED5CEF7D5C6EECDB5EEC4AD
DBAB94DBAB94DBB39CDBA28CD29973D28873D28873DBAB94E5BBA5E5BBA5EECDB5F7D5C6
F7DDCEF7DDCEF7D5C6EECDB5EEBBA5E5B39CDBAB94D2A28CC09984C9886BC9886BC99173
C9917BC99173B68063D2A28CD2A28C9C6E5A926E63774C42534442774C39403231805E52
A5806BA56E5AA5806BAD8873C08873C99173C0917BD2A28CC09984C09984C09984C09984
C09984A5806B644439403231534442492A29533229D2A28CC95E4AC96E52FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7A591A5492A29403231533C31492A29492A29402A29403231403231
1210181B1918402A291B1918492A29775E52EEC4ADF7CDB5F7CDB5F7D5BDEECDB5F7D5BD
F7D5C6EEBBADDBB39CA5807BB6806BC0917BC0917BAD8873AD8873926652926E63775E52
80544A895E4A895E4A8054429C6652A56652A56652C9917BDBB39CE5BBA5EECDB5F7D5C6
F7D5C6F7D5BDF7D5BDEEC4ADEEBBA5E5B39CDBB39CD2A28CC9917BC99173C9886BC9886B
C09973C9917BD2A284C99173D2A28CD2A284D2A28CC0917BC0917BA5806BA56E5AA5806B
A56E5AC09973C9917BC9917BD29973D29984C09984D29984D2A284D2A28CD2A28CD2A284
C09984775E52533C31493C39402A292E1918643C31B6806BB65442C96E52F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7ADA2A5402A292E22212E22212E22212422212E2221402A292E2221
2422211B19181B1921402A29402A29805E52EEC4ADEECDB5F7D5BDEECDB5F7D5BDF7D5BD
F7D5BDF7D5C6EECDB5EEBBADD2998C896E6B897773A58884A5776BA5776B926652805E52
9C6E5A89545289544A894C3989544AAD7763B6806BD29984E5B39CF7BBB5EECDB5F7D5C6
F7D5C6EECDB5EECDB5EEC4ADEEBBA5EEBBA5DBB39CDBAB94C98884C08873B68063B68063
B68063C08873C9917BDBAB94DBA28CD2A284C9917BC99173C09973C09973B6806BC99173
C9917BD29984D29973C09984D2998CC09984D29984C09984C09984C09984C09984C09984
AD8873644442372A312E2A39403C392E1918895E4AB6806BA55442C06652F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7C0ABBD5332293719182E19182E19182422213719182E2221090810
2E22211B19182422214032315344426D5E52DBB39CEEC4ADF7CDB5F7D5BDF7D5BDF7D5BD
F7D5C6F7D5C6F7D5C6F7D5BDEECDB5D2A28CD2998CD2998CA58884C98884D2998CC09184
C08873A5807BC0917BB6806BB6806BC9917BDBA28CEEBBADEECDB5F7D5BDF7D5C6F7D5C6
F7D5C6F7CDB5F7BBB5EEBBA5EEC4ADE5BBA5DBB39CDBAB94C98884B6806B925442805442
925442AD6E5AC09973C9917BD2A284DBA28CD2A284DBA28CDBA28CD2A284D2A284D2A284
C09984C09984D2A284D2998CC09984D2A28CD2998CC09984C09984D2998CD2A284C09984
A5806B533C31242221372A312422211B1918C08873B68063A55442C96E52F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7D2CDDE5332311B19182E22212422212E2221402A292E2221121018
2E22212E22211B1921242221534442805E52D2A28CEEC4ADEECDB5EECDB5F7D5BDF7D5BD
F7D5C6F7D5C6F7D5C6F7DDCEF7D5C6EECDB5EECDB5EECDB5F7D5C6F7D5C6F7D5C6D2C4BD
F7BBB5D2C4BDF7BBB5D2C4C6F7BBB5F7D5C6EECDB5EECDB5EECDB5F7D5C6F7D5C6F7D5C6
EECDB5EECDB5F7CDB5EEBBADEEC4ADEEBBADE5BBA5E5AB9CD2A28CC9917B926652774C42
7744397744399C6E5AB6806BC99173D2A28CD2A28CDBAB94DBA28CD2A28CD2A28CD2A284
D2A28CD29984D2A28CD2A28CC09984D2A28CC09984D2A284C09984D2A28CC09984D2A284
805E52402A292422212E22311B1921403231C99173C96E5AA55442C06652898084F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7E5DDEF6444392E22213719182422212E22212422212422211B1918
0908102E22212E2221402A295344426D5E52C09984E5BBA5EEC4ADF7CDB5F7D5BDF7D5BD
F7D5C6F7DDCEF7DDCEF7DDCEF7DDCEF7DDCEF7DDCEF7DDCEF7DDCEF7E7DEF7DDCEF7DDCE
F7DDCEF7DDCEF7DDCEF7DDCEF7DDCEF7D5C6F7D5BDF7D5BDEECDB5F7D5C6F7DDCEF7D5BD
EECDB5EECDB5EECDB5EEC4ADEEC4ADEEC4ADE5BBA5EEB3A5E5BBA5EEBBADD2A28CB6806B
89545280544A644439533229533C31774C42AD7763D2A284D2A28CD2A28CD2A284D2A284
D2A284C09984C09984C9917BC9917BC08873AD8873C9917BD2998CD2A28CD29984AD8873
6444392422212E22211B1921403C39492A29A56652B6806B9C4C39AD77635B4C4ADBCDD6
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7533231533C31402A292E22212422212E22212E22212E2221
0908102E2221242221402A29644439775E52C09984DBAB94EEBBA5F7CDB5F7D5BDF7D5BD
F7D5C6F7D5C6F7DDCEF7D5C6F7DDCEF7E7DEF7E7DEF7DDCEF7E7DEF7E7DEF7DDCEF7E7DE
F7E7DEF7E7DEF7E7DEF7DDCEF7DDCEF7DDCEF7DDCEF7D5C6F7DDCEF7D5C6F7D5C6EECDB5
F7BBB5F7BBB5EECDB5EEC4ADEEBBA5EEC4ADEEBBA5E5BBA5EEBBADE5BBA5DBB3A5DBB3A5
D2A28CB6806B89545280544A643C31533229533C31643C3180544AAD8873C09973C08873
C9917BC0917BAD8873AD7763926652926652B6806BD2A28CD29984D2998CD29984A5806B
492A292E22212E22212E22212E22312E1918774439A56652B680639C6E5A64545292888C
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F75344426444424032312E22212E22212422212E22212E2221
1B19181210182E2221533C31534442775E52C0917BD2A28CEEC4ADF7CDB5F7D5BDF7D5BD
F7D5C6F7D5C6F7DDCEF7DDCEF7DDCEF7DDCEF7E7DEF7E7DEF7E7DEF7DDCEF7E7DEF7E7DE
F7DDCEF7DDCEF7E7DEF7E7DEF7DDCEF7E7DEF7DDCEF7D5C6F7D5BDF7D5C6F7D5BDEECDB5
F7D5BDF7D5BDEEC4ADEEC4ADEEBBA5EEC4ADEEC4ADEEBBADEEC4ADEEBBADEEBBADE5BBA5
DBB3A5DBAB94D2998CA5806B926E6380544A644439533C31533C31774C4280544A926652
77665A80544A9266529C6E5A926652AD806BD2998CD2A28CD29984C09984C9917B9C6E5A
402A291B19182E22212E2231372A312E1918401918802A296D2A21533229645452ADA2A5
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7644439644439533C31402A292E2221402A292E22212E2221
242221090810402A29402A295344426D5E52AD8873D2A284E5B39CF7CDB5F7D5BDF7D5C6
F7D5BDF7DDCEF7D5C6F7DDCEF7D5C6F7DDCEF7DDCEF7DDCEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7DDCEF7DDCEF7DDCEF7DDCEF7D5C6F7D5C6F7D5C6EECDB5EECDB5
EECDB5EECDB5EEC4ADF7C4ADEEC4ADEEBBADEEC4ADEEBBADEEC4ADEEC4ADE5BBA5E5B39C
E5BBA5DBB39CDBB39CD2A28CC09984B6806B926E63895452644439644439774C39774C39
774C42774C42895452A56E5AB6806BC09984D2998CC09984C09984C9917BC0887380544A
2E22212E22212422212E22212422211B19182E0000531010533229493C396D5E52FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7DBD5E7644C4A644439644C4A403231242221402A292E22212E2221
2E2221372A31372A31493C39534442775E52A5806BB6998CDBB39CEEBBA5F7D5BDF7D5BD
F7D5BDF7D5C6F7D5C6F7D5C6F7DDCEF7DDCEF7DDCEF7E7DEF7E7DEF7DDCEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DDCEF7E7DEF7DDCEF7D5C6F7DDCEF7D5BDF7D5BDF7D5BD
F7D5BDF7C4ADEEC4ADEEC4ADEEC4ADEEBBA5EEBBA5EEC4ADEEC4ADEEC4ADEEBBADEEB3A5
E5BBA5E5AB9CDBB39CDBB39CD2A28CD2A28CC09984C9917BAD8873AD77639C6E5A926652
9C6E5AA56E5AC08873C09984C09984D29984C98884C09984C09984C9917BAD8873533C31
402A292E22212E2221402A292422212422211B1918402A29402A29402A2964545292888C
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7C9B3B56444395B4C4A644439533C31403231402A292E22212E2221
2E22212E22212E2221402A29533C31644442926E63C0917BDBAB94EEC4ADF7CDB5F7D5BD
F7D5BDF7D5C6F7DDCEF7D5C6F7DDCEF7DDCEF7E7DEF7DDCEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DDCEF7DDCEF7DDCEF7D5C6F7D5BDF7D5BDEECDB5EECDB5
EECDB5EEC4ADEEC4ADEEBBA5EEBBA5EEC4ADEEBBADEECDB5EEBBA5EEC4ADEEBBADE5B39C
E5B39CE5B39CDBB39CDBB39CDBAB94D2A28CD2A28CD2998CD2998CC9917BC9917BC98884
C98873C09984C09984D29984C09984D29984C98884D29973C09984C08873A5806B492A29
402A292E2221242221242221372A312422211B19211B19182E2221402A29372A315B4C4A
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F792888C644439644439533C31403231403231372A312E22212E2221
371918403231402A292E2221533C31533C31775E52A5806BD2A28CEEBBA5EECDB5F7D5BD
F7D5BDF7D5C6F7D5C6F7DDCEF7DDCEF7DDCEF7E7DEF7DDCEF7DDCEF7DDCEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DDCEF7DDCEF7DDCEF7DDCEF7D5BDEECDB5F7D5C6F7D5BD
F7CDB5F7CDB5EEBBA5EEC4ADEEC4ADEEBBA5EEC4ADEEBBA5EEBBA5E5BBA5EEBBA5E5BBA5
E5B39CE5BBA5E5AB94DBB39CDBAB94DBB39CD2A28CDBB39CDBAB94DBAB94D2A28CD2A28C
D2A28CD29984D29984D2A284D2998CD29984D29984D29984C9917BAD8873895E4A402A29
402A292422212E2221242221402A292422212422212E22212E22211B1918533C315B4C4A
C0ABADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F777665A533C315B4C4A644C4A534442403231533231402A292E2221
2E22212E22212E22212E2221402A29533C31644439805E52AD8873E5BBA5EEC4ADF7CDB5
F7D5C6F7D5C6F7D5C6F7D5C6F7DDCEF7DDCEF7DDCEF7DDCEF7DDCEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DDCEF7DDCEF7DDCEF7D5BDEECDB5F7D5BDF7D5BDEECDB5
EEC4ADEEC4ADEEC4ADEEBBA5EEBBA5EEC4ADEEC4ADEEBBA5EEBBA5EEB3A5E5B39CE5B39C
E5BBA5E5BBA5E5AB9CE5B39CDBB39CDBAB94DBB39CDBAB94DBAB94D2A28CD2A28CD2998C
D29984D2998CD2A28CD2A28CD2998CC09984D29984C09984AD88739C6E5A644439403231
2E22212422211B19214032311210181B19211B19212422212E2221121018372A31533C31
A5998CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7644C4A533C315344425B4C4A534442403231493C39402A292E2221
1B19182E22212E2221402A292E2221533C316444396444429C6E52D2A284EEC4ADEECDB5
F7D5BDF7D5C6F7D5C6F7D5C6F7DDCEF7DDCEF7E7DEF7E7DEF7E7DEF7E7DEF7DDCEF7E7DE
F7E7DEF7E7DEF7DDCEF7E7DEF7DDCEF7DDCEF7DDCEF7D5C6F7D5BDF7D5BDF7D5BDEEC4AD
EEC4ADEEBBA5EEC4ADEEBBA5EEBBA5EEBBA5EEBBA5EEC4ADEEBBA5E5B39CEEBBA5E5BBA5
E5B39CE5B39CDBAB94DBB39CDBAB94DBAB94DBB39CDBA28CD2A28CD2A28CDBA28CD2A28C
D2A28CD2A28CC09984C09984C09984C09984C09984C9917BA5806B6D5E52493C392E2221
1B19181B1921372A311210181B19211210181B19181B19180908101B1918402A29533C31
9C807BFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F75344425344425B4C4A5B4C4A644439534442493C39402A292E2221
402A291B19183719182E2221402A29402A29644C4A775E52774C42C0917BDBAB94F7CDB5
F7D5BDF7D5C6F7D5C6F7D5C6F7DDCEF7DDCEF7DDCEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7DDCEF7E7DEF7DDCEF7DDCEF7DDCEF7DDCEF7D5C6F7D5C6F7BBB5EECDB5
EECDB5EEBBADEEBBA5EEBBA5EEBBA5EEBBA5EEBBA5EEBBA5E5B39CE5BBA5E5B39CE5B39C
DBAB94E5B394DBB39CDBB39CDBAB94DBAB94DBAB94DBAB94D2A28CD2A28CD2A28CD2A284
D2A28CD2A28CD2A284D29984D2A28CD29984C9917BAD88739C6E5A644439402A292E2221
242221402A292422211B19211B19211B19181B19181B19181B19182422212E2221533C31
806E63F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7EFEFF7F7F76D5E526444395B4C4A5344425B4C4A5344424032314032312E2221
402A291B19182E22212E22214032314032315B4C4A6D5E52775E52B6806BDBAB94EEC4AD
F7CDB5F7D5BDF7D5C6F7DDCEF7D5C6F7DDCEF7DDCEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7DDCEF7E7DEF7DDCEF7DDCEF7DDCEF7D5C6F7D5C6F7D5BDEECDB5EECDB5
EEC4ADEEBBA5EEBBA5EEBBA5EEBBA5EEBBA5EEBBA5E5B394E5BBA5EEB3A5E5B39CE5B39C
E5B39CDBAB94DBAB94DBAB94DBAB94DBAB94DBAB94DBA28CDBAB94DBA28CD2A28CDBA28C
D2A28CD29984C09984C09984D29984C9917BC0917BAD806B805E52533C31402A29242221
403231402A291210181210181B19211210180908101210181B19212422212E2221403231
897773F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7644439533C316444395344425344425B4C4A493C39493C39402A29
402A29402A292E2221402A29402A292E2221533C3164444277665AB6806BD2A284E5BBA5
EEC4ADF7D5BDF7D5C6F7D5C6F7D5C6F7D5C6F7DDCEF7E7DEF7E7DEF7E7DEF7DDCEF7E7DE
F7E7DEF7E7DEF7DDCEF7E7DEF7DDCEF7DDCEF7D5C6F7D5C6EECDB5F7BBB5F7D5BDF7CDB5
EEBBADEEBBA5EEBBA5E5B39CE5B39CEEBBA5EEBBA5E5B39CEEB3A5E5B39CE5BBA5E5B39C
DBAB94E5AB94DBAB94DBAB94DBA28CD2A28CDBAB94DBA28CD2A28CD2A284DBA28CD29984
D2A28CD29984D29984D29984C9917BC99173AD8873926E63644442534442533C31403231
2422212422211B19211B19181210181210180908101210181B19182422211B1918533C31
EEE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F75B4C4A5B4C4A6444395B4C4A5B4C4A5B4C4A5B4C4A534442492A29
402A29402A291B1918402A29402A29403231644439774C42926652A5806BC9886BE5B39C
EEC4ADF7D5BDF7D5BDF7DDCEF7D5C6F7DDCEF7D5C6F7DDCEF7DDCEF7E7DEF7E7DEF7E7DE
F7E7DEF7DDCEF7E7DEF7E7DEF7DDCEF7DDCEF7DDCEF7D5C6F7D5C6F7D5BDF7D5BDEEBBA5
EEC4ADEEBBA5E5BBA5E5B39CE5B39CE5B39CEEB3A5EEBBA5E5B39CE5AB94E5AB94DBAB94
E5AB9CE5AB9CDBAB94DBAB94DBAB94D2A28CDBA28CD2A28CD2A28CD2A28CD2A28CD2998C
C9917BC09984D29984C09984C08873C08873926E63806E63644439493C39402A291B1918
1B19181B19181B19211210181210180908101B19181210181B1921242221402A29645452
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEF6444425344425344425B4C4A6444425B4C4A645452403231493C39
402A292E2221402A29402A29403231533C31534442644C4A805E52AD7763C08873DBA28C
EEBBA5EECDB5F7D5C6F7D5C6F7D5C6F7D5C6F7DDCEF7DDCEF7E7DEF7DDCEF7DDCEF7E7DE
F7E7DEF7E7DEF7E7DEF7DDCEF7DDCEF7DDCEF7DDCEF7D5C6F7D5BDEECDB5EEC4ADEEC4AD
EEC4ADEEBBA5E5BBA5E5B39CE5B39CE5BBA5E5B39CEEBBA5E5B39CE5B39CDBB39CE5AB94
DBA28CDBAB94DBAB94DBA28CDBAB94DBA28CD2998CD2A28CD29984D29984D2A28CD29984
D2A284D29984C09984C09984AD8873A5806B926E6380544A533C31402A292E22211B1921
2422311B19211B19211210181210181B19211210181B19181B19181B1918402A29644C4A
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7EEE7E7534442534442533C315344425B4C4A5B4C4A5B4C4A534442534442
2E22212E2221403231402A29403231533C31493C39644439926652AD7763C08873D2A28C
E5BBA5EECDB5F7D5BDF7D5BDF7D5C6F7D5C6F7DDCEF7E7DEF7DDCEF7E7DEF7E7DEF7DDCE
F7E7DEF7E7DEF7E7DEF7DDCEF7DDCEF7D5C6F7DDCEF7D5C6EECDB5F7BBB5F7CDB5EEBBA5
EEBBA5EEBBA5EEBBA5EEBBA5EEBBA5E5BBA5E5B39CE5B394E5B39CE5B39CE5AB94DBB39C
DBB39CDBAB94DBAB94DBA28CD2998CD2998CD2A28CD2A28CD2A28CD2998CD2A28CD29984
D29984C09984C09984C0917BAD806B9C6E5A9C6E5A644439533C31402A29402A29242221
242221402A292422212E22212422211B19211B19181B19212422212E2221402A29805E52
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7EEE7E7644C4A5B4C4A492A29534442644C4A5B4C4A6454525B4C4A534442
492A292E2221402A29403231402A294032316444426D5E529C6E5A9C6E5AAD7763C99173
DBAB94EEC4ADEECDB5F7D5BDF7D5BDF7D5C6F7D5C6F7DDCEF7E7DEF7DDCEF7E7DEF7DDCE
F7DDCEF7DDCEF7DDCEF7DDCEF7D5C6F7D5C6F7D5C6F7D5C6EECDB5EEC4ADEEC4ADF7C4AD
EEBBA5E5B39CE5B39CE5B39CE5B39CE5B39CE5AB9CE5B39CE5B39CE5B39CE5AB9CE5AB9C
E5AB94DBB39CDBAB94D2998CDBA28CDB998CD2A28CD2A28CC09984D29984D2998CD29984
D29984C9917BC0917BAD8873A5806B895E4A6D5E52644439492A29402A292E22312E2221
372A31402A291B19211210182422212422211B1921121018121018242221493C39EEE7E7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F76D5E52493C39493C396444395B4C4A5344426454525B4C4A533C31
5344422E2221403231403231493C39403231533C316D5E52806E63774C429C6E5AB6806B
DBA28CEEC4ADEECDB5EECDB5F7D5C6F7D5C6F7D5C6F7DDCEF7DDCEF7DDCEF7DDCEF7DDCE
F7DDCEF7DDCEF7DDCEF7D5C6F7D5C6F7D5BDEECDB5F7D5BDEEC4ADEEC4ADEECDB5EEBBA5
EEBBA5EEBBA5E5B394E5B39CE5B39CE5B39CE5B394E5B39CE5B39CE5B39CE5B39CE5AB94
DBAB94DBAB94DBAB94DBAB94DBA28CD2A28CD2A28CD2998CD29984C09984D29984D29984
C09984C09984AD8873A5806B9C6E5A6D5E52644442493C39402A29372A31242221242221
1B19182E22211B19211B19211210181210180008100908101210182E2221644442F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7806E6B534442493C396444395344426D5E525B4C4A5B4C4A534442
534442402A29242221533C31493C39534442403231644439644C4A6D5E52926652AD7763
D29984EEC4ADEEC4ADF7D5BDF7D5BDF7D5C6F7D5C6F7D5C6F7DDCEF7D5C6F7DDCEF7DDCE
F7D5C6F7D5C6F7DDCEF7D5BDF7D5C6F7D5C6F7D5C6EECDB5EECDB5F7CDB5EEC4ADEEBBA5
E5B39CE5B39CE5AB9CE5B394E5AB9CE5B39CE5AB94E5AB94E5AB9CE5B39CE5AB94E5AB94
E5AB94E5AB9CD2998CDB9984D29984D2A28CD2998CD2A284D2A284D29984D29984D29984
C9917BC08873AD806B92665280544A644439534442533C312E22212E22212E2221242221
2422211B19211B19211210181B19210008100908101210181B1918402A29806E63F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7897773644C4A493C39533C31493C395B4C4A5344425B4C4A493C39
493C395B4C4A402A29242221533C31403231534442533C316D5E52644442774C42A5806B
C08873E5B39CEECDB5EECDB5F7D5BDF7D5BDF7D5BDF7D5C6F7D5C6F7D5C6F7D5BDF7D5C6
F7D5BDF7D5C6F7D5BDEECDB5F7D5C6F7D5BDF7D5BDF7BBB5EEC4ADEEC4ADEEBBA5EEBBA5
E5AB94E5B394E5AB94E5B394E5AB9CE5B39CE5B39CE5B39CE5B39CE5B394E5A28CE5AB94
DBAB94DBAB94DBA28CDBA28CDBA28CD2A284D2A28CD2A28CD29984C09984C9917BC9917B
AD8873A5806B9C6E5A80544A644442533C31533C31402A292E2221242221242221242221
2E22212422211B19211B19211210180908101210181B1918402A29644439FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F78977736D5E5A493C39533C31534442493C39644C4A6D5E5A403231
534442493C392E1918402A292E2221493C395B4C4A403231534442644439644439926652
AD7763D2A28CE5B39CEEC4ADF7D5BDF7D5BDF7D5BDEECDB5F7D5C6F7D5BDF7D5BDF7D5C6
F7D5C6F7D5C6F7D5BDF7CDB5EECDB5EECDB5F7BBB5EEC4ADF7C4ADEEC4ADE5B394E5B394
E5AB94E5B39CE5B394E5B394E5B394E5B394DBAB94E5AB94DBAB94E5A28CDBAB94DBA28C
DBA28CDBA28CDB9984D2A28CDBA28CD2A28CD2998CD2A284D2A284C9917BC08873C08873
B6806B9C6E5A80544A774C42534442492A29402A292E22211B19181B1918242221242221
2422212422212422211B1921242221121018090810242221493C39644439F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7AD999C806E6B5344425344425B4C4A5344425B4C4A644C4A534442
533C31493C39493C392E2221403231403231534442534442493C39644C4A5B4C4A775E52
9C6E5AC9917BD2A284E5B39CEECDB5EEC4ADEECDB5EECDB5F7D5BDF7D5BDF7D5BDF7D5BD
F7D5BDF7D5BDEECDB5EECDB5EECDB5F7C4ADF7D5BDEEC4ADEEBBA5EEBBA5E5AB94E5B39C
E5B394E5AB94DBA28CE5AB94DBAB94DBA28CDBAB94E5A28CE5AB94E5A28CDBA28CDB9984
DBA28CDBA28CDB998CDBA28CD2A28CD29984D2A284D2A284C9917BC09984C0917BAD806B
A5806B9C6E5A774C42644439533C31402A292E22212E22211B19181B19181B19211B1918
2E22212422211B1921121018090810000810121018403231402A2977665AF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7D2BBC6896E6B644C4A533C315B4C4A534442534442644C4A6D5E5A
4032315B4C4A403231403231402A29403231493C395B4C4A5344425B4C4A5344426D5E52
80544AAD8873DBA28CE5B39CE5BBA5EEC4ADEEC4ADEEC4ADF7D5BDF7D5BDF7D5BDEECDB5
F7D5BDF7BBB5EECDB5EEC4ADEECDB5EEC4ADEEC4ADEEBBADEEBBADE5B39CE5B39CE5AB94
E5A28CE5AB94E5A28CDB9984DBA28CE5A28CDB9984E5B394DBA28CDBA28CDBA28CD2A284
D29973D29984D2998CD2A28CD2A28CD29984D29984C09984C0917BC0917BAD8873A5806B
92665280544A644439644439492A29402A292E22211B19181210181210181210181B1918
1B19180908100908100008100008100008101B1918403231493C39AD999CF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7806E63644C4A5B4C4A5344425B4C4A493C39534442645452
534442534442372A31372A31403231372A31493C39493C395B4C4A493C39533C31644442
644439926652A5806BC0917BD2A28CE5B39CE5B39CE5BBA5EEC4ADEECDB5EEC4ADEECDB5
EECDB5EECDB5EECDB5EEC4ADEEC4ADEEBBADEEC4ADEEC4ADE5BBA5DB9984DBA28CDB9984
DBA28CDBA28CDBA28CDB9984DB9984DBA28CDBA28CDB9984DBA28CDB9984DBA28CD29973
D29984D29973D29984D29984C9917BC0917BC0917BC08873AD8873AD77639C6E5A9C6E5A
926652644439533C31492A292E2221402A292422211B19181B19181B1918121018121018
121018090810000810000810000810121018402A29403231533229F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7FFFFFF8980846D5E525B4C4A644439644C4A53444253444A645452
534442533C314032312E2221402A29402A29372A315344425B4C4A644C4A403C39402A29
64444264444280544A9C6E5AAD8873C08873C9917BD2A28CDBB3A5DBB39CEEC4ADEEC4AD
E5BBA5D2C4B5E5BBA5EEBBA5EEC4ADE5B394EEC4ADE5BBA5E5BBA5DBAB94C09984D29984
D29984DBA28CD29984D29984D29984D2A284DB9984DB9984DB998CDB9984D29984D29984
D29973D29973D2887BD2887BC09973C9917BC08873B6806BAD806B9C6E5A9C6E5A80544A
774C42644439533C31492A212E22212422211B1918121018090810121018121018121018
1210180908100008100008100008101B1921402A29403231896E6BF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7C9BBC677665A644C4A493C395B4C4A534442534442534442
645452493C39533C31402A29402A292422215B4C4A493C39493C395B4C4A5B4C4A644C4A
4032316444426D5E52775E52775E52A5776BAD7763C0917BDBAB94C0917BD2A28CDBAB94
DBB3A5DBAB94DBB3A5DBB39CDBB39CDBAB94E5BBA5DBAB94D2A28CC99173AD806BB6806B
B6806BC99173C9886BD2887BD29984C9886BD29984C99173D28873D2887BD29984D29984
D29973C9917BC9917BC08873C08873C08873B6806BAD806BA5806B92665280544A774C42
643C31533C31402A292E22212E22210908101B1918121018121018121018121018121018
0908100008100008100008101210184032312E22212E2221EEE7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF806E636D5E5A534442533C31644C4A533C31534442
5B4C4A534442402A29533C31402A29402A29403231403231645452534C4A5B4C4A534442
5B4C4A6454526D5E5277665A806E6377665A9C6E5A897773AD8873AD806BA5806BAD8873
AD8873AD806BAD8873C0917BD2A284C98884D2A28CC0917BA5806B9C6E5A9C6E5A926652
9C6E5A9C6E5AB68063B6806BC08863B6806BC9886BC08873C9917BC9886BC9886BC08873
C08873C08873B6806BAD8873B6806BAD7763AD7763926E63805E52774C42774C42644439
533C31492A292E22212E22212422211210181B1918121018090810090810090810000810
000810000810000810121018372A31402A292E2221805E52FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A5888477665A5B4C4A493C395B4C4A534442534442
5344425B4C4A403C39402A29372A31402A29533C315344425344425B4C4A645452645452
5B4C4A6D5E5A5344426454526454526D5E52805E52926E63926652896E6B896E6B9C6E5A
806E63926E639C6E5A9C6E5AAD8873D2A284AD8873A5806B926E63926652926652805E52
895E4A805E529C6E52AD6E5AAD6E5AB68063B68063B68063C9886BB68063B6806BB6806B
A56E5AAD7763AD6E5AAD806BAD7763A56E5A926E6392665280544A774C42643C31492A29
492A29402A292E22212E22211B19181B1918121018121018090810090810000810000810
000810000810000810402A292422212E2221402A29EED5CEF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D2CDDE8977735B4C4A5344425344425B4C4A534C4A
403C396D5E52493C39402A29402A29372A31403231533C316454525B4C4A6D5E5A494C52
5344426D5E5A77665A6D5E5A645452805E529C6E5A6D5E5277665A775E52805E52805E52
805E5280544A92665280544A9C6E5A9C6E5AA5806B9C6E5A9C6E5A77665A775E52774C42
774C42805442774C42895E4A9266529C6E52A56E5AA56E5AAD7763AD7763A56E5A9C6E5A
9C6E5A9C6E5A9266529C6E5A926652926652926652774C42774C42644439533C31492A29
402A292E22212E1918242221121018121018090810121018090810000810000810000810
0008100008101210182E2221372A31242221533231F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A599A5644C4A5344425344425B4C4A493C39
534C4A534C4A534442403231242221403231493C395B4C4A645452645452645452645452
6D5E5A5344426D5E5A806E6377665A805E5277665A77665A6D5E52644442644C4A644C4A
6444396D5E52644442774C42774C42775E52805E5277665A644C4A6D5E52644C4A644C4A
774C42644442774C39774C39774C42805442926652926652926652926652895E4A775E52
926652805442805442895E4A805E5280544A774C426D5E52644439492A29402A29402A29
4032312422211B19181B19211B1918121018121018000810090810090810000810000810
0008100908102E2221402A291B1921533231A58884F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DBD5E7806E6B644C4A5344425344425B4C4A
493C39534C4A6454525344424032314032315B4C4A5344426D5E5A6D5E5A5B4C4A77665A
645452534442644C4A6D5E52775E5277665A6D5E526D5E52774C42644439493C39644C4A
493C39534442644C4A533C31644C4A6444396D5E52644439534442645452534442402A29
533C31493C39493C39533C31533C31533C31644439643C31643C31644439644439644439
644439533C31533C31533C31533C31533C31533C31533C31533229492A212E22212E2221
2422211B19211210181210181B19181B1921121018121018000810000810000810000810
1210182E22212E22211B1921403231644439FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5DDE7898084644C4A5344425344425B4C4A
5344425344425344425B4C4A534442493C395B4C4A6D5E5A64545277665A6D5E5A6D5E5A
5B4C4A5344425B4C4A644442644442775E52774C42644439644439493C39534442493C39
403231403231534442493C39402A29644C4A534442534442534442403C39493C39493C39
402A29403231403231402A29402A29492A29492A29533C31533C31533C31533C31533C31
533C31533229492A29533C31492A29403231402A29492A29402A294032312422212E2221
1B1918242221121018121018121018121018121018000810000810000810000810090810
2E22312422212E2221492A29534442D2C4DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C0ABAD8977735B4C4A5B4C4A533C31
5B4C4A403C39534C4A5344426D5E5A5B4C4A493C395B4C4A806E63534C4A6D5E5A6D5E5A
6D5E5A6D5E5A6454526D5E52644C4A6444395B4C4A644439644C4A403231534442534442
403C39403C395344425B4C4A534442403231534442534442533C31403231372A31403231
372A312E22212E2221402A29402A292E22212E2221492A292E2221402A29403231402A29
402A29402A29402A292E2221402A292E2221402A292E2221402A292E22212E2221242221
1B1918242221121018090810121018000810090810000810000810000810000810242221
242221402A291B1921492A29A5807BF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D2C4CEADA2A55B4C4A5344425B4C4A
534442534C4A5B4C4A5344425344426D5E5A6D5E5A806E6B493C396454526454525B4C4A
493C394032315B4C4A644C4A775E52533C315B4C4A644442534442534442534442493C39
493C39534442644C4A403C39372A31372A31403C39402A29402A29402A29402A292E2221
2E22212422212422212E22212E22212E2221402A29242221402A292E22212E2221242221
2E2221402A292E22212E2221402A292E22212E22211B19182E22212422211B1918090810
1B19181B1918121018000810121018090810000810121018000810000810121018242221
4032311B1921402A299C8084F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFC9BBC6896E6B5B4C4A534442
5B4C4A534442403231493C39534C4A4032316454526D5E5A6D5E5A6D5E5A403C39493C39
6D5E5A806E636D5E52534442644442533C31493C39493C39403231403231534442534442
402A292E22312E2231403C39372A312E2231402A292E2231402A292E2231242221242221
1B19212422211B19212422212422212422212E22211B19182E22212E2221402A292E2231
1B19182422212422211B19182E22211B19212E22211B19181B19212E22211B1921242221
121018121018121018090810000810000810000810000810121018242221242221242221
2E22212E2221805E52EEE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DBCDD6C9BBCE644442534442
5B4C4A5B4C4A5B4C4A493C39534442534C4A403C395344426454526D5E5A6D5E5A645452
534C4A534C4A493C395B4C4A644439403231403231534442493C39372A31493C39493C39
2E2A392E2231403C39534442372A312E2231402A292422212E2231242221242221242221
2422211B19211B19181B19212422211B19212422211B19212422212422211B1918402A29
1210181B19181B19181B19182E22212E22211B19181B19181210182422211B19181B1918
1B19211210181210181210180008100008101210181B19212422211B19214032312E2221
402A29774C42F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DBCDD677665A534442
493C395B4C4A5B4C4A534C4A534442534C4A5344426D5E5A534C4A5344425344426D5E5A
6D5E5A806E6B534442403231533C31402A29402A29493C39493C39402A29534442403231
493C392E2A39403C39372A312E22212422212E22311B19211B1921372A312422311B1921
1B19211B19211210181210181210182422212422211B19181210182422212422211B1918
2422211B19211210182422211210182422211B19181210181B1921121018090810121018
0008100008101210180008100008100908101210181B19211B1921493C392E2A39402A29
644442EEE7E7EEE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F789777377665A
534442493C395B4C4A493C39534442403C395B4C4A403C39534C4A6D5E5A5B4C4A534442
493C395B4C4A403231534442403231402A292E22212E2221493C39402A29372A31402A29
372A311B19212E22211B19212E2231402A291B19212422211210181B19211B19212E2221
1B19211210181210181210181B19211210181210182422211B19211210181210181B1921
1B19211B19212422210908101B1921121018121018121018000810121018000810000810
0008100008100008100908101B19211B19211B19182422211210182422212E1918926652
EEE7E7EEE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5DDE79C807B
77665A5344425B4C4A5344425B4C4A534C4A534442534442534442403C395344425B4C4A
534442403C39402A29534442403231402A292422212E2221372A31372A312E22212E2231
372A3140324A1B19212E2A392E22211B19212422211B19211B19211B1921242221242221
1210181210181210181B1921121018121018121018242221242221121018121018121018
1B19211B19211210182E22311B19211B1921121018090810000810090810000810000810
0008101210181B19212422311B19211210182E22311B1921242221402A29774C42A5998C
EEE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C9B3BD
8977736D5E52493C395B4C4A534442534C4A534C4A6D5E5A534C4A5B4C4A645452645452
53444A403C39402A295B4C4A4032312E22212422212422212E2221372A312422212E2221
2E2221403C39121018372A311210182422211B19211210181B19211210181210181B1921
1B19211210181210181210181B19211B19211210181B1921402A291B1921000810121018
1B19211B19212422211210181B1921121018000810000810000810000810090810121018
1B19212E22311B19211B19211B1921242221402A292E2221533C316444399C6E5AE5DDE7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
C0ABAD806E6B5B4C4A5344425B4C4A493C39534C4A493C39534C4A494C52534C4A534442
493C39403C392422215B4C4A402A29372A311B19212422211B19212E22212E22211B1921
1B19181B19181210181B19211B19211210181B19211210181B19211210181B1921121018
1B19211210181210181210181210181B19211210181B19212E2A392E2A392E2A39121018
1210181B19211B19211B19212422311B19212422212422312422212422212422211B1921
2E22311B19181210181B1921372A312E22212E2221533C31533C31926652896E6BF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7C9BBCE896E6B645452534C4A5B4C4A493C39534C4A6454526454526454526D5E5A
645452534C4A403C39534442493C392E22212E22311B19211B19211210182E22211B1921
1B19211B19182422211210182422211210181B1921121018121018121018121018121018
1210182422211210180008101210181210182422211B19211B1921403C39494C63534442
494C521B19212E22311B19211210181B19211B19211B19212422212E22312422211B1921
1B1921403C39493C39242221403231533C31402A2964443980544A806E63F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7806E7B8977736454525B4C4A534C4A493C39534442534C4A645452645452
64545253444A403C39645452493C39402A29402A292E22211210181B1921242221242221
1B19211210181B19181210182422211B19211B19210908101B19211B19211210181B1921
1210181B192112101812101800081012101812101840324A2E2A39242239494C526D5E5A
2E22312E22312E2A392E2A39403C392E22312422212422211B1921242221402A29492A29
493C39372A31402A29403231402A29533C31533C31774C42926652F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFF806E7B896E6B6D5E5A645452534C4A493C39534442534C4A535463
6D5E5A534C4A645452534442533C31403C394032312E22212422211210181B1921242221
1210181B19181B19182422211B19212422211210181B19211210181B19211B1921121018
1210181210181B1921121018121018121018121018000810494C5240324A40324A2E2A39
6D5E5A5B5E6B6D5E5A49445A53444A53444A64545253444A493C39402A29242221242221
403231403231403231493C395B4C4A644439774C42775E52F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F792889C77665A5B4C4A534C4A5B4C4A493C395344425B4C4A
6454525B5E6B6D667B6D5E5A493C39493C39533C31403231402A291B19211B1921242221
2E22211B19181B19211B19181210182422211210181210181210181210181B1921121018
1210181210181B19211B19210008101210182422211B192112101824223140324A534442
494C52403C392422311B1921242221372A31403231493C39493C39493C39493C395B4C4A
534442534442534442533C31533C31644442926652897773F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7805E526454526D5E5A5344425B4C4A645452
6D5E5A6D5E5A6D5E5A806E6B6D5E5A403231403231403231403231372A31534442242221
403C39372A312E22212E22312422211210181B19211210181B19211B19211210181B1921
1210182422212422311B19211B19211B19212422212E2A391B19212E2231403C39242239
53444253444A1B19212422212422212E22312422212422211B1921372A312E2221403C39
403231402A29533C31774C42926652895452DBCDD6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7ADA2AD806E635B4C4A5B4C4A5B4C4A534C4A
6454526D5E5A806E6B898084806E7B5B4C4A492A29403231403231402A29402A29403231
493C39493C39493C392E22212E2231242231402A291B19211B19211B19212422212E2231
1B19211B192140324A2422212E2A392E22312422212E2231494C522E2A392E2A392E2A39
242231242221403C39403C39372A31493C39403C39403231402A29534442533C31402A29
533C3164443964443980544A775E52DBCDD6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D2C4DE806E635B4C4A493C39534442
5B4C4A6D5E5A806E6B806E6B807773806E6B6D5E5A403C39403231402A29372A31402A29
402A29534442534442493C39403C396454521B19212E2221121018372A312E2A392E2231
2E2A3937324A403C39403C392E2A396D6E7B5B4C4A5354632422315344426D5E5A494C52
53444A534442534442534442534442493C39493C395344425344425B4C4A6D5E525B4C4A
534442774C429C6E5A775E52F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F789809477665A645452
5B4C4A6D5E5A80777380777392888C898084807773806E6B644C4A6D5E5A77665A534442
493C3937191853444253444264545249445A534442534C4A493C392422391B19215B5E6B
53444A494C526D5E5A6D6E7B49445A49445A494C526D5E5A5B5E6B535463645452534C4A
5B4C4A6D5E52644C4A645452644C4A644C4A644C4A5B4C4A493C39533C316444396D5E52
895E4A6444429C8084FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D2C4CE897773
6D5E5A6D5E5A5B4C4A645452645452806E7B6D6E7B807773806E6B807773806E6B806E6B
8077736D5E5A53444A5B4C4A494C526D5E5A6D667B6D5E5A807773494C5253444A2E2231
49445A40324A53444A494C526D667B6454525B4C4A5B4C4A5344425B4C4A6454526D5E52
644C4A644C4A6444425344426444396444395B4C4A774C42775E5280544A9C6E5A6D5E52
644439C9B3BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
ADA2AD5B5E6B6454526D5E5A645452806E6B898084807773806E6B806E6B77665A806E6B
807773806E6B806E6B806E6B5354636D5E5A645452806E6B5B5E6B6D5E5A6D6E7B49445A
40324A40324A2E2A39403231493C396D5E5A5B4C4A5B4C4A5B4C4A493C39493C39533C31
533C31533C31493C39644442774C426D5E52775E5280544A80544A775E52644439644442
D2C4D6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7C9BBC6806E7B6D5E526D5E5A6D5E5A5B5E6B806E7B92888C807773898084807773
80777377665A807773897773898084807773897773807773806E6B898084645452807773
6D5E5A5B4C4A53444A53444A493C39403C395344426D5E5A6454525344425B4C4A5B4C4A
774C42644C4A80544A6D5E52805E52806E63926E639C6E5A774C425344429C8084FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7E5DDEF5B5E6B403C525B4C4A5354636D6E7BA59194806E7B
92888C89808492888C897773806E6B8077739C807B897773897773897773806E639C807B
89777389777377665A77665A806E6B806E63805E5277665A926652805E5277665A896E6B
896E6BA5776BA5806BA5806B806E63644C4A534442775E52C9BBC6F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5DDE7A599B580778C80778CA591949C91A5
C0B3C6AD999CAD999CAD999C9C807B9C807B8977736D5E5A8977739C807B9C80849C807B
9C807B9C807B8977738977739C807B896E6B806E63896E6B897773A5776B9C807BA5806B
806E6377665A806E63644C4A644C4A806E63C9B3BDFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5DDEF
EEE7E7D2C4D6C0B3C6B6B3BDC0B3C6A59194A591949C8084897773896E6B8077736D667B
8077738977738977739C807B806E6B896E6B806E6B896E6B806E63896E6B806E6377665A
775E5277665A775E52897773A599B5FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7EEE7E7E5DDEFEEE7E7F7EFEFEEE7E7D2C4D6C9BBC692889CA591A592889C898084
8977738977738977738977738977739C807B897773806E6B806E6B806E63775E52645452
77665AA591A5F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFE5DDE7DBD5E7C9BBC6DBCDD6D2C4DEEEE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Red) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EEEEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEEEEE
E5E5E5E5DBDBDBDBDBDBDBDBDBDBDBD2D2DBD2D2D2C0D2F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEEEE5E5E5
E5E5DBDBDBDBDBDBDBDBDBDBDBDBD2D2D2D2D2D2D2C0D2F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEEEEEEEE5E5DBE5
DBDBDBD2D2DBDBDBDBDBDBDBDBD2DBDBD2DBD2D2D2C0D2F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7EEEED2D2E5E5DBDBDBDB
DBDBDBDBDBD2DBD2D2DBDBDBD2DBD2D2DBD2D2D2D2D2F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EEEEF7F7F7F7F7F7F7F7F7F7F7F7D2EED2D2E5E5E5E5DBDBDBDBDB
DBDBDBDBDBD2D2D2D2D2D2DBD2DBD2DBD2D2D2D2D2DBF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D2F7F7F7EEEEEEE5E5E5DBDB
DBDBDBDBD2C0D2D2D2D2D2DBDBDBD2DBD2D2D2D2D2D2F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7EEF7F7F7F7EEF7F7EEE5E5E5DB
E5EEE5DBDBD2D2DBD2D2D2D2D2DBD2D2DBD2D2D2D2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7F7F7EEEEEEF7F7F7F7F7EEF7F7EEEEEEE5E5
E5EEEEEEE5DBDBD2D2D2D2DBD2D2DBD2DBD2D2D2D2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EEF7F7F7F7F7F7F7EEF7F7F7F7F7F7F7F7F7F7F7F7EEEEEEEEEEE5
EEEEE5EEEEE5DBE5DBD2DBDBD2DBDBDBDBD2D2D2DBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EEF7F7F7F7EEF7EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7F7EEEE
EEEEEEEEEEE5E5DBDBDBDBDBDBD2DBDBDBDBD2DBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEE
EEEEEEEEE5E5E5E5DBDBDBDBDBDBD2DBD2D2D2DBEEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EEEEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7
F7EEEEE5EEE5E5E5E5DBDBDBD2D2DBD2D2DBD2DBEEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7E5DBEEF7EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EE
F7EEEEEEEEE5E5DBE5DBDBDBD2DBD2DBDBDBD2DBEEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F777EEF7EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EEEEEEEEE5E5E5E5E5DBDBD2DBD2D2DBDBDBDBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F78053EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7F7
EEEEEEEEEEE5E5E5DBE5DBDBDBD2D2DBDBDBDBDBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F75B4080F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEEEEEEE
EEEEE5E5EEE5E5E5E5E5DBDBDBD2D2D2DBD2EEDBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7D25349EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEE5EE
EEEEEEEEE5E5DBE5E5DBDBDBD2D2D2D2D2D2D2D2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F74964F7EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEEEEEE5
EEE5EEE5E5E5DBE5E5DBE5DBDBD2D2D2D2DBDBDBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FF6D53F7EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7EEEEEEE5E5E5
E5E5E5E5E5E5DBDBDBDBDBDBDBD2DBD2D2DBDBDBEEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F78953B6EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7EEE5E5E5E5E5
E5E5E5E5DBDBDBDBDBD2DBDBDBD2DBDBDBDBDBDBD2EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F75380F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7EEE5E5E5E5E5
E5E5E5DBDBDBDBD2DBD2D2DBDBD2DBDBD2DBDBD2D2D2F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7C953F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7F7F7F7F7F7F7F7F7F7F7F7EEEEE5E5E5EEE5
E5E5E5E5DBDBD2D2D2D2D2DBDBDBDBDBD2DBD2D2D2DBEEF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
D253EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DBF7F7EEE5E5E5DBDBE5E5
DBDBE5E5D2E5D2D2D2D2D2DBDBDBDBDBDBDBDBD2DBDBDBF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
6D80EEF7F7F7F7F7F7F7F7F7F7F7F7EEF7F7F7F7F7F7F7F7F7F7EEE5D2DBDBDBDBDBDBD2
DBDBDBDBE5D2C9DBDBD2D2D2DBDBDBDBDBDBDBD2D2DBDBEEF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F792
49F7EEF7F7F7F7F7F7F7F7F7F7F7EEEEEEEEF7F7F7F7F7F7EEE5E5D2DBE5C0F7DBADE5D2
D2C9D2DBDBD2D2D2D2D2D2D2D2DBDBE5DBDBDBD2DBDBDBDBF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C05B
49F7F7F7F7F7F7F7F7F7F7F7F7F7EEE5E5EEF7F7F7EEE5E5D2ADC0E5D2D2C9C9EEB6D2C9
A5D29CC9D2D2D2D2D2D2D2D2DBDBDBE5DBDBDBDBDBDBDBD2DBE5E5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5AD49
C0F7F7F7F7F7EEEEF7F7F7F7F7F7E5DBDBF7F7E5E5C977D2E5DBE5DBEEF7F7EEE5E5C9C9
B6B6C09C9CC9D2C9C9D2D2D2DBDBDBE5E5E5DBDBDBDBDBDBDBD2F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A59240
EEF7F7F7F7F7EEEEF7F7F7F7F7E5E5DBE5EEDB9289EEF7F7F7F7F7F7F7F7F7F7EEEEEEEE
D2ADAD89A564B6C0D2DBD2D2DBDBE5E5E5E5DBDBD2DBDBDBDBD2F7D2E5F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7805377
EEF7F7F7F7F7EEF7F7F7F7F7F7E5DBC9D2AD8092D2F7F7F7F7F7F7F7F7F7F7F7EEF7F7EE
EEE5C0A5894964B6C0D2D2D2DBDBE5EEE5E5E5DBDBDBDBDBDBDBDBF7EEF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7F7F7E5F7F7F78949C0
F7F7F7F7F7F7EEF7F7F7F7F7E5E5C9C992776DADE5F7F7F7F7F7F7F7F7F7F7F7E5F7F7EE
F7D2D2EE9CA53737ADC9D2D2D2DBE5EEEEE5E5DBD2DBDBDBDBDBC9C9D2F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DB5340F7
EEF7F7F7F7EEF7EEF7F7F7F7E5DBC0D2B69C77E5E5DBEEF7EEF7F7E5F7F7F7E5E5EEEEF7
E5EEF7EED2DBB6B6649CC0D2D2DBE5EEEEE5E5DBDBDBDBDBDBDBD2A5C9D2DBF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C9531B64D2
F7F7F7F7EEEEF7EEF7F7F7EEE5C9DBE5E5E5DBDBE5E5DBE5E5E5E5E5EEF7D2DBDBE5E5E5
D2E5EEE5DBDBD2B69C6D9CC9D2DBE5EEEEEEE5DBDBD2D2D2DBDBDBDBD2C9D2E5F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7802E402EC0F7
F7F7F7F7F7EEF7E5F7F7F7F7E5C9E5EEEEF7F7F7F7EEEEEEE5EEE5E5EEEEDBDBDBDBDBC9
D2D2DBC9D2EEC9D2A553649CD2D2E5EEEEEEE5DBDBD2D2DBDBDBDBF7F7DBD2DBF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5D22E1B532EF7F7
F7F7F7EEEEF7EEEEF7F7F7F7E5C9E5EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEE5E5DB
E5D2D2C0C0D2C0AD9C2E64779CD2E5EEEEEEE5DBDBD2D2DBDBDBDB9CADDBE5DBEEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DB921B402E49F7EE
F7F7F7EEF7EEEEEEF7F7F7EEE5DBC9EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEEEE5E5
E5DBDBD2E5D2D2C0B69292AD9CD2DBEEEEEEE5DBDBD2D2DBDBDBDBB664F7F7EEEEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E54992D2AD80F7F7
F7F7F7EEF7F7F7EEEEF7EEEEE5E5DBE5EEF7F7F7F7F7F7F7F7F7F7F7F7F7EEEEE5EEEEE5
E5E5DBDBD2DBDBDBD2D2D2C9C9C9DBE5EEEEE5DBD2DBD2DBDBDBDBC08077F7EEF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DB77F7EEEEEEEEEE
F7F7F7EEF7F7F7F7F7F7F7EEE5E5DBDBEEEEF7F7F7F7F7F7F7F7F7F7F7EEEEE5EEEEE5E5
E5DBD2D2D2D2D2D2D2D2D2D2C9D2D2E5E5EEE5DBDBD2D2D2DBDBDBC06DC9D2F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B6EEF7F7F7EED2EE
EEF7F7F7F7F7F7F7F7F7F7EEEEE5E5DBE5EEF7F7F7F7F7F7F7F7F7F7F7EEEEE5E5EEE5E5
E5DBD2D2C9C9C9C9C9C9D2D2D2D2DBE5EEE5DBDBD2D2D2D2DBD2D2C91BC9F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DBF7F7F7F7F7EEEEF7
EEF7F7F7F7F7F7F7F7F7F7F7EEEEE5E5DBEEEEF7F7F7F7F7F7F7F7F7F7EEEEE5E5E5E5DB
D2D2C0C9C9C9C9C9C9C9C9C9C9D2DBD2E5E5E5DBD2D2D2D2D2DBD2B64089E5F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DBF7F7F7F7F7EEF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EEE5E5DBE5EEF7F7F7F7F7F7F7F7F7EEEEE5E5E5DBDBDB
D2D2C9C9C9C9C9C9C9C9C9C9C9D2DBE5DBDBDBDBD2D2D2D2D2DBD2B61B5389F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7F7F7EEF7E5F7D2F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEE5E5E5EEF7F7F7F7F7F7F7EEF7F7F7E5E5E5DBD2D2
D2D2C9C9C9C9C9D2D2C9C9C9C9DBE5E5E5E5DBD2D2D2D2DBD2D2DBB61B2EC9F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEE5DBF7EEF7
F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEE5E5DBE5EEF7F7F7F7F7F7F7F7F7F7EEEEE5DBDBD2
B6C9C9C9C9C9C9D2D2D2C9D2DBE5E5E5DBDBDBDBD2D2D2D2DBD2D29C376DF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5E5DBF7EEF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEE5E5E5EEF7F7F7F7F7F7F7F7F7F7EEEEE5DBDBDB
DBC9C9B6C9C9C9D2D2D2DBDBE5E5E5E5DBE5DBDBDBD2D2D2D2D2D2A52E4053E5F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEDBE5E5EEF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7F7EEE5E5E5F7F7F7F7F7F7F7F7F7F7EEEEE5E5DBDB
DBDBD2DBB6C0C9C9D2DBDBE5E5E5E5E5E5E5DBDBDBD2D2D2D2D2DBAD64491B80DBF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7F7EEEEC9D2EEEEF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7F7E5E5E5EEEEF7F7F7F7F7F7F7F7F7EEE5DBDBDBD2
D2D2D2DBD2B6C9D2D2DBE5E5EEEEE5E5DBDBDBDBD2DBD2D2D2D2DBD2C09C774953A5F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5DBDBDBEEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEE5F7F7F7EEEEF7F7F7EEF7EEDBDBD2D2D2
D2D2D2D2C9B6C9D2DBE5E5E5EEE5E5E5DBDBE5DBDBDBD2DBDBDBDBD2D2C9B65380E5F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5DBD2D2D2E5D2F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7EEEEEEF7F7F7F7EEEEEEF7F7F7EEE5E5DBD2D2C9
C9C9D2C9B6C0C9DBDBE5E5E5EEEEE5E5DBE5DBDBDBDBD2D2DBDBDBD2D2D2D2B6F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5E5D2C9DBE5EEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7EEEEEEF7F7F7F7F7F7F7F7F7EEEEE5DBD2C0C0C9
C9C0C9C9C9C9D2DBDBE5EEEEE5EEE5E5E5E5DBDBDBD2D2D2D2DBDBC9C9D2D2C0F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7F7E5DBD2C9D2EEEEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEF7F7EEF7F7F7F7F7F7F7F7EEF7EEE5DBD2C9C9C0
C0C0C0C9C9D2DBDBE5E5E5E5EEE5E5E5DBDBDBDBDBDBDBD2D2D2DBC9C9D2D2DBFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5E5C9C9DBEEEEF7F7F7
F7F7F7F7F7F7F7F7F7F7EEF7EEF7F7EEEEEEEEF7F7F7F7F7F7F7F7F7EEE5E5DBD2C0C9C9
C9C9C9D2D2DBDBE5E5EEEEE5EEE5E5E5E5DBDBD2D2D2D2D2D2D2DBD2D2D2D2D2F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7F7E5DBC9C0DBEEF7F7F7F7
F7F7F7F7F7F7F7F7EEEEF7F7F7EEEEEEEEEEEEF7F7F7F7F7F7F7F7F7F7EEE5DBD2C0C9C9
C9C0C0D2D2DBDBE5E5EEEEE5E5E5E5DBDBDBDBDBDBD2D2D2D2D2DBD2DBD2D2D2D2F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5F7E5E5DBB6C0DBEEEEEEF7F7
F7F7F7F7F7F7F7F7EEEEEEEEEEEEEEEEEEEEEEEEF7F7F7F7F7F7F7F7F7EEE5DBD2D2C0C9
C0C0D2D2DBDBE5E5E5E5E5E5E5E5E5E5E5DBD2D2D2D2D2D2D2DBE5C9D2D2DBD2DBF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5E5C9DB9292ADB6E5EEF7F7F7F7
F7F7F7F7F7F7F7F7EEEEEEEEE5EEEEEEEEEEEEEEF7F7F7F7F7F7F7F7EEEEE5DBD2C9C9C9
C9C0D2D2D2DBE5E5E5E5E5E5E5E5E5E5DBDBDBDBD2D2D2D2D2D2DBA5C9D2DBD2D2EEF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5D2C980A5808992E5F7F7F7F7F7
F7F7F7F7F7F7EEEEEEEEEEEEE5E5E5E5EEEEEEEEEEF7F7F7F7F7F7F7EEEEE5D2D2C9C0C9
C9C9D2D2D2DBDBE5DBDBE5E5E5E5E5E5DBD2DBD2D2D2D2D2D2D2C0ADC0C9D2D2D2F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DBC964D28077649CE5F7F7F7F7F7
F7F7F7F7F7EEF7F7F7F7F7EEEEEEE5E5DBE5EEEEEEF7F7F7F7F7F7F7EEE5DBD2C9C9C9C9
C0D2D2D2DBDBDBDBDBE5E5E5DBDBDBDBD2DBD2D2D2D2D2D2D2C0D2ADC0C9C9DBD2DBF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5E59CAD5380807777E5F7F7EEF7F7
EEF7EED2EEF7F7F7F7F7D2F7F7D2E5E5DBDBDBDBEEEEF7F7F7F7F7F7EEE5DBD2C9C9C0C0
C9C0D2D2DBD2DBDBDBDBDBDBD2D2DBDBDBDBD2D2D2D2D2D2D2C0D2AD9C9C9CC9D2D2F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DBE5A5AD2E64406477E5F7F7EEEEF7
F7F7F7EEDBC0DBD2C0C9C0C0C0D2C9D2DBDBDBDBE5EEF7F7F7F7F7F7EEE5DBC9C9C9C9C0
C0C9C9C9C0D2C0D2D2D2DBDBD2DBDBDBDBDBD2D2D2D2D2C0D2DBD2AD9CA59CB6C9D2F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DBE5B6641B1B2E5364EEF7F7F7F7F7
F7EEEEDBC0AD776492B6B69C929CADADC0D2C9DBE5EEF7F7F7F7F7F7EEE5DBD2C9C9C0C0
B6ADC0D2D2C9C0D2D2C0D2DBDBDBDBE5DBD2D2D2D2D2C0C0D2D2D2A59CA5A5B6C9DBF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEE5E5D22E2E2E40406DEEF7EEF7F7F7
F7F7F7EEEEDBC064A5C96DA553127764ADA5A59CA5E5EEF7F7F7F7F7EEE5DBD2C9ADC0B6
B6C0D2DBDBDBDBDBDBD2D2D2C0D2DBDBDBDBD2D2C0D2C0D2D2D2D2ADA5A5A5B6C9D2F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFE5C9E5EE40242E405364EEF7F7EEEEEE
F7F7F7EEEED2DBC09C49498977126477B6AD80A5D2EEEEF7F7F7F7F7EEEEDBD2C9B6ADAD
B6D2DBDBDBDBDBD2D2DBDBD2D2D2D2DBDBDBD2D2D2C0D2C0C0D2C092899C9CC0C9DBF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF64F7C9DBE5641B2E404977EEF7F7EEEEEE
F7F7F7F7F7EEDBDBEEDB7753401B53536DA5ADC0DBE5EEF7F7F7F7F7EEEEDBD2B6B6B6A5
6D77C0C9C0ADAD9C92ADC0C0C0D2D2C0D2D2D2C0C0C0C0D2D2D2C092899CA5C9D2D2FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E54949F7E5F7E57724402E4077EEF7EEEEEEF7
F7F7F7F7F7F7EEE5DBDBDBA592649277A5B6ADE5E5E5EEF7F7F7F7F7EEEEDBD2C9B6B6AD
9C80C0D2B6776D6477928980ADADADADC0C0C0C0C9C9C0D2D2C0AD77808092D2D2C9F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7534037E5F7E5E580402E1B2E80EEEEEEF7F7E5
EEF7EEF7F7F7EEEEE5D2D2DBD2ADB6ADB6ADD2DBE5E5EEF7F7F7F7EEEEE5DBD2C9B6B6B6
A59C9CDB6D9C092E77537789539292929CADC9C9C0D2C0C0D2C0A577647777D2DBC9FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F777492E2E64DBAD9C49372E244080F7F7F7EEF7E5
C0EEEEF7F7F7F7F7EEEEE5E5DBDBD2D2DBDBDBE5E5EEF7F7F7F7F7F7EEEEDBD2C0B6C9B6
B6ADC0AD64A5004964539C804053646DADB6C9D2D2D2D2C0C0C0805B644077D2C9C9F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF4953402E373777402E402424409CEEF7EEEEF7EE
DBD2DBEEF7F7F7F7F7EEEEE5DBDBDBDBDBDBE5E5EEEEEEF7F7F7F7EEEEE5DBD2C9C9C0C0
C9C0D2ADC05B1B1B53406449497792C0B6C0D2C9C9D2C0C0D2C06464534064DBC9C9F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EE4949532E402E4937241B1B2E2E80EEF7F7F7EEF7
EEC9DBD2EEEEF7F7EEF7EEEEDBDBDBDBD2D2D2DBE5E5EEF7F7F7F7EEEEE5DBD2C0C9C9C9
C9C9B6D2D29C927753774080A5A5A5ADC0C9C0D2C0C0C0C0C0A56440534953D2C9C9FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A54940534949404040121B401B4977EEF7F7F7EEF7
F7EEDBA5B6C0C0ADAD929277808989809CA5A5C9DBE5EEF7F7F7F7EEEEE5DBD2C9C9C9C9
C0C9D2C9D2D2D2C0C0A5A5A5A5C0C9C9D2D2C0D2D2D2D2D2C0775349402E64B6B6C9F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD402E2E2E242E402E241B1B404080EEEEF7EEF7F7
F7F7EEEED28989A5A5A592809C89898989ADB6D2E5F7EEF7F7EEEEEEEEEEDBDBC9C0B6B6
B6C0C9DBDBD2C9C9C0C0B6C9C9D2D2C0D2C0D2C0C0C0C0C0AD64372E402E89B6A5C0F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C053372E2E24372E092E1B2440536DDBEEF7F7F7F7
F7F7F7F7EED2D2D2A5C9D2C0C0A5C0B6B6C9DBEEEEF7F7F7F7F7F7EEEEE5DBDBC9B69280
92ADC0C9D2DBD2DBDBD2D2D2C0C0D2D2C0D2D2C0C0D2D2C0A5532437241BC0B6A5C9F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D2531B2E242E402E122E2E1B245380D2EEEEEEF7F7
F7F7F7F7F7EEEEEEF7F7F7D2F7D2F7D2F7F7EEEEEEF7F7F7EEEEF7EEEEEEE5E5D2C99277
77779CB6C9D2D2DBDBD2D2D2D2D2D2D2C0D2C0D2C0D2C0D28040242E1B40C9C9A5C089F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5642E37242E24241B092E2E40536DC0E5EEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7F7F7EEEEEEEEEEEEE5EEE5EED2B6
898064535377ADD2D2D2D2D2D2C0C0C9C9C0ADC9D2D2D2AD64242E1B4049A5B69CAD5BDB
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F75353402E242E2E2E092E24406477C0DBEEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7F7EEEEEEEEEEE5EEE5DBDB
D2B689806453536480ADC0C0C9C0ADAD9292B6D2D2D2D2A5492E2E2E2E2E77A5B69C6492
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F75364402E2E242E2E1B122E535377C0D2EEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7F7EEEEEEEEEEEEEEEEEEE5
DBDBD2A592806453537780927780929C92ADD2D2D2C0C99C401B2E2E372E40806D5364AD
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7646453402E402E2E24094040536DADD2E5F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEEEEEF7EEEEEEEEEEEEE5E5
E5DBDBD2C0B6928964647777777789A5B6C0D2C0C0C9C0802E2E242E241B2E5353496DFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DB6464644024402E2E2E3737495377A5B6DBEEF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEEEEEEEEEEEEEEE
E5E5DBDBD2D2C0C9ADAD9C929CA5C0C0C0D2C9C0C0C9AD53402E2E4024241B4040406492
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C9645B645340402E2E2E2E2E40536492C0DBEEF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEEEEEEEEEEEEEEEEEEEEEE5
E5E5DBDBDBD2D2D2D2C9C9C9C9C0C0D2C0D2C9D2C0C0A549402E242437241B1B2E40375B
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7926464534040372E2E3740402E535377A5D2EEEEF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7F7F7F7EEEEEEEEEEEEEEE5EEE5
E5E5E5DBDBDBD2DBDBDBD2D2D2D2D2D2D2D2D2D2C9AD894040242E244024242E2E1B535B
C0F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F777535B64534053402E2E2E2E2E40536480ADE5EEF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7F7EEEEEEEEEEEEEEEEEEEEEEE5E5
E5E5E5E5DBDBDBDBDBD2D2D2D2D2D2D2D2C0D2C0AD9C64402E241B40121B1B242E123753
A5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F76453535B534049402E1B2E2E402E5364649CD2EEEE
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEEEEEEEEEEEEEEEE5EEE5
E5E5DBDBDBDBDBDBD2D2DBD2D2D2C0C0C0C0C0C9A56D492E1B1B37121B121B1B091B4053
9CFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F753535B5B645349402E401B372E4040647777C0DBF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEEEEEEEEEEEEEE5E5E5E5
DBE5DBDBDBDBDBDBD2D2D2D2D2D2D2D2D2D2C9AD9C64402E2440241B1B1B1B1B1B242E53
80F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F76D645B535B5340402E401B2E2E40405B6D77B6DBEE
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEEEEEEEEEEEEEE5E5EEE5E5
E5DBDBDBDBDBDBDBDBDBD2DBD2D2C0C0D2C9C0AD80534024404012121B1209121B242E40
89F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F764536453535B49494040402E40402E536477B6D2E5
EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7F7F7EEEEEEE5E5EEEEE5EEE5E5E5
DBE5DBDBDBD2DBDBD2D2DBD2D2D2D2D2C9C9AD926453534024241B1B121209121B241B53
EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F75B5B645B5B5B5B534940401B404040647792A5C9E5
EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEE5E5E5E5EEEEE5E5E5DB
E5E5DBDBDBD2DBD2D2D2D2D2C9C0D2C0C0C092806449401B1B1B1B1212091B121B244064
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F76453535B645B644049402E40404053536480ADC0DB
EEEEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEEEEEE5E5E5E5E5EEE5E5DBE5
DBDBDBDBDBDBD2D2D2D2D2D2D2D2C0C0ADA5928053402E1B241B1B12121B121B1B1B4064
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7EE535353535B5B5B53532E2E40404053496492ADC0D2
E5EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7F7EEEEEEEEEEEEE5E5E5E5E5E5DB
DBDBDBDBD2D2D2D2D2D2D2D2D2C0C0C0AD9C9C64534040242440242E241B1B1B242E4080
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7EE645B4953645B645B53492E40404040646D9C9CADC9
DBEEEEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEEEF7EEE5E5E5E5E5E5E5E5E5E5E5
E5DBDBD2DBDBD2D2C0D2D2D2D2C9C0ADA5896D6449402E2E37401B1224241B12122449EE
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F76D4949645B53645B53532E40404940536D80779CB6
DBEEEEEEF7F7F7F7F7F7F7F7F7F7F7F7F7F7EEF7EEEEEEEEEEEEE5E5E5E5E5E5E5E5E5E5
DBDBDBDBDBD2D2D2D2C0D2D2C0C0ADA59C6D6449403724241B2E1B1B12120009122E64F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F780534964536D5B5B535340245349534064646D92AD
D2EEEEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EEEEF7EEEEE5E5E5E5E5E5E5E5E5E5E5E5
E5E5D2DBD2D2D2D2D2D2D2D2C9C0AD92806453532E2E2E24241B1B121B0009121B4080F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F789644953495B535B49495B4024534053536D6477A5
C0E5EEEEF7F7F7F7F7F7F7F7F7F7F7EEF7F7F7F7EEEEEEEEE5E5E5E5E5E5E5E5E5E5E5E5
DBDBDBDBDBD2D2D2D2C0C9C9ADA59C80645353402E2424242E241B1B1209121B4064FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7896D49535349646D4053492E402E495B4053646492
ADD2E5EEF7F7F7EEF7F7F7F7F7F7F7F7EEEEF7EEF7EEE5E5E5E5E5E5E5E5DBE5DBE5DBDB
DBDBDBD2DBD2D2D2D2C9C0C0B69C80775349402E1B1B24242424241B241209244964F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD8053535B535B64535349492E4040535349645B77
9CC9D2E5EEEEEEEEF7F7F7F7F7F7EEEEEEF7F7EEEEEEE5E5E5E5DBE5DBDBDBE5E5E5DBDB
DBDBDBDBD2D2D2D2C9C0C0ADA59C776453402E2E1B1B1B1B2E241B12090012404077F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D28964535B5353646D405B40404040495B535B536D
80ADDBE5E5EEEEEEF7F7F7EEF7F7EEEEEEEEEEEEEEE5E5E5E5E5E5DBDBE5DBE5DBDBDBD2
D2D2D2D2D2D2D2C0C0C0ADA59280646449402E1B1212121B1B09090000001B4049ADF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F780645B535B49536453533737403749495B495364
6492A5C0D2E5E5E5EEEEEEEEEEEEEEEEEEEEEEEEE5DBDBDBDBDBDBDBDBDBDBDBDBDBDBD2
D2D2D2D2C9C0C0C0ADAD9C9C926453492E40241B1B1B1212120900000012404053F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF896D5B64645353645353402E404037535B644040
6464809CADC0C9D2DBDBEEEEE5D2E5EEEEE5EEE5E5DBC0D2D2DBD2D2D2D2DBDBDBDBD2D2
D2D2D2D2C0C9C0B6AD9C9C80776453492E241B120912121212090000001B404089F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C97764495B5353536449534040245B49495B5B64
40646D7777A5ADC0DBC0D2DBDBDBDBDBDBDBE5DBD2C9ADB6B6C9C9D2D2C9D2C9D2D2D2D2
D2C9C9C0C0C0B6ADA59280776453402E2E091B12121212120900000012402E2EEEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF806D53536453535B5340534040404064535B53
5B646D7780779C89ADADA5ADADADADC0D2C9D2C0A59C9C929C9CB6B6C0B6C9C0C9C9C9C0
C0C0B6ADB6ADAD928077776453492E2E24121B12090909000000001237402E80FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A5775B495B5353535B404037405353535B6464
5B6D5364646D80929289899C80929C9CADD2ADA59292928089809CADADB6B6B6C9B6B6B6
A5ADADADADA592928077644949402E2E1B1B12120909000000000040242E40EEF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D2895B53535B53406D494040374053645B6D49
536D776D64809C6D77778080808092809C9CA59C9C77777777807789929CA5A5ADADA59C
9C9C929C9292927777645349402E2E2412120912090000000000122E372453F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A56453535B49535353402440495B64646464
6D536D80778077776D646464646D647777778077646D6464776477777780929292928977
928080898080776D6449404040241B1B1B1212000909000000092E401B53A5F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DB806453535B4953645340405B536D6D5B77
6453646D77776D6D776449644953645364646D6453645340534949535353646464646464
645353535353535353492E2E241B12121B1B121200000000122E2E1B4064FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5896453535B5353535B53495B6D64776D6D
5B535B646477776464495349404053494064535353404949404040404049495353535353
53534953494040494040242E1B24121212121200000000092E242E4953D2F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C0895B5B535B4053536D5B495B80536D6D
6D6D646D64645B64644053534040535B5340535353403740372E2E40402E2E492E404040
4040402E402E402E402E2E241B241209120009000000002424401B49A5F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D2AD5B535B53535B53536D6D804964645B
49405B6477535B645353534949536440373740404040402E2E24242E2E2E4024402E2E24
2E402E2E402E2E1B2E241B091B1B12001209001200001224401B409CF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C9895B535B5340495340646D6D6D4049
6D806D536453494940405353402E2E40372E402E402E24241B241B2424242E1B2E2E402E
1B24241B2E1B2E1B1B2E1B241212120900000000122424242E2E80EEF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DBC964535B5B5B4953534053646D6D64
5353495B64404053493749492E2E4053372E40242E242424241B1B1B241B241B24241B40
121B1B1B2E2E1B1B12241B1B1B1212120000121B241B402E4077F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DB7753495B5B535353536D5353536D
6D8053405340404949405340492E40372E242E1B1B37241B1B1B12121224241B1224241B
241B122412241B121B120912000012000009121B1B492E4064EEEEF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7897753495B4953405B40536D5B53
495B405340402E2E49403740371B2E1B2E401B24121B1B2E1B1212121B1212241B12121B
1B1B24091B12121200120000000000091B1B1B2412242E92EEEEF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E59C77535B535B5353535340535B
534040534040242E37372E2E37401B2E2E1B241B1B1B24241212121B1212122424121212
1B1B122E1B1B12090009000000121B241B122E1B244077A5EEF7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C9896D495B5353536D535B6464
5340405B402E24242E37242E2E40123712241B121B12121B1B1212121B1B121B401B0012
1B1B24121B120000000009121B2E1B1B1B24402E53649CE5F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C0805B535B49534953495353
4940245B40371B241B2E2E1B1B1B121B1B121B121B121B121B121212121B121B2E2E2E12
121B1B1B241B24242424241B2E1B121B372E2E53539289F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C98964535B49536464646D
64534053492E2E1B1B122E1B1B1B241224121B1212121212122412001212241B1B404953
491B2E1B121B1B1B242E241B1B404924405340648080F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78089645B534953536464
645340644940402E121B24241B121B12241B1B091B1B121B121B1212001212402E24496D
2E2E2E2E402E24241B244049493740404053537792F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF80896D645349535353
6D5364535340402E24121B24121B1B241B24121B121B1B1212121B12121212004940402E
6D5B6D495353645349402424404040495B647777F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F792775B535B49535B
645B6D6D49495340401B1B242E1B1B1B1224121212121B1212121B1B0012241B12244053
4940241B243740494949495B5353535353649289F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F780646D535B64
6D6D6D806D4040404037532440372E2E24121B121B1B121B1224241B1B1B242E1B2E4024
53531B24242E24241B372E40404053779289DBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD805B5B5B53
646D8089805B4940404040404949492E2E24401B1B1B242E1B1B40242E2E242E492E2E2E
2424404037494040405353405364648077DBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D2805B4953
5B6D808080806D40404037404053534940641B2E12372E2E2E3740402E6D5B5324536D49
5353535353494953535B6D5B53779C77F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7897764
5B6D808092898080646D7753493753536449535349241B5B53496D6D4949496D5B536453
5B6D64646464645B4953646D89649CFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D289
6D6D5B6464806D8080808080806D535B496D6D6D8049532E494053496D645B5B535B646D
6464645364645B7777809C6D64C9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
AD5B646D648089808080778080808080536D64805B6D6D4940402E40496D5B5B5B494953
53534964776D778080776464D2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7C9806D6D6D5B80928089808077808989808980808964806D5B53534940536D64535B5B
7764806D8080929C77539CFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7E55B405B536DA5809289928980809C898989809C898977778080807792807789
89A5A5A580645377C9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7E5A58080A59CC0ADADAD9C9C896D899C9C9C9C9C89899C89808989A59CA5
807780646480C9FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7E5EED2C0B6C0A5A59C8989806D8089899C8089808980898077
77777789A5FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EEE5EEF7EED2C992A5928989898989899C898080807764
77A5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5DBC9DBD2EEF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 300},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001;1P00`40o`000?l0003oooooobgoool0
0?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool0
0?ooool]oooo003ooooo;Oooo`00ooooobgoool001Ooool6moOg00?_knogmoOgmoL07_Ogm`03aLG5
eMGEeMGE00?EeMD00mgMgMGEeMgMg@06gMgM1=GEe@07cLg=a<C4a<C4a<C4/k>c^k^k/k>c00V[Zj/2
XZ:R00J0P82RXZ:RXZ:RXZ:IVIVRXZ89moOg00?_knogmoOgmoL02_Ogm`03kno_moOgmoOg00?gmoLP
oooo1_Ogm`03kno_moOgmoOg01kgmoL018B4Q;fm_Kfm_Kfm_@;6a/H00lk>c/K6a/k>cP06c/k>0lK6
aP03_Kfm]KFe[Jf]00:][Jd00ibLW:FUYIbLW009U9BD0Xb<S003Q8B4S8b<S8b<00:4Q8@00hb<S?Og
moOgm`07moOg00?_knogmoOgmoL02_Ogm`03kno_moOgmoOg00?gmoLIoooo000Goooo00C_knogmoOg
moOWinL;moOg00?WinOgmoOgmoL05OOgm`03aLG5eMGEeMGE00GEeMD3gMgM00?EeMGMgMgMgMd00mGE
e@;=cLd00lC4a;^k^k^k^`02^k^k00>c/k>[Zj^[Zj/00Z^[Z`05XZ:RZj^[Zj^[XZ:RZj^[00NRXZ80
0iVIVJ:RX_Ogm`05moOg00?WinOgmoOgmoL04oOgmb3oool01>o_koOgmoOgmnOWi`_gmoL00nOWioOg
moOgm`0EmoOg00>DU9Bm_Kfm_Kd01LK6aP?>c/h00lK6a/k>c/k>cP03a/K60[Fe]@03[Jf]YJFUYJFU
00:UYJD00ibLW9BDU9BDU002U9BD00F<S8bDU9BDU9B<S8bDU9@01Hb<S004Q8B4S8b<Q8B4S8b<1_Og
m`03inOWmoOgmoOg01?gmoLIoooo000Goooo0_Ogm`03kno_moOgmoOg00;gmoL00no_koOgmnOWi`0@
moOg00?_knogmoOgmoL02_Ogm`03aLG5eMGEeMGE00;EeMD00mgMgMGEeMGEe@02gMgM00CEeMGMgMgE
eMGEeMD3cLg=0/C4a003P820^k^k/k>c00>[Zj/3XZ:R0j^[Z`03XZ:RZj^[XZ:R00NRXZ800iVIVLC4
a?Ogm`0KmoOg8?ooo`;gmoL00no_koOgmoOgm`02moOg00?_knogmoOWinL04?Ogm`03kno_moOgmoOg
00[gmoL00ibLW;fm_LK6aP02_Kfm00?>c/k6a/K6a/H00/k>cP04a/K6c/k>Q8B4a/K60kFe]@:][Jd2
YJFU0YbLW0:DU9@00hB4Q8b<S8b<S003U9BD00>4Q8BDU9B<S8`01Xb<S0:4Q8@00kfm_OOgmoOgm`0J
moOg6Oooo`005oooo`?gmoL00nOWioOgmoOgm`06moOg0^OWi`03moOginOWmoOg00[gmoL00nOWioOg
moOgm`09moOg00?5aLGEeMGEeMD01=GEe@03gMgMeMGEeMGE00;EeMD3a<C400F9RHV0P820P82[Zj^S
Xj<01;>c/`:SXj<00j^[Zj:RXZ:RXP0<XZ:R00>ATI7WinOgmoL02OOgm`04inOWkno_moOginOW0oOg
m`03inOWmoOgmoOg00;gmoL00nOWioOgmnOWi`03moOg8?ooo`?gmoL00nOWioOgmoOgm`06moOg0^OW
i`03moOginOWmoOg00[gmoL00nOWioOgmoOgm`09moOg00B4Q8Bm_Kfm_Kf4Q8@3a/K600?>c/j4Q8C6
a/H00/K6aP03Q8B4_Kfm]KFe00:UYJD00iBDU8B4Q8B4Q004W9bL00>DU9B4Q8BDU9@018b<S004Q8B4
S8b<S8b<S8b<0XB4Q0><S8`2Q8B400?WinOgmoOgmoL02?Ogm`04inOWkno_moOginOW0oOgm`03inOW
moOgmoOg00;gmoL00nOWioOgmnOWi`03moOg6Oooo`005oooo`03kno_moOgmoOg02CgmoL5eMGE00?M
gMgEeMGEeMD01=GEe@03a<C4^k^k^k^k00Bk^k/00j>SXj^[ZiVIV@02VIVI00B[Zj^SXj>IVIV[Zj/4
XZ:R00>[Zj^RXZ:RXZ801Z:RXP03a<C4moOgmoOg01WgmoL00no_koOgmoooo`0Ooooo00?_knogmoOg
moL09?Ogm`06Q8B4_Kfma/K6_Kfma/K6c/k>1/K6aP04Q8B4]KFe]KFe]KFe0Zf][@03YJFUW9bLW9bL
00><S8`2U9BD00><S8bUYJF<S8`00hb<S003U9BDS8b<S8b<00J<S8`00kfm_OOgmoOgm`0ImoOg00?_
knogmoOoool06?ooo`005oooo`?gmoL00nOWioOgmoOgm`0QmoOg00?5aLGEeMGEeMD01mGEe@03cLg=
eMGEaLG500?EeMD01<g=cK^k^k^k^k>c/`:[Zj/01IVIVJ^[Zk>c/j>SXiVIV@02XZ:R00>c/k>RXZ:R
XZ800Z:RXP03VIVIXZ:RXZ:R00BRXZ800nOWioOgmoOgm`0KmoOg8?ooo`?gmoL00nOWioOgmoOgm`0Q
moOg00B4Q8Bm_Kg6a/Jm_Kd6a/K600Je]KFm_Kf4Q8Bm_Kg6a/Jm_Kd3]KFe00N<S8bLW9bDU9B<S8bL
W9bUYJFLW9`00hb<S006YJFUS8b<S8b<Q8B4S8b<Q8B40Xb<S005Q8B4S8b<S8b<S8b<g]kN01ggmoLI
oooo000Goooo1OOgm`03kno_moOgmoOg01ogmoL6eMGE00?5aLGEeMGEeMD00lg=c@CEeMD00lg=cMGE
eK^k^`04^k^k00J[Zj^c/k>c/k>[Zj^IVIVRXZ82VIVI00>RXZ:[Zj^RXZ801j:RXQkgmoLPoooo1OOg
m`03kno_moOgmoOg01ogmoL00kfm_LK6a/K6aP03a/K600>e]KG6a/K6a/H00kFe]@C6a/H01;Fe]Kfm
_KFe]Jf][@>UYJD019bLW:FUYJFUYIbLW0F<S8`00iBDU8b<S8b<S002S8b<00B4Q8B<S8b<S8b<S8`N
moOg6Oooo`005oooo`_gmoL00no_koOgmoOgm`0ImoOg00?5aLGEeMGEeMD00mGEe@03aLG5eMGEeMGE
00CEeMD2gMgM0mGEe@03cLg=P820a<C400>k^k/02k>c/j>SXk^k^j^[ZiVIVJ^[ZiVIVJ:RXZ^[Zj:R
XZ^[Z`05XZ:R00>c/k?gmoOgmoL07?Ogmb3oool;moOg00?_knogmoOgmoL06OOgm`04]KFe_Kfm_Kfm
a/K60[fm_@03Q8B4a/K6a/K600C6a/H2c/k>0lK6aP03]KFe[Jf][Jf]00BUYJD02XB4Q:FUYIbLW8b<
S9BDU8b<S8B4Q9BDU8b<S9BDU0F<S8`00ibLW?OgmoOgm`0LmoOg6Oooo`005oooobOgmoL01lG5aMGE
eMGEeMGEeLg=cMGEeLG5a@04eMGE0mgMg@;EeMD3gMgM0/C4a004cLg=^k^k^k^k^k^k0[>c/`:[Zj/2
VIVI00B[Zj^c/k>c/k>RXZ82Zj^[0Z:RXP03Zj^[^k^kmoOg00WgmoL00no_koOgmoOgm`0AmoOg8?oo
obOgmoL01kFe]Kfm_Kfm_Kfm_KFe]LK6aXB4Q004a/K60lk>cP;6a/H3c/k>00>UYJF][Jfe]KD00jf]
[@:UYJD2W9bL0Xb<S004U9BDW9bLW9bLS8b<0YBDU004Q8B4S8b<U9BD]KFe2_Ogm`03kno_moOgmoOg
017gmoLIoooo000Goooo0_Ogm`03inOWmoOgmoOg027gmoL01mGEeLG5aMGEeLG5aLg=cMGEeLG5a@04
eMGE0]gMg@?EeMD3gMgM0mGEe@04a<C4RHV9^k^k^k^k0[>c/`B[Zj/00h20P8V9RJ:RXP05XZ:R00>[
Zj_5aLGgmoL01oOgm`03inOWmoOgmoOg00?gmoL00nOWioOgmoOgm`0=moOg8?ooo`;gmoL00nOWioOg
moOgm`0QmoOg00?6a/Je]KFm_Kd00[Fe]@06a/K6Q8B4Q8B4a/K6Q8B4a/K60/k>cP?6a/H3c/k>00G6
a/J4Q8Bm_KfUYJFe]KD00ZFUY@:4Q8@4U9BD00B<S8b4Q8B4Q8B4Q8@2S8b<00B4Q8B<S8bDU9C6a/H8
moOg00?WinOgmoOgmoL00oOgm`03inOWmoOgmoOg00ggmoLIoooo000Goooo00GgmoO_knogmoOgmoO_
knl08?Ogm`04gMgM/k>caLG5cLg=1mGEe@;MgMd00mGEeMgMgMGEe@04gMgM0mGEe@;=cLd2a<C40[^k
^`:[Zj/00j:RXZ^[Zj:RXP02XZ:R00>c/k>RXZ:c/k<00Z:RXP03Zj^[inOWmoOg00_gmoL00no_koOg
moOgm`06moOg00?_knogmoO_knl01_Ogmb3oool01OOgmno_koOgmoOgmno_k`0PmoOg00CWinNUYJFe
]KFe]KD2a/K600>m_Kg6a/J4Q8@00/K6aP;>c/h00lK6a/k>c/K6aP04c/k>0/K6aP03_Kfm]KFe]KFe
00:][Jd2YJFU0YbLW003S8b<U9BDQ8B400:<S8`01ibLW8b<S:FUYHB4Q8b<S9BDU>OWi`0<moOg00?_
knogmoOgmoL01_Ogm`03kno_moOgkno_00KgmoLIoooo000Goooo00?gmoO_knogmoL08_Ogm`03IVIV
a<C4eMGE00WEeMD00mgMgMGEeMGEe@02eMGE00?MgMgEeMGMgMd01MGEe@;4a<@2/k>c1J^[Z`:RXZ80
1:^[Zj:RXZ:RXZ>SX`:[Zj/:moOg00?_knogmoOgmoL04_Ogmb3oool00oOgmno_koOgm`0RmoOg00=J
FUZ][Jf<S8`02LK6aP03c/k>a/K6a/K600;6a/H01<k>c/K6a/k>c[fm_@;6a/H2_Kfm0Zf][@:UYJD0
0ibLW9BDU9BDU002U9BD0Xb<S003U9BDS8b<S8b<00>DU9@:moOg00?_knogmoOgmoL04_OgmaWoool0
01OooolTmoOg00=^KVi4A4C=cLd00mGEe@03gMgMeMGEeMGE00?EeMD00mgMgMGEeMGEe@02eMGE00?M
gMgEeMGEeMD00mGEe@03cLg=eMGEa<C400>k^k/3/k>c00B[Zj^RXZ:[Zj^[Zj/3XZ:R00B[Zj^c/k>[
Zj^[Zj/OmoOg8?ooobCgmoL016=SHd92@[Fe]HB4Q0;6a/H00lk>c/K6a/K6aP03a/K600K>c/k6a/K6
a/J4Q8Bm_Kg>c/h2a/K600Fm_Kg6a/J4Q8Be]KFm_Kd00Zf][@>UYJD019bLW9BDU9BDU8b<S0:DU9@3
S8b<00BDU9B4Q8BDU9BDU9@OmoOg6Oooo`005oooo`SgmoL01>o_koOgmoOgmno_kaOgmoL00da<C2XZ
:UiNGP04eMGE00CMgMgEeMGMgMgMgMd3eMGE00CMgMgEeMGEeMGEeMD2gMgM0]GEe@03cLg=a<C4cLg=
00;4a<@2^k^k00>c/k>k^k^c/k<00j^[Z`:RXZ800iVIVJ:RXZ:RXP02XZ:R00>k^k^[Zj_gmoL07_Og
mb3oool8moOg00C_knogmoOgmoO_knlGmoOg00=:BTXY:BUBDU801<K6aP04c/k>a/K6c/k>c/k>0lK6
aP04c/k>a/K6a/K6a/K60/k>cP05a/K6_Kfm]KFeYJFU]KFe00:][Jd2YJFU00>4Q8BUYJFLW9`00iBD
U0:<S8`01hB4Q8b<S8b<S8b<S8B4Q:f][IBDU00OmoOg6Oooo`005oooo`04moOgkno_moOgkno_0_Og
m`03kno_moOgmoOg01WgmoL00lC4a4A4A2XZ:P04eMGE0]gMg@;EeMD00mgMgMGEeMGEe@02eMGE0]gM
g@GEeMD01;^k^h20P;^k^k>c/`Fk^k/00k>c/j^[Zj^[Z`02Zj^[1j:RXP03a<C4moOgmoOg01ggmoLP
oooo00CgmoO_knogmoO_knl2moOg00?_knogmoOgmoL06OOgm`07c/k>@T92:BTYc/k>a/K6_Kfma/K6
00;>c/h2a/K600?>c/k6a/K6a/H00/K6aP;>c/h3a/K60[fm_@04]KFeYJFUYJFUW9bL1JFUY@03W9bL
U9BDU9BD00:DU9@01Hb<S8B4Q8B4Q8b<S8B4Q002S8b<00>m_KggmoOgmoL07OOgmaWoool001Ooool4
moOg0^OWia_gmoL00dI6AS`l?4A4A002aLG53MGEe@;MgMd2eMGE00C5aLG4a<B9RHV0P807/k>c0Z^[
Z`03Xj>SXZ:RXZ:R00JRXZ800j^[Zj>SXmGEe@0NmoOg8?ooo`CgmoL2inOW6oOgm`06@T92<C4a0000
Q8B4]KFeQ8B43<K6aP;>c/h01<K6aXB4Q8B4Q:f][@:UYJD2Q8B400BLW9b4Q8B4Q8B4Q8@4U9BD0XB4
Q0:<S8`4Q8B40YBDU003a/K6moOgmoOg01cgmoLIoooo000Goooo1_Ogm`03kno_moOgkno_01SgmoL0
0dA4A9VIVLg=c@0>eMGE00?MgMgEeMGEeMD00]GEe@03cLg=^k^k/k>c00N[Zj/:XZ:R00>IVIV0P82[
Zj/00Z:RXP03eMGEmoOgmoOg01_gmoLPoooo1_Ogm`03kno_moOgkno_01SgmoL00d92@Xb<S;Fe]@08
a/K60[fm_@05a/K6_Kfma/K6a/K6c/k>00?6a/H01;fm_KFe]KFe]JFUY@>LW9`019BDU9bLW9BDU9BD
U0R<S8`01HB4Q8b<S8B4Q8B4Q9BDU002S8b<00?>c/kgmoOgmoL06oOgmaWoool001Ooool3moOg00?W
inOgmoOgmoL06oOgm`03;2`/gMgMeMGE00CEeMD00mgMgMGEeMGEe@06eMGE0]gMg@07eMGEgMgMeMGE
^k^kTI6A^k^kTI6A00F0P8000i6ATJ^[Zj:RXP03XZ:R00>IVIV0P82RXZ801J:RXP04VIVIXZ:RXZ:R
XZ:R5?Ogm`03kno_moOgmoOg00KgmoLPoooo0oOgm`03inOWmoOgmoOg01_gmoL0124Q8Lk>c/K6a/K6
aP:m_Kd00lK6a/k>c/K6aP02a/K60[fm_@?6a/H2c/k>00O6a/K>c/k6a/Je]KF<S8be]KF<S8`01G]k
N`03Q8B4U9BDS8b<00><S8`2Q8B41Hb<S0:4Q8@3S8b<5?Ogm`03kno_moOgmoOg00KgmoLIoooo000G
oooo1OOgm`03kno_moOgmoOg01SgmoL00k>c/a`L7=GEe@0:eMGE00?5aLGEeMGEeMD01=GEe@04gMgM
^k^k^k^k^k^k0Y6AT@:0P8000i6ATH20P820P002P82000>IVIVRXZ:RXZ803::RXP03/k>c^k^kmoOg
00WgmoL00no_koOgmoOgm`0?moOg8?ooo`GgmoL00no_koOgmoOgm`0HmoOg00Be]KD00036a/Jm_Kd2
a/K600>m_Kg6a/K6a/H00lK6aP03_Kfm]KFe_Kfm00G6a/H01<k>c[Fe]KFe]KFe]@:<S8`2Ng]k00><
S8akNg]kNg/00W]kN`B<S8`2Q8B41Hb<S006Q8B4S8b<S8b<S8b<W9bL[Jf]2_Ogm`03kno_moOgmoOg
00ogmoLIoooo000Goooo7oOgm`03a<C4?3`leMGE00WEeMD2cLg=00?5aLG=cLgEeMD00mGEe@05^k^k
cLg=^k^k^k^kTI6A00:0P802IVIV00R0P81gMgMgMgMgMgN0P828R8R0P82IVIT2XZ:R00>0P82RXZ:R
XZ800Z:RXP08Zj^[XZ:RVIVIXZ:RZj^[XZ:RZj^[inOW6oOgmb3ooolOmoOg00?6a/Ha<C6<S8`01<K6
aP05_Kfma/K6a/K6a/K6_Kfm00Be]KD4a/K600Ze]KGFe]Je]KFe]KF<S8akNg]cLg=:BTYJFUYkNg/3
Jf][0g]kN`B4Q8@4S8b<00RDU9B<S8b4Q8B<S8bDU9B<S8bDU9CWinLKmoOg6Oooo`005oooo`05moOg
kno_moOgmoOgkno_01WgmoL01>o_keiNGVi^K/G5a@?EeMD00lg=cMGEeMGEe@03eMGE00O=cLfk^k_4
a<C=cLgEeMGMgMgEeMD00k^k^`03/k>cTI6AKVi^00EVIVH01fi^KVIVIVIVIVIVIX20P7MgMhR8R003
VIVI00FRXZ:IVIVRXZ:RXZ:[Zj/01J:RXP:[Zj/KmoOg8?ooo`05moOgkno_moOgmoOgkno_01WgmoL0
2>o_keYJFV=SHkFe]Kfm_LK6a[fm_KFe]@C6a/H02;fm_KFe]JFUYJFUYKFe]LK6a/k>c/K6aP>e]KD0
0jFUYHB4Q6=SH`05FUYJ00QSHf=JFUYJFUY:BTYkNg][Jf^4Q8B<S8`4Q8B40Xb<S003U9BDS8b<S8b<
00><S8`00iBDU:f][OOgm`0JmoOg6Oooo`005oooo`CgmoL00nOWioOgmnOWi`0FmoOg00FSXj<820PX
:2SEeMG5aLD00mGEe@04a<C4eMGEeMGEeMGE0/G5a@03a<C4/k>c/k>c00;EeMD00lC4a96ATH20P002
000000b0P828R8R0P820P80R8R:c/k<R8R:0P80c<c=6ATH@4114A4@2IVIV00H00028R8R0P820P82R
XZ:0P804XZ:R00R0P82RXZ:RXZ:RXZ:[Zj^RXZ;=cLgEeMDImoOg8?ooo`CgmoL00nOWioOgmnOWi`0F
moOg00Je]KD820PY:BW6a/Je]KF4Q8@2_Kfm00B][Jf4Q8C6a/K6a/H2]KFe00F][Jf4Q8B4Q8B4Q8C6
a/H00hB4Q0800000324Q8APH68B4Q8B4Q10@48B4Q1PH69bLW24Q8E9BDPP82492@P9SHf<016][Jg]k
N`P8200000:4Q8@00hb<S8B4Q8B4Q002Q8B40hb<S004U9BDS8b<kno_inOW6OOgmaWoool001Ooool7
moOg00?_knogmoOgmoL04_Ogm`04gMgMVIVI?3`lVIVI1=GEe@03a<C4^k^kgMgM00;EeMD2a<C400Bc
/k>IVIVATI6k^k/3P82000HR8R8S8b=VIVJATI5gMgNc/k<2inOW00aEEEFATI68R8Q^KVj0P82RXZ80
001NGUiDE5ANGUj8R8RATI43VIVI00BRXZ:[Zj^c/k>c/k<2XZ:R00J[Zj^RXZ:RXZ:[Zj_4a<CWinLI
moOg8?ooo`OgmoL00no_koOgmoOgm`0BmoOg00g_knnLW9`i>CV4Q8Bm_Kf4Q8C6a/Jm_Kf][JfUYJG>
c/k6a/Jm_Kd00Zf][@04U9BDQ8B4Q8B4]KFe0W]kN`0@Hf=S61PH20P8FUYJQ8B4Jf][YJFUinOWg]kN
BTY:Q8B4Lg=cFUYJHf=SW9bL00000TY:BP0:DU9BLg=cNg]k0000Lg=cQ8B4S8b<U9BDW9bLU9BD0Xb<
S006U9BDS8b<S8b<U9BDa/K6g]kN6OOgmaWoool001Ooool:moOg00?_knogmoOgmoL03oOgm`03XZ:R
R8R8:RXZ00CEeMD00lg=cK^k^k^k^`03eMGE00_4a<Bc/k>RXZ:ATI6RXZ9VIVHb<S9NGUjk^k_MgMgW
inL00^o_k`;WinL00no_knOWilg=c@03eMGE00S4a<A<C4a^KVigMgM4A4ADE5AVIVI^KVh3VIVI00NR
XZ:c/k>k^k^c/k>RXZ:[Zj^RXZ800j^[Z`04a<C4moOga<C4gMgM5oOgmb3oool:moOg00?_knogmoOg
moL03oOgm`08[Jf]S8b<:BTYc/k>_KfmQ8B4_Kfm]KFe0ZFUY@?6a/H02jf][IbLW8b<S7=cLhB4Q5YJ
FRTY:DY:BZf][Lk>c]kNgP02kno_00GNg]kWinO_knoNg]j4Q8@00lk>cP0Ba/K6>CTiBTY:Jf][>CTi
@T92DU9BHf=S0000Lg=cQ8B4S8b<W9bLYJFUU9BDS8b<U9BDS8b<0iBDU004]KFemoOge]KFinOW5oOg
maWoool001Ooool3moOg00K_knogmoOgmoO_knogmoO_knlCmoOg00AgMgM4A4A<C4c=cLd3eMGE00?=
cLfk^k_EeMD00mGEe@09a<C4XZ:RTI6AP82020P88R8RE5ADa<C4gMgM00?WinL01^o_knOWinOWino_
knOWilG5a@;WinL2eMGE00Rk^k/0001DE5@Z:RXl?3aDE5AVIVJ0P802VIVI00>RXZ:c/k>k^k/00[>c
/`:RXZ801j^[Zj:RXZ^[Zk>c/mGEeNo_knOWi`0GmoOg8?ooo`?gmoL01^o_koOgmoOgmno_koOgmno_
ka?gmoL02W=cLd92@T92@[Fe]Kfm_HB4Q;fm_KFe]JFUYKfm_@?6a/H02Jf][Hb<S7=cLf=SHc4a<B4Q
8D92@[fm_Lk>cP02g]kN00WWinO_knoNg]kWinO_knoNg]jDU9CWinONg]h00/k>cP0?YJFU0000BTY:
8B4Q:BTY@T92DU9B0000Lg=cQ8B4S8b<W9bLYJFUW9bLU9BD00:<S8`01iBDU8b<S9BDU:FUYNOWino_
knOWi`0GmoOg6Oooo`005oooo`[gmoL01>o_koOgmno_kno_k`OgmoL02^OWioOgmno_kno_kmgMgNo_
knOWih20P3`l?9VIV@CEeMD00lC4a;^k^mGEe@03eMGE01:c/k>RXZ:8R8R8R8PR8R8Z:RY^KVjc/k?W
inOEeMG5aLGWinO_knoEeMGWinO_knoWinN1PH42inOW0]GEe@;4a<@01Ta<C7MgM`P820P824a<C000
00:IVIT00j:RX[>c/k^k^`02/k>c00>[Zj^RXZ:[Zj/00Z:RXP05/k>c^k^k^k^ka<C4kno_01KgmoLP
oooo2_Ogm`04kno_moOgkno_kno_1oOgm`03inOWmoOgkno_00?_knl02nOWihB4Q3Ti>HB4Q;fm_LK6
aXB4Q;fm_Jf][JFUYKfm_@02a/K600>m_KfLW9b<S8`00V][J`0A20P88B4QFUYJW9bLg]kNa/K6YJFU
g]kNkno_a/K6g]kNkno_g]kNQ8B4inOWg]kNc/k>00?6a/H01STi>F][J`P820P823Ti>DY:BP:4Q8@0
18b<S9BDU:FUYHB4Q0:DU9@02Hb<S9BDU8b<S8B4Q9bLW;Fe]Lk>c]KFe^o_k`0FmoOg6Oooo`005ooo
oaCgmoL00no_koOgmoOgm`04moOg00GEeMDl?3`Z:R[EeMG=cLd00mGEe@03a<C4eMGE^k^k00?EeMD0
1j:RXYVIVHR8R8R8R1@D528R8X20P002TI6A00Zk^k^ATI7MgMgWinN[Zj_EeMGWinOEeMF[Zj^k^k/2
eMGE00F[Zj_=cLg5aLFRXZ:c/k<00YVIV@0D?3`l92@TVIVIVIVIXZ:R/k>c^k^kP820/k>cXZ:RZj^[
XZ:RVIVIXZ:RZj^[a<C4TI6A^k^ka<C4eMGE2_Ogm`03kno_moOgmoOg00SgmoLPoooo5?Ogm`03kno_
moOgmoOg00CgmoL01NOWic4a<BTY:LK6a[Fe]@03_Kfm00>][Jfm_KfUYJD00/K6aP0:_KfmS8b<Q8B4
Hf=SNg]k000061PHLg=cQ8B4Lg=c0ZFUY@0?c/k>g]kNU9BD_Kfmg]kN_KfmU9BDYJFUc/k>a/K6U9BD
]KFeQ8B4S8b<YJFU00:<S8`01S4a<A0@48B4Q8B4Q8b<S9BDU0:UYJD039bLW8b<S9BDU8b<S8B4Q8b<
S9BDU;Fe]IBDU;Fe]Kfm_NOWi`[gmoL00no_koOgmoOgm`08moOg6Oooo`005oooo`03moOginOWmoOg
01KgmoL01^OWifIVIR0P81TI6@000<C4a0;EeMD2a<C400>0P834a<B[Zj/00]GEe@08RHV9P820P820
TI6AXj>SPH61EEEEA4A40X20P003TI6APH61XZ:R00:RXZ82TI6A00L820PA4A4A4A4R8R8Z:RY^KVhR
8R801H20P009IVIV000020P8R8R8XZ:R/k>c^k^kP820/k>c00>RXZ802820P::RXZ>SXk>c/mGEeLC4
a8V9RLC4a1GgmoLPoooo00?gmoOWinOgmoL05_Ogm`03inOWHf=S0000008000000lK6a[fm_Kfm_@02
[Jf]0ZFUY@>4Q8@01;Fe]HB4Q6=SHa0@40:4Q8@00bTY:APH634a<@028B4Q0XB4Q0:<S8`2Q8B40`00
000320P8410@Hf=S008000002Q0@4:FUYHB4Q8b<S4Y:BQ0@434a<@0008B4Q9BDU0:UYJD00iBDU8B4
Q8b<S003Q8B400>DU9B4Q8CWinL00lK6aQGgmoLIoooo000Goooo2OOgm`03inOWmoOgmoOg00cgmoL0
1mgMgLC4a28R8Q0@428R8]GEeK^k^`02eMGE0/C4a003^k^ka<C4a<C400;EeMD01/C4a:^[Zh20P:^[
Zk^k^mGEe@;MgMd00mGEeMgMgMGEe@03gMgM1;^k^`06/k>cZj^[P820MgMgP820MgMg0VIVIP09VIVI
IVIVKVi^?3`l20P8A4A4C4a<VIVIZj^[00:k^k/03K>c/j:RXZ:RXZ:RXYVIVH20P::RX[>c/h20P9VI
VMGEeLg=cNOWi`0DmoOg8?ooo`WgmoL00nOWioOgmoOgm`0<moOg00OWinOFe]HQ8B4@410H61S6a/Je
]KD00[fm_@:][Jd02kFe]Jf][Jf][Kfm_HB4Q:f][IBDU6=SHiBDU:f][LK6aP02c/k>00?6a/K>c/k6
a/H00lk>cP>e]KD03Zf][JFUYIbLW7]kNf][Jg]kNf][Jd92@U9BDW=cLe9BDUYJFS4a<A0@408i>CT0
1HB4Q9BDU:FUYJFUYIbLW003S8b<0XB4Q007S8b<W9bLNg]kW9bLinOWa/K6inOW01CgmoLIoooo000G
oooo2OOgm`03inOWmoOgmoOg00cgmoL02lg=cHR8R1TI6B8R8RXZ:]GEeLg=cMGEeK^k^lg=cK^k^`03
cLg=00WEeMFk^k_4a<B[Zj^IVIV8R8Rk^k_EeMGMgMd00]GEe@04gMgMeMGEeMGEgMgM0mGEe@04cLg=
^k^k^k^ka<C40[>c/`0=Zj^[VIVIR8R8P820MgMgKVi^IVIVE5AD<S8bC4a<?3`lR8R8XZ:R00:k^k/0
2[>c/j^[Zj:RXZ:RXYVIVH20P::RXZ^[Zj:RXTA4A0?WinLDmoOg8?ooo`WgmoL00nOWioOgmoOgm`0<
moOg00?Fe]J<S8`H61P00R4Q8@03a/K6]KFe_Kfm00Je]KD02Kfm_KFe]Jf][IBDU8B4Q6][Jjf][LK6
a/k>cP02a/K600C>c/k6a/K6a/K>c/h2a/K601Bm_Kfe]KFUYJFUYJF][JfDU9BLW9bDU9B<S8`0001k
Ng][Jf]SHf=BDU92@T8Y:BTi>CTa<C5kNg^<S8`2YJFU0YBDU009S8b<Q8B4Q8B4Q8B4S8b<U9BDW9bL
>CTig]kN00;WinLDmoOg6Oooo`005oooo`03kno_moOgmoOg01GgmoL01MgMgC`l?6IVIPP825ADE004
eMGE00C=cLgEeMGEeMGEeMD2cLg=00O5aLG=cLf[Zj^RXZ:ATI6c/k?5aLD00mGEe@05gMgMeMGEeMGE
eMGEgMgM00;EeMD00lC4a;^k^k>c/`02^k^k00Bc/k>[Zj^RXZ:0P805VIVI0XR8R003P820R8R8VIVI
00:k^k/00k>c/j:RXZ:RXP02XZ:R00N0P82[Zj^[Zj^[Zj]gMgMNGUkWinL05OOgmb3oool00no_koOg
moOgm`0EmoOg00KWinLi>CUBDU8820Q:BT[6a/H3_Kfm00Be]KFm_Kfm_Kfm_Kd4]KFe00FDU9B<S8ac
Lg>LW9b4Q8@00lK6aP0:c/k>a/K6a/K6a/K6c/k>a/K6_Kfm[Jf]YJFUQ8B40ZFUY@03W9bLU9BDS8b<
00B4Q8@01hb<S8B4Q7=cLf][Jf=SHf][JhB4Q002YJFU00BLW9b<S8b<S8b<S8`2Q8B40YBDU004[Jf]
Lg=cDU9BinOW5OOgmaWoool001OooolHmoOg00GEeMENGUkEeMF9RHVk^k/00/g=c@;EeMD01<g=cMGE
eMGEeK^k^`?EeMD01lg=cK>c/j:RXYVIVI6ATLC4a=GEe@03gMgM0]GEe@;MgMd01]GEeK^k^k^k^k^k
^k>c/k^k^`:c/k<01:^[Zj:RXZ:RXYVIV@:RXZ82VIVI00>0P82IVIV8R8P00YVIV@03^k^k/k>c/k>c
00FRXZ83Zj^[00=NGUjk^k_4a<@05OOgmb3ooolHmoOg00?WinMBDU:m_Kd00ZFUY@:e]KD2_Kfm00Fe
]KFm_Kfm_Kfe]KG6a/H00[fm_@07]KFeW9bLS8b<Q8B4Lg=cYJFUa/K600?>c/h2a/K60/k>cP06a/K6
]KFeYJFUYJFUQ8B4YJFU0YbLW003U9BDS8b<Q8B400V4Q8@017=cLjFUYHB4Q9BDU0:<S8`3Q8B40YBD
U004YJFUFUYJa/K6]KFe5OOgmaWoool001OooolGmoOg00?_knnRXZ;=cLd00]GEe@05cLg=a<C4cLg=
cLg=^k^k00OEeMD01lg=cK^k^k>c/j:RXYVIVH61PMGEe@04gMgM0]GEe@;MgMd01Lg=cK^k^k^k^k>c
/k^k^`02/k>c00F[Zj^RXZ:0P82ATI68R8P00i6AT@05P820VIVIVIVIXZ:RVIVI00:c/k<00j^[ZiVI
VIVIV@02VIVI0j:RXP03/k>c6ATI^k^k01KgmoLPoooo5oOgm`07kno_W9bL]KFea/K6Q8B4]KFea/K6
00>e]KD01HB4Q<K6a/K6a[fm_LK6aP02_Kfm00Ne]KFUYJFLW9b<S8b4Q8BDU9Bm_Kd01<k>cP;6a/H2
c/k>00Fe]KFUYJFUYJFDU9BUYJD00iBDU006S8b<Q8B4Ng]kJf][Ng]kLg=c0W]kN`07Q8B4Lg=cQ8B4
Q8B4U9BDQ8B4U9BD00>4Q8@01g=cLhB4Q8b<S8b<S:f][B4Q8KFe]@0FmoOg6Oooo`005ooooaOgmoL0
2LG5aMGEeMGEeMGEeLC4a<g=cLG5aMGEeHV9R@06eMGE00gMgMgEeMFATI60P82k^k^SXj>RXZ:ATI69
RHWEeMGMgMgEeMGMgMd01=GEe@06aLG5RHV9Zj^[XZ:RZj^[TI6A0X20P005VIVITI6AP820TI6AP820
00:ATI42P82000BATI60P829RHV9RHT2XZ:R19VIV@BRXZ800a0@40000820P00EmoOg8?oooaOgmoL0
1LK6a[fm_HB4Q8B4Q8b<S002]KFe00Bm_Kfe]KFm_Kf4Q8@4a/K600?>c/k6a/Je]KD00ZFUY@0AU9BD
S8b<0000YJFUa/K6c/k>a/K6c/k>a/K6Q8B4S8b<a/K6]KFeYJFUQ8B4S8b<U9BD00:4Q8@300001W=c
L`05Hf=SLg=c0000Q8B4410@00R4Q8@01Hb<S9bLW10@400008B4Q00EmoOg6Oooo`005ooooaKgmoL0
2^OWilg=cMGEeMGEeLC4a820P=GEeLC4a=GEeLg=c@;EeMD6gMgM00OEeMFk^k_4a<Bk^k^[Zj^RXZ:k
^k/00]GEe@;MgMd00i6ATLC4a<g=c@02eMGE00G4a<Bc/k>[Zj^[Zj^8R8P00Z:RXP03VIVIR8R8TI6A
00:ATI42VIVI0Y6AT@04R8R8VIVIZj^[/k>c0j:RXP>IVIT01h20P::RXZ^[ZiVIVATI6B8R8[>c/`0E
moOg8?oooaKgmoL03>OWikFe]Kfm_LK6aZf][HB4Q;fm_LK6a[fm_KFe]Kfm_LK6aPK>c/h01kfm_KFe
]Jf][JFUYIBDU8b<S:FUY@02a/K60/k>cP03Q8B4[Jf]]KFe00:m_Kd02:f][IbLW9BDU9BDU7=cLhB4
Q8b<S8B4Q09cLg<2Ng]k17=cL`05Jf][Q8B4U9BDU9BDQ8B400:<S8`4Q8B400J<S8bDU9B<S8`Q8B4a
<C6e]KDEmoOg6Oooo`005ooooaKgmoL3eMGE00GMgMg=cLfRXZ;EeMG=cLd01=GEe@KMgMd02=GEeLg=
cLC4a;^k^k>c/h20P::RX/g=c@;MgMd7eMGE00K4a<Bc/k>[Zj^[Zj^IVIV0P802R8R80i6AT@05VIVI
R8R8TI6AVIVIXZ:R00>c/k<3XZ:R0iVIV@06P820XZ:RXZ:RP820:RXZKVi^5_Ogmb3ooolFmoOg00Rm
_Kg6a/Jm_Kg>c/je]KF4Q8Bm_Kfe]KD3_Kfm00?6a/K>c/k>c/h01<k>cP08a/K6]KFe[Jf]YJFUU9BD
Q8B4S8b<]KFe0/k>cP03a/K6Q8B4_Kfm00:m_Kd01<K6a[fm_Jf][HB4Q0:DU9@02HB4Q6][Jg=cLf=S
Hg]kNg=cLg]kNg=cLg]kN`02Lg=c00B<S8bLW9bDU9BDU9@3S8b<18B4Q0:<S8`00hB4Q34a<G]kN`0F
moOg6Oooo`005ooooaKgmoL3eMGE00OMgMfc/k>SXj>k^k_=cLgEeMFk^k/00]GEe@?MgMd00nOWimgM
gMgMg@02eMGE00?=cLg4a<Bk^k/00Z:RXP08a<C4eMGEeMGEgMgMeMGEgMgMeMGEgMgM0]GEe@03^k^k
/k>c/k>c00>RXZ800i6ATH20P8R8R002TI6A0YVIV@04R8R8Zj^[Zj^[^k^k0[>c/`FRXZ802IVIVJ:R
XZ:RXZ:RXX20P28R8S8b<TA4A>o_k`0DmoOg8?oooaKgmoL2_Kfm00C6a/K>c/jLW9bDU9@2]KFe00Bm
_Kfe]KFm_Kg6a/H3c/k>00_Ng]k>c/k>c/k6a/Jm_Kfe]KF][JfUYJF4Q8B<S8b][Jd00/K6aP0:c/k>
a/K6c/k>a/K6c/k>a/K6_Kfm[Jf]S8b<W9bL0hb<S008Ng]kHf=SLg=cLg=cNg]kLg=cQ8B400000YBD
U004YJFUW9bLW9bLQ8B40hb<S0>4Q8@2S8b<00E[Jf/Q8B4a<C52@T;_knl05?OgmaWoool001Ooool0
0oOgmno_koOgm`05moOg00?_knogmoOgmoL02_Ogm`09inOWcLg=eMGEeMGEcLg=VIVI/k>ccLg=^k^k
00CEeMD3gMgM0^OWi`;MgMd02]GEeLg=cK^k^lC4a:^[Zj:RX[>c/k^k^mGEeMgMg@;EeMD01]gMgNOW
imgMgMGEeLg=cK>c/`:[Zj/3XZ:R0X20P0:8R8P00i6ATHR8R::RXP05/k>c0Z:RXP0=VIVIXZ:RVIVI
VIVIP820XZ:R/k>cR8R8A4A4:RXZ20P8cLg=kno_01?gmoLPoooo00?gmoO_knogmoL01OOgm`03kno_
moOgmoOg00[gmoL01MKFe[Fe]Kfm_LK6a[Fe]@02Q8B40[Fe]@>m_Kd01<K6a/k>c/k>c/k>cP;Ng]h2
c/k>00Zm_Kfe]KFe]KF][Jf4Q8B<S8bLW9be]KG6a/K>c/h2a/K600S>c/kNg]k>c/k6a/Je]KF4Q8BL
W9bDU9@3S8b<00N4Q8A[Jf]cLg=[Jf]cLg=kNg^<S8`01IbLW004Q8B4S8b<Q8B4S8b<0hB4Q008S8b<
W9bLLg=c>CTi:BTY20P8e]KFkno_4oOgmaWoool001OooolEmoOg00W5aLGEeMGEeMG=cLg4a<B8R8R9
RHW=cLfk^k/01=GEe@03gMgMinOWinOW00?MgMd2eMGE00?=cLgEeMFk^k/00[>c/`06^k^kcLg=eMGE
eMGEaLG5eMGE0]gMg@;EeMD00lC4a::RXZ:RXP03XZ:R0iVIV@06P820R8R8R8R8VIVIZj^[/k>c0[^k
^`04/k>c^k^kXj>SZj^[1::RXP09P820XZ:R/k>cVIVIR8R8GUiN10@4A4A4TI6A01?gmoLPoooo5OOg
m`07]KFe_Kfma/K6]KFe[Jf]Jf][Q8B400:e]KD3_Kfm00C6a/K>c/kNg]kNg]h3c/k>0/K6aP07]KFe
_Kfm]KFeW9bLU9BD[Jf]]KFe00;6a/H02;Fe]LK6a/k>c/k>c/K6a[fm_Jf][HB4Q0B<S8`2Q8B400Mc
Lg=[Jf]cLg=kNg^4Q8BDU9BLW9`00ZFUY@04W9bLYJFUU9BDU9BD18b<S009Q8B4S8b<W9bLLg=cHf=S
BTY:>CTi@T92U9BD01?gmoLIoooo000Goooo5OOgm`03a<C4P820P820008R8R800iVIVH20P96AT@05
eMGE0mgMg@03aLG5gMgMeMGE00?EeMD01LG5aK^k^h20P8V9RH20P003eMGE00R0P835aLGEeMGEeMF9
RHVk^k^c/k>0P802VIVI00BATI60P82ATI6ATI42P82000J8R8RIVIVRXZ:SXj>c/k>k^k/3/k>c00V[
Zj^RXZ:RXZ:RXZ:0P82RXZ:0P82RXZ:c/k<00YVIV@04R8R80000MgMgeMGE4oOgmb3ooolEmoOg00R4
Q8B<S8`Q8B40000820R4Q8BDU9Be]KD3_Kfm00?6a/J4Q8C>c/h01<k>cP;6a/H018B4Q;fm_KFe]KFe
]@:UYJD01Xb<S8B4Q<K6aXB4Q:FUYKFe]@:4Q8@00kFe]JFUYHB4Q003Q8B400@0000820P000000003
Hf=S00H00024Q8BLW9bLW9bUYJF4Q8@2W9bL00BDU9B4Q8B4Q8B<S8`3Q8B400><S8bLW9b4Q8@00`00
0003Lg=cinOWmoOg01;gmoLIoooo000Goooo5OOgm`07RHV9TI6AMgMgMgMgR8R8XZ:RRHV900KEeMD0
0mgMgNOWimgMg@02gMgM0mGEe@05^k^kcLg=a<C4P820cLg=00;EeMD00mgMgMGEeMGEe@02eMGE00Nk
^k_4a<Bk^k^c/k>9RHVIVIV8R8P00Y6AT@03R8R8P820R8R800:8R8P01::RXZ^[Zk>c/k^k^`Bc/k<0
1:>SXj:RXZ:RXYVIV@:RXZ800h20P:^[Zk>c/`02TI6A00>IVIV9RHWgmoL05?Ogmb3ooolEmoOg00>e
]KF4Q8A[Jf/00V][J`05S8b<U9BD_Kfma/K6_Kfm00?6a/H00lk>c]kNg/k>cP02c/k>0/K6aP03_Kfm
]KFe]KFe00:][Jd03;Fe]LK6a/K6a/k>c/K6aXB4Q<K6a[fm_KFe]Jf][JFUYIbLW0:4Q8@01G=cLg]k
Ng=cLg=cLf=SH`02Jf][00MkNg^<S8bDU9B4Q8BUYJFLW9bUYJD00YbLW004U9BDS8b<S8b<Q8B40Xb<
S003Q8B4U9BDYJFU00=cLg<00b4Q8OOgmoOgm`0CmoOg6Oooo`005ooooaCgmoL02=GEeH20P96ATI6A
TGMgMhR8R::RXXV9R@?EeMD2gMgM00?EeMGMgMgMgMd00mgMg@08eMGE^k^keMGE^k^kcLg=^k^kP820
cLg=0]GEe@;MgMd3eMGE00G=cLg4a<Bk^k^c/k>0P8000Y6AT@>8R8P00h20P96ATIVIV@02Zj^[0[>c
/`>k^k/00k>c/j^[Zj^[Z`02XZ:R19VIV@07XZ:R/k>cR8R8R8R8VIVITI6Aoooo01CgmoLPoooo5?Og
m`0;c/k>YJFUQ8B4Lg=cJf][Lg=cS8b<YJFU_Kfma/K6_Kfm00;>c/h00lK6a/k>c/k>cP03c/k>00?6
a/Je]KFm_Kd00[Fe]@03[Jf]YJFU]KFe00;6a/H2c/k>0lK6aP05]KFe[Jf]YJFUW9bLQ8B4009kNg/4
Lg=c00IkNg^4Q8BDU9BDU9BLW9b4Q8@3YJFU00>LW9bDU9BDU9@01Hb<S003Q8B4S8b<YJFU009[Jf/2
Q8B400?oooogmoOgmoL04_OgmaWoool001OooolDmoOg00Bk^k^9RHVRXZ:ATI42R8R800>[Zj^9RHWE
eMD00]GEe@06gMgMeMGEgMgMgMgMeMGEgMgM0]GEe@06aLG5eMGEcLg=eMGE^k^ka<C40[^k^`?EeMD0
0mgMgMGEeMGEe@02eMGE00G=cLfc/k>[Zj^0P82IVIT0196AT@03P820VIVIXZ:R00>[Zj/00k^k^k>c
/k^k^`03/k>c0j:RXP:IVIT01::RXYVIVIVIVK>c/`:8R8P00iVIVH20P?Ogm`0DmoOg8?oooaCgmoL2
]KFe00^<S8b4Q8AcLg=cLg>DU9BUYJG6a/Jm_Kg6a/K>c/k6a/H00/k>cP0<a/K6c/k>a/K6a/K6]KFe
_Kfm]KFe_Kfm]KFe[Jf]YJFU[Jf]0lK6aP08c/k>a/K6a/K6a/K6_Kfm]KFeW9bLU9BD0XB4Q008Ng]k
Lg=cNg]kNg]k0000Q8B4S8b<U9BD0YbLW003YJFUW9bLYJFU00>LW9`02HB4Q8b<S8b<S8b<S8B4Q8b<
S8B4Q8b<S:FUY@02Ng]k00=cLg>4Q8CgmoL05?OgmaWoool001OooolCmoOg00GMgMfk^k_5aLFRXZ:I
VIT00XR8R003Zj^[a<C4eMGE00;EeMD2gMgM1MGEe@05cLg=aLG5eMGE^k^kcLg=00;4a<@00k^k^lC4
a=GEe@07eMGE0[^k^`03XZ:RP820VIVI00>ATI42VIVI00>RXZ:[Zj^[Zj/00[>c/`:k^k/2/k>c0Z^[
Z`03XZ:RVIVIXZ:R00>IVIT02820P9VIVK>c/j:RXYVIVJ:RXX20P<C4a1CgmoLPoooo4oOgm`09c/k>
YJFUQ8B4S8b<Q8B4Jf][Lg=cU9BD[Jf]00?6a/H2c/k>1<K6aP04_Kfm]KFe]KFe_Kfm0[Fe]@:][Jd0
0jFUYJf][Kfm_@02a/K600Rm_Kg6a/K6a/K6a/Jm_Kfe]KFUYJF<S8`2Q8B40g]kN`>4Q8@2U9BD0YbL
W0:UYJD2W9bL0YBDU0:4Q8@00hb<S8B4Q8B4Q002Q8B400><S8bUYJF<S8`00XB4Q00320P8a/K6moOg
01?gmoLIoooo000Goooo4oOgm`0:eMGE/k>cTI6AZj^[VIVIP820R8R8/k>ca<C4cLg=0]GEe@03gMgM
eMGEgMgM00CEeMD2cLg=00>k^k_=cLg=cLd00[^k^`03RHV9cLg=cLg=00SEeMD01;^k^j^[Zh20P9VI
V@:ATI42VIVI00J0P82IVIVRXZ:[Zj^c/k>k^k/2/k>c00Bk^k^c/k>[Zj^[Zj/2XZ:R00>IVIVRXZ:I
VIT00YVIV@03/k>cZj^[TI6A00:RXZ800h20P:^[ZoOgm`0CmoOg8?oooa?gmoL04;fm_IBDU:FUYIbL
W8B4Q6][Jg=cLibLW:FUYKFe]Kfm_LK6a/k>c/K6a/k>c/K6aP>m_Kd2]KFe00BUYJFe]KFe]KF][Jd2
YJFU0[Fe]@04a/K6_Kfm_KfmQ8B40lK6aP03_KfmYJFUU9BD00:4Q8@2Ng]k18B4Q007S8b<W9bLW9bL
YJFUQ8B4W9bLYJFU00:DU9@00ibLW8B4Q8b<S002Q8B400><S8b4Q8B4Q8@00YbLW005Lg=cQ8B4S8b<
410@U9BD01CgmoLIoooo000Goooo4_Ogm`0:aLG5XZ:RP8200000IVIVA4A4EUIF0000^k^kaLG52=GE
e@06cLg=aLG5a<C4P820^k^k/k>c0[^k^`05P820RHV9cLg=cLg=aLG500GEeMD01lG5aLg=cK^k^j^[
Zh20P96ATH20P002TI6A00>8R8RIVIVRXZ800j^[Z`04/k>cXj>SZj^[Zj^[0Z>SX`05Zj^[RHV9Zj^[
XZ:RP82000:IVIT00h20P::RXZ>SX`02IVIV0X20P003R8R8Xj>SmoOg01;gmoLPoooo4_Ogm`05[Jf]
Q8B420P80000DU9B0092@T801F=SHjFUYHB4Q<K6aXB4Q003a/K60hB4Q0:e]KD2YJFU00>][Jf4Q8BU
YJD00jFUY@>e]KD2a/K600>4Q8C6a/K6a/H00[Fe]@07YJFUU9BD0000Ng]kLg=cNg]kLg=c00:4Q8@0
1Xb<S9BDU9BDU8B4Q9bLW9BDU0:4Q8@3U9BD00B4Q8BDU9B<S8b<S8`3Q8B400B<S8bUYJEBDU9BDU82
000000=cLg>UYJGgmoL04_OgmaWoool001OooolBmoOg00W4a<BATI6ATI4H61QDE5A<C4a4A4A^KVjk
^k/03MGEe@03cLg=^k^k^k^k00>[Zj/00lC4a<g=cLg=c@06eMGE00Bk^k^c/k>RXZ:8R8P3TI6A00B8
R8RIVIV0P82[Zj/2XZ:R0Z^[Z`03Xj>SZj^[XZ:R00:[Zj/3XZ:R00>IVIVRXZ:RXZ800YVIV@03Zj^[
XZ:RMgMg00:8R8P00h20P8R8R::RXP0CmoOg8?oooa;gmoL01Jf][G=cLg]kN`0004Y:BP02@T9200=J
FUZUYJF4Q8@00lK6aP05_Kfma/K6Q8B4a/K6c/k>00C6a/H00kFe]Jf][JFUY@02W9bL00RDU9B][Jfe
]KFe]KFm_Kg6a/J4Q8C6a/H2_Kfm00B][JfLW9b<S8`00002Lg=c00EkNg]cLg=cLg>4Q8BDU9@00Xb<
S0:DU9@00ibLW9BDU8b<S002U9BD00><S8b4Q8B<S8`00Xb<S0>4Q8@02:FUYHb<S6=SHf=SHf][J`00
07]kNhb<S1?gmoLIoooo000Goooo00?_knogmoOgmoL03_Ogm`06kno_/k>cTI6AKVi^;2`/E5AD0UiN
GP04IVIV^k^keMGEcLg=0]GEe@04cLg=eMGEa<C4cLg=1=GEe@04a<C4eMGEeMGEa<C40[^k^`03XZ:R
Zj^[/k>c00;=cLd5eMGE0[^k^`03XZ:RTI6ATI6A00:8R8P00i6ATIVIVH20P004XZ:R0j^[Z`03VIVI
XZ:RXZ:R00FRXZ802iVIVJ:RXYVIVJ^[Zj:RXWMgMeiNGTa<C2`/;9VIVHR8R00CmoOg8?ooo`03kno_
moOgmoOg00kgmoL01^o_kiBDU8B4Q5YJFQ0@4492@P9BDU8025YJFZFUYHB4Q;Fe]LK6a[fm_KFe]Kfm
_@:e]KD4a/K600B4Q8C6a/K6a/Je]KD2YJFU00>4Q8BDU9BLW9`00[Fe]@?6a/H2_Kfm0ZFUY@03S8b<
0000Ng]k009cLg<00g]kNhB4Q8B4Q004S8b<0iBDU0B<S8`00hB4Q8b<S8b<S004Q8B400JUYJF<S8aS
Hf=:BTXi>CT@4102Lg=c4oOgmaWoool001OooolAmoOg00_WinNATI6[Zj]^KVh00014A4@Z:RY4A4AN
GUjk^k_EeMD00/g=c@?EeMD01lG5aK>c/iVIVK>c/j:RXY6ATH20P002TI6A00RIVIV8R8RIVIV0P82R
XZ:[Zj^k^k_=cLd5eMGE00>k^k^c/k>RXZ800Y6AT@:8R8P3TI6A0iVIV@>RXZ800k>c/j:RXZ^[Z`03
Zj^[1::RXP:IVIT02;>c/j:RXX20P5iNGUADE4A4A820P8R8R1?gmoLPoooo4OOgm`0;g]kNLg=cW9bL
FUYJ410@>CTi:BTY@T92DU9BYJFU_Kfm00:e]KD2a/K600Rm_Kfe]KFLW9b4Q8BLW9b4Q8AkNg/00002
Q8B400><S8b4Q8B<S8`00Xb<S003U9BDYJFU]KFe00C6a/H01;fm_Jf][IbLW8b<S09cLg<00f][Jg=c
Lg]kN`02Ng]k00>4Q8B<S8b4Q8@00hb<S003W9bLS8b<U9BD00>DU9@3S8b<0hB4Q008W9bLS8b<Jf][
BTY:@T920000Hf=SNg]k4oOgmaWoool001OooolAmoOg00[EeMFATI6[Zj^0P80H61PI6ATR8R8l?3a4
A4C4a<@5eMGE00S=cLf0P828R8R0P81<C4a4A4AVIVJ0P802KVi^00QVIVJ0P81^KVj0P828R8R[Zj^k
^k_4a<@5eMGE00Bk^k^c/k>IVIVATI42R8R800>IVIV0P828R8P00YVIV@05TI6AVIVIVIVIVIVIP820
00:[Zj/00k>c/j^[Zj^[Z`02XZ:R0YVIV@03XZ:RVIVIP82000:RXZ801X20P6IVIUADE5ADE820P9VI
VA?gmoLPoooo4OOgm`0;_KfmLg=cW9bLJf][410@61PH8B4Q<C4a@T92[Jf]Q8B400>m_Kd05<K6a[Fe
]Hb<S7=cLf][JcTi>D92@U9BDV][JeYJFV=SHe9BDV][JeYJFW]kNg=cLiBDU:FUYJf][Kfm_@?6a/H0
1[fm_Jf][IbLW8B4Q7=cLf][J`9cLg<01F][Jg=cLhB4Q8B4Q7]kN`04Q8B40YBDU004W9bLU9BDW9bL
Q8B40Xb<S004Q8B4S8b<Q8B4Q8B40Xb<S006Jf][DU9B@T92@T92Hf=SQ8B44oOgmaWoool001OooolA
moOg00c4a<AgMgN[Zj^IVIT0000R8R8Z:RXb<S9NGUk4a<C5aLGEeMD2cLg=0]GEe@0BaLG5a<C4/k>c
VIVIA4A4P8204Q8BP820A4A4410@C4a<?3`lIVIVE5ADC4a<E5AD/k>ca<C41=GEe@06a<C4/k>cXZ:R
TI6AR8R8VIVI0X20P003VIVIXZ:RZj^[00>[Zj/02::RXYVIVIVIVIVIVJ:RXZ^[Zk>c/j^[Z`:RXZ83
VIVI00F0P82RXZ:RXZ:0P81VIVH00UADE003KVi^VIVImoOg01;gmoLPoooo4OOgm`0<[Jf]Jf][W9bL
S8b<410@8B4Q:BTY<C4aDU9B[Jf]Q8B4_Kfm0[Fe]@:m_Kd03;Fe]Jf][IbLW8B4Q3Ti>F][JaPH66][
Jd92@QPH63Ti>BTY:@92@T8013Ti>D92@YBDU:f][@?6a/H01;fm_Jf][IbLW8b<S0=cLg<016=SHf][
JhB4Q8B4Q0BDU9@2S8b<0hB4Q003U9BDW9bLU9BD00:<S8`4Q8B40Xb<S006Jf][DU9B@T92@T92FUYJ
Q8B44oOgmaWoool001Ooool@moOg00`l?3b0P81^KVj9RHVSXj<0000R8R8Z:RXX:2Q<C4c=cLgEeMD3
cLg=0]GEe@;5aLD01820P:^[Zh61PH20P08000000bXZ:Q0@4000000200000TA4A00:P820/k>ccLg=
eMGEgMgMaLG5eMGEcLg=^k^kXZ:R0X20P0040000IVIV000000000X20P007<c<cP8208R8R8R8R4A4A
P820VIVI00:RXZ800hV9RJ:RXZ:RXP02P82000VIVIV0P82IVIV0P82ATI5VIVIDE5A6ATH000000XR8
R1?gmoLPoooo4?Ogm`03:BTYS8b<DU9B00:4Q8@01`00024Q8BTY:B4Q8D92@[Fe]HB4Q003]KFe00Rm
_Kg6a/Je]KF4Q8B<S8bDU9@@410Y:BT3000000@H61P820PY:BT@4102@T9200@00024Q8Be]KF4Q8@2
c/k>00C6a/Je]KFUYJF<S8`2Hf=S00E2@T9BDU800000000@41001P0000J4Q8@00hb<S8B4Q0000003
Q8B400B<S8`00012@T9:BTX2@T9200=[Jf/0003gmoL04_OgmaWoool001Ooool?moOg00d820PZ:R[4
a<Bc/k?4a<Bc/k<0000Z:RXR8R8Z:RYNGUk4a<C5aLD00lg=c@GEeMD02lg=cK>c/j^[Zj>SXh20P6IV
ITa<C6IVITa<C00006i^KP03/k>c00W=cLgEeMGWinOWinOEeMG4a<Bk^k^RXZ:8R8P00X20P09^KVh0
2eADE820P;>c/da<C28R8S`l?4a<C4A4A5ADE7MgMh20P002R8R81I6AT@>IVIT01hR8R4a<C5ADE5AD
E00009VIVH20P00CmoOg8?ooo`ogmoL28B4Q00Z][JfLW9b][JfLW9`0000Y:BTQ8B4Y:BUBDU:][Jd4
]KFe0lK6aP:m_Kd02;Fe]IbLW9BDU8B4Q6][Je9BDTY:BU9BDP92@T801UYJFYBDU9BDU9BDU;Fe]Hb<
S0;Ng]h03lK6aZf][JFUYHb<S6][Jf=SHf][JeYJFU9BDT92@Zf][Kfm_CTi>APH62TY:@03@T9200=S
Hf=[Jf]cLg<00W=cL`AkNg/3Q8B400McLg=2@T9:BTY:BTYBDU9cLg=SHf<04oOgmaWoool001Ooool0
1>o_koOgmoOgmno_k`_gmoL02aPH61TI6J:RX/C4a;>c/j:RXQ@D52XZ:QTI6B8R8UiNGP02cLg=0]GE
e@04/k>ccLg=eMGEaLG50]GEe@;=cLd05K>c/j:RX[>c/j:RXXR8R820P6i^KP000::RXYVIVJ^[Zk^k
^lC4a=GEeNOWimgMgLg=cLC4a;^k^j:RXXR8R003P8200VIVIP0;P820GUiNP82020P8:RXZC4a<92@T
E5AD?3`lIVIVKVi^009VIVH018R8R96ATIVIVJ:RXP:IVIT02I6ATH20P4a<C4A4A5iNGPP82::RXVi^
K_ooo`0BmoOg8?ooo`04kno_moOgmoOgkno_2oOgm`0;410@61PHS8b<[Jf]W9bLS8b<20P8>CTi61PH
8B4QDU9B00:e]KD2_Kfm00JLW9be]KFm_Kf4Q8C6a/Jm_Kd2]KFe00RLW9b<S8bLW9b<S8acLg=SHf=J
FUY2@T82Q8B400ZDU9BUYJF][Jf<S8cNg]k>c/je]KF][JfUYJF<S8`2Hf=S00=[Jf]SHf=BDU800U9B
DP0>FUYJNg]k410@>CTi@T92410@BTY:<C4aDU9BHf=SDU9B@T92Jf][Ng]k18B4Q009Ng]kJf][@T92
>CTiDU9B0000S8b<DU9Boooo01;gmoLIoooo000Goooo3_Ogm`08IVIV8R8R410@?3`lTI6AKVi^C4a<
:2PX0R8R8P0;:RXZKVi^cLg=aLG5cLg=eMGE^k^kR8R8^k^kaLG5eMGE00;MgMd01MGEeLg=cH20P;>c
/j^[Z`03XZ:R00FIVIVRXZ:c/k>k^k_4a<@00]GEe@;MgMd01mGEeLC4a;^k^j^[ZhR8R820P8R8R002
P82000U^KVh00014A4BRXZ8820Q<C4a4A4@0001gMgL00S`l?004A4A4GUiN0000TI6A1::RXP09VIVI
TI6AGUiNC4a<A4A4<S8b0000R8R8KVi^01?gmoLPoooo3_Ogm`08FUYJ8B4Q410@:BTYLg=cFUYJ>CTi
<C4a0R4Q8@03:BTYHf=S]KFe00:e]KD01/K6aZFUYG=cLjFUYHB4Q<K6aP;>c/h01/K6a[Fe]Hb<S9bL
W9BDU8b<S0>4Q8@01Xb<S9BDU:FUYJf][Kfm_LK6aP;>c/h01[fm_Jf][JFUYIBDU00006=SH`9[Jf/0
4F=SHeYJFV=SHd92@Zf][A0@459BDT92@S4a<G=cLcTi>C4a<D92@U9BDV=SHg=cLhB4Q003S8b<00V4
Q8AkNg]BDU9:BTXi>CTa<C4820Q[Jf]BDU804oOgmaWoool001Ooool00no_koOgmoOgm`0:moOg00Co
oolZ:RXR8R8@410220P800=<C4`Z:RXR8R800R8R8P0;:RXZKVi^cLg=RHV9cLg=eMGEcLg=VIVIXZ:R
RHV9eMGE00;MgMd2eMGE00N9RHVc/k>RXZ:RXZ:[Zj^RXZ:0P8000[>c/`04^k^ka<C4a<C4eMGE0]gM
g@06cLg=^k^k/k>c/k>cP820R8R80YVIV@05R8R8VIVIP820R8R8C4a<008I6AT02C8b<PP823`l?3`l
?5iNGVIVIYVIVH20P::RXP02TI6A00BRXZ:IVIV0P82ATI42A4A400Dl?3`Z:RXH61Q^KViNGUh04oOg
mb3oool00no_koOgmoOgm`0:moOg00CooolY:BTY:BT@410220P800=2@T8Y:BTa<C400R4Q8@03:BTY
FUYJ]KFe00:e]KD01/K6a[Fe]Hb<S8b<S9BDU<K6aP;>c/h2a/K600NUYJFLW9b<S8b<S8bDU9B<S8b4
Q8@00YBDU004YJFU[Jf][Jf]a/K60/k>cP06]KFe[Jf]W9bLW9bL0000Jf][0W=cL`09Jf][Lg=c0000
Lg=cBTY:8B4Q61PH:BTY20P8008i>CT2DU9B00IcLg=SHf>4Q8AcLg=kNg^<S8`2Q8B400QkNg]2@T8i
>CTa<C4Y:BT0001JFUY:BTXCmoOg6Oooo`005oooo`03kno_moOgmoOg00[gmoL02^OWibXZ:R8R8R8R
8QTI6A0@43`l?2XZ:P0001TI6@8R8R802fi^K/C4a<G5aMGEeLg=cMGEeLg=cI6ATHV9RLC4a=GEe@02
gMgM00?EeMG5aLG4a<@00Z^[Z`05/k>cXZ:RR8R8R8R8Zj^[00:k^k/02Lg=cMGEeMgMgMGEeLg=cK^k
^k>c/j^[Zh20P002R8R80i6AT@0?P820XZ:RKVi^KVi^C4a<A4A40000GUiNP820KVi^P820R8R8P820
TI6AXZ:R00BIVIT02H20P4A4A38b<TA4A2XZ:R8R8UiNGVi^K_ooo`0BmoOg8?ooo`03kno_moOgmoOg
00[gmoL02>OWib4Q8BTY:B4Q8APH610@43Ti>C4a<@@Q8B402V=SHjf][KFe]Kfm_KFe]LK6a[Fe]G]k
NhB4Q:f][@C>c/h01XB4Q:f][IBDU9BDU9bLW8b<S09cLg<039BDU:FUYJFUYKFe]LK6a/k>c/K6a[Fe
]JFUYIbLW9BDU8B4Q09[Jf/01g=cLg]kNg=cL`0008b<S5YJFV=SH`02@T9200Da<C5BDU9[Jf]JFUY[
Jf/00W=cL`03Ng]kS8b<Q8B400>4Q8@02F][JcTi>C4a<D92@RTY:@P824Y:BU9BD_ooo`0BmoOg6Ooo
o`005oooo`ggmoL00i6ATBXZ:S0`<003:RXZ0S8b<P09410@:RXZ6ATI:RXZGUiNa<C4cLg=eMGEcLg=
00;EeMD00k^k^h20P820P002TI6A0XR8R003IVIVGUiNE5AD009NGUh01eADE6IVIVIVIY6ATK>c/k^k
^lg=c@03eMGE00K4a<Bk^k^c/k>c/k>0P82ATI42R8R800>IVIVATI60P8000j:RXP:ATI4010000820
P6i^KYVIV@:ATI43VIVI0j:RXP09P820GUiN?3`l?3`l:RXZ6ATI0000E5ADKVi^01?gmoLPoooo3OOg
m`03YJFU:BTY<C4a00<Y:BT2<C4a00hH61PY:BTH61PY:BUBDU:][Jfe]KFm_Kfe]KFm_Kg6a/J][JdH
61Q[Jf/2Ng]k0W=cL`03@T92DU9BBTY:009:BTX02492@U9BDU9BDW]kNibLW:FUYKFe]LK6aP:m_Kd0
1Zf][JFUYIbLW9bLW0P827=cL`9[Jf/01W=cLg]kN`0008b<S8B4Q8b<S09kNg/014Y:BV][JeYJFW=c
L`9kNg/0100008B4Q8B4Q8B4Q0:<S8`02HB4Q59BDS4a<CTi>BTY:APH624Q8D92@U9BDP0CmoOg6Ooo
o`005oooo`ggmoL01j:RXR8R8P000000028R8P00028R8P03000000HR8R80001NGUj0P834a<C5aLD4
eMGE00F1PH69RHTR8R8A4A68R8P00P000004410@20P80000410@0P000008P820VIVIPH61TI6AaLG5
eMGEcLg=RHV90X20P004^k^k/k>cR8R8P8200`00000420P8PH61XZ:RXZ:R1H20P005TI6AVIVIP820
VIVIP82000BIVIT2P82000P410@R8R8Z:RXP820I6AT0001DE5AVIVH9moOg00CWinOgmoOgmoOWinL6
moOg8?ooo`ggmoL01jFUYBTY:@000000024Q8@00024Q8@0200000R4Q8@050000DU9BS8b<YJFU]KFe
00:m_Kd01hB4Q<K6aXB4Q8B4Q0P8200008B4Q00300000U9BDP09BTY::BTY@T9220P8Q8B4U9BD]KFe
Q8B4a/K600:e]KD3YJFU00>LW9b4Q8ASHf<00d92@P04DU9B410@Q8B4Q8B41P000003Q8B40000Q8B4
00J4Q8@2000000@Q8B4a<C4Q8B4H61P2@T9200=BDU;gmoOgmoL01oOgm`04inOWmoOgmoOginOW1_Og
maWoool001Ooool2moOg00C_knogmoOgmoO_knl7moOg00?=cLdb<S8000000R8R8P0;:RXZ8R8R410@
8R8R6ATI8R8RA4A4GUiNXZ:Ra<C4cLg=00KEeMD3cLg=0]GEe@06a<C4^k^ka<C4^k^ka<C4TI6A0lg=
c@;EeMD01LG5aLg=cLg=cK^k^lC4a002^k^k00BRXZ:ATI5VIVI<C4`2A4A400D0002ATI6RXZ:RXZ:[
Zj/01::RXP0;VIVIXZ:RXZ:RP820VIVIXZ:RVIVIXZ:RVIVI0P82:RXZ008R8R801QTI6C8b<P0005AD
E6IVIX20P1;gmoLPoooo0_Ogm`04kno_moOgmoOgkno_1oOgm`03g]kN<C4a0000008Q8B400bTY:B4Q
8APH60038B4Q00E2@T9BDU:<S8bUYJFe]KD00[fm_@C6a/H3]KFe0/K6aP06_Kfm]KFe_Kfm]KFea/K6
Q8B40kFe]@;6a/H00hB4Q;Fe]KFe]@03[Jf]00FUYJF<S8akNg]BDU92@T800STi>@05BTY:Lg=cS8b<
S8b<U9BD00:<S8`00hB4Q8b<S8B4Q002S8b<18B4Q00<S8b<Q8B40000:BTY8B4Q<C4a8B4Q<C4aDU9B
@T92DU9BQ8B44_OgmaWoool001Ooool3moOg00?_knogmoOgmoL01oOgm`03gMgMA4A4000000@R8R80
2ATI6@00028R8RXZ:TA4A5iNGYVIVH20P<g=c@03eMGE1mgMg@03aLG5gMgMgMgM00?MgMd3eMGE00C=
cLgEeMGMgMg5aLD2cLg=0lC4a005^k^k/k>c^k^kXZ:RP820009DE5@0100003`l?4a<C7MgM`FRXZ82
VIVI00RATI60P828R8RATI6IVIVRXZ:IVIT000028R8R00PI6ATl?3`Z:RX0001<C4agMgM<C4c=cLdA
moOg8?ooo`?gmoL00no_koOgmoOgm`07moOg00?_knli>CT00000124Q8@0961PH00008B4Q:BTY@T92
DU9BQ8B4YJFU]KFe00:m_Kd00lK6a/k>c/k>cP0;c/k>00K6a/Jm_Kfm_Kfe]KG6a/K>c/h3]KFe0jf]
[@:UYJD02jf][Hb<S6][Je9BDTY:BRTY:C4a<D92@V=SHhB4Q8b<S005Q8B400AkNg]cLg=cLg=kNg/2
S8b<00>4Q8@a<C4Q8B400R4Q8@07>CTi:BTY@T92>CTiHf=SBTY:e]KF017gmoLIoooo000Goooo3_Og
m`03<S8b:2PX8R8R00@R8R802000028R8RXZ:TA4A5iNGYVIVJ^[Zlg=c@GEeMD01]gMgNOWinOWimgM
gNOWilG5a@CWinL3gMgM00[EeMGMgMgEeMGEeMF9RHVk^k_=cLg4a<Bk^k_4a<@3^k^k0[>c/`05XZ:R
P820E5AD?3`l<S8b008l?3`00eADE8R8R8R8R002TI6A00F8R8QgMgMVIVJ0P82RXZ800iVIV@030000
8R8R8R8R008R8R801QTI6DA4A820P6i^KUADE8R8R17gmoLPoooo3_Ogm`03<C4a8B4Q8B4Q00@Q8B40
1@00024Q8BTY:CTi>E9BDP02Q8B400>e]KFm_Kfm_Kd00lK6aP06c/k>g]kNg]kNc/k>g]kNc/k>1=kN
gP?>c/h01<K6a/k>c/K6a/K6aP>e]KD00jf][JFUYJf][@05YJFU00F<S8a[Jf]2@T8a<C4Y:BT00S4a
<@03BTY:Lg=cLg=c009kNg/02G=cLf=SHe9BDV][Jhb<S8B4Q8b<S8B4Q2TY:@038B4Q00La<C4H61P@
411SHf=JFUYBDU:<S8`04OOgmaWoool001Ooool>moOg00=4A4@0000R8R80128R8P08410@8R8R?3`l
A4A4GUiNTI6AP820cLg=1=GEe@?MgMd3inOW00C5aLGWinOMgMgMgMd2inOW00?5aLGMgMgEeMD00mGE
e@05aLG5eMGEa<C4a<C4^k^k00;4a<@02X20P;^k^k^k^k^k^k>c/j^[Zh20P6i^KUADE4A4A08l?3`0
2DA4A6IVIVIVIUADE6IVIVi^KP0009VIVJ:RXP02VIVI00>ATI4Z:RXI6AT00R8R8P07:RXZ6ATI20P8
:RXZ<S8bE5ADXZ:R017gmoLPoooo3_Ogm`03@T9200008B4Q00@Q8B4021PH624Q8C4a<D92@U9BDW]k
Nhb<S;Fe]@:m_Kd2a/K60lk>cP?Ng]h01<k>c]kNg/k>c/k>cP;Ng]h2c/k>00K6a/Jm_Kg6a/Jm_Kfe
]KFm_Kd2[Jf]00>UYJF][Jf][Jd00jf][@:UYJD01IBDU0P826=SHdY:BSTi>@02<C4a00M2@T9BDU9J
FUY:BTYBDU9JFUY2@T800Xb<S0:4Q8@017]kN`P821PH624Q8@8a<C401QPH60P8224Q8BTY:E9BDZFU
YA7gmoLIoooo000Goooo3_Ogm`05A4A410@4:RXZ8R8R:RXZ008R8R80200002XZ:RXZ:TA4A5iNGXR8
R::RX/g=c@?EeMD00mgMgMGEeMGEe@03gMgM1^OWi`?MgMd3eMGE0lg=c@?4a<@03K^k^lC4a820P<C4
a;^k^k>c/k^k^k>c/j:RXYVIVH20P6i^KUADE002A4A40da<C003E5ADKVi^P82000>IVIT00i6ATHR8
R00000048R8R00HI6AT0000b<S8l?3aNGUkooolAmoOg8?ooo`kgmoL01CTi>C4a<BTY:B4Q8BTY:@02
8B4Q00`0000Y:BTY:BU2@T9BDU9cLg>4Q8Be]KFm_Kg6a/Jm_Kg>c/h2a/K60lk>cPKNg]h3c/k>0lK6
aP>e]KD7[Jf]00VUYJFLW9bUYJFLW9b<S8b4Q8A[Jf]SHf=BDU800cTi>@92@T80159BDUYJFP0008b<
S0:4Q8@00g]kNg=cL`0000048B4Q00HH61P0000Y:BTi>CUBDU;ooolAmoOg6Oooo`005oooo`ggmoL0
1Y6ATDA4A4A4A30`<28R8RXZ:P@R8R801bPX:0@414A4A0000861PH20P<G5a@04eMGE0]gMg@;5aLD0
0nOWilG5aNOWi`04inOW00?5aLGMgMgEeMD00]GEe@;5aLD2a<C40h20P004^k^kP820a<C4^k^k0[>c
/`07Xj>S/k>cXZ:RXZ:RP820TI6AR8R80080000220P800B8R8RIVIVIVIV8R8P2VIVI0X20P003:2PX
8R8R8R8R00<R8R801@P8228R8RXZ:P0000P8200AmoOg8?ooo`ggmoL01ZFUY@P820P8234a<B4Q8BTY
:@@Q8B401bTY:@000492@V=SH`000:FUYKFe]@02_Kfm0/K6aPC>c/h00mkNg/k>c]kNgP04g]kN0/k>
cP03a/K6S8b<_Kfm00:e]KD2[Jf]1JFUY@:][Jd2Q8B40YbLW008Q8B4S8b<Q8B420P80000@T920000
DU9B0P0000>4Q8@0100008B4Q7=cLf=SH`HQ8B401@00024Q8BTY:A0@40P8200AmoOg6Oooo`005ooo
o`ggmoL00hR8R4A4A0@41002<S8b00HZ:RXR8R8R8R8@410Z:RXR8R82?3`l00ANGUj0P82k^k_=cLd4
eMGE0]gMg@04inOWgMgMgMgMaLG51NOWi`?MgMd01]GEeLg=cMGEeLG5aLg=cK^k^`;4a<@00k^k^lC4
a;^k^`03^k^k00Rc/k>k^k^SXj>[Zj^c/k>RXZ:c/k>[Zj/3XZ:R0YVIV@08XZ:RVIVIVIVIVIVITI6A
R8R8GUiN:RXZ0b8R8P08:RXZ8R8R8R8R8R8R6ATI?3`lC4a<Zj^[4?Ogmb3oool=moOg00><S8`i>CTa
<C400c4a<@8Q8B400a0@42TY:B4Q8@02<C4a00ABDU8820RUYJFe]KD2_Kfm0/K6aP;>c/h01=kNg/k>
c/k>c/k>cPGNg]h3c/k>00>m_Kfe]KG6a/H00[Fe]@05YJFU[Jf][Jf]YJFU[Jf]00BUYJD02IbLW:FU
YIBDU9BDU9bLW8b<S9bLW9BDU8B4Q002S8b<1XB4Q004Ng]kLg=cBTY::BTY0b4Q8@08:BTY8B4Q8B4Q
8B4Q61PH<C4aBTY:[Jf]4?OgmaWoool001Ooool:moOg00O_knogmoOgmoMVIVHl?3a<C4a4A4@00S8b
<P03:RXZ8R8R8R8R008R8R801bXZ:S`l?4A4A0P82;^k^lC4a<g=c@03eMGE1MgMg@KWinL2gMgM00CE
eMG=cLgEeMGEeMD3a<C40[^k^`;4a<@01;^k^k>c/k>c/k>c/`:k^k/01:>SXk>c/j^[Zk>c/`:[Zj/0
1::RXYVIVIVIVIVIV@:RXZ83VIVI00>8R8Q^KVi4A4@00R8R8P0:6ATI<S8b410@6ATI00008R8R410@
:RXZ?3`lVIVI4?Ogmb3oool:moOg00O_knogmoOgmoMJFUXa<C5:BTY2@T800S4a<@03:BTY8B4Q8B4Q
008Q8B401bTY:C4a<CTi>E9BDZFUYJf][KFe]@03a/K61Lk>cPKNg]h2c/k>00Fm_Kfe]KFm_Kfm_KfU
YJD00Zf][@:UYJD2[Jf]0ZFUY@:LW9`2YJFU0YbLW004U9BDW9bLU9BDU9BD0Xb<S004Q8B4S8b<S8b<
S8b<0hB4Q003Lg=cFUYJ>CTi00<Q8B400c4a<APH624Q8@028B4Q00@H61Pa<C4a<C6<S8`@moOg6Ooo
o`005oooo`ggmoL03Da<C3`l?4A4A4A4A38b<S`l?2XZ:R8R8P00028R8RXZ:R8R8S`l?002A4A400>R
XZ;4a<C=cLd00mGEe@;MgMd3inOW00K5aLGWinOWinOWinOMgMgWinL2gMgM1=GEe@03a<C4^k^ka<C4
00Bk^k/01820P;>c/k^k^k^k^`:c/k<01:>SXj^[Zj^[Zk>c/`JRXZ84VIVI012ATI60P81NGUhl?3`0
000I6ATZ:RX@410I6AT@410I6AT820PI6ATZ:RXl?3b0P80@moOg8?ooo`ggmoL04dY:BS4a<D92@T92
@S4a<CTi>BTY:B4Q8@00024Q8BTY:B4Q8C4a<CTi>D92@XB4Q:f][KFe]Kfm_@02a/K60/k>cP?Ng]h0
1/k>c]kNg]kNg]kNg/k>c]kNgP;>c/h01lK6a[fm_Kfm_Kfm_Jf][JFUYJf][@05YJFU00>LW9bUYJFU
YJD00YbLW0>DU9@00ibLW8b<S8b<S004S8b<18B4Q009Ng]kJf][DU9B>CTi00008B4Q<C4a61PH8B4Q
008H61P01A0@41PH62TY:C4a<G]kN`0@moOg6Oooo`005oooo`SgmoL00no_koOgmoOgm`02moOg0TA4
A009C4a<A4A4A4A4?3`l:RXZ8R8R20P86ATI8R8R008Z:RX2C4a<00>ATI6[Zj_=cLd00mGEe@?MgMd6
inOW00?MgMgWinOMgMd00]gMg@;EeMD00k^k^lg=cK^k^`05^k^k00Fc/k>k^k^c/k>c/k>[Zj/00[>c
/`B[Zj/6XZ:R00ZIVIV0P82ATI68R8Q^KVi4A4@Z:RXR8R8Z:RXR8R856ATI0R8R8P03?3`lKVi^moOg
00ogmoLPoooo2?Ogm`03kno_moOgmoOg00;gmoL2@T9200U:BTXi>CU2@T8i>CTY:BTQ8B4820PH61PQ
8B400RTY:@06BTY:@T92Ng]kU9BD]KFe_Kfm0/K6aP?>c/h6g]kN00?>c/kNg]k>c/h00/k>cP;6a/H2
]KFe00>][JfUYJFUYJD00jFUY@04Q8B4YJFUW9bLW9bL0YBDU003W9bLU9BDU9BD00:DU9@2S8b<00>4
Q8B<S8b<S8`00hB4Q007Ng]kLg=cFUYJ>CTi:BTY8B4Q:BTY00<Q8B4361PH0R4Q8@03<C4aHf=SmoOg
00ogmoLIoooo000Goooo2?Ogm`06kno_moOgmoOgkno_moOgGUiN0TA4A006C4a<A4A4<S8b<S8b8R8R
20P80R8R8P8b<S801Ta<C5iNGX20P:^[ZlC4a<g=c@?EeMD2gMgM1^OWi`04gMgMinOWgMgMgMgM0mGE
e@03cLg=a<C4^k^k00Fk^k/5/k>c1J^[Z`03XZ:RZj^[XZ:R00:RXZ83VIVI0Y6AT@06P820GUiN?3`l
:RXZ8R8R:RXZ0Q0@40046ATI410@00006ATI0R8R8P03<S8bMgMgmoOg00ogmoLPoooo2?Ogm`0:kno_
moOgmoOgkno_moOgDU9B>CTi@T92BTY:@T920S4a<@048B4Q20P88B4Q8B4Q0S4a<@07BTY:DU9BJf][
U9BD[Jf]]KFe_Kfm00;6a/H2c/k>1]kNgP04c/k>g]kNc/k>c/k>0/K6aP03_Kfm]KFeYJFU00JUYJD0
0hB4Q:FUYIbLW002W9bL1IBDU003S8b<U9BDS8b<00:<S8`3Q8B400P0001kNg][Jf]BDU8a<C4Y:BTQ
8B4Y:BT261PH00<Q8B4H61P@41000b4Q8@03<C4aLg=cmoOg00ogmoLIoooo000Goooo3OOgm`07A4A4
30`<A4A4A4A4C4a<30`<10@4008Z:RX01P0002XZ:RXZ:R8R8P@414A4A0:0P8000k>c/lC4a=GEe@04
eMGE0lG5a@;WinL2aLG500SWinOMgMgEeMGEeMG5aLFATI7EeMF0P802^k^k1K>c/`03Xj>SZj^[Xj>S
00>[Zj/6XZ:R00>IVIV0P82IVIT00YVIV@06P82020P8KVi^A4A410@4:2PX0P0000036ATI410@410@
008000001ATI6B8R8PP821@D5>OWi`0@moOg8?ooo`ggmoL01`P8200000000492@TY:BPP820000002
:BTY00`0000Y:BTY:BTQ8B4a<C52@T9[Jf/00024Q8B][Jfm_Kf4Q8@3a/K60lk>cP;Ng]h2c/k>00ON
g]k>c/k6a/K6a/J4Q8Be]KFm_Kd00jFUY@:LW9`01HB4Q:FUYHB4Q9BDU8B4Q004U9BD00>4Q8B<S8b4
Q8@00Xb<S0:4Q8@01@P828B4Q8B4Q8B4Q7=cL`02Hf=S0P0000048B4Q000000008B4Q0QPH608@4100
1@00024Q8@P8210@4>OWi`0@moOg6Oooo`005oooo`cgmoL00no_kdA4A4A4A002A4A400E<C4aDE5@b
<S8l?3`R8R800RXZ:P09<S8b?3`lA4A4C4a<MgMgR8R8XZ:R^k^kcLg=00?EeMD2gMgM00?WinOMgMgW
inL00nOWi`?MgMd2eMGE00?=cLg4a<C4a<@00[^k^`:c/k<00k^k^k>c/k>c/`02/k>c00b[Zj^RXZ:[
Zj^RXZ:[Zj^RXZ:IVIVRXZ:IVIV0P82IVIVRXZ83VIVI00N0P81^KViDE5@l?3`Z:RXR8R8000000QTI
6@8@41001QTI6A0@41TI6ATI6BXZ:Ta<C17gmoLPoooo3?Ogm`03kno_@T92@T920092@T801DY:BU9B
DS4a<CTi>B4Q8@02:BTY0S4a<@92@T801F=SHg=cLhb<S:FUYKFe]@03a/K60/k>cP03g]kNc/k>g]kN
00?Ng]h3c/k>00?6a/Jm_Kfe]KD00Zf][@:UYJD2W9bL00>UYJFLW9b4Q8@00YbLW005U9BDS8b<U9BD
Q8B4U9BD00><S8`7Q8B40V=SH`03BTY:<C4a:BTY00@Q8B4261PH00HQ8B4H61PH61PH61PY:BU:BTXA
moOg6Oooo`005oooo`[gmoL00no_koOgmnOWi`02A4A400@410A<C4a<C4a<C4`2A4A400@R8R8b<S8Z
:RXb<S82?3`l00I4A4AgMgN8R8RRXZ:k^k_=cLd3eMGE00GMgMgWinOMgMgWinOMgMd00nOWi`07gMgM
eMGEgMgMeMGEcLg=^k^kcLg=00Jk^k/3/k>c00F[Zj^c/k>c/k>[Zj^RXZ800YVIV@>RXZ800h20P9VI
VIVIV@02VIVI00FATI40001^KVi4A4@l?3`00RXZ:P038R8R:RXZ8R8R008R8R826ATI0R8R8P03:RXZ
GUiNoooo013gmoLPoooo2_Ogm`03kno_moOginOW0092@T80100004Y:BTY:BTY:BP92@T800b4Q8C4a
<BTY:@02<C4a00Pi>CT@411SHf=cLg><S8bUYJFe]KFm_Kd2a/K600G>c/kNg]k>c/kNg]k>c/h00mkN
gP04c/k>a/K6c/k>a/K60kFe]@JUYJD019bLW9BDU9bLW9BDU0:LW9`00iBDU8B4Q8b<S005S8b<18B4
Q005Ng]kBTY:FUYJ>CTi<C4a008Y:BT00b4Q8BTY:B4Q8@038B4Q00H0000Q8B4Q8B4Y:BUBDU;oool@
moOg6Oooo`005oooo`SgmoL01No_koOgmoOgmoOgmnOWi`02C4a<01<0001<C4a<C4aDE5A<C4a4A4@R
8R8Z:RXb<S8Z:RXb<S94A4A>CTi^KVigMgNATI6[Zj_4a<C5aLD00mGEe@03gMgMinOWaLG500GMgMd3
eMGE00C=cLg4a<C4a<B0P805/k>c00>[Zj^c/k>c/k<00j^[Z`04/k>cRHV9XZ:RVIVI0Z:RXPBIVIT2
TI6A00B8R8P0001NGUi4A4@2:RXZ0R8R8P03:RXZ6ATI410@008R8R82410@00<R8R8l?3cWinL04OOg
mb3oool8moOg00G_knogmoOgmoOgmoOWinL00TY:BP0D0000BTY:BTY:DU9BBTY:@T928B4Q:BTY<C4a
:BTY<C4a@T92DU9BFUYJHf=SLg=cU9BD[Jf]]KFe_Kfm0/K6aP03c/k>g]kNc/k>00G>c/h3a/K600Be
]KF][Jf][JfUYJD:W9bL00>DU9BLW9b4Q8@018b<S0B4Q8@2Ng]k00AcLg=:BTYBDU8i>CT2:BTY00Da
<C4Q8B4Y:BTQ8B4H61P00R4Q8@05000061PH8B4Q>CTiinOW017gmoLIoooo000Goooo2oOgm`0;kno_
moOgGUiN?3`l10@4C4a<A4A4E5ADC4a<?3`l0000008b<S802S`l?38b<S`l?4i>CTa<C6i^KX20P::R
X/C4a<g=c@?EeMD7gMgM0]GEe@05cLg=eMGEa<C4a<C4cLg=00:k^k/8/k>c1:^[Z`>RXZ86VIVI00F8
R8R0P81>CTi4A4@l?3`00RXZ:P038R8R00008R8R008I6AT2410@00@820P@410R8R94A4@BmoOg8?oo
o`_gmoL00no_koOgme9BDP02>CTi00I:BTY2@T9BDU9:BTXa<C400002<C4a00<i>CTa<C4a<C400T92
@P05FUYJJf][S8b<[Jf]]KFe00?6a/H7c/k>00C6a/J4Q8Be]KFm_Kd2[Jf]00Be]KFUYJFUYJFDU9@3
W9bL00BDU9BLW9bLW9bLW9`4U9BD18b<S0F4Q8@02G=cLf][Je9BDT92@STi>BTY:C4a<B4Q8@000003
8B4Q0QPH6004410@61PH8B4Q@T924_OgmaWoool001Ooool8moOg00?_knogmoO_knl00_Ogm`05KVi^
A4A410@4A4A4GUiN009<C4`00dA4A000028R8P02?3`l00M4A4@b<S94A4ANGUiVIVIgMgNIVIT00/C4
a0CEeMD00mgMgMGEeMgMg@02eMGE00CMgMgEeMGEeMGEeMD3cLg=00O4a<Bc/k>c/k>[Zj^c/k>[Zj^c
/k<00Z^[Z`03/k>cZj^[Zj^[00:[Zj/2VIVI00BRXZ:IVIVRXZ:RXZ82VIVI00BATI68R8R0P81VIVH2
A4A400<l?3`R8R8R8R800R8R8P8I6AT01a0@41TI6@P8200001TI6BXZ:Vi^KP0BmoOg8?ooo`SgmoL0
0no_koOgmno_k`02moOg00E[Jf]2@T8i>CU2@T9BDU800TY:BP08@T9200008B4Q<C4a>CTi@T92<C4a
20P80U9BDP05Hf=SQ8B4[Jf][Jf]_Kfm00?6a/H00lk>c/K6a/k>cP02a/K600C>c/jm_Kg6a/K6a/H3
]KFe00F][Jf4Q8BLW9bLW9bDU9@00YbLW0:DU9@01IbLW9BDU9BDU9BDU9bLW002Q8B40Xb<S0B4Q8@0
1g]kNg=cLf][Je9BDPP82492@S4a<@068B4Q00LH61PQ8B4@410@410H61PY:BUSHf<04_OgmaWoool0
01Ooool=moOg00mgMgM<C4`l?3`410@<30a4A4A<C4``<30410@820PR8R8P820`<314A4@000000TA4
A08000000j:RXX20P=GEe@02eMGE00?5aLGEeMGEeMD01=GEe@04cLg=aLG5TI6AP8200/C4a007/k>c
Xj>S/k>cXj>S/k>cXj>S/k>c00:SXj<5XZ:R00F0P82RXZ:RXZ:0P82RXZ801820P0060000A4A4A4A4
0000:2PX8R8R0P0000<R8R800`0001TI6@000002000000<X:2Q4A4CgmoL04_Ogmb3oool=moOg00Yc
Lg=:BTXa<C40000820Q2@T9:BTXa<C40000820P28B4Q00<a<C52@T8000000P000004@T92Hf=SS8b<
Q8B40kfm_@0;Q8B4a/K6Q8B4a/K6Q8B4a/K6_Kfm]KFeQ8B4]KFeYJFU00:][Jd2Q8B41iBDU0J4Q8@0
0hb<S8B4Q8b<S002Q8B400<0001cLg=SHf<00TY:BP04@T9200008B4Q8B4Q0P0000DQ8B401@00010@
400002TY:CTi>@0CmoOg6Oooo`005oooo`SgmoL00no_koOgmoOgm`02moOg00FIVIU^KVi4A4A<C4a4
A4@00Ta<C004A4A4?3`l?3`l8R8R0S8b<P0:A4A410@4C4a<C4a<GUiNKVi^TI6AXZ:RcLg=a<C40/g=
c@GEeMD2cLg=00?4a<CEeMG4a<@00[^k^`04Zj^[/k>cZj^[XZ:R0Z^[Z`03XZ:RZj^[XZ:R00:RXZ80
1YVIVJ:RXZ:RXX20P::RXYVIV@:RXZ82TI6A0X20P004KVi^C4a<A4A4:2PX0R8R8P<I6AT01000028R
8QTI6A0@408820P00a0@42XZ:VIVIP0CmoOg8?ooo`SgmoL00no_koOgmoOgm`02moOg00FLW9a[Jf]2
@T9:BTY2@T800TY:BP04@T92<C4a>CTi8B4Q0S4a<@0:@T920000BTY:BTY:DU9BFUYJNg]kQ8B4]KFe
[Jf]0[Fe]@Fm_Kd2]KFe00>UYJFm_Kf][Jd00ZFUY@>DU9@01Xb<S9BDU9BDU8b<S9BDU8B4Q0:<S8`0
0hB4Q8b<S8b<S002S8b<0hB4Q007Ng]k0000Jf][Jf][FUYJ@T92>CTi00<Q8B4261PH00DQ8B40000Q
8B4Q8B4H61P00a0@4003:BTYFUYJmoOg01;gmoLIoooo000Goooo3OOgm`04^k^kKVi^30`<C4a<0TA4
A003C4a<GUiN0000008b<S802bXZ:S8b<S`l?4A4A4a<C4A4A5iNGUADE8R8R::RX[^k^`03a<C40]GE
e@04cLg=eMGE^k^kcLg=0lC4a0:k^k/2/k>c00BRXZ:[Zj^RXZ:IVIT2XZ:R00>IVIVRXZ:RXZ800Z:R
XP:IVIT00h20P::RXYVIV@02VIVI00FATI60P820P81VIVIDE5@00TA4A003:RXZ8R8R6ATI00<@4100
0aTI6@P820P8200320P800<@410l?3bIVIT04oOgmb3oool=moOg00C6a/I[Jf/0001:BTX2@T9200=:
BTYJFUX000000S4a<@0;:BTY<C4a>CTi@T92BTY:@T92DU9BBTY:Lg=cS8b<YJFU00>][Jd2_Kfm00Je
]KFm_Kfe]KFe]KF][JfUYJD3[Jf]0YbLW004Q8B4U9BDS8b<Q8B40Xb<S0:4Q8@2S8b<00>4Q8AcLg>4
Q8@00Xb<S0>4Q8@01G]kNg=cLf][Je9BDTY:BP02>CTi00<Y:BTQ8B4H61P011PH60H@41000cTi>IbL
W?Ogm`0BmoOg6Oooo`005oooo`kgmoL026i^KTa<C4A4A4a<C3`l?4A4A5ADE4A4A08Z:RX0138b<RXZ
:S`l?0`<308l?3`2A4A400=VIVJ0P82RXZ800[>c/`03^k^ka<C4a<C400C=cLd02<C4a820P<C4a<C4
a;^k^iVIVJ:RXX20P0:RXZ82VIVI0Z:RXP03P820VIVIXZ:R00BIVIT3TI6A0XR8R006IVIVKVi^IVIV
A4A4?3`l:RXZ0R8R8P<I6AT2410@10P82003410@8R8R<S8b01CgmoLPoooo3_Ogm`08Hf=SBTY:@T92
BTY:>CTi@T92DU9B@T92134a<@09>CTi20P8>CTi<C4a@T92>CTiDU9BJf][S8b<00:LW9`00jFUYJf]
[JFUY@04]KFe1:f][@04YJFUQ8B4S8b<Q8B40Xb<S0:4Q8@2S8b<0XB4Q005S8b<Lg=cQ8B4Lg=cQ8B4
00=kNg/2Lg=c00I2@T9JFUYBDU8i>CTa<C4Y:BT28B4Q1APH60@@41000aPH624Q8BTY:@0DmoOg6Ooo
o`005oooo`03moOgkno_moOg00[gmoL01Ooooh20P4a<C4A4A4a<C002A4A400ADE5@410@b<S8R8R83
:RXZ00A4A4A<C4`l?3`Z:RX3A4A40XR8R007TI6AXZ:R/k>cP820a<C4^k^ka<C400:k^k/01H20P<C4
a;^k^k^k^j^[Z`02VIVI00FRXZ:IVIVIVIVIVIVRXZ801iVIV@04R8R8VIVITI6AR8R80X20P00:KVi^
E5ADC4a<A4A4?3`l:RXZ8R8R6ATI410@20P80a0@40@820P00aTI6B8R8Vi^KP0DmoOg8?ooo`03moOg
kno_moOg00[gmoL02oooohB4Q492@STi>DY:BT92@TY:BU9BDP00034a<B4Q8@02:BTY00Da<C52@T9:
BTXi>CTY:BT00T92@P0:BTY:Lg=cLg=cNg]kS8b<YJFUS8b<[Jf]YJFU]KFe0ZFUY@05Q8B4[Jf]YJFU
YJFUU9BD00:4Q8@00hb<S8B4Q8B4Q007Q8B40W=cL`04Ng]kLg=cNg]kLg=c0V][J`05FUYJBTY:@T92
>CTi<C4a008Q8B4261PH00@@410H61PH61PH61P4410@0R4Q8@03Jf][moOgmoOg01;gmoLIoooo000G
oooo3_Ogm`04^k^kA4A4?3`lC4a<0dA4A00751@D?3`l:RXZ:RXZ8R8RC4a<?3`l00=<C4`0138b<TA4
A5iNGUiNGP9gMgL01Y6ATJ^[Zh20P:^[Zk>c/j^[Z`:c/k<01J>SXk^k^j^[Zj:RXY6AT@02P82000RA
TI68R8R8R8RIVIV8R8RIVIV0P828R8P3VIVI00BATI60P828R8R8R8P3P82000Q4A4A<C4`l?3`l?3`Z
:RXR8R80000I6AT4410@00P0000820P820P820P@410b<S8R8R;WinLDmoOg8?ooo`kgmoL01<K6aTY:
BSTi>DY:BP=2@T801a0@434a<BTY:BTY:B4Q8DY:BSTi>@03BTY:01<a<C52@T9BDU9BDU9[Jf]SHf=k
Ng^DU9@820RDU9BUYJFDU9BUYJFLW9bDU9BUYJFDU9B<S8acLg<00V][J`08Lg=cJf][Ng]kQ8B4Jf][
Q8B4Lg=cNg]k0XB4Q003Lg=cNg]kLg=c009cLg<3Jf][0T92@P8a<C400bTY:B4Q8@00000561PH110@
400461PH<C4a8B4QinOW5?OgmaWoool001Ooool?moOg00D00014A4@l?3a<C4`410@00TA4A08X:2P2
:RXZ00<`<300001<C4`00TA4A007C4a<E5ADA4A4A4A4ATI6CTi>IVIV0080000220P800<0000820P0
00000h20P0050000IVIVIVIVATI6CTi>008000000`P82820P820P004P82000@820P0000000000003
IVIV00EDE5@<30`0000X:2PZ:RX00R8R8P030000410@410@00H820P01000028R8R8R8P0001GgmoLP
oooo3oOgm`050000@T92<C4aBTY:00000092@T801bTY:B4Q8B4Q8BTY:C4a<@0004Y:BP02@T9200A:
BTYBDU92@T92@T82DU9B00ASHf=BDU9[Jf]BDU82Hf=S00IBDU9JFUX00000001[Jf]SHf<2DU9B00E2
@T9BDU92@T9:BTY2@T8016=SH`08Jf][Hf=SDU9BHf=S@T92Hf=S@T92Hf=S0T92@P040000:BTY8B4Q
:BTY0R4Q8@03000061PH61PH00H@410010P8224Q8B4Q8@0001GgmoLIoooo000Goooo3oOgm`04ADE5
C4a<A4A4A4A40Ta<C00371`L?3`l:RXZ008Z:RX03C8b<Q@D54a<C5iNGTa<C4A4A5iNGTI6AUADE5iN
GVi^KUiNGVIVIP03GUiN00EDE5AVIVIDE5A^KVj0P8000Vi^KP07IVIVGUiNC4a<E5ADC4a<GUiNIVIV
009^KVh00fIVIWMgMfi^KP03KVi^16IVIP9<C4`02@@412XZ:RXZ:R8R8QTI6B8R8Q0@40P8210@4005
20P800D@410R8R8Z:RXR8R8b<S805OOgmb3oool?moOg00ABDU9:BTY2@T92@T82BTY:00@@410i>CTY
:BTY:BT2<C4a00D@411:BTYJFUYBDU92@T800UYJFP9BDU800eYJFU9BDUYJFP03DU9B00E:BTYBDU9:
BTYJFUY[Jf/00eYJFP05DU9B@T92@T92@T92BTY:009BDU800eYJFT92@V=SH`04FUYJ159BDP92@T80
2C4a<BTY:BTY:B4Q8APH624Q8APH610@41PH6005410@00DH61PQ8B4a<C4Q8B4a<C405OOgmaWoool0
01Ooool?moOg00fATI5<C4a4A4A4A4A<C4`l?3a<C4a4A4@b<S8R8R8b<S8l?3a4A4@00eADE005GUiN
A4A4CTi>IVIVGUiN009VIVH01UiNGTA4A4a<C4A4A5iNGTA4A09<C4`015iNGVIVITa<C5iNGP9<C4`0
1DA4A4a<C4a<C4a<C5ADE003IVIV0UiNGP08IVIVE5ADE5ADGUiNE5ADC4a<GUiNA4A40RXZ:P04<S8b
8R8R6ATI6ATI0Q0@40H820P01B8R8RXZ:QTI6C8b<X20P00EmoOg8?ooo`ogmoL03JFUYDY:BT92@T92
@TY:BSTi>DY:BT92@S4a<B4Q8C4a<CTi>D92@P03DU9B00EJFUY2@T92@T9JFUYBDU800UYJFP05DU9B
@T92BTY:>CTiDU9B00=2@T801E9BDUYJFTY:BU9BDTY:BP02@T920STi>@92@T83DU9B00=:BTYBDU9B
DU800T92@P05DU9BBTY:@T92DU9B>CTi008Y:BT0134a<B4Q8APH624Q8@8H61P6410@00DQ8B4Y:BTQ
8B4a<C64Q8@05OOgmaWoool001Ooool?moOg00?EeME^KVi<C4`00TA4A004C4a<30`<E5ADA4A40S8b
<P0:C4a<A4A4GUiNC4a<IVIVE5ADA4A4C4a<GUiNIVIV0UiNGP09C4a<10@4C4a<?3`lA4A4C4a<?3`l
A4A4GUiN0094A4@00eADE4A4A2PX:005?3`l00=4A4@l?3a4A4@00dA4A0Hl?3`01C8b<R8R8R8R8R8R
8QTI6@02410@00<I6AT@410@41000`P8200600008R8R8R8R6ATI<S8bA4A45_Ogmb3oool?moOg00?W
inM[Jf]:BTX00T92@P04BTY:20P8DU9B@T920S4a<@06BTY:@T92FUYJBTY:FUYJDU9B0T92@P0BDU9B
FUYJDU9BDU9B@T92>CTiBTY:>CTi@T92BTY:<C4a20P8DU9B>CTi@T92DU9B@T928B4Q0STi>@<a<C40
0cTi>C4a<CTi>@03>CTi1S4a<@03:BTY8B4Q8B4Q008Q8B4261PH00<0000H61PH61P0110@40<Q8B40
0c4a<CTi>OOgm`0EmoOg6Oooo`005oooo`ogmoL00mGEeH20P4a<C002A4A400U<C4a4A4A4A4A<C4a4
A4@l?3a<C4aDE5AVIVH00UiNGP06C4a<A4A4A4A4A4A4GUiNC4a<0TA4A00710@4?3`l<S8b<S8bA4A4
?3`l20P800=4A4@2?3`l00<X:2Pb<S8b<S8012XZ:PDl?3`0138b<RPX:2XZ:S8b<P<Z:RX28R8R00<I
6ATR8R8@41000a0@40@820P01P00028R8R8R8RXZ:TA4A<C4a1KgmoLPoooo3oOgm`03inOWQ8B4BTY:
0092@T8024Y:BT92@T92@TY:BT92@STi>DY:BU9BDP=JFUX01TY:BT92@T92@T92@U9BDT92@P8i>CT0
1`0003Ti>C4a<C4a<D92@STi>@P82003@T920STi>@03:BTY<C4a<C4a00@Y:BT5<C4a00@Y:BTQ8B4Y
:BTa<C43:BTY0R4Q8@0361PH8B4Q61PH00<H61P5410@0R4Q8@03:BTY@T92g]kN01KgmoLIoooo000G
oooo4?Ogm`0;Zj^[MgMgC4a<C4a<?3`l30`<C4a<A4A4GUiNC4a<?3`l009<C4`4GUiN00QDE5A<C4a4
A4A<C4a4A4A<C4`00014A4@2?3`l00=4A4A<C4`000000TA4A003?3`l<S8b:RXZ00<R8R82:RXZ0b8R
8P03:RXZ<S8b:RXZ008Z:RX01R8R8RXZ:R8R8RXZ:R8R8RXZ:P8R8R801ATI6B8R8Q0@40P820000005
20P800DR8R8Z:RXI6ATZ:RZ0P8005oOgmb3oool@moOg00f][JecLg=:BTY:BTXa<C4820Q:BTY2@T9J
FUY:BTXi>CU2@T9:BTX015YJFP08DU9BBTY:>CTiBTY:>CTiBTY:0000@T920STi>@03@T92BTY:0000
0092@T84<C4a0R4Q8@8Y:BT38B4Q00<Y:BTa<C4Y:BT00RTY:@068B4Q:BTY8B4Q:BTY8B4Q:BTY0R4Q
8@0361PH8B4Q61PH00L@41001B4Q8BTY:B4Q8BTY:G]kN`0GmoOg6Oooo`005ooooa3gmoL00lC4a::R
XTa<C003A4A400/0000410A4A4@B4Q9DE5@<30aDE5@D51@<30`L71`R8R800TA4A003?3`l30`<10@4
008000002@@412PX:000000003`l?28R8RPX:28R8RXZ:P028R8R00<0000R8R800000128R8P0;0000
8R8R8R8R8R8R00008R8R00008R8R00008R8R6ATI00<00003410@00<820P0000820P0100000048R8R
00002PX:P8206?Ogmb3oool@moOg00?>c/j4Q8A:BTX00d92@P8000002D92@Q0@459BDPP8259BDQ0@
40P821PH624Q8@02@T9200<a<C4820P000000`000008:BTY00000000>CTi<C4a:BTY8B4Q:BTY2B4Q
8@0700008B4Q8B4Q8B4Q00008B4Q000000<Q8B4011PH624Q8@00000000<H61P5410@0P00008Q8B40
0`0008B4Q?Ogm`0GmoOg6Oooo`005ooooa7gmoL01<g=cK^k^dA4A4A4A09<C4`01C`l?4A4A4a<C3`l
?4A4A002GUiN00EDE5A<C4a<C4`<30a4A4@00S8b<P0:A4A4?3`l:2PX?3`l:RXZ8R8R?3`lA4A48R8R
:RXZ1B8R8P<I6AT0228R8QTI6B8R8P00028R8QTI6BXZ:Q0@408I6AT28R8R0QTI6@04410@00006ATI
6ATI0a0@400820P8410@6ATI8R8R6ATI<S8b8R8RC4a<6_Ogmb3ooolAmoOg00CFe]K>c/i2@T92@T82
BTY:00Di>CU2@T9:BTXi>CU2@T800UYJFP05DU9BBTY:BTY:20P8>CTi008a<C400d92@STi>C4a<@02
>CTi00La<C4i>CU2@T8a<C4Y:BTQ8B4a<C40124Q8@0361PH8B4Q8B4Q00@Q8B400aPH62TY:APH6002
61PH0R4Q8@<H61P00`0001PH624Q8@0361PH00<@410H61PQ8B400R4Q8@03<C4a8B4Q@T9201[gmoLI
oooo000Goooo00?_knogmoOgmoL03oOgm`04cLg=IVIVA4A430`<0Ta<C004A4A4C4a<A4A4C4a<0TA4
A09NGUh00fi^KP0003`l?002:RXZ0S`l?0060000<S8b?3`l:RXZ?3`l:RXZ0R8R8P8I6AT012XZ:R8R
8QTI6ATI6@<@41028R8R00h@410R8R8R8R8I6ATR8R8I6AT0000@410R8R8I6AT@410I6AT0000@4102
20P800@@410820P820P@41026ATI00<l?3`Z:RX000000^OWiaWgmoLPoooo00?_knogmoOgmoL03oOg
m`04e]KFFUYJ@T9220P80TY:BP04@T92BTY:@T92BTY:0T92@P9JFUX00f][J`00034a<@02:BTY0STi
>@030000<C4a>CTi008i>CT00c4a<B4Q8C4a<@028B4Q0S4a<@8Q8B4361PH0R4Q8@0461PH8B4Q8B4Q
61PH0R4Q8@03000061PH8B4Q008H61P00b4Q8A0@41PH6002410@00@H61P@410@410H61P28B4Q0STi
>@030000inOWinOW01WgmoLIoooo000Goooo4oOgm`0AMgMgIVIV10@4C4a<?3`lA4A4?3`lC4a<30`<
GUiNC4a<A4A4?3`lC4a<0000<S8b:RXZ008R8R802c`l?2XZ:RXZ:RXZ:QTI6B8R8QTI6B8R8QTI6B8R
8Q0@40026ATI00D0000@410@410@410I6AT00Q0@40030000410@410@00<I6AT00`0001TI6A0@4002
410@00<820P0000820P010P8208I6AT01R8R8Q0@428R8QTI6FIVI^OWia[gmoLPoooo4oOgm`0ALg=c
FUYJ0000BTY:>CTi@T92>CTiBTY:20P8FUYJBTY:@T92>CTiBTY:0000<C4a:BTY008Q8B4013Ti>B4Q
8BTY:C4a<@HQ8B4011PH624Q8B4Q8B4Q8@<H61P0124Q8APH61PH624Q8@8H61P38B4Q00<0000Q8B4H
61P00QPH60L@4100224Q8APH624Q8APH624Q8APH6492@^OWia[gmoLIoooo000Goooo4oOgm`05gMgM
P820A4A4C4a<A4A4009<C4`2A4A400Pl?3a4A4A<C4a4A4@l?3`0000b<S8Z:RX28R8R00TZ:RXR8R8R
8R8Z:RXb<S8I6ATZ:RX0000R8R800aTI6@058R8R0000410@410@6ATI00<@4100128R8Q0@410@410@
408I6AT0100001TI6ATI6A0@40D820P02Q0@41TI6B8R8Q0@428R8QTI6B8R8RXZ:Ta<C861PA_gmoLP
oooo4oOgm`05inOWNg]k@T92BTY:@T92009:BTX2@T9200Pi>CU2@T9:BTY2@T8i>CT0000a<C4Y:BT2
8B4Q00La<C4Q8B4a<C4a<C5:BTXQ8B4i>CT01R4Q8@04000061PH61PH8B4Q0aPH60048B4Q61PH61PH
61PH0R4Q8@04410@8B4Q8B4Q61PH1A0@400561PH8B4Q<C4a0000<C4a008Q8B400bTY:D92@XB4Q00K
moOg6Oooo`005ooooaCgmoL01K>c/eIFES`l?4a<C4A4A004C4a<0UADE004A4A4?3`l20P8<S8b1b8R
8P07?3`l410@:RXZ00006ATI410@6ATI008@410011TI6A0@410@410@408I6AT01A0@40P821TI6@P8
210@40026ATI00<0000I6AT@410010P82003410@6ATI8R8R008I6AT01`0002XZ:R8R8S`l?4A4A6i^
K]GEe@0KmoOg8?oooaCgmoL01Kfm_E9BDSTi>DY:BT92@P04BTY:0U9BDP04BTY:>CTi20P8<C4a1b4Q
8@07>CTi61PH<C4a00008B4Q61PH8B4Q008H61P0124Q8APH61PH61PH608Q8B401APH624Q8B4Q8A0@
41PH60028B4Q00<0000Q8B4H61P0110@400361PH8B4Q<C4a00<Q8B401RTY:B4Q8C4a<CTi>EYJF^OW
ia_gmoLIoooo000Goooo5OOgm`048R8RC4a<A4A4C4a<0P`<300910@4A4A4A4A4A4A451@D30`<0000
:2PX8R8R008000000aTI6@0001TI6@026ATI00@0000@4100000I6AT5410@00<0000@410000000Q0@
4004000020P8:2PX20P80P0000046ATI000000006ATI0P00008R8R802ATI6@0001PH610@4000020P
828R8P@411@D5002IVIV7?Ogmb3ooolEmoOg00@0001:BTY2@T9:BTX220P800P0001BDU92@T92@T8@
410820P0000Y:BT48B4Q00@0000Q8B40000H61P3000000@Q8B4H61P0000H61P3000000<H61P@410H
61P00P0000058B4Q>CTi8B4Q0000410@008Q8B400a0@424Q8B4Q8@058B4Q0QPH60<Q8B40134a<@00
0492@V=SHacgmoLIoooo000Goooo5_Ogm`03KVi^MgMgE5AD009<C4`00`@414a<C5ADE002E5AD00=4
A4@D51@l?3`00RXZ:P0;8R8R410@00008R8R6ATI410@6ATI410@00006ATI20P8008I6AT2410@00@I
6AT@410@410820P2410@0R8R8P06C4a<GUiN8R8R8R8R:RXZ?3`l0b8R8P046ATI8R8R:RXZ?3`l0RXZ
:P06<S8b:2PX?3`lC4a<IVIVkno_7OOgmb3ooolFmoOg00=kNg]cLg=BDU800TY:BP030000BTY:DU9B
009BDU800dY:BQ0@43Ti>@02:BTY00<Q8B4H61PQ8B400R4Q8@<H61P28B4Q00H@410Q8B4Q8B4H61P0
000Q8B4261PH00L@410H61PH61P820Pi>CUBDU9JFUX00S4a<@8i>CT00c4a<B4Q8B4Q8@028B4Q00XY
:BTi>CTa<C4Y:BTa<C4Q8B4a<C52@T9BDU;_knlMmoOg6Oooo`005ooooaKgmoL03?ooofi^KVi^KUiN
GUADE0`<34A4A4a<C5ADE5iNGTa<C4A4A08l?3`01S8b<R8R8R8R8Q0@428R8Q0@408I6AT01B8R8P00
010@41TI6A0@40026ATI0Q0@40036ATI410@410@008@410010P8238b<S8b<RXZ:P9NGUh3A4A400=D
E5A4A4@l?3`00R8R8P<b<S801C`l?4A4A4a<C5iNG^o_k`0NmoOg8?oooaKgmoL03oooog]kNf][JeYJ
FU9BDPP82492@TY:BV=SHeYJFTY:BT92@S4a<CTi>C4a<@028B4Q00<0000Q8B4H61P00QPH608Q8B40
0aPH624Q8APH60028B4Q0QPH60038B4Q61PH61PH008H61P01a0@44Y:BTY:BSTi>EYJFV][JeYJFP02
BTY:00=BDU9:BTXi>CT00R4Q8@<a<C401CTi>@P82492@U9BD^o_k`0NmoOg6Oooo`005ooooaSgmoL0
2XR8R6IVITa<C4a<C3`l?4A4A4a<C5ADE5iNGTI6AP<l?3`00c8b<RXZ:QTI6@028R8R0aTI6@030000
410@410@008@41000aTI6A0@410@40026ATI00d820P@410R8R8@410R8R8b<S94A4A<C4`l?3`0000R
8R8Z:RXb<S800c`l?008C4a<A4A4A4A4A4A4?3`l10@4IVIVMgMg7oOgmb3ooolHmoOg00ZLW9aJFUY:
BTY:BTXi>CU2@T9:BTYBDU9[Jf]JFUX2>CTi0S4a<@08:BTY8B4Q8B4Q8B4Q61PH8B4Q61PH000011PH
60038B4Q61PH61PH008Q8B402A0@41PH624Q8@00034a<DY:BT92@U9BDSTi>@028B4Q0S4a<@<i>CT0
24Y:BT92@T92@T92@S4a<@00059BDW=cLaogmoLIoooo000Goooo6_Ogm`05GUiNE5ADA4A4C4a<E5AD
009NGUh00di>CUiNGS8b<P03<S8b00@0000R8R8l?3`Z:RX28R8R00<0000I6AT@41000QTI6@8@4102
8R8R0aTI6@058R8R20P88R8R?3`l8R8R0094A4@00`00028R8R8R8P028R8R00TI6ATR8R8l?3`b<S8Z
:RXl?3a<C4a4A4C=cLd08?Ogmb3ooolJmoOg0U9BDP03@T92BTY:DU9B009JFUX00dY:BUYJFS4a<@03
<C4a00T0000Q8B4i>CTa<C4Q8B4a<C40000Q8B4H61P00R4Q8@0461PH00008B4Q<C4a1B4Q8@05<C4a
>CTi>CTi@T92BTY:008Q8B400c4a<B4Q8B4Q8@028B4Q00Li>CTa<C4Y:BTa<C52@T9BDU;Fe]H08?Og
maWoool001OooolJmoOg00>RXZ9<C4a<C4`00Ta<C006E5ADGUiN0000KVi^C4a<:RXZ0S8b<P03:RXZ
<S8b?3`l008l?3`28R8R00XZ:RXI6ATI6ATI6ATR8R80000I6ATb<S8R8R8Z:RX28R8R00@0000Z:RXZ
:RXZ:RX28R8R00Tl?3`Z:RXl?3`l?3`b<S8Z:RX410@Z:RXl?3`00TA4A003E5ADC4a<moOg023gmoLP
oooo6_Ogm`03[Jf]@T92BTY:009:BTX01U9BDUYJFP0007]kNdY:BRTY:@8a<C400bTY:C4a<CTi>@02
>CTi00<Q8B4a<C4Y:BT01R4Q8@06BTY:8B4Q>CTi<C4a8B4Q410@0cTi>@04<C4a8B4Q>CTi<C4a0STi
>@05<C4a:BTY0000:BTY<C4a008i>CT00dY:BU9BD_Ogm`0PmoOg6Oooo`005ooooa_gmoL01dA4A000
02@T94A4A4a<C5iNGVIVIP02000000QFEUH/;2`000020P80000X:2P00014A4@210@40P000003410@
8R8R20P8008000002A`L72`/;00004A4A4a<C00004A4A5ADE4a<C004A4A40P`<3004A4A410@410@4
C4a<0TA4A0030000GUiNinOW027gmoLPoooo6oOgm`07@T92000061PH@T92BTY:FUYJHf=S00800000
0e9BDRTY:@000002000000DY:BT00012@T80000@41000P00000?61PH<C4a8B4Q0000@T9261PH>CTi
61PHFUYJ@T920000@T92DU9B@T92BTY:00=2@T8220P800=2@T80000000000d92@P030000DU9BinOW
027gmoLIoooo000Goooo7OOgm`06a<C4MgMgGUiNGUiNA4A4E5AD0Vi^KP07MgMgKVi^IVIVKVi^MgMg
GUiNA4A4009<C4`046IVIUiNGWMgMda<C4A4A000038b<TA4A4a<C6IVIUADE4a<C4A4A4a<C5ADE5iN
GP9<C4`3A4A40Ta<C005GUiNA4A4GUiNA4A4/k>c02CgmoLPoooo7OOgm`06c/k>Lg=cFUYJFUYJ@T92
DU9B0W]kN`06Lg=cJf][Hf=SJf][Lg=cFUYJ0TY:BP07DU9BNg]kFUYJLg=cDU9BBTY:410@009:BTX0
1U9BDW]kNe9BDTY:BT92@TY:BP9BDU82BTY:00Y2@T8i>CTi>CU:BTY2@T9BDU9:BTYBDU8i>CVm_KdT
moOg6Oooo`005ooooaogmoL02j:RXUiNGUADE5ADE6i^KX20P7MgMfi^KVIVIVi^KWMgM`03KVi^0UAD
E00:KVi^GUiNGUiNKVi^0000<S8b:RXZ<S8b?3`lGUiN0Ta<C0Dl?3`010@414a<C5iNGUiNGP9DE5@2
A4A400?4a<CgmoOgmoL08oOgmb3ooolOmoOg00^][Je[Jf]BDU9BDU9[Jf^4Q8AcLg=[Jf]:BTY[Jf]c
Lg<00f][J`06@T92DU9BJf][Jf][FUYJNg]k0TY:BP04>CTi<C4a>CTiFUYJ0TY:BP8i>CT3<C4a00@0
0012@T9BDU9BDU82BTY:00<@4112@T;Fe]H09OOgmaWoool001OooolPmoOg00>k^k]>CTiNGUh00UiN
GP03KVi^R8R80000009gMgL016IVIWMgMgMgM`00009gMgL01Fi^KX20P5ADE5IFETa<C002A4A40S`l
?003A4A4E5ADA4A400A<C4`00eADE5iNGVi^KP02KVi^00=<C4`0003oool09_Ogmb3ooolPmoOg00S6
a/IBDU9JFUYJFUY[Jf]kNg^<S8`00002Lg=c00AJFUYcLg=cLg<00002Lg=c00A[Jf^4Q8ABDU9BDU83
BTY:0STi>@03@T92DU9B@T92009:BTX01492@TY:BT92@U9BDP9SHf<015YJFT92@P000?ooobKgmoLI
oooo000Goooo8_Ogm`0=gMgMGUiN?3`lC4a<E5AD0000KVi^R8R8P820R8R8MgMgIVIVP82000=gMgL0
0fi^KP0007MgM`02IVIV0Vi^KP04GUiNIVIVGUiNIVIV0Vi^KP07MgMgP820KVi^C4a<A4A4GUiN^k^k
02SgmoLPoooo8_Ogm`0=kno_Jf][DU9BBTY:Hf=S410@Ng]kS8b<Q8B4S8b<Lg=cHf=SNg]k00=cLg<0
0f=SHg=cLg=cL`02FUYJ00=[Jf]SHf=BDU800U9BDP03FUYJJf][Jf][009[Jf/01F=SHdY:BT92@U9B
D/K6aP0XmoOg6Oooo`005oooo`03kno_moOgmoOg027gmoL01]gMgIVIVGMgMa4A4I6ATK>c/`>IVIT0
1820P7MgMeiNGWMgM`B0P802MgMg00F0P81^KVi^KViVIVIgMgL00X20P007KVi^IVIVC4a<C4a<KVi^
/k>coooo02WgmoLPoooo00?_knogmoOgmoL08OOgm`06inOW]KFeS8b<Q8B4YJFUa/K60ibLW006Ng]k
Lg=cFUYJLg=cNg]kQ8B40W]kN`9cLg<03W]kNf][Jf=SHf=SHf][Jg]kNf][Jf=SHeYJFT92@TY:BV=S
Hkfm_OooobWgmoLIoooo000Goooo00?gmoOWinOgmoL09OOgm`06eMGEinOWa<C4TI6AXj>SPH610X20
P0@00002MgMg00@0001VIVH0001VIVH2KVi^00I>CTi4A4A6ATH00016ATJATI4/moOg8?ooo`03moOg
inOWmoOg02GgmoL2inOW0/K6aP08YJFUQ8B4U9BDQ8B4410@8B4Q410@00000g=cL`03Hf=SJf][Hf=S
009SHf<01T92@U9BDU9BDP000492@[Fe]BcgmoLIoooo000Goooo00C_knogmoOgmoOWinLYmoOg00?_
knogmoOgmoL00oOgm`07inOWgMgMeMGE^k^kcLg=a<C4inOW03CgmoLPoooo00C_knogmoOgmoOWinLY
moOg00?_knogmoOgmoL00oOgm`?WinL01<K6a]KFe]kNg^OWicCgmoLIoooo000Goooo=OOgm`03kno_
moOgmoOg03KgmoLPoooo=OOgm`03kno_moOgmoOg03KgmoLIoooo000GooooK_Ogmb3ooom^moOg6Ooo
o`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Ooo
o`00ooooobgoool00?ooool]oooo0011oooo0P0000?oool400000oooo`<00003oooo0`000003oooo
0000000000;oool20000Loooo`@00003oooo0`0000Coool400000_ooo`<00015oooo0010oooo00@0
003oooooool00003oooo00<0003oooooool00_ooo`030000oooooooo00?oool00`000?ooooooo`03
oooo00@0003oooooool0001eoooo00@0003oooooool00003oooo00<0003oooooool00_ooo`040000
oooooooo00000_ooo`030000oooooooo04Koool0043oool00`000?ooo`00000200000_ooo`030000
oooooooo00;oool400000_ooo`@00002oooo00@0003oooooool0001eoooo00@0003oooooool00003
oooo00<0003oooooool00_ooo`040000oooooooo00000_ooo`@00015oooo0010oooo00<0003ooooo
ool00oooo`@00003oooo0P0000Coool200000_ooo`@0001foooo0`0000Coool010000?oooooooooo
o`8000000oooo`0000000003oooo0P0004Koool0043oool00`000?ooooooo`2>oooo00@0003ooooo
ool00003oooo00<0003oooooool0DOooo`00@Oooo`<0002<oooo100000?oool20000Doooo`00oooo
obgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00oooo
obgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00oooo
obgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`006?oo
o`KgmoL00oO_koOgmoOgm`0MmoOg00K^eLk^cKGgeKggeKggeHCgeLH2mmg>00?geLKggLkggLh01OOM
cP;geLH00oOE_Nk=]Nk=]@02k/B]00CU/icU^jGU/icU/i`8fj^D00SKXXcBXXcBXXCKVHCBXXcBXXC0
VHCBXX`9moOg00?gknogmoOgmoL02_Ogm`03mno_moOgmoOg00?gmoLPoooo9oOgm`03k^k^moOgmoOg
013gmoL4k^k^0nGUi@[Kfm/5d];B00?0`<3Bd];gmoL06oOgmaWoool001Soool01?O_koOgmoOgmoO_
k`[gmoL00oOWioOgmoOgm`0EmoOg00CgimkgcKGgeKggeKd3mmG600GggLkgeLKggLkggLkgeLH00oOM
cP;geLH2k/fe0^k4[@?U^jD00nFcW=^[U=^[U002fj^D00KKXXcKZiCKZiCKZiCKXXCKXX`4dZ:<00CB
XXCBXXc0VHCBXX`6moOg00?gknogmoOgmoL04oOgmb3ooolhmoOg0nk^kPGUiND:fm_K1];BdP03`<30
d];BmoOg01_gmoLIoooo000Hoooo0_Ogm`03mnOWmoOgmoOg00;gmoL00oOWioOgmoOWi`0?moOg00?g
inOgmoOgmoL02_Ogm`03mlG>mlFemmFm00;geH@00oOMc_OEa_OEaP04mmG600KgeHCVaKGgeHC^cKG2
a;G2a:D2i82U00C1/jG1/hC1XicKXi@2fj^D0]:RQ006fj:4dZ:4dZ:4fj:<fj^DdZ:41]:RS003dZ:4
`9V4d/B]00_gmoL00oOWioOgmoOWi`03moOg00?ginOgmoOgmoL00_Ogm`04mnOWmoOgmoOgmnOW0_Og
mb3ooolcmoOg00CVi^KgmoO^k^k^k^h2`/;200GTi>C0`<31`L7Kfm_1`L400]_Kf`?Bd]800m_Kfm;B
d];BdP02fm_K2=;BdP03`<30d];BmoOg01_gmoLIoooo000Hoooo0_Ogm`03mnOWmno_moOg00OgmoL2
mno_00?gmoOgknogmoL02OOgm`03mno_moOgmoOg00WgmoL01NkEc^k=]OOE_OOE_OOEQ003mmG600Wg
gLkgeKggeLKgeLKBa<K^cKGBa;gBa;GU^jD00^F[W003fk>Lfj^Dfk>L00CK/i`00m^cYM:RQ=:RS005
dZ:<00?KXXcBXXCKZi@01=:RS003fk>LmoOgmoOg00WgmoL2mno_4?Ogmb3ooolWmoOg00?^k^kgmoOg
moL02OOgm`03`/;2d];Bd];B00CUiND8fm_K1M;BdP05fm_Kd];Bfm_Kd];Bfm_K00CBd]800m_KfoOg
moOgm`0KmoOg6Oooo`006?ooo`03mno_moOgmoOg02?gmoL01_OEa_OE_OOE_OOEa_OEQ?OMcPKgeLH0
2?OE_M;4a_Nk]ONk]NJkYNjk[NjkYNFcW0;UZi`2fiV<0]^[U003fk>L`8V4dZ:<00CBXX`01=^RQ=^R
S=:RS=^RS0CBXX`00m;4_OOgmoOgm`0ImoOg00?gknogmoOoool07ooooc?gmoL01=;Bd_OgmoOgmoOg
m`?^k^h2iNGU1M_Kf`03d];B`<30d];B00?Bd]83fm_K00?Bd];Kfm_Bd]801=;BdQggmoLIoooo000H
oooo0oOgm`03mno_moOgmoOg023gmoL01OOEa_O=]OOE_OOEa_OEQ005mmG600OVaHCgeKg^cKGgeLKg
eKggeLKVaKD00_Nk]@0;k[^]iK>LiJ^L`HV4iJ^Lk[>UiJ^Lfk>LdX2<dZ:<fk>U00?BXX`01M:RQ=^I
Q=:RS=:RS=^[U003dZ:<00?gimkgmoOgmoL06oOgmb3ooolamoOg00?^k^kgmoOVi^H00oOgm`04k^k^
moOgmoOgi>CT0^GUi@05fm_KiNGUk^k^`L71fm_K00;Bd]800m_Kfm;Bd];BdP02d];B00?Kfm_Bd];B
d]801=;BdQkgmoLIoooo000Hoooo1OOgm`03mno_moOgmoOg01kgmoL2mmFm1?OEaP04k/femmFmmmG6
mmG60^k=]@CgeLH00nK5Q?OE_ONk]@02k[^]00S^^jGU^jGUZic^/jG^^jg^/jG1RHcKXX`2dYV<0]:R
S006dZ:4dZ:<fj:<dZ:<fj:<dZ:40]:RS1kgmoLPoooo;OOgm`03i^KVmoOgmoOg00?^k^h4moOg00?^
k^kgmoOgmoL00^k^kP?UiND2k^k^00?UiNGKfm_Kfm/00m;BdP04fm_Kd];Bd];Bfm_K1M;BdQkgmoLI
oooo000Hoooo2oOgm`03mno_moOgmoOg01SgmoL02>k=]OOE_OOE_OOE_OOEQ?OE_OOEa^k=]@GgeLH3
mmg>0_OEaP0Ak/fek/B]k[^]k/B]i;^Uk[^Uk[>UiJ^Lk[>Ui:^4fiV<iJ^DfiV<dZ:<fk>UdZ:4fj^D
00?KXX`2dZ:<00?K/icgmoOgmoL07?Ogmb3ooolWmoOg00?Vi^KgmoOgmoL00oOgm`03i^KVmoOgmoOg
00WgmoL4k^k^00cUiNG^k^k^k^kTi>C^k^kUiNGKfm_UiNGKfm_Bd];Kfm_Bd]83fm_K0m;BdP03fm_K
moOgmoOg01cgmoLIoooo000Hoooo9_Ogm`04i/femmFmmmFmmmFm0^K5Q003i/FemmG6mmG600;geLH2
mmg>1?OEaP03mmg>mmG6i/F400;ga:d00nj0YNjk[NjkY@02k[>U00?TXhCUZic1RH@00]^9Q006fj:4
fj>4dZ:4dZ:4fj:4dZ:<0]:RQ003iY64moOgmoOg00SgmoL00oOWioOgmoOgm`02moOg00?ginOgmoOg
moL03?Ogmb3ooolWmoOg00?Vi^KgmoOgmoL01>KViPcgmoL00nKVi_Ogmnk^kP04k^k^00CTi>CUiNGU
iNG1`L44fm_K0];BdP05fm_Kd];Bd];Bfm_Ki^KV01kgmoLIoooo000Hoooo0_Ogm`03mnOWmoOgmoOg
023gmoL01_OEa_OE_OOE_OOE_Nk=]NK5Q0CgeLH01?OE_OOMc_OMc_OMcP;geLH3mmg>0oOEaP03mmFm
iXVemk^e00;^^jD02^FcW>BSQ>F[U>F[W>F[U=^IS=^RS=:0S=:RS=^cW0;BXX`00m^[U=:RQ>kWi`08
moOg00?gknogmoOgmoL04oOgmb3ooolYmoOg0^k^kQ7gmoL01^k^k_OgmoOgmnk^k^CTi>k^kPCUiND2
fm_K0];BdP06fm_Kd];Bd];Bd];Bfm_Kk^k^7_OgmaWoool001Soool01OOgmoO_koOgmoOgmoO_k`0P
moOg00S1TJG^cKGgeKg^cKGgeLKgeHCgeLKgeKd3mmG600GggLkgeLKggLkggLkgeLH00oOMcP07mmG6
mmg>mmG6mmFmi/femlB]k/B]00;^^jD03^B[Q>F[W=^RS>F[U=^[U=^RS=:RS=^cW=:RS=^cYM^RS=^[
U=:RQ>kWi`cgmoL00oO_koOgmoOgm`06moOg00?ginOgmoOgknl01_Ogmb3ooolUmoOg00CUiNGKfm_V
i^K^k^hDmoOg00?^k^kgmoO^k^h00^k^kP;UiND01m_KfnGUiM_Kfm_Kfm;Bd]_Kfm;BdP02fm_K00?B
d];Kfm_^k^h07_OgmaWoool001Soool00oOgmoO_koOgm`0RmoOg00=VA0SgeKg^eLh03oOEaP03mmg>
mmFmmmG600;geLH01_OE_OO4[Nk4[NjkYNjcYNBSQ0CUZi@00m^[U=:RS=^[U002dZ:<00?K/icKZiCK
Zi@02_Ogm`03mnOWmoOgmoOg01;gmoLPoooo9OOgm`03MgMgk^k^i^KV01OgmoL3k^k^1>GUi@04`L71
fm_Kd];Bfm_K0];BdP?Kfm/OmoOg6Oooo`006?ooobCgmoL0181^Hd940?OEa_OE_@_geLH2mmFm00?g
gLkgeLKgeKd00_OEaP04mmFmk/femlB]k[^]0njkY@07i;>4iK>DiJ^Dfj:<iJ^Dfj^Dfj:400;BXX`0
1=^[U=^cW=^cYM^[U1ogmoLPoooo9?Ogm`03P820De=Ck^k^01CgmoL00nk^k_OgmoOgm`04k^k^0nGU
i@04fm_K`L71fm_Kfm_K0];BdPCKfm/OmoOg6Oooo`006?ooo`SgmoL01?OWioOgmoOgmoO_kaOgmoL0
0e]<BT0Z:H1D@P05mmG60oOMcPOgeLH01OOMc_OEa_OE_Nk=]Nk4[@02k/fe00K^a:g^^jG^^jGU^jGU
/icT/h@3iJ^D00?UZicKXXcKP8@00m:RS003fj^DdZ:<bZ^401ogmoLPoooo8oOgm`03Fe]K@410P820
01?gmoL7k^k^00?UiNG^k^kUiND00nGUi@03`L71fm_Kfm_K00CBd]800nk^k]_KfoOgm`0NmoOg6Ooo
o`006?ooo`04moOgmnOWmnOWmnOW0_Ogm`03mnOWmoOgmoOg01SgmoL01OOWid04241404400>K5Q002
mmF42_OEaP;ggLh2mmG600?geHCgeKgVRKD00^j0Y@0<k[^Ui;>4k[^Ui;^Uk[^Ui;>4iJ>4fj^DiJ>D
iJ^Dfj^D`J:41]:RQ003dX24moOgmoOg01ggmoLPoooo8_Ogm`90@4000d51@Nk^k_Ogm`0BmoOg00?V
i^K^k^k^k^h00^CTi003k^k^i>CTi>CT00;UiND01M_KfnGUiNGUiL71`M_Kf`07d];B7oOgmaWoool0
01Soool4moOg0_O_ka[gmoL01_ooofeNFU<l<OOEa^k=]OOE_@cgeLH3mmg>00CgeLKVaKGga:g^^jd2
k[^U1NFcW004iK>DiJ>Dfj^Dfj^D1=^RS007dZ:4fj:<dZ:<dZ:<fj:<fj^Dk]G>01kgmoLPoooo8OOg
m`04KFe]De=CmoOgk^k^4_Ogm`04k^k^moOgk^k^k^k^2>GUi@KKfm/01=;Bd]_Kfm;Bd];BdP;Kfm/0
0nk^k_OgmoOgm`0LmoOg6Oooo`006?ooo`KgmoL00oO_koOgmoOWi`0GmoOg00B9Mg=CA4:fVHc^cKD7
mmG60oOE_@03mmG6mmFmmmG600;ggLh3mmG600?VaKGg^kG^/jD00nF[W003iJ^DiJ^LiJ^D00;UZi@4
fj:<00GBXXcKXXcKXXcBXXCKXX`00]^IQ004fj:<fj:4dZ:<k]G>7OOgmb3ooolQmoOg00<10@6f][K^
k^h04oOgm`03k^k^moOgk^k^00OUiND5fm_K00CBd];Kfm_Kfm_Bd]85fm_K00?Bd];^k^kgmoL07?Og
maWoool001Soool3moOg00?gknogmoOgmoL06_Ogm`03Dc`aP6iSmmg>00;geLH01?OE_OOEa_OEa_OM
cP;geLH3mmFm0oOEaP08mmg>mmG6mmG6mmg>mmG6iY64mk^ekY6<1NF0N`03iI64iJ^Dfj^D00;KXX`0
1]:RS=^IQ=:IQ=:RQ=^RS=:RS0;KXX`00m:RQ=^RS=:0Q002dZ:<5?Ogm`03mnOWmoOgmoOg00KgmoLP
oooo8OOgm`030000moOgmoOg01?gmoL00nk^k_Ogmnk^kP06iNGU00O1`L7Kfm_Kfm_Kfm_Bd];Kfm_B
d]800]_Kf`05d];Bfm_Kfm_Kd];Bfm_K00?Bd]8MmoOg6Oooo`006?ooo`GgmoL00oO_koOgmoOgm`0G
moOg00O1/kEC?37ggLkgeLKgeKggeLKgeH@01OOEaP04mmFmk/femmFmmmFm1?OEaP;ggLh2mk^e0^jA
S0?UP7/00nB02>F0NnF0N`02iH1k00?KP8cBXXcBXX`00]:RQ003dZ:<fj:<fj:<00;KXX`01]:RQ=^R
S=:RS=:RS=^cW>jk[@[gmoL00oO_koOgmoOgm`0?moOg8?ooob3gmoL00lW9bE=CDoOgm`0:moOg00?V
i^KgmoOgmoL02?Ogm`;^k^h2iNGU00?^k^kUiNGUiND00^GUi@;Kfm/4d];B1M_Kf`CBd]800m_Kfnk^
k_Ogm`0KmoOg6Oooo`006?oooaogmoL00e840>kEc_OE_@03mmG600?geHCggLkgeLH00_OEaP05mlFe
mlfemlfemmFmmlfe00?geLH2mk^e00KKcMKg^kGVTHCUP7_UP7?UMf/2ffIJ00?U06_KMf_KMf/00^F0
N`03`81kdYV4dZ:400;BXX@01M:IQ=^RS=^RS=^RS=^[U002fj:<00GBP8CKZiCKXXcKZiCgknl06oOg
mb3ooolOmoOg00?Bd]9CDe?Vi^H04_Ogm`04fm_KmoOgmoOgk^k^0^GUi@04`L71fm_KiNGUiNGU0]_K
f`03iNGUd];BiNGU00CBd]87fm_K00CBd];Kfm_Kfm_Kfm/LmoOg6Oooo`006?ooo`07moOgmnOWmoOg
moOgmnOWmoOgmnOW01OgmoL00i:8S00<0>k=]@02mmFm00?geHCgeKggaH@00oOEaP08mmF4i/BUk[^U
iXVUiX2UmlFemmG6mi640_N0Y@0AiY64iI64i80Q`000`B8H`6IBdb8@fb8HRFIJ`280dTIBbDA:dTIB
ffI:`01[`8P0dXP800;BP8@01m:I0=:0Q=^RS=^RS<6RQ=^RS=^RQ002dZ:<00GKXXcKZiC:/hcgilkg
inL06OOgmb3ooolNmoOg00BBTY99BDV0P83Vi^H9moOg00?Vi^K^k^kVi^H01OOgm`0:i^KViNGUi>CT
`<30d];B`L71`<30dm?CRHV9`L710];BdP05bLW9d];B`L71d];B`<3000GBd]82fm_K00?1`L7Kfm_K
fm/00];BdP;Kfm/00l;2`_OgmoOgm`0ImoOg6Oooo`006?ooo`CgmoL00oO_koOgmoOgm`0FmoOg00?0
ZkeKC4Y100000_OE_@09mmG6mmFmmmFmmlB4mmg>mmG6mmg>mlfei/BU00;U/i@02njkYOOEa_OEa^J0
S>F[U>F0Lm9NDZe<>L2[YL20Q=;4aP02bK>e00W^^jffXYc0P;FUIU;BVHbLGT[9E4[BKV?BMf/00]:8
N`;BVH@01m:0Q=^RS=^[U>FcU=^[U=^RS=^0Q002fj:<00CKZiCBXXcK/icUgNlImoOg8?oooaggmoL0
0l30`5]KFdU9B@0;moOg00?^k^kUiNGTi>@00oOgm`06k^k^iNGU`<30[Jf]`<30iNGU0];BdP08bLW9
b<S8][Jfd];BbLW9YJFUd];BR8R81m;BdP?Kfm/00nGUiM_Kfm_Kf`04fm_K00?Bd];UiNGUiND06OOg
maWoool001Soool7moOg00?gknogmoOgmoL04_Ogm`05iMg_[IVLBC`i`964mmFm00;geLH00oOE_Nk4
[NJIQ002mmG600?geKgga:gUP8@00]^IQ00NmmFmmk^eiH1k`H1SMb8HdWM[iJ^LffIJiI64bS<QmnOW
mnONk]G>iGM[iI64b@QB]X1S]Z:L`964W6IBR5A:dUiBbHQcbI5kdYV4dYUcdYT0fj:<fj^DiK>L0^Fc
U004fj:<fj^Dfj:<fj:<0]^[U003d/C6moOgmoOg01OgmoLPoooo7?Ogm`04iNGU[Jf]BDU9`<301?Og
m`;^k^h5moOg00CUiNGKfm_Cdm?gmoL2iNGU00O9bLUgMgO0`<3Kfm_UiNGKfm_^k^h00_Ogm`04i>CT
iNGUbLW9bLW90[Jf]P04P820W9bLbLW9d];B0/W9b@;Bd]83fm_K0^GUi@KKfm/00m;Bd_OgmoOgm`0H
moOg6Oooo`006?ooo`[gmoL00oO_koOgmoOgm`0?moOg00FUXZfBR8a0:RWVeHcgeLH00_OE_@03mlfe
k[^UiY6400?geLH02OO4[NFRS=^ALnFRS>jcYM]VFY8b:HPJ2?OMcP02mnON0_O_k`05mnO6mno_mnON
mmg>k/fe00;^eLh04];4aZe<>Je^FXU^JbA4:KID@/1VD]9^Hm^IQ=:ILm:I0=^RS>FcW>FkYNFcW>Fc
U=^RQ=:RS0CKZi@00m;4]M;4e^GMi`0GmoOg8?oooacgmoL01:FUYI:BTT10@>k^kPCgmoL2k^k^1?Og
m`;UiND01]_KfnCTi=_Kfi:BTXV9RNk^kPSgmoL02nKVi^k^k^k^k^k^k];BdZf][HV9RJFUYFATI;Jf
]/30`003d];B0]_Kf`?UiND2fm_K00SBd];Kfm_Kfm_Kfm_Bd];gmoOBd];UiNDGmoOg6Oooo`006?oo
o`;gmoL01oOWioO_koOgmoOgmoO_koOgmoOWi`0CmoOg00F0Mg=CA49gC4;VaKGgeLH00_OE_@03mlfe
k[^UmmF400?geLH02?O4[L600<V0Hm:8Lje<>H0R8I9D@];4S0?gimh01?OWioO_koOWa_O_k`;gimh0
4Nk=]OOWinK5c^kEc^FkYL2[YJED@PT006@l:KID@/1VD]:8Lm:RQ=:I0=^RS>FcW>jkY@02iK>L00C1
XXCKXXcKZiCKXX`2fj^D00?KTJGgkno^inL05oOgmb3ooolLmoOg00B0P81CDe=gMgO^k^h4moOg00?^
k^kgmoOgmoL00oOgm`03iNGUfm_KbLW900:0P8000i:BT];Bd_Ogm`08moOg00?Vi^KgmoOgmoL00^k^
kP07iNGUP820RHV9BDU9I6AT][Jf`<3000;Bd]82fm_K00CUiNG^k^kUiNGUiND7fm_K00?gmoO^k^kg
moL05_OgmaWoool001Soool:moOg00CginOgmoOginOginL6moOg00?ginOVinOgmoL00_OWi`08iLGW
mnOWdmGW0@00@2PY`964i/F4mmF40_OE_@03i/B]iY6UiY6400;geLH06_OE_NFRS<200<28Ji8@01@P
46DR0:D0D/610>JAQ?O5YNJAYOO5c_OWc^F1Q?OWc_O5W>F1Q>F[W>JSYNK5a^F1Q<;4Q=;4a^k5Q800
008f20P052@<<HPD0<00D]:IQ=^RS>FcU>jkYNj0YNFcQ<6RQ=:RQ=^RQ=^0Q=^RQ=^RS<20U86AQ<20
U=;4[M?Ei`[gmoL00oOWioOgmoOgm`08moOg8?oooaGgmoL02nKVi_OgmoOgmoOgmnGUiOOgmm?Cd`41
0D10@<30`>KViP03moOg0nKViP?gmoL02NGUiL71`L30`<30`10@46EUIJFUYNGUiM?Cd`02i^KV0_Og
m`05iNGUmoOgmoOgmoOgiNGU00?Vi^H01NGUiL;2`/;2`Y2@T861P@02=SHf00/T92B0P83Bd];Bd];K
fm_UiNG^k^kTi>CUiNGKfm_Bd]801=_Kf`05`<30PH61`<30d];Bdm?C01GgmoLIoooo000Hoooo00?g
moOgknogmoL05oOgm`05bK_>Dc`a6aTQI4A2d/C600?geKd01>k4[NjkYOO=]NJAQ0;geLH03>k=]NFA
Q<V0HnF[U>F[W>F[U=]gJm]VF^F0Lm^ALnF[W>FAQ0;UXX`00nBRQ?Nk]M9^H`02fgM[01kUTHCUXXCB
KV?UXXc^cKGU/icK/hCBXXbfVHbLKUY]8QRL?370R03KXXcU/ic^^jG^a:g^^jG1XXcKXXcBXXcBVHCB
XXcKXXcK/hCKeNOBa=K9^lKBa<kUeNLDmoOg8?oooa_gmoL01451@A/K6fATI=;BdP?gmoL2k^k^00Sg
moO^k^kgmoOgmoO^k^kUiNG9bLWKfm/2iNGU0]_Kf`;UiND00m_KfnGUiNGUi@02iNGU00C^k^kgmoOB
d];Kfm/3iNGU00?Bd];UiNGTi>@00]_Kf`08d];B][JfW9bL30`<bLW9d];Bfm_KiNGU0^k^kP03iNGU
fm_Kfm_K00?Bd]83fm_K00?Bd];9bLW0`<005OOgmaWoool001SooolImoOg00J0KV<^8R50:RT^6AS0
THCgeLH2mmFm0_O4[@0;k/B]mlB]iH6DmmG6mmFmmk^eiJ:<`H00k[>Uk/femmG600;geKd02^JkYNjc
YNjcYNF[W>jcYNF[W>B1S>jAS=^IS=^IQ0;KMf/07LUVF]9^Hm9^Hm^cW<V8Jl:08LV8Q=:RS:EgJe<@
46@I4908>M:RQ>FcU>jkYNk4[NjkYL6SU=^RS=:RQ=:RS=^RS=^[U=^SU?OgmoO_km_=e];4e]?Ei`0D
moOg8?oooa[gmoL01820P00002h^;/30`0GgmoL00nk^k_OgmnGUi@03moOg00GUiNG9bLWUiNG^k^kV
i^H00oOgm`;^k^h01>CTi>k^k^GUiNGUi@;^k^h4fm_K00_9bLWBd];Bd];9bLWBd];^k^k9bLWBd]:U
YJE0@42LW9`00];BdP04iNGUk^k^k^k^iNGU0]_Kf`;Bd]83fm_K0_Ogm`03fm_Kd];BmoOg01CgmoLI
oooo000Hoooo2?Ogm`03mnOWmoOgmoOg00ggmoL01nGMi`8001/I65<b<BhR6?OEa_Nk]@02mmFm0^k4
[@0;mk^ek/B]i/B]mmG6mmFmmlB]iJ^D`H00k[^]mmg>mmG600;ggLh2mmG61?OMcP;g^kD2k[^]013^
/jGUZic106_UP7_BMf_BKV?0IU;005;0IU:]KUZL?34^211T6A0DA3WBVHCUZi@3k[^U00G1XXcKXXcB
XXcBVHCKVH@00]^RS005W81k[IVLfmGWiMgWb/G601CgmoLPoooo6?Ogm`05iNGUd];B;Rh^4a<C;Rh^
00CgmoL00nKVi^k^k_Ogm`02k^k^0oOgm`04iNGUbLW9iNGUk^k^3?Ogm`;^k^h2iNGU00?Kfm_UiNGB
d]800/30`009d];B`<30[Jf]W9bL92@TMgMgW9bLd];BiNGU00;^k^h00nGUiM_Kfm_Kf`02d];B0m_K
f`05W9bL[Jf]fm_K`L71k^k^01CgmoLIoooo000Hoooo2?Ogm`03mnOWmoOgmoOg00ggmoL02m_=eQ88
240Z:BhR8DTZ8OOEa^k=]ONA]OO=]Nk=]ONk]@02k/fe00SVaKGg^kGg^kG^a:gUZiC9R03^^jggeLH2
mmg>1?OEaP;ggLh00oOEa_OEQ?O=]@03k[^U00[^a:gU/iCUZiCKVHcKVHCBR7_006_BKV?0IU:fE482
TS8Y00><337BR7_KXX`00njkY@0<`J>Dfj:<dZ:4dYV4fiV4fj:<fj:4]Z:LI4@imnONmno_k^OW5?Og
mb3ooolHmoOg00OKfm^BTY8K6a/00019BDWgmoO^k^h00_Ogm`03i^KVmoOgk^k^00;^k^h2moOg00G^
k^kUiNGKfm_9bLW^k^h03?Ogm`?^k^h3iNGU00?Kfm_Bd];UiND00];BdP07`<30][JfTY:B[Jf]W9bL
d];Bfm_K00;^k^h00nGUiM_Kfm_Kf`02d];B0m_Kf`05][JfI6ATmoOgi^KVk^k^01CgmoLIoooo000H
oooo00?gknogmoOgmoL05OOgm`06iMgW02@@dYV<[FiJP5A:mmG60_OE_@03mlfek/femmFm00;geKd0
2>k=]OOE_Nk=]Nk=]NF[U<600>FcW>k=]@KgeLH01OOMc_OEa_OMc_OEQ?O4[@02k[^U017U/ic^^jGT
/hCUZiCUXXcKXXcKVHCBVHCKVHCKVHcBVHCBR7_BR7?9P6?9R6_KVHCU^jD00^jkY@0<`J:<dZ:<fj:<
dZ:4fj:<fiV4fj^D`:^]P7McMeiBmoOgi^OW5?Ogmb3ooolHmoOg00?UiNE9BDVBTY800X20P0CgmoL0
1>KVi_OgmoOgmoOgm`;^k^h01nKVi^k^k^GUiNGUiM_KfnGUiNKViP0;moOg00C^k^kTi>C^k^k^k^h3
iNGU00?Kfm_Bd];Kfm/00]_Kf`;Bd]83bLW900SKfm_UiNG^k^kUiNGKfm_Bd];Kfm_Bd]83fm_K00C0
`<20P81gMgOVi^HEmoOg6Oooo`006?oooaOgmoL02oOWii:0Q6I40>K5]NJAQ>j9YL;4Q>k=]NJ1]OO5
]NK5Q002mmF400_gTKGgeHCgeKggeKg^cKGT/hC1P8CKT@3TP8C^cKGgeH@00_OMcPCgeLH03?OMc_N1
Q>jkYNjkYNFcU>BcQ>jkYNFcU>F[U=^RS=:RQ=:0Q0;0P002`94000K0P03BR030R03BP8CBV@3U/h@2
i;>400_1P8CBP8CBP8CBP03BXXCKXXcBXXC0XjD96039^hCBa;D05OOgmb3ooolHmoOg00ZBTY9VIVKg
moOVi^K^k^k2`/;^k^kVi^KgmoOVi^H6moOg00K^k^kTi>CUiNG1`L7Kfm_Ti>@:moOg0^k^kP03i>CT
k^k^iNGU00;UiND00m_Kfm;Bd/30`005`<3000SBd];0`<3Bd];Bd];UiNGTi>C1`L7Kfm/6d];B00C0
`<092@W9bLWBd]8EmoOg6Oooo`006?oooaOgmoL01M_EioOE_OOEQ?OE_OOMcP02k/fe00CgeKgVaKGg
eKggeKd6mmG600Og^kG^a:gTZhCUXXcKVHC^^jG^cKD00_OEaP08mmg>mmG6mmG6mmFmmmg>mmF4k/fe
k[^U0^FRS008iJ^D`J:4dZ:4dYV4`9V4bI5kbI5cbHQc0lVAL`08bHQcbI5cdXQkfj^DdYUciK>LiK>D
`HV40m:IQ0?BXX@01;JRW40b<HV0Q>GMkaGgmoLPoooo5oOgm`03fm_KmoOgmoOg00;gmoL2k^k^00?g
moO^k^kgmoL02?Ogm`;^k^h2iNGU00?:b/[^k^kgmoL02?Ogm`;^k^h3iNGU00CKfm_Bd];Bd];0`<08
bLW900?Bd];Kfm_Bd]800^GUi@03fm_Kd];Bd];B00;Bd]801]_Kfm;Bd[Jf]T10@8V9RNGUiAGgmoLI
oooo000Hoooo5oOgm`06flgFmmFmmmF4mmFmmlB]k/fe0_OE_@04mi6emmFmmmG6mmG61?OMcP09mmG6
mmFmmk^ei;>4iJ:<fi5ciK>Dk[^UmmG600;ggLh3mmG600CgeKgVaHC^^jgUZi@2iJ^L00SKZiCKVHCB
VG?BVG?9TG?9TG_9P7?9TG<2bI5k0/VAL`07bH1SdZ:4fiV4iJ^Dfj^Dfj:<fh2400?BVH@01m:RQ=:R
S=:RS;JRW1/I65=4@XV0Q00EmoOg8?oooaOgmoL00m_KfoOgmoOgm`02moOg00?^k^kgmoOgmoL02oOg
m`05k^k^iNGUiNGU`L71k^k^00SgmoL2k^k^0^GUi@?Kfm/2d];B2LW9b@03d];Bfm_KiNGU00?Kfm/4
d];B00KKfm_Bd]:f][HK6a]CDe>1PH4EmoOg6Oooo`006?oooaKgmoL02^kWioO=]OOE_NK4Q?O4[NFc
U?OE_M;4a_OE_OO5]@;geLH6mmg>00CgeKgg^kG^P:GUZi@2iJ:<00_^^jGgeLKgeLKggLkgeLKg^kGg
a:g^cKGgeKgga:gU/i`00^F[U004fj^DdX00dZ:<dYV40/V8L`04bI5cbI5kdYUcdYUc0/VAL`07bH1S
fiV4iJ^DiK>DiJ^DiJ:<dZ:<00?BVH@01m^IQ=:RS=:RQ;JIS1/I8BhR<LVk]@0EmoOg8?oooaKgmoL0
2>k^k_OgmoOgmoOgmnk^k^GUiOOgmm;BdPcgmoL2k^k^0^GUi@03k^k^moOgmoOg00CgmoL01>k^k_Og
moOgmoOgm`;UiND00m_Kfm;Bd];BdP02d];B1<W9b@;Bd]83bLW900GKfm_UiNGUiNGUiNGKfm/01];B
dP05fm_K][Jf6a/K;Rh^`L7101GgmoLIoooo000Hoooo5_Ogm`08mmFmmmG6mmFmi/f4iJ:<fj^DmmFm
k/fe0_OE_@;geLH6mmg>00cgeLK^cKG^P:GU/iCUXXcKVHCUXXc^cKGggLkgeLKgeKggeLH2mmFm01?g
eHCgeKg^a:g^^jGU/icKZiCBRHBfP6_9R7?9R6_9R7?9TG?9TG_BVG?BR7_BVG?9TG?BP03U/i`00^Fc
U0?KXX`3dYV400KBXXcKVHCBXXbLP8@g:S5]KW/FmoOg8?oooa[gmoL01>k^k/71`OOgmnk^kP_gmoL3
k^k^00CUiNG1`L7UiNG^k^h9moOg00K^k^kTi>CKfm_Kfm_Bd]:f][H5bLW90];BdP03`<30d];Bfm_K
00?UiND3fm_K1];BdP03W9bL=cLgKFe]01KgmoLIoooo000Hoooo5_Ogm`;geKd02OOEa^FAS>FcW=^[
U?Nk]Nk=]OOE_ONA]OOEaP04mmg>00SgaLkggLkggLkgeLKgeKgga:G^^jGU/i@2iJ:<00?^a:ggeLKg
gLh00_OEaP04mmg>mmG6mmG6mmFm0^jk[@0?iK>Lfk>Lfj:<fj:<bI5kbHQc]X1[bH1cbI5kdYUcdYV4
dXQkfiV4`J^DiK^U00;U/i`03]^RS>F[U=^RS=^RS=:RQ=:IQ=:RS=:RQ=:RS:F0JbhR8D0b<E=4@^G=
kaCgmoLPoooo6_Ogm`04iNGU`L71moOgk^k^3_Ogm`04k^k^iNGUiNGUk^k^2OOgm`03k^k^i>CTfm_K
00?Kfm/00lW9bH20P<W9b@02bLW90m;BdP03fm_KiNGUiNGU00;UiND01<71`M_Kfm_Kfm_Kf`GBd]80
1:FUYBh^;T10@451@AGgmoLIoooo000Hoooo00?gmoOginOgmoL01OOgm`03mnOWmoOgmoOg00[gmoL0
2NK5U?O5]OOEQ>K5Q<R00<2AQ>B9YNk=]ONk]@02mmFm00?geLKggLkggLh00oO5cP;ggLh04_OEa_OE
Q>J1]ON0YNBcQ>FSU>FRQ>BcS>J1Q?OEa_O5Q?OEQ?OEa_OMc_O5a_OEQ>k4YNB[Q0;1XX`02m:RQ=:R
S=:0Q=:0Q=^IQ820HlV8Hl20Lm:80=^RQ<6RS002i;>400KU/icU/hC1XiC1XXCKP8CBXX`2dX2400WB
VHCBXXCBXXb0R7=002482PPC01P0102UPH@04oOgmb3ooolEmoOg00SVi^KgmoOgmoOVi^K^k^k9bLW0
`<3^k^h=moOg00O^k^kgmoOgmoOTi>CUiNGTi>CVi^H02?Ogm`04k^k^`<30`L71fm_K1=;BdP07TY:B
P820bLW9`<30d];B`L71iNGU00;Ti>@2iNGU00?1`L7Kfm_Kfm/01M;BdP07fm_KP820@41020P80000
De=CYJFU01?gmoLIoooo000Hoooo5?Ogm`09mnOWmlB]mmFmmlB]iK>Dfh24fk>Lk/femk^e00;geKd0
0oOEQ?OE_OOMcP03mmg>00CgaLkggLkggLkgeLH2mmFm00Gg^kG^a:g^^jG^^jGU/i`00_OEaP0<k/fe
k/B]mmFmmmG6i/F4mk^ek[^Ufj^Dfj:<dYV<dYV4dZ:<0m:IQ007P81SbHQ[dYUcfj:<iJ^LiK>Li;>4
00?U/i`2fj^D00C1ZiCKXXcKXXcBXX@3fj:<00KBVHCBVG?9R7>fP6/0A4;UgNLCmoOg8?oooaSgmoL0
1>GUiM_Kfm_Kfl[:bQ7gmoL2k^k^00GUiNGgmoOgmoOgmoO^k^h00oOgm`04k^k^moOgk^k^fm_K1];B
dP05bLW9][JfbLW9d];Bfm_K00;UiND01^k^k^GUiNGUiNGUiM_KfnGUi@?Kfm/01=;Bd]_Kfm_Kfm_K
f`;Bd]801<W9bA8B4X20P>GUiA?gmoLIoooo000Hoooo5?Ogm`08mmG6mlfeiJ:<fi5cdViSdQ40iK>L
d/Be0oOE_@03mmF4mmG6mmg>00CggLh05oOEa_OMc_OEa_OEa^K5]ONk]Nk4[Njk[Nk=]OO4[OOEQ?OE
_Nk4[Njk[Nk=]OOE_ONA]NjkYNFcU>F[U=^IQ=:IQ<2A0002bI5k00KBVG?9TG>0P6?9R7?KVHcKZi@2
iK>L00KT/hC^^jGU/icU/icKZiCUZi@2fj:<00GKVHCBXXCBVHCKVHCK/i`01=:IQ003]Y64moOgmoOg
01;gmoLPoooo5_Ogm`03iNGUfm_Kd];B00;Bd]800l30`?OgmoOgm`0=moOg00C^k^kgmoO^k^k^k^h4
moOg0^k^kP?gmoL00nk^k^GUiL71`@02d];B0lW9b@04`<30][Jf`<30bLW90]_Kf`;UiND2k^k^0^GU
i@03`L71fm_Kfm_K00;Kfm/2d];B0]_Kf`?Bd]800i:BT_OgmoOgm`0CmoOg6Oooo`006?oooaCgmoL0
2oNc]OO=]NFAQ>EgJm9gJlV02>F[W>k=]OOE_OOEa_OE_@03mmG600?ggLkgimkggLh00_OMcP;geLH0
1_OE_NJ9]OO4[Njk[Nk4[Nk=]@?geLH03_OE_OOEa_OEa_OE_NJ0YNjkYNFcW=^[U=:IQ<2IQ<20LlVA
Ll28LlVAL`;9R6/01m:8Nm^RS=^[U>FcW>jkYNBcQ>jcY@02iK>L00CU/iCUZiCKXXcKVH@2dZ:<00?B
VHCBXXcKXh@00/VAL`;BVG<00l2SYOOgmoOgm`0BmoOg8?oooaKgmoL2iNGU00CBd];9bLWKfm_Ti>@?
moOg00C^k^kgmoO^k^k^k^h8moOg0^k^kP04iNGUd];B`<30`<300/W9b@05`<30bLW9bLW9bLW9d];B
00;Kfm/01>CTi>k^k^GUiNk^kP?UiND3fm_K0m;BdP;Kfm/2bLW900?Bd];0`<3gmoL05?OgmaWoool0
01SooolDmoOg00gVTHCga:gUTHCKTG?BMf_0P03^^jG^cKGgeKggeLKgeKgggLkgeLH01OOMcP;geLH0
1oNk]OOE_NJ9]Njk[OO4[ONk]Nk=]@02mmG60_OMcP?geLH01nK4YNjkYNFcW=^RS=:IQ<VANl20L`03
`8Qc00C9TG_0T@3KZiCKZi@2iK>L00GU^jGT^jGU^jGU/icUZi@00]^[U004fj:<fiV<fiV<fiV<0]:I
Q003dZ:4bHQ[bHQ[00;BVH@00m^cW?OgmoOgm`0BmoOg8?oooaCgmoL02>k^k_OgmnGUiM_Kfm;Bd/W9
bM;Bd^k^kPogmoL2k^k^00?gmoO^k^kgmoL01_Ogm`05k^k^moOgk^k^iNGUd];B00;9bLT4`<3000C9
bLWBd];Kfm_Kfm/3iNGU00C^k^kUiNGUiNGUiND6fm_K0];BdP03fm_KbLW9bLW900;Bd]800oooooOg
moOgm`0BmoOg6Oooo`006?oooaCgmoL02_N9]ONk]NFRS>FAQ<V8LlV84>jk[Nk=]OOEa_OE_@;geLH3
mmg>00WgeLKggLkgeLKgeKg^cKGgeKg^cKGgTKG^a:d00^jkY@04k[^]mmG6mmG6mmg>1?OEaP07i/Fe
iK>LiJ^Dfj:<dYV4`9V4bI5c00?9TG/00m:RQ=:0Q=^[U002iJ^L0^jkY@0:i;>4iK>LiK>LiK>LiJ^D
fj:<dZ:<dYV<dYV4dZ:<0]:IQ006dY64dXQkdXQkdYUcdZ:<dY645?Ogmb3ooolFmoOg0^GUi@;9bLT0
0m_Kfnk^k_Ogm`0:moOg00?Vi^KgmoO^k^h00_Ogm`?^k^h8moOg00G^k^kUiNGUiNGBd];0`<001<W9
b@04`<30d];Bfm_Kfm_K0^GUi@03k^k^iNGUk^k^00?UiND00l71`M_Kfm;BdP05d];B00?Kfm_Bd];B
d]800];BdQGgmoLIoooo000Hoooo4oOgm`0;mmF<i864iI64iJ:<fiV4P81[`80@k/B]i/Fei/F4mmF4
00;geLH00oOMc_OEa_OEaP02mmF400GVaKG^cKGVaKGVTJGVRKD00^j0Y@07k[^UkXVUk/BUi/FemmF4
mmFmmmF400?geLH02?NAQ>jkYNFRQ=^RS=:IQ<2IQ<2ANl2A00;0VH@2dX2400S1ZiCU/icU/hCT/hCT
^jGU/hCU/iCUZi@2`J^D00?KXXcBP8CBP8@00m:IQ007dX24`864`800dX24dZ:4dZ:<dX0001CgmoLP
oooo5?Ogm`07i>CTiNGUiNGUfm_KP820`<30fm_K00;Vi^H9moOg00C^k^kVi^KVi^KVi^H5k^k^00?V
i^KgmoOgmoL01_Ogm`03k^k^iNGUd];B00;0`<001lW9bL30`<30`<30`=;Bd]_Kfl71`@02iNGU00?T
i>CUiNGUiND00^GUi@;1`L47d];B00?1`L70`<3Bd]800m;BdQCgmoLIoooo000Hoooo4_Ogm`04mno_
iK>D`H00fiV<0Y9VDP04[GMSY80Qk/femmFm1_OEaP;geKd00oO=]NK5]Nk4[@02k[^]00?U^jG^^jg^
a:d01>k=]@03mmF4mmG6mmFm00?geLH01NK5]Njk[NF[U=^RS=:IQ003bI5k00[0VHCBVHCBVHCBXXCU
ZicU^jGU/icUZiCU/icU^jD2iK>L00KUZiCKZiCKZiCKXXCBXXcBVH`2dYV400SBVHcBXXBUIU;9KU;B
XXCK/icBR7?^inLCmoOg8?oooa?gmoL2iNGU00O9bLVBTY:BTY:][Jff][KUiNGVi^H02_Ogm`?^k^h0
0nGUiNk^k^k^kP04k^k^1oOgm`;^k^h00nGUiM;Bd/W9b@03bLW900C0`<3Bd];Bd];Kfm/9iNGU0m_K
f`GBd]800m_KfjFUYLW9b@03d];B00?^k^kgmoOgmoL04OOgmaWoool001SooolBmoOg00WgeKgUXXc0
R7>0E4:UKUZ0E4Z9GTZ0:R7geKd00_OEaP05mmFmmmG6mmG6mmG6mmFm00;geLH01^k=]Nk4YNk=]Nk4
[Njk[NFcW0;U^jD01^jk[Nk=]Nk=]Nk=]NK5Q?OEaP;geKd2mmG6013VcKG^^jGUZiCBVG?BVHC9TG_0
P7?9TG?9R8CBVHcBVHCBXXCKZiCUZicK/icKZi@5iJ^D00CKZiCBVHcBXXCBVH`2dYV40]:RS007`::4
[FiJ`6IBbI5kdZ:<dYT0mk^e01?gmoLPoooo4oOgm`08iNGUd];BP820YJFUP820RHV9TY:BiNGU2OOg
m`G^k^h4iNGU1>k^kPKgmoL2k^k^00CUiNGBd];9bLW0`<03bLW90];BdP;Kfm/00nGUiM_Kfl71`@05
iNGU00?Bd];Kfm_Bd]801M;BdP04`<30[Jf]`<30bLW90];BdQCgmoLIoooo000Hoooo4_Ogm`09mlB]
fi5c@10YdYV4P5A:Mda2I4A2Q2X0mmFm00CgeLH01OOEQ?OE_OOEa_OEa^kEcP04mmG600_^cKG^^jgT
ZhCUZicKZiCUZic^a:g^cKGVaKGgeLKgeKd00_OEaP06mmFmiY6]iK>Lfj:<dXQkbHR40/VAL`06`8Qc
dYUcdYV4dZ:<fj:4fj:<0]^[U003iK>LiJ^L`J:400;KZi@01]^RS=:RS=^[U=:0S=:RS=:RQ0;BVH@0
2=:IS<2RQ:egHl28HlV8JlVALm:02=^RS1?gmoLPoooo4oOgm`08fm_KbLW9@410P820MgMgI6ATW9bL
iNGU2?Ogm`03k^k^moOgmoOg00;gmoL3k^k^0^GUi@04`L71k^k^k^k^k^k^1_Ogm`04k^k^iNGUfm_K
`<300lW9b@03`<30d];Bd];B00GKfm/2iNGU1=_Kf`OBd]801<30`=;BdZf][L30`0;9bLT00m;Bd]_K
foOgm`0BmoOg6Oooo`006?ooo`03mno_moOgmoOg00kgmoL04_O_knFcU>FAQ8a^FU<l<H1D@X1NDWMN
DVDR0?OE_OOEa^k=]OOEa_OE_NK5]Nk=]M;4]Nk=]@CgeLH02];4_OOEa_OEa/20YNFkYM^[U=^RS=^[
U=^cW>k=]@CgeLH01OOE_NJAYNFkYM^RS=:IQ002bI5k00K0R7?9TG_0VHCBVHcBXXCBXX`2fj:<0m^[
U00CdXV4dZ:<fj:<fj:<fj^Dfj:<dZ:<dZ:4dYV4dZ:4dYV4dYV<`::4[GMSW5i:W4`iW3`a`0QBdXQc
01?gmoLPoooo4_Ogm`;UiND019bLW0410H20P820P09gMgL00nGUiOOgmnk^kP02moOg00C^k^kgmoO2
`/;^k^h4moOg00CBd];gmoOgmoOBd]82iNGU0m_Kf`;^k^h5moOg00G^k^kUiNGKfm_0`<39bLT00/30
`005bLW9`<30d];Bfm_Kd];B00GKfm/2d];B0m_Kf`KBd]800l30`=;BdZf][@02W9bL00>8R8SBd];B
d]804oOgmaWoool001SooolAmoOg00_gaIcKTG?UZi`T000:410001P08R50101T003geHCgeKd00^K5
]@0:mmF4i/F4i/B]bX6D`80@P800D`0H0000P800P81[0h000007P0P8`808dXP8bH00fj^Di82UmmF4
00CgeLH03NJA[NFcW=^0Q<2ALlVALlV0Hl28Hh20JhV0Ll2A0<2A2<2A0<2IQ002dX2400_0P8CBXXcB
XXCKXiCKZiC1ZiCKZiCBXXCBP8cBP8CBXX@00/2IQ008dX2<dZ:<YH1[W4I2YEA2Q4@0P012dXP04oOg
mb3ooolBmoOg00?Kfm_UiNFTY:@00`000004@410I6ATi>CTmoOg0^KViP;gmoL01^KVi/;2`/30`820
P5=CDd10@0B0P800292@T8V9RH20P<30`<W9bM_KfnGUiNk^kPGgmoL01Nk^k^GUiM_Kfl30`<W9b@02
`<3000>0P829RHW0`<000l30`0;Bd]800l30`=_Kfm;BdP02fm_K00?1`L7Bd];Bd]800m;BdP;0`<02
d];B00JUYJFLW9bUYJF4Q8C9bLWBd]8CmoOg6Oooo`006?oooa7gmoL03>k4[NEgJnF[W08@02h842hR
8D0Z:D0b<Fa40?OEa^k=]OOE_@;gcKD2mmFm017^cKG^a:gK/ic0VH@T02W9/ke]GUZUP6]CA48B01QT
?2V]Mf>UIU:UE4:LC3VU403^a:d01?OEaP0:i/B]iK>Lfj:<dYUcbI5c[HQcP81S]X1[`9V4dZ:<1=^[
U007fj:<dYV<dYV<`9V4dZ:4fj^Dfk>L00;KZi@01M:RS<2IQ=:IQ<2IQ=:IQ002dZ:<00J]P6^UIU:U
E4:UE4:0A4;BVH@CmoOg8?oooa7gmoL01>k^k^GUiNGUiM;BdP8^;Rh2@41000=]KFg^k^kVi^H01OOg
m`0<i^KVk^k^fm_K`<30I6ATYJFUBDU9YJFUDe=C4Q8BMgMgI6AT0ZFUY@04W9bLYJFUiNGUk^k^1?Og
m`06k^k^iNGUfm_K`<30[Jf]`<300[Jf]P03`<30d];Bfm_K00CKfm/2d];B00?0`<3Bd];Kfm/00]_K
f`;Bd]800l30`=;Bd/30`003d];B00J][JfUYJFUYJFTY:C9bLWBd]8CmoOg6Oooo`006?oooa3gmoL0
3?ooonFcW<U^D^F[U40R8B@R8BhR<D0Z:E<l<FA<0?OE_OOEaP?^cKD04oOEQ?OE_Nk=]Nk=]M:RS=^[
U820NdTl>DTZ8HV0Q7M^U00027M<>KJRW:fIW81D@ZED@/:I8Nk=]@02mmG60_OMcP09i/F4k[^Ufj:<
dYUcbHQ[]X1[[FiJ]X1SdZ:400?K/i`00m^[U=:RS=:RS002fk>L00KBP8cBXXCBXXcKZiCK/icKZi@2
dZ:400O0VHCBXXC0VHC0VHC0P8BBKV>9GTX00YaNBP03`012fiV4moOg01;gmoLPoooo4?Ogm`0<oooo
iNGUbLW9iNGUk^k^0000;Rh^@410De=CI6ATk^k^moOg0nk^kP;gmoL04>KVi^k^k];Bd]_Kfl30`9bL
W4U9BHV9RGMgMa8B4VATI7MgMjBTY820P:FUYM;BdP;^k^h4moOg0^k^kP03fm_K`<30][Jf00:][Jd0
0kJf]];Bd]_Kf`03fm_K0];BdP03fm_Kd];Bd];B00;Bd]82fm_K0m;BdP0;`<30d];B`<30d];B`<30
TY:BRHV9W9bLP820bLW9fm_K01?gmoLIoooo000Hoooo3oOgm`0;ooooI3`YmlB]bFiBfiV4I0006aTQ
;R8Q@2XYBBXYIT`@00;geKd3k/fe01CgeHCgeKggeKggeLK^a:gKZiC:ZhCK/iagGU9C?350:RTC40QC
<RU]GUZUIU:]KU[0IU;1XXc^cKGgeKd2mmg>01?gimkVaHC^^jGKXXcBR7^fP6^fP6>T049]8QQgA3W0
R7?9TG^006>]P6^LIU:BIU:]Mf?0TG_0TH@00]:RQ005`9V4dZ:<dZ:<`824`95k00;0VH@02]:IQ=:I
S<2A299VDXUDBYaVDZEVD/20Hm:8Nooooa;gmoLPoooo4?Ogm`0<I6ATmoOgbLW9fm_KiNGU0000;Rh^
@410BDU9MgMgk^k^moOg0nk^kPCgmoL01>k^k]_Kfm_Kfnk^kP9CDe<02T10@1/K6e=CDe=CDbDU9Jf]
[L30`=_KfnGUiNk^kPCgmoL2k^k^00OKfm^BTY:f][Jf][JUYJE]KFegMgL00/30`0:][Jd00ibLW9:B
TX20P002`<300];BdP03`<30d];Bd];B00C0`<02d];B00G0`<2BTY:9RHVLW9b1PH400];BdP03oooo
moOgmoOg013gmoLIoooo000Hoooo3_Ogm`0=iMGWBBXYBBXQmlB]iK>LmlB]I@00928Q@2XY;R8Q@2XY
IT@0mmFm00?^cKD01?O=]OOEa_OEa_OEaP;geKd02nk=]L6SU=^[U=^cYJF0Ji9VDP14@WM<@ZEVD[J0
Hje^FP02iK>D00?^cKGgeKgggLh00_OWgP0Ci/B4k[^Ufj:<dXQkbHQ[]X1SY01:W6iBP5A2`:^]d/Bm
=P0iKB8HI3`YMda2TViSREABP5A2[H1[00:]R7<00l2ILl2ANl2AN`02bI5k00G0VHCBVHCBVHb0R01g
C4800X1DBP03TVIBdXQcbH1S01?gmoLPoooo3oOgm`0=@D51BDU9moOgiNGUmoOgiNGU92@T@410;Rh^
@410MgMgk^k^i^KV00;^k^h6moOg00_^k^kUiNGKfm_Kfm^UYJFBTY9TI6BBTY9gMgNTY:B][Jd00nGU
i@03k^k^moOgmoOg00;gmoL2k^k^00gKfm_0`<2f][Jf][J][JfLW9b0P830`<2f][IgMgM]KFeTI6Ag
MgL00X20P0B][Jd3`<300/W9b@05`<30d];B`<30[Jf]MgMg00:0P8000i:BT];Bd/W9b@0CmoOg6Ooo
o`006?ooo`04mno_moOgmnOWmno_2_Ogm`0<Dc@a@1TH=aTHiJ:<mlB]iK>LP008@3`i;RXi6aTH;R8Q
P4`@0^k=]@;geKd00nFcW>K5]Nk=]@02mmG600?geKg^cKGTPI@00]:RS00Cfk>LdZ:<Y81S[FiJ]X1S
[FiJdZ:4fiV4iJ^4k/B]mmFmmmg>mnONmmg>k/BUiK^Ufj:<dYUcbHQ[00:fP6<04jEVDYaVDYb0Nm_=
eP`0FPT842hZ>GM<@U<l<GMVFP4D099VDY9^Hi9VDYa^DZegHlV0Jl2IQ=:RQ002`9V400WBVHB0P6]g
C49TA3UgGU9gC4;BP8C9KU;oool04_Ogmb3oool?moOg00A0@40g=cOUiNGgmoL2iNGU00D0000^;RhK
6a/^;Rj0P8000^k^kP;gmoL01>GUiNk^k_OgmnKViP;gmoL2k^k^00[UiNGBd];Kfm_Bd]:][Jff][J]
[JfTY:CBd];Kfm/2iNGU00C^k^kgmoOgmoOgmoL2k^k^00?UiNGKfm_0`<000kJf]P0;YJFUW9bLV9RH
KFe]W9bL2@T9;Rh^MgMgDe=CRHV9De=C00>BTY801Hb<S<W9bLW9bL30`=;BdP03`<3000RUYJEgMgMT
I6AgMgMBDU;Kfm_9bLWooolBmoOg6Oooo`006?ooo`03mnOWmoOgmoOg00_gmoL0244R200R8Bh@42@8
21<002E<@P008@0R<@8T8R402d0Z:H1<0?N9]NK5]Nk=]OOEa^B9YL200<Z9U>K5Q?OEaP02mmg>00GV
aHC^a:GT/hcU/icKXX@00]:RQ007fh24fiV4`J:4iK>Di82Ui/B]mmG600?ggLh01NJ0YNBcQ=^SU=:0
Q<20L`03P81S01b025;0P02]06<00000200921100010:24404X0=35C7100A49065:T06>0P6?0P030
P0SBXXc0P8C0VHC0P8@00490A0Q013508R5T337000S9CT8CmoOg8?ooo`kgmoL01T51@@0002h^;R@T
91<C4bDU9@80000292@T00Q0@420P83Vi^KVi^K^k^kgmoOTi>C0`<02`/;21?Ogm`03i^KVi>CTiNGU
00;Kfm/2d];B00KKfm_1`L7UiNGTi>C^k^kVi^H3moOg00OVi^K^k^kTi>CKfm_0`<20P830`<001820
P005@4100@4100002@T9@410008000001D10@5=CD`000410@820P003`<3000GBd];0`<30`<30`<00
00001410@0;9bLTCmoOg6Oooo`006?ooo`03mno_moOgmoOg00[gmoL02>kWidTZ8E<b:BhR8D0I62h@
44Tl>B@R8@8K6B42;R8Q01B0A27gcKGgeKggeKg^cKGgeLK8PC7KZiCBVHc^a:g^eLkggLkVeLkgeLK^
cKG^a:gKZiCKXiCKXXcBVG<2dXQc00CKZiCU^jG^cKGgeLH2mmg>01WgeLK^RJGU/icKZiCBXXc0VHC9
R6_9P6?9TG_9TG>fP6?BXXb@8PRBKV=gC49CA49gC3U0<S6004:UKUZUP6^]R7?0R7?9TG?0P0P01L2I
Q008900Y@38aDdA2BBXYDc8Y`088bFiBoooo4_Ogmb3oool=moOg00[^k^i9BDU1@D4^;Ri0@40^;Ri9
BDTg=cL0000K6a/2;Rh^00V0P83^k^kgmoOgmoO^k^kgmoO^k^k9bLWBd]800^k^kP;gmoL00nk^k^KV
i^k^kP04fm_K0];BdP04fm_KiNGUiNGUk^k^0oOgm`;^k^h00nGUiM_Kfl30`005bLW900RBTY;Bd]:L
W9bBTY9gMgMCDe=0@420P803YJFU00B][Jg0`<30`<3Bd]84`<3000JUYJETI6A0@41CDe=9BDUBDU82
bLW900?oooogmoOgmoL04?OgmaWoool001Soool=moOg00>UTJE08R5C?3400TTZ:@08@2XY@38a010@
6aTH@2XY6aTHBBXYIT@00_O=]@07mmFmk/femmFmiY64fk>LYH1k]X1[00;0TG/02:f8Li9VDY9^HgMN
DX1DBXUNBX1D@YaVDP:UIU800lVANl6cQ>k=]@02mmG60_OE_@0=kX2UiK>Lfk>LdZ:<bI5kbI5cbHQ[
`9UcbI5kdZ:4bI5cdZ:4dZ:<00;0TG/01:F0JjE^FZD0B/2IL`;9TG/01=:ILm:IQ<2IQ=:RQ0;BXX`0
2M:RQ<2IQ5<L44Tl>D0Z:BhI66@l<KH0@/U^DP0CmoOg8?ooo`ggmoL00jFUYDU9BD10@002BDU90d10
@0064Q8B@4106a/KBDU9MgMgk^k^0_Ogm`06k^k^moOgmoOgk^k^PH61][Jf0/30`0:][Jd00i:BTWMg
Mh20P002RHV900N0P824Q8BUYJG9bLWKfm_UiNG^k^h00oOgm`;^k^h00nGUiM_Kfl30`003bLW900?0
`<39bLW0`<000m;BdP;0`<03YJFU00G0`<39bLW9bLWBd];0`<001=;BdP09`<30MgMgDe=CBDU9@410
;Rh^92@T][JfbLW901?gmoLIoooo000Hoooo3OOgm`0:[J:U028Q;R8Q;R8Q928Q;R8Q@2XY928Q6aTH
6aTQ0T0Z:@04P4@0k/femmFmk/fe0_OE_@0CmmF4k/fek[^]dYV<RFi[RGMcY@00YGM[TVIBP5iBW6iJ
REA2RD`iREA:[GMS]X1[dYV4iK>Dk/fe00;geLH2k/fe00K^P:G^^jGK/icKZiC9R8C0R7<2]X1S00K0
R7?9TG_KZiCBXXC9TG_9TG<2`9Uc00JfP6_9TG?BVHCBVG?0VHCBVH`6`9V400R]R7<T000^:SU0?3T^
6AR9GTZT04;0IU8<moOg00?gknogmoOgmoL01?Ogmb3oool=moOg00Z][Je0@40^;Rh^;RhT92@^;Ri0
@40^;Rh0000K6a/2@41000B0P83^k^kVi^K^k^h4moOg00C^k^kBd]:9RHV9RHT2YJFU0X20P003W9bL
RHV9RHV900:9RHT01[Jf]];Bd^GUiOOgmnk^k_Ogm`G^k^h00m_KflW9bL30`003][Jf00C0`<39bLWK
fm_Bd]82bLW900C0`<20P839bLW9bLT2d];B0/30`003d];B`<30`<3000;0`<002H20P6ATI3Lg=bh^
;T10@2h^;X20P:FUYL30`00CmoOg6Oooo`006?ooo`ggmoL03l2[_A<@22hI62hI62@R8CLI62hR8@P0
01/I62@R8D0b<E=4@TTB4>k4[OO=]@03mmFm0_OEaP0:mmFmk/fedZ:<dYV<P8R4bHR4dYV<`964`8Qc
P81k0[J0J`04bI5kfj:<k[^]i/Fe0oOEaP0=mlfemk^ekX2UiK^Ufk>Lfj^DbHR4]X1[P5A2TUA2[FiJ
`9UcbI5k00;BXX@2fj:<0]:RQ006`824`9V4dZ:4dYV<`9V4dZ:<0/2IQ00;dYV<dZ:4`9V4YH1[020Q
=bXa928Q6aTH`8QcY012bFiB00[gmoL00oOWioOgmoOgm`06moOg8?ooo`ggmoL03l30`5=CDbHV9Rh^
;R@T93Lg=bh^;PT92@X:2R@T9410@5=CDfe]KM_KfnKViP06moOg00G^k^kBd];Bd];Bd]:UYJD00l30
`005YJFU`<30][JfP820fm_K00;^k^h5moOg0^k^kP0<iNGUfm_KbLW9][JfTY:BP820TY:B[Jf]`<30
d];Bfm_Kd];B0]_Kf`;Bd]82`<300];BdP04`<30d];B`<30`<300];BdP09P820De=C92@T=cLg92@T
6a/KP820YJFUbLW901?gmoLIoooo000Hoooo0_Ogm`04mnOWmoOgmoOgmno_1oOgm`0>d/gN4a0@;R8Q
928Q;R8Q@2XY;R8Q0P00;R8Q6aTQ928QDdA2P080k/B]0^k=]@;geKd2mmG600GggLkgeLK^cKG^cKGV
aH@00_OEaP06d/Bmmk^edX2ed/C6mk^emmG60^k=]@03i/F4mmG6mmG600;^cKD02?O=]Nj0[Njk[NFk
YNF[W=:RS<VANa94@P9gA3T01Ya^F[J0Jl200=:RS=^[U=^RS0;BXX`05=:RQ=:IQ=:RS=:RS<2IQ=:R
S<20Q<2IQ=:RS<2IQ=:RQ81NDP0R8BhR<A/I8D0b<LVALh54@/1VDXV0Q1;gmoLPoooo3OOgm`0>d];B
De=C2PX:92@T;Rh^@410;Rh^4Q8B;Rh^6a/K92@TDe=CP820d];B0^k^kPKgmoL3k^k^0_Ogm`06d];B
moOgd];BmoOgd];BmoOg0nk^kP;gmoL00nKVi^k^k_Ogm`03k^k^00CUiNG0`<39bLVBTY83MgMg00BD
U9C9bLWBd];Bd]82fm_K1];BdP;0`<003];Bd/30`=;Bd/30`820P410@2@T92h^;Q/K6d10@<W9bJFU
YL30`8V9RA;gmoLIoooo000Hoooo0_Ogm`;ginL9moOg00?UeNL0024020P012@R8@092000;R8Q928Q
@2XY@4@0@1P0`J^4kX2Umlfe00;geKd01?OEa_OMc_OEa_OMcP?gaLh00oOWg_OMc_O5cP02mlG>0_OM
cP06mmG6mmF<mmF4i/F4mmG6i/Fe0^J9]@05k/fekX2Uk/B]i;^Ui;>U00;T^jD02Y:008000800BP14
400@2400004d8D0P0800282000;0P0000l2A082808TAH`02P01B00n0P03BVHCBP8cBVHBUP6=002TT
8R4:0240834820PUA124002<IT90A4:BR8@04OOgmb3oool=moOg00?UiNE0@400000012@T90032PX:
20P892@T0090@4000fEUIL30`<30`00DmoOg00?Vi^KgmoOgmoL00^KViPC^k^h3i>CT00WBd]:BTY:0
P820P8000010@41CDe<10@50@4000X20P0?0`<001H20P8V9RH20P:BTY<30`003d];B00/0000T92@^
;Rh:2PX0000820PT92BDU9B<S8a0@42BTY804OOgmaWoool001Soool>moOg00m0A490<S4^8R4^8R4T
8R4^8R4:000B41P^8R5C?35CA49045;BXXc^a:ggcKD00_OE_@03mmG6mmg>mmg>00;ggLh2mnON00gg
gLkgimkgimkggLkgaLkgimkggLkgimkggLkgeLKgeHCgeKg^cKD00_OE_@0>k/B]kX2Uk/B]k/B]k[^]
k/B]k[^]i;^Ufk>Ufj^DdYV<YH1[P4A2I4@i0U<l<@0GMda2P5A:4VIBP5A:TVIBW6iJTVIB[H1[dX2<
dYV4`9V4bI5kW6iJ@2XY2P00;R8a=bXa;QTH@1TH02XQDc8YI5AB[J:U017gmoLPoooo3_Ogm`05De=C
@410;Rh^;Rh^92@T008^;Rh01a8B4Rh^;U=CDe=CDgMgMl30`<;2`P0GmoOg00?Vi^KgmoO^k^h01nk^
kP07iNGUfm_Kfm_KP820TY:BP820I6AT009CDe<01`0009:BTWMgMh20P9:BTYbLW820P003d];B00C0
`<39bLT0000K6a/2;Rh^00Lg=cL^;Rh0001]KFeCDe=TI6B][Jd04OOgmaWoool001Soool>moOg00QT
A3UC?350:RT^8R50:RT^8R4T8R492102@2XY00]CA48]25;BXXCU/icgcKGgeKggeLKgeHcgeLKggLkg
eLH00_OMcP03mlG>mnONmnON00?gimh4mmg>0_OEaPC^cKD01Nk4[NK4[Njk[Nk4[Njk[@02k/B]00SU
/hCU^jGK/icK/icBXXb0P02BKV>9E582I4@i00IgC3UgC01gC4:9E5:UKUZfP6/3`9V400g9TG_0R7>0
E4X^8R4T8R4^8R4T8R4K6AP^001C4019?3U]GU;oool04OOgmb3oool>moOg00ETI6A0@410@40^;Ri0
@4000Rh^;P070000@410@410De=CKFe][Jf]`<3001KgmoL4k^k^00?gmoO^k^k^k^h00nk^kP?UiND0
1]_Kfm;Bd/30`;Jf]Y:BTXV9R@9TI6@3MgMg00B9RHVUYJF0P83Bd]82`<3000g9bLW0`<00000^;RhT
92@^;RhT92@K6a/20P9CDe=9BDU]KFgoool04OOgmaWoool001Soool=moOg00KKeNMTA0QTC4Y0<S4T
8R50:RT2;R8Q0SLZ<@06BC`iDdA29@12]YV<fk>Lk[^U0_OE_@03mmF4mmG6mmG600?ggLh00oOWg_OM
c_OWgP04mnON00GggLkgimkggLkgeLKgeH`00oOE_@03mlB]k/B]k/B]00;^^jD3k/B]00?^/jGU^jGU
Zi`00]^cW009dZ:<`9V4bI5k[HQc[GMSW6iJT6IBYFiJ`8Qc00;0VH@02M:IQ<28Q<2IQ<VANjf8Le<l
<D0Z:BhR8D0Z:@02928Q00DK6AQ0:RU0:RUTE5:BR8`04OOgmb3oool=moOg00KKfm]TI6ATI6A0@40T
92A0@402;Rh^00PV9RHg=cM9BDUCDe=gMgNUYJFBTY;^k^hHmoOg2Nk^kP;UiND02]_Kfm;Bd];Bd/30
`<W9bJf][Hb<S9:BTYbLW:FUY@?0`<001/W9bL30`<30`<W9bJf][D10@08^;Rh01410@2@T92@T9000
0090@4000fATI9:BT_Ogm`0@moOg6Oooo`006?ooo`ggmoL01/Vc]D1426A4>E<l<D0b<D0Z:@@^8R40
2d0Z:E<l<@14@/2ANm^[U>k4[OO=]OOE_OOEQ?OMc_OEaP02mmg>00?gimkgaLkgimh01OOWgP?ggLh0
0oOEa_OE_Nk=]@02k/fe0^k4[@07k[^Uk/B]k[^]k/fek[^Uk/B]i;><00;U/i`2fk>L00CBXXCBXXcB
VHcBVH`2bI5k00c9R030VHC0VHCBVHC0VHCBVHC0R030VHC0R7>UP6]9:RU0:RT2928Q00Lg:S4T8R4K
6B4:0010:RTg:S5KC4X04OOgmb3oool=moOg00C9bLUTI6A0@41CDe<2@41012h^;P06@410De=CI6AT
TY:B`<30k^k^5OOgm`_^k^h3iNGU0]_Kf`CBd]83bLW90/30`004d];B`<30bLW9d];B0/30`003YJFU
@410;Rh^008T92@01cLg=b@T91/K6bh^;T10@3Lg=e]KF`0AmoOg6Oooo`006?ooo`[gmoL02oOWioOg
moOgma802404040<0400040b<A<R<@0R8BH00002028Q00T^8R50:250112004:0P03T^jG^a:GgaKGg
eH@00_OEaP;ggLh00oO5c_OMc_O5cP05mnON0oOMcP04mmF<i/FemmF4i/Fe0^K4Y@?^P:D05>k4[Njk
YNjkYNBcYNBcQ>FcQ>FkYNF[U<6cW=^SU=:RS=^SU=^[U=:RQ=:RS=:0Q=:IQ=:0Q=:RQ=:IS0;0VH@0
28V0Lh`8DP14240R8@0R8@008@0R8@00208002401B@R8A8@61<X<E<<0829S00@moOg8?ooo`ggmoL0
0a8B4T10@410@002@41000<C4a<0000^;Rh00P000007;Rh^@410De=CI6ATP820i>CTk^k^01;gmoL2
i^KV00?gmoOVi^KVi^H01^k^kP;Ti>@3iNGU00C1`L7Kfm_Kfm_Bd]82fm_K1];BdP05`<30d];B`<30
RHV9S8b<008000000b@T90X:2P000003000000D^;RhB4Q8C4a=CDe>0P8004?OgmaWoool001Soool=
moOg00QTC4YC101KC4YCA490<S59?3U0:RT:0002;R8Q00U0:RT^8R50135TA4:LKU;BXXC^a:g^cKGg
eH@00_OEaP;ggLh3mnON00GggLkgimkgimkgaLkgimh00oOMcP03mmG6mmFmmmFm00;^a:d00njkYNk4
[NjkY@02k[^U00C^a:g^^jGU/icT^jD2iK>L00GKZiCK/icKZiCK/icKXX`00]:RS003fj:<dZ:<dZ:<
00C0VH@04L2A0:F0JfeNDTTl>BhR8A/I61<88A8@61/I8A8@61/I60T841/I640Z:E<l<Ib0Noooo`0?
moOg8?ooo`ggmoL046ATI5=CDe=CDe=CDd10@4U9BD10@2h^;PX:2Rh^;T10@2h^;U=CDfATI0@41=;B
dP;^k^hDmoOg2>k^kP03iNGUk^k^iNGU00;UiND5fm_K1M;BdPC0`<004<W9bJFUYFe]KDU9B@X:2Q/K
6cLg=a8B4Q/K6a8B4Q/K6`T92A/K6d10@5=CDibLW13gmoLIoooo000Hoooo2?Ogm`03mnOWmoOgmoOg
00;gmoL2DdA2015KC4YTA3UCA499?3U0:RT08R4K6APg6AP^8R50:RU020QgGU9gC4;0TG_KZiCgcKGg
eH@00_OEaP?ggLh5mnON00?gaLkgimkggLh00oOMcP05mmG6mk^ek/fek/fek[^]00G^^jD01NFcW>Fk
YNFcW=^[U>FcU002fk>L0m^[U0?BXX`03M:RQ=:RS=:RQ=:IQ=:RS=:IQ8V0Lia^FVA4>D0Z:BhR8B@R
8@0R8@026aTQ0a/I6004928Q;R8QDc`aP6iS4?Ogmb3oool=moOg0U=CD`09Fe]KI6ATDe=CBDU9@410
;Rh^0000=cLg;Rh^0090@40016ATI7MgMl30`=_KfaGgmoL7k^k^00KTi>CUiNGUiNGUiNGKfm_UiND5
fm_K2=;BdP08bLW9[Jf]W9bLI6AT@41092@T@41092@T1A/K6`0492@T;Rh^De=CP8204?OgmaWoool0
01Soool8moOg00[ginOgmoOgmoOgknogmoM]GU90A0QCA49KC4YCA482@38a00l08R4K6AP^8R4^8R50
<S50001]GU9gGU:fP6_KZiC^a:ggaKGgeLKggLkgeLH00_OMcPGgimh00oO5c_OWg_OMcP02mmg>00Gg
eLKgeHC^cKG^cKG^a:d01NjkY@03iK>DiK^Uk[>U00;U/i`5fj^D00?KXXcKZiCKXX`00]:RS00EdYV4
`9V4`9V4dYV4bI5kP81[P5iBDc`a@2XY928Q@38a00084Q0H6aTQ4Q0H2@P@4Q00928Q;R8Q@38aRGMc
013gmoLPoooo3OOgm`05KFe]I6ATDe=CFe]KDe=C0090@40012h^;P0002h^;Rh^;P90@4001E]KFfEU
IKJf]]_Kfnk^kP0CmoOg2>k^kP03iNGUk^k^iNGU00;UiND7fm_K00CBd];Kfm_Bd];Bd]84`<3000J]
[Jf0P81CDe=0@4000010@4024Q8B00PK6a/B4Q80000K6a/T92@^;Ri0@429RHT@moOg6Oooo`006?oo
o`ggmoL01FA4>D04<E=4@U=4@U]<BP02BC`i0T0Z:@0:;R8Q@2XY@2XY0R0QI4A2MfIJ]X1[dZ:4iK^U
i/B]1?OEaP04mmg>mnONmnONmmg>0_OWgP04mlG>mnONmmg>mmg>0_OEaP04iXVemmFmmlfek[^]0^jk
Y@09iK>Lk[^Uk[^UiK>Lk[>UiK>LiK>4fj^DiJ^D00;KZi@01m:RS=^[U=^RS=:RS=:RQ=^RS=:0Q003
dYV400[9TG_9TG>026=TA49CA49C?350<S4T8R40024K6AP24Q0H00H9210B41PT8R4K6AQC?37^inL@
moOg8?ooo`ggmoL01FATI5=CDd10@5=CDe]KF`02BDU90T10@00:;Rh^@410@410;Rh^De=CI6AT][Jf
d];BiNGUk^k^4?Ogm`04k^k^moOgmoOgi^KV0^k^kP;UiND2k^k^00KTi>CUiNGUiNGUiNGKfm_UiND2
fm_K00?Bd];Kfm_Kfm/01m;BdP04bLW9[Jf]TY:BI6AT0U=CD`04000092@T6a/K6a/K0Q8B4P060000
6a/K92@T6a/KDe=Ck^k^4?OgmaWoool001Soool=moOg00=KC4Y0A0QKC4X00e]<BP04DdA2@2XY@2XY
6aTH0T0Z:@0=@00aMda2TVIBYH1[bHQ[iK>Li/B]mmFmmmg>mmG6mmg>mmG6mmg>00Cgimh00oO5c_OW
g_OMcP02mmg>00OgeLKgeHCgeKg^^jG^a:g^^jGU^jD00^FcW005k[>Uk[^UiK>LiJ^D`J^D00;UZi`2
fj^D00?BXXCKXXcBXX`00m:RS004`948`9V4dYV4`9V40/28L`04P6iSI4@iBC`i@2XY0Q/I60096aT0
4Q0H4Q0H2@P@6aTH4Q00928Q@2XYI5AB017gmoLPoooo3OOgm`9KFe/02410@5]KFe]KFe]KFe=CDdU9
BD10@1/K6`=0@4001VATI18B4ZFUYLW9bNGUiNk^kQ?gmoL2k^k^1>GUi@05k^k^i>CTiNGUiNGUfm_K
00;UiND2fm_K00?Bd];Kfm_Bd]800m;BdP03bLW9`<30d];B00;0`<001I:BTX20P6ATI4U9BD10@003
6a/K0Q8B4P062@T94Q8B6a/K92@T@410I6AT4OOgmaWoool001Soool:moOg01KginOgmoOVinM0A49C
101CA490A49KC4Y0A4900000000^8R508R50:RU0<S51101TA0R0AU:]Mf?0R7?BXXcTRJD2mmF40_OE
aP03mmg>mlG>mlG>00;gaLh2mnON0_OMcP05mmG6mmg>mmG6iX6ei/BU00;^P:D01^jkYNBkYNBcQ>Fk
YNFcW>BcQ0;U/i`03<6SU=^RS=^[U=^[U=^RS=:0Q=:0S=:RS=:0Q=:IQ=:RS=:0Q0;0VH@04/2A0:f0
Hh@0BP1405<l<D0Z:@0R8@008B@R8@008@80000001/I8A8@600000X0040Z:@1<@Q7gmoLPoooo3?Og
m`06i^KV@410De=CDe=C@410Fe]K0T10@003@D510000@4100090@40025=CDd51@@000:f][L30`=;B
d^CTi>k^kPogmoL3i^KV0^k^kP?Ti>@2iNGU00CTi>CUiNG1`L71`L43fm_K2=;BdP?0`<001HB4Q92@
T00005=CDd10@004000000P20P80000K6a/B4Q80000:2PY0@400000AmoOg6Oooo`006?ooo`SgmoL0
4oOWioOgmoOgmoOgmnkWifA<BTT825=4@VA<BU]<BVADDU]<BT4002hR8D0Z:D0b<D0Z:D0006eNDP02
W6iJ00B]Mf?9TG?:P8C^cKD2mmFm0_OEaP03mlG>mmg>mnON00CggLh4mmG600C^a:G^a:gga:g^^jD4
iK>L00[UZicU/icU/icU/icUZicUZiCK/icKZiCBVHcKP8`2dZ:<0170VHCBVHCBVHcBVHC9TG_0TG^]
R7>UP6^9GTYTA119:RU0:RT^8S4^8R4g:S40224B41P00R@R8@056aTQ4Q0H928QBC`ik^OW017gmoLP
oooo3?Ogm`0:k^k^I6ATFe]K@D51I6ATFe]KI6ATFe]KDe=C20P81410@008I6AT30`<W9bL[Jf]bLW9
fm_Kk^k^i^KV3_Ogm`?^k^h00nKVi^GUiNGUi@09iNGU00CKfm_Bd];Kfm_Kfm/2d];B0170`<3Bd];B
d];Bd];9bLW0`<2][Jf1PH5]KFeTI6A9BDU0@40^;RhV9RI0@40K6a/B4Q800R@T908B4Q800b@T94U9
BNk^kP0AmoOg6Oooo`006?ooo`_gmoL02oO_koOgmfeNDTTl>FA4>E]<BU=4@VADDU]<BU<402hR8@02
@38a00Q9?3U0<35]GU:0KV=gC4:LKUZfP6_:P8`2k/fe0oOEaPKggLh2mmG600GgeKg^cKGgeKg^a:g^
cKD00njkY@04iK>DiK>LiK>LiK>D0nFcW003iJ>Dfj^Dfj^D00;KZi@2dZ:<00CBVHcBVHC0VHCBVH@2
`9V400N]R7>UP6^LKUY]GU901010:RTg:S400R@R8@036aTH2P0Q6aTQ008B41P01008400042hR8FA4
@Q;gmoLPoooo3OOgm`09KFe]BDU9@410Fe]KDe=CI6ATFe]KDe=C0P820090@40024U9BD10@5=CD`00
07MgMibLW;Jf]]_Kf`;^k^h<moOg00?^k^kgmoO^k^h01>k^kPWUiND4fm_K1=;BdP0>`<30d];B`<30
`<30[Jf]YJFU30`<I6ATBDU9@410=cLg92@T0000;Rh^0Q/K6`8B4Q801000018B4Rh^;VATI1;gmoLI
oooo000Hoooo2?Ogm`03mnOWmoOgmno_00;gmoL01H1^Jd4406A4>E=4@VeNDP02Fda:00eCA490:RTT
8R5C?359?3U0001TA3UTC4Y]GU:BIU:]Mf?2P8C^a:d00_OE_@CgeLH2mmg>0_OEaP08mmFmmmG6mmG6
mmG6k/fei/fek/B]k[^U0^FcW003iJ^LiJ>DiK>L00;UZi@02NF[W>FcW>F[U>F[U>F[W=:IS=^IQ=:0
Q=:IS002dZ:40]:IQ007`940`8Qc[H1[TVIBP5A:I4@iD`@000<^8R42928Q00PK6B4B41PK6B402109
210B41Q0:RV0KV<BmoOg8?ooo`ggmoL01H20P5=CDd10@5=CDfe]K@02Fe]K00iCDe=0@40T92ACDe=9
BDUCDe=0@41TI6A]KFfBTY:][JgBd];^k^kVi^H=moOg0^k^kP03moOgk^k^i>CT00cUiND8d];B00G9
bLW0`<2][JfBTY8000000U=CD`<^;Rh01B@T91/K6a/K6a8B4Q/K6`02000000<K6a]0@420P8004_Og
maWoool001Soool=moOg01>9Mg=030QC?359?3UKC4YCA49KC4Y9?3UKC4Y0:RTT8R5C?350001C?35]
GU9TA49gC4:UP6_0P1000^k=]@?geKd2mmG600KgeKggeLKgeKggeHC^cKGgeLH2mmFm00Sg^kG^a:g^
^jG^^jGUZiCU/iCUZiCUXi@4iK>L00CU/iCUXXCKZiCKZi@2fj:<00kBXXCBXXcBXXcBVHC0VHC9TG^9
P7>UP6^LKUZ0E4YTA49C?350:24^8R43928Q00T^8R40024K6B4B41P9210B41P020QTA3Woool04_Og
mb3oool=moOg00N9RHUTI6A1@D59BDUKFe]CDe=KFe/00TU9B@0<@41092@TDe=C@410De=C@D51I6AT
MgMgYJFU`<30iNGUk^k^2_Ogm`04k^k^moOgmoOgmoOg0nk^kP03i>CTiNGUiNGU00SUiND4fm_K1=;B
dP0:`<30bLW9[Jf]YJFUW9bLP820@410De=C@410;Rh^12@T908K6a/01Q8B4PT92A8B4T10@6ATI?oo
oa;gmoLIoooo000Hoooo3OOgm`0?RGMcBA`HDc`aDdA2BC`iI4a:KEiJ@000BC`i;QTH@2XY;R8QB@`8
@38aDdA2009TA3T0199VDX0R0>FcW>k4[@?geKd00nK5Q?OE_OOE_@02mmG600OgeHCgcKG^cKG^cKGg
^kG^a:gVa:d00^FcU003iJ^DiK>LiK>D00;U/i@01M^[U>F[U=^[U>FRS=^RQ002fj:<00CKVHCBXXcB
XXcBVH`2dZ:400W9TG_0R7>0P6>LKUZ0E4YgC49CA499:RT08R400Q/I60@T8R401Q/I8B@R8A8@60T8
400P8FA4>A?gmoLPoooo3OOgm`0?RHV9KFe]@D51De=CBDU9I6ATKFe]@410@D51;Rh^@410;Rh^BDU9
Fe]K@410009TI6@019:BTZf][M;Bd^CTi0?gmoL00nk^k_OgmoOgm`05moOg00G^k^kgmoO^k^kgmoO^
k^h01nGUi@03fm_K`L71iNGU00CKfm/00m;Bd]_Kfm;BdP03d];B0/30`007][JfW9bLP820MgMg@D51
@410;Rh^008K6a/492@T00HK6a/T92@B4Q800019BDUTI6@CmoOg6Oooo`006?ooo`SgmoL00oOWioOg
moOgm`02moOg00B0VH@0A49C101KC4X2DdA201=TC4Y0001930Q0<3408R508R50001CA4911010C4YC
A49UGU:004;BXXCU/icTRJG^a:g^a:GVa:D00_OE_@05i/FemmFmiX6ek/BUk/fe00;Va:d04^j0[NBc
Q>FSU>FSU>FRQ>F[U<6RS<60Q<6RS=^9Q>FRQ<6RQ<6RS=:0Q=:00=:0Q=:IS=:RS0;BP8@02l20Q<2A
Nl2A0820Lh00@X14BVA406A4>D4X8D0Z:@X000024Q0H00DB400K6AP:0000000001000P0840034Q0H
@20Q9@0H01?gmoLPoooo3OOgm`:0P8001T10@5]KFe=CDe=CDfATI451@@90@4000`000410@410@002
@D5100M0@41CDe=UIFF0P829RHW0`<3Ti>@00nk^kP;gmoL00nKVi_OgmoOgm`02k^k^0^KViP;^k^h0
1>CTi>GUiNGUiNGUi@;1`L400m_Kfl71`M_Kf`02`L7100?Kfm_Bd];Bd]801M;BdP;0`<001820P:FU
YH20P820P09TI6@00d10@2h^;PX:2P034Q8B00<:2PX000092@T010000003@4109BDUmoOg01;gmoLI
oooo000Hoooo3_Ogm`0804a2Fda:DdA2Fda:BC`iDdA2@4A2DdA20SLZ<@0;@38a0BPaBC`iFda:BC`i
Dc`aI4A204@@YH1[`95kdZ:<00;U/i`00nB0YNk=]Nk4[@03k/fe0^k4[@06k[^]k/B]k/B]`IV4fj:<
fiV40m^RS009fiV4fj:<fj:<fiV4fj:<fiV4dX00dYV4dYUc00;BVH@2`95k00_0R7>]R7>]Mf>LKUZ@
IU9TA3UC?359:RT^8R50:RT000000Q/I60<B41P300P@00<B41Q0:RU0<R405?Ogmb3oool>moOg00R0
P810@41CDe=KFe]9BDUCDe=TI6ACDe<2=cLg00=0@40g=cM9BDT00TU9B@06De=CI6ATI6ATTY:BP820
d];B0nGUi@[^k^h00nGUiM_Kfm_Kf`0:fm_K1=;BdP0=bLW9`<30`<30`<30[Jf]S8b<W9bLTY:BI6AT
De=CBDU9000092@T00<K6a/24Q8B00L92@T000000000000B4Q90@41CDe<05?OgmaWoool001Soool0
0oOgmoO_koOgm`0:moOg01[oool9001KC4YTA3UTC4YCA49CA4Y0A49C?350<S4^8R50:RT0:R5CA49K
C4YTC4Y0?3U0:RUTA4:0E4ZLKUZ]R7?0R7?9TG_BXXCK/i`2k/B]00WU^jG0P:G^^jG^a:gU/iC^a:gU
^jG1ZhC0VH@00]:IQ004fj:<dYV4dYV4dZ:40]^IQ003fiV<fiV4dYV400;BVG<2dXQk00C0TG?0R7>f
P6^]P6/2W6iJ00P0A49TA3UC?359:R4^8R4T8R4B41P921044Q0H0`0840036aTQ@2XY028Q01CgmoLP
oooo3OOgm`03ooooRHV9BDU9009TI6@2De=C00ATI6ACDe=0@40^;Rh2@41000<g=cMCDe=TI6@00T10
@09TI6@03X20P:f][L30`<W9bM;Bd]_Kfl[:b^k^k^GUiM;Bd^GUiNk^k^CTi>k^kP;UiND01=_Kfl30
`=;Bd]_Kf`CBd]83fm_K1M;BdP0?`<30bLW9`<30][Jf[Jf]W9bLP820MgMgI6ATDe=CBDU992@T6a/K
4Q8B2@T900<B4Q801`T92@000000000001/K6d10@8V9R@0DmoOg6Oooo`006?ooo`kgmoL0144R@VA<
BTTl>E]<BP9CA4800d14@TTl>E<l<@02@2XY00<00019?3U9?3T00U]<BP03I4a:@000KEiB009gGU80
2:EgJjegHl214<2ANm:RS=^[U=^cYM^SQ0;K/i`01M^[U>FkYM^[U<200:f0J`02]X1[00[9TG?9R6_B
R039R6_BVHC9TG?BR7?BR7_BVHCBVG<2bI5k0/28L`08]X1[[H1[YH1[TVIBP5A:I0`0Dc`a@2XY0RhR
8@032@P@4Q0H4Q0H00<B41P01@T840084008418@640b<@02;R8Q5?Ogmb3oool>moOg00C9bLUTI6A9
BDUKFe/3De=C00M0@41CDe=0@410@40T92AKFe]9BDT00U]KF`0:I6AT@410I6ATIFEUMgMgYJFU[Jf]
`<30fm_K`<301]_Kf`06iNGUfm_Kd];BbLW9[Jf]][Jf0/W9b@;Bd]800lW9bM;Bd/30`004d];B00o9
bLW0`<30`<30`<2f][J][JfUYJF0P81gMgMTI6ACDe=0@40^;Rh820PK6a/0118B4P@00000118B4T10
@2h^;^k^kQCgmoLIoooo000Hoooo3_Ogm`06P6iSKEiJDdA2Dc`aI4a:Dc`a0U=4@P0B@2XYDc`a@2XY
@28Q@38aI5ABDda:Fda:DdA2@4A2KEiBMfIJP6iSMfIJW6iJR@1c[H1[YH1[0Zf8L`09[H1S`95kdZ:4
bHR4dZ:<`95kQ01:W6iJTVIB00:LKUX02;J0Hh20HkJ0JlV8Jl28LlVANlV8Jl28H`;0R7<01[J0Jjf8
Lj@0HjegHi9^Hh1NDP9gC4801D04<DTZ:BhR8BhR8B@R8@024Q0H0`T840<021001A8@63LZ<D0Z:BhR
8H1NDP0DmoOg8?ooo`kgmoL01Oooo`0005=CDe=CDfATI003De=C00=0@41CDe=0@4000d10@00<De=C
Fe]KDe=CFe]KI6ATIFEUP820MgMgW9bLRHV9[Jf]YJFU1:f][@;0`<000m;Bd/30`:FUY@02W9bL00R@
T92LW9bf][Jf][K0`<2f][K9bLW0`<02bLW90l30`00:Y:BT][Jf[Jf][Jf]TY:BP820MgMgI6ATDe=C
BDU90Rh^;P0300006a/K4Q8B00<92@T3000000DB4Q8g=cM0@400003oool05?OgmaWoool001Soool>
moOg00FUP8AgIUYKC4Y9?3UKC4X00U=4@P05Fda:@3`i@2XY=bXa@2PQ009CA4801E]<BVADDVADDTU<
BU=4@P02I5AB00=]GU:0GU:BIT800XU^J`0?W6iJP6iST6i2W6iJ[HQcdZ:4[HQcYH1[TVI2TVIBP5iB
REi:P5iBW6iB[FiJ00>fP6<03lV8JkJ0HkJ0JjE^FZegHje^FZf0JjEV@Y9^Hi9VDX1DBWM<@V@l<DTZ
:D0Z:@02;R8Q0Q/I60034Q0H2@P@2@P@00@021001D0Z:B@R8BhR8D0Z:NKEaP0DmoOg8?ooo`ogmoL0
12DU9E]KFdU9BE]KF`=CDe<2@41000Dg=cM0@41CDe=CDe=KFe/00VATI006Fe]KKFe]@410I6ATKFe]
P8200Y:BTP04RHV9W9bLP820TY:B0YbLW003P820[Jf]YJFU00>BTY82P82000>LW9b][Jf][Jd00[Jf
]P05P820][Jf][Jf][JfYJFU00>][Jd01JFUYI:BTY:BTX20P6ATI002BDU900A0@40^;Rh^;RhK6a/2
4Q8B0PT92@@000001410@2@T92h^;T10@1GgmoLIoooo000Hoooo3_Ogm`03d/GFPA4Q@4a:009CA480
55]<BT0<245<@T44040R8@0R8@0P<E<<06ADDT14@VADDT14DT54@VE6FP1>@VA4DX1NDQAVFVE6DVA4
@P80C48020144014@P14@QA<@QA>DX00@QAVFPA4@P9TC4801GM<@P14@WM<00140814@P02P6IB0X1V
@P0?04i2T6IBP4A2P4A2R4i:P4A24TA2IDa2I4@0@00Y@2PQ@28Q928Q2QTH000Q008B41P00`0040T8
4008400300P@00D000008R4C22408R4100005OOgmb3oool?moOg00V0P810@41CDe=CDe=KFe]1@D50
@411@D50@4000P0000=0@40026ATI410@451@D51@@0006ATI820P1@D509UIFD6000000DD51B0P80D
51@410AUIFD00VATI0040000MgMg0@414Q8B1820P003PH6151@DT92@00B0P8000a8B4VEUIFATI003
@41000@T92@:2PX0000B4Q82000000<92@T0000000000P0000050P8200004a<C00000@4101GgmoLI
oooo000Hoooo3oOgm`03fmGWP6i[I4a:009CA4801dT<25=<BVADDU=4@T0b<D0005=4@P02KEiJ01MK
C4YgIUY0A49TC4Y]GU9gGU9gIUY]GU9UC49TA3U9?3UTC4Y9?3U0A49C?35TC4YTA3U]GU9TA3U0A49C
A490:RUC?3400TTl>@9C?3400fA4>F@l<F@l<@03I4@i1U<l<@05Dc8YBBXQ;R8Q928Q6aTQ008B41P0
0a/I61/I8A8@600400P@00HB41P^8R4K6B50<S5TA3WooolEmoOg8?ooo`ogmoL00m?Cdh20P6ATI002
De=C00AKFe]1@D5TI6ACDe<2@41000QKFe]1@D5]KFeKFe]gMgMTI6ACDe=TI6@2MgMg0Ve]K@0>MgMg
@410I6ATBDU9De=CI6ATDe=CI6ATKFe]I6ATDe=CI6ATDe=C@4100TU9B@=CDe<6I6AT1e=CD`0420P8
;Rh^92@T6a/K0Q8B4P036a/K4Q8B4Q8B00@00002;Rh^00<K6a]0@41TI6@05_OgmaWoool001Soool?
moOg00?UgNN9P8ATC4X01E=4@P06Fda:DdA2B@`8KEiJI5ABMfIJ0VeNFP0?DdA2Fda:I4A2I4A2MeiB
Mda2I4@iBC`iDdA2BC`i@38a@000BC`i@2XYI4a:009CA480140404Tl>DTl>D0Z:@90<S400d0Z:DTZ
:DTZ:@05Dc`a00]C<RU9:RUC?3508R50:RU9:RU0:RU0<S4T8R4:000T8R40118@600:000@00P@00P@
00P@2@P@;R8a928QBBXYDdA2d/CN5_Ogmb3oool?moOg00?UiNF9RHUTI6@00U=CD`09Fe]KDe=CDe=C
Fe]KDe=CBDU9Fe]KI6ATMgMg009]KFd015]KFe=CDd10@6ATI09gMgL2I6AT00M1@D59BDU0@410@41C
De=9BDU0@4000e=CD`03@410BDU9@41000A0@402BDU91U=CD`0:@D51BDU9@410@410BDU9@4100000
;Rh^6a/K92@T118B4P@000001PP822@T92h^;TU9BE=CDm;BdQKgmoLIoooo000Hoooo4?Ogm`0=`:^]
RGMcFda:Fda:D``0@3`iDda:DdA2KEiJB@`8Fda:P6iSDda:00=]GUX01fADDVeNDVA<BVA4>E]<BVA4
240b<@02DdA200E0?3U0101KC4YCA490<S400U=4@P04@30a=bXa@38a=bXa0RhR8@07@2XY;R8Q;R8Q
BBXY;R8Q@2XY@28Q00=0:RT01BhR8@0R8D0Z:BhR8D0Z:@02;R8Q00D0000T8R4B41P9210B41P01@08
408T8R400`088DTZ:JF0N`0GmoOg8?oooa3gmoL01/30`8V9RE]KFe]KFe=CDd10@09CDe<01Fe]KE]K
FdU9B@0005=CD`04KFe]0fATI005Fe]KI6ATI6AT@410De=C0090@4000e=CDe]KFd10@003De=C00=0
@40g=cL000000Rh^;P90@402;Rh^00<820Q0@410@4000d10@00>0000@410;Rh^@410;Rh^@410;Rh^
92@T6a/K92@T4Q8B2@T900002@T91000000592@T@4106a/KBDU9YJFU01OgmoLIoooo000Hoooo4?Og
m`03d/C>[J:UFda:009CA4801e=<BU]<BU=4@U=4@VeNFX1^JdTl>@02I5AB00QKC4Y0<35KC4YTC4Yg
GU9C?35KC4Y0A482DdA20TTl>@05@4A2@3`i=bXa=bXa@3`i00=0:RT2;R8Q0R@R8@8^8R401d0Z:B@R
8D0Z:BhR8B@R8BhR8D0Z:@02;R8Q00d08R4^8R4K6AP^8R4T8R4K6AP9210K6APB41P0210B41P92100
01000P0840054Q0H928Q@38a00PQW82401SgmoLPoooo4?Ogm`07d];B[Jf]Fe]KDe=CFe]KDe=CFe]K
009CDe<2KFe]00D0001TI6ATI6AKFe]9BDT00T10@004MgMgDe=CFe]KI6AT0U=CD`99BDT015=CDfAT
I410@3Lg=`E0@4000bh^;R@T92@T9003;Rh^00U0@400000^;Rh^;RhT92@^;Ri0@40^;Ri0@4000Rh^
;P046a/K;Rh^00002@T90Q/K6`054Q8B0000000000004Q8B008000001A8B4P0001/K6d10@9bLW00H
moOg6Oooo`006?oooa3gmoL01?OWilV9aXTZBT14@P9CA4803D0004Tl>E=4@T000454@VADDVeNFT0L
640D401<@TTL45=4@VA40002@30a00a000008S5110111000:RT08350100g:S4^8S50:RTT8R408R42
928Q0P008@056aT0000Q000Q928Q6aT0008T8R403000018@6000000001/I60X08@X001/I618@02@R
8A/I0000008B41P00`00400840084002000000H002408R4T8R408R40003VinLHmoOg8?oooa7gmoL0
0lW9bHV9RD10@002De=C00=0@419BDUCDe<00d10@007KFe]@410@410@D510000@D51I6AT0090@400
3451@D10@0000451@@0002h^;P000410@2HV9T10@2@T9000008T92@2000000LK6a/0000T92@0000T
92@0000T92@00P0000044Q8B00000000;Rh^0PX:2P046a/K4Q8B000000000a8B4PP000000bHV9X20
P>KViP0HmoOg6Oooo`006?ooo`03mno_moOgmoOg00ogmoL00m_=eWMVFT440002Fda:00ECC4YCA49C
A49]GUYCC4X00U=4@P05KEiJ04i:DdA2@38aDc`a0090:RT03DTl>D0Z:E=4@T0b<DTl>@0X>CLZ<BhR
8B@R8BhR<A/I8A<88B@R<@036aTQ0Q8@608T8R404A/I618@62@R8@0002@R8A/I8A8@62@R8@0001/I
618@61/I8A8@60T840004008418@600200P@00P9210B400K6B59?3T^:SU0:RUTA4;^inLImoOg8?oo
oa;gmoL01M_KfgMgMe=CDdU9BE]KF`04De=C00=1@D5CDe=CDe<00Ve]K@03P820@410De=C0090@402
BDU90T10@006BDU9;Rh^@410=cLg92@T;Rh^0Q/K6`04=cLg92@T6a/K6a/K0a8B4P8T92@03Q8B4R@T
92@T91/K6b@T91/K6`00018B4R@T91/K6a8B4Q/K6`00018B4P800000118B4P000000018B4P8K6a/0
0dU9BBh^;T10@002k^k^6OOgmaWoool001SooolCmoOg0269Mg=CA499?3UKC4Y9?3UCA49030Q0?3UC
C4Y]GUYKC4YCA49930Q0<S5CA490<S50:RT^8R488250:RTg:S50:RTg:S4:024K6B4^8S50:RTK6B4T
8R4B400K6B4^8R4K6B400Q8@60074Q004Q0H4Q0H928Q6aTQ4Q0H4Q00008K6B400b@R8@T8418@0002
4Q0H00<0210B41P021000`08400:2@P@6aTQ6aTQ00004Q0H928Q;QTHTVIBk^OWi^OW6OOgmb3ooolC
moOg00j9RHUgMgM1@D5KFe]9BDUCDe=0@41KFe]0@41]KFeKFe]CDe=9BDUKFe/3@4100Rh^;P0;BDU9
0000@410=cLg6a/K;Rh^6a/K00006a/K92@T4Q8B008K6a/01@X:2Q8B4Q8B4Q8B4Q/K6`024Q8B00<0
000B4Q8B4Q800a/K6`0300006a/K4Q8B008B4Q86000000T92@TK6a/K6a/T92@B4Q8T92@^;Rj2PX;^
k^h06_OgmaWoool001SooolCmoOg00KUgNLD05YCA49KC4YCA49KC4X3DdA201=0?3UCA49KC4Y01010
:RUCA490<S50:RTT8R4V8R4g:S4^8R4^8S4g:S40400^:ST^8R4K6B4T8R400Q/I8@8T8R434Q0H00<B
400B41PB41P00R@R8@8B41P26aTQ00LB41P^8S4K6B4B41P92100210921000P08400;4Q0H6aTQ928a
6aTQ4Q0H2P0Q928Q@2XYMda2YIV<k^OW01[gmoLPoooo4oOgm`06iNGUW9bLDe=CFe]KDe=CFe]K0e=C
D`04@410De=CFe]KDe=C1410@00;92@T;Rh^=cLg9RHV;Rh^=cLg@4106a/K;Rh^2PX:92@T00<K6a/0
1B@T9000018B4Q8B4Q/K6`034Q8B00@T92@B4Q8B4Q8B4Q826a/K00D20P8K6a/K6a/B4Q892@T01000
000:4Q8B6a/K92@T4Q8B;Rh^6a/K92@T@410MgMgY:BT6oOgmaWoool001SooolDmoOg00V9<c5]GU99
?3UKC4YCA49CC4Y]GUYCC4YKC4X00VADDP05@0@8@2XYFda:@38a;R8Q008T8R4033LZ<B@R8BhR8BhR
8@0@63LZ<A8@62@R8A/I8A8@618@018@608K6B424Q0H00LB400K6B4B41PK6B50:RTK6B4001000Q/I
8@03928Q4Q0H4Q0000@021000`T8418@02hR<@036aTQ00HT8R408R5C?35TA3VLKU[UgNLKmoOg8?oo
oaCgmoL01<W9b@T92DU9BE]KF`=CDe<01D51@E]KFfATI6ATI5=CD`03@41000D^;RhT92@T92@^;RhT
92@00Rh^;P07@4104Q8B=cLg00006a/K4Q8B6a/K008B4Q8011/K6a8B4Q8B4Q8B4P8K6a/01A8B4P00
01/K6`00018B4P026a/K00<0000K6a/B4Q80100000034Q8B6a/K;Rh^008K6a/01`000410@2h^;U=C
DfATI9bLW>GUi@0KmoOg6Oooo`006?oooaCgmoL04/2SYH1^Je]<BU=4@U]<BT4<24Tl>E=<BTU<DU=<
BU=4@T0l>B@R8E]<BT0Z:CLZ<A/I8@008@8^8R400a/I8A/I618@60026aTQ00LB41PK6B4B41PB400K
6B4B41PK6B400a8@60036aTQ4Q0H6aTQ008^:ST00`80618@61/I8@026aTQ00<0024T8R4T8S400b@R
8@0:2P0Q6aTH4Q0H6aTQ=bXa;R8Q0R0QDc`aTVIBRFi[7?Ogmb3ooolEmoOg00R0P81KFe]CDe=KFe]9
BDUCDe=1@D59BDT2De=C00U9BDU0@4000010@40g=cLK6a/T92@K6a/^;Rh00a/K6`084Q8B6a/K4Q8B
6a/K4Q8B6a/K4Q8B6a/K1A8B4P036a/K4Q8B2PX:008^;Rh24Q8B0Q/K6`0392@T6a/K92@T00<T92@0
1a/K6bh^;Q/K6a8B4Q/K6bHV9Rh^;P02De=C00>BTY:9RHWgmoL06oOgmaWoool001SooolEmoOg00C1
/lJ0KV/0E590A482@@`80T14@P9TE5801414@T0l>D14@TTl>@808R407@80018@02@R8@008A/I8@00
018@62@R8A8@01/I8@00418@018@618@018@60008A8@6000418@6000000@00X88@0P>D54@PP040X0
8BhR<@X88@000003000Q00/T8R408R492240:350:2T08R508R5C?3500020A4:0KV<07OOgmb3ooolE
moOg00K1`L60P8000010@41KFe]1@D42@4100fATI003De=C@410BDU9008000002`X:2Q8B4P000000
01/K6a8B4P00018B4P0001/K6`0000044Q8B00D0000B4Q800000000B4Q800`000003BDU9@D5120P8
008:2PX00`0000X:2P00000300000PT92@030000@41000000090@4000fATI820P820P00MmoOg6Ooo
o`006?oooaKgmoL07?oooh1^NhU^JfADDU=<BTTl>E=4@U=<BU=DHd5<BVADDU=4@U<l<D0l>D0b<B@R
8A8@61/I8B@R8A8@61/I62@R8A/I8B@R8A8@61/I8A8@01/I8@<B41P04a/I8A8@618@618@600844U<
DT0bBP0R26eNFU]NJfeNFTU4FU=4BVADDU=4BTTl>D0Z:B@R8@0R8@02@38a00E9?3UKC4YTA3UgC4;g
knl07_Ogmb3ooolFmoOg00Kooon0P829RHU]KFeTI6A1@D43De=C00A]KFeCDe=0@41CDe<2@41000D^
;RhT92@B4Q8T92@B4Q800Q/K6`0592@T00004Q8B6a/K4Q8B008K6a/24Q8B00<K6a/B4Q8B4Q800Q8B
4P070000@410@410;Rh^KFe]Fe]KBDU9009CDe<01FATI5=CDdU9B@0002@T9003@41000A9BDU0@41g
MgMgMgLOmoOg6Oooo`006?oooaSgmoL02Y:8W5=4BU=<BU]<BTTl>E=4@U]<BT1D@VeVNfeNFP99?3T0
2U<l<D0R8A/I8A/I8B@R8BhR8A/I01/I618@62@R8@<B41P04Q/I8A8@618@618@61/I8@08018@62@R
8A/I8A8@62@R<D00@TU<DT0l>B@R<A/I8B@R8D0b<@A9?3T3DdA20U<l<@03I4A2P6IBmoOg01kgmoLP
oooo6?Ogm`0:TY:BMgMgFe]KDe=CBDU9De=CFe]KI6ATFe]KKFe]0TU9B@06De=C@410@4106a/K92@T
;Rh^0a/K6`0300004Q8B4Q8B008B4Q800a/K6a8B4Q8B4P026a/K00d0000B4Q8T92@B4Q8T92A0@41C
De=9BDU0@400000T92@g=cM0@4000dU9B@03Fe]KDe=CDe=C009CDe<00d10@9:BTXV9R@0OmoOg6Ooo
o`006?oooaWgmoL01X1FDVADDVeNFU=4@U]<BVADDP9]GUX00h1^JfeNFT0b<@02@38a010g:S5CA48T
8R50?3TV8R4^8S4T8R4B41PK6B4B41PK6B4B41PK6B4B41PT8R4T8S426aTQ00PT8R4^:STK6B4^8S40
83UCA49CA4XK6B44928Q00XK6B4g:S4^8R50<350:RUC?35gC4:BIU:9E5;CaMHOmoOg8?oooa[gmoL0
1H20P6ATI5=CDe]KFfATI002KFe]00<0001]KFe0@4000d10@0044a<C92@T@410=cLg0Rh^;P030000
6a/K4Q8B008K6a/24Q8B0R@T90<K6a/01B@T90X:2Rh^;T10@2@T9002De=C00<0000T92@^;Rh00R@T
90036a/K9RHV@4100090@40015=CDgMgMh20P=_Kfb3gmoLIoooo000Hoooo6OOgm`03YJ:UP6iSFda:
009KC4X025=<BVADDX1^JhV0Q81^Ne]<BTTZ:D0b<@90:RT01d0b<DTl>DTl>BhR8BhR<B@R<D0Z:@02
6aTQ00XT8R4^8S4K6B4K6B50<TXT8R4^8S4T8R4^8S59C582;RXi00/T8S4T8R50?3U0?3T1:350?3U0
<S50:RUCA49C?350:2400VA4>@03P5A:MeiBflgF023gmoLPoooo6_Ogm`07[Jf]0000Fe]KFe]KDe=C
I6ATKFe]00:0P8000e]KFdU9BD10@003@4100dU9B@03;Rh^92@T@41000<K6a/01B@T90X:2Q/K6d10
@2@T9002;Rh^00<T92@820P^;Rh00Rh^;P8T92@00d10@3Lg=dU9B@03@41000=CDe=0@41CDe<00VAT
I003P820De=CmoOg023gmoLIoooo000Hoooo6_Ogm`06d/CNP6iSFda:BC`iDdA2BDa:0X1^J`06P7Mc
P6i[KEiJ@30a@2XY=bXa0T0Z:@0DDdA2BC`i@3`iI5AB6aTQ;R8Q4P0@;RXi;R8a;RXi=c9:@3`i02Pi
KFikFda:DeAS928aDdA2BDaBDdA:0e=4@P0;@@@0BC`iDdA2DdA2Fda:KEiBDdA2Mda2W6iJMeiBmno_
027gmoLPoooo6oOgm`06P820Fe]KBDU9De=CFe]KKFe]0h20P004KFe]@410@41000000T10@09CDe<0
1TU9BD10@1/K6bh^;Q8B4SLg=`8^;Rh02SLg=d10@410@2h^;Ve]KE]KF`0005=CDfe]KDU9B@ACDe<2
BDU90U=CD`06BDU9Fe]KDe=CMgMgW9bLMgMg8_OgmaWoool001SooolLmoOg01j1P9ABA4X0E599C4X0
A480E58000200000IW<0A480EU80ITX0A480=341001CA490A599A5Y1A491C4X0010C000:0R51A4Y0
0491A4Y9A590A599C499C4X2DdA200i0A490C4YTC49TA490A49TA0Q0C4YCC49171005004A1P0A010
002DP8@SmoOg8?oooacgmoL01H61PE9BDP0004U9BFe]K@02000000>0P8000020P800100000049BDU
De=CDe=C@4100T51@@80000011<C4`000410@451@@99BDT02D10@4U9BD51@E=CDfATI451@D10@6AT
I410@002I6AT00Q0@41CDe=1@D40001]KFd00010@42DU9@SmoOg6Oooo`006?oooaogmoL02`T2:FAD
DVeNFVADDX1^JhV0Q81VHh1^JgMVFX1^Jh1gL`02P6i[00MCE6=]GUYTE5:0KV]9GTY]KW]9A5X00T0b
BP03;RXi@30aKEiJ00=KC4X024Tl>D4l<E<l<E<l<DTl>FA4@VE<@WMNDP:0E4X00gMNDVA4>D14@P0U
moOg8?oooaogmoL01Zf][E]KFfATI6ATI820P8V9R@:0P8000`000820P820P003P82000A1@D5TI6B0
P81KFe/2KFe]0T10@004;Rh^@410BDU9KFe]0U]KF`99BDT3De=C00A0@41gMgM]KFegMgL2P8200VAT
I003d];BmoOgmoOg02?gmoLIoooo000Hoooo7oOgm`03`K?6P6ikKEiB009]GUX015]NJh08281gLhV0
Q0:0Mg<07@1VDXUgLhV0Q81gLhUgLh1gLh0006ADDX1gLfeNFU]<BU=4BT44240l>E=4@VeNFVADDU=4
@U]<BWM<@VA<BX1DBVeNDX1>@Y9^Hia^FWM<@U=4@Yb0Q00VmoOg8?ooob3gmoL01lW9b@0006e]KFe]
KE]KFh20P9:BTP03P82000EgMgN0P829RHV0P829RHT00X20P004RHV9I6AT0000Fe]K0U=CD`05BDU9
@410De=CI6ATDe=C009KFe/00gMgMfATI0000002P82000FBTY:LW9agMgL@413oool09_OgmaWoool0
01SooolRmoOg00gUgNmKGV]0?59CA49]KW^UTIB0KW^BR8b0P8B9Mg>0KV^0Mg>LP7/00XUgL`0>P6iS
W81kRGMcRGMcMfIJ06I:P6iSP5iBMfIJTVIBP5iB0FI:RFi[YGM[0ZF0J`0404a2DdA2MeiBbK_6:?Og
mb3ooolRmoOg00gUiNEKFe]0@41KFe]CDe<U9BF0P82BTY:9RHVBTY:9RHV0P82LW9`00hV9R@03P820
R8R8RHV9009gMgL3P82000<B4Q:0P81gMgL00XV9R@:UYJD01H20P6ATI5=CDgMgMlW9b@0XmoOg6Ooo
o`006?ooo`03mno_moOgmoOg027gmoL01^GMih0AQ81gS:FAU9bAYL2caP:]VI`2W81k00B9Mg=]GUZ8
07>LP8@3W81k00n9Mg>807>9KV^0KV>9KV^9Mg>UMf^4P6^0KV=gIUZ0KV=TC4X0C4;9/kgoool0:OOg
mb3ooolTmoOg00KUiNFUYJF0P820P82LW9c0`<03[Jf]00BLW9b9RHU]KFf9RHT4W9bL0XV9R@0>W9bL
RHV9P820RHV9YJFUW9bLYJFUP820MgMg0000I6ATP820bLW9oooo:OOgmaWoool001SooolXmoOg00GU
gNo^inO0P<Jf/kg0/lH00ZFAU005W824RFISP7McKFIkP7Mc00:9Mg<03800JhU^Jh1^JhU^Jh1^HhU^
J`1V@WMNDWMVFWMNDXUgLjFI]B_gmoLPoooo:?Ogm`08iNGUk^k^d];B`<30][JfP820YJFUW9bL0XV9
R@07P8200000RHV9RHV9W9bLP820RHV900:0P8000hV9RH20P7MgM`02MgMg00<10@6UYJGoool0:oOg
maWoool001Soool3mnOW9oOgm`0?i<GWi^OWmno_i^OWd/CF`K?6P824TX2DPH24PFMSPEESREESR@52
T81JR6MS00>0IV<016ADDWMVDZFAYOOWibggmoLPoooo:_Ogm`09i^KViNGUi^KVi^KVd];B`L71TY:B
YJFUTY:B00:1PH43RHV900R@T928R8R0P820P81gMgMTI6AgMgNUYJD^moOg6Oooo`006?ooocGgmoL0
0oO_koOgmoOgm`0emoOg8?ooofkgmoLIoooo000HooooKOOgmb3ooom^moOg6Oooo`00ooooobgoool0
0?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool0
0?ooool]oooo000ioooo1@000003oooo0000000000;oool200000_ooo`<00003oooo0P0000Coool4
00000_ooo`<00003oooo1000073oool300000_ooo`030000oooooooo00<00003oooo100004Ooool0
03[oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool00`000?ooooooo`03oooo00@0
003oooooool00002oooo00@0003oooooool00002oooo00<0003oooooool00oooo`040000oooooooo
0000L_ooo`040000oooooooo00000_ooo`030000oooooooo00?oool010000?ooooooo`0004Soool0
03[oool00`000?ooooooo`03oooo00@0003oooooool00002oooo00<0003oooooool00oooo`040000
oooooooo00000_ooo`040000oooooooo00000_ooo`@00002oooo00@0003oooooool0001boooo0`00
00?oool400000_ooo`040000oooooooo0000B?ooo`00>_ooo`800003oooo100000Coool300000ooo
o`800004oooo0`0000?oool200001?ooo`<0001boooo00@0003oooooool00003oooo0P0000Coool3
0000B?ooo`00>_ooo`040000oooooooo00005oooo`030000oooooooo00Woool00`000?ooooooo`1`
oooo00@0003oooooool0000;oooo00<0003oooooool0A_ooo`00>Oooo`D0000Foooo0P0000[oool2
0000LOooo`@0000;oooo0P0004Soool00?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]
oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]
oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool003Koool3
0000;?ooo`<0001;oooo0`0003[oool30000>Oooo`00>Oooo`030000oooooooo02[oool00`000?oo
ooooo`1;oooo00<0003oooooool0??ooo`030000oooooooo03Koool002[oool300001?ooo`<00003
oooo0`0000?oool200000oooo`<00004oooo0P0000[oool300000oooo`800002oooo0P000005oooo
0000oooo0000oooo00<00004oooo0P0000?oool300001?ooo`<00003oooo100000Ooool700000_oo
o`800002oooo100000Soool300000oooo`800002oooo0P000005oooo0000oooo0000oooo00<00004
oooo0P0000;oool200000_ooo`800002oooo0`0000?oool200000oooo`<0000:oooo0`000008oooo
00000000oooo0000oooo0000oooo1@0000;oool300000oooo`<00002oooo0`0002goool002_oool0
0`000?ooooooo`04oooo00D0003oooooooooool000000_ooo`030000oooooooo00Soool00`000?oo
ooooo`0=oooo00<0003oooooool00oooo`040000oooooooo00000_ooo`070000oooo0000oooo0000
oooo000000;oool010000?ooooooo`0000;oool00`000?ooooooo`03oooo00@0003oooooool00005
oooo00@0003oooooool00008oooo100000;oool010000?ooooooo`0000;oool010000?ooooooo`00
00Soool00`000?ooooooo`03oooo00@0003oooooool00002oooo00L0003oool0003oool0003oool0
00000_ooo`040000oooooooo00000_ooo`040000oooooooo00000_ooo`040000oooooooo00001Ooo
o`040000oooooooo00001Oooo`030000oooooooo00Soool02P000?ooooooooooo`000?ooo`000?oo
o`000?ooo`@00002oooo00@0003oooooool00002oooo00<0003oooooool01_ooo`030000oooooooo
02[oool002_oool00`000?ooooooo`04oooo00D0003oooooooooool000000_ooo`030000oooooooo
00Ooool300003_ooo`030000oooooooo00?oool010000?ooooooo`0000;oool01`000?ooo`000?oo
o`000?ooo`000002oooo00@0003oooooool00002oooo00<0003oooooool00`0000?oool400000_oo
o`040000oooooooo00002oooo`040000oooooooo00000_ooo`040000oooooooo00000_ooo`030000
oooooooo00Koool00`000?ooooooo`03oooo00@0003oooooool00002oooo00L0003oool0003oool0
003oool000000_ooo`040000oooooooo00000_ooo`040000oooooooo00000_ooo`030000oooooooo
00@00002oooo00<0003oooooool00oooo`<0000;oooo00T0003oooooooooool0003oool0003oool0
00001?ooo`040000oooooooo00000_ooo`030000oooooooo00@00002oooo0`0002goool002_oool2
00001?ooo`800004oooo100000Ooool010000?ooooooo`0000koool00`000?ooooooo`04oooo0P00
00;oool3000000?oool0003oool0100000Coool200000oooo`@00003oooo0P0000Coool300002Ooo
o`<000000oooo`000000000200001?ooo`<00009oooo0`0000?oool200000_ooo`<000000oooo`00
0?ooo`0400001?ooo`800002oooo100000Coool200000_ooo`D00002oooo100000Woool200000_oo
o`<000000oooo`000?ooo`02oooo0`0000?oool400000_ooo`800003oooo100002coool002_oool0
10000?ooooooo`0001?oool010000?ooooooo`0000koool010000?ooooooo`0002Woool00`000?oo
ooooo`0Eoooo00<0003oooooool0<?ooo`030000oooooooo05goool002[oool500000oooo`030000
oooooooo00koool300003oooo`<0000Xoooo0P0001Koool20000A_ooo`030000oooooooo04Woool0
0?ooool]oooo003ooooo;Oooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {299, 0}} -> {-0.109762, -0.0500106, \
0.00742317, 0.00742317}, {{14.75, 143.063}, {292.25, 163.938}} -> {-27.8826, \
-10.4207, 1.16445, 1.16445}, {{155.875, 284.188}, {292.25, 163.938}} -> \
{-192.216, -10.4207, 1.16445, 1.16445}, {{14.75, 143.063}, {151.125, \
22.8125}} -> {-28.766, -177.05, 1.17565, 1.17565}, {{155.875, 284.188}, \
{151.125, 22.8125}} -> {-192.216, -174.754, 1.16445, 1.16445}}]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "Before to move on a next section, we remove the needless variables, and \
check the used memories. In addition to the memories required to store the \
approximately recovered color image data, the decomposed color components in \
the spherical coordinate require about 1.1 mega bytes memories.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
Remove[\"colorDG\",\"colorC\",\"label\",\"colorCG\",\"composedG\"];
memoryUsed\
\>", "Input"],

Cell[BoxData[
    InterpretationBox[\(5192\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ 5192, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4.3.5 Decomposed Image compression ",
  FontFamily->"Times New Roman",
  FontSize->12]], "Subsection"],

Cell[TextData[{
  "\t",
  StyleBox[
  "This section examines a nature of wavelet image compression as well as \
recoverability to the decomposed color image components in the spherical \
coordinate. Similar to that of the red, green and blue components image data \
compression, we employ the Coifman's 6",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[", 12",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[", 18",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[", 24",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" and 30",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[
  " order base functions for the wavelet transform. A target image to be \
compressed is the image data shown in Fig. 8.\n\tThe decomposed color image \
data are rearranged to a one-dimensional form for a convenience of a \
correlation coefficient computation. After that, we compute the correlation \
coefficients and approximately recovered color image data by the following ",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" codes.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
dSampleFl=Flatten[colorD];
deCompR=Table[ZeroMatrix[dim[[2]],dim[[3]]],
\t{Length[base]},{dim[[1]]}];
corC=Table[
\twMat=waveletMatrix[dim[[2]],base[[i]]];
\twMatTrans=Transpose[wMat];
\tpSpect=Table[filter*waveletND[colorD[[j]],{wMat,wMat},2],
\t\t{j,dim[[1]]}];
\tdeCompR[[i]]=Table[waveletND[pSpect[[j]],
\t\t{wMatTrans,wMatTrans},2],{j,dim[[1]]}];
\tcorRelation[Flatten[deCompR[[i]]],dSampleFl],
\t{i,Length[base]}];\
\>", "Input"],

Cell[TextData[{
  "\t",
  StyleBox[
  "Figure 10 shows a relationship between the correlation coefficients and \
the order of base function. Similar to those of the red, green and blue \
components image data compression, employment of the higher order base \
functions yields the higher correlation coefficients.\n",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["\t",
    FormatType->InputForm],
  StyleBox[
  "Finally, we remove the needless variables and check the used memories.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
deCompG=ListPlot[corC,PlotStyle->RGBColor[0,1,0],
\tPlotRange->All,PlotJoined->True,ImageSize->{450,300},
\tPlotLabel->\"Fig.10.Decomposed recoverbility of Coifman\",
\tAxesLabel->{\"\[Times]6 order\",\"Cor.Coe.\"}];
Remove[\"corC\",\"wMat\",\"wMatTrans\",\"pSpect\"];memoryUsed\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 450 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 -863.145 868.186 [
[.2619 -0.00738 -3 -9 ]
[.2619 -0.00738 3 0 ]
[.5 -0.00738 -3 -9 ]
[.5 -0.00738 3 0 ]
[.7381 -0.00738 -3 -9 ]
[.7381 -0.00738 3 0 ]
[.97619 -0.00738 -3 -9 ]
[.97619 -0.00738 3 0 ]
[1.025 .00512 0 -6.28125 ]
[1.025 .00512 52 6.28125 ]
[.01131 .09194 -36 -4.5 ]
[.01131 .09194 0 4.5 ]
[.01131 .17876 -36 -4.5 ]
[.01131 .17876 0 4.5 ]
[.01131 .26557 -36 -4.5 ]
[.01131 .26557 0 4.5 ]
[.01131 .35239 -36 -4.5 ]
[.01131 .35239 0 4.5 ]
[.01131 .43921 -36 -4.5 ]
[.01131 .43921 0 4.5 ]
[.01131 .52603 -36 -4.5 ]
[.01131 .52603 0 4.5 ]
[.01131 .61285 -36 -4.5 ]
[.01131 .61285 0 4.5 ]
[.02381 .64303 -26 0 ]
[.02381 .64303 26 12.5625 ]
[.5 .63053 -128 0 ]
[.5 .63053 128 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .00512 m
.2619 .01137 L
s
[(2)] .2619 -0.00738 0 1 Mshowa
.5 .00512 m
.5 .01137 L
s
[(3)] .5 -0.00738 0 1 Mshowa
.7381 .00512 m
.7381 .01137 L
s
[(4)] .7381 -0.00738 0 1 Mshowa
.97619 .00512 m
.97619 .01137 L
s
[(5)] .97619 -0.00738 0 1 Mshowa
.125 Mabswid
.07143 .00512 m
.07143 .00887 L
s
.11905 .00512 m
.11905 .00887 L
s
.16667 .00512 m
.16667 .00887 L
s
.21429 .00512 m
.21429 .00887 L
s
.30952 .00512 m
.30952 .00887 L
s
.35714 .00512 m
.35714 .00887 L
s
.40476 .00512 m
.40476 .00887 L
s
.45238 .00512 m
.45238 .00887 L
s
.54762 .00512 m
.54762 .00887 L
s
.59524 .00512 m
.59524 .00887 L
s
.64286 .00512 m
.64286 .00887 L
s
.69048 .00512 m
.69048 .00887 L
s
.78571 .00512 m
.78571 .00887 L
s
.83333 .00512 m
.83333 .00887 L
s
.88095 .00512 m
.88095 .00887 L
s
.92857 .00512 m
.92857 .00887 L
s
.25 Mabswid
0 .00512 m
1 .00512 L
s
gsave
1.025 .00512 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
81.000 12.813 moveto
(order) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .09194 m
.03006 .09194 L
s
[(0.9943)] .01131 .09194 1 0 Mshowa
.02381 .17876 m
.03006 .17876 L
s
[(0.9944)] .01131 .17876 1 0 Mshowa
.02381 .26557 m
.03006 .26557 L
s
[(0.9945)] .01131 .26557 1 0 Mshowa
.02381 .35239 m
.03006 .35239 L
s
[(0.9946)] .01131 .35239 1 0 Mshowa
.02381 .43921 m
.03006 .43921 L
s
[(0.9947)] .01131 .43921 1 0 Mshowa
.02381 .52603 m
.03006 .52603 L
s
[(0.9948)] .01131 .52603 1 0 Mshowa
.02381 .61285 m
.03006 .61285 L
s
[(0.9949)] .01131 .61285 1 0 Mshowa
.125 Mabswid
.02381 .02248 m
.02756 .02248 L
s
.02381 .03985 m
.02756 .03985 L
s
.02381 .05721 m
.02756 .05721 L
s
.02381 .07457 m
.02756 .07457 L
s
.02381 .1093 m
.02756 .1093 L
s
.02381 .12666 m
.02756 .12666 L
s
.02381 .14403 m
.02756 .14403 L
s
.02381 .16139 m
.02756 .16139 L
s
.02381 .19612 m
.02756 .19612 L
s
.02381 .21348 m
.02756 .21348 L
s
.02381 .23085 m
.02756 .23085 L
s
.02381 .24821 m
.02756 .24821 L
s
.02381 .28294 m
.02756 .28294 L
s
.02381 .3003 m
.02756 .3003 L
s
.02381 .31767 m
.02756 .31767 L
s
.02381 .33503 m
.02756 .33503 L
s
.02381 .36976 m
.02756 .36976 L
s
.02381 .38712 m
.02756 .38712 L
s
.02381 .40448 m
.02756 .40448 L
s
.02381 .42185 m
.02756 .42185 L
s
.02381 .45657 m
.02756 .45657 L
s
.02381 .47394 m
.02756 .47394 L
s
.02381 .4913 m
.02756 .4913 L
s
.02381 .50867 m
.02756 .50867 L
s
.02381 .54339 m
.02756 .54339 L
s
.02381 .56076 m
.02756 .56076 L
s
.02381 .57812 m
.02756 .57812 L
s
.02381 .59548 m
.02756 .59548 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cor) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coe) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -189 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.813 moveto
(.10) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Decomposed) show
171.000 12.813 moveto
(recoverbility) show
255.000 12.813 moveto
(of) show
273.000 12.813 moveto
(Coifman) show
315.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 0 r
.5 Mabswid
.02381 .01472 m
.2619 .43085 L
.5 .52214 L
.7381 .59862 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{450, 300},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000720001;1P00`40o`000?l0003ooooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00Noooo`@0001B
oooo0P0005?oool30000DOooo`800016oooo001koooo00<0003oooooool0D_ooo`040000oooooooo
0000Doooo`030000oooooooo04ooool010000?ooooooo`0004Goool007coool00`000?ooooooo`1C
oooo00<0003oooooool0Coooo`D0001Coooo00<0003oooooool0@oooo`00OOooo`030000oooooooo
05?oool00`000?ooooooo`1>oooo00@0003oooooool0001Boooo0P0004Koool007_oool010000?oo
ooooo`00057oool010000?ooooooo`00057oool00`000?ooo`00001Boooo00<0003oooooool0AOoo
o`00O?ooo`80001Coooo0P0005?oool20000D_ooo`<00015oooo003ooooo`oooo`00oooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool002Soool00`000?ooooooo`3oooooI_ooo`060000
oooooooooooo0000oooo0`0000[oool200000oooo`@00003oooo100000;oool300000_ooo`@00004
oooo000Xoooo00<0003oooooool0ooooofOoool00`000?ooo`000002oooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool00_ooo`040000oooooooo00000_ooo`030000
oooooooo00Coool00`000?ooooooo`04oooo000Oooooo`0006L0000=oooo00D0003oooooooooool0
00000_ooo`030000oooooooo00Koool010000?ooooooo`0000?oool00`000?ooooooo`02oooo00@0
003oooooool00002oooo100000?oool00`000?ooooooo`04oooo000Xoooo00<0003oooooool03_oo
o`030000oooooooo00koool00`000?ooooooo`0>oooo00<0003oooooool03_ooo`030000oooooooo
00koool00`000?ooooooo`0>oooo00<0003oooooool03_ooo`030000oooooooo00koool00`000?oo
ooooo`0>oooo00<0003oooooool03_ooo`030000oooooooo00goool00`000?ooooooo`0>oooo00<0
003oooooool03_ooo`030000oooooooo00koool00`000?ooooooo`0>oooo00<0003oooooool03_oo
o`030000oooooooo00koool00`000?ooooooo`0>oooo00<0003oooooool03_ooo`030000oooooooo
00koool00`000?ooooooo`0Coooo00<0003oool000000_ooo`<0000:oooo0P0000?oool400000ooo
o`<00003oooo0P0000?oool400001?ooo`00:?ooo`030000oooooooo05;oool00`000?ooooooo`1B
oooo00<0003oooooool0DOooo`030000oooooooo05;oool00`000?ooooooo`0Boooo00D0003ooooo
ooooool000000_ooo`030000oooooooo01Ooool00`000?ooooooo`0>oooo000Xoooo00<0o`3ooooo
ool0ooooofgoool300005_ooo`80000@oooo000Xoooo00<00000o`3oool0oooooiSoool002Soool0
0`00003o0?ooo`3oooooV?ooo`00:?ooo`8000000`3o0?ooooooo`3oooooU_ooo`00:?ooo`030000
oooo0?l00?oooonHoooo000Xoooo00@0003oooooool0o`3oooooUoooo`00:?ooo`040000oooooooo
0?l0oooooiOoool002Soool01@000?ooooooooooo`3o003oooooU_ooo`00:?ooo`030000oooooooo
00;oool00`3o0?ooooooo`3oooooToooo`00:?ooo`800003oooo00<0o`3oooooool0oooooi?oool0
02Soool00`000?ooooooo`03oooo00<0o`3oooooool0oooooi;oool002Soool00`000?ooooooo`03
oooo00<0o`3oooooool0oooooi;oool002Soool00`000?ooooooo`04oooo00<0o`3oooooool0oooo
oi7oool002Soool00`000?ooooooo`04oooo00<0o`3oooooool0oooooi7oool002Soool00`000?oo
ooooo`05oooo00<0o`3oooooool0oooooi3oool002Soool200001oooo`030?l0oooooooo0?oooon?
oooo000Xoooo00<0003oooooool01_ooo`030?l0oooooooo0?oooon?oooo000Xoooo00<0003ooooo
ool01oooo`030?l0oooooooo0?oooon>oooo000Xoooo00<0003oooooool01oooo`030?l0oooooooo
0?oooon>oooo000Xoooo00<0003oooooool02?ooo`030?l0oooooooo0?oooon=oooo000Xoooo00<0
003oooooool02?ooo`030?l0oooooooo0?oooon=oooo000Xoooo00<0003oooooool02Oooo`030?l0
oooooooo0?oooon<oooo000Xoooo0P0000_oool00`3o0?ooooooo`3oooooRoooo`00:?ooo`030000
oooooooo00[oool00`3o0?ooooooo`3oooooRoooo`00:?ooo`030000oooooooo00_oool00`3o0?oo
ooooo`3oooooR_ooo`00:?ooo`030000oooooooo00_oool00`3o0?ooooooo`3oooooR_ooo`000_oo
o`800004oooo0P0000?oool300000oooo`<00005oooo0`0000;oool200001_ooo`030000oooooooo
00coool00`3o0?ooooooo`3oooooROooo`0000Goool0003oooooool000002_ooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00@0003oooooool00002oooo00<0003oooooool00oooo`030000
oooooooo00goool00`3o0?ooooooo`3oooooR?ooo`0000Goool0003oooooool000002Oooo`<00003
oooo0`0000;oool500000oooo`030000oooooooo00Coool300003Oooo`030?l0oooooooo0?oooon8
oooo00001Oooo`000?ooooooo`000008oooo00@0003oooooool00002oooo00@0003oooooool00002
oooo00@0003oooooool00005oooo00<0003oooooool00oooo`030000oooooooo00koool00`3o0?oo
ooooo`3oooooQoooo`0000Goool0003oooooool000002?ooo`040000oooooooo00000_ooo`040000
oooooooo00000oooo`030000oooo000000;oool010000?ooooooo`0000Goool00`000?ooooooo`0>
oooo00<0o`3oooooool0ooooohOoool000;oool200002_ooo`<00003oooo0`0000Coool200000ooo
o`800006oooo00<0003oooooool03oooo`030?l0oooooooo0?oooon6oooo000Xoooo00<0003ooooo
ool03oooo`030?l0oooooooo0?oooon6oooo000Xoooo00<0003oooooool04?ooo`030?l0oooooooo
0?oooon5oooo000Xoooo0P0001;oool00`3o0?ooooooo`3oooooQ?ooo`00:?ooo`030000oooooooo
017oool00`3o0?ooooooo`3oooooQ?ooo`00:?ooo`030000oooooooo01;oool00`3o0?ooooooo`3o
ooooPoooo`00:?ooo`030000oooooooo01;oool00`3o0?ooooooo`3oooooPoooo`00:?ooo`030000
oooooooo01?oool00`3o0?ooooooo`3oooooP_ooo`00:?ooo`030000oooooooo01?oool00`3o0?oo
ooooo`3oooooP_ooo`00:?ooo`80000Eoooo00<0o`3oooooool0oooooh7oool002Soool00`000?oo
ooooo`0Eoooo00<0o`3oooooool0oooooh3oool002Soool00`000?ooooooo`0Eoooo00<0o`3ooooo
ool0oooooh3oool002Soool00`000?ooooooo`0Foooo00<0o`3oooooool0ooooogooool002Soool0
0`000?ooooooo`0Foooo00<0o`3oooooool0ooooogooool002Soool00`000?ooooooo`0Goooo00<0
o`3oooooool0ooooogkoool002Soool200006?ooo`030?l0oooooooo0?oooomnoooo000Xoooo00<0
003oooooool06?ooo`030?l0oooooooo0?oooommoooo000Xoooo00<0003oooooool06Oooo`030?l0
oooooooo0?oooomloooo000Xoooo00<0003oooooool06Oooo`030?l0oooooooo0?oooomloooo000X
oooo00<0003oooooool06_ooo`030?l0oooooooo0?oooomkoooo000Xoooo00<0003oooooool06_oo
o`030?l0oooooooo0?oooomkoooo000Xoooo00<0003oooooool06oooo`030?l0oooooooo0?oooomj
oooo000Xoooo0P0001coool00`3o0?ooooooo`3oooooN_ooo`00:?ooo`030000oooooooo01coool0
0`3o0?ooooooo`3oooooNOooo`00:?ooo`030000oooooooo01goool00`3o0?ooooooo`3oooooN?oo
o`00:?ooo`030000oooooooo01goool00`3o0?ooooooo`3oooooN?ooo`000_ooo`800004oooo0P00
00?oool300000oooo`<00005oooo0`0000?oool300001?ooo`030000oooooooo01koool00`3o0?oo
ooooo`3oooooMoooo`0000Goool0003oooooool000002_ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`0Noooo00<0
o`3oooooool0ooooogOoool00005oooo0000oooooooo000000Woool300000oooo`<00002oooo1@00
0003oooo0000000000<00004oooo0`0001ooool00`3o0?ooooooo`3oooooM_ooo`0000Goool0003o
ooooool000002?ooo`040000oooooooo00000_ooo`040000oooooooo00000_ooo`040000oooooooo
00000_ooo`040000oooooooo00001Oooo`030000oooooooo01ooool00`3o0?ooooooo`3oooooM_oo
o`0000Goool0003oooooool000002?ooo`040000oooooooo00000_ooo`040000oooooooo00000ooo
o`030000oooo000000?oool00`000?ooo`000005oooo00<0003oooooool08?ooo`030?l0oooooooo
0?oooomeoooo0002oooo0P0000[oool300000oooo`<00004oooo0P0000Coool200001Oooo`030000
oooooooo027oool00`3o0?ooooooo`3oooooM?ooo`00:?ooo`030000oooooooo027oool00`3o0?oo
ooooo`3oooooM?ooo`00:?ooo`030000oooooooo02;oool00`3o0?ooooooo`3oooooLoooo`00:?oo
o`80000Soooo00<0o`3oooooool0ooooog?oool002Soool00`000?ooooooo`0Soooo00<0o`3ooooo
ool0ooooog;oool002Soool00`000?ooooooo`0Soooo00<0o`3oooooool0ooooog;oool002Soool0
0`000?ooooooo`0Toooo00<0o`3oooooool0ooooog7oool002Soool00`000?ooooooo`0Uoooo00<0
o`3oooooool0ooooog3oool002Soool00`000?ooooooo`0Uoooo00<0o`3oooooool0ooooog3oool0
02Soool200009oooo`030?l0oooooooo0?oooom_oooo000Xoooo00<0003oooooool09_ooo`030?l0
oooooooo0?oooom_oooo000Xoooo00<0003oooooool09oooo`030?l0oooooooo0?oooom^oooo000X
oooo00<0003oooooool0:?ooo`030?l0oooooooo0?oooom]oooo000Xoooo00<0003oooooool0:?oo
o`030?l0oooooooo0?oooom]oooo000Xoooo00<0003oooooool0:Oooo`030?l0oooooooo0?oooom/
oooo000Xoooo0P0002[oool00`3o0?ooooooo`3oooooK?ooo`00:?ooo`030000oooooooo02[oool0
0`3o0?ooooooo`3oooooJoooo`00:?ooo`030000oooooooo02[oool00`3o0?ooooooo`3oooooJooo
o`00:?ooo`030000oooooooo02_oool00`3o0?ooooooo`3oooooJ_ooo`00:?ooo`030000oooooooo
02coool00`3o0?ooooooo`3oooooJOooo`00:?ooo`030000oooooooo02coool00`3o0?ooooooo`3o
ooooJOooo`00:?ooo`80000^oooo00<0o`3oooooool0ooooofSoool002Soool00`000?ooooooo`0]
oooo00<0o`3oooooool0ooooofSoool002Soool00`000?ooooooo`0^oooo00<0o`3oooooool0oooo
ofOoool002Soool00`000?ooooooo`0^oooo00<0o`3oooooool0ooooofOoool002Soool00`000?oo
ooooo`0_oooo00<0o`3oooooool0ooooofKoool000;oool200001?ooo`800003oooo0`0000?oool3
00001Oooo`<00002oooo0P0000Koool00`000?ooooooo`0`oooo00<0o`3oooooool0ooooofGoool0
0005oooo0000oooooooo000000[oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`040000
oooooooo00000_ooo`030000oooooooo00?oool00`000?ooooooo`0`oooo00<0o`3oooooool0oooo
ofGoool00005oooo0000oooooooo000000Woool300000oooo`<00002oooo1@0000Coool00`000?oo
ooooo`03oooo0`00037oool00`3o0?ooooooo`3oooooI?ooo`0000Goool0003oooooool000002?oo
o`040000oooooooo00000_ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`800006
oooo00<0003oooooool0<Oooo`030?l0oooooooo0?oooomToooo00001Oooo`000?ooooooo`000008
oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003oool000000oooo`030000
oooooooo00Goool00`000?ooooooo`0boooo00<0o`3oooooool0ooooof?oool000;oool200002_oo
o`<00003oooo0`0000Coool200000oooo`<00005oooo00<0003oooooool0<_ooo`030?l0oooooooo
0?oooomSoooo000Xoooo00<0003oooooool0<oooo`030?l0oooooooo0?oooomRoooo000Xoooo00<0
003oooooool0=?ooo`030?l0oooooooo0?oooomQoooo000Xoooo0P0003Goool00`3o0?ooooooo`3o
ooooHOooo`00:?ooo`030000oooooooo03Goool00`3o0?ooooooo`3oooooH?ooo`00:?ooo`030000
oooooooo03Goool00`3o0?ooooooo`3oooooH?ooo`00:?ooo`030000oooooooo03Koool00`3o0?oo
ooooo`3oooooGoooo`00:?ooo`030000oooooooo03Koool00`3o0?ooooooo`3oooooGoooo`00:?oo
o`030000oooooooo03Ooool00`3o0?ooooooo`3oooooG_ooo`00:?ooo`80000ioooo00<0o`3ooooo
ool0oooooegoool002Soool00`000?ooooooo`0hoooo00<0o`3oooooool0oooooegoool002Soool0
0`000?ooooooo`0ioooo00<0o`3oooooool0oooooecoool002Soool00`000?ooooooo`0ioooo00<0
o`3oooooool0oooooecoool002Soool00`000?ooooooo`0joooo00<0o`3oooooool0oooooe_oool0
02Soool00`000?ooooooo`0joooo00<0o`3oooooool0oooooe_oool002Soool20000??ooo`030?l0
oooooooo0?oooomJoooo000Xoooo00<0003oooooool0??ooo`030?l0oooooooo0?oooomIoooo000X
oooo00<0003oooooool0??ooo`030?l0oooooooo0?oooomIoooo000Xoooo00<0003oooooool0?Ooo
o`030?l0oooooooo0?oooomHoooo000Xoooo00<0003oooooool0?Oooo`030?l0oooooooo0?oooomH
oooo000Xoooo00<0003oooooool0?_ooo`030?l0oooooooo0?oooomGoooo000Xoooo0P0003ooool0
0`3o0?ooooooo`3oooooEoooo`00:?ooo`030000oooooooo03ooool00`3o0?ooooooo`3oooooE_oo
o`00:?ooo`030000oooooooo043oool00`3o0?ooooooo`3oooooEOooo`00:?ooo`030000oooooooo
043oool00`3o0?ooooooo`3oooooEOooo`00:?ooo`030000oooooooo047oool00`3o0?ooooooo`3o
ooooE?ooo`000_ooo`800004oooo0P0000?oool300000oooo`<00005oooo0`000004oooo00000000
00001_ooo`030000oooooooo047oool00`3o0?ooooooo`3oooooE?ooo`0000Goool0003oooooool0
00002_ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00@0003oooooool00002oooo00<0
003oooooool00oooo`030000oooooooo04;oool00`3o0?ooooooo`3oooooDoooo`0000Goool0003o
ooooool000002Oooo`<00003oooo0`0000;oool5000000Goool0003oooooool000001Oooo`<00012
oooo00<0o`3oooooool0oooooe?oool00005oooo0000oooooooo000000Soool010000?ooooooo`00
00;oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool300001_ooo`030000oooooooo
04?oool00`3o0?ooooooo`3oooooD_ooo`0000Goool0003oooooool000002?ooo`040000oooooooo
00000_ooo`040000oooooooo00000oooo`030000oooo000000?oool00`000?ooooooo`05oooo00<0
003oooooool0A?ooo`030?l0oooooooo0?oooomAoooo0002oooo0P0000[oool300000oooo`<00004
oooo0P0000?oool300001Oooo`030000oooooooo04Coool00`3o0?ooooooo`3oooooDOooo`00:?oo
o`030000oooooooo04Goool00`3o0?ooooooo`3oooooD?ooo`00:?ooo`030000oooooooo04Goool0
0`3o0?ooooooo`3oooooD?ooo`00:?ooo`800017oooo00<0o`3oooooool0ooooodooool002Soool0
0`000?ooooooo`17oooo00<0o`3oooooool0ooooodkoool002Soool00`000?ooooooo`17oooo00<0
o`3oooooool0ooooodkoool002Soool00`000?ooooooo`18oooo00<0o`3oooooool0ooooodgoool0
02Soool00`000?ooooooo`18oooo00<0o`3oooooool0ooooodgoool002Soool00`000?ooooooo`19
oooo00<0o`3oooooool0ooooodcoool002Soool20000B_ooo`030?l0oooooooo0?oooom<oooo000X
oooo00<0003oooooool0B_ooo`030?l0oooooooo0?oooom;oooo000Xoooo00<0003oooooool0Booo
o`030?l0oooooooo0?oooom:oooo000Xoooo00<0003oooooool0Boooo`030?l0oooooooo0?oooom:
oooo000Xoooo00<0003oooooool0C?ooo`030?l0oooooooo0?oooom9oooo000Xoooo00<0003ooooo
ool0C?ooo`030?l0oooooooo0?oooom9oooo000Xoooo0P0004koool00`3o0?ooooooo`3oooooB?oo
o`00:?ooo`030000oooooooo04goool00`3o0?ooooooo`3oooooB?ooo`00:?ooo`030000oooooooo
04koool00`3o0?ooooooo`3oooooAoooo`00:?ooo`030000oooooooo04ooool00`3o0?ooooooo`3o
ooooA_ooo`00:?ooo`030000oooooooo04ooool00`3o0?ooooooo`3oooooA_ooo`00:?ooo`030000
oooooooo053oool00`3o0?ooooooo`3oooooAOooo`00:?ooo`80001Aoooo00<0o`3oooooool0oooo
odGoool002Soool00`000?ooooooo`1Aoooo00<0o`3oooooool0ooooodCoool002Soool00`000?oo
ooooo`1Aoooo00<0o`3oooooool0ooooodCoool002Soool00`000?ooooooo`1Boooo0P3o0?oooom4
oooo0002oooo0P0000Coool200000oooo`<00003oooo0`0000Goool300000oooo`030000oooooooo
00Coool00`000?ooooooo`1Doooo0P3o0?oooom2oooo00001Oooo`000?ooooooo`00000:oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`030000oooooooo05Koool30?l0ooooocooool00005oooo0000oooooooo000000Woool300000ooo
o`<00002oooo1@0000?oool00`000?ooooooo`04oooo0`0005Woool30?l0oooooccoool00005oooo
0000oooooooo000000Soool010000?ooooooo`0000;oool010000?ooooooo`0000;oool010000?oo
ooooo`0000Goool00`000?ooooooo`03oooo00<0003oooooool0G?ooo`80o`3ooooo>_ooo`0000Go
ool0003oooooool000002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000
oooo000000;oool010000?ooooooo`0000Goool00`000?ooooooo`1Noooo0`3o0?oooolgoooo0002
oooo0P0000[oool300000oooo`<00004oooo0P0000;oool400001Oooo`030000oooooooo067oool2
0?l0ooooocGoool002Soool00`000?ooooooo`1Soooo0`3o0?oooolboooo000Xoooo00<0003ooooo
ool0I_ooo`80o`3ooooo<?ooo`00:?ooo`030000oooooooo06Soool30?l0ooooobgoool002Soool2
0000K?ooo`<0o`3ooooo:_ooo`00:?ooo`030000oooooooo06koool20?l0ooooobSoool002Soool0
0`000?ooooooo`1`oooo0`3o0?oooolUoooo000Xoooo00<0003oooooool0Loooo`80o`3ooooo8ooo
o`00:?ooo`030000oooooooo07Goool30?l0ooooob3oool002Soool00`000?ooooooo`1hoooo0P3o
0?oooolNoooo000Xoooo0P0007_oool30?l0oooooa_oool002Soool00`000?ooooooo`1moooo0`3o
0?oooolHoooo000Xoooo00<0003oooooool0P?ooo`80o`3ooooo5_ooo`00:?ooo`030000oooooooo
08;oool30?l0oooooa?oool002Soool00`000?ooooooo`25oooo0P3o0?oooolAoooo000Xoooo00<0
003oooooool0Qoooo`<0o`3ooooo3_ooo`00:?ooo`80002;oooo0P3o0?ooool<oooo000Xoooo00<0
003oooooool0S?ooo`<0o`3ooooo2Oooo`00:?ooo`030000oooooooo08ooool30?l0ooooo`Koool0
02Soool00`000?ooooooo`2Boooo0P3o0?ooool4oooo000Xoooo00<0003oooooool0U?ooo`<0o`3o
oooo0Oooo`00:?ooo`030000oooooooo09Ooool20?l0o_ooo`00:?ooo`80002Joooo0`3o0?_oool0
02Soool00`000?ooooooo`2Loooo0P3o0?Woool002Soool00`000?ooooooo`2Noooo0`3o0?Koool0
02Soool00`000?ooooooo`2Qoooo0`3o0??oool000;oool200001?ooo`800003oooo0`0000?oool3
00001Oooo`<00002oooo0P0000Koool00`000?ooooooo`2Toooo0P3o0?7oool00005oooo0000oooo
oooo000000[oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`040000oooooooo00000_oo
o`030000oooooooo00?oool00`000?ooooooo`2Voooo0`3o0>koool00005oooo0000oooooooo0000
00Woool300000oooo`<00002oooo1@000005oooo0000oooooooo000000Goool30000ZOooo`<0o`3[
oooo00001Oooo`000?ooooooo`000008oooo00@0003oooooool00002oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo0P0000Koool00`000?ooooooo`2/oooo0`3o0>Soool00005oooo
0000oooooooo000000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?oo
o`000002oooo00@0003oooooool00005oooo00<0003oooooool0[oooo`<0o`3Uoooo0002oooo0P00
00[oool300000oooo`<00004oooo0P0000?oool200001_ooo`030000oooooooo0;;oool30?l0h_oo
o`00:?ooo`030000oooooooo0;Goool40?l0g_ooo`00:?ooo`030000oooooooo0;Woool30?l0fooo
o`00:?ooo`030000oooooooo0;coool30?l0f?ooo`00:?ooo`800030oooo0`3o0=Goool002Soool0
0`000?ooooooo`32oooo0`3o0=;oool002Soool00`000?ooooooo`35oooo0`3o0<ooool002Soool0
0`000?ooooooo`38oooo0`3o0<coool002Soool00`000?ooooooo`3;oooo0`3o0<Woool002Soool0
0`000?ooooooo`3>oooo0`3o0<Koool002Soool20000d_ooo`@0o`32oooo000Xoooo00<0003ooooo
ool0eOooo`<0o`2ooooo000Xoooo00<0003oooooool0f?ooo`<0o`2loooo000Xoooo00<0003ooooo
ool0foooo`<0o`2ioooo000Xoooo00<0003oooooool0g_ooo`<0o`2foooo000Xoooo00<0003ooooo
ool0hOooo`<0o`2coooo000Xoooo0P000>Goool30?l0/?ooo`00:?ooo`030000oooooooo0>Ooool3
0?l0[Oooo`00:?ooo`030000oooooooo0>[oool30?l0Z_ooo`00:?ooo`030000oooooooo0>goool4
0?l0Y_ooo`00:?ooo`030000oooooooo0?7oool30?l0Xoooo`00:?ooo`030000oooooooo0?Coool3
0?l0X?ooo`00:?ooo`80003hoooo0`3o09goool002Soool00`000?ooooooo`3joooo5`3o08Koool0
02Soool00`000?ooooooo`3ooooo4_ooobX0o`1Loooo000Xoooo00<0003oooooool0oooooccooolF
0?l0A_ooo`000_ooo`800004oooo0P0000?oool300000oooo`<00005oooo0`000004oooo00000000
00001_ooo`030000oooooooo0?oooonHoooo00001Oooo`000?ooooooo`00000:oooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`02oooo00<0003oooooool01?ooo`030000
oooooooo0?oooonHoooo00001Oooo`000?ooooooo`000009oooo0`0000?oool300000_ooo`D00002
oooo0`0000Goool30000oooooiSoool00005oooo0000oooooooo000000Soool010000?ooooooo`00
00;oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`0000Goool0
0`000?ooooooo`3oooooV?ooo`0000Goool0003oooooool000002?ooo`040000oooooooo00000_oo
o`040000oooooooo00000oooo`030000oooo000000;oool010000?ooooooo`0000Goool00`000?oo
ooooo`3oooooV?ooo`000_ooo`80000:oooo0`0000?oool300001?ooo`800003oooo0`000?oooonP
oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0067oool3
0000>?ooo`<0001Zoooo0P000;Ooool006Coool00`000?ooooooo`0foooo00<0003oooooool0J_oo
o`030000oooooooo0;Goool005Goool300001?ooo`<00003oooo0`0000?oool200000oooo`D00002
oooo0P0000Coool200000_ooo`@00004oooo0`0000?oool300000oooo`800002oooo0P000005oooo
0000oooo0000oooo00<00004oooo0P0000?oool300001?ooo`<00003oooo100000Ooool400000ooo
o`<00003oooo0`0000?oool200001?ooo`800004oooo0`0000;oool4000000?oool0000000000P00
00Coool300000_ooo`<00004oooo0`0000?oool200001Oooo`030000oooooooo00Soool200000ooo
o`@00009oooo0`0000?oool200001?ooo`<00002oooo10000008oooo00000000oooo0000oooo0000
oooo1`0000;oool20000L_ooo`00E_ooo`030000oooooooo00Coool01@000?ooooooooooo`000002
oooo00<0003oooooool02?ooo`050000oooooooooooo000000;oool00`000?ooooooo`06oooo00@0
003oooooool00002oooo00<0003oooooool00oooo`030000oooooooo00?oool010000?ooooooo`00
00;oool01`000?ooo`000?ooo`000?ooo`000002oooo00@0003oooooool00002oooo00<0003ooooo
ool00oooo`040000oooooooo00001Oooo`040000oooooooo00002Oooo`030000oooooooo00;oool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`040000oooooooo00000oooo`800003oooo00<0
003oooooool01?ooo`030000oooooooo00;oool010000?ooooooo`0000Coool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`050000oooooooooooo000000;oool01`000?ooooooooooo`000?oo
o`000008oooo00@0003oooooool00003oooo00<0003oooooool02?ooo`030000oooooooo00?oool0
10000?ooooooo`0000Coool00`000?ooooooo`02oooo00<0003oooooool00_ooo`060000oooo0000
oooo0000oooo100000;oool010000?ooooooo`0007?oool005Koool00`000?ooooooo`04oooo00D0
003oooooooooool000000_ooo`030000oooooooo00Soool01@000?ooooooooooo`000002oooo00<0
003oooooool01_ooo`040000oooooooo00000_ooo`@00002oooo00<0003oooooool00oooo`040000
oooooooo00000_ooo`070000oooo0000oooo0000oooo000000;oool010000?ooooooo`0000;oool0
0`000?ooooooo`0300000oooo`@00002oooo00@0003oooooool00009oooo00<0003oooooool00_oo
o`@00002oooo00<0003oooooool00oooo`040000oooooooo00000_ooo`040000oooooooo00000_oo
o`@00003oooo00<0003oooooool00_ooo`040000oooooooo00001?ooo`030000oooooooo00;oool0
0`000?ooooooo`04oooo00D0003oooooooooool000001Oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo00Soool00`000?ooooooo`03oooo00@0003oooooool00004
oooo00<0003oooooool00_ooo`030000oooooooo00;oool01@000?ooo`000?ooo`000004oooo00@0
003oooooool00002oooo00<0003oooooool0LOooo`00E_ooo`800004oooo0P0000Coool400002Ooo
o`050000oooooooooooo000000;oool00`000?ooooooo`06oooo00@0003oooooool00003oooo0P00
00Coool300000oooo`800002oooo0`000003oooo0000oooo00@00004oooo0P0000?oool400000ooo
o`800004oooo0`0000Soool400000oooo`800004oooo0`0000?oool200000_ooo`800002oooo0P00
00;oool200000oooo`@00002oooo0`0000Coool200001?ooo`030000oooooooo00?oool200000_oo
o`D000001Oooo`00000000000?ooo`0200002?ooo`800003oooo100000Soool00`000?ooooooo`04
oooo0P0000Coool200000oooo`@000001_ooo`00000000000?ooo`0000?oool3000000?oool00000
00000P0007Coool005Koool010000?ooooooo`0001Goool01@000?ooooooooooo`000002oooo00<0
003oooooool01_ooo`040000oooooooo0000=Oooo`030000oooooooo033oool00`000?ooooooo`0:
oooo00<0003oooooool02?ooo`030000oooooooo01Koool00`000?ooooooo`08oooo00@0003ooooo
ool0000?oooo00<0003oooooool0QOooo`004_ooo`<00003oooo0P0000?oool400000oooo`800004
oooo0`0000?oool200001?ooo`<00003oooo0P0001Ooool500000oooo`030000oooooooo00koool2
00001?ooo`800008oooo100003Goool20000<Oooo`800007oooo00@0003oooooooooool200001_oo
o`030000oooooooo01_oool200002Oooo`<0000:oooo00<0003oooooool00oooo`800025oooo000A
oooo00<0003oooooool00oooo`040000oooooooo00000oooo`030000oooooooo00Soool00`000?oo
ooooo`03oooo00@0003oooooool00002oooo00<0003oooooool0oooooh_oool0017oool00`000?oo
ooooo`03oooo00@0003oooooool00003oooo00<0003oooooool02?ooo`030000oooooooo00?oool0
10000?ooooooo`0000;oool40000oooooh[oool0017oool00`000?ooooooo`04oooo0P0000?oool4
00002?ooo`030000oooooooo00Coool200001?ooo`80003oooooRoooo`004Oooo`040000oooooooo
00005?ooo`040000oooooooo0000oooooiKoool001;oool300005Oooo`<0003oooooU_ooo`00oooo
ol?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooo
ol?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooo
ol?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooo
ol?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooo
ol?oool00001\
\>"],
  ImageRangeCache->{{{0, 449}, {299, 0}} -> {0.522908, 0.994082, 0.0117938, \
3.23437*^-06}}],

Cell[BoxData[
    InterpretationBox[\(7160\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ 7160, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "Figure 11 shows a comparison between the RGB image and the decomposed \
image data. The red and green lines are corresponding to the RGB and \
decomposed image data, respectively. From a result shown in Fig. 11, it is \
clarified that the color image data compression by the wavelet transform \
greatly depends on the data arrangement. \n\tThus, it is preferable to use \
the decomposed image data in the spherical coordinate in order to attain a \
high compression rate by the discrete orthogonal wavelet transform.\n",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["\t",
    FormatType->InputForm],
  StyleBox[
  "Before to move on the next section, we remove the variables used for the \
correlation coefficients, and check the used memories.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
Show[rgbG,deCompG,
\tPlotLabel->\"Fig.11.Comparison RGB(red) and decoded(green)\",
\tAxesLabel->{\"\[Times]6 order\",\"Cor.Coe.\"},ImageSize->{450,300}];
\tRemove[\"rgbG\",\"deCompG\"];memoryUsed\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 450 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 -62.4711 63.3985 [
[.2619 .28086 -3 -9 ]
[.2619 .28086 3 0 ]
[.5 .28086 -3 -9 ]
[.5 .28086 3 0 ]
[.7381 .28086 -3 -9 ]
[.7381 .28086 3 0 ]
[.97619 .28086 -3 -9 ]
[.97619 .28086 3 0 ]
[1.025 .29336 0 -6.28125 ]
[1.025 .29336 52 6.28125 ]
[.01131 .03977 -30 -4.5 ]
[.01131 .03977 0 4.5 ]
[.01131 .16657 -30 -4.5 ]
[.01131 .16657 0 4.5 ]
[.01131 .42016 -30 -4.5 ]
[.01131 .42016 0 4.5 ]
[.01131 .54696 -30 -4.5 ]
[.01131 .54696 0 4.5 ]
[.02381 .64303 -26 0 ]
[.02381 .64303 26 12.5625 ]
[.5 .63053 -137 0 ]
[.5 .63053 137 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .29336 m
.2619 .29961 L
s
[(2)] .2619 .28086 0 1 Mshowa
.5 .29336 m
.5 .29961 L
s
[(3)] .5 .28086 0 1 Mshowa
.7381 .29336 m
.7381 .29961 L
s
[(4)] .7381 .28086 0 1 Mshowa
.97619 .29336 m
.97619 .29961 L
s
[(5)] .97619 .28086 0 1 Mshowa
.125 Mabswid
.07143 .29336 m
.07143 .29711 L
s
.11905 .29336 m
.11905 .29711 L
s
.16667 .29336 m
.16667 .29711 L
s
.21429 .29336 m
.21429 .29711 L
s
.30952 .29336 m
.30952 .29711 L
s
.35714 .29336 m
.35714 .29711 L
s
.40476 .29336 m
.40476 .29711 L
s
.45238 .29336 m
.45238 .29711 L
s
.54762 .29336 m
.54762 .29711 L
s
.59524 .29336 m
.59524 .29711 L
s
.64286 .29336 m
.64286 .29711 L
s
.69048 .29336 m
.69048 .29711 L
s
.78571 .29336 m
.78571 .29711 L
s
.83333 .29336 m
.83333 .29711 L
s
.88095 .29336 m
.88095 .29711 L
s
.92857 .29336 m
.92857 .29711 L
s
.25 Mabswid
0 .29336 m
1 .29336 L
s
gsave
1.025 .29336 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
81.000 12.813 moveto
(order) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .03977 m
.03006 .03977 L
s
[(0.986)] .01131 .03977 1 0 Mshowa
.02381 .16657 m
.03006 .16657 L
s
[(0.988)] .01131 .16657 1 0 Mshowa
.02381 .42016 m
.03006 .42016 L
s
[(0.992)] .01131 .42016 1 0 Mshowa
.02381 .54696 m
.03006 .54696 L
s
[(0.994)] .01131 .54696 1 0 Mshowa
.125 Mabswid
.02381 .07147 m
.02756 .07147 L
s
.02381 .10317 m
.02756 .10317 L
s
.02381 .13487 m
.02756 .13487 L
s
.02381 .19826 m
.02756 .19826 L
s
.02381 .22996 m
.02756 .22996 L
s
.02381 .26166 m
.02756 .26166 L
s
.02381 .32506 m
.02756 .32506 L
s
.02381 .35676 m
.02756 .35676 L
s
.02381 .38846 m
.02756 .38846 L
s
.02381 .45186 m
.02756 .45186 L
s
.02381 .48356 m
.02756 .48356 L
s
.02381 .51526 m
.02756 .51526 L
s
.02381 .00807 m
.02756 .00807 L
s
.02381 .57866 m
.02756 .57866 L
s
.02381 .61035 m
.02756 .61035 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cor) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coe) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -198 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.813 moveto
(.11) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Comparison) show
171.000 12.813 moveto
(RGB) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
189.000 12.813 moveto
(H) show
195.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(red) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
213.000 12.813 moveto
(L) show
225.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(and) show
249.000 12.813 moveto
(decoded) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
291.000 12.813 moveto
(H) show
297.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(green) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
327.000 12.813 moveto
(L) show
333.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.5 Mabswid
.02381 .01472 m
.2619 .08819 L
.5 .10802 L
.7381 .11992 L
.97619 .1227 L
s
0 1 0 r
.02381 .56034 m
.2619 .59072 L
.5 .59739 L
.7381 .60298 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{450, 300},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000720001;1P00`40o`000?l0003ooooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0
0?ooooo3oooo003ooooo`oooo`008_ooo`030000oooooooo0?oooonNoooo000Roooo00<0003ooooo
ool0oooooikoool002;oool00`000?ooooooo`3oooooW_ooo`008_ooo`80003oooooWoooo`008_oo
o`030000oooooooo0?oooonNoooo000Roooo00<0003oooooool0oooooikoool002;oool2o`00oooo
oiooool002;oool00`000?ooool00002o`00oooooicoool002;oool00`000?ooooooo`02oooo1?l0
0?oooonHoooo000Roooo00<0003oooooool01_ooo`?o003oooooUOooo`008_ooo`030000oooooooo
00Woool3o`00oooooi;oool002;oool00`000?ooooooo`0<oooo1?l00?oooon>oooo000Roooo00<0
003oooooool04?ooo`?o003oooooRoooo`000_ooo`800004oooo0P0000?oool300001?ooo`800003
oooo0`0000Koool00`000?ooooooo`0Coooo0ol00?oooon8oooo00001Oooo`000?ooooooo`00000:
oooo00D0003oooooooooool000000_ooo`040000oooooooo00000_ooo`030000oooooooo00?oool0
0`000?ooooooo`0Foooo1?l00?oooon4oooo00001Oooo`000?ooooooo`000009oooo0`0000;oool0
10000?ooooooo`0000;oool010000?ooooooo`0000Goool300006_ooo`?o003oooooPOooo`0000Go
ool0003oooooool000002?ooo`040000oooooooo00000oooo`800003oooo0`0000Koool00`000?oo
ooooo`0Moooo0ol00?oooomnoooo00001Oooo`000?ooooooo`000008oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo00<0003oooooool01Oooo`030000oooooooo023oool4o`00oooo
og[oool000;oool200002_ooo`<00003oooo0P0000Coool300001Oooo`030000oooooooo02Coool3
o`00ooooogOoool002;oool00`000?ooooooo`0Woooo0ol00?oooomdoooo000Roooo00<0003ooooo
ool0:_ooo`?o003oooooLOooo`008_ooo`030000oooooooo02goool4o`00ooooofgoool002;oool0
0`000?ooooooo`0aoooo0ol00?oooomZoooo000Roooo00<0003oooooool0=?ooo`?o003oooooIooo
o`008_ooo`030000oooooooo03Ooool4o`00ooooof?oool002;oool00`000?ooooooo`0koooo0ol0
0?oooomPoooo000Roooo0P0003ooool3o`00oooooegoool002;oool00`000?ooooooo`11oooo1?l0
0?oooomIoooo000Roooo00<0003oooooool0AOooo`?o003oooooE_ooo`008_ooo`030000oooooooo
04Soool3o`00oooooe?oool002;oool00`000?ooooooo`1;oooo1?l00?oooom?oooo000Roooo00<0
003oooooool0Coooo`?o003oooooC?ooo`008_ooo`030000oooooooo05;oool8o`00ooooodCoool0
02;oool00`000?ooooooo`1Joooo3?l00?oooolhoooo000Roooo00<0003oooooool0I_ooo`co003o
oooo;?ooo`008_ooo`030000oooooooo07;oool<o`00ooooob3oool002;oool00`000?ooooooo`1n
oooo3Ol00?oooolCoooo000Roooo00<0003oooooool0Roooo`co003ooooo1oooo`008_ooo`80002H
oooo3?l00?[oool002;oool00`000?ooooooo`2Soooo3ol00>_oool002;oool00`000?ooooooo`2b
oooo4_l00=Woool002;oool00`000?ooooooo`34oooo4Ol00<Soool002;oool00`000?ooooooo`3E
oooo4Ol00;Ooool002;oool00`000?ooooooo`3Voooo4_l00:Goool002;oool00`000?ooooooo`3h
oooo<ol007;oool002;oool00`000?ooooooo`3ooooo;?ooobco0016oooo000Roooo00<0003ooooo
ool0oooooikoool002;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo0?oooonN
oooo000Roooo0P000?oooonOoooo000Roooo00<0003oooooool0oooooikoool002;oool00`000?oo
ooooo`3oooooW_ooo`008_ooo`030000oooooooo0?oooonNoooo000Roooo00<0003oooooool0oooo
oikoool002;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo0?oooonNoooo000R
oooo00<0003oooooool0oooooikoool002;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000
oooooooo0?oooonNoooo0002oooo0P0000Coool200000oooo`<00004oooo0P0000Coool200001_oo
o`030000oooooooo0?oooonNoooo00001Oooo`000?ooooooo`00000:oooo00D0003oooooooooool0
00000_ooo`040000oooooooo00000_ooo`030000oooooooo00?oool00`000?ooooooo`3oooooW_oo
o`0000Goool0003oooooool000002Oooo`<00002oooo00@0003oooooool00002oooo00@0003ooooo
ool00005oooo0`000?oooonNoooo00001Oooo`000?ooooooo`000008oooo00@0003oooooool00003
oooo0P0000Coool200001_ooo`030000oooooooo0?oooonNoooo00001Oooo`000?ooooooo`000008
oooo00@0003oooooool00002oooo00@0003oooooool00002oooo00@0003oooooool00005oooo00<0
003oooooool0oooooikoool000;oool200002_ooo`<00003oooo0P0000Coool200001_ooo`030000
oooooooo0?oooonNoooo000Roooo00<0003oooooool0oooooikoool002;oool00`000?ooooooo`3o
ooooW_ooo`008_ooo`030000oooooooo0?oooonNoooo000Roooo00<0003oooooool0oooooikoool0
02;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo0?oooonNoooo000Roooo00<0
003oooooool0oooooikoool002;oool20000oooooiooool002;oool00`000?ooooooo`3oooooW_oo
o`008_ooo`030000oooooooo0?oooonNoooo000Roooo00<0003oooooool0oooooikoool002;oool0
0`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo0?oooonNoooo000Roooo00<0003ooooo
ool0oooooikoool002;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo0?oooonN
oooo000Roooo00<0003oooooool0oooooikoool002;oool00`000?ooooooo`3oooooW_ooo`008_oo
o`030000oooooooo0?oooonNoooo000Roooo0P000?oooonOoooo000Roooo00<0003oooooool0oooo
oikoool002;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo0?oooonNoooo000R
oooo00<0003oooooool0oooooikoool002;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000
oooooooo0?oooonNoooo000Roooo00<0003oooooool0oooooikoool002;oool00`000?ooooooo`3o
ooooW_ooo`008_ooo`030000oooooooo0?oooonNoooo000Roooo00<0003oooooool0DOooo`@0001C
oooo0P0005Koool30000D_ooo`800016oooo000Roooo0P0005;oool00`000?ooooooo`1Coooo00@0
003oooooool0001Foooo00<0003oooooool0D?ooo`040000oooooooo0000AOooo`008_ooo`030000
oooooooo05;oool00`000?ooooooo`1Doooo00<0003oooooool0D_ooo`D0001Doooo00<0003ooooo
ool0@oooo`008_ooo`030000oooooooo05?oool00`000?ooooooo`1Doooo00<0003oooooool0DOoo
o`040000oooooooo0000Doooo`800016oooo000Roooo00<0003oooooool0DOooo`040000oooooooo
0000D_ooo`040000oooooooo0000E?ooo`030000oooo000005?oool00`000?ooooooo`15oooo000R
oooo00<0003oooooool0D_ooo`80001Doooo0P0005Koool20000Doooo`<00015oooo000Roooo00<0
003oooooool0oooooikoool002;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo
0?oooonNoooo000Roooo00<0003oooooool0oooooikoool002;oool00`000?ooooooo`3oooooW_oo
o`008_ooo`030000oooooooo0?oooom/oooo00H0003oooooooooool0003oool300002_ooo`800003
oooo100000?oool400000_ooo`<00002oooo100000Coool002;oool00`000?ooooooo`3oooooKOoo
o`030000oooo000000;oool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`02oooo00@0003oooooool00002oooo00<0003oooooool01?ooo`030000oooooooo00Coool0
01Wooooo0000K00000koool01@000?ooooooooooo`000002oooo00<0003oooooool01_ooo`040000
oooooooo00000oooo`030000oooooooo00;oool010000?ooooooo`0000;oool400000oooo`030000
oooooooo00Coool002;oool00`000?ooooooo`0>oooo00<0003oooooool03oooo`030000oooooooo
00koool00`000?ooooooo`0>oooo00<0003oooooool03_ooo`030000oooooooo00koool00`000?oo
ooooo`0?oooo00<0003oooooool03_ooo`030000oooooooo00koool00`000?ooooooo`0>oooo00<0
003oooooool03oooo`030000oooooooo00koool00`000?ooooooo`0>oooo00<0003oooooool03_oo
o`030000oooooooo00ooool00`000?ooooooo`0>oooo00<0003oooooool03_ooo`030000oooooooo
00koool00`000?ooooooo`0?oooo00<0003oooooool03_ooo`030000oooooooo01?oool00`000?oo
o`000002oooo0`0000[oool200000oooo`@00003oooo0`0000?oool200000oooo`@00004oooo000R
oooo00<0003oooooool0Doooo`030000oooooooo05?oool00`000?ooooooo`1Doooo00<0003ooooo
ool0Doooo`030000oooooooo01;oool01@000?ooooooooooo`000002oooo00<0003oooooool05ooo
o`030000oooooooo00koool002;oool00`000?ooooooo`3oooooLoooo`<0000Foooo0P00013oool0
02;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo0?oooonNoooo000Roooo00<0
003oooooool0oooooikoool002;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo
0?oooonNoooo000Roooo00<0003oooooool0oooooikoool002;oool00`000?ooooooo`3oooooW_oo
o`008_ooo`80003oooooWoooo`008_ooo`030000oooooooo0?oooonNoooo000Roooo00<0003ooooo
ool0oooooikoool002;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo0?oooonN
oooo000Roooo00<0003oooooool0oooooikoool002;oool00`000?ooooooo`3oooooW_ooo`008_oo
o`030000oooooooo0?oooonNoooo000Roooo00<0003oooooool0oooooikoool002;oool00`000?oo
ooooo`3oooooW_ooo`008_ooo`030000oooooooo0?oooonNoooo000Roooo0P000?oooonOoooo000R
oooo00<0003oooooool0oooooikoool002;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000
oooooooo0?oooonNoooo000Roooo00<0003oooooool0oooooikoool002;oool00`000?ooooooo`3o
ooooW_ooo`008_ooo`030000oooooooo0?oooonNoooo000Roooo00<0003oooooool0oooooikoool0
02;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo0?oooonNoooo000Roooo00<0
003oooooool0oooooikoool002;oool00`000?ooooooo`3oooooW_ooo`008_ooo`80003oooooWooo
o`008_ooo`030000oooooooo0?oooonNoooo000Roooo00<0003oooooool0oooooikoool002;oool0
0`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo0?oooonNoooo000Roooo00<0003ooooo
ool0oooooikoool002;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo0?oooonN
oooo000Roooo00<0003oooooool0oooooikoool000;oool200001?ooo`800003oooo0`0000?oool3
00000oooo`@00005oooo00<0003oooooool0oooooikoool00005oooo0000oooooooo000000[oool0
0`000?ooooooo`03oooo00D0003oooooooooool000002?ooo`030000oooooooo0?oooonNoooo0000
1Oooo`000?ooooooo`000009oooo0`0000?oool300000oooo`030000oooooooo00Goool30000oooo
oikoool00005oooo0000oooooooo000000Soool010000?ooooooo`0000;oool010000?ooooooo`00
00Coool00`000?ooooooo`04oooo00<0003oooooool0oooooikoool00005oooo0000oooooooo0000
00Soool010000?ooooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`0000Goool0
0`000?ooooooo`3oooooW_ooo`000_ooo`80000:oooo0`0000?oool300000oooo`800006oooo00<0
003oooooool0oooooikoool002;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo
0?oooonNoooo000Roooo00<0003oooooool0oooooikoool002;oool00`000?ooooooo`3oooooW_oo
o`008_ooo`030000oooooooo0?oooonNoooo000Roooo00<0003oooooool0oooooikoool002;oool0
0`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo0?oooonNoooo000Roooo0P000?oooonO
oooo000Roooo00<0003oooooool0oooooikoool002;oool00`000?ooooooo`3oooooW_ooo`008_oo
o`030000oooooooo0?oooonNoooo000Roooo00<0003oooooool0oooooikoool002;oool00`000?oo
ooooo`3oooooW_ooo`008_ooo`030000oooooooo0?oooonNoooo000Roooo00<0003oooooool0oooo
oikoool002;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo0?oooonNoooo000R
oooo00<0003oooooool0oooooikoool002;oool20000oooooiooool002;oool00`000?ooooooo`3o
ooooW_ooo`008_ooo`030000oooooooo0?oooonNoooo000Roooo00<0003oooooool0oooooikoool0
02;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo0?oooonNoooo000Roooo00<0
003oooooool0oooooikoool002;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo
0?oooonNoooo000Roooo00<0003oooooool0oooooikoool002;oool00`000?ooooooo`3oooooW_oo
o`008_ooo`030000oooooooo0?oooonNoooo000Roooo0P000?oooonOoooo000Roooo00<0003ooooo
ool0oooooikoool002;oool00`000?ooooooo`3oooooW_ooo`008_ooo`030000oooooooo0?oooonN
oooo000Roooo00<0003oooooool0oooooikoool002;oool00`000?ooooooo`3oooooW_ooo`008_oo
o`030000oooooooo0?oooonNoooo000Roooo00<0003oooooool0oooooikoool002;oool00`000?oo
ooooo`3oooooW_ooo`000_ooo`800004oooo0P0000?oool300000oooo`<00005oooo0`0000Coool0
0`000?ooooooo`3oooooW_ooo`0000Goool0003oooooool000002_ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo0?oooonNoooo00001Oooo`00
0?ooooooo`000009oooo0`0000?oool300000_ooo`D00004oooo0`000?oooonNoooo00001Oooo`00
0?ooooooo`000008oooo00@0003oooooool00002oooo00@0003oooooool00002oooo00@0003ooooo
ool00005oooo00<0003oooooool0oooooikoool00005oooo0000oooooooo000000Soool010000?oo
ooooo`0000;oool010000?ooooooo`0000?oool00`000?ooo`000005oooo00<0003oooooool0oooo
oikoool000;oool200002_ooo`<00003oooo0`0000Coool200001Oooo`030000oooooooo0?oooonN
oooo000Roooo00<0003oooooool0oooooikoool002;oool40?l0oooooigoool002;oool010000?oo
ooooooooo`P0o`3oooooUOooo`008_ooo`030000oooooooo00Woool80?l0ooooohgoool002;oool0
0`000?ooooooo`0Aoooo203o0?oooon5oooo000Roooo00<0003oooooool06Oooo`P0o`3oooooOOoo
o`008_ooo`030000oooooooo027oool70?l0ooooogKoool002;oool00`000?ooooooo`0Xoooo203o
0?oooom^oooo000Roooo0P00037oool80?l0ooooofKoool002;oool00`000?ooooooo`0hoooo203o
0?oooomNoooo000Roooo00<0003oooooool0@?ooo`P0o`3oooooE_ooo`008_ooo`030000oooooooo
04Soool80?l0ooooodkoool002;oool00`000?ooooooo`1@oooo4P3o0?oooolloooo000Roooo00<0
003oooooool0H_oooa`0o`3ooooo8?ooo`008_ooo`030000oooooooo07kooolM0?l0ooooo`?oool0
02;oool00`000?ooooooo`2Koooo903o0=koool002;oool00`000?ooooooo`2ooooo;03o0;;oool0
02;oool00`000?ooooooo`3[ooooK03o04Koool002;oool00`000?ooooooo`3oooooW_ooo`008_oo
o`80003oooooWoooo`008_ooo`030000oooooooo0?oooonNoooo000Roooo00<0003oooooool0oooo
oikoool002;oool00`000?ooooooo`3oooooW_ooo`00oooool?oool00?ooooo3oooo003ooooo`ooo
o`00oooool?oool00?ooooo3oooo003ooooo`oooo`00E?ooo`<0000/oooo0`0004?oool00`000?oo
ooooo`0Boooo00<0003oooooool0C_ooo`030000oooooooo00<0000Koooo00<0003oooooool0Kooo
o`00Eoooo`030000oooooooo02[oool00`000?ooooooo`11oooo00<0003oooooool05?ooo`030000
oooooooo04coool00`000?ooooooo`04oooo00<0003oooooool06Oooo`030000oooooooo06koool0
04Soool300001?ooo`<00003oooo0`0000?oool200000oooo`D000000oooo`000000000300000_oo
o`800004oooo0`0000?oool200000_ooo`8000001Oooo`000?ooo`000?ooo`0300000oooo`D00000
0oooo`000000000200000oooo`<00002oooo0`0000Coool200000_ooo`800002oooo0P0000Koool3
00000_ooo`030000oooooooo00800002oooo100000Coool00`000?ooooooo`02oooo100000?oool3
00000oooo`@00003oooo00<0003oooooool01oooo`L00002oooo0P0000;oool400002?ooo`@00002
oooo0`0000?oool300000oooo`800004oooo100000;oool300000oooo`@00002oooo00<0003ooooo
ool00oooo`<00002oooo100000?oool300000oooo`<000000oooo`0000000002oooo0P0000?oool0
0`000?ooooooo`1]oooo0019oooo00<0003oooooool01?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`08oooo00<0003oooooool00oooo`030000oooooooo00Ooool00`000?ooooooo`03
oooo00@0003oooooool00002oooo00L0003oool0003oool0003oool000000_ooo`030000oooooooo
00@00003oooo00<0003oooooool01?ooo`030000oooooooo00Coool010000?ooooooo`0000;oool0
10000?ooooooo`0000;oool00`000?ooooooo`06oooo00@0003oooooool00002oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo00;oool0
0`000?ooooooo`03oooo00@0003oooooool00004oooo00<0003oooooool01oooo`@00002oooo00@0
003oooooool00002oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool0
0`000?ooooooo`03oooo00@0003oooooool00003oooo00<0003oooooool00_ooo`040000oooooooo
00000oooo`030000oooooooo00;oool00`000?ooooooo`03oooo00<0003oooooool00oooo`040000
oooooooo00001?ooo`030000oooooooo06goool004Woool00`000?ooooooo`04oooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00Soool00`000?ooooooo`03oooo00<0003oooooool01ooo
o`030000oooooooo00?oool010000?ooooooo`0000;oool01`000?ooo`000?ooo`000?ooo`000002
oooo00<0003oooooool00oooo`050000oooooooooooo000000Koool010000?ooooooooooo`<00003
oooo00@0003oooooool00002oooo00@0003oooooool00008oooo0`0000?oool00`000?ooo`000002
000000Goool0003oooooool000000oooo`030000oooooooo00?oool00`000?ooooooo`02oooo1000
00;oool010000?ooooooo`0000Coool00`000?ooooooo`0:oooo00@0003oooooool00002oooo00@0
003oooooool00002oooo00<0003oooooool01_ooo`040000oooooooo00000_ooo`@00002oooo00<0
003oooooool00oooo`040000oooooooo00000_ooo`040000oooooooo00000_ooo`@00002oooo00@0
003oooooool00003oooo00<0003oooooool00_ooo`040000oooooooo00000oooo`030000oooooooo
00;oool400000_ooo`@00002oooo00@0003oooooool00004oooo00<0003oooooool0KOooo`00BOoo
o`800004oooo0P0000Coool400002Oooo`030000oooooooo00?oool00`000?ooooooo`07oooo00<0
003oooooool01?ooo`800002oooo0`000003oooo0000oooo00@00004oooo0`0000;oool400000ooo
o`800003oooo100000?oool200000_ooo`@00009oooo00@0003oooooool00002oooo00<0003ooooo
ool00oooo`<00004oooo00<0003oooooool00_ooo`@00003oooo0P0000Coool300001?ooo`030000
oooooooo00Soool3000000?oool0000000000P0000Coool300002Oooo`<00003oooo0P0000Coool3
00000oooo`800004oooo0`0000?oool200001?ooo`<00003oooo00<0003oooooool00oooo`@00000
0oooo`000000000200000oooo`800004oooo0P0000;oool400001Oooo`030000oooooooo06goool0
04Woool010000?ooooooo`0001Goool00`000?ooooooo`03oooo00<0003oooooool01oooo`040000
oooooooo0000?_ooo`040000oooooooo00000_ooo`030000oooooooo00?oool010000?ooooooo`00
00Coool00`000?ooooooo`0@oooo00D0003oooooooooool000006Oooo`030000oooooooo00Woool0
0`000?ooooooo`0Eoooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`0P
oooo00<0003oooooool0K_ooo`003?ooo`<00003oooo0P0000?oool400000oooo`800004oooo0`00
00?oool200001?ooo`<00003oooo0P00013oool500000oooo`030000oooooooo00koool200001?oo
o`80000:oooo0`0002;oool00`000?ooooooo`0Hoooo100000Coool3000000?oool0000000000P00
00Koool00`000?ooooooo`0>oooo0P0000;oool00`000?ooooooo`0Goooo0P0000[oool200005_oo
o`80000:oooo0P0000Goool00`000?ooooooo`0Noooo00<0003oooooool0Koooo`002oooo`030000
oooooooo00?oool010000?ooooooo`0000?oool00`000?ooooooo`08oooo00<0003oooooool00ooo
o`040000oooooooo00000_ooo`030000oooooooo0?oooonAoooo000;oooo00<0003oooooool00ooo
o`040000oooooooo00000oooo`030000oooooooo00Soool00`000?ooooooo`03oooo00@0003ooooo
ool00002oooo10000?oooon@oooo000;oooo00<0003oooooool01?ooo`800003oooo100000Soool0
0`000?ooooooo`04oooo0P0000Coool20000oooooi7oool000_oool010000?ooooooo`0001Coool0
10000?ooooooo`000?oooonLoooo000<oooo0`0001Goool30000oooooicoool00?ooooo3oooo003o
oooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003o
oooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003o
oooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003o
oooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003o
oooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00\
\>"],
  ImageRangeCache->{{{0, 449}, {299, 0}} -> {0.599455, 0.984204, 0.0116009, \
4.35677*^-05}}],

Cell[BoxData[
    InterpretationBox[\(7161\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ 7161, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4.3.6 Recovered image comparison",
  FontFamily->"Times New Roman",
  FontSize->12]], "Subsection"],

Cell[TextData[{
  "\t",
  StyleBox[
  "This section shows the approximately recovered color images. We have two \
types of the recovered images. One is recovered from the conventional red, \
green and blue compressed components. The other is recovered from the \
compressed radius, attitude and longitude components.\n\tFigure 12 shows the \
recovered color images from the 25 percent compressed image data. ",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  "lly, the right side images have higher recoverability than those of right \
side ones, but our human eyes could not find out a big difference between \
them. Hence, a small different recoverability between them is no meaning to \
us, but sometimes, it becomes a significant difference for the image \
identification and visualizations.\n",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["\t",
    FormatType->InputForm],
  StyleBox[
  "Because of a great memory requirement of a next section, we remove the \
used variables and check up the used memories.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["compR=Table[colorComp[deCompR[[i]]],{i,Length[base]}];", "Input"],

Cell["\<\
compeG=Table[{
\tShow[convertRGB[rgbR[[i]]],
\t\tPlotLabel->StringForm[\"RGB ``order\",6*i],
\t\tAspectRatio->dim[[2]]/dim[[3]],DisplayFunction->Identity],
\tShow[convertRGB[compR[[i]]],
\t\tPlotLabel->StringForm[\"Decomposed ``oder\",6*i],
\t\tAspectRatio->dim[[2]]/dim[[3]],DisplayFunction->Identity]},
{i,1,Length[base],2}];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[compeG],ImageSize->{300,400},
\tPlotLabel->\"Fig.12. Compressed image by Coifman\"];
Remove[\"compR\",\"deCompR\",\"compeG\",\"rgbR\",\"base\"];
memoryUsed\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.52381 
%%ImageSize: 300 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0362812 0.47619 [
[.5 1.53631 -107 0 ]
[.5 1.53631 107 12.5625 ]
[ 0 0 0 0 ]
[ 1 1.52381 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.53631 -168 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.813 moveto
(.12) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Compressed) show
177.000 12.813 moveto
(image) show
213.000 12.813 moveto
(by) show
231.000 12.813 moveto
(Coifman) show
273.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.52381 L
0 1.52381 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0362812 0.477324 0.489796 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -35 0 ]
[.5 1.0125 35 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(RGB) show
87.000 12.813 moveto
(30) show
99.000 12.813 moveto
(order) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
DEDFE0DEE1E1DEE0E0DEE0E1DEE0E0DEE1E2DEE1E2DEE0E0DEE0E1DEE1E2DEE1E2DEE0E1
DEE1E2DEE1E2DEE1E1DEE1E1DEE1E2DEE0E0DEE1E1DEE1E2DEE1E2DEE1E2DFE1E2DFE1E2
DEE1E2DEE1E1DEE0E1DEE1E1DFE2E2DFE2E3E0E2E3E0E2E3DFE2E2DDDFE0DBDDDEDADCDC
D9DBDCDBDDDDDCDFDFDDDFE0DFE2E2E7EAEAEAEEECE9EEEDE8EAE9E7DFDAE2D2C6E6D7C9
E3D4C8E4D5CBE4D5CDE4D8D0E6DAD3E6DAD4E4D7D2E6DBD4E3D9D3E2D7D2E2D7D2DFD6D0
E1D4CCDED3CEDED0C9DDCEC6DCCFC9DCCCC7DFD0C4DECEC3DACBC2D9CABFD9C7BCD8C6BC
D6C3B8D7C4BAD9C4BAD9C4BAD9C4B9D8C2B7D7C1B5D2BAB0D0BAAED0B5AACFB6AACBB0A5
CBB1A6CCB1A6CDB2A7CDB5AACDB5A9D0B4AACCB5AACCB5A9CBB4A7C0A89DCDBCB5DFE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E0DEE1E2DEE1E2DEE1E2DEE0E0DEE1E1
DEE0E1DEE1E2DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEDFE0DEE1E2DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2
DEDFE0DEE1E2DEDFE0DEE0E1DEDFE0DEE1E2DEE2E2DEE0E0DEDFE0DEE1E2DEE1E2DEDFE0
DEE1E2DEE2E2DEE0E1DEE0E1DEE1E2DEDFE0DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDFE0DEE0E1DEE1E1DEE1E1DEE0E1DEE0E1
DEE1E2DFE2E2DEE1E1DDE0E1DEE1E1E3E6E6E5E8E9E3E6E7DFE1E1DDD1CBDDC2B0DFC7B4
DFC7B6DFC7B7E0C8BBDFCBC0E0CBC0E0CBC1E0CABFE0CDC1E1CEC4E1CDC3E1CDC3DDCBC1
DEC9BADDCABFD9C4B6DBC3B5D7C3B6D4BEB0D8BEACD7BCABD3B8A9D2B6A5D0B3A3D3B2A4
CEAF9FCDAC9ACBA997C9A696C8A594C8A392CAA595C8A291C9A594CAA191CAA494CAA091
C7A191C79F8FC59E8DC59F8FC29D8CC69D8EC29E8EC39E8DC3A08CB48F7EC8B3AADEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDFE0DEE1E2DEE1E2DEE1E2DEE0E0DEE0E1
DEDFDFDEE1E2DEE1E1DEE0E0DEE1E2DEE1E2DEE1E2DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEDEDFDEE1E2DEE1E2DEE0E0DEE1E2DEE1E2DEE1E2
DEDFE0DEE1E2DEDFDFDEE0E1DEDEDFDEE1E2DEE2E2DEE0E1DEDFDFDEE1E2DEE1E2DEDFDF
DEE1E2DEE2E2DEE0E1DEE0E1DEE1E2DEDFE0DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DFE1E2DFE2E2DFE1E2DEE1E1DEE1E1DDDDDEDDDFDFDEE0E1DFE2E2E0E3E4E1E4E5
E2E5E6E1E5E5DFE2E3DEE1E1DEE0E1DDE0E1DEE1E3DCDEE0D8D9DBD6C5BED9B6A1DABBA5
DBBCA9DBBCA9DCBDADDBC0B3DBBFB2DBBFB2DCC0B1DAC1B1DEC4B6DFC4B6DFC3B5DAC1B3
DABFACDAC0B1D4BAA7D8B9A5D2B7A6CEB09DD2AE98D0AC96CDA793CBA48FC7A28ECDA18E
C79E89C49982C0937DBD8F7BBB8D78BB8C78C0907CBF907BC29581C5927FC59783C89582
C59683C4937FBF907BBF8F7CBB8C78BF8C79BB8D7ABC8E79BD9078AF826EC7B2A9DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDFE0DEE1E2DEE1E2DEE1E2DEE0E1DEE0E0
DEDEDFDEE1E2DEE1E1DEDFE0DEE1E2DEE1E2DEE1E2DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEDEDFDEE1E2DEE1E2DEDFE0DEE1E2DEE1E1DEE1E2
DEDFE0DEE2E2DEDFE0DEE0E1DEDEDFDEE1E2DEE1E2DEE0E1DEDFE0DEE1E2DEE1E2DEDFE0
DEE1E2DEE1E2DEE0E0DEE0E0DEE1E2DEE0E0DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DFE1E2DFE2E2DFE1E2DEE1E1DEE1E1DDDEDEDDDFDFDEE1E1E0E2E3E0E4E4E2E5E6
E2E6E6E1E4E5E0E3E4DFE2E2DEE0E1D9DBDCD8DADCD8DADBD7D9DBD5C0B8D8B29CD9B7A1
DBB9A6DAB9A6DBBAA9DABDAFD9BBACD9BAACDBBCADD9BDACDDBFB0DDBEAEDDBEAFD8BCAC
D7BAA7D9BBABD3B5A2D8B4A0D0B19ECDA995D1A590CDA38DCA9D89C89B86C49984C89784
C49581C3927CBE8D76BB8A76B88570B58470BB8772BC8A74BE8D78C18D78C1917CC6917C
C2907BC38D78BD8B74BE8A75BB8872BB8772B98974B98973BA8A70B38977CCBBB5DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E0DEE1E2DEE1E2DEE1E2DEE0E1DEE0E0
DEDEDEDEE1E2DEE1E2DEDFE0DEE1E2DEE1E2DEE1E2DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEDEDFDEE1E2DEE1E2DEDFE0DEE1E2DEE0E1DEE1E2
DEDFE0DEE1E2DEE0E1DEE0E1DEDEDEDEE1E2DEE0E1DEE1E1DEE0E1DEE1E2DEE1E2DEE0E1
DEE1E2DEE1E1DEE0E0DEE0E0DEE1E2DEE0E1DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DFE1E2DEE1E2DEE1E2DEE1E1DEDFE0DEDFE0DEE1E1DFE2E2E0E3E3E0E4E4
E0E3E3DFE2E2E0E3E4E1E4E4DFE1E2D6D8D9D3D5D6D6D8D9DADEE0D8C0B6DAB6A0DBBBA6
DCBDABDCBDAADCBDADDCC0B3DABDAFDBBDAEDCBFB1DCBFAFDDBFB0DCBDACDDBEAED7BBAB
D5BAABD8B9ABD5B6A6D9B3A1D1B09DD1A998D3A393CEA28ECA9B89C99A88C69784C79583
C69583C79683C3927FC09380BD8978B78978BB8A75BD8D7ABC8C79BE8E7ABF917EC4937D
C08F7BC38D79BE8C77BF8D79BE8D79BB8B76BB8C78BA8C77BA8A72BF9F91D4CCC8DEE1E1
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E1DEE0E1
DEDEDFDEE1E2DEE1E2DEE0E0DEE1E2DEE1E2DEE1E2DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEDFE0DEE1E2DEE1E2DEE0E0DEE1E2DEE0E0DEE1E2
DEDFE0DEE1E2DEE1E2DEE0E0DEDEDEDEE2E2DEE0E0DEE1E2DEE1E1DEE1E2DEE1E2DEE1E1
DEE1E2DEE0E1DEE0E0DEE0E0DEE1E2DEE1E2DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE0E0DEE1E2DFE1E2DFE2E2DFE2E2
DDE0E0DDDFE0E1E4E4E3E6E6E0E3E4D5D8D9D1D2D3D6D8D8DFE4E5DCC3B6DDBDA9DEC2AF
DFC2B3DFC3B2DEC1B4DFC5B8DCC1B3DDC1B2DEC4B7DFC2B5DDC0B2DBBDADDDC0AFD7BCAD
D5BCB1D9BAAED8B8ADDBB5A7D3B1A0D6AB9ED7A699D0A493CC9D8ECC9D8EC99A8AC79687
C99889CD9E8FCA9C8EC9A091C69385BB9386BF917EC09585BD8F7FBE9480BE9584C39882
C0917EC4907EC0927EC19481C39683BD927EBF9481BC9280BD907ACDBBB2DDDEDEDEE1E1
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1
DEDFE0DEE1E2DEE2E2DEE0E1DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2DEE1E2DEE2E2DEE1E2
DEE2E2DEE0E1DEE1E2DEE1E2DEE0E1DEE1E2DEDFE0DEE1E2
DEE0E0DEE1E2DEE2E3DEE0E0DEDEDFDEE2E2DEDFE0DEE1E2DEE2E2DEE1E2DEE1E2DEE2E2
DEE1E2DEE0E0DEE0E1DEE0E1DEE1E2DEE2E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DFE1E2DFE2E3DFE0E1DEE1E2DEE1E1DEE1E1DEE0E1
DCDEDFDCDFDFE0E3E4E3E6E6E1E4E5D9DBDCD5D7D7DADCDCE2E7E8DFC4B6DFC3AFE1C6B5
E0C6B9E1C7B7DFC5B9E0C8BCDEC4B6DFC4B6E0C7BCE1C5B9DDC1B4DBBFAFDDC2B2D7BEB0
D5BFB6D9BCB1DABCB3DCB9ADD5B5A5DAB0A7DAAAA2D2A99AD0A295D0A396CDA090C89B8D
CD9D91D3A59AD0A59AD1AA9DCD9C91C19B91C39887C49B8FBF9285BF9886BF9989C49C88
C09583C59483C29784C49987C79C8ABF9986C19988BF9888C19785D9D2CEE3EBEDDEE1E1
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E3DEE1E2DEE1E2DEE1E1DEE1E2DEE0E1
DEE0E0DEE1E2DEE2E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE2E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEDFE0DEE1E2
DEE0E1DEE1E2DEE2E2DEE0E1DEDFE0DEE1E2DEDFE0DEE2E2DEE2E2DEE1E2DEE1E2DEE2E2
DEE1E2DEE0E0DEE0E1DEE0E1DEE1E2DEE2E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DFE1E2DFE2E3DFE1E1DFE1E2DEE1E1DEE0E1DDE0E0
DDE0E0DDE0E0DEE0E1DEE1E2DFE2E3E1E4E4E1E4E4E2E5E5E2E6E6DFC3B2E0C5B2E1C7B6
E0C6B8E0C6B6DFC5B8E0C7BADEC3B5DFC4B6E0C7BCE1C5B9DDC2B5DBC0B1DDC3B4D9C1B4
D7C2BADBBFB4DCBFB7DDBDB2D8BAABDDB8AFDCB1A9D5AFA1D4A89CD4AA9CD0A696CBA093
D0A197D5A89ED4A99ED4ADA1D1A196C69E94C69A8BC69C91C19487C09887C19B8BC49E8A
C09988C59786C39988C59B8AC79C8BC09B88C09988C19A8AC59E8FDFDEDDE5EEF2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E2DEE1E2DEE1E2DEE0E1DEE1E2DEE0E1
DEE0E1DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E0DEE1E2
DEE1E1DEE1E2DEE1E1DEE1E1DEE0E1DEE1E1DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE0E1DEE1E1DEE1E1DEE1E2DEE2E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DFE2E2DFE1E2DFE1E2DEE1E1DEE0E1DDE0E0
E0E2E3E0E3E3DADDDDD8DADBDDDFDFEBEEEEF0F4F4EBEFF0DFE0E0DDBFACDFC4B0DFC5B2
DFC3B3DDC2B0DEC3B4DEC3B5DDC1B0DEC2B3DFC4B9DFC3B6DDC2B5DCC2B4DDC5B6DBC5B7
DAC4BADDC2B7DDC2B8DEC2B6DAC1B3DEC0B6DDB9B0D7B5A7D8AFA2D9B2A1D3AC9BCFA79A
D4A59BD6A99DD5A89BD4A99CD2A295C99B91C9988BC8998DC49386C19585C39A89C59C8A
C19B8BC49887C49A88C59988C59786C29986BE9684C39987CAA59AE0E2E2E3EAEDDEE2E2
DEE1E1DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE0E0DEE1E2DEE0E1
DEE1E1DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2
DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2
DEE1E2DEE1E1DEE0E0DEE2E2DEE1E2DEE0E1DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DFE1E2DEE1E2DEE0E1DDE0E0
E2E5E5E2E5E6D8DADBD2D4D5DADCDBF1F4F3FAFFFFEFF4F5DCD8D7DABCA7DEC2ADDEC2AD
DDC0ADDBBDABDCC0B0DCC0AFDCBEACDDC0B1DEC1B5DDC1B2DDC2B5DDC5B7DDC6B9DEC8BB
DEC7BBDFC6B9DFC6B9DFC7BADDC8BADFC9BDDEC1B5DABCAEDCB7A8DDB9A6D6B3A0D4AEA0
D7AA9FD6A99BD5A698D4A496D2A293CC988CCC978AC99587C79385C29183C59887C69988
C19C8CC39986C49987C49785C29380C39783BC927FC49885D0AEA5DFE1E2DFE4E5DEE2E3
DEE1E1DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE0E0DEE1E2DEE1E2DEDFE0DEE1E2DEE0E1
DEE1E2DEE1E2DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2
DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE0E1DEDFE0DEE2E2DEE2E2DEE0E0DEE1E1DEE1E2DEE1E1DEE1E2DEE1E2DEE1E1
DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DFE1E2DEE1E2DEE1E1DEE0E1
E2E5E5E2E6E6D9DBDCD3D6D6DADCDCEFF2F1F5FAFBE5E9EBD9D0CCD9BAA5DEC1ACDCBFAA
DCBEAAD9BBA9DCBFADDBBDADDBBEABDCBFB0DEC0B3DDC0B1DDC3B6DEC7BADDC7BAE0CABD
E1C8BAE0C8BADFC8BADFCABCDFCCBFE0CEC1DEC7B8DDC2B3DFBEAEDFC0ABD8B9A4D9B4A5
DAADA1D6AA9AD5A695D4A092D3A393CF9789CE968ACB9384C99384C49081C79785C69786
C29C8BC29986C49885C39584C1907DC39683BC907DC59783D5BAB4DDE0E1DDDEDEDEE2E3
DEE1E1DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEDFE0DEE1E2DEE1E1DEDFE0DEE1E2DEE0E1
DEE1E2DEE1E2DEDFDFDEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E0DEE1E2
DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E2DEE1E2
DEE2E2DEDFE0DEDFE0DEE2E2DEE2E2DEE0E0DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E1
DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DFE1E2DFE1E2DEE1E2
DFE1E2DFE2E3DFE2E2DEE1E1DFE2E3E0E4E4DCDFDFCAC9CBD7C7C0D9BBA6DDC1ADDCBFAB
DCBEABDABDABDCBFAEDCBEAEDCBFADDDC0B2DEC0B3DEC1B2DEC5B8DFC8BBDEC7BAE0C9BD
E1C7B8E0C6B8DFC8BADFCABDE0CCBFDFCEBFDEC7B7DEC4B5E0C2B1DFC2ACDBBDA7DBB8A8
DCAFA1D7AC9AD6A695D5A192D5A595D1998ACF988ACC9484CB9585C79283C79784C69685
C29A89C29986C29784C39684C19380C49785BE927FC59985DAC9C7DEE1E1DBDBDADEE1E1
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDFE0DEE1E2DEE0E1DEE0E0DEE1E2DEE0E1
DEE1E2DEE1E2DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E0DEE1E2
DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E2DEE1E2
DEE1E2DEDEDFDEE0E0DEE1E2DEE1E2DEE0E0DEE2E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2
DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DFE1E2DEE1E2DEE1E2DEE1E1DFE2E2DFE2E3E0E3E3
DADCDDDADCDDE7EBEBEDF1F1E6EAEBCACDCFB7B5B6A69FA0D6BEB3DBBEAADDC1B0DCBFAE
DDC0B0DBC1B1DDC1B1DDC1B3DDC2B2DEC2B5DEC2B5DFC3B6DFC7BADFC8BCDFC5B9E0C6BA
E0C3B5DFC3B5DFC6B9DEC8BCDFC8BBDEC9B9DDC3B3DEC3B5DFC2B1DDC1ACDCBEA8DCB9A7
DCAE9FD8AD9AD7A896D7A394D8A798D29D8ED09C8CCE9887CC9987CA9686C69785C69685
C19685C29987C09684C29886C39886C49A88C29785C59C89DDD8D9DFE2E3DCDBDADEE0E0
DFE2E2DFE2E2DEE1E2DEE1E2DFE1E2DEE1E1DEDFE0DEE1E2DEE0E0DEE0E1DEE1E2DEE0E1
DEE1E2DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2
DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E2DEE1E2
DEE1E2DEDDDEDEE0E1DEE0E1DEE1E1DEE0E1DEE2E2DEE1E1DEE1E2DEE0E1DEE1E2DEE1E2
DEE1E2DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DFE2E2DFE1E2DEE1E1DDE0E1DFE2E2E0E3E4E2E5E5
D6D8D9D6D7D8EDF1F1F7FCFBE8EDEFB2B3B6928B8C857776D6B8A8DDC1AFDDC2B2DDC0B2
DDC2B5DDC6B8DFC2B4DEC3B8DFC5B7DEC4B8DFC4B6E1C6B9E0C9BCDFC8BBE0C3B7DFC3B7
DEC0B2DEBFB2DEC4B8DDC5B9DEC2B6DDC3B1DCBCACDDC0B1DDC0AFDABCA9DCBCA7DCB7A4
DCAC9CD8AD9AD7A997D8A697D9A79BD3A192D09F8DCF9C8ACD9C89CC9A89C69785C69584
C19380C29987BE9583C19987C59E8BC39C8BC69B8BC59F8DE0E4E7DFE3E4DDDCDCDEDFDF
DFE2E3DFE2E3DEE1E1DFE2E2DFE2E2DEE1E1DEE0E1DEE1E2DEDFE0DEE1E2DEE1E2DEE0E0
DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2
DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEDDDDDEE1E2DEE0E0DEE0E1DEE0E1DEE2E2DEE0E1DEE1E2DEE0E0DEE1E2DEE1E2
DEE1E2DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DFE2E2DFE1E2DEE1E1DDE0E1DFE2E2E0E3E4E2E5E6
D7D9DAD6D8D8ECF0F0F4F8F7DEE1E49E9B9E7C6F6E76625FD7B4A3DEC3B3DDC3B4DDC1B4
DEC4B8DFC9BCDFC3B6DFC5BADFC6BADFC5BADFC4B7E1C6B9E0C8BCDFC7BAE0C2B6DEC2B5
DDC0B2DDBEB0DDC4B8DDC3B8DDBFB2DDBFADDBB8A8DCBCADDABDACD8B9A6DBB9A4DAB4A1
DAAB9AD7AD9AD6AA98D7A897D8A79BD1A393CEA08CCF9E8BCD9D89CD9C8BC59785C69583
C1907DC29885BD9482C19987C5A08DC39C8DC99F8EC5A190E0E9ECDFE3E3DEE0DFDEE0E0
DFE2E3DFE2E3DEE1E1DFE1E2DFE1E2DEE1E1DEE1E1DEE1E2DEDFE0DEE2E2DEE1E2DEE0E1
DEE1E2DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2
DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2
DEE1E1DEDDDEDEE1E2DEE0E0DEDFE0DEE0E1DEE1E1DEE0E0DEE1E2DEDFE0DEE1E2DEE1E2
DEE1E2DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DFE2E2
DFE2E2DEE1E2E1E5E5DCDEDFC4C2C4938A897C6A67836B65D9B6A4DFC3B4DDC2B4DEC2B6
DFC4B9DFC9BDDFC3B7DFC5BADFC6BBDFC6BADEC2B6DEC2B6DEC5B9DEC6B9DFC3B6DDC4B7
DDC4B6DEC1B3DEC7BBDEC5B8DDC1B2DEC1AFDCB9AADABAAAD9BBA9D7B7A6D9B5A2D8B29F
D8AD9BD5AE9BD5AD9AD4A997D4A798CEA291CB9F89CE9E8ACD9B88CC9D8CC79886C69582
C2907CC09683BD9481C09884C49E8BC39B8BC99F8FC5A292DEE5E7DFE2E3E0E4E5DFE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E0DEE2E2DEE1E2DEE0E1
DEE1E2DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2
DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2
DEE1E2DEDFE0DEE1E2DEDFE0DEDFE0DEE0E1DEE0E1DEDFE0DEE1E2DEDFDFDEE1E2DEE1E2
DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E1DFE2E2E0E3E3DEE0E1DCDEDFDADDDD
E9EDEDE9EDEED0D2D3B8B7B9A1999A907F7B907771A3897FDBBBABDFC2B4DEC2B4DEC2B6
DFC4B8DFC8BCDFC2B7DEC4B7DEC5B9DEC5B9DDC0B5DBBDB1DCC1B5DEC5B8DDC4B8DDC9BC
DECBBCDFC7B9DFCBBEE0C8BADEC5B5E0C6B4DDBCAFD9B8A7D9B8A6D8B6A5D6B19FD6B09D
D6B09ED3AE9BD2AE9ACFA994CEA593C99F8CC89B86CC9C87CD9986CB9C8BC89986C69482
C4917DBF957FBF9480C09581C29985C49988C89E8DC5A191DADAD9DEE1E1E1E8EBDFE4E5
DEE0E0DDE0E0DEE1E2DEE1E1DEE1E1DFE2E2DFE2E2DFE1E2DEE0E1DEE2E2DEE1E2DEE1E1
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2
DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E1DEE1E2DEE0E0DEDFDFDEE0E0DEDFE0DEDEDFDEE1E1DEDFDFDEE1E2DEE1E2
DEE1E1DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DDDFE0DEE0E1E0E2E2E1E4E5DEE0E2DADCDDD6D8D8
F1F5F5F0F5F7BDBCBE969093827372957C74AB8E84C9AEA0DEC2B3DEC2B4DEC2B4DEC3B7
DFC4B7DFC6BADEC1B6DDC2B4DEC4B6DEC5B7DDBEB4D9BAACDABDB1DDC4B7DBC5B9DECCBF
DFD0C1E0CCBDE0CDC1E1CABBDEC7B6E2C8B8DDBDB1D7B3A2D8B2A1D8B2A2D3AB9AD3AB99
D4AF9FD0AC99D0AD98CAA690C9A38DC69B87C69783CA9984CD9684C99B89CA9985C79481
C5937FBD947DC29480C0937DC0947FC49784C69C8AC5A090D6CBC7DCDDDCE2EAEDDFE5E6
DDDEDEDCDFDFDFE1E2DEE0E1DEE0E1DFE2E3DFE3E3DFE2E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE0E1DEDFDFDEE0E0DEDFDFDEDEDFDEE1E1DEDFDFDEE1E2DEE1E2
DEE1E1DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DDE0E0DEE0E1DFE2E2E1E4E4DEE1E2DBDEDED7D9D9
EFF3F3ECEFF1ABA6A782787877625EA18377C4A598E7CBBAE0C6B8DEC1B4DFC2B4DFC4B7
DFC3B6DEC4B8DEC1B5DDC1B1DDC3B3DEC5B5DDBFB4DABBADDABDB0DEC4B7DCC7BADECDC0
DFD0C2E0CDC0E0CBBEE1C6B7DDC1B1E2C1B2DCB4AAD4A898D6A797D5A698D0A192D1A190
D2A798CFA493CFA794C9A18CC69F88C69884C49582C89883CB9482C59886C99884C79481
C69481BD937BC49480C1917CBF907BC59581C59986C59E8ED0BBB3D9D3D1E1E6E8DFE5E6
DDDFDEDCDFDFDFE2E2DEE0E1DEE0E1DFE2E3DFE3E3DFE2E2DEE2E2DEE1E1DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE0E1DEDFE0DEE0E0DEDEDFDEDFDFDEE1E2DEDFE0DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E1DEE1E1DFE1E2DFE2E3E0E3E3
E0E3E4D6D6D79D9391857774866E67B39485D5B6A8F1D4C2E1C7B8DEC2B5DFC2B4DFC4B7
DEC3B6DEC3B6DEC2B5DEC2B1DEC2B1DFC4B3DFC3B5DEC2B4DEC1B5DFC3B7DEC7BBDFC9BC
DFC8BCDECABEDFC1B5DFBBADDAB0A1DEACA0D79E95D19386D19387D09184CF9185CE9082
D09488CF9687D19B8BCD9A87C99B86CB9784C59785C69985C79481C09380C59480C69482
C69582BE937CC59480C2917CBF8F79C59380C49684C39B8ACBACA0D3C4BDDDDAD9DFE2E3
DFE2E3DEE1E2DFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E2DEE1E1DEE1E2DEE1E1
DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE0E1DEE1E2DEE1E2DEE0E0DEDFE0DEDFDFDEDFE0DEE1E2DEE0E1DEE1E2DEE1E2
DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DFE2E2E1E4E4DFE2E2DCDFE0DADDDDDFE2E2E4E8E8EBEFF0
C9C9CBB7B1B195857F9B887FAA8F85C9AA9BDDC0B2EBCFBDE0C5B4DEC3B7DFC2B5DFC3B7
DEC2B6DEC4B5DFC3B5E0C3B1DEC2AFDFC2AFE1C7B5E5CCBEE4C8BBE0C3B7E2C6B9E0C1B5
DEBCB1DBC3B9DDB3A9DCACA1D5998ED89088D08178CE7B71CC7D74CA776DCF8078CC7D72
CD7B72CF8378D38C7FD39081CD9484D29686C59989C49A87C2947FBB8E7AC08E7CC59482
C69582C1947EC69380C4927EC0907BC59381C49381C09785C5A090CDB0A4D7C8C2DEDDDD
E0E6E7E1E4E5DEE1E1DFE2E3DFE3E3DDE0E1DDDFE0DEE1E2DEE2E2DEE1E2DEE1E2DEE0E1
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEDFE0DEE1E2DEE2E2DEE0E1DEDFE0DEDFE0DEE0E1DEE2E2DEE1E1DEE1E2DEE1E2
DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1
DEE1E2DEE1E2DEE1E2DEE1E1DFE2E2E3E6E6E0E3E4DBDEE0D8DADBDEE2E1E6EAEAF0F4F5
AFADAF9A8E8D937D74B8A092D2B6A8DEC1B2E2C7B8E0C3B3DFC2AFDEC4B8DFC2B6DEC3B7
DEC1B5DEC3B3DFC3B3E0C2AFDEBFABDEBFAAE1C8B4EAD3C5E8CDC0E0C1B6E4C3B6E0B7AD
DDAEA6D7B9B2DBA69CD89D94D0847CD17973CA6860CB6862C86B65C36159CF736ECA6C65
CB655ECE726AD37C73D8857BD18D81D69386C5998AC29A88BE937EB78A74BB8A78C39482
C59481C49481C69380C69481C2927DC59382C49180BE9381C19684C79D8DD1B5AADDD6D4
E1E7E9E3E6E7DEE0E0DFE3E3E0E4E4DCDEDFDCDEE0DEE0E2DFE2E2DEE1E2DEE1E2DEDFE0
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE0E0DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEDFDFDEE1E2DEE2E2DEE1E1DEDFE0DEE0E0DEE0E1DEE2E2DEE1E2DEE1E2DEE1E2
DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1
DEE1E2DEE1E2DEE1E2DEE1E1DFE2E2E3E6E6E1E4E4DCDFE1D9DBDCDFE2E2E3E6E7E2E4E6
9891938C7A779A8073D0B6A3EFD3C3ECD1C1E3CABAD7B9A9DEC0ACDEC5B9DEC2B6DEC3B7
DEC1B4DEC3B1DEC0AFDEBCA9DCBBA6DEBCA7E1C6B1E9D1C3E7CBBEDFBDB2E2BCAFDEAEA4
DBA39CD2ADA7D89C94D4938CCD7A76CD706CC65F58CA6461C6645FBE5852CE706CC76560
C65953CB6760CE6E67D47771CE827AD3887EC39285C19585BC927CB78A74BA8976C29481
C59380C69583C69381C89785C39480C59483C4907EBD917EBF907CC2907CCCA596DACBC7
E0E2E3E1E4E6DDE0E0DFE3E3E0E3E4DCDEE0DCDEE0DEE0E2DFE1E2DEE1E2DEE1E2DEDFE0
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE0E0DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEDFE0DEE1E2DEE2E2DEE1E1DEDFDFDEE0E1DEE0E1DEE1E1DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DFE2E2E0E2E3E0E2E3DFE2E2E0E3E4D9DADCBCB9BB
887B7C957F78AC8F80DDC1ADF7DBCAEFD5C4E2C7B6D5B5A5DDC0ADDEC5B9DEC2B6DEC4B7
DFC1B2DFC1AEDCBAA7D9B29DDAB49FDDB9A4E0C0ACDFC2B6DFC1B4DCB5ABD9B0A3DCA69D
D99D97CD9E9AD49993D2918BCB827ECC7D7AC66E67CC7674C96F68BC625CCC7A75C56B67
BF5C56C3635DC2635DC66863C4756EC4746BBE8377BF8B7BBF8F7ABE917ABD8D78C2947E
C5917EC79483C69583CA9A88C59682C69683C58F7EBE917EBF8F7BC28C77C99C8BD4BDB4
DCD5D2DCDDE0DDDFE1DFE2E2DFE2E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEDFE0
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE0E1DEE1E2DEE1E2DEE1E1DEDFDFDEE1E1DEE0E0DEE0E1DEE1E1DEE1E2DEE1E2
DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DFE2E2DDE0E2D9DBDCDDE0E0E3E5E5E7EAEAE0E1E5CAC7CB897F81
816E6CAF968BC4A796E0C4B0EFD3C2EACFBDDFC1AFD8B6A5DEC2B1DEC4B8DEC2B5DEC4B7
E0C1AFDFBFABD9B29ED2A58FD6AC96DCB5A2DDB5A6D1AA9FD2B0A4D8ACA2CCA196D8A097
D69C96C9918DD09D97D0958FCC9592CE9997C88C86D09693CD857ABC7973C98D86C27A75
B86B62B96761B25E56B25A54B56761AF5B54B86E64BD7D6EC48A78C89983C2947BC19479
C48E7BC69482C69785CC9E8BC79883C89884C5907EC19380C1917EC4907BC79A86CDADA0
D5C3BAD4D2D6DDDEE2DEDFE0DCDFDFE1E5E4E1E5E4DFE2E2DEE0E1DEE1E2DEE1E2DEE0E1
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E1DEE1E1DEE1E2DEE0E1DEE0E1DEDFDFDEE1E2DEDFE0DEDFE0DEE0E1DEE1E1DEE1E2
DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E2
DEE1E2DEE1E2DFE1E1DFE2E3DCDFE2D3D6D6DADCDCE4E6E5ECEFEFD9D8DEB7AFB55A494A
816964CDB2A3DCBFAEDFC4B1E0C5B4E1C5B1DBB9A5DCB8A4DEC3B5DEC3B7DEC1B5DEC5B7
E0BFABDFBAA7D5A893CB9780D1A18DD9AF9DD7A69BC19087C59F92D4A398C0958AD49D94
D49E97C68883CDA39FD09C95CEABA8D1B9B7CCADA8D3B7B3D29C8DBF948DC7A298C18D87
B27E73B17068A45F559F514AA55C54994740AF5A50BA6F61C78374CF9D88C7997CC19374
C48B78C69381C79987CEA28DC99A86CA9B85C6917FC39583C39583C69683C69A86C79F8D
CEB0A2CCC6CADCDBE1DBDBDDDADBDCE3E7E6E4E8E6DFE3E1DEE0E1DEE1E1DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E1DEE1E2DEE1E2DEE0E0DEE0E1DEDFDFDEE1E2DEDFDFDEDFDFDEE0E1DEE1E1DEE1E2
DEDFDFDEE1E2DEE1E1DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E2
DEE1E2DEE0E1DEE1E1DFE2E2DDDFE1D3D6D7DBDCDDE4E6E5EAEEEEC7C4CC9D9198422C2B
8C6F67E5C9B7EDD1BFDEC2B0D5B9A9D9BAA6D7B29DDFB8A4DEC5B8DEC3B6DEC1B5DEC5B6
DFBBA5DCB29FD09F88C58C75CA9380CFA090CA8E87B3776FBC9084D19C91BA8E84D29E96
D2A199C78882CDABA8D0A39AD0BDB9D5D1CFD0C6C0D6CCC6D5AC9AC3A9A2C8B3A8C29E97
B18F82AD7B729E695D95534B9A574E8B3E38A44C43B26357C2796CCD9784C79779C09171
C48A78C59380C89C89D0A590CC9D89CB9E87C79481C69785C59987C89B89C69986C39581
C8A08EC6BABCD8D5DCD7D4D9D7D7D9E3E6E5E3E8E5DFE2E1DEE0E1DEE1E1DEE1E2DEE2E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE0E0DEE0E1DEDFE0DEE1E2DEDFDFDEDFE0DEE0E0DEE1E2DEE1E2
DEDEDFDEE1E2DEE0E1DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1
DEE1E2DEE0E0DEE1E2DEE0E1DFE1E1DDDFE1E0E2E3E1E3E4E0E3E4A8A4AB7D6D744D3331
A18377EDD1BDF1D5C4DEC2B0D2B6A5D6B4A0D6AF9ADEB6A1DFC5BADEC3B7DEC3B6DEC4B4
DDB29DD6A793CA957EC1846EBF806FBF8678B46E69AC665DB9877CCF998DBD9286D3A69D
D3A49BCB938CCFB4B0D1A89DD4C4C0D8D9D8D3CCC5D6CCC5D4AC9AC9B3ACCBBBB0C6A9A2
B6998CB1887DA47C719A6459975A4F87484197483FA55D52B46B5FC08272C08C70BE8E70
C48C7AC69481CBA08CD2A792CEA28ECDA18AC99884C79886C69988C89C8BC59785C1927D
C59884C3B0ADD2CDD1D0CCD3D5D3D7DEDFE0DEE1E2DFE2E2DEE1E2DEE1E2DEE1E2DEE2E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE2E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E1DEE1E2DEE0E0DEE0E0DEE0E1DEE1E2DEDFE0DEE0E1DEE0E0DEE1E2DEE1E2
DEDEDFDEE1E2DEE0E0DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1
DEE1E1DDDFDFDEE1E2DDDEDFE1E2E1E9EBEEE6E9EADBDDE0CFD1D3827C825E4C51735753
BD9F90E8CDB9EACFBEE0C3B0D7BAA7D7B29ED7B09CDBB39FDFC4B9DEC4B7DFC5B8DFC2B2
D9A795CE9A86C48E75BF816CB56D5EAD695D9C4E49A95C52BD857AD09A8DC79C8FD6B0A8
D4A79CD2A69FD4BBB7D3AA9ED8C3BDDBD5D5D5C4BCD5BCB3D1A091CFB2ACD0BAB1CDAFA6
C09C90BA9487B2958BA97D719A64568E5E56894C44975C52A05C51AB6458B57963BC8A6F
C58F7DC69582CEA38ED4A894D1A894CEA38ECB9C87C69785C59886C69A89C59482C2947F
C49682C3A99FCAC2C3C8C2CCD2CED5D6D5D7D7D7DCDEE0E3E0E3E4DFE2E2DEE1E2DEE2E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE2E2DEE0E0DEE1E2DEE0E0DEE0E0DEE1E2DEE1E2DEE0E0DEE1E1DEE0E1DEE2E2DEE1E2
DEDFDFDEE1E2DEDFE0DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDFE0
DEE1E1DDDEDEDEE1E2DCDCDEE2E2E0F2F3F7E7E9EAD0D2D7B9B8BD5D5559493437A1857F
D9BCA9E0C5B1E0C5B5E1C3AFDDBFAADAB29FDAB39FD9B09DDFC3B8DEC4B8DFC6B9DEBFAF
D49D8DC68D79BF876EBF816EAD61549E5348893731AC5B50C3877DD29E90D2A99AD9BCB3
D7AA9FD9BBB2D8C2BCD5AB9EDBBEB6DDCACBD6B6ACD3A79CCD9286D5ADA7D5B4ADD2B0A6
CA9B91C49D90C3ACA3BB9788A1706099786E80554D8B5E558D504494453CA86555B8846F
C3907EC69683D0A68FD6A996D4AD99D0A591CDA08AC69784C39683C49785C4907FC49885
C59683C4A393C3B6B3C0B8C4CDC7D0CECACED0CDD6DCDEE3E1E4E5DFE2E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE2E2DEDFE0DEE1E2DEE0E1DEE0E1DEE2E2DEE1E2DEE0E1DEE2E2DEE0E1DEE1E2DEE1E2
DEDFE0DEE1E2DEDFE0DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDFE0
DEE1E1DCDDDEDEE1E2DDDCDEE1E1DFEEEEF2D7D8D8BBBAC09F989D403536493131C8ACA3
ECD0BCD9BDAAD8BCACE0C0ACE1C1ABDCB2A0DCB6A3D7AF9CDFC2B5DEC3B7DFC6B8DEBCAC
D19586C0836FBD846AC28675AD63589B504585362FB36658CA8E84D4A495DBB4A3DCC3B9
D8AEA2DEC9BFDCC5BED6AD9EDEB7AEDFBEBED6A99ED1978ACB887ED9A6A0D8ACA5D5ACA1
D1978ECCA093CFB9B0C8A695A97A69A78D81815F5687635A82493C802E289B5246B37C6A
BF8B7BC69682D1A68ED7AA98D6B09DD1A895CFA38DC69684C39481C29582C38E7EC69A89
C69785C69E8ABEADA5B9B0BBC6BDC6C8C1C6CBC5D1D9D9E1E0E3E4DFE2E2DEE1E2DEE1E1
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDFDFDEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEDFE0DEE1E2DEE0E1DEE0E1DEE2E2DEE1E2DEE1E1DEE2E2DEE0E1DEE0E1DEE1E2
DEE0E0DEE1E2DEE0E0DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDFE0
DEE1E2DDDEDFDEE1E2DEE0E0DDDDDED7D5DBB2AEAE999399807376312121644945DCBEB4
F1D6C0D7BAA8D6B9A8DDBDA8E1BEA9DCB2A1DCB7A4D6AE9CDEC1B2DEC1B5DEC3B4DCB9A8
CE9283BD7E69BD846BC78F80B87A6EA8685E97534ABF7C6ED1998FD6AA9CDEB7A7DDC4B9
D9B3A6E0CCC2DDC4BCD8AEA0DFB2A9DFB6B2D5A296D19385CC877DD9A29AD7A29AD4A497
D39289CE9A8ED3B5ABCCA392B27E6EB496888F685F8F695F83493D7322208F433BAA7061
B87F70C4927FD0A38BD7AC9AD7B19ED4AA98D0A58EC69784C39481C19580C28E7DC69988
C79785C79B85BFA79BB4A8B1BCB0B7C6BCC1C8C2CED3D0D9DDDFDFDEE1E2DEE1E2DEE1E1
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE0E1DEE0E0DEE1E2DEE1E1DEE1E1DEE2E2DEE1E2DEE1E2DEE1E2DEE1E1DEDFDFDEE1E2
DEE0E1DEE1E2DEE0E1DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E0
DEE2E3DDDFE0DFE1E1E1E5E4D6D7DEB5B1B883797775676B644E4F301B1A92746CDFBFB4
EBD1BBDBBBAAD9BAA8DABAA5DEB9A6DBB3A1DCB6A3D5AF9CDDC0AEDEBEB2DDBFAFDBB7A5
CD9382BC7D67C0866FCD9A8CC99D90C09287B68479CD998AD7A59BD8B2A4DDB7A8DCC0B5
DAB7AADEC7BCDCC1B6D9AFA3DEAFA5DFB0A9D4A194D29889CE8F83D79F94D4988DD0998B
D28B82CC9084D0A699C79484BA7E6FBE9685A470659F71658E50456D2323873932A16355
AE6E61C18E7BCD9E87D7AD9CD8B09DD6AC9AD0A68EC69885C59582C0957FC08F7CC69484
C79583C69984C2A393B0A3A8AF9FA3C5B9BDC8C3CCCCC7D0D9D8D9DDE0E0DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE0E0DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEDDDEDEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DFE1E1
DEE3E3DEE1E1DFE1E0E3E9E7CFCFDB948E945B4A465844455233323C211FC3A298DBBAAE
E0C6B0DFBCACDEBDA9D8B8A3DCB4A3DAB4A3DBB6A3D5B19DDDC0ABDEBBAEDDBBAAD9B5A3
CD9683BE7F6AC48A74D3A497DAC0B0DABDB1D8B7AADBB6A8DDB3A8DBB9ACDBB5A7DCBBAE
DABBAEDCBFB2DBBCB0DAB1A7DDADA3DEACA0D3A193D2A08FD1988AD49D8FD19082CB8E7F
CE857BC88479CA9383C08272C17C70C7917EBA776BB0786B9D5A506E2D2D83363099594B
A65F54BE8977CA9983D6AE9DD7AE9BD8AD9BCFA58EC69885C69683C0957FBE907CC5907F
C79381C69885C6A08EAE9F9F9E8C8CC2B5B9CAC5CBC8C1C9D6D3D4DDDFE0DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEDFE0DEE1E1DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E1DEE1E2DEDDDEDEE1E2
DEE2E2DEE1E2DEE2E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DFE1E2
DEE3E3DFE2E3DFE2E1E2E8E7C9C7D481777B4D373154393754302B553631E6C5B9D6B6A8
D7BBA7E1BDADE1C0AAD7B7A3DBB3A3DAB7A6DAB7A4D6B3A0DCC0AADEBAADDCB8A7D8B4A2
CE9B86C18570C78E79D6A99BE4D3C2EBDACCEFDBCDE5CCBFE0BEB3DCC0B3D9B5A8DBB8AB
DABEB1DAB8ABDABAADDBB4AADCADA2DCA99AD2A293D2A694D39F8FD19C8BCD8C7AC78877
CA8376C47D71C38472BA7565C47C70CB8C77CA7D6FBE7F6FAB665B783D3B863D35985648
A2574CBC8573C7947FD4AD9BD6AB99D8AC9ACFA38DC69785C69683C0957EBD907BC48D7A
C69280C59887C99E8AAD9C9A887573BCAEB1CEC9CDCAC2C9D6D3D4DDDFE0DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEDFE0DEE1E2DEE1E2DEE1E2DEE2E2DEE1E1DEE1E2DEE1E2DEE1E1DEE1E2DEDEDEDEE1E2
DEE2E2DEE1E2DEE2E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E2
DEE1E2DFE3E3DFE2E2DEE1E2C6BEC8847473654D4370534B724C4379594FF0D2C5D6B7A6
D4B7A3E1BCADE2C0ABD7B8A5DBB5A7DBBBABDBB9A7D8B8A6DCC1ABDEBCADDCB9A8D8B4A2
D09F8BC78D79C9907CD4A495E3CEBCEEDECEF5E5D6E8D6C9E2C6BBDEC5B9DAB9ADDCB9AC
DBBFB3DAB8AADABCADDCB7ADDCAFA1DAA897D2A292D1A592D3A290CF9D8BCC8D7AC68A77
C88676C37E70BE806BB87564C37E70C98873CC8272C28371B3726489544C934D439E5E4E
A45C4EBB8371C5907CD1A894D5A996D6AA97CDA18BC69583C49381BF937DBD9079C28E79
C6927FC59887C89B87AD9C986D5C5BB1A3A6D4CFD2D3CFD3DBDBDBDFE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE0E0DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E2DEDFE0DEE1E2
DEE2E2DEE1E2DEE2E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE2E2
DEDFE0DFE2E3DDE1E4D7D5DAC6B6B998817B987E72A28376A07B6FA28274E5CDBFD9BBA9
D6B8A5E0BBACE0C0AAD9BBA9DDBBADDDBFB0DDBCACDBBDADDDC2AFDFBFAFDDBCACD9B5A4
D3A392CD9683CA927ED09A89DAB8A4E5CDBBECD9C8E6D4C8E1CBBFDEC8BCDCC1B4DDBDB0
DDC0B5DCBCADDCC1B1DDBCB0DCB3A3D8A997D2A391D0A18DD2A08FCFA08CCC937EC7907C
C68D79C38574BB846EB97D6BBF8171C38771C58472BF8572B77D6CA06C5DA46557A96D5A
AA6A57BB8371C48E7ACEA38CD3A794D3A693CC9F89C69280C2907EBF907CBD8F78C19079
C49280C59987C59885AD9C99504445A19597D9D4D6E1E0E2E3E5E6E0E4E4DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE0E1DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E2DEE1E1DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE2E3DEE2E3
DEDDDEDEE1E2DCE0E4D1CAD1C8B1ABB39689CFB4A5D6B7A5D0AD9ECAAB97D3C0B3DCBFAB
DAB9A8DEBBACDEBFABDCBEAEDEC1B3DEC4B5DEBFB1DEC2B4DEC5B3DFC3B3DEC0B0DAB7A6
D6A799D3A08FCA9580CA8F7CCE9D88D8B5A2DEC3B2E2CCC0DFCDBFDFCABDDFC8BBDEC2B6
DEC0B5DEC1B2DEC6B6DEC1B3DCB8A6D7AC99D3A491CE9C88D09E8DD0A38FCC9A84C99984
C6957DC38E79B98B74BA8775BA8471BB856FBA8572BA8671B98671B6836DB77D6BB67F69
B37A64BC8573C48E7ACB9D84D0A591D0A28ECB9C88C58F7DBF8D7CBF8D7BBE8E77C0937A
C39380C59986C19683AD9B99372E33908486D9D3D6ECF0EFE9EFEFE2E6E6DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E1DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E2DEE2E3DEE1E2
DEE1E1DEE1E2DEE1E1DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E3DEE1E2
DEDEDEDEE1E2DCDEE0CFC2C9CCB1A4CBAC9BF6DAC9FADAC4F1CFBDE5C7B1C5B4A7DDC2AC
DDBBAADDBCACDDC0ACDEC1B2DFC6B8DFC7B9DFC2B6E0C6BADFC7B7DFC6B6DEC4B5DCBAA9
D9AC9FD7A998CC9884C78A75C58873CDA08BD1AE9CDDC2B6DECBBEDFCABDE0CCC0DFC6B9
DFC0B5E0C5B5DFCAB9DFC5B6DDBEAAD7B19FD4A793CE9B86CF9D8CCFA592CC9F89CA9E89
C49A80C2947EB79078BB8E7BB58671B4846EB28570B68670BA8B74C59377C48E79C08C75
BB896FBE8976C5907CC99A80CEA28FCD9E89CA9A86C58D7CBE8B7ABF8C7BBF8D76BF957C
C19380C49885BE9483AB9896261F257B7073CEC9CCEEF4F3E9F0F0E2E5E5DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E3DEE1E2
DEE1E1DEE1E2DEE1E1DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DDDBD9D1C2C4D3B9A8DBBEACFEDFCCFFDCC5F6D3BFEFD0BAC3AFA3DEC3AD
DFBAABDDBEACDDC1AFDFC4B5E0C8BBDFC8BBDFC5B9E0CABEDEC8BBDEC8B8DEC6B8DDBDAD
DAB0A3D8AF9DD09E8BC98D78C4836EC8947FCCA08DD9BBAEDDC8BBDFC9BCE0CDC0DFC6B9
E0C0B5E0C6B5DFCABADFC8B9DEC2AFD9B7A5D5AA97D09D8ACF9E8DCEA592CB9F8AC99E89
C29980C1947EB78E78BA8D7CB48570B2836EAF8470B6866DBB8B74C9967AC7937DC4937A
C09177C2907CC89480C99B81CC9E8CCB9A86C89785C48D7CBE8B7ABE8C7ABF8C77BF957D
C0937FC29683BE9583A6918E1F181F64595FB6B1B5E4E9E9E2E6E6DFE2E3DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE2E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DFE1E2DFE1E2DFE1E2DEE1E2DEE2E2DEE1E0DFE1E1
DFE6E6DEE1E2DED6CED8C7C1DBC5B1E1C9B8EDCAB6EEC6AFE7C0ACE9C9B6CAB1A5DEC2AD
DEB9AADEC0ACDEC2B3DFC5B8DFC9BCDFC9BCDFC8BBDFCCC1DEC9BDDEC9BADEC7BADDC0B0
DBB4A6D7B4A0D5A493CD9782C78B76C8927DCD9987D7B7A7DDC4B7DFC7BBDFCBBEDFC5B7
DFC0B5E0C4B4DEC7B7DFCABBDEC5B4DCBCAAD6AD9BD3A290CFA18FCCA391C99B87C79A86
BF957EBF907BB78975B98777B4846EB2826EB2846FB8876CBC8773C59076C48F79C3937A
C3937CC79783CB9A85CC9E86CB9B89CA9884C79683C48F7DBF8D7CBE8C7ABE8B78BF937D
C0937DC09481BF96849F888123191F4F444C969397D1D2D5D5D4D5DBDDDEDEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E0DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DFE1E2DFE2E2DFE2E2DFE1E2DEE1E1DEE2E3DFE0E0E0E1E0
DFE9EADFE0E0DFD0C2DECBBDE2CEBAE3CFC0D4AC98D4A792D1A792DDBBABD4B4A8DEC2AE
DEB8A9DEC2ADDFC3B6DFC6B9DFC9BCDFC9BCDEC9BDDECCC2DDCABEDDC9BBDDC8BADDC2B3
DBB7A9D6B6A0D9AB9BD2A38FCD9882CB9480CF9784D5B3A2DDBFB4DFC5B9DEC8BBDFC2B4
DFC0B4DFC2B3DDC4B5DFCBBCDEC7B8DFC0AFD6AF9ED5A696D0A290CA9F8EC79583C49480
BD8F7BBD8A77B88471B78171B5816DB4826EB7836FBC886ABD8372BE8872BE8974C19179
C6947FCB9F8BCE9F8BCEA28CC99886CA9683C69583C4917FC0907EBE8E7BBE8B7AC0917E
BF937DBF9280C198859A7F7531222542353D797478BAB6BCC7C0C2D7D8D9DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDFE0DEE1E1DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DFE1E2DFE2E2DFE2E2DFE1E2DEE1E1DEE2E3DFE1E0E0E1E0
DFE8E8DEDBD8DFC8B5E2C9B5E4CEBBE0CBBDBF927EBF8F7CBF9581D3AFA2DCB7ABDFC2AE
DEB9AADFC3AEDFC3B7DFC7BBDEC8BCDECABDDECBBFDDCDC3DDCBBFDDC9BDDDC8BCDEC4B6
DBBBABD5B8A2DDB1A2D8AD9AD2A38ECE9885D29885D5B09EDDBCB1DEC4B7DEC5B9DEC0B0
DEBFB2DEC1B1DDC1B2DECABCDEC6B8E0C1B0D6B09FD6A899CFA18FC79B8BC4907FC18E7C
BB8A79BC8674BA806FB77C6EB67F6BB4816CBA816EBE886ABE8172B98270BB8572C1917A
C99683CFA491D0A38FD0A591C89785CB9583C69582C59381C2927FBF8F7BBD8C7CC08F7F
C0927CBE9280C39B879A7A6D483230443138675E5FA39BA2BAB1B4D3D2D4DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDFE0DEE1E1DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DFE2E3
DFE0E0DDD1CADEBDA8E0BEA9DFC0AED9BDAFB78672B98977BB9582D1ADA0E0B9ACDFC2AE
DEBBABDFC3AFDFC2B6DEC8BBDEC9BCDECBC0DECCC0DDCEC5DECCC1DEC9BEDECABEDFC5B8
DEC0AFD8BAA5DEB8A8DCB1A2D5AA96D19C8AD39D89D5AF9DDEBBAFDEC3B7DEC4B7DDBEAD
DDBDAFDDC0B0DDC1B2DEC7BADDC2B5E0BEAED5AF9ED4A697CC9E8BC59787C28D7DBF8B7A
BB8978BB8473BB816FB87C6DB47D69B17E68B97E6BBE876CBF8375BB8675BE8A77C49680
CC9B89D2A795D0A591D0A693C89886CB9785C69583C59482C49380C0907CBE8E7DC08E7E
C0927DBF9481C49D8AA17B6B674940593C3D69545190868BB1A9ACCFCBCEDEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E0DEE1E1DEE1E2
DEE1E2DEE1E2DEE1E2DFE1E2DEE1E1DEE0E1DEE0E1DEE1E1DEE1E2DEE0E0DEE2E4DCE3E5
DED4D3DBC5B7DAB19DDAAD99D5A898D1A898BA8572BF907FC3A391D6B2A3DFB9ACDFC2AD
DEBDACDEC3B1DEC1B4DEC8BCDEC9BDDECDC3DECDC2DFCFC6E0CDC3E0CBBFE0CCC0E1C6BA
E1C5B2DEBDAADFBDABE0B1A6D6AC99D3A090D4A590D7AF9EDEBDAFDEC4B7DEC4B7DCBCAB
DBBAABDDC0B0DEC2B2DEC3B6DCBCAFDDB8A9D4AE9BD0A291C99886C29283C08C7DBD8B79
BB8A78BB8473BB8470B9806EB17C66AD7963B67B68BE866FC0897AC19080C59483CA9D89
D0A18FD2A796CFA591D0A592C79A87CB9986C79684C69583C59381C3917EBE917EC08E7D
C1927EC09784C4A08DAC806D8962517B524A7A574D837779ADA9ABCDC6C9DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E1DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DFE1E2DEE0E1DDDFE0DDDFE0DEE0E1DEE1E2DEDFDEDEE2E6DAE1E4
DDC7C5DAB9A6D7A694D39B89CA8E81C6917FC08976C99B8BCEB5A3DCB9A9DEBBADDEC2AD
DEC0AEDEC2B2DEC1B2DDC8BCDECABEDECEC5DFCEC3E0D0C7E1CEC3E2CBC0E2CDC1E2C5BA
E4C8B5E3BFAEDEC0ADE2B0A8D7AE9BD6A696D6AF9AD9B1A1DEC0B1DEC5B8DFC4B7DABCA9
DAB8A9DCC0B0DEC4B3DDC0B3DBB6A8DAB2A3D3AB97CB9D8BC59180BF8E7FBE8C7CBB8A78
BC8C78BA8573BB8871BA8470AF7B65AA775FB47967BE8674C29180C99B8BCEA08FCFA491
D3A694D2A696CDA390CEA390C79D89CB9B88C89784C69583C59281C5927FBF937EC08E7C
C2917FC29A87C4A290B88670A97A62A16C5B9161517D6E6CADACAECCC4C6DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E1DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DFE1E2DEE1E1DDDFE0DDDFE0DDE0E1DEE1E2DEE0DFDEE2E5DADDDF
DEBDB9DBB29CD49D8DCF8E7DC17A6EBE7F6CC58E7BD1A595D7C2B1E1C0AEDEBDAFDEC2AD
DEC3B0DEC2B5DEC1B2DEC8BCDECABEDFCEC5E0CDC2E1CFC5E1CDC1E2CABDE2CBBFE2C3B8
E3C8B5E4BEB0DDC0ACE1AEA7D7AF9DD8AB9DD7B6A1DBB4A5DEC2B2DEC5B9DFC4B7DABCA9
DAB8A9DCC1B0DFC5B4DDBDB0DAB2A4D8AC9DD1A892C89986C28D7CBB8C7CBC8B7AB98977
BB8C78B98673BA8A73BB8873AF7D66AB7860B57C6AC08A7AC59886D0A594D4A998D3A997
D6AB98D2A696CDA28FCDA28FC89F8ACA9C89C89785C69583C69181C59180C0947EBF8D7B
C2917FC39B89C5A493C08A73C18B6FBE836BA8705C816D66B2B3B4CEC8CADEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E1DEE1E2DFE2E2DFE2E2DDD6D4
DFBAB3DFB39DD39789CE8878BE7366B97764C69280D5AA9ADAC5B3E2C2B0DEBFB0DEC2AE
DEC6B5DEC3B7DEC3B4DEC8BCDFCABDDFCCC1DFCABEDFCBBFDFC9BCDFC5B7DEC5B7DEBEB2
DEC2B0DFB9ACD9BBA9DDACA3D7AF9ED8AFA1D6B8A4DBB7A8DEC2B2DEC5B8DFC4B6DBBEAC
DBBAABDDC1B2DFC5B5DDBCAEDAB2A3D6A999D1A48FC79783C08B7AB88A7AB98878B78674
B88975B68674B98A73BC8A75B3816BB27E67BC8573C59182C99E8CD5AA98D7AD9CD4AB99
D7AD9AD3A695CEA28FCEA18EC9A08BCA9C89C89684C69582C58F80C49080C0947EBF8D7B
C1907EC49988C6A596C28B74CB9176CC9277B9826C907369BBBCBCD4D3D6DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E1DFE2E3E0E4E4E1E4E4DFE2E2DFE1E1DEE4E7DFE0DCE1CBC5
E1BBAFE2B6A5D29486CF8776BD7465B77865C59683D5AB9BD9C1AEE0C2B1DEC1B1DEC2B1
DFC9BADFC5BADFC6B9E0C8BBDFC9BCDFC8BBDEC6B9DCC5B6DBC3B4D9C0AFD8BDADDAB7AA
D7B9A9D5B2A5D4B3A3D6AA9DD6AF9ED7B1A3D4B5A3DBB9AADDC0B2DFC4B7DEC4B4DCC0AF
DCBDB0DDC1B3DFC4B6DDBDADDBB5A5D6A998D0A08CC79783BF8B7AB48979B68575B58371
B58672B28574B78974BD8C77B98771BB8973C69281CB9A8ACDA290D7AB98D7AE9CD4AB99
D8AE9BD4A795D0A38FCFA18FCBA08BC99A87C79583C49481C48E7FC28D7FBF917EBF8C7C
C08F7CC49685C8A598C08873CB9078CC987DC2937DA67E71C8C4C4DBE2E5DFE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DDE0E1E0E3E4E2E6E7E3E7E7E1E3E4E0E1E1DEE4E8DFDAD2E2BEB2
E0BAABE2B9ABCF9183CD8776BB7866B67C6AC49B88D5AC9BD8BCA8DDC1B1DEC2B1DEC2B3
E0CBBFDFC7BCDFC8BDE1C8BBDFC7BADEC4B5DCC2B3D9BFAED6BDACD4BAA8D2B5A4D5B1A2
CFB0A2CCAB9ED0AB9ECFA997D5AD9DD6B1A3D2B1A0DABAABDDBEB1DFC3B6DEC4B3DEC3B3
DEC1B5DEC2B5DEC2B6DDBEADDCB8A7D6A997D09D8AC79783BF8C7AB28979B38372B4816E
B28270AF8575B68875BD8D79C08D78C5947FCF9E8DD2A391D1A593D7AA97D6AD99D2AA97
D8AE9BD4A894D3A390D0A190CD9F8BC89886C69381C39380C28D7DBF8B7FBF8E7EBF8C7C
BE8F7BC39282C9A49ABB8471C48875C6997FC8A08CBC897BD3C8C7E2EDF0DFE2E2DFE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE0E1E0E3E3E2E6E7E3E7E7E1E4E4DFE1E1DEE2E5DDCFC3DEAD9E
DAB3A1DCB4A9C78B7DC48272B57966B27E6DC5A08DD6AF9DD7B9A4DCC1B1DEC3B2DFC2B6
E0CBC0DFC8BCDFC9BEE0C7BADFC5B8DEC1B1DCC0B0D9BDABD5BAA8D3B8A4D2B2A0D5AF9F
CEAC9ECCAB9DD1A89CCEAB96D5AD9BD5B1A2D2B09FDABDACDDBEB2DFC3B5DEC4B3DFC5B5
DFC4B8DFC2B6DEC1B6DDBFADDCBAA9D6A997CF9A88C79682BE8C7BB18978B28170B4806D
B0816FAE8676B68776BD8D7AC3917DCB9B88D3A494D4A895D2A695D5A794D4AA96D0A894
D5AB98D3A792D3A28FCFA08FCD9D8AC79684C49281C2927FC18D7DBD8A7EBF8C7DBF8B7D
BD8E7BC19181C8A299B47F6DBB7F6FBD957DC8A692CD9182D8C5C0E5EEEFDFE2E2DFE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DFE2E2DFE2E3DEE1E2DEDCDBD9BDADD19A89
D0A591CEA59ABA8172B27869A77261AA7B6BC7A491D8B3A1D9BAA6DBC0B2DEC3B3DFC2B6
DFC7BCDEC6BADEC8BCDFC5B8DFC4B6DFC2B2DEC2B1DEC2AFD9BCAAD8BBA7D9B9A6DBB4A3
D7B1A1D8B5A4D7AC9FD5B19CD8AD9BD7B2A2D7B5A4DBC2B0DEC2B4DFC3B5DEC4B4E0C5B5
E0C4B8DFC2B7DEC1B4DEC0ADDBB9A8D5A997CE9887C59380BE8C7BB38977B2816FB5826F
B28271B08676B78777BC8D7AC2917FCB9C8BCDA192D0A694CFA493D0A28FD1A693CDA491
CFA593CEA38ECF9F8CCD9C8BCA9A88C59482C39381C1917FC08E7EBD8B7DBF8B7DBE8C7D
BD8E7CBE9385C59F96AD7867B47767B78E77C4A08ED19382D5B7ADE1DEDDDEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2E0E3E3DCDEDFD9DBDBD9DADBDCDFE0DCE1E3DFD4CBD4A896C08876
C0907CB98E82A774649A695C9467589F7465CAA794DAB9A6DCBEACDCC0B2DEC3B4DEC2B6
DCC2B6DEC4B6DDC4B7DCC3B6DEC3B4DFC5B6E1C5B5E5C9B6DFC1AEE1C1ADE3C2B1E4BCAA
E3BAA7E9C2AFE0B3A5DFB8A4DAAE9BDAB3A1DDBDAADEC7B3DFC6B6DEC4B5DFC4B6DFC4B2
DFC4B6DFC2B7DEC1B3DEC0ACD9B5A5D3A997CC9886C28E7CBD8A7BB78875B4826FB78572
B58673B38777B88679BB8C7ABD8F7EC59989C29688C89F8FC9A08FC99D8ACDA290CBA18E
C79C8CC89C89CA9A88C99786C59785C39281C29481C19180C0907FBF8D7DBF8C7BBD8D7D
BE8D7EBB978AC19C91A67160B0715EB38570BD9280CC8E7CCCA191D9C4BFDEE0E1DEE1E1
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEDFE0DEE1E2DEE1E2DEE1E1DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2E1E4E5DBDDDDD5D6D6D3D4D5D9DBDDDCDFE2DEC8B8CF9581B07967
AE79669F736692645580584E80594F916C5ECDA896DCBEAADEC2B2DCC0B1DFC3B4DEC1B5
DABDAFDDC2B3DCC1B1D9C1B3DCC0B1DEC5B9E2C6B6E8CDBAE2C3B1E7C5B2E9C8B8E9C0AF
EBBFAAF3CAB5E5B7A7E6BBA9DBAE9ADBB19FE1C2ADDEC7B1DFC7B5DEC4B4E0C4B7DEC2B0
DEC2B4DFC2B6DEC2B1DEC0ACD8B2A2D2A897CB9885C08A78BB887ABA8772B58370B88775
B88875B58876BA877ABA8C7AB88D7DBF9384B68B7DC09789C29B8AC29785C99D8DC89D8B
C09586C29685C49685C69382C19582C19281C19582C09181C09281C08F7DBF8D7BBC8D7C
BF8D80B99B8FBD998CA06B5AAB6B55AF7A66B3806EC18472C18B74D0A79EDDE0E0DEE1E1
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEDFDFDEE1E2DEE1E2DEE1E1DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2E1E4E4DCDEDED6D7D7D4D6D6DADDDEDCDDDEDBB8A2CC8975A67160
99635182574A7B54466948416E4E47846256CFAA97DDC2ADDFC4B6DCBFB0DEC2B3DEC1B3
DABCABDDC1B1DBBEACD6BEAFD9BBABD8BFB3DBBFAFDFC3B2DCBCAAE2BEAFE1C0B2E1BAAA
E3B8A5E8BFABDDAF9FDFB2A2D5A895D6A998DCBAA5D8BDA7DBC1ADDCC2B0E0C2B6DEC1AE
DEC1B2DEC2B6DEC2B1DFC1ACD6AF9FD1A796C99784BD8774BA8578BB8570B5826EB78775
B78874B68876BC897CBA8C7BB88E7DBC9081B48879BE9385C09987BF9684C79B8BC89C8A
BE9183C19584C39584C59381C09583C19382C09783C09181BF9481C1917CBE8D7ABB8E7C
BF8D82B89D92BB96889C6958A6664EAA6E5BA96E5DB67765B7785EC89085DDE0E0DEE1E1
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DFE1E2DFE2E2DFE1E2DFE2E3E1E4E5DFD9D6D4A18ACB8775A47262
834F41613D3464433A583C38614540765950D1AC99DEC4B0DFC4B6DBBFAEDDC0B0DEC2B2
DCBFAEDEC1B0DCBEAAD2B9A9D3B2A1CCAFA3CBAB9BC6A798C8A797CFAB9FC4A598C9A497
C49E92BF9B8DC4978AC6978AC69C8BCA9B8BCBA38FCAA692D2B39EDABCA9DEC1B4DEC1AF
DEC1B2DEC2B5DEC2B1DFC1ADD6AE9FD1A795C89583BC8671B88374B8826DB3806BB28270
B2826FB58876BE8C7EBE8F7CBF9481C09280C09180C69786C49B88C49987C99C8BCB9E8B
C49586C69A87C89A88C99886C39A88C49786C09785BF9182BD9380BF917CBC8E7ABA8D7B
BF8E83B89D91BB96869A6B5A9F624BA56351A26050AE6856B26E54C48779DEE1E1DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DBDDDEE3E6E7E9EFF0EDF2F3E8ECECE1D3CACB8973CC8D7EAA7A6B
6D3F364226234E34304C3331583F3B6B524BD3AF9CDFC5B2DEC3B3DBBEACDCBEACDFC2B1
E0C5B3DEC3B1DCBEAACFB5A3CCA896BE9B8CB79282A48275AE8B7EB38F899B7D74A6867B
997A77856862A0766BA17467B38B7DB9887BB48372B98977C69F8AD7B5A1DCBFB0DEC1B2
DEC1B3DEC2B4DEC3B3DFC1AED6AF9FD1A694C79381BC876FB68170B27F6AAE7C66AC7B67
AA7A68B28775BF9180C2937FC99C88C79682D2A28CD29F8ACB9F8ACC9F8DCD9E8CCFA08C
CC9C8BCDA28CCFA18CCF9F8EC9A18EC79C8BC09786BE9282BB917DBC8F7CB98E7AB88D7B
BE8F83BA9A8CBD96849A6F5F985E4BA059489E5747A85948B26C54C38678E0E3E4DFE2E2
DFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE2E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2D8D9DBE5E9EAF1F8FAF5FCFCE9ECEAE2CABBC27560CD968AB28476
5B342E2814183B2829432B2C513936624C48D4B29EDFC5B3DEC1B0DABEAADABCA8DFC2AF
E3CAB8DFC4B2DDBFABCEB19EC7A08DB28A79A57C6C866055977367997674765951866961
6F585D4D38387D564E7D5145A07B70A9766C9E6455A96E5EBC8C77D4AE99DABDABDFC2B5
DEC2B5DEC2B5DEC3B6DFC2B0D6B1A0D1A592C5917FBD886EB4806CAC7C68AA7862A6745F
A2715FAD8573BF9481C69783D1A38CCC9882DEAD95D9A28BCF9F89D0A28FCD9E8BD0A08C
D1A08ED2A78ED4A68FD2A594CEA593CA9F8EBF9786BC9281B98F7BB98E7BB68E7AB78C7B
BD9182BC9687BE95829A7363905C4B9A5141995142A64F3EB46F5AC3897BE2E6E6E0E3E3
DFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE2E2DEE1E2DEE1E2DEE2E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2D9DADBE5E9EAEDF4F5EDF2F2DAD9D6E0BFABBE6B58CF9F93BC8D80
502F2C190C142E1F253C26284B34325E4946D5B5A1DFC4B3DCC0ADDABEA9D9BBA6DDC0AC
E3CAB9DEC3B2DDC0ABCFB19EC7A08DB08673A076657B53488E695E8D6B6A64463F755A52
58444E2C1B2068433D673C309571679E6B63915345A15F50B6816CD2A893D9BBA7DFC3B7
DFC3B7DEC4B7DEC5BADFC2B1D7B2A1D1A592C5907EBD886DB37F68A77A65A77660A26F59
9B6857A57F6EBC9582C69987CDA18BC6947FD4A58ECE9982C69581C79B89C69987C79986
CA9B89CDA38ACFA38CCDA392CCA491C89E8CBE9484BB9180B78D79B78D7BB38E7AB68B7A
BC9181BE9383BC927F97726489594C934D3E944D3FA74E3DB87663C28A7BE3E6E6DFE3E3
DFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E1DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2E1E5E5DBDDDECECCCDB6ADAADBB19CC2715DD3A396C59385
50302F190F172A1D24352225452F2D624C48D6B6A2DEC1B1DBBEABD9BEA8D9BBA6DBBBA7
DFC3B2DDC2B0DDC0ACD5B7A4CEAB98BC9581AC85748C65589C766A9575706E50487B6057
5E4950301F236A463E683E319571669E6A61935748A66252B9826ED1A690D8BAA5DFC3B5
DFC5B9DFC8BCDEC9BFDEC2B2D7B4A2D2A793C5917FBD876DB37E66A57863A87761A06E58
9562519B7463B59181C1998AB99281B28676AA8171A97E6DAC7D6DAE8577B48C7DB38878
B28979BB937CBD9481BD9686C29A85C09683BC907EB98F7CB68B78B68D7BB28E7BB58B7A
BA8F7FBE9280B68D7A8E6B5D8154498B4D3F8C4C3EAD5948BC7E6BBF8574E0E3E4DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE0E0DEE1E2DEE1E2DEE0E0DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2E6EBEAD9DBDBBEB8B9A0959785726FD1A18CC97F6AD4A291CA9483
5636362219212B1E262F2022402A2A69524CD7B8A4DDBFADDABDAAD9BDA8DABDA9D7B5A1
D7B8A6DCBEADDCBFACDCC0AED9BBABD1B09CC5A391AF8A7BB79284AC8C828E6D63927569
795F5F4F3C3A7D594C794F429D776AA57265A06958B37361C18D78D1A791D8B9A5DEC2B2
DEC7BBDFCCC2DECCC3DDC2B2D7B5A2D3A996C69381BE866FB37E66A67861AA7A64A16F5A
935E4D916756AC897FB7978D9B7D7396736A6F4E47775850895E548B685E9D7A6F987267
906F63A17B68A37F70A68373B28A74B58976B98B77B88C79B68A77B78D7AB28D7BB58B7A
B98C7DBE917FAC8472835E537A4F46814E43844B3EB66C5BC08570BC7B69DDDFDFDDDFE0
DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEDEDFDEE1E2DEE1E2DEDFE0DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2ECF2F0CBCAC99C8E8F6F5C5E533835C18E7CCB8C76CF9B87C78E7C
5D3D3C30262B2F22292B1F213B2627725951D7B8A4DCBCAAD9BDA9D8BCA8DBBEACD4B09C
D0AC9BDABAA9DABDABE2C7B7E4CBBCE5CAB8DEC2AFD5B3A1D4AF9FC5A695B28F82AD8D7E
997970785F5895705F906658A87E6FAE7B6BB1806CC28973CB9B86D1AA94D8B9A5DEC2AF
DEC9BCDFCFC7DFCFC5DDC2B2D7B5A2D4AB98C79683BE8571B37F66A87760AC7C67A3715D
925C4B895C4BA4827CAE948E8069657C6260371E2149363668423E6A4B468568627F5D56
70564E8764558B6A5F917160A37A64AA7D69B68770B78A75B68978B88E7AB28D7BB58B7A
B8897BBA8F7D9F7969755047714941754F477C4D40C08170C38A74B9725EDADBDBDCDEDF
DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E2DEE1E2DEE1E2
DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEDDDEDEE1E2DEE1E2DEDFDFDEDFDFDEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2EAEFEEB4AEAC7B67674A30322F0E0CA97767C08B77BF8C78B77F6F
5D3F3F392F3232242B281E20392426795E54D8B9A5DCBAA7D8BDA9D8BCA8DBBFAFD3AE9B
CBA493D6B4A3D7B9A8E2C7B9E8D0C2EED7C6EBD3C1EDCDBAE4C1AFD5B49FCAA596BE9B8A
B28A7B997A6DA7806CA17667AF816FB3806DBC8F79CC9981D2A691D1AC97D8B9A5DEC2AE
DECABDDFD0C8DFD0C5DBC0AFD6B4A1D4AB99C79886BF8674B37F67AA775FAD7D68A67360
955F4C885948A27F79AB938E766160715C5C1A070E302429553431553A36745A576E4F4B
5D46407856497D5E558567569B715AA57762B4846DB68973B68978B98F7BB38D7CB58C7B
B8897BB48A798E6C5E67443D67443C664B46744D41C5917FC28871B76954DBDDDDDCDEDF
DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEDDDEDEE1E2DEE1E2DEDFE0DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DDDFE0938684604848391D1E22000088594FA17465A2746497675B
533A3B392F3231242A271E203722257C6156D9B9A5DCB9A7DABEAAD9BDA9DBC0AFD4B19E
CBA392D2AD9CD3B3A1DABCAFE1C6B9E5CEBFE5CDBCEACCBADFBDACD2AF99CDA696BD9987
B68A78A68071AB826DA57767AD7B68B37C68BD8E78CE9D85D4AA95D2AC98D8B9A5DEC2B0
DECABDDECFC4DECDC1DABEACD6B29FD3A997C69B88BE8978B27E69AB765EAD7B64A77560
9C675293614FA88379B1948C846A667B6562281419392B2E583935553A336E53506B4E49
5D453F785649805E53886A589F725CA87A64B5856EB68974B58A78B98F7CB38E7CB48C7B
B98D7DAB83727B5C525B3C395C3E3855403E6C4A3FC39583BC7D67B7634EE3E5E6DEE1E1
DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEDDDEDEE1E2DEE1E2DEE0E1DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2CBC7CB6E59584C3333381D1C270809633B36764F477C584F6D4944
412F3231292C2D2228271E203822257B6055DAB9A5DDBAA8DCBFABDABEAADBBFAED7B6A4
CEA897CFA696CEAB99CDAA9FD4B2A4D0B6A9D1B7A8D5B7A7CBAA9BC39D8ABF9787B08A7A
AD7E6CA37869A57A66A06F5DA6715DAE7360B7826EC89882D1A894D3AC99D7B9A4DFC2B4
DFCABDDECBBDDEC7BBD8BAA7D6AF9DD2A794C59D8ABE8E7CB17D6BAC765DAC775FA8765F
A5725AA3715DB48B79BB9789A3807592776E533B3A5A44426C4C4465473C70534F74564F
6C4F478561518F685A977563A97B66B0836CB78873B78A75B48C79B9907DB38F7DB28C7B
BA917F9E7869674B4551393851393544313166463CBB907FB36B59B7604BECF0F1E1E5E5
DFE2E3DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2
DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEDEDEDEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2B9AFB74C312F3D24253E262432191B4020204B2828563C3A432C2E
2E2328272024291F25281F213A2426785E54D9B8A4DEBAA9DFC1ACDBC0ABDBBEACDBBDAB
D3AF9ECCA192CBA693C19A8FC79E8EB99B90BB9D91BC9D91B59488B2897AAD8577A17B6C
A172619C6D609E71609A66559F6955A96C5AB07764C2917ECEA693D4AC9BD7B9A5DFC3B7
DFC9BCDDC6B5DEC1B3D7B7A3D7AC9BD0A491C49F8CBE9480B07D6FAD775FAA745AA8765D
AC7B62B3816BBD9178C49884C29582AC8A7A86685F8362588564577B5A4A785750826358
825F5496705DA17663A88371B68571BA8C76B98B79B88C78B38E7AB9907EB3907DB18D7A
B8937F8E6A5E543B39483638463431352224644239B28675A95849B75E4AF1F6F7E3E7E7
E1E4E5DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2DEE1E2
DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEDEDFDEE1E2DEE1E1DEE2E2DEE2E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2AEA1AC361615331C1C422D2A3B272A270F132B0D1139272922161D
1F181F1F181D251C222B20223D282A755B52D6B4A0DEB9A8DFC1ACDCC0ACDBBEABDEC2B0
D7B6A6CCA294CBA592BC9388BF9383AB8A80AD8D83AC8D83A6877EA87F74A47D6F987568
9C6E5F996B5F9D70619966559F6957AA6E5EAE7462BF907ECCA693D6AE9ED7BAA7DFC3B9
DEC6B9DCC1AEDDBCADD6B49FD7AB9ACFA391C5A18EC09884B28074B07A63A87258A6755C
AD7E65B88771BE9073C3917AD09D86BA937EAC8879A47A6A9B7867916D59866056937262
977061A57D69B0826CB58D7BBC8B79BE927CB98D7CB88E7AB38E7AB99180B5907DB18D7A
B08E797B5B51442F2F3F33373D302F2C181B6A443AAC7D6CA14B3EB65F4AEAEFEFE3E7E7
E1E4E5DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2DEE1E2
DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEDFE0DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2ADA1AD3211102D18193F2B293A2A2E1D0C101E060C2B1D21140C15
17131A1D1619231B202E2224422E2F725951D1AC99DBB7A5DEBEA9DCBFABDBBFABDFC4B1
DBBCADD0AA9CCFAC9AC09B8FC19787AC8C82AE8E84AC8E85A88B82AD867DA984779E7E73
A5796CA0776DA67B6EA17464A87665B37C6DB5806EC49887CEAA98D8B3A5D9BDABDFC2B8
DDC2B5DBBDA9DCB9A9D6B19ED7AB9AD0A693C7A491C39B89B6867BB4806CA5725AA0725B
A57660AF7E6AB18368B4816BC5927BB58B76B68F7DB08370A7816FA17C66966E5FA37E6A
A77D6DAF8571B68871B98E7CBA8A79BB907BB68C7CB98E7CB48E7BB99080B6907DB38F7B
9F7F6D654A43372628362C34352B2E2A1518794E41AC77659F483BB5624DD3D4D6DFE1E2
DFE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E0DEE1E2DEE1E2
DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE0E1DEE1E2DEE0E0DEE0E1DEE0E1DEE1E2DEE0E0DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2B6ACB83C1C1B2C1A1B362323312427201317220F13281C20130D15
1712191F171A231B203324264834356F584FC8A390D7B2A0DAB9A5DBBEA9DDC0ACDFC4B0
DDC0B2D7B7A9D5B8A8CCADA0CBA899BA9C91BA9D92BB9E93B69B93BB9992BA988BAD9288
B78E82AE8D85B79084B08B7EB78B7DC09485C29684CDA695D2B2A0DCBAADDCC0B1DDC1B4
DCBEB0DABAA8DBB8A7D6B09DD7AD9BD3AA98CAA693C89D8DBD8E83BA8876A474609A6E5B
9768589D6C5C9B6F5B9C6D5BA77966A27866AA8270AC806DA9816FAA846FA67D69AF8770
AF8774B18875B48A73B58878B18472B38875B18978B98E7CB58C7BB88F80B88E7CB4907A
89695B4E38353022242F253030282D2E191B8C5A4BAF73619F4D3DB16551B1AEAFD8D8DA
DBDEDEDFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E0DEE1E2DEE1E2
DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEDFE0DEDFE0DEDFE0DEE1E2DEDFE0DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2
DEE1E2DEE1E1DEE1E2C1BCC74B2E2D301F202F1B1E281D1F281E202C1E202C1F221B1319
1A131923191B241C203726284E3B3B6D564EBF9986D1AD99D6B4A1DBBCA7DEC2ADDFC2AE
DFC3B7DEC3B7DDC4B6DAC1B3D7BBADCAB1A4CBB0A5CDB1A5C7AFA7CDB0A9CDAEA1C0AAA1
CAA79BBDA69EC9A69CC0A49AC8A398CEAD9FD0AE9CD7B5A4D7BAA8DEC0B4DEC3B6DCC0B0
DABAABDAB8A7DAB8A6D7B09ED7AF9CD5AE9DCEA996CD9E90C4978BC09181A57968966C5E
8C5D528B5B4E875E51865C4F8660518D6357976F5FA27866A77C6BAF8975B38A72B88C73
B38C79B08776AF8873AF8071A67C6BA97F6EAD8574B88E7CB78B7BB98E80B98C7AB28D78
7152483A29292B2023291E2B2C252C341E209B6453AF6E5B9D5342A966538D8586CECBCE
D8DADADFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E0DEE1E2DEE1E2
DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE2E2DEE1E2DEDFE0DEDFDFDEDFDFDEE1E2DEDFE0DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2CDCBD5593E3D3827282E191D23181A302628362A2A302324241A1E
1E151A261B1E271D213C2929523F3F6B564DB58F7DCCA793D4B19EDBBAA6DFC3AEDEC1AC
E0C5B9E3CCC0E2CCC0E5CFC1E0CABDD9C2B4D8C1B5DBC1B4D6C1B8DAC3BBDBC1B5CFBEB6
DABBB1CBBBB4D7BAB1CDB9B1D5B7ADDAC1B4DBC1B0DEC0B0DBC1AEE0C4B8DFC4B8DBBFAC
DAB7A8D9B7A7D9B7A6D7B09FD7B19DD7B2A0D1AB98D2A195CBA092C69A8CAA8174997166
8A5C5584554B7F584F7B554C7351457F564D875F51976F5FA07566AD8674B78D75B88A71
B18A77AB8172A98471A9796B9E7565A37969AC8272B88E7BB88A7CBA8E7FB98A79AA8470
5B3D392B1E20291F22271B282B242C3723249A6352A763529554439A62526F6364C2BDC2
D9DBDBDFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2DEE1E2
DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE2E2DEE1E2DEE0E0DEDFE0DEDFE0DEE1E2DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2D6D5DE5F454343302E351F22261A1C32292A392D2D3023242A1F21
20161B271B1F2B20233F2B2B5442416B554DAE8876C8A28ED6B09DDDBAA6DFC3AEDEC1AD
E0C5B8E4CEC2E3CFC3E7D3C5E4CFC3E0CBBDDFCABFE1CABDDECCC3E1CDC5E2CCC2D9CAC3
E0C8BFD4C8C1DEC8C0D6C6BFDDC3BADFCCC0E0CBBAE1C5B6DDC4B2E0C5B8DFC4B6DABEAA
DAB8A7DAB7A7D8B7A4D8B09FD7B19DD7B2A1D3AD9AD5A699D1A898CCA395B58E82A77E73
986C6490625889625B825E5475554A80574E815B4E90685B956C5FA47D6DAF856DAE8069
A7806FA1786AA27C6DA677679B7363A37969AD8173B88E7BB88B7DBC8E7EB989779A7463
4C302F24191C281F22291B262C232C352324835146915145844E3F83574A5F5050B6B0B5
DFE2E3DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE2E2DEE1E2DEE0E1DEE0E0DEE0E0DEE1E2DEE0E1DEE1E2DEE1E2DEE2E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E1D9D8E15F4442503734422B2B2F21222F262738292A2E21232D2022
22171B271B212F2226422D2D5442406B554DA68271C39C88D8B09DDFBAA7E0C3AEDEC2AE
DFC4B4E1CABEE2CCC0E4CEC1E2CDC1E1CCBFE0CEC3E1CCC0E0D0C8E1CFC6E1D1C8DDD0C9
E1CFC6DACEC7E0D0CADCCDC5DFC9BEE0CFC5E0CCBEE0C5B7DEC5B4DFC3B5DDC3B2DABEA9
DBBAA8DBB8A6D7B5A2D8B19FD6B19DD7B1A0D5AE9CD6AB9DD5AD9CD2AB9BC49C90BA9083
B0867BA87C6FA0796E9672658A675B8C62578661548E655A8B6559986F619E75619E705F
9B7263976D609E7567A577679C7464A87D6CB28076B78E7AB88C7DBD8D7DB78875846053
42282A23191C291F212D1E262E242B3021225D3631733B356E403668463F594948A9A2A6
E7ECEDDEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E1DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE2E3DEE1E2DEE1E2
DEE1E2DEE2E2DEE0E1D7D4DC5B403D5B3E394F37343928292D22243624272B1E212F2123
24191C271B23342529422E2E533F3D6A534B9E7B6BBD9582D7AE9AE0BAA6DFC2ADDEC2B0
DEC2B0DEC4B8DFC7BADFC7BADFC8BCDFCBBFDFCFC5DFCDC1DFD2CADFCFC5DFD3CBDFD3CC
DFD2CADFD2CADFD5CFDFD0C7DFCBBFDFCEC5DFCBBEDFC3B7DEC5B4DDC1B1DBC1ADDABDA9
DCBDAADCB9A6D6B4A0D8B29ED6B09CD6AF9ED6AF9DD7B0A0D7B19ED6B19FD2AA9DCEA393
C9A292C39889BA9283AE8979A37E6F9C72648E6A5E8E645B8460568D63568E65548F6255
8F65578E64579B6F63A67968A17868AF8271B7817AB78D79B68D7CBC8B7AB184706C4A42
3C2527261C1E2A1F21312226302429291D1F361A1C54272755322D4D34325847469A9195
ECF0F2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E1DEE1E2DEE2E2DEE2E2DEE2E2DEE1E2DEE2E2DEE1E2DEE1E2DEE2E3DEE1E2DEE1E2
DEE1E1DEE2E2DEE1E1CBC6CB583C3861423D59403B412E2F2D20233621252B1D202F2022
261A1D281C24372629412D2D4F3B39674F48947263B28A79D1A793DEB6A3DEC0ABDFC2B0
DEC1ADDCC0B3DDC2B5DBC1B5DCC5B8DECABEDECFC6DDCDC2DFD2CADDCEC3DDD3CCE0D4CD
DDD3CCE2D3CBDED6D1E1D2C8DFCCBEDECDC3DEC9BDDDC2B6DEC4B4DCBFAEDABFAAD9BDA9
DCBEAADCB9A5D6B39ED8B29ED6AF9CD6AD9CD7AF9ED7B3A2D8B39FD8B4A1DCB2A4DBAF9D
DAB5A2D7AD9BCEA492C29D89B99180AC827299776A956A618563588A5F53885E50895D53
8B60538D62569C6E62A87D6BA77D6DB58775BB837DB78D79B38C7AB68674A57A68583834
3823262A1F212A1F21332426302328221A1D17070E3A191C402525362527554444897F81
E4E7E8DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E1DEE1E2DEE2E2DEE2E2DEE2E2DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE0E1DEE1E2DEE1E2B3AAAE563A366144405C443F4733333123253823272E1E212E1F21
2A1C1F291D243724283D2A2B4A3634604741856559A17C6DC29986D8B09DDCBDA9DEC2AF
DEC1ADDCBFB2DCC1B4DABFB3DCC5B8DECABEDED0C7DDCDC4DFD2CADDCEC4DDD3CCE0D4CD
DDD3CCE2D4CCDED5CEE1D3CADFCBBDDECBC1DDC8BCDDC2B5DEC3B2DCC0ACDABEA9D9BDA8
DBBDA9DBB7A3D6B19DD8B19DD7AE9BD6AD9BD7B09ED6B3A1D8B19DD8B3A0DFB4A4DFB3A0
DFBAA4DDB4A1D5AA97CBA692C49B89B88F7DA78476A2766C93706495695C92675992665C
94685B976B5EA27567AD826FAD8274B78A78BD857EB78D78B08977A97C6B906B5B482D2C
3422252C21232B1F223124262E21261F191C0C030B2A1318311D20281C204F3E3E766A6A
CDC9C9DFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E1DEE1E2DEE2E2DEE2E2DEE2E2DEE1E2DEE2E2DEE1E2DEE1E2DEE0E1DEE1E2DEE1E2
DEE0E0DEE1E1DFE2E3938888553A355C44425B433F4A373638292B3C272B3321232C1E20
2D1E202A1E2335222537262744302F563E3975574E8E6C60AD8675CFA793D9B9A5DEC1AD
DFC2AEDEC0B4DDC1B5DCC1B5DDC7BBDECBBEDFD0C7DECEC5DFD1C9DED0C6DED2CBE0D4CD
DED3CCE1D4CCDFD2C9E0D3CCDFCBBDDECBBFDEC9BDDEC3B6DDC2B0DDC1ADDBBDABD9BCA8
D9BAA6D9B4A1D7B09CD8AF9CD7AE9BD7AD9BD8B09DD6B19ED7AE9BD6AF9DDBAF9FDAAF9C
D9B29DD8B09CD2A694CCA893C79E8CC09885B69281B48779AA8374A87D6DA67A6AA6796C
A77A6BA97C6DAC8171B38875B4897AB78B7ABD887DB88C78AB847297706077574C3E2828
3121232C21242A1F232C21252A1E251D181D100A12221419271A1E21181D453435645553
ACA19FE0E2E3DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDFDFDEE1E2DEE1E2
DEDFE0DEE0E1DFE3E3746462543A3455434358423F4C3A393F3031402D2F3824262A1C1F
3020222B2022321F213222243F2B2A4C35316649437B5D54987463C59D89D6B4A0DDBFAA
DFC3B0E0C3B7DEC3B7DEC4B7DECABDDECABEDFCFC5DFCFC5DFCFC7DED0C9DFD0C8DFD3CC
DFD2CBDFD3CCDFCDC3DFD3CCDFCABDDFCBBEDFC9BCDEC5B6DCC0AEDDC2AEDDBCADD8BCA7
D8B7A3D8B09ED7AF9CD7AD9AD7AD9AD8AE9BD7AF9CD6AE9AD6AB98D3A999D5A997D1A896
CFA693D0A893CB9F8EC9A592C79E8BC69E8BC49E8BC69887C19785BD9280BD8F7EBC8E7E
BB8E7DBC8E7EB78E7BB88E7BBA8E80B78C7BBB8A7BB68A76A37C6B8362555E443D382627
2F21222C2024281E25261E23251B241D171D19151B1F181B22181D1F171B3B2A2C54423E
8F7D79E0E3E4DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E1DEE1E1DEE1E1DEE1E2DEE1E1DEE1E2DEE1E2DEDEDEDEE1E2DEE1E2
DEDFE0DEE0E0DFE2E35B4946533A345042435440404F3D3C4637384432333C27292A1D1F
3221232C20212F1C1E2F20223B2727432D2B5A403C6C514A876455BC937FD1AD99DCBBA7
DFC2B0E0C4B7DFC3B8DFC6B9DFCBBEDECABDDECDC3DFCFC6DECEC5DFD1CADFCFC6DED1CB
DFD1CADDD1CBDFCABEDED2CCDFC9BDDFCABCDFCABCDFC5B6DCBFADDEC2AFDEBCAED8BBA6
D6B4A0D7AD9CD7AE9BD6AB98D7AC99D8AD9AD7AE9BD5AB97D4A795D0A595CFA390CAA290
C79C8AC9A08BC49988C6A18FC69D89C9A18ECDA692D2A490D1A490CCA18DCE9F8BCC9D8A
CA9C89C99A89BF9782BC927FBE9183B68B7AB68A78B0857398726370554A4B3431322527
2D21222B2024261D25201A222018221C161D211D211E1B1E1E171D20191C33222548332D
806A65E1E3E4DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E1DEE1E1DEE1E1DEE1E2DEE1E1DEE1E2DEE1E2DEDEDFDEE1E2DEE1E2
DEE0E0DEE0E0DFE1E2513C39523B3651414252414252403E4B3C3D4736373F2B2C2E1F22
3421232D21212E1C1E301F223925263E2A28543C39644A457D5B4EB48A76CCA490D9B7A3
DEC0ADE0C4B5DFC3B7E0C6BADFC9BCDEC9BBDECBC0DFCFC6DECEC5DFD2CBDFCEC5DDD1CA
DFD1CBDDD1CBDFCABEDDD2CCDEC9BDDFC9BCDFC9BCDFC5B7DCBFAEDEC0AEDEBCADD8B9A5
D6B3A0D6AC9BD7AD9BD5A997D6AA97D7AC99D6AC9AD4A995D2A594CFA292CCA18EC79F8C
C49886C69C88C39887C59F8CC69C89C9A08DD0A692D3A590D4A692D0A48FD1A38FCF9F8C
CD9F8BCB9C8AC19984BD9381BE9181B78B79B08774A67D6D896558614941412C2B2E2325
2B21232B1F24231B241C171F1B151F1A141C231E221D1B1E1C161C211B1E2D1D203F2823
87746FE0E3E4DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDFDFDEE1E2DEE1E2
DEE0E1DEE0E1DEE0E0523C39523C385542405142445542414F3F4049393A412E30352426
3621232E20212E1D1F3321243925273D2A28533C3A62474478574BAE816EC69A85D6B29E
DBBBA8DDC2B1E0C3B5E0C6B9DFC6BADFC8BADFCABEDFCFC6DECFC6DFD2CBDFCFC6DED2CB
DFD3CCDDD1CADECCC1DED2CBDEC9BDDEC9BCDFC9BCDFC5B8DDC0AFDEBDADDEBCACD9B7A3
D7B3A1D7AB9AD5AD9BD3A795D3A895D5AB98D5A998D4A894D1A493CFA191CCA18EC89F8C
C69988C89B88C49A88C69D8BC69C89C79C89CCA18DCD9F8BCC9F8CCB9D89CA9E8BC99986
C79A85C49684BE9481BB9280BB8D7CB88875A8816F98736578564C543F3A3E29292A2024
2921242B1F2320192219141C18121C18121B1F1A1E1B191E1A151A221E212B1B1F3D2520
A09290E0E2E3DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDFE0DEE1E2DEE1E2
DEE1E1DEE0E1DDDEDF58413F523E3A5A413E5043465843435242434C3D3E4332343D292C
3821233020222F1F223823263A27293D2B2A543E3B63474477574BA87967BE8F79D2AB98
D8B6A2DBC0ACE0C2B3E0C6B9E0C4B7E0C7BADFCABDDFD0C7DFD1C8DFD3CBDFD0C7DED3CB
DFD4CEDFD1CADECEC5DED1CADECABDDEC9BCDEC9BDDFC4B8DDC1B1DEB9ACDDBCA9D9B5A1
D8B3A1D8AB9AD4AC9AD2A593D1A693D3A996D4A797D4A893D0A493D0A190CCA290CA9F8C
C99B8ACA9C89C69D8AC69C89C69A88C39685C69887C49684C09583C29480C19683BF8F7E
BE917DBA8D7CB88D7CB78F7EB58775B584709E786988675C6748414A36343E2829271F22
2720252A1F221E182018121916111A16101A1914191A151C1914192420232C1C1F432A27
BDB8B7DFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E0DEE1E2DEE1E2
DEE1E2DEE0E1DDDCDD5E4746523F3D5B403B5144465944445444464F4141463738442F30
3A23253020233122243C26293C292C3F2E2D55403D65474479594DA07161B7856FCCA390
D6B19DDABEA9DFC2B2E0C5B8E0C2B5E0C6B9DFC9BBDFD0C6DFD1C9DFD2CADFD0C7DFD2CB
DFD4CEE0D1C9DED0C7DFD0C8DECABDDEC9BDDEC8BCDFC3B8DDC1B1DDB7AADCBBA7D9B39F
D8B2A0D7AB99D3AB99D1A492D0A591D1A795D3A495D3A792D0A493D0A18FCDA391CCA08D
CB9D8CCC9C8BC89F8BC69987C59887C09181C09181BC8F7DB78D7CBA8B79B98F7DB98778
B78A77B28675B48878B28A7AAD806DAD7D69936F63795B52593C374330303E292A261E21
2620262B1F221C171F18111816111A15101A150E1519121B1A151A2520232F1F21543D3B
D6D7D7DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E0DEE1E2DEE1E2
DEE0E1DEE0E1DCDBDC5E4846514040563B37524243584344564647544545493B3C483233
3E27293020233224263F292A3F2C2E41302F543E3C6548447B5B50986A5AB07C68C69986
D4AC98DABDA8DEC1B0DEC4B5DEC1B4DFC4B8DFC6BADECEC4DED0C7DECFC6DECFC6DFD0C7
DED2CADFCFC6DED0C7DFCEC3DEC9BCDEC8BBDEC7BADEC2B6DBBFAEDCB5A8DABAA5D9B19D
D7B09ED6A997D1A996D0A592D0A491D0A794D2A393D2A691D0A492D0A390CEA290CEA08E
CC9E8DCC9D8CC79E8BC59785C49585BF8F7FBD8E7FB98D7CB48A79B78877B88C7BB88576
B58875B08574B18676AC8675A57A679F726087665B6D51494F34303E2B2E3B282A261E21
251F262C1F221C17201A121A19141C17111B110B13170F191D181D251E20362425715E5D
E3E6E7DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDFE0DEE1E2DEE1E2
DEDFE0DEE0E0DBDADB5B47445041414E363354403E5743435848475849494D3E3F493535
412D2F312023352527402B2C412F30433231513B396349427D5D528E6355A87562BF8F7B
D1A693DBBCA8DBC0AEDBC3B2DCC0B2DCC2B6DDC4B7DDCBC2DDCDC4DDCBC2DDCDC4DECDC3
DDCDC5DECDC2DECEC5DFCABEDFC7BBDFC6B9DDC5B8DEC1B3D8BCA9DAB4A5D9B9A4D8AF9C
D5AC9AD4A895D1A793D0A591D1A492CFA794D2A290D0A590D0A492D0A490CFA08FCFA08F
CB9E8DCA9E8EC69C89C49483C49382BF8F7FBD8F80BB8E7DB68C7AB78979BC8C7CBC8878
B78977B28776AF8675A6806F9D74638B66567A5C54634741482E2C3B282C362528261E22
251E252D20231D18211D151D1E181F19141C0F0B13140D17201C22251A1C412C2C958786
E4E8E9DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDEDFDEE1E2DEE1E2
DEDEDFDEDFE0DBDADB5B48444F414345312F553E3A5542435848475C4B4C504242493736
453234322123372627402D2C4331314533324E38376149417D5E53835C509F6E5CB68470
CC9F8DDAB9A6D8BEABD8C0ADDBC0B1DAC0B4DCC2B5DCC8BEDCCAC1DCC7BDDDCBC2DEC9BE
DDC9BFDDCABEDECCC1DEC6B8E0C5B9DFC5B6DDC3B5DDBFB0D6B9A4D9B4A2D7B6A2D7AD9A
D3A896D2A793D0A490D1A691D2A492CFA793D1A28ECFA38FD0A391D0A490D09E8DD09F8F
CB9D8CC99F8FC59987C49282C49181C19181BE9182BE9180BA8F7CB98B7BBF8D7EC08B7B
B88B79B48978AC85739E7968936C5D77584B6D524B5A3E3A432A2A39262A302227261F22
261E232E20241E1A221F1720221B221B151D0E0A14120C15231F2627191B513B3AB9B1B0
E2E5E5DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDEDFDEE1E2DEE1E2
DEDEDEDEDFE0DBDBDC5F4D4A504143402F2F563C365341425748465D4C4C5445454A3938
4836373524263827283F2D2C4332324635344C37365D473F795C5378554B926556AB7A66
C59684D7B4A2D6BBA7D8BEAADBC1B0DABFB3DCC1B4DCC6BBDDC9BEDDC5B9DDCABFDEC7BA
DEC6BADDC7BBDFCABDDEC3B3DFC3B7DFC2B3DDC1B2DDBDADD6B7A1D8B4A1D6B4A0D7AC98
D2A593D1A691D0A28ED1A690D2A392CFA692CFA18CCFA28ED0A290CFA48FCF9C8BCF9D8D
CA9D8AC89F8EC49685C49181C59180C29282BF9383C09482BE917DB98C7DC18D7EC18D7C
B78A79B28876A57F6E957060866256664C426048435036333D27273524282B2025261F22
271E222E2125201A23201821231C221A151D0E0C15120D15251F252F1D1E695553D5D1D1
DEE0E1DFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDEDEDEE1E2DEE1E2
DEDEDFDEDFE0DCDDDD6B5957514142413133563B365141415545445B494A5848484B3C3A
4837383B2B2C3928293C2C2C4231314535354B383759453E6F564F6E4E47825A4E9E715E
BA8A78D2AC99D6B6A2DBBDA7DFC4B1DFC2B3DFC3B5DEC5B7DFC8BCDFC5B8DFCABCDFC6B9
DFC5B7DFC6BADFC8B9DDC0AFDEC1B4DEC0AFDDBEAFDCBAAAD7B5A0D9B4A1D6B19DD7AB97
D2A490D1A591CFA08CD0A48DD0A191CEA390CD9F8BCFA08DCEA08ECEA18DCD9A89CD9A89
C99B88C79C8BC49384C49281C49180C19382BF9383C19582BF917DB98D7DBE8C7CBE8B7A
B38775AA816F9A746489645677564D5A413A533D3A462F2C3423242F2125271E24261F21
281F222C2024201A231C161F1E181F14111A120F1917131A241A1F3D28278B7B7AE3E3E2
DDDFE0DFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDEDFDEE1E2DEE1E2
DEDFE0DEE0E1DDDFE07C6A6A564343463739543C375140415242425746465C4A4B4D3E3D
48373642333439282B382A2B402F2F4434354C3A3B54413C624E49644843704E45906959
AD7C6BCBA18DD6B09BDEBBA5E3C5B1E4C5B3E1C6B4DFC4B3E1C8BAE1C7B7E0C9B8DFC6B8
E0C6B5E0C5B8DEC6B5DCBEABDBBFB0DCBDABDCBCADDBB7A7D9B4A1D9B4A1D6AD9AD7AA96
D3A38FD2A491CE9E8BCEA18ACC9E8ECDA08DCA9C89CF9E8BCB9E8CCD9D89CA9887C99684
C79884C59886C39082C49281C29280BF9280BF9281BF9580BE907BB88D7CB88877B78775
AB816F9E76658B64577B564B6648435238344733323B28272B1E20281D21231C22251E20
2A2023291F231F192117121C1511180D0B1618141D201B20241417503936B0A8A7E5E7E7
DEE1E1DFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDEDFDEE1E2DEE1E2
DEE0E1DEE1E1DEE1E2907E815D49474E3E40523C395040404F40405242425E4C4D4F4040
4736354A3A3B39292B35272A3D2D2C4133354C3D3D4F3C3B5444435C43405F433E826154
9D6D5DC0947FD3A792DEB6A0E4C4AEE7C5B0E2C5B2DFC1AEE2C7B7E3C8B5E1C7B3DEC5B6
E0C5B3E0C2B6DCC3B0DABBA8D8BCACDABAA7DBB9AAD9B4A4DAB3A2D9B29FD5A995D6A793
D3A18CD2A38FCD9B89CC9D86C99B8ACC9D89C79988CF9C89C99B8ACC9985C79685C5937E
C59580C49481C38D80C39381C09280BD907EBD907FBD937DBB8D78B58A79B08472AD816F
A179679169597B54496E4840563A384B302F3D2A2B31222321191C20191C201A20231D1F
2B2023241C211E171F110D180C09120606111E18212B242829141568504CD2D2D1E1E4E5
DFE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEDFE0DEE1E2DEE1E2
DEE1E2DEE1E2DFE3E3A59599695451544344503C3A5040404E3E3F4F3F3F5E4B4C524242
4837354F3F3F39292C3325283B2A2B3E30334B3D3F4A393A4A3D3E563F3F523C3973584E
8B5E50B18471C89A85D5AB97DDBBA5E2BEA8DEBEA9DBBBA7E1C3B2E1C5B1E0C3ADDDC3B2
DFC3B0DFBFB1DBBFAAD9B8A4D6BAA8D8B6A2DBB7A8D8B0A1DAB0A0D6AD9AD1A38FD2A28E
D19D89D0A08CCB9986CA9883C79886CB9986C69786CF9A86C89987CB9482C59583C29079
C3927CC3907CC28B7EC29280BE927FBB8E7BBC8D7CBA9079B68974B08674A77E6CA27867
956E5D825B4E6B463D603C37472F2F44292A332324281D1F1A15191A16191D181E201A1D
281E211D181D19141C0C0B1508061004041021192033292C37201F836D69E9EFEFDCE0E1
DFE2E3DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E0DEE1E2DEE1E2
DEE2E2DEE2E2DFE3E3BAAEB27965645744434E3C3950403F5040414E3E3E5A4748534445
4B3A395140403A292C3324273B292A3B2C30493C3D483739473B3D523E3F4C3938654D47
7850469D7364B38875C29886CAA995D2AD98D3AF9AD3B19DDCBCA9DBBDA8DDBCA6DBBEAB
DDBEABDBB9ABD8BAA5D8B6A1D7B9A5D8B29EDCB6A5D6AE9DD7AD9CD1A491CA9A86CB9A86
CB9783CD9B87CA9582CA9480C79683CA9682C79584CD9783C99685CB917FC69481C39079
C29078C38F79C28A7DC1907EBD917DBA8C78BA8A78B48A74AF8471A87E6C9F7564966D5D
896253754F445E3C3554332F3C27293923252B1E2022191D1612181714181B151C1C171B
21181C1411181310190B0C160A0A140B091420151B37292A523B39A1918DF1F7F8DBDFE0
DFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2DEE1E2
DEE2E2DEE1E2DFE2E3CDC7CA8B7C7C5944404F3C3851403F544343503E3F544142554546
4F3F3E503F3E3B2A2C3524273C282A38282C47383A473839493C3D513F404A3B3A594240
65453F866257987464A78172B19180BC9684C49A86C7A291D3B19ED1B09CD7B39ED7B6A1
D7B7A4D3B0A1D4B39FD7B29DD8B7A1D7AC9ADBB4A1D4AA99D1A795C99783BF907CC18F7C
C28F7BC7947FC7917BC88F7DC7937FC7937DC89380C9937ECA9382CA8E7CC79380C49079
C18E74C38E77C2897BBE8D7CBC8E78B98875B68674AE826FA57D6C9E7362956B5B886053
7C554868453C533530492C293322252D1C20241A1C1D151B15101717121918131B171219
1710160B09120A0B150E0F1912111C17131C1F10143A282874615FBDB5B4EBF1F1DDE0E1
DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DCDCDE9F94975E4842523F3A534140574545513F404E3B3C564647
5343444F3D3C3D2B2C3926273D282B3625284435374739394E3F405141424C3E3D503A3B
553C3A71524D7D60558B6B5F96786BA47E70B28372B79284C7A391C3A08DCCA793CFAA95
CCAC9AC8A595CCAA97D2AA96D5B19BD3A493D7B09BCEA592C79E8CBD8A75B28571B48270
B58471BD8B76C08A73C38879C58F79C28E77C7907BC28D78C98F7EC78A78C6917DC38F79
BE8B70C08C74BE8677B98777B88872B58270B0806EA579689A75669267578A5F527A5248
6E473E5C3B3548302D3F27252D1F2222171C1E181A19121A150E1717111916101A120E17
0D081103020D03061211121C1B1A24251E24200E11412C2B998A89D6D6D6E0E4E4DFE2E2
DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE0E1E6EAEAB3ACB06B564F59464353403F5744435240414A3939564647
5545474E3C3B402E2E3C28283D282B352326433234483A3A5443435344455042424C373A
4C383A61484668524A765A517E645A8F6B60A17162A68276B79282B18D7DBB9685C09A85
BC9B8BB89686BF9B8AC59C89CCA690CA9989CDA692C39B88B99280AE7C68A27967A47463
A77766AE7F6BB58069BA7F71BD8771B9866FC28974BA8671C38877C08472C08A77BD8A76
B8856BB9866EB68070B28070B0806AAE7B6AA778679A6F618E6B5E845A4C7C53486B453E
603B354F322F3E2B29362322281D201A141A1A1719161019140C16150F19120D180D0B16
06040F00000C00041014131C201D262F2528291516553F3EB8AFAEE6ECEED7D8D9E0E2E3
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E1DEE1E1DEE0E1E8EEEEC5C2C682706C665453513D3C523F3E5140414C3B3C544646
5244454E3E3C4332323F2A2B3B272A352327433233493A395746465546475547464E3C3F
4A3A3C5843445E4B466B544C6F585181605792655793746AA480719C796CA38073AA8473
A48577A48374AA8677B08676B9927FBB8B7CBB9784B28C7AA581719C705F916C5D926558
96695A9B6F5EA4725DAA7264AE7965AC7A64B57E6AB07C68B97F6DB57C6AB47F6CAF7F6D
AD7C64AC7B65A97565A67768A37562A270609A6D5E8D6559815E53754D426C463E5C3936
53332F432B2A3425252F2021241B1E17131A191519130E18110A14110B160D09150A0915
0606120304100306101611181D17203323263C2727786564CEC9CAEBF2F5D5D6D7E0E2E3
DFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E1E5EAEAD4D4D79F93927666684F3C3C4B3837514141514141524444
4D40404F413F473737422D2E3826293625294534344A3A395A49495748485A4B4B544547
4F40415543445C4A4768544E67534E795C54865F5281675E8F6E6086655B86685F8F6C60
886B618C6D61926E62946B5FA17A6AA77B6BA583739D7A698D6E62876657805F547D564D
845A4D845D518E62509663559968579A6C57A4715EA3715DAA7362A5715FA2705F9C7160
9F705B9A6C5A976757986D5D9368589264568A6054805B507451476641395A3A354E302E
462C2B3825262B1E1F291D21211A1D18131B18131A110E180D08130C0712070510080915
0A0C190C0D170B0A14180D14190F17342023584242A49795DBDADBE7EDEFD9DADBDFE1E2
DFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DFE2E3DFE2E3BCB6B8897B81523F3F4735335142425646474F4141
473B3B5144424A3C3C44313136262A39292D4736364C3B3A5B4C4C594B4A5F4E4E5B4F4F
5647475646475E4D4A69585363524F745B537B5C50715C537B5C5171524C6B514D74554F
6D534B74585079574E785249876155916A5B8C6F61866658765A52725C516E534C694944
724B416D4B447751447F5446825749875C4A8F62519464529666559365538D6050866052
8E6252865C4D835749886151805A4E7F574B79534971504868443C583632492F2C412829
3A27282E202423171B231B211E181B1A141D18111B100D1809061106040E01020D070914
10131F16161F1611191E0E12190C133A2325766263CEC8C7E2E4E5E0E3E4DEE1E1DEE1E1
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DFE1E2DBDCDDE6EAEAD3D1D69E939B5C4B4C4A38375041415748484D3F3F
4439395247454D4040463435382A2D3E2E314A3A39503E3D5D4E4E5C4D4C615050615654
5D4D4C58494961504E6A5A5563524F70595172594F65534B6A4E455F43415741415F4442
563F3B5F4742654640613F396F4C447A594C765C5270544A634A4660514B5E4744573D3B
603E37583C3A6041396945396B463D714C3E7A52458055478157487E5748785143715146
7A5348724C416E483C7453456E4B436B494067463F61453E5B38334C2E2C3B2727372225
312426271D221D13181E171F1B161A19131D160F1A0E0D1707061103030E00020C070A14
1415211C1A2120171D2A151827181D4C3538968586EBEBEAE4E9E9D9DADAE2E6E6DEE1E1
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DFE2E2D9DBDCE7EBEBDFE0E5B4ACB47161645644444E3E3F5343434C3D3D
473C3C5349485042434937383D30324333364E3E3D56444360504F5F504E625151625755
60504F594A4A62515068575364514E6A544B6A554D5F4C465E453F513A394D3B3B533C3C
4834324F3B39593D3B5337335B3E3A644942644E475F4640563F3D524644503C3C483434
4F33304732314C353055382F5638325C3D3364433A69453B69473C69483D65443A5F433C
65443D5F3E375B3B335F44395D3F3A583C36573B36513A3550302D422A29322223301F22
2A2123231C211A111818131C18131916101A120B170C0B16070712040611020711080A13
14111B1C151B271A1E3C252846373A6F5C5FB3A8A9F4F7F7E4E9EAD8D8D8E2E6E7DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DBDDDEE4E8E8E2E5E8C8C4CB8E7F836B585A4F3D3E4C3B3C4C3D3D
4E4243534A4A5143444B3A3B4538394838395141415D4C4B625250625351605151615453
5F504F594A4960504F62504D664E4A634C44634E4A5E474257403C4835364C3B3C4D3B3B
403030443435533C3C4C38354D3636513B3B574340513B3A4E3837473B3B4433353D2D2E
412B2B3A2B2C3C2B2A442D29452E2B472F2B503530503530523731543A34553A35513936
5036324E332F49302C4A352E4F333146302E49312E412E2B452A2A3B27272D20222B1D20
251E21221C2119111A120F18141018100C160C08120B0914090913080C16090E190A0B13
130B13190D112E1D20543D407163649C9094CCC7C8EDF1F1E2E7E7DADCDCE1E4E4DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E1DFE2E3E0E4E4D8D9DDAB9EA38371755441434836364E3F3E
55484952494A5143444B3C3D4D3F404D3C3D5345456353526352506355535D504F5F4F4E
5C4E4D5849485C4D4C5D4846674A465B433C5C47465D433F533D3C4333344E3F3F4C3D3D
3D30323D30344F3D40493C3A423135412F354C3B3B4633364933333F30343A2B2F34282A
3424283126282E23253625263725253524243E29293926273E2929412D2C463230443030
3D2A293F2A293A2728362725422A293526283C28283224233A2527352526291E21261C1F
221B1E211C2018121B0E0B15110D160B091207050F0A08120C0B150E111C121621110F15
170A101C0B0E3A27296F5A5D9D9292C8C3C7DFE1E1E1E4E4DFE2E3DEE1E1DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E1DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2E0E4E4DBDDDEDEE1E0E3E6E8C4BABF9B8C916450544A373750403F
58484A4F44465041434C3D3E54454550414055474766565661514F6354535A4D4C5B4B4A
594B4B584948584948584240654642543B355440405A3F3C503C3C4032345041414B3E3E
3C3134382E344B3D42473E3E3A2D343526324334363B2C32422E3038282E32252A2E2426
2B2026292225241D222B1E232C2022271C20302023281C202E1F2232222538292A37272B
2C1F213222242D1F23271C1E362224291E23302022251B1C2E20252E2324241C1F211A1D
1D171B1E1A1E17111C0A08120E0B1607071106050F0B09130E0D1613151E1A1A241C151A
2514182C191B513F408D7B7EC1B9B9E7E9ECEAF0F1D6D8D9DDDEDFE1E5E5DDDFE0DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE0E1DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2E1E4E5DADCDDDDE0DFE6EAECD4CED2B2A7AC7F6F73544141513F3E
534243493C3E4F40414C3E3F5749485245455548486455555D4E4C5F514F564948584746
564848594A4954444354403F60423E4D35304A3739533A394D3A3B4031334E3F40483B3B
3D3135362C3645393E423B3D3528312F222E3A2D3132252D38272B3122292C21272A2124
241C24221D221E191F231A21241C2020181F271B201F181D24191E261B1F2A1F222A1E24
20181C281C2023191F1E161A2B1B2021191F251A1D1B1418211920251D211C171C1A161B
15111718131A130F1A0A07120C0B160708120B0B140F0E180F0F1817151D2019202B1F21
3F2D2F503D3F766768AB9EA1D7D3D2F2F6F9ECF3F4D4D6D7DCDDDEE1E5E6DDDFE0DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2E0E3E3DCDEDFDEE1E0E4E8E9DCDADCC6BFC4A2969B67545455413F
4B39384334344D3F3F4C3F4057494A5248495547485E5050564948594B4A524443554444
5245455A4C4A503E3E524040583E3B47302E3F2F30483434493839402E3148393B443437
3D3035342A383C31373D343A31232D2C202B32252B281F272C1E262B1E27261E25281F23
201A221D181F1A151D1E171F2019201D171F21181E1D181C20171D1E161B1E15191F151E
19131920181D1B151A1A131822171E1D171D1C1419140F1615121B1D171D121018131118
0D0C14100C150F0B160B07130C0C170A0B1714131D14151F11111A1C151A26161B402E2C
6351527F7070A39A9AC6C1C3E0DFDFEDF1F3E8EDEED8DBDCDCDEDFE0E3E4DEE0E1DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DFE2E2DFE3E3DFE1E2D6D4D7C4BDC37D6C6C5D4847
47353341302F4D3F3F4C4141564849504A4B5345455748485044455345454F3F40544343
5042435A4D4B4B38385041424F3A38402B2C3427283D2E2F4535363F2B2F4132353F2D31
3D2D3333283832282E372C342E1F282C20282B1F26211A21201721251B24221C24261E22
1D182019131D18131C1B151E1E17201D18201E171D1F1A1D20181D1A1419150F13171019
1611191B161C1713181A13191C141D1C161D151117100D150C0C1715111A0B0B140D0D16
0708120906110C09130E09150E0D180F0E1B1F1B261C1C2616151D24171A30171958423D
88787AAFA4A4CECACADDDEDFE1E4E5E1E4E5E0E3E3DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEDFE0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE0E1E0E3E3DFE2E3DBDEDEE0E4E4E0E2E4DDDBE09788886E5A59
4F3E3C4736344F403F4B3F405244454C47485042425142424C42435042434F3F40544444
4F4142574C4A4432324E40424634343A272A2C212233292A3E30323C272D392B2E38262C
3A2A303126362A202630242F2C1C252B1F25261B231C171E19121E2019231F1A23241C21
1C161F17111B17111A19131C1C161F1E18201C161D211C1F231A201B151B130E14160F19
17131C19151D1814181C151C19141F1D161D1210170F0D17070A15110E180708120B0B15
0608140906120E0A14120D1912101A15121D261F29232129201A20332021422525755E59
AA9E9FD4CECDEBEDECEBF0F1E0E5E6D7D9D8D9DADBE3E6E6DFE3E3DDE0E0DFE2E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE0E1E0E3E4DFE1E3DADCDDE0E5E4E4E8E9E8E9EDB0A6A78A7A7A
6859575949485141414A3C3C4B3C3D453E3F4B3F3F4D403F4D4344514546544445574849
5041435046463C2B2C4B3E3F3E2E2E352327271D202B232634292D362329322529322128
32242B2C2330221A202A1F2A281B23271D2223192219151C18131F1D18211D1922211920
1B151E17101B150E1816111B19141D1C161E1A151C221D21271E241E192118141D1D161E
1D19221B17201C171D1E16201C17221D171E141118120E190A0B15110D170B0A130E0C17
0E0D1A110E1A15111B17131F18151F1C151C281C232A20242F212349333060434196837F
C4BCBDE5E3E3F4F8F8EEF5F5DFE5E6D5D6D6D7D8D9E3E6E6E0E3E4DDE0E0DFE2E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E1DFE2E3DEE1E2DCDEDEE0E4E4E3E7E8E7E9ECC7C4C4ACA1A2
8C807F7465675745474A393A4636363F3434483C3D4C4040514748554B4D5A4C4D5C4E4F
524345473F40342627493A3B392828312024251C22271F232A21272D1F262C21242B1E25
281E25261F281C161C241B26231A21221A2020192319141D1B16211C17201C17211D171E
1A151F18121C130D16120E1916111B19131C18131C211C232B222A241F29221F2C292026
2620291E1A25241C25201925211C251E172019141B17111C111018150F18130E1615101A
1A1723201C27211C251E1C26221B2424191B28161A321E1E432C29644C47846C69B7ACAA
D5D2D3E7E8E8EEF2F2E9EEEEE0E4E5D9DBDBDADBDCE1E4E4DFE2E3DEE0E1DFE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E1DFE2E2E0E3E3E0E4E4DBDDDECCC8C9
B2A9A9928689624F524F3C3E4634353E2F2F463D3D4C4241554B4C585052605354605254
55464840383C2F24264939393625242F1F23271D26241C20211A22241B23271D20241D23
1F181F211B2018141A1F19221F1A211D171E1E1A241A141E1F1A241A161F1C16201A151D
19141F19131D120C16100C18130F1916111A18121B211B252F26302B25322E2C3C362B2F
2F2831241E2A2C222D221B2A2820292018231F191F1D16201B161B1B131A1D151A1E151D
28202B2F2A322D272F26242D2E232B2E1F1C2C14153D211C5B3D36816A63A89793D3D2D2
E0E2E2E1E4E5E1E4E4E0E3E3DFE2E3DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DFE1E2DEE0E1DEE1E1E0E3E4DEE0E1DCDEDFDADEDDE7EDEEE4E4E6
CFCACBAEA6AA7564685E4B4D4F3E3F473535483E3F4D4242564A4B574F515F5354605254
5848493F373B332A2C4E3D3C3A28273121252B2029251B201C161E1E1820241C1F201B22
1A151C1D191B1713191C171F1D1A2019151C1C192318121C1F1A2319141D1A141E17121C
18121D1A151D130E180F0C17100D17150F1918121B201A273028332F29383735483F3337
372F382A232F322733251E2E2D242C241B27261F24241C25241D2023191F271C1F271B22
3328313A3237372D332E292F3A2A303C28223A1E1C4F2E2778574E9E8A82C6BBB8E6EBEE
E5EAEBDBDFE0D6D8D9D9DADADEE0E0E2E5E6E1E4E5DDE0E0DEE0E1DFE2E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DFE1E2DEE0E1DEE1E1E0E3E4DDDFE0DBDDDDD9DCDBEBF1F2ECEFF1
DFDDDFC4C0C4928589796A6D6657595C4C4B4F43434C40405143434E4445574A4A594C4F
59494A453D4142393C59484845333337292B34252C281D211E161E1C161F241C201E1B20
1B161C1E191B1A151B1B161E1C191F18141C19151F140E191A151E16111B18121B16101B
16101A1B151C17111C110D180F0C16150F1A19131B1F19282E27333129393C384B40353B
3D353E312935342A362721302F272F2A202D2E262A2B242C2C24272D22282F23252F2227
382B313C2F323B2B2E36292B4531324E342E543834684A43987D74B8A9A4D7D3D1EDF4F6
E6ECEDD9DEDFD3D5D6D7D7D8DEDFDFE3E6E7E2E5E6DDDFE0DEE0E1DFE2E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DFE1E2DEE1E1DEE1E2DFE2E3DDE0E0DCDFDFDBDEDEE7ECEDE9ECED
E3E4E5D4D3D6B4ADB09C9295857A7D7A6E6C5A4A4B4C3F404A39394235364B3C3C504346
5A4A4A52494C574D516757585444444033343E2B2E2E2125251B211E161F271E23201B20
221B20221B1F20191E1D161E1E181E1A151E17111A0F0914130D17140E18150F19160F1B
140E171A151C1D172316111A0F0C1717111D1B151B1F19292925313026383D36483C323C
3F3841362F39342C372A24312E2830322733352D31332D33312A2E382D32362B2C37292D
3A2B2E3A28283C26253F2826513835624441775D5886706BB8A7A2CDC6C3DFDFDEE9EFF0
E4E9E9DCE0E1D8DADBD9DBDCDDDFE0E0E3E4E0E3E4DEE0E1DEE1E1DFE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E1DEE1E2E0E3E3E0E4E4
E1E4E4DFE1E3D3D3D5BEBBBEA69FA49B94926A58585344464836353B2A2B423232493D40
5C4C4B5F54576C61657366676354564B3E3E48323035272A2F22252318212D2229251D21
2C2226291F25291F232119202219201F1821170F180D07120D0711150D18150F1819101C
130D161B161D251D2A1C151D120E1A1C14221F191D211A2B25232E2F23353E3342372E3C
413A423C353C332D362D28312E28303A2D383B33363A3439372F3442363B3D32323E3133
3D2D2C3A22214126214B2B2660443D7858589B8481A59895D4CFCDDDDEDEE1E4E5E0E3E4
DFE2E3DFE2E2DEE1E1DEE0E1DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DFE1E2DEE1E2DEE0E1DFE2E2E0E3E3E1E3E4DADBDBD9DCDC
DDE1E2E5E9E9E9EDEED9DADCC2BFC4B9B5B3806E6F635658534140412E2F433232493C3F
5D4D4C675B5C776A6E786B6D6C5E605346465039353E2F313A2A2B2D1E2635282F2C2225
37292D30242A322629291E24271D24261E271D121A130C1610091419111C18121B1F1521
17111A1E19212D2531241D24181522251D2A26202327203026242F3024353F333E352E3C
433B42423A3F352F35322C32312A3040313B4036383F383A3B3136493B3E433635453838
42312D4226244E312A5F3C34755B51907375BAA9A7BEBAB9E6EAECE6EDEFE0E5E7D9DADA
DCDDDEE1E3E3E3E6E6E1E5E5DFE2E3DDE0E0DDE0E0DFE2E2DFE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DFE1E2DEE1E2DEE0E1DFE2E3E0E3E4E1E3E4D8D9D9D7DADA
DCE1E1E6EBEBEFF5F6E5E8EAD4D4D8CDCDCC9C8E8F8176796E605E564648524343524547
5E4E4D65585A7464687265666B5D5F594B4C543F3D47383944323239292E3F3034372A2A
3F303238292E3B2D2F33262A2F252C322932281D25231B221E1720221B26211B24281E2C
211A25251F2B362D392E292F25202F322B38322B2D342D392E2C36362B3A4538403A3340
483D43493E403C32363B32353B2E314533394336364435363E2E314B38394A37334A3B39
4E3934553837684C467C5E56937D75AB9598CFC4C3D0D1D1ECF4F6E8F0F3DFE4E6D7D8D7
DADCDCE0E2E3E3E6E7E2E5E6DFE2E3DDE0E0DDE0E0DFE2E2DFE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DFE2E2DFE2E3DFE2E3DADCDCDADDDD
DEE1E2E4E8E8EAEFF0E6E9EBDDDFE1DADBDBBAB3B5A7A0A3948B8A786C706E6060635657
6050515F51536756586758586455575E4D505646475142424F3C3B4937394B3A3B443433
46383742303144363640313238313840373F392D35393135332D342F2A352D2831332B3A
2E27362E29383F354039363D342F3F423C483F383B453D463B38413E36414D4146443D45
4F404550424246373A46393B49353349353646353349312F422C2B4A3230523730513F3C
5E46427156558A736E9E8A85B3A7A2C5B9BCDAD7D7DBDEDEE8EFF1E5ECEEDFE3E4DADBDB
DCDDDEDFE1E2E1E4E4E0E4E4DFE2E3DEE0E1DEE0E1DFE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE2E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E1DEE1E2
DFE2E2DFE2E3E0E3E4E1E4E4E1E4E4E1E4E4D6D6D7CBC8CCBAB7B69C969B8D8283796D6D
67585B5C4E515B4A4B5E4E4D5F4F52635256594E545B4E4D59464659484658474552413F
5042414D3A384F40404E3E3D433F4550474D4B40475248484B454A3E3B453C363F413949
3E35473A3346483D4744424A453E4F524C564D4448564C524A444D494249564A4D50484A
564346574543523D3E524241583D384F39354B373451312D4A2E2B4D322D5E3C335B4844
7259568F7879AC9C99BFB7B5D2CFCEDBDADCE0E3E4E1E4E5E0E4E5E0E4E5DEE1E1DEE1E1
DEE0E1DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DFE1E2DEE1E1DEE1E1DEE0E1E1E4E5E1E4E5
DFE1E2DCDEDED8D9DADCDEDEE1E5E4E3E7E8E8EDEFE4E6EAD8D9D9BCBAC0ABA3A4938988
786B6E64585C5D4D4D6152506455576B5B605F5962665A5A64525368585667565362504E
5D514F5A46435B4D4D5D4C4B514D535F54595C50566458575E56594E49524A424B4D4554
4C4153453C4F4E434A4E4A515249585D555D574C4E625657574C5252494C5C4F4F594E4B
5B44455C47435D43425D484664443E57403A563F3B5F3B355A3C365A3E386F4D436E5B57
8A7271AC9A9CC8BEBED8D9D9E6EBEDE8F0F1E2E9EAE3E6E7D9DADADBDCDCDEDFDFE1E5E6
E0E3E4DEE1E1DDDFE0DDE0E0DEE1E1DFE2E2DFE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DFE1E2DEE1E1DEE0E1DEE1E1E1E5E5E1E4E5
DFE1E2DADCDDD6D7D8DADDDDE1E5E4E4E7E9EDF4F5EEF1F4E6E9E9D1D2D7C3BEBFAEA7A7
938A8E7E7478726566756967776B6E786B706B67737266696D5F62736666786765705F61
6F64646956546A5B5D6C5B5A60595F6A5D60695A5F6D5E5D675C5F5B5158554A51574C59
5648564F4251524449544C50584B566155585A4B4C6555545D4D4F5849485D4D4B5D4D47
5C42405F4641644744634C486A4A44624D46664F4C74524C745853735C57886B648B7D7A
A59393C2B7BAD8D4D5E4E9EAEDF4F7ECF5F6E2EAEBE3E6E7D7D8D8D9DAD9DEE0E0E2E5E6
E0E4E4DEE1E2DDDFE0DDE0E0DEE1E1DFE2E2DFE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE0E1DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E1E0E3E4E0E3E3
DEE1E1DCDEDED9DBDCDCDFDFE0E4E3E2E6E7E9EEEFEAEDEFE7EAEADCDEE1D4D3D4C7C5C5
B5B1B3A19CA0958D8E968E8C948C8F8880857B78847E7279786D747D73778A7B7A7F6F76
857A7D7B69697A6B707B6A6B70656A746465746165705E5D6A5C5E67575C5F505560515A
5E4C54594750544446594A4B5C4A4F604E4E5B4644634F4C604A485D45425C49455F4942
5D413C6145406B4D46684F4A6D504E715E577B65648E736C937D7B948582A5928EAEA6A4
C0B7B8D3CED0DFDFE0E5EAEBE9EEF0E7EEEFE1E7E8E1E4E5DADBDBDBDBDBDEE1E2E0E3E4
DFE3E3DEE1E2DEE0E1DEE0E1DEE1E1DFE1E2DFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEDFE0DEE0E1DEE1E1DEE1E1DEE1E2DEE1E2DEE1E2DEE2E2DEE1E1DEE1E2DEE1E2DEE1E1
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E1DEE1E1DEE1E1DFE1E2DFE2E2DFE2E3E0E3E3E1E4E4E1E4E5E1E4E4DFE2E3DDDFDF
D5D6D7C6C5C9BAB7BAB8B5B4B4AFB39B979B8E8B978B818B847D8787818A9C8F918E818C
9B92978D7D818B7D848A7B7D8373787F6D6C7F6A6C735F606E5C5F755F616A585B6B585E
6853546650515A4848604B49614C4B614B475D4641634C48654B456446405F4943634941
61453D664A4574574D705751735B5B82726D928080A99690B3A4A4B6B0AFC1B9B9D0CDCD
D8D7D9DEE0E1E0E3E3E1E3E4E0E2E3DFE2E3DFE1E2DFE1E1DEE0E1DDDEDEDFE3E4DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE2E2DEE1E2
DEE1E1DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2
DEDFDFDEE0E1DEE1E1DEE1E1DEE1E2DEE1E2DEE1E2DEE2E2DEE1E1DEE1E2DEE1E2DEE1E1
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DFE1E2DFE1E2DDE0E0DDE0E1
DEE1E2E0E3E3E2E5E6E0E3E4DEE0E1DDDFDFD9D9DAD8DBDADBDEDFE2E5E4E6EAEBEAEFF0
EBEFF0E1E3E7D7D8DBD4D5D4CDCCD0AEAEB1A3A1AB9D949F94929D96949EAEA4A89F97A4
B1A9B0A1949B9E929B9C8F9397868B8E7D7C8D797B7D6A6D786769856E6F7A686A7A676B
77635F77605D6856556D56536D58546B534F69514C6C555271585073534C6B554F6F554E
6D544C745A56836B617F6964806F73988C89A99C9EC0B7B2CCC6C8D1D3D4D7D8DAE7EAEB
E8EEF0E5EBEBDFE4E4DDDEDED9D9D9D9D9DADDDDDDDDDFDFE1E5E5E0E2E2DFE4E6DDE0E0
DEE0E1DFE1E2DFE2E2DFE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E1DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2
DEDEDFDEE0E0DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DFE1E2DFE1E2DDE0E0DDE0E1
DEE1E2E0E3E4E2E6E6E0E3E4DDDFE0DCDEDED7D8D8D7D9D8DADCDDE2E5E4E7ECECEDF3F4
F1F6F7EBEFF2E5E8EAE1E4E4DCDDE0C0C3C5B9B7BFB2ADB6ABACB5ACACB6C0BBC0B4B0BC
C3C0C6B5ADB4B2AAB4B0A8ACAEA0A5A49796A292959385888D7F829A8788908385908184
8E7E7A8E7B7881727284706E84726E826D6B816E6A83716F88756E8B706B83726D85716C
84716B8C79789C8B84998A86998F95B1ABAABFB8BBD2CFCDDCDBDEE0E6E8E2E8ECEFF6F8
EDF6F8E7EFF0E0E6E7DCDEDED8D9D9D8D9DADDDEDFDDE0E1E2E7E8E2E6E7DFE3E4DDE0E0
DEE0E1DFE1E2DFE2E2DFE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEDFDFDEE0E0DEE2E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E1
DEE1E2DFE2E3E0E3E4DFE2E2DDDFE0DCDFDFDADCDCDADDDDDCDFDFE1E4E4E4E8E9E8EDEE
EBEFF0E8ECEEE6E9EBE4E7E8E1E3E5D1D4D5CDCDD2C8C7CCC5C7CDC5C7CDD0D0D4C9C9D2
D2D2D7C9C6CBC5C2CAC5C1C5C4BDC1BDB6B6BAB0B4B0A8ACA8A0A4B1A5A8AAA3A6A9A1A4
A99F9EA89C9BA09598A09293A29594A19294A19694A29797A59B97A89895A39895A19693
A29792AA9FA1B9B0ADB8B1B0B8B5BBCACACAD1D1D4DCDFDFE2E5E8E4EBEDE4ECEFEBF2F4
E9F2F4E5EDEEE1E7E8DDE1E3DBDFDFDBDEDFDEE1E2DEE2E3E1E6E7E2E8EADFE1E1DEE0E1
DEE1E1DEE1E2DFE1E2DFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE1E2
DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEDFE0DEE0E0DEE2E2DEE0E0DEE1E2DEE1E2DEE1E1DEE0E1DEE2E2DEE1E2DEE1E2DEE2E2
DEE1E2DEE1E1DEE2E2DEE2E2DEE1E2DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E1DEE1E1DEE1E1DEE1E2DEE1E2DFE2E2DFE2E3DFE2E3E0E3E3
E0E3E4E0E3E4E1E4E5E1E4E5E1E4E4DFE2E2DDE0E1DCDEE0DCDFE1DBDDDFDDE0E1DBDEE2
DEE0E2D9D9DCD6D6DCD6D6D8D8D6D8D4D2D3CFCCD0CCCACDC2C1C4C6C2C5C2C1C5C1C0C3
C2BFC0C0BBBDBEB7BDBBB4B8BFB7B9C0B6BCC0BCBDC1BDBDC1BFBEC3BDBCC1BCBABDBAB8
BEBAB8C6C3C7D3D1D1D4D4D5D5D6DADEE1E2DFE2E4E2E6E7E2E5E7E1E7E8E1E6E7E1E6E6
E1E5E6E0E4E5E0E3E5DEE3E3DFE3E3DFE1E2DFE2E3DEE2E3DFE2E2E0E7E9DDDCDBDEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE2E2
DEE2E3DEE1E2DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE1E1DEE1E2DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2
DEDFE0DEE0E1DEE2E2DEE0E0DEE1E2DEE1E2DEE1E1DEE0E1DEE2E2DEE1E2DEE1E2DEE2E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E1DEE2E2DEE1E2DEE1E2DEE1E2DFE2E2DFE1E2
DEE1E2DEE0E1DDE0E0DEE0E1DFE2E2DFE2E3E1E5E6E1E5E6E0E3E4DDE0E1DBDDDED9DADB
D7D9D9D9DBDBDCDFDEDDE0E1DFE3E2E7EAEAE8ECEAE9EDECEBEEEDEAEAE8E5E6E4E7E8E6
E4E5E3E4E3E2E1E1E3E2E2E2E5E5E5E4E3E4DFDEE1E0E0E2D7D8DAD6D6D8D5D6D9D3D4D6
D6D4D6D2D1D3D5CFD4D0CCCFD4CED1D6CFD5D7D6D6D8D6D5D5D6D5D6D5D4D6D3D0D1D0CF
D3CFCED9D8DAE3E2E2E5E6E6E6E6E7E9E9E8E4E6E5E1E1E2DDDDDBDCDBD9DBD9D7D6D4D2
D7D4D2D9D6D5DDD9D8DCDCDBDFDEDDDFDDDCDCDCDBDCDBDADAD8D6DADCDCD9D4D1DFE2E2
DFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE2E2
DEE2E3DEE1E2DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE0E1DEE1E2DEE1E2DEE2E2DEE1E2DEE1E2DEE1E2
DEDFE0DEE0E1DEE1E1DEE0E0DEE0E1DEE1E2DEE1E2DEE0E0DEE1E1DEE1E2DEE1E2DEE1E1
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE1E2DFE2E2DFE1E2
DEE1E2DEE0E1DDE0E0DEE1E1DFE2E2E0E3E3E2E5E6E2E5E6E0E3E3DCDFE0DADCDCD7D8D9
D5D7D7D8DADADBDDDDDCDFDFDEE2E1EAECECECF0EEECF2F0EEF1EEEDEAE6E6E0D9EAE5DC
E6E0D9E7E1DBE5DFDDE6E2DEE9E5E2E9E5E3E5E0E0E8E5E2E1DFDDDFDCDBDFDCDCDDDBD9
DFDBD8DCD8D8DFD6D6DBD3D3DDD5D5DFD5D7E1DBD6E0DAD5DDD9D5DDD8D3DDD5CFD9D3CE
DAD1CCDED6D4E3DBD8E5DEDAE6DED9E5DCD7E1D9D3DBD1CDD7CDC7D6C9C3D5C8C1CFC1BC
D0C2BCD2C4BFD6C8C2D6CBC6D8CEC8D9CCC7D6CCC7D6CBC5D3C8C1CEC5C0D4C8C3DFE2E2
DFE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE0E1DEE1E2DEE1E2DEE1E2DEE0E0DEE1E2
DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
DEE1E2DEE0E0DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2DEE1E2
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0362812 0.97619 0.489796 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -53 0 ]
[.5 1.0125 53 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Decomposed) show
129.000 12.813 moveto
(30) show
141.000 12.813 moveto
(oder) show
165.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
E5DADBE5DCDCE5DBDBE5DBDCE5DBDBE5DCDDE5DCDDE5DBDBE5DBDCE5DCDDE5DCDDE5DBDC
E5DCDDE5DCDDE5DCDCE5DCDCE5DCDDE5DBDBE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDCE5DBDCE5DCDCE6DDDDE6DDDEE6DDDEE6DDDFE5DDDDE3DADBE2D8D8E1D6D6
E1D6D6E3D8D8E4DAD9E3DADBE5DDDDEDE6E6EFEAE8EDEAE8F0E6E3EEDAD4EBCDC0EED2C3
ECCFC2EDCFC5EBD0C7EBD3CBECD6CEEDD5D0EAD3CDECD7CFE9D4CEE8D1CEE8D2CEE5D0CB
E7CFC7E4CECAE5CCC4E3CAC2E2CAC5E1C8C3E5CBC0E5CABEE1C7BDE0C6B9E1C2B5E0C1B6
DFBEB2E0BFB4E2BFB4E2BFB4E2BFB2E2BCB0E0BBAFDBB5A9D9B5A6DAAFA3D9B0A3D5AA9E
D5AB9ED6AB9FD7ADA0D7AFA3D7B0A2DAAFA3D6AFA3D7AFA1D5AF9FCAA395D7B7AEE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDBE5DCDDE5DCDDE5DCDDE5DBDBE5DCDC
E5DBDCE5DCDDE5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DADBE5DCDDE5DCDDE5DBDCE5DCDDE5DCDDE5DCDD
E5DADBE5DCDDE5DADBE5DBDCE5DADBE5DCDDE5DDDDE5DBDBE5DADBE5DCDDE5DCDDE5DADB
E5DCDDE5DDDDE5DBDCE5DBDCE5DCDDE5DADBE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADBE5DBDCE5DCDCE5DBDCE5DBDCE5DBDC
E5DCDDE6DDDDE5DCDCE4DBDBE5DCDCE9E1E2EAE4E4E8E1E2E6DBDBE4CCC5E4BDAAE6C2AE
E6C2AFE6C2B1E7C3B5E6C6BAE7C6BAE7C6BCE7C5B9E7C8BBE8C9BEE8C8BEE8C8BDE4C6BB
E5C4B4E4C5B9E0C0B0E2BEAEDEBEB0DBB9AAE0B9A5DEB7A4DBB3A2D9B19ED7AF9CDAAE9D
D6AA98D4A793D3A490D1A18ECFA08CD09E8BD2A08DCF9D89D0A18DD29C8AD1A08CD19B89
CF9D8ACF9B88CD9985CD9A87CA9884CE9886CA9986CB9A85CB9B84BA8B76D1AEA3E5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DBDBE5DBDC
E5DADAE5DCDDE5DCDCE5DADBE5DCDDE5DCDDE5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5D9DAE5DCDDE5DCDDE5DADBE5DCDDE5DCDDE5DCDD
E5DADBE5DCDDE5D9DAE5DBDCE5D9DAE5DCDDE5DDDDE5DBDCE5DADAE5DCDDE5DCDDE5DADA
E5DCDDE5DDDDE5DBDCE5DBDCE5DCDDE5DADBE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DDDDE5DCDDE5DCDCE5DBDCE4D8D9E4DADAE5DBDCE6DDDDE6DEDFE7DFE0
E8E1E2E7E0E1E6DDDEE5DCDCE5DBDCE4DBDCE4DCDFE3D9DCDED4D6DCC0B9DEB19ADFB69F
E1B8A3E0B8A3E2B9A7E1BCADE2BAABE1BAABE3BBAAE1BCABE5C0B0E6BFAFE5BFAEE1BDAD
E1BAA4E1BCAADBB5A0E0B49ED9B39ED5AB95D9A990D6A78FD3A28BD19F88CD9D87D29C87
CC9A82C9957AC59076C18C74BF8A71BE8871C48C74C48C73C79179CA8F78CA937CCE917A
CA927BC98F77C48C73C48B74C08970C48871C08A72C18B71C28D71B17F67D0ADA2E5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DBDCE5DBDB
E5D9DAE5DCDDE5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5D9DAE5DCDDE5DCDDE5DADBE5DCDDE5DCDCE5DCDD
E5DADBE5DCDDE5DADBE5DBDCE5D9DAE5DCDDE5DCDDE5DBDCE5DADBE5DCDDE5DCDDE5DADB
E5DCDDE5DCDDE5DBDBE5DBDBE5DCDDE5DADBE5DBDBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DDDDE5DCDDE5DCDCE5DBDCE4D8D9E4D9DAE5DBDCE6DDDEE7DFE0E8E0E1
E8E1E2E7DFE1E6DEDFE6DDDDE5DBDCE0D6D7DFD4D7E0D4D6DDD4D7DABBB2DDAE96DEB39B
E0B5A0DFB59FE0B6A3E0B9A9E0B6A6DFB6A5E1B8A6E0B8A6E3BBA9E4BAA7E4BAA7DFB8A5
DDB5A0DFB6A3D9B09BDFAF98D6AC96D4A58ED7A188D29F85CF9981CD977EC8957DCD937D
C99279C78F74C18A6FBE876EBA8269B7816ABE846BBF866CC28A71C48A71C58E75CB8D74
C68D74C78A70C1876CC1876DBE856BBF846BBD856CBD866BBD8668B7866FD5B6AEE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DBDCE5DBDB
E5D9D9E5DCDDE5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5D9DAE5DCDDE5DCDDE5DADBE5DCDDE5DBDCE5DCDD
E5DADBE5DCDDE5DBDCE5DBDCE5D9D9E5DCDDE5DBDCE5DCDCE5DBDCE5DCDDE5DCDDE5DBDC
E5DCDDE5DCDCE5DBDBE5DBDBE5DCDDE5DBDCE5DBDBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DADBE5DADBE5DCDDE6DDDDE6DEDFE7DFDF
E6DEDFE5DDDEE6DEDFE7DFE0E5DCDDDED3D3DCCED0DFD2D3E0D9DCDEBBB1DFB29AE1B7A0
E2B8A5E2B9A4E2B8A7E2BCACE1B8A8E1B8A7E3BBAAE2BAA9E3BBA9E3B9A5E4BAA6DEB6A5
DCB6A4DFB5A4DBB19FE0AF9AD7AB95D7A490D99F8BD39E86D09782CE9680CB947DCC917C
CB917BCC937BC78F78C59079C18670BA8671BF866EC18A72C08872C38B72C38E76C98F75
C58C73C78971C2896FC38A71C38A71C0876EC08971BE8870BE876AC69B8ADCC7C2E5DCDC
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDCE5DBDC
E5D9DAE5DCDDE5DCDDE5DBDBE5DCDDE5DCDDE5DCDDE5DBDBE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DADBE5DCDDE5DCDDE5DBDBE5DCDDE5DBDBE5DCDD
E5DADBE5DCDDE5DCDDE5DBDBE5D9D9E5DCDDE5DBDBE5DCDDE5DCDCE5DCDDE5DCDDE5DCDC
E5DCDDE5DBDCE5DBDBE5DBDBE5DCDDE5DCDDE5DBDBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DBDBE5DCDDE5DCDDE5DCDDE5DDDD
E4DBDBE4DADBE7DFE0E9E1E2E6DEE0DED2D2DCCBCCDFD2D1E5DFE1E3BEB0E3B8A2E5BDA8
E5BDADE6BFABE5BDADE5C0B2E3BCADE4BCACE5BFB1E5BEAFE4BCACE2B9A6E4BBA9DDB7A7
DBB8ABDFB5A8DEB4A6E1B1A0D9AC99DCA798DDA192D6A08CD29987D29987D09682CD9280
CF9482D49A88D09886CF9C89CC8F7EC18F7FC48D77C6917EC28B77C49078C4917CC9947A
C58E76CA8C76C58E76C79079C9927BC38E77C49079C28E78C28C72D5B5ABE4D9D9E5DCDC
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDC
E5DADBE5DCDDE5DDDDE5DBDCE5DCDDE5DCDDE5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDCE5DCDDE5DCDDE5DBDCE5DCDDE5DADBE5DCDD
E5DADBE5DCDDE5DDDEE5DBDBE5D9DAE5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDBE5DBDCE5DBDCE5DCDDE5DDDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDEE5DBDCE5DCDDE5DCDCE5DBDCE4DBDC
E3D9DAE3D9DAE6DEDFE8E1E2E6DFE0E1D6D6DFD0D0E2D6D6E9E3E3E6C0AFE6BEA9E8C2AF
E7C1B2E8C2B1E6C0B2E7C3B5E5BFB0E6C0AFE7C3B6E7C1B3E4BDAEE1BAA9E4BDACDEB9AA
DBBAB1E0B7ABE1B7ADE3B4A7DCB09FE1ACA1E1A69BD9A493D69E8ED79F8FD59B89CF9686
D4988ADAA093D8A193D7A697D5978AC8978ACA937FCB9787C68E7DC5947EC69581CA9880
C7917CCC907CC9937DCB9580CE9783C6947EC89580C69480C7937DDFCDC9E8E6E9E5DCDC
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDEE5DCDDE5DCDDE5DCDCE5DCDDE5DBDC
E5DBDBE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DADBE5DCDD
E5DBDCE5DCDDE5DDDDE5DBDCE5DADBE5DCDDE5DADBE5DCDDE5DDDDE5DCDDE5DCDDE5DDDD
E5DCDDE5DBDBE5DBDCE5DBDCE5DCDDE5DDDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDEE5DCDCE5DCDDE5DCDCE4DBDCE4DBDB
E4DADBE4DBDBE5DBDCE5DCDDE6DDDEE7DFE0E7DFDFE8E1E1E9E1E1E6BEABE7C0ABE8C2AF
E7C1B2E7C1AFE6C0B2E7C2B4E5BFAFE6C0AFE7C2B6E7C0B3E4BDAFE1BBABE4BFAEDFBCAE
DEBDB4E1BAAFE3BBB1E4B8ACDEB5A5E4B3A9E3ADA3DCAA9ADBA495DBA695D8A18FD39B8C
D89D8FDDA497DBA497DBA89AD99C8FCD998DCE9584CE9889C88F7FC79480C89683CB9982
C79480CC937ECA9580CC9682CE9783C79680C89581C89682CC9A88E4DAD9E9EAEEE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDDE5DCDDE5DCDDE5DBDCE5DCDDE5DBDC
E5DBDCE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADBE5DCDD
E5DBDCE5DCDDE5DCDCE5DCDCE5DBDCE5DCDCE5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDCE5DCDCE5DCDCE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDDE5DCDDE5DCDDE5DCDDE4DBDCE4DBDB
E6DDDEE6DEDFE2D7D7E0D5D5E4DADAEFEAEAF0F2F2EEEBEDE7DBDAE4BBA5E6BFA9E6C0AB
E6BFACE4BDAAE5BEAEE5BFAEE3BCAAE5BDADE6BFB3E6BEB0E3BDAEE2BDAEE3C0B0E2C0B2
E1C0B5E3BEB1E4BEB2E4BDB0E1BCADE5BBB0E4B5A9DEB0A1DFAB9BE0AD9ADAA794D7A293
DBA193DDA596DBA394DBA495D99D8ED09789D09484CF9585CB8F7FC7917ECA9682CC9882
C89783CA947FCB9580CB9580CC937EC8957EC5927CC99580D1A192E5DDDDE8E6E9E5DDDD
E5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DBDBE5DCDDE5DBDC
E5DCDCE5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDD
E5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDD
E5DCDDE5DCDCE5DBDBE5DCDDE5DCDDE5DBDCE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE4DBDCE5DBDB
E8E0E1E8E1E2E0D4D5DBCFCFE2D6D5F3F1F1F5FFFFF0F0F3E4D3D2E1B7A0E5BDA7E4BDA6
E3BCA6E1B8A4E3BBA9E3BBA9E2BAA6E4BBABE5BDAFE4BCACE3BDAEE4C0B1E4C1B3E4C4B5
E5C2B5E5C1B3E5C1B3E5C2B3E4C3B4E5C4B7E4BDAFE1B8A7E3B3A2E3B59FDCAF99DBAA99
DEA697DCA594DBA290DAA08FD99E8CD29484D29283CF9180CD8E7DC88D7BCB947FCC9581
C89884C9947ECB957FCA927EC88F78C9937CC28E77CA947DD7AA9FE5DCDDE6DFE0E5DDDE
E5DCDCE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DBDBE5DCDDE5DCDDE5DADBE5DCDDE5DBDC
E5DCDDE5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDD
E5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDCE5DADBE5DDDDE5DDDDE5DBDBE5DCDCE5DCDDE5DCDCE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE4DCDCE5DBDC
E8E0E1E8E1E2E1D5D6DCD0D0E2D6D6F1EEEFF2FAFAE9E5E7E1CAC6DFB69EE4BCA6E3BBA4
E2BAA3DFB6A2E2BAA7E2B9A6E2B9A4E3BAAAE4BBADE4BBABE4BEAFE5C2B3E4C2B4E7C6B7
E7C3B4E7C3B4E6C3B4E6C6B6E6C8B9E5CABAE4C3B2E3BDACE6BAA7E6BBA4DEB59DDFB09F
E0A99ADCA692DBA28DDA9D8BD99F8BD59381D49282D08F7CCF8F7CCA8C7ACC937DCC937F
C89884C7957ECA947EC9917CC78D76C9927BC18D75CB937CDCB5AEE5DBDBE4D9D9E5DDDE
E5DCDCE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DADBE5DCDDE5DCDCE5DADBE5DCDDE5DBDC
E5DCDDE5DCDDE5DADAE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDBE5DCDD
E5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDDE5DCDD
E5DCDDE5DADBE5DADBE5DDDDE5DDDDE5DBDBE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDC
E5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE6DDDEE5DDDDE5DCDCE6DDDEE6DFE0E2DADAD4C4C4DFC2BAE0B7A0E3BCA7E2BAA4
E2BAA4E0B8A5E3BAA7E2B9A8E2BAA6E3BBACE4BCADE4BCACE5C0B2E5C3B5E5C2B4E7C5B6
E8C2B2E7C2B2E6C3B3E6C6B7E7C7B9E5C9B9E5C2B1E4C0AFE7BDABE6BDA6E0B9A1E1B4A1
E2AA9ADDA792DCA28DDB9D8BDBA18DD79583D59483D2907CD1917DCD8E7BCD937DCC927E
C79681C7957EC8937DC8927DC78F78C9937DC48F78CB957EE1C4C1E5DBDCE3D6D5E5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADBE5DCDDE5DBDCE5DADBE5DCDDE5DBDC
E5DCDDE5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDBE5DCDD
E5DBDBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDDE5DCDD
E5DCDDE5D9D9E5DADBE5DCDDE5DCDDE5DBDBE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDD
E5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE6DCDDE6DDDEE6DEDF
E1D6D7E2D7D7EBE6E7F0ECEEE9E6E8D4C6C7C7ACABB39894DEB9ADE2B9A4E3BDA9E3BBA7
E3BCA9E2BCABE4BCAAE3BCACE4BDACE4BDAFE5BDAEE5BFAFE6C3B4E6C3B6E5C1B2E7C2B4
E7BFAFE6BEAFE6C2B3E5C3B5E6C3B5E5C4B3E4BDACE5BFAEE6BDABE4BCA5E2B9A2E3B4A1
E3A998DFA893DDA38FDD9F8DDEA291D89987D69885D4947FD2957FD0917FCD937DCC927D
C7927DC8957FC6927CC8947FC9947ECA9681C8937DCB9882E4D3D4E6DDDEE3D6D5E5DBDB
E5DDDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADBE5DCDDE5DBDBE5DBDCE5DCDDE5DBDC
E5DCDDE5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDD
E5DBDBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5D8D8E5DBDCE5DBDCE5DCDCE5DBDCE5DDDDE5DCDCE5DCDDE5DBDCE5DCDDE5DCDD
E5DCDDE5DBDBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDDE5DCDDE5DCDCE4DBDCE6DCDDE7DEDFE6E0E1
DED2D2DFD2D1EFEDEEF8F8FBEAE9EDC0ACABA6817E90716ADDB3A2E4BCA8E3BEACE4BCAB
E4BDAEE4C1B1E5BEAEE5BFB1E5C0B1E5BFB2E5BFB0E6C2B3E7C4B6E6C3B5E6BFB0E5BEB0
E5BBACE4BBABE5BFB2E4C0B3E6BDB0E5BDABE4B6A6E5BAABE4BBA9E2B7A3E3B7A1E3B29E
E3A795DFA894DEA491DFA190E0A394D99C8BD59B85D59882D39881D39582CC937ECC917C
C78F78C8957FC4917BC79580CB9984C99884CC9783CB9A86E5DFE2E6DEDFE4D7D6E5DADA
E5DDDEE6DDDEE5DCDCE5DCDDE5DCDDE5DCDCE5DBDCE5DCDDE5DADBE5DCDDE5DCDDE5DBDB
E5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDD
E5DBDBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5D7D8E5DCDDE5DBDBE5DBDCE5DBDCE5DCDDE5DBDCE5DCDDE5DBDBE5DCDDE5DCDD
E5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDDE5DCDDE5DCDCE4DBDCE6DCDDE7DEDFE7E0E1
DFD4D4DFD2D2EEECEDF6F4F6E3DCE0AE94918D66607D5E54DDB09CE5BEACE3BEAEE4BCAE
E5BFB2E5C4B6E6BFB0E6C1B4E6C2B4E6C1B4E5C0B0E6C2B3E6C4B6E5C2B4E6BEAFE4BDAF
E4BBACE3BAAAE4BFB2E4BEB2E5BAACE4BAA7E3B2A2E3B7A7E2B8A6DFB3A0E2B39EE2AF9A
E2A693DEA894DEA592DEA391DFA394D79E8CD49C85D59A84D39981D49884CC937ECC917B
C78C75C8947EC3907AC7957FCC9C86C99885CF9A87CB9C89E5E5E8E6DEDFE5DADAE5DADB
E5DDDFE6DDDEE5DCDCE5DCDDE5DCDDE5DCDCE5DBDCE5DCDDE5DADBE5DDDDE5DCDDE5DBDC
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDD
E5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDD
E5DCDDE5D8D9E5DCDDE5DADBE5DADBE5DBDCE5DCDDE5DBDBE5DCDDE5DADBE5DCDDE5DCDD
E5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDCE6DDDE
E5DDDDE5DCDDE7E0E1E3D9D9CFBBBCA1827D8C615989675BDFB29DE6BEAEE4BEAEE5BDB0
E5BFB3E6C5B7E6BEB1E6C1B4E6C2B5E6C1B4E5BEB0E5BEB0E5C0B3E5C1B3E5BEB0E4BFB1
E4BFB0E4BDADE5C2B5E5C0B2E4BCACE5BCA8E2B4A4E1B5A3E0B6A2DEB39FE0B19BDFAE98
DFA994DCAA94DBA892DAA590DBA291D49E89D29A82D49983D39780D39984CD947ECC917A
C88C74C7927BC49079C6947DCB9A83C99783D09B87CB9D8BE4E0E2E5DDDEE6DFE1E5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADBE5DDDDE5DCDDE5DBDC
E5DCDDE5DCDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDD
E5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDD
E5DCDDE5DADBE5DCDDE5DADBE5DADBE5DBDCE5DBDCE5DADBE5DCDDE5DADAE5DCDDE5DCDD
E5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE4DBDCE5DCDCE6DDDDE6DEDFE4DBDCE2D9DAE3D7D7
EEE9EAECE9EBDACCCCC4B1AFB0928D9D796F9E6E65AB8475E2B7A4E5BEAEE4BDAEE5BEB0
E5BFB2E6C3B6E5BDB1E5BFB1E5C0B2E5C1B3E5BAAFE3B8AAE3BCAEE4C0B2E5BFB2E4C4B6
E4C6B6E6C2B2E5C6B8E6C4B4E4C1AFE6C2ADE2B9A8DFB4A0DEB49EDDB39EDCAD97DCAC95
DCAC96D9AB93D8AB92D4A58CD5A18BD09B84D0967ED3977FD4957FD19983CE957ECD907A
CA8D76C59178C59079C69179C8957ECA9580CF9A85CC9D8AE2D5D3E4DCDCE6E4E6E5DFE0
E5DADBE4DBDBE5DCDDE5DBDCE5DBDCE6DDDDE6DDDDE5DCDDE5DBDCE5DCDDE5DCDDE5DCDC
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDD
E5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDCE5DCDDE5DADBE5DADAE5DBDBE5DADBE5D9DAE5DCDCE5DADAE5DCDDE5DCDD
E5DCDCE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE4DADBE5DBDCE6DDDEE7DFE0E3DCDDE0D8D8E1D1D1
F3F1F2F1F2F5CBB5B4A38A868F6D659F7669B88579D2A998E5BDACE5BDAEE5BDAEE5BEB0
E5BFB1E5C1B4E5BCB0E5BDADE4BFAFE5C0B1E5B9AEE2B3A6E1B8AAE4C0B1E4BFB4E4C7B9
E5CCBBE7C7B7E6C9BAE7C6B4E3C3B0E7C5B0E1BAAADCAF9ADDAF99DCAF9AD9A892D9A891
D9AC96D6A990D5AA8FD0A388CF9F85CD967ECD927BD1947CD3927DCE9881CF967DCD9079
CB8F78C39075C89078C68F76C69077CA937CCD9782CC9C89DEC6C0E3D8D7E6E6E9E5E0E1
E4D9D9E3DADAE5DCDEE5DBDCE4DBDCE6DDDEE6DEDEE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DBDCE5DADAE5DBDBE5D9DAE5D9DAE5DCDCE5DADAE5DCDDE5DCDD
E5DCDCE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE4DADBE5DBDCE6DDDDE7DFE0E4DCDEE1D9D9E1D2D3
F2EFF0EEEBEEBB9F9B8D726C805D52AA7D6CD09C8FEDC6B4E7C2B2E5BDAEE5BDAEE5BFB1
E5BFB0E5BFB2E5BCAFE4BCABE4BEADE5C0AFE5BAAEE2B4A6E2B8AAE4BFB0E4C0B5E5C8BA
E5CBBBE7C8BAE6C6B8E7C2B1E3BDAAE7BDABE1B1A3DBA390DBA38FDBA390D69D8AD79D89
D7A390D4A18BD4A48BCF9E83CD9B80CD937BCC917BCE947BD1907BCA957ECF957CCD907A
CC907AC38F73CA9078C78D74C58C73CB917ACB957FCB9A86D9B6ACE1CECBE6E1E4E5E0E1
E4D9D9E3DADAE5DCDEE5DBDCE5DBDCE6DDDEE6DDDEE5DCDDE5DCDDE5DCDCE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DBDCE5DADBE5DADBE5D9DAE5D9DAE5DCDDE5DADBE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDCE5DCDCE5DCDDE6DDDEE6DEDF
E6DEDFDED0D1AD8C848E72698F695BBD8E7CDFAFA0F6D0BEE7C2B2E5BDAFE6BDAEE5BFB1
E5BEAFE5BFB0E5BDAFE5BDAAE4BEABE5C0ACE5BEAFE5BEAEE5BDAEE5BFB1E5C2B4E5C4B6
E6C4B6E5C5B8E6BCAFE6B7A7E1AA9BE5A79ADE998ED88E7FD98E80D78C7DD58D7ED58C7B
D78F81D59180D79784D39580CF967ED1937CCB937DCC957DCD9079C68F78CC9079CC907A
CC917AC48F74CB9078C88D74C58B71CB8F78CA927CC99782D3A799DDBEB6E4D4D3E5DDDE
E5DDDEE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDDE5DCDCE5DCDDE5DCDC
E5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDCE5DCDDE5DCDDE5DBDBE5DADBE5D9DAE5DADBE5DCDDE5DBDCE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE7DFDFE5DDDDE3DADBE2D7D8E7DCDCEBE2E3EBECEE
D2C4C4C4ABA7A37E72A38376B38A7AD2A593E5BBABF1CAB8E7C0AEE5BEB0E5BEAFE5BFB1
E5BDB0E5BFAFE5BEAFE6BEAAE4BDA9E5BEA9E6C4AEE8CAB7E9C4B6E6BEB1E6C4B3E6BCAF
E6B7ABE1BEB3E4AFA2E2A79ADD9387DF8B81D77D71D4776AD4786DD07365D57C71D2796B
D5776BD67F71DB8679DB8B7BD4907DD89380CA9681C9977FC89077C28872C78974CB907A
CC917AC79076CC8F78CA8E76C68C73CB8F79CA8F7AC6937ECD9B89D6AB9DE0C2BCE5D8D8
E6E1E3E8DFE0E5DCDCE6DDDEE6DDDEE4DADCE4DADCE5DBDDE5DDDDE5DCDDE5DCDDE5DBDC
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DADBE5DCDDE5DCDDE5DBDCE5DADBE5DADBE5DBDCE5DDDDE5DCDCE5DCDDE5DCDD
E5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDCE6DDDDE9E1E2E6DEDFE2D9DBE0D4D5E8DBDBEEE4E5ECF3F5
BBA6A5A888809F7667BF9B8AD9B1A0E4BCABE8C3B3E7BEADE5BDA9E5C0B2E5BEB0E5BEB1
E5BCAFE5BEACE5BEACE6BDA8E4BBA5E5BBA4E6C6ACEAD3BEEDC9BBE7BCB0E7C2AFE6B3A6
E5A99FDDB5ABE2A195DE998DD78075D7756BCD6657CF6658CE675DC75F50D46F66CE695C
D06254D56E61DC766CE07F74D7887ADC8F80C89782C79780C39075BF836DC38471CA907A
CB9179CA9079CC8F79CC907AC88E75CB8F7ACA8D78C48F79C7927CCE9985DAAFA3E4D0CF
E7E2E5E9E1E2E5DBDBE6DEDEE6DFDFE2D9DBE2D8DBE4DBDDE5DCDDE5DCDDE5DCDDE5DADB
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DBDBE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DADAE5DCDDE5DDDDE5DCDCE5DADBE5DADBE5DBDCE5DCDDE5DCDDE5DCDDE5DCDD
E5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDCE6DDDDE9E1E2E6DFE0E3DADCE1D6D6E8DCDCEBE0E2E2E2E3
A58A8798756AA57A67D7B19CF3D0BEF0CDBDE8C6B5DEB4A2E4BBA6E5C0B3E5BEB0E5BEB1
E5BCAEE5BEAAE5BCA8E4B8A2E3B69FE4B7A0E6C4A9EAD0BDECC7B9E6B8ADE6BAA8E5AA9E
E39D96DAA7A1DE988DDA8F84D2776ED26D64C85E4ECF6257CC6157C15848D46C64CC6356
CA5847D16357D6695FDC7269D57E73D98478C78F7EC5927DC28E73BF846DC1846FC99079
CB8F78CC917BCC8F79CE927DCA9078CC907BCB8C77C38D76C48D75C78D75D3A18FE2C6C1
E6DDDEE8DFE1E4DADBE6DEDEE6DEDFE3D9DBE2D9DBE4DBDDE5DCDDE5DCDDE5DCDDE5DADB
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DADBE5DCDDE5DCDDE5DCDCE5DADAE5DBDCE5DBDCE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE6DDDEE6DDDEE5DDDEE6DEE0E0D4D7C6B3B3
9575709F7A6DB68975E4BDA7FAD8C7F3D1C0E7C3B1DCB09EE4BBA7E5C0B3E5BDB0E5BFB1
E5BCACE5BDA8E3B6A1E0AE96E0B098E3B59DE6BCA6E6BDB0E6BCAEE4B0A5E2A99DE3A196
E19791D89794DB958CD98C83D37D77D47874CD6A5FD5716DD06A61C16055D4756FCB675F
C45A4CC96055C86054CD645ACA7166CB7064C47F70C58773C58B72C48D72C38A70C89076
CB8D76CD907BCC917BD09680CB927ACD927CCB8B76C48D76C48B73C68970CF9883DDB7AE
E3D0CCE3D8DBE4DADCE5DDDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADB
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDCE5DCDDE5DCDDE5DCDCE5DADAE5DCDCE5DBDBE5DBDCE5DCDCE5DCDDE5DCDD
E5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DDDDE4DBDDE0D6D6E5DADBE9E1E0EBE6E7E2DEE2CFC2C6977874
8C6760B89181CDA18DE7C0AAF3CFBEEFCBB8E5BDA9DFB29EE4BDAAE5C0B2E5BDAFE5C0B1
E6BCA9E6BAA5E0AD97DAA087DCA88FE2B19BE5AFA0DDA199DBAB9CE0A79BDB9690E19A91
E09590D78987D89791D98F88D58F8CD99292D48581DB8F8FD77F75C6746DD38780CB756F
C0675CC0635BB65C4EB6584DBA6458B3594BBF6A5CC47966CA8671CA9979C69272C79071
CB8A73CD8F7ACD927DD29983CD947CCE947DCB8C76C78F78C68E76C88C73CD967FD5A899
DEBEB4DBCDD1E3D8DDE4DADBE4D9DAE8E0DFE8E0DFE6DDDCE5DBDCE5DCDDE5DCDDE5DBDC
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDCE5DCDDE5DCDDE5DBDCE5DBDCE5D9DAE5DCDDE5DADBE5DADBE5DBDCE5DCDDE5DCDD
E5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDD
E5DCDDE5DCDDE5DCDCE6DDDEE3DADDDCD0D0E3D6D6EAE1E1EEECEDD9D6DCBBABAF62453F
8C6259D5AD9CE3BBA7E6BFAAE7C0AEE8C0AAE1B49EE3B39EE5BFAFE5BFB0E5BCAFE5C0B0
E6BBA4E5B6A0DCA48CD39378D79D85E0AA96E29D96D08580CF998ADD9E91D48585DF968E
E09692D67E7DD79D9ADB958ED7A5A2DBB2B2D8A6A3DBB2AEDB9688C98E87D09C92CB8682
BD786CBA6A63A85C4EA25045A95A4C9B4737B65746C16A58CE7E6DCEA07EC99973C78F6C
CB8671CC8F79CD957FD49D86CF967ED0977ECC8D77CA917BC9917BCC927BCC967ECD9B86
D6AB9AD3C1C4E2D6DCE2D6D8E1D6D6EBE2E1EBE3E1E6DDDCE4DBDCE5DCDCE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDCE5DCDDE5DCDDE5DBDBE5DBDCE5DADAE5DCDDE5DADAE5DADAE5DBDCE5DCDDE5DCDD
E5DADAE5DCDDE5DCDCE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDCE5DCDCE6DDDDE3DADDDCD0D1E3D6D7EAE1E0EDEAEBC9C2C8A28D90412A24
96685CEAC5B1F0CDBBE5BEAADDB4A2E1B59EDEAD96E5B49DE5C0B2E5BEB0E5BDAFE5C0AF
E5B69EE2AE98D69A81CC886DD18E78DA9889D98382C26D67C58A7BDA9789CF7E7EDE9790
DF9894D87D7CD7A5A3DC9C94D8B8B3DBCCC9D9C0B9D9C9BFDCA794CCA49AD0AEA0CC9791
BD897AB8746DA565569951469E55458B4030AA4938BA5E4DCA7465CF987BCA9670C58D69
CB8570CC8F78CF9882D6A089D29982D29A80CD9079CC937DCC947FCF9682CC957EC79179
CE9C87CCB6B6DED0D7DDCFD4DFD2D4EAE1E0EAE2E0E6DDDCE4DBDCE5DCDCE5DCDDE5DDDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DADBE5DBDCE5DADBE5DCDDE5DADAE5DADBE5DBDBE5DCDDE5DCDD
E5D9DAE5DCDDE5DBDCE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDC
E5DCDDE4DADBE5DCDDE5DBDCE5DCDCE3DADCE6DDDEE7DFE0E6DFE0B09FA485696A4D322A
AD7B6DF1CDB8F3D2C0E5BEAADAB19EDEAF98DDAA93E5B29BE5C0B3E5BEB0E5BEB0E5BFAE
E3AE96DDA38CD19176C78066C87A67CE7B72C56262B75E55C28274D99486D18381DF9E97
DF9C96DC8887DAADABDCA097DBC0B9DCD6D2DAC7BEDACABDDBA794D1AFA4D2B6A8D0A39B
C19383BC8078AD7769A25F549C57478B46389D4336AF554ABB6757C77E6BC68868C48A67
CB8872CC9079D19C84D8A38BD59E87D39D83CF947CCD947ECC9580CF9883CC937DC58E75
CA947DCAACA7D8C8CCD7C7CEDCCED2E5DADBE5DCDDE5DDDDE5DCDDE5DCDDE5DCDDE5DDDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDCE5DCDDE5DADBE5DBDBE5DBDCE5DCDDE5DADBE5DBDCE5DBDBE5DCDDE5DCDD
E5D9DAE5DCDDE5DBDBE5DBDBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDC
E5DCDCE4D9DAE5DCDDE4D9DAE8DDDCEDE7ECE9E5E7E1D8DBD9CACC8E76776549467A5349
C79887EEC9B3EFCBBAE7BEAADEB5A0DEAD97DFAB95E2AE98E6C0B3E5BFB1E5C0B2E5BDAB
E0A38ED5957ECB896DC57D64BD6757BB5E55A94440B15849C48072D99586D69189E1AAA2
DFA097E19D9ADEB5B2DDA497DFBEB7E1D0CFDEBDB6DCB7ACD99B8BD8ADA5D9B5AAD6A9A0
CA9689C58C82BC8F83B4766AA15F4E97594C94433CA3514BA65948B65C50BD735CC28667
CA8C75CC917BD49F86DAA48DD8A48DD59F86D2987FCD937DCB947ECD9681CB907AC79078
CA927ACAA598D1BDBDCFBDC6D8C9D0DCD0D2DDD2D8E4DBDFE6DEDFE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DDDDE5DBDBE5DCDDE5DBDBE5DBDBE5DCDDE5DCDDE5DBDBE5DCDCE5DBDCE5DCDDE5DCDD
E5D9DAE5DCDDE5DADBE5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADB
E5DBDCE3D9D9E5DCDDE3D7D9EADDDBF4EFF6E8E6E8D8CCD0C8B0B2684F4D4C322DAD7E74
DFB7A3E6C0AAE6C0AEE8BEA8E3BAA4E0AD98E1AE98E0AC96E6BFB2E5BFB2E6C1B3E5BAA9
DB9885CD8971C68465C57D66B65A4CAA4A40903127B25847CA8376DB9889DDA294E1B6AC
DFA598E3B5ACE2BCB6DDA697E4B8B0E6C4C6E1AEA7DDA196D68C7FDFA7A1E0AEA8DCAAA0
D4958BCE968ACBA79CC69080A96A57A571638F48459A504F924D3B9E3E34B25D4DBF8066
C88D76CC927BD6A287DCA58FDAA992D6A18AD49C83CC927CCA927CCA937DCA8C78CA947D
CB927CCB9F8CCAB2ADC7B3BED2C2CBD3C5C9D5C8D2E2D9DFE7DFE0E6DDDEE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DDDDE5DADBE5DCDDE5DBDCE5DBDCE5DDDDE5DCDDE5DBDCE5DCDDE5DBDCE5DCDDE5DCDD
E5DADBE5DCDDE5DADBE5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADB
E5DCDCE3D8D9E5DCDEE3D7D9E8DCDAF0EAF1DDD3D3C8B2B5B28F8F46302C4B2F28D3A59B
EFCEB7E0B8A3DFB7A4E6BCA5E7BCA5E2AE99E3B19CDEAA95E5BEAFE5BFB1E6C1B2E4B7A5
D7917FC67F66C38062C9816CB85B50A7473D8D3025BA6250D28A7DDE9D8FE1B19CE2BFB3
DFAA9BE3C6B8E5C0B8DEA897E7B2A9E9B8B9E1A198DB9183D38277E4A09BE4A4A1E0A69B
DB9189D5998DD5B5AAD2A08DB37360B1867592504E98535486463586291DA54A3FBA7761
C58872CC927BD7A287DDA690DDAC96D8A38ED59F85CC927CC9907AC8917AC98A76CD9681
CC937ECC9A82C5A99FC0ABB4CCB8C0CEBDC1D0C1CDDFD4DCE6DEDFE5DDDDE5DCDDE5DCDC
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADAE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DADBE5DCDDE5DBDCE5DBDCE5DDDDE5DCDDE5DCDCE5DDDDE5DBDCE5DBDCE5DCDD
E5DBDBE5DCDDE5DADBE5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADB
E5DCDDE3D9DAE5DCDDE5DBDBE3D8D9DDD0D6C1A7A2AC8A8A936A66311F1A6B453BE4B9AD
F3D5BCDFB5A1DEB4A0E4B9A2E7BAA3E2AE9AE3B29DDDAA95E5BDACE5BCAFE5BEAEE3B5A2
D58E7BC27A60C48062CE8A77C77068BA5B57A64742C97666D99488E0A496E3B6A0E2C0B3
E0AE9FE3CABAE5BFB5DFAA99E7ADA3E9AFADE09B8FDA8D7DD48276E49B94E39A95DF9D91
DD8B83D79488D9B1A6D59E8BBB7866BC917D9E5A579E5B5A884636761F14993B32B26A58
BF7A68CA8E77D69F84DEA793DEAD97DAA691D6A187CC937CC99079C69178C88A75CD9480
CD937DCC977DC5A294BBA3AAC3ABB0CCB8BBCFBDC8D9CBD4E4DADAE5DCDDE5DCDDE5DCDC
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DBDCE5DADBE5DCDDE5DCDCE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DADAE5DCDD
E5DBDCE5DCDDE5DBDCE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDB
E5DDDEE4DADBE5DCDCE7E0DFDCD2D8BFABAF957167865F5A7148412F1A149D6D61E5BBAE
EFCEB5E2B6A3E1B5A0E1B59EE4B49FE1AE9BE2B29CDCAB95E4BCA8E5B9ABE4BAA9E1B29F
D38F7AC2795FC78266D59684D7938AD28481CA7472D89184E0A095E2AC9EE2B4A0E3BCAE
E1B2A3E3C4B4E4BCB0E0AB9CE6AA9FE8AAA3DD9B8DDA9382D6897CE0998EDF9288DA9384
DA857CD48A7DD8A193D08F7CC27968C6917DAF665EAA675F944C3E731E18903229A95D4C
B86859C78A73D49A80DEA995DEAC96DDA793D6A187CC937DCB917BC69177C68B74CD907C
CD917BCC957CC89F8DB89EA0B89B9BCDB4B6D1BDC5D3C2CAE0D3D4E4DBDBE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DBDBE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5D8D9E5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDC
E5DEDEE5DCDCE6DDDBE8E4E2D4CBD5A08889654539623F375531283D2016CD9B8FE1B6A8
E7C1AAE5B7A6E5B9A2DEB39CE2AF9CE0B09CE1B29CDCAC96E3BBA5E5B7A8E3B6A4DFB09C
D3927BC47B61CB866CDAA08FE1BAAAE3B7ABE3AFA5E4B0A3E5ADA2E3B3A6E2B0A0E3B6A8
E2B5A8E3BAACE2B7AAE1ACA0E5A89DE5A79ADA9C8CDA9B88D99383DC9788D98A7CD38978
D58074CF7F71D18D7CC77D6AC87868CE8C77C27264B87363A555497823228C2F26A15442
AF594BC5856FD1947BDCAA96DEAA94DEA994D6A186CD947ECC927BC69177C48C74CB8C77
CD8F79CC947DCC9C87B69A97A88783CCB0B0D4BFC4CFBCC3DDCECFE4DADBE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DADBE5DCDCE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5D8D9E5DCDD
E5DDDDE5DCDDE5DDDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDD
E5DEDEE5DDDEE6DDDCE8E3E2CFC3CE8B726F50342758362C542F235C3223EBC1B4DCB1A2
DFB69FE8B8A7E8BBA4DDB29CE1AE9DE1B2A0E1B29DDCAF9AE3BBA3E5B6A6E3B4A1DEAF9B
D4967FC88167CE8A71DCA594E4D3BAE8DDC4EBE0C5E9C8BAE7B9ADE4BAADE2AFA2E3B2A4
E3B8ABE3B2A6E1B5A6E2AFA3E3A89BE2A493D89E8CD9A18CDA9A88D79784D48774CE8370
D17E6FCA7969C97F6ABF725DCB7868D28770CE7C67C27E66B3605486303291332C9F513F
AA5244C2816BCE8F77DBA894DDA792DFA893D59F85CD937DCC917BC69176C38C73C98973
CC8E78CC947FCF9A82B59892927069C7A9A8D7C3C6D1BDC3DDCECFE4DADBE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDCE5DCDDE5D9D9E5DCDD
E5DDDDE5DCDDE5DDDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE6DDDEE5DCDDE4DCDDCDBAC28D6F696C4838774D3F77473888513EF1D0C2DCB2A0
DCB19CE8B8A7E8BCA4DEB49FE2B1A0E2B6A4E2B4A1DFB39FE3BCA5E5B7A7E3B5A2DFAF9B
D69B84CE8870D08C74DBA08EE3CFB3E8E3C4ECEDCCEBD3C4E8C2B5E4C0B3E3B3A7E4B3A6
E4BAADE3B2A4E1B7A7E3B2A7E2AA9BE0A390D89E8BD7A18BDA9D89D69984D28973CD8570
CE826EC87A68C47C63BD715CCA7A69D0846CD0816AC68368BC6C5E9844449F433CA55945
AC5746C18069CB8C74D8A48DDBA58FDDA690D49D84CC917BCA8F79C68F75C38C71C88A71
CB8E78CC9480CE977FB49790755751BA9E9CDACACCDACACEE2D5D6E5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DBDBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDDE5DADBE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDD
E5DADBE6DDDEE4DCDFDFD0D5CDB1B3A07C72A37765AD7C6AAB7363B27965E8CABCDFB7A2
DEB29EE6B7A6E7BBA4E0B6A2E4B6A6E3BBAAE3B7A6E1B8A6E4BEA8E5BAA9E4B8A5E0B19D
D99F8AD4927CD08E76D69681DFB69CE5CEB3E9DDC0EAD1C2E7C7B9E5C3B6E4BBAEE4B8AA
E4BBAFE4B7A7E3BCABE4B7AAE3AE9CDEA490D99F89D69D85D89C88D69B85D28F77CE8C75
CD8971C8816CC08066BE7964C57D69C98369C9836BC48469BE7865AC6056AF5B50B16852
B26450C18069CA8A72D49E84D9A38DDAA28BD39A82CC8E78C88C76C58C74C38B70C78C71
CA8E78CB947FCB947DB39792573F3AA9908FDBD0D3E5DCDEE8E1E2E7DFDFE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DBDCE5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDDE5DCDCE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDEE4DCDE
E5D8D9E5DCDDE4DADFDAC4CCCFABA6BB9181D8AF9DDEB29ED9A796D3A58FD9BBADE2BBA4
E0B5A1E5B7A5E5BBA4E2BAA7E5BDADE5BFAFE5BAABE4BDADE5C0ADE6BEACE5BCAAE1B3A0
DDA391D99C87D19079D18C75D59880DEB19BE3C0ABE7C8BAE6C8B9E5C5B7E5C3B5E5BEAF
E5BBAFE5BDABE4C1B0E5BCADE3B49FDDA892DAA08AD59880D79A85D69E88D3967CCF957C
CC9175C98A71BE876CC0836DC08069C18167C0816AC08269BF8269BC7F65BD7863BC7B61
B9765CC2826BCA8A72D1997CD7A08AD69E86D19880CB8B76C58974C58973C48A6FC68F72
C98F78CB957FC7927BB297923C2B28967F7ED9D1D5EFECEBEDEAEBE8E1E1E5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDCE5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDEE5DCDD
E5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDEE5DCDD
E5D9D9E5DCDDE4D8DBD7BDC4D3AC9FD4A792F8D8C6FBD8C2F3CDB9E6C6AECCAEA0E4BDA5
E3B7A4E4B7A5E4BBA6E4BDABE6C1B2E6C2B2E6BEAFE6C2B4E5C2B1E5C1B0E5C0AFE2B5A3
DFA798DDA591D2947DCD866DCC836BD69984DCA696E4BDB0E4C6B7E5C6B7E6C9B9E5C1B3
E6BCAFE5C1AEE5C5B3E5C1AFE3B9A3DEAD98DBA38CD5977FD59984D6A18AD39B81D09B81
CA9678C89075BD8C70C18A73BB8268BA8065B97F68BD8068BF886AC6956DC58F6FC48A6C
BF8667C4856ECB8C74D09678D49D87D39A82D0957ECB8974C48772C58872C5896EC59174
C88F78CA947DC4907BB0948F291D1B816A6BD0C6CAF1F1EFEEEBECE8E0E1E5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDEE5DCDD
E5DCDCE5DCDDE5DCDCE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE4D6D4D8BDBFDAB4A2E3B9A3FEDDCBFFDBC3F7D2BCECD0B8CBA99CE5BEA6
E4B6A4E4B9A5E4BCA9E5BFAFE6C4B5E6C4B5E6C0B3E6C5B8E5C3B4E5C3B2E5C2B2E3B8A7
E1AC9DDEAB96D69983CF8970CA7F66D18D79D79787E1B6A7E4C3B5E5C4B6E6C9BAE6C2B3
E6BCAFE6C2AFE5C5B3E6C4B2E4BEA8E0B29EDCA690D79982D59A85D5A18BD29B81CF9B81
C89578C79175BD8A70C18973BA8167B87F65B77E67BD8066C0886BC99A6EC79672C79171
C48F6EC88B74CE9078D09779D29A84D1967ECE937DCB8974C48772C48872C5886FC59175
C68F77C8927BC4917CAB8D862116156B5355BDADAEEAE5E5E8E1E1E6DDDEE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DDDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDEE5DBDBE6DCDC
E5E1E2E4DCDDE4D2C8DDC3BBE0C1AAE8C5B1F1C6B2F2C2ABEBBEA7EAC7B2D1AC9EE4BDA6
E5B5A4E5BBA6E5BDACE6C1B2E6C4B6E6C4B6E6C3B5E6C7BBE5C4B7E4C4B4E5C2B3E4BBAA
E1AFA0DDAF99DBA08CD4937ACE876ED08D76D5937FDEB1A0E4BFB1E5C3B4E5C7B8E6C0B1
E6BBAEE6C0AEE5C3B1E6C6B5E4C1AEE3B8A4DCA894D99E89D69D87D39F89CF977FCD967E
C59176C58C73BD856DBF836EBA8066B87F65B97F67BF8264C1846AC7926DC6906FC89072
C89073CD937CD1957ED29A7ED19781D1937CCD927CCA8B75C58974C48872C48770C58F76
C68F76C6907AC5927CA5847A251816563F41A48C8ADBCCCEDDCECFE2D8D9E5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADBE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDDE5DDDDE5DCDDE5DCDDE5DDDEE5DBDAE6DCDB
E4E4E5E4DBDBE5CCBCE2C7B6E6CCB3E7CBBADBA791DBA38BD7A28BE3B7A5DAAFA2E5BDA7
E5B4A3E5BDA6E5BEAFE6C1B3E5C4B6E5C5B6E5C5B7E5C8BCE4C5B8E4C4B5E4C3B4E4BDAD
E1B3A2DCB199E0A694D99F87D4937BD19078D6937CDCAE9BE4BAAEE5C1B2E5C3B5E6BDAD
E6BBAEE6BDACE4BFAEE6C6B6E5C2B2E5BCA8DCAA97DCA28FD69E88D09B87CD917BCA9079
C38B73C3866FBE8069BD7D69BB7E65B97E65BD7F67C28462C37F6AC48469C4856BC78D71
CD9077D29A83D49B83D59E84D0947FD1927BCC917BCB8D77C68C76C48A73C48772C68D76
C58F75C58E78C8947EA07B6E33201C483133896D68C7B0B3D0BABBDED2D4E5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADBE5DCDCE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDDE5DDDDE5DCDDE5DCDDE5DDDEE5DCDBE6DCDC
E5E3E4E5D6D3E5C4AEE7C5AEE8CBB3E4C7B8C68D76C68B74C69078DDA999E2B3A5E5BDA8
E5B4A3E5BFA7E5BEB1E5C2B5E5C3B6E5C5B7E4C6B8E4C8BDE4C6B9E4C4B6E4C3B5E5BFAF
E2B6A5DDB39BE3AD9CDEA893D89F87D4957DD7957CDBAC97E4B7ABE5BFB1E5C0B2E5BBAA
E5BAACE5BCABE3BDACE5C5B6E5C1B2E7BDAADCAB98DCA492D59D87CE9783CB8C78C78A74
C18671C2826DC07D66BD7965BC7B63BA7D64BF7E65C38562C47C6AC27C69C37F6AC88C73
D1917CD6A089D69F87D6A18ACF937ED1917BCC907BCB8F79C88E77C58B73C38874C68B77
C68E74C48E78C99780A077654C2F27492E2E76574FB09597C4ABABDACCCEE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADBE5DBDCE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DDDE
E5DBDBE5CCC4E4B9A2E7BAA2E7BBA8E0B8A9BD816ABF846EC39079DBA796E6B4A6E5BDA8
E5B6A4E5BFA8E5BEB0E5C3B5E5C4B6E5C6BAE4C8BAE4C9BFE5C7BBE5C5B8E5C5B8E6C0B2
E4BBA8DFB59EE5B3A1E2AD9BDBA68ED69982D89A81DCAB96E4B7A9E5BEB1E5BFB1E4B9A7
E4B8A8E5BBAAE4BCABE5C2B4E4BDAFE6B9A8DBAB97DAA290D39983CB927FC88976C58772
C18570C1806BC17D66BD7964BA7960B77A60BE7B63C48463C57F6DC47E6EC78370CC9078
D59582D8A38DD7A18AD7A28CCE947ED1927DCD917BCB907ACA8F79C68C74C48A75C68A76
C68E75C5907ACA9982A678636C44375D3935734F449C807FBCA3A3D7C6C8E5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDBE5DCDCE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DBDCE5DBDCE5DBDDE5DCDDE5DBDBE5DDE0E3DDDF
E5CFCEE4C0B1E2AC96E3A892DFA192D9A292C0816AC68B77CB9E89DEAC9BE6B5A6E5BEA7
E5B9A5E5BEAAE5BDAEE4C3B6E4C5B7E5C8BDE5C9BCE5CBC0E6C9BDE7C6BAE6C7BAE7C1B4
E7C0ACE4B8A4E5B8A5E5AD9FDCA892D99D88DAA189DDAB97E4B8A9E5BFB1E5BFB1E2B8A4
E2B5A5E4BBAAE4BEACE5BFB0E3B7A9E4B4A2DAA994D69E8ACF937EC88E7BC78875C38771
C18670C1806BC18068BF7C66B7785EB3765ABB7860C38367C78572CA8978CE8E7BD19881
D89C88D9A38FD5A08AD6A18BCD967FD1957FCD927CCC917BCB8F79C98D76C48D76C68A75
C78E76C6937DCB9C85B17C658F5D48804E438152438D726DB8A3A1D5C1C3E5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDCE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE4DADBE4D9DAE5DBDCE5DCDDE5DBD9E5DDE1E2DCDE
E5C2BFE2B49FDFA08DDD9582D4877BCF8B78C6856ECF9784D4B09DE3B5A2E5B6A7E5BDA6
E4BCA7E5BDACE5BCACE4C3B6E4C5B7E5C9BFE6C9BDE7CBC1E8C9BEE9C6BAE8C9BCE8C1B4
EAC4AFE9BBA9E4BCA7E8ACA2DDA994DCA28FDCAA93DFAD9AE4BBAAE5C0B2E5BFB1E1B7A3
E1B4A2E3BCAAE5BFADE4BBACE2B1A2E1AD9CD9A78FD29883CB8D78C58B77C48874C18670
C28870C0816BC18469C08068B5785DB07356B9765EC3836CC88D78D09783D49B87D6A08A
DAA28DD9A28FD49F89D59F89CD9981D19781CE937DCC917CCC8E79CB8E77C58F76C68A74
C88D77C89580CB9E89BD8268B07559A76752975D48856961B8A6A3D4BEC0E5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDCE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE4DADBE4DADAE5DBDCE5DCDDE5DBDAE5DDE0E2D7D9
E5B9B3E2AE95DD9785D78877C97567C47B64CB8A74D7A18FDBBEABE6BCA9E5B8A8E5BDA6
E4BFAAE5BDAEE5BCABE4C4B5E5C6B8E5C9BFE6C8BCE7CABFE8C8BCE9C5B7E8C7B9E8BEB2
EAC3AEEABAAAE3BCA6E7AAA1DEAA96DEA796DDB19BE1B09EE4BDACE5C1B3E5C0B0E1B7A3
E1B3A2E3BCAAE6C0AEE4B8A9E1AE9DDEA896D8A48BCE947EC88974C18874C28772BF856F
C1886FBF826BC0866AC2846AB5795EB17457BB7862C68672CB957ED5A28CD9A691D9A590
DBA790D9A18FD39D88D49E87CE9B83D19882CF937DCC917BCC8D79CC8D78C69077C58973
C88D77C99781CB9F8CC6866BC78866C67E60AE6C5386685DBDADAAD7C2C5E5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DBDCE5DCDDE5DDDDE5DDDDE5D0CF
E6B6ADE4AF96DB9282D68371C36F5EBE745CCC8E78DBA694DEC2AEE7BEABE5BAA9E5BDA8
E5C2AFE5BEB1E5BEAEE5C4B6E5C5B7E6C7BCE6C6B9E6C6B9E5C4B6E5C1B1E5C1B1E5B9AC
E5BDAAE5B4A6DFB7A2E3A79CDEAA97DFAA9ADDB39DE2B2A1E4BDACE5C0B2E5C0AFE2B9A5
E2B5A5E3BCABE6C0AFE4B7A8E1AE9CDDA592D7A087CD937CC68772BD8672BF8470BD836C
BF856DBC826BBF876BC2866DB97D62B87B5EC3816BCB8C7ACF9A84D9A890DCAB95DAA892
DDAA93D9A28ED49D88D49D87CF9C84D09881CE927CCC917BCB8B78CA8C78C69077C58973
C88C76CA9580CDA08FC9876CD18F6DD48E6BBF7E63946F61C6B6B3DBCED1E5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DBDCE6DDDEE6DFE0E6DFE0E5DDDDE5DDDCE5DEE2E5DBD7E8C6C0
E7B6AAE7B39FD9907FD6836FC3705DBC755DCB927CDBA794DEBDA8E6BEABE5BCAAE5BDAA
E6C5B4E5C0B4E6C1B3E6C4B5E6C4B6E6C3B5E4C2B3E3C0B0E1BEAEE0BBA9E0B8A6E1B2A3
DEB4A3DDAC9EDCAE9CDEA595DDAA97DEAC9CDBB09CE3B3A3E4BBACE5BFB1E5C0AEE3BCA9
E3B9A9E4BDADE5BFB0E4B8A7E2B09EDDA491D79C84CD937BC58772BA8571BC826CBB7F68
BB816AB8816CBD866CC3886FC08369C2856ACD8D79D29682D39E89DCA891DDAA94DAA792
DEAA94DAA38ED69E88D59D88D19B84CF9680CD917BCB9079CA8A77C88977C58D77C58874
C68B75CA917DCEA191C6846BD18D70D39573C89074AA7A6AD1BEBCE0DDE0E5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE4DBDCE6DEDFE7E2E3E7E3E3E6E0DFE5DDDCE5DEE3E5D6CCE8B9AD
E7B4A5E7B4A6D58D7CD3826EC1745DBC7861CB9680DBA894DEB8A1E4BCABE5BDABE5BEAD
E6C7B9E5C2B5E6C4B7E7C3B5E6C2B4E5BFAEE3BDACE1B9A7DDB8A6DBB5A1DBAF9CDCAC9C
D6AA9BD5A496D8A696D8A48FDCA996DCAC9CDAAC98E3B4A4E4B9ABE5BEB0E4C0ADE5BEAD
E5BCAEE5BDAFE5BEB0E4B9A7E2B4A1DCA590D69882CE937BC58872B78571B97F69BA7D65
B87D68B5816DBC846DC48971C68970CC9077D59B86D99F89D7A18CDDA690DDA892D9A690
DEAA94DAA48DD99F88D69D89D39B84CE947ECC8F7AC98F78C88976C58777C58A76C58874
C48B73C98E7ACFA093C18069CA856ECB9676CB9E83C38574DCC3C1E5EAEBE5DDDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE4DBDCE6DEDFE7E1E2E7E3E3E6E1DFE5DDDCE5DCE0E4CBBDE3A997
E2AD9BE2AFA4CD8776CA7F69BB755DB97A64CB9B85DCAA96DFB49DE3BCABE5BEABE5BEAF
E7C6BAE5C3B6E6C4B8E7C2B4E6C1B2E5BDABE3BBA9E1B8A3DCB5A2DAB39DDAAD98DCAB98
D5A798D5A595D8A394D6A58EDCA894DCAC9BDAAB98E2B7A6E5B9ABE5BEAFE4C0ADE6C0AF
E6BFB2E5BDB0E5BDB0E4BBA7E3B5A2DCA590D59680CD927AC48973B78570B87E67BA7C64
B77C67B4826EBC836EC38972CA8D75D19780D8A18DDBA48DD9A28EDCA28DDBA58FD7A38D
DCA791D9A38BD99E87D59C87D39983CD927CCA8E79C88E78C78975C38676C58875C58875
C38A73C78D79CE9E92BA7A65C27B68C29275CBA48AD58D7AE2BFBBE8EAEBE5DDDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DDDDE5DDDEE5DCDDE5D7D5E1B8A7D69681
D89F89D6A092C07E6AB87460AD6F58B07762CD9F89DEAF9AE0B59FE3BBABE5BEACE5BEB0
E5C3B6E5C2B4E5C3B6E5C0B2E5BFB0E5BEACE5BDABE5BDA8DFB8A3DFB7A0E0B4A0E2B09D
DDAC9ADEB09DDEA798DBAD95DEA994DEAD9BDDB19DE2BEA9E5BDADE5BFAEE5C0AEE6C0AF
E6C0B2E6BEB0E5BCAEE4BCA6E2B4A1DBA590D4947FCC8F78C48873B9856FB87E67BB7E67
B87F68B5836FBD836FC28972C88D77D09884D39D8AD6A28DD6A08CD79D88D8A18CD4A08A
D6A08CD49E86D69B84D39883D09680CB907BC98F79C78D78C68A76C38775C58775C48875
C38A74C48E7DCB9B8FB3745EBB735FBC8A70C99D86DA8E7AE0B1A6E8D9D8E5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE6DEDEE3D9D9E2D5D5E2D4D5E5D7DBE5DADEE6CFC5DCA38FC6846D
C98B72C38977AE715A9F6552996350A4715CD0A28DE1B49FE3B9A6E3BBABE5BFAEE5BDB0
E3BDAFE5BFB0E4C0B0E2BFB0E4BEAEE6C0B0E7C1AEEAC5B0E5BCA8E7BDA7E8BFACEAB7A4
E9B69FECC1AAE5AF9FE2B69FE1AA94E0AE9AE1BAA4E1C4ACE4C2AFE5C0AEE6BFB0E6BFAC
E6BFB0E5BDB0E5BCACE4BCA6E0B19EDAA490D3947EC98A74C38673BD846DB97E67BC816A
BA836BB8846FBE8371C18872C38B76CB9582C89281CE9B88D09B87D09882D39D89D19C87
CE9885CF9881D09680CF937ECC937DC98E7AC8907AC78D78C68C77C58975C58873C38975
C48976C19383C7988AAC6D57B76C56B98069C58C7AD48974D69C89E4BDB9E4DBDCE5DCDC
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DADBE5DCDDE5DCDDE5DCDCE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE8DFE0E2D8D8E0CFCFDFCCCEE4D2D8E5D7DDE5C4B2D69079B6755E
B5765CA86F5A98614A855544855647966855D3A48FE3BAA3E4BDACE2BBABE5BEAEE5BDAE
E1B9A8E4BDACE3BCAADFBDADE3BCABE4C1B3E8C2B0EDC9B5E8BEAAEDC0ACECC6B4EFBCA9
F1BCA2F4CBB1E9B4A3E7B9A6E1AA93E1AD98E3BFA7DFC6AAE3C4AEE4C0ADE6BFB1E5BDA9
E5BEAEE5BDB0E5BDABE5BCA5DEAD9BD9A48FD1947EC68670C18472C0836ABB7F67BD836D
BC866CBB846FC08372C08872BE8975C58F7DBD8576C59382C99682C9937DCF9986CE9984
C7907EC9927DCB917DCC8F7AC7917AC88E79C7917AC78D79C68E79C68B75C58972C28974
C58978BF9788C39485A66751B2674CB6755FBD7868C9806BC7876CDBA198E4DADBE5DBDC
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DADAE5DCDDE5DCDDE5DCDCE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE7DFDFE3D9D9E1D1D1E0CED0E4D4D9E6D6D9E2B39BD1856DAB6D57
9F604789523F81513C6D4537724A3E885F4ED5A590E4BDA7E5BFAFE2BAA9E5BDADE5BDAD
E1B7A5E4BCAAE2BAA6DCB9A9E0B7A5DFBAADE3BAA8E5BEACE3B7A3E9BAA9E4BDAEE8B5A4
E9B59CEABEA7E1AC9AE2AF9EDBA48DDCA590E0B79FDABBA0E0BEA7E3BDAAE6BEB0E4BCA8
E5BCACE5BDAFE5BDAAE5BCA5DDAA98D8A38FD0937DC3836CC08170C18167BB7E66BC836D
BC856BBC846EC28574C18873BE8975C28C79BA8271C38F7EC7947FC6917BCD9784CE9883
C58D7BC8917CC9917CCB8F79C6917BC88F7BC7937CC68D7AC58F79C78D74C48972C18A74
C5897ABE998BC19281A2654EAC6245B26953B46655BD735EB97656CF8C7DE4DADBE5DBDC
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DDDDE5DCDDE5DDDEE6DFE0E5D4D0DB9D83D0846DAA6E5A
884C3767372A6840305C382E6542377A5647D7A892E5BFA9E5BFAFE2BAA8E4BCAAE5BDAC
E3BAA7E4BDAAE2B9A4D9B5A2DAAE9AD4AB9BD4A693CFA190D1A28FD7A598CBA091D09F8F
CB9A8AC79686CB9382CD9382CD9883D19684D39E88D1A28BD9AE97E1B8A3E5BCAEE4BCA9
E4BCACE5BDAFE5BDABE5BCA6DCAA98D7A28ECE917BC28269BE7F6CBD7F65B87C62B87E67
B87F67BB846EC48876C48B74C5907AC68E79C58E78CC937FCA9780CA9680CF9884D19A84
CA917ECC9680CE9680D0947FC99680CA937FC6937DC58D7AC38F78C58D74C28A72C08974
C58A7BBE998AC1927FA06751A55E42AD5E47AB5948B4644FB36C4CC98371E5DCDCE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE2D8D9E9E1E3EBECEEECF2F0E8EDE7E4D2C3D1866BD18A77B07662
733B2B46211B513127502F275C3C316F4E42D9AA95E5C0ACE5BEADE1BAA6E2B9A5E5BEAB
E6C1ADE5BEABE3BAA4D6B09CD3A38EC59784C08D78AD7B6BB68774BC8A81A5786AAE8172
A0756F8F6158A87161AB6E5CB98775C08374BD7D69C38270D09882DEB09AE3BAA9E5BDAC
E5BCADE5BDAEE5BEADE6BDA8DDAB98D7A18CCD8F79C28367BC7E68B87C62B4785EB2775F
B17560B8836DC58D78C88F78CF9980CD9279D6A084D99B81D09B83D09C86D39A84D59D85
D29884D39E85D59D85D59B87CF9D87CD9884C6937EC48E7AC18D76C28B74BF8A72BE8973
C38C7BC09585C3927D9F6B579D5B42A7543DA5523FAE5640B56A4CC78370E6DEDFE6DDDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DDDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDDFD4D6EBE4E6EDF7F9EFFEFAE7F0E4E3CBB4C77357D39283B8806D
612F232B12103E251F47282255362C66483EDBAD98E6C0ADE4BDA9E1BAA4E1B7A1E5BDA9
E9C6B2E5BFACE4BBA4D4AC97CE9B85B78671AC78628C5C4C9D6F5EA1736B7D54478C6558
76545453322E835244844D39A67768AF7265A4604CB36756C6856FDBA991E1B8A5E5BEAF
E5BDAFE5BEAEE5BFB0E6BDAADDAC9AD7A18BCC8D77C28465BA7C64B17960B07459AC7056
AA6B58B3816BC59079CC937CD6A085D29479E1AD8DE29F7FD39C82D39F8AD49A84D69D84
D79C87D7A488D9A388D8A18DD3A28CCF9B87C5937EC28E7ABF8B73BF8A73BB8A72BD8873
C28D7BC29180C3917B9F6F5B955842A04D359F4D39AA4D34BA6C51C88672E8E1E2E6DEDE
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DDDDE5DCDDE5DCDDE5DDDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDDFD5D6EAE4E6ECF2F4ECF1EFE1D8CEE2BFA4C26A4ED69A8CC28A77
5729211C0B0B311D1A40231D4F312863463DDCB09AE6BFADE3BBA6E0B9A2E0B69FE4BBA5
E9C6B3E5BFACE4BBA5D6AD97CE9B85B5826BA6725C7E504093665693686068433779574A
5E42442D1A186C41346A3A279A6E5FA4675B94513CA95A47BF7B64D9A48BDFB7A1E5BEB1
E5BFB1E5C0B1E5C1B4E5BDABDDAE9BD8A18BCB8C77C38465B97B60AC765DAD7257A76B50
A36250AC7A65C2917ACC9580D39D84CD9075D9A386D79577CB9279CC9783CD947FCE957D
D09781D3A083D49F85D39F8BD1A08ACE9A85C4907CC18D78BD8971BC8973B98A72BC8772
C18D79C48F7BC18F779B6F5C8E5542984A33984B36AC4B32C0715AC88672E9E1E2E6DEDE
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE7E0E1E2D8D9DDC3C5CDA29DE0AE95C86E54D99F8FCB8F7C
572B241C0D0E2D1B1939201A492C2366483EDDB29CE5BDAAE2BAA4E0B9A1E0B7A0E1B6A0
E5BFACE4BDAAE4BBA5DBB39DD5A691C39179B4806A92604FA173619C7167744C3F805C4F
644647321D1A6E43356B3B289A6D5EA4675997543FAE5D49C17D65D7A289DEB59FE5BEAF
E5C0B3E5C3B6E5C4B9E5BEACDDAF9BD9A28CCB8D77C38365B87A5EAB755BAE7358A66A4F
9E5B4AA36F5ABC8C79C89583BF8E7AB9826DB47969B17864B37964B5816EBB8775BA8470
B88571C18F73C39079C3927EC8967DC6917BC28C76BF8B75BC8770BC8973B88A73BB8772
C08B77C48E78BC897294675486513F8F4A37904935B4553EC57962C6816CE7DEDFE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DBDBE5DCDDE5DCDDE5DBDCE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDECE6E5DFD7D5CEB0AFBA8589A1625DDC9985D27963DB9D8AD28F7B
5C312C2716172E1C1B321E184327206E4E43DDB39DE4BAA7E0B9A3DFB8A1E0B8A3DEB19A
DFB3A0E3B9A6E3BAA5E2BCA8E0B7A4D9AB95CE9E88B98471BE8E7BB38879966859997160
805A57553630845442804B37A37363AB6E5DA7654FBC6D58C98870D7A38ADEB59EE5BDAC
E5C2B5E5C7BCE5C8BDE4BEACDDB09BDAA48ECC8F79C48267B97A5DAC7459AF765CA76B51
9B574698624DB38577C09285A3786B9E6F617845407C544A8F5A4A926353A375679F6D5E
966B5AA7775EAA7A67AD7F6AB9856BBB856DBF876FBE8871BC866FBD8972B88973BA8772
BF8875C38D77B2806A895A487F4C3C844C3C884935BF6753C78168C37761E4D9DAE4DADB
E5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5D9DAE5DCDDE5DCDDE5DADBE5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDF2EEEBD4C5C1B18580874E4D642D25D18173D78271D6967FD08873
613933332321321F1F2D1C163F241D775548DEB49EE3B7A3DFB8A2DFB7A1E1BAA6DBAC95
D8A794E1B5A2E1B9A4E8C3B1E9C7B6EBC6B2E5BDA8DDAE9ADAAB98CCA18DBA8978B48875
A2736880594D9E6A5498604DAE7A68B57763B97B63CB836BD2977ED7A58DDFB59EE5BDA9
E5C4B6E5CAC1E5CBC0E3BDABDDB09BDBA691CD927BC48169BA7B5DAE7457B2785FA96D55
9A56438F5842AB7E74B98E8589645C855E563A1C1C4C33306C403470483A8B645984594D
7553448D604B916656966D57AA765BB07960BC8368BC866DBC856FBE8A72B88974BA8872
BE8573C08B75A575607A4C3C764637784C3F814936C77C68C9876CBF6E56E2D6D5E3D9DA
E4DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5D8D9E5DCDDE5DCDDE5DADAE5DADAE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDF0EBE9C2A6A28D5F57542A252C0F06BC675DCF7C71C68770C17966
603D373B2D283522212B1C153C211B7E5B4CDFB49EE3B5A1DFB8A3DFB7A1E2BBA8D9AA94
D39F8CDEAF9CDEB5A1E8C2B2EDCCBDF3D3C1EFCFBCF1CAB5E9BDAADBB098D1A18EC69781
BA8472A07663B07B62A9705CB57D68BB7B64C48A71D4947AD8A28AD8A790DFB59FE5BDA8
E5C5B7E5CBC2E5CBBFE2BCA9DDB09ADBA791CD947EC5826CB97B5FB07356B3795FAC6F57
9D59448E553EA87B72B68D857E5C567A585217090B32222257322859372B7A564E734C42
6043377C523F83594B8A634DA16D51AA7359BA8064BC856BBC8570BF8B73B98974BA8873
BE8572B987719467556B41336B41336B483C794936CA8D77C78569BD664CE3D7D7E3D9DA
E4DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5D8D9E5DCDDE5DCDDE5DADBE5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE4DADBA67C766D423A3A1C15160600994B44B4625DA96F5C9F6053
5538333A2D283422212A1C153B201A815D4DDFB59FE3B5A0E0B9A3DFB8A2E2BBA9DBAC97
D39E8BDAA895DAAE9AE1B7A8E8C2B3EBCAB9E9C9B7EEC9B5E5B8A7D9AB92D3A18EC5947E
BF856EAC7D68B37D63AD725DB37760B9775FC48970D4997ED9A78ED8A891DFB49EE5BDAA
E5C6B7E5CABFE5C8BBE1B9A5DDAE98DAA590CC9780C48570B87A61B07355B3775CAD7157
A4614A985D45AE7F72BA90848C665E8360592813143C29275C362C58372A7250476F4B41
6042367D523F855A4B8D6650A46E53AD765BBB8166BC856BBB8670BF8B74B98A74BA8873
BF8975B07F6A8158485E3A30603B2E5B3C32724634C7937AC27960BC6045E9E0E1E5DCDC
E5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5D8D9E5DCDDE5DCDDE5DBDCE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDD2C1C67E5048532F27381C15200B056E322C883F3C82544673443C
442D29342621301F1E2A1C163B201A805C4DE0B59FE4B5A1E3BBA5E0BAA4E2BAA7DEB29D
D6A28FD6A18FD5A791D5A598DCAD9CD7B1A2D7B2A2DBB3A1D2A594CB9881C6927FB78671
B47A63A97460AC755DA76A54AB6D55B36F57BD7E65CE947AD6A58DD9A892DEB49EE6BEAD
E5C5B7E5C6B7E5C3B4DFB6A1DDAB96D8A28DCB9982C48A74B67963B17255B17457AE7256
AC6D51A96D53B98772C29382A97B6E9873675934335E413B72483B6A4332745046785347
704D3F8A5D489464519C725BAF775DB67F64BD846BBD866DBA8871BF8C75B98B75B98873
BF8E78A374616C483C54372F55362B4A2D256C4231BF8E75BA6751BD5D41F1ECEEE8E0E0
E6DDDEE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDD
E5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5D9D9E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDBFAAB2522C243F221B40241A351712441D1954201D5B3930462925
31211E2A1D192B1C1B2B1C163D221C7D5A4BE0B39DE5B5A2E5BCA6E1BBA5E1BAA6E2B8A4
DAAA97D39D8AD1A28BC89588CF9986C19688C2998AC39989BC8F80BA8471B4816EA67763
A66E58A16957A46D57A0634BA4654DAD6952B5735BC88E76D4A28BDAA894DDB59EE6BEB1
E5C4B6E4C1AFE5BCADDEB29CDDA894D6A08ACA9B85C48F78B57A67B27356B07052AE7354
B37759B97D62C38E70C9957DC6917CB087748C6158885E508C5F4F8255407D5448876050
865C4B9C6C54A7725BAD8069BB8169BF896EBF8771BE8870B98A72BF8C77B98C75B88872
BC917893665558392F4B342F4A3127391F19693F2EB7836CAE5540BD5B3FF4F2F5E9E2E2
E7DFE0E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDDE5DCDD
E5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5D9DAE5DCDDE5DCDCE5DDDDE5DDDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDB39CA631170F331B15472A1F43221E26100E2A0E0B3C2520241514
221615221612271A182E1E1841251F795849DDAF99E4B5A2E6BCA6E2BCA5E1BAA5E4BEA9
DFB19FD49E8CD1A18BC28F81C68E7AB28678B4897BB3887AAE8375B07A6BAB78669E715F
A16A579F6657A36C589F624BA4654DAF6B55B37059C68C76D3A18CDCAA98DEB6A0E6BEB3
E5C1B3E3BDA7E4B7A6DDAF99DDA793D69F8ACB9D87C6947DB77C6CB5765BAE6E4FAB7153
B37B5BBE8369C48C6AC78E72D59A7FBE9077AE8672AA7660A1745F99684F8B5D4D986E5A
9C6C59AB7960B67E63BA8A73C28871C48E74BE8975BE8A73B98A72BE8D78BA8C75B78972
B48B72805748462D2542302E412D252E17116E4130B17963A54934BC5B40EEEAEDE9E2E2
E7DFE0E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDDE5DCDD
E5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DADBE5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDB39CA72A140C2D181244281E4225201C0D0B1B09072C1B17150C0B
1B111020140F251816321F19462B25765648D7A892E2B29EE4B9A3E2BBA4E2BAA5E6C0AB
E2B7A6D8A595D5A893C79688C9927FB4887AB58A7CB4897CB08679B68174B17F6EA5796A
AC7563A97164AE7664AA6E5AAF715BBA7864BC7B65CB937FD5A591DFAF9EE0B8A5E5BEB2
E4BDAFE2B9A3E3B5A2DCAD97DDA793D7A18CCD9F89C99781BC8273BA7C63AC6D51A66D52
AB7257B57A62B77F5FB97E62CB8E71BB876EB78F75B87F65AC7D67A9765C9C6A56A87A62
AC7965B48169BC8569BF8A75C08671C18C73BC8874BF8A74B98A73BE8C78BC8C75B88B73
A57B646A46393A251F3A292A3928232C150F7F4A37B2735DA34630BB5E44DBCFD0E5DCDD
E5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDBE5DCDDE5DCDD
E5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DBDCE5DCDDE5DBDBE5DBDCE5DBDCE5DCDDE5DBDBE5DCDDE5DCDDE5DCDCE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDBDA7B2381C142D18133A201937211B21120F210F0C2A1A16150C0B
1A0F0E22140F25181636221B4C312B735546CF9F89DDAE99E1B59FE2B9A2E3BCA6E6BFAA
E4BBACDFB2A2DCB3A1D4A799D3A291C19789C2988BC3988BBF968AC69389C39282B68D7F
C08979B9877CC18A7ABB8474C18574CA8E7DCB907CD4A18DD9AD99E2B5A6E2BBAAE4BCAE
E3B9A9E1B6A1E2B3A0DDAC96DDA994D9A691D0A28CCE9985C38A7BC0846EAB6F56A06952
9E644FA36753A16B52A26952AE745BAA735DAF8067B57B62AF7D66B18066AC7961B58368
B5836DB7846DBA866BBB8470B7806AB9846DB78570BE8B74BB8873BE8B78BE8A74B98D73
8F645152352B32201B322225342523301711945540B66F59A44933B76249BCA8A6DED2D5
E3D8D8E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDBE5DCDDE5DCDD
E5DBDBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DADBE5DADBE5DADBE5DCDDE5DADBE5DCDDE5DCDDE5DCDCE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDC9B6C04E2C23321D163219142B1A152B1B162F1B162F1D171E110F
1D100F2517112719163B241D523831715345C5947FD8A892DEAF9AE1B7A0E4BDA7E5BEA7
E5BEB0E5BEB1E3BFB0E1BCADDFB6A6D2AB9CD2AB9ED4AC9ED0AA9FD6AAA1D6A999C9A499
D4A193C7A097D3A093CB9D91D29C8FD8A797D8A995DEB09DDDB5A1E5BBADE5BEAFE3BBAA
E1B5A5E0B3A1E1B3A0DDAB97DDAB95DCAA96D4A58ED49A89CB9384C78C79AC745F9E6754
9358499057458D5A488D57458D5B46955E4C9E6A55AB735CAE7862B5846CBA856ABE886A
B98871B6826EB5846BB57C68AC7862B07B65B3826CBE8A74BC8774BF8B78BF8873B78A70
774D3E3D261F2E1D182C1C20302222371C16A45D47B76854A44E38AE634B977F7BD5C6C9
E0D4D4E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDBE5DCDDE5DCDD
E5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DDDDE5DCDDE5DADBE5DADAE5DADAE5DCDDE5DADBE5DCDDE5DCDDE5DCDCE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDD4C5CF603A313C241C30171324171133241B3A271E342019281713
21110F281813291B173F261F563D366F5244BB8B76D2A38CDCAC96E2B69FE5BEA8E5BCA6
E6C0B2E9C8BAE8C8BBEACBBBE6C6B7E0BDADDFBCAFE2BDAEDDBCB2E2BEB6E3BCAFD7B9AF
E2B6AAD2B5ADE0B5AAD6B3AADEB1A6E1BCADE1BDA9E4BBA9E1BCA8E7BFB2E6C0B2E1BAA6
E0B3A1E0B2A1E0B39FDEAB98DDAD96DDAD9AD7A791D89D8DD29B8BCD9684B37C6AA26C5B
93564B8A5241855446835041794D3C8752418E5A47A06955A7705BB3826CBE896CBF8668
B7866FB17D6AAF7F69AF7662A4715BA97560B27F6ABE8A73BE8674C08A77BF8671AF8268
603A2E2D1C162C1D172A191D2E21223C2019A55948AF5C4B9D4E3A9F5F49765F5AC9B8BB
E1D5D5E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDDE5DCDD
E5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DDDDE5DCDDE5DADBE5DADBE5DADBE5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDDCD0D9674138492C23381D1827191336261D3D2A213420192E1B16
2413102A19152E1D19432921583F376F5244B3846ECE9D86DCAC96E3B69FE6BFA8E5BCA6
E6C0B1E9C9BCE9CABDEDCFBFE9CBBDE6C6B7E5C6B9E7C6B7E4C7BDE7C8BFE8C8BCDFC6BD
E8C4B9DAC3BBE6C3BBDDC1B9E4BEB4E5C8BAE5C7B4E7C0B0E3C0ACE7C0B2E5C0B0E1B9A4
E1B3A1E1B3A1DFB29DDEAC98DDAD96DEAE9ADAA993DBA192D8A391D39F8DBE8978B07969
A26559975D4D905E508B58497C50408752428956449863519D6854AB7864B68064B57B60
AE7C66A87361A97864AC735EA16F59A97560B37D6BBE8A73BE8775C28A77BF866FA0705A
4F2D252617122C1C172B191C2F21213A20198E473E994A3E8C4836895341634D47BDABAE
E6DDDEE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DBDCE5DBDBE5DBDBE5DCDDE5DBDCE5DCDDE5DCDDE5DDDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDCDED4DD654037553429462821311F1833231B3C261F311E18311D17
2514112B181633201C452A23583F366F5143AC7E69C99881DDAC96E5B6A0E6BEA8E5BDA8
E6BFAEE8C6B8E8C7BAEACABBE8C9BBE7C8B9E6C9BEE7C8BAE6CBC2E7CBC1E8CCC3E3CCC4
E7CAC1E0CAC1E7CBC5E2C8BFE5C4B8E6CBBFE6C8B8E7C0B1E4C0AEE6BFAFE4BEACE0B9A3
E1B5A2E1B3A0DDB19BDEAD98DDAC96DDAD99DCAA95DDA796DBA995D8A794CC9788C38B7A
BA7F72B17766A873649F6C5B916250945D4C8D5C4A96605092604E9F6A57A67057A56C55
A06E5A9E6857A4705EAB735EA3715BAE7964B87D6EBD8A72BE8975C38975BD846D8A5B49
4526202617122C1C16301C1C312120331E18662D2C7A362F733C2D6D42355C4640AF9D9F
ECE7EAE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDCE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DDDEE5DCDDE5DCDD
E5DCDDE5DDDDE5DBDCDBD0D8603D345F3B2F53342A3C251E301F1939221D2E1C16321E18
2716122B181837221E462B24563D336F5042A37862C2917ADCAB94E6B5A0E6BDA7E5BEA9
E5BDAAE5C0B2E6C2B4E6C2B4E6C4B6E6C6B9E6CAC0E6C8BBE6CDC4E6CABFE6CEC6E5CEC7
E6CDC5E5CDC4E5D0CAE5CBC2E6C7B9E6CABFE5C6B8E5BEB0E5C0AEE4BCAAE2BCA7E0B9A2
E2B8A3E2B49FDDAF99DFAD97DDAB95DDAB97DDAA96DDAB9ADEAD97DCAD98D9A596D49E8C
CF9D8ACA9481C18C7BB68470AA7966A46D5A9466549660518B5C4B935E4C95614B955E4B
94614F94604EA16A5AAC755FA7745FB57E68BD7D72BD8971BC8974C28772B78068724638
3F221D291A132D1D1634201C33221F2C1B15391719582421592F245131285B443DA08D8E
EFECF0E4DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDCE5DCDDE5DDDDE5DDDDE5DDDDE5DCDDE5DDDDE5DCDDE5DCDDE5DDDEE5DCDDE5DCDD
E5DCDCE5DCDDE5DBDCD1C1C65B3A2F6540335C3E31462B242F1E19381F1B2E1B15321E18
2918132C18193A231F452A2353382F6C4B3E996F5BB78671D6A38CE4B29CE5BBA5E5BEAA
E4BCA7E3BBADE4BEAFE2BCAFE4C0B2E5C5B8E5CAC0E4C8BCE5CDC4E4C9BDE4CEC7E7CFC7
E4CEC6E9CEC5E4D2CBE8CDC3E5C7B7E5C7BDE5C3B7E4BDAFE5BFAEE3BBA7E1BAA3E0B8A2
E3B9A4E3B49EDCAE97DFAD97DDAA95DCA995DDAB97DDAE9BDFAE98DFB09AE1AE9EE0AC98
DDB39BDBAA95D3A08CC79982BF8D78B37D699F73609C65568C5F4E905B498E5A468F5A49
905D4B935E4CA26959AF7962AD7964BA836DC17F75BD8971B98972BB826CAA775F5B352A
3B201C2D1C162D1D1736221B33211D25181318080A3C191743241C3A231D5A413A907A78
E9E2E5E5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDCE5DCDDE5DDDDE5DDDDE5DDDDE5DCDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DBDCE5DCDDE5DCDDBBA5A658382D6442375F42354B302934211C3B211D301C16311D17
2C1A152D1A193A221D4127204E332A6444388B6250A77865C8957EDEAC96E3B8A2E5BDA9
E4BCA6E3BAACE3BCADE1BAADE3C0B2E4C5B8E5CBC1E4C8BDE5CDC4E4C9BEE4CEC6E7CFC8
E4CEC6EACFC6E4D0C8E8CEC4E5C7B7E5C6BBE5C3B6E4BDAFE5BEACE3BBA6E1B9A3E0B8A2
E2B8A2E2B29CDDAD96DFAD96DDAA94DDA994DEAB97DDAE9ADFAD96DEAE99E4B09EE3B09A
E1B89EE0B29BDAA791CFA38BCA9882BF8B75AD806DAA71629B6B599B655298634F996252
9A65529E6755A9705FB37E67B47F6BBD8671C38176BD8971B5866FAE79639667524B2B22
381F1A2F1E182D1D1834221B311F1C2116120C04062B1412331C162B1A16543A3480655F
D5C4C3E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDDE5DCDD
E5DBDBE5DCDCE5DDDE9D837E58382B5F42395E41364E342C3B27213F2521361F192F1C15
301C162E1C18381F1A3B231D482D255A3B2F7A5344936957B4826CD6A38CE0B59FE5BCA7
E5BDA8E4BCAEE4BDAFE3BCAFE4C3B4E5C6B8E5CBC1E5C9BFE6CCC3E5CBC1E4CDC5E7CFC7
E4CEC6E8CFC7E5CDC3E7CFC6E6C6B7E5C6BAE5C4B7E4BFAFE4BDAAE3BCA6E2B8A4DFB8A1
E0B59FE0AF9ADDAC95DEAB95DEA994DEA994DEAB96DDAC97DEAA94DCAA96E1AB98DFAC96
DDB097DDAD96D7A38ED1A48DCD9A85C6947DBB8E79BB8371B17E6BAF7864AD7661AD7563
AD7662B07764B37C68B9846DBA8572BD8772C38475BD8870B0806A9C6D577D534341261E
341F182F1E192D1D192F1F1A2D1C1B20161211090A2414102B17132416124A302B6D5047
B59C97E6DDDEE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADAE5DCDDE5DCDD
E5DADBE5DBDCE5DDDE7A605858372A5840395C3F3650372F432E27442A263B211B2D1A14
331D172E1D17351C173620194328204F32276A463A80594B9F6F5ACC9881DCAF99E4BAA4
E6BEAAE6BEB1E4BEB1E4BFB1E5C5B7E5C6B8E5CABFE5CAC0E5CAC1E5CCC3E5CCC2E6CEC6
E5CDC5E5CEC6E5C9BDE5CEC7E6C5B7E5C6B8E5C5B6E5C0B0E3BCA7E4BDA8E3B8A6DFB7A1
DEB29CDEAC97DEAB95DEA993DEA893DEA994DEAB95DCA993DCA691D9A592DBA590D8A48F
D5A28CD6A38CD19B86CFA18ACD9A83CC9A83CA9A84CC947FC7937DC38E78C48B76C28A76
C18A75C28A76BD8A73BE8A73C08A78BC8873C08673BB866FA87863885F4C6340333B231D
321F172E1E1A2B1C1A291B192819192015131C12102216102615122115113F27225B3E32
947970E7DEDFE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDCE5DCDCE5DCDCE5DCDDE5DCDCE5DCDDE5DCDDE5D9D9E5DCDDE5DCDD
E5DADBE5DBDBE5DDDE5E463D57372A553F38593D36523B3249342D472F2A40251E2D1A14
361E182F1E16321A14321D173E241D462B215E3D32714E418D604DC38E77D8A892E3B7A0
E6BEAAE7C0B1E5BFB2E6C1B3E5C6B8E5C5B6E5C8BDE5CAC0E5C9BFE5CCC5E6CAC0E4CCC5
E5CCC4E3CDC5E5C5B9E4CDC7E5C4B7E5C5B6E5C5B6E5C1B0E2BBA6E5BDA8E4B7A8DEB6A0
DDAF99DDA995DEAA94DDA791DEA792DEA993DEAA94DBA790DAA38ED7A08ED69F89D19D88
CE9782D09B84CB9480CD9C87CD9881CF9D86D3A28BD7A089D6A18AD19E86D29C85D19983
CF9882CE9782C4947BC28E78C48D7CBC8873BC8670B6826B9D6E5A7552414F312836221C
301F172E1E1A291B1A2417172315171F1413251A1521181122141122161235201B4B3023
83685EE7DEDFE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDCE5DCDCE5DCDCE5DCDDE5DCDCE5DCDDE5DCDDE5D9D9E5DCDDE5DCDD
E5DBDBE5DBDBE5DCDD513A3257382B563E37573D38563D354F39324A332D432822321D17
381E18301F16311A14331D173C231C41281E58392F69473C825745BB856ED2A088E0B39C
E5BBA7E6BFAFE6BFB1E7C2B4E6C4B6E5C4B5E5C6BAE5CAC0E5C9BFE5CDC6E6CABFE4CCC5
E6CCC5E3CCC5E5C5B8E4CDC6E5C4B7E5C5B6E5C5B6E5C1B1E2BBA7E5BBA8E5B7A7DFB49E
DDAE99DDA794DDA994DBA48FDCA690DDA892DDA892DBA58ED9A18DD69D8BD39C86CF9A84
CC937ECE9780C9937FCC9A84CC9881CF9C85D6A28BD8A28AD8A38CD4A189D5A089D39C86
D29C84CF9984C5967CC38F7AC48D7ABD8771B6836CAB7A658E614F65463744292132201A
2E1F182D1D1A2619191F14141E12151D1212261B152018121F13112418142F1B173E271C
8C7167E7DEDFE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5D9DAE5DCDDE5DCDD
E5DBDCE5DBDCE5DBDB533A3156392E5A3E36553F3A593F38523C364D3730452C2639211C
391F18311F16311B15361E193C231D40271F573A3067443B7D5442B47D66CC957DDCAD97
E2B7A1E4BDAAE6BEAFE7C1B3E6C1B4E6C3B4E5C5B8E5CBC1E5CAC1E6CEC6E6CAC0E4CDC5
E5CEC7E4CCC5E5C7BBE4CDC5E5C4B7E5C4B6E5C4B6E5C0B1E3BCA9E5B8A7E4B7A5DFB29D
DEAE9ADDA793DCA894DAA28EDAA48EDBA691DCA591DBA48CD7A08CD69C89D29D86CF9A84
CD9480CF9680CB9680CD9983CD9781CD9882D29C86D29C84D19B85D09A82CF9B84CE957F
CD967EC9927DC39179C18E79C18974BD846DAE7D679D6F5C7D5343583C3041261F2E1E19
2C1F1A2D1D192317171C11111B10121B10102316121F15121C1210261B152D1A153A251B
A88E86E6DDDEE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADBE5DCDDE5DCDD
E5DCDCE5DBDCE4D9DA5C3E36563B315E3E3454403C5C403A553F3A503A3347302A412621
3A2019331E18321D173B211B3D251F412820583C3267443B7C5443AD765FC48B72D8A791
E0B19BE2BBA5E7BDADE7C1B3E6BFB1E7C2B4E5C5B7E6CBC1E6CCC2E6CEC6E6CBC1E5CEC6
E6CFC8E5CDC4E5C9BFE5CCC4E4C5B7E5C4B6E5C4B6E5BFB2E4BCABE4B5A6E3B7A3E0B09B
DEAF9ADEA793DAA893D8A18CD8A28BD9A48FDBA290DAA48CD7A08BD69C88D29E88D09B84
CF9782D19781CD9983CD9781CC9681C9927DCC947FCA927CC6917BC89079C6927CC58B76
C48D75C08974BE8974BD8B76BB836CBB8068A475618D64536B45374E332A42261F2A1C17
2B1E1B2D1C182115151B100F190F10190E0F1D100E1E12111B120F281D172F1B15402A21
C7B2AEE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDBE5DCDDE5DCDD
E5DCDDE5DBDCE3D7D864433B563C345F3D3154413C5D413B58413C543E3749342E482C26
3D211B331E18341F193F231E402722432B23593D3369443B7D5545A56E58BD8168D29E89
DDAC95E1B9A2E6BDABE7C0B2E6BDAFE7C1B3E6C4B5E6CBC0E6CCC3E6CEC4E6CBC1E5CDC5
E5CFC8E6CCC3E5CBC2E6CBC2E5C5B7E5C4B6E5C3B6E5BEB1E3BCABE3B2A4E2B7A1E0AE99
DFAE9ADEA692D9A792D7A08BD6A08AD8A38EDAA08ED9A38BD6A08BD69D88D39F89D29C86
D19A85D29983CE9B84CC957FCB947FC68D79C68D79C28B75BE8873C18771C08B75BF836F
BD866EB8826DBA846FB88672B37C65B37960986B5A7F58495C3A2D472D26422620291B17
291D1B2E1C171F14151B0F0E190F0F180D0F180C0B1C10111C1310291E17321D17563B33
DED1D1E5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDBE5DCDDE5DCDD
E5DBDCE5DBDCE3D6D664443C553D365A392D5540395C403B5A433D58423B4C38324C2F29
41251F341D1836211B422620422A24452D25583B3269453B8058479D6752B5795FCC957F
DAA791E1B9A1E4BDAAE5BFAFE5BCADE5C0B2E5C2B3E5C9BFE5CBC1E5CBC1E5CAC0E5CBC2
E5CDC4E6CAC0E5CBC1E6C9BDE5C4B6E5C3B5E5C2B4E5BDB0E2BAA8E2B1A1E1B69FDFAC96
DDAB97DCA590D8A58FD7A08AD6A08AD6A38DD99F8CD8A28AD6A08BD69E88D49E89D49C87
D29A86D19985CD9A83CB937DCA917DC58B77C38A77BF8874BB8670BD846FBF8873BE816E
BB846DB7816CB7826EB2826DAB765FA46F578C6253724D405231274229233F251F281C17
291D1B2F1D181F15151D100F1C11111A0F10130A0A190D0F1F1613271B1538221B7A5952
E9E1E3E4DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADBE5DCDDE5DCDD
E5DADBE5DBDBE2D5D660433B553D3751332A573D355B403A5C453E5C463F503C354D322B
452A24341D1838231C432922452C26472F2755382F684539825A49925F4CAE7159C58B73
D6A28CE1B8A1E1BCA8E2BEABE3BCACE3BDB0E4BFB1E4C6BCE4C8BEE4C6BCE4C8BEE5C8BD
E4C9BFE5C8BCE5C9BFE5C5B8E6C3B5E5C1B3E4C0B1E4BCADDFB7A3E1B09EE0B49DDFAA94
DBA893DAA48DD7A28CD7A18AD7A08AD6A38DD89E89D7A089D69F8BD69F89D59C88D59B87
D19A85D09A86CC9881CA907BCA8F7BC58B78C38B78C18A75BD8772BD8570C28874C28470
BD856FB9836EB5826DAC7D67A2705A90624D7E594B6744384C2C223F262239221E291C18
281C1A301E1A2016162012122215141C111111090A160B0D251816261913432922A3817B
EAE3E5E5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5D9DAE5DCDDE5DCDD
E5D9DAE5DADBE2D5D65E443C553E38482E26583B31593F395C453D604842543F384D352D
4A2E29351F193A241D432A22462E2749312852352D664537825B4B885847A56A53BC8068
D29C86DFB5A0DEBAA4DFBCA7E1BBAAE1BBADE3BCAFE3C3B8E3C6BBE3C2B7E4C7BCE5C5B8
E4C5B9E4C5B8E5C7BBE5C2B2E6C1B3E6C0B0E4BEAEE4BAAADDB49DE0AF9BDEB29BDEA992
D9A48FD8A38BD7A089D7A28AD8A08BD5A28CD79E87D59F88D69F8AD6A089D69A86D69B88
D19984CF9B87CB957FCA8E7ACB8D79C78D79C48D7AC48D78C08B74BE8773C68976C68772
BF8671BA856FB1816BA4765F9769557C5542714F435E3B3147271F3C242033201D291D18
291C19301F1B2117182314152619171E13130F090A130A0B2A1B19281812553730C6AAA6
E8E0E1E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5D9DAE5DCDDE5DCDD
E5D9D9E5DADBE2D6D6624A42553E38432C2659392D573E385B443C61494358413B4D372E
4C322D38221B3B251E422B22472F2849322A4F342C6244357E594A7D524298614CB1765D
CB927DDDB09BDCB6A0DEB9A3E2BCAAE1BBACE4BCAEE3C1B5E4C4B8E3C0B3E4C5B9E5C2B4
E4C2B4E4C2B5E5C5B7E4BFADE6BFB1E5BEADE4BCABE3B8A7DCB29ADFAF9ADDAF98DDA791
D8A18BD7A28AD69E86D7A288D89F8BD5A28BD59D85D59E87D69E89D6A088D69884D59986
D09883CE9B87CB927ECA8D7ACB8D78C88E7AC58F7CC6907AC38D76BF8975C78976C78874
BE8671B8846EAB7C659A6C578B5F4E6B483864453A53332A41241D39221E2E1E1B291D17
2A1C18301F1B2218182315162719181D1212100A0B140B0B2B1A18301C15724F48DFCBCA
E5DBDBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5D9D9E5DCDDE5DCDD
E5D9DAE5DADBE3D7D86F564E553E38452F295A392C553E3859423A5F46415D443E4F3930
4D342E3F28213C251F3F2A22462F2749322B4F352E5E4134745346734B3E875644A36D56
C18670D9A892DDB29BE1B8A1E6BFABE5BDADE5BEAEE5C0B1E5C4B6E5C1B2E6C5B6E5C2B3
E5C1B1E5C1B3E5C3B3E3BCA8E4BCAEE4BCA9E3BAA9E2B6A4DDB199DFB09ADDAC96DEA790
D9A089D7A189D69C85D6A086D69D89D59F88D39B83D59C85D49C87D59D86D49682D39682
CF9680CD9884CA8F7CCA8D7ACA8D78C78F7AC58F7BC7917AC48D75BF8A76C48874C38872
B8836DB07D679F705B8E604C7C52445F3D30573A31492C23382019321F1A2A1C19291C16
2B1D182F1E1A2318181F1315211514170F0F150D0E1A100F2717143F251D98746EE9DEDE
E4DADAE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5D9DAE5DCDDE5DCDD
E5DADBE5DBDCE4DADA81676158413A4B342E59392D543E37563F385B433D604741513B33
4B342C472F293D25203C2721442D2547322B4F3731583D33664A4069453A754B3C956550
B47761D29D85DDAB94E5B69EEAC1ABEAC0ADE7C2AFE6C0ADE8C4B4E8C3B1E7C4B2E5C1B2
E7C1AFE6C0B2E5C1AEE2B9A5E2BAA9E3B9A4E3B7A6E1B3A1DFB09BDFB09ADCA993DDA58F
DA9E87D8A089D49A84D59C82D39986D49C85D09882D69A84D29A84D49982D1947FCF927B
CD947DCC947ECA8C7ACA8E79C88E79C58E78C58D79C59178C48C73BD8974BD8570BC846D
AF7E67A3725D90604D8152416B443956352A4B30283E261D2D1C152A1B16261A17281C15
2D1E182C1C18231717191011170E0F0F090B1C101125171522141055352CBEA09DEAE2E3
E5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5D9DAE5DCDDE5DCDD
E5DBDCE5DCDCE5DCDD967B785F463F543B35583A2E533D37523D36563F38624943543D36
4A332B4E37313D262139241F412A2245302B503A34533931584139604037634135865D4B
A46953C79077DAA28AE5B199EBBFA8EDC0AAE7C2ACE6BDA7E9C2B1EAC3AFE8C2ADE5C0B0
E8C0ACE6BEAFE3BEA9E1B6A1DFB7A5E1B69FE2B5A4E0AF9DE0AF9BDEAE99DAA58FDCA38D
DA9C85D89E88D39782D3987ED09682D39881CE9580D69881CF9782D2947ECD927DCB8F75
CB9178CA8F78C98978CA8E79C68E79C38C76C48B77C38F75C1896FBB8671B5816AB27E66
A5765E9566517F51407245375A372E4F2E25402720342018241711221712231816261A14
2E1E17291915211414120C0D0D080908040624131430201C2315106F4C41DBCCCBE7DFE0
E5DDDEE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DADBE5DCDDE5DCDD
E5DCDDE5DCDDE6DEDEAC91916B514959403A553A2F533D36513C35533C35624842563E38
4B342C523C363D262137221E3F2820422D294F3A354E36304E3A345A3D35563930785445
915A47B78068CF957DDDA68FE3B69EE8B9A2E3BBA3E2B7A0E7BEACE8C0AAE7BEA7E4BEAC
E7BEA9E5BBABE1BAA4E0B39DDEB5A1E0B29BE2B3A1DEAC9AE0AC9ADBA994D69F88D89E87
D79981D79B85D1947FD1947BCD937ED2957ECC927ED6957ECE947FD1907ACB917BC98C71
C98E74C98C73C98776C98E78C48E78C18A73C28974C08B71BD856CB6816BAD7A63A7755E
9A6C558659466F433464392D4B2D2547272036201A2B1B141D130F1C140F201514231812
2B1B162214121D11120E090B0805060603052714143827203420198D695EEDEBEBE3DBDC
E5DDDEE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDBE5DCDDE5DCDD
E5DDDDE5DCDDE6DEDFC1A9AB7D625B5A413A52392F543D36543D37523B355E443E58403B
4E372F543E373E262137211D3F26203E2A254D39334B352F4B3832563C354F372F6A493D
7C4D3DA36F5BB9846DC9947ED1A48DDAA891DAAA93D9AC96E2B7A3E2B8A1E4B8A0E2B9A5
E3BAA5E1B4A4DEB69EDFB19ADEB59EDFAD97E2B29EDDA997DDA895D79F89D0967FD2967E
D1937BD39780D0917AD09078CD927BD0927ACD917CD3937BCF927DD18D77CC907AC98C71
C88C70C98B71C88675C78C77C38D75C08870C08670BA866CB58068AE7A63A4725B9B6954
8E5E4A794C3B613A2C5730253F251F3C211B2D1C1525171219100D1A110E1D12121F1410
231612180E0D160D0E0E0A0B0C07090D070923121039272056382FAC8B83F1F5F5E2D9DA
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDDE5DCDD
E5DCDDE5DCDDE6DDDED4C1C49278735A423851392F563D35584039533C35583E3859423C
533C34543C343F272239221D4026203B26224A35304B352F4D3933553C364E38305E3F36
6942368C5E4F9D705CAD7D69B78C78C3917CCC947ECD9E8AD9AC97D7AC95DDAF97DEB29A
DCB39EDAAB9BDAAF98DCAE96DDB39BDDA794E2AF9ADAA692D8A28ED1927BC68C73C88B73
C78B73CD9177CD8D73CD8B76CD9077CD9076CE9079CE8F77CF8F7BD08A74CD8F79C98C72
C78A6CC88B6FC78573C48974C18A70BF846DBC836CB37F66AA7A64A370599B67528E5C49
82503E6D41325633264C2A1F36201A301A16261812201310180D0C1A0F0E1C10101A100F
180E0D0D07080D090A120C0E170E101A10111D0F0C3A271F815B52C8B0ABEEEDEEE4DBDC
E5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE3D7D9A78F8E5E463B533C33583D355C423A543C365138325A433D
58403A533A324029233C231D41252139231E48322D4B362F523C36553E39503B34543731
593A31764F44815D4C9067569B7463A97A67B97F69BD8E7DCD9F8AC89C86D2A38CD5A78C
D1A894D09F8ED2A690D7A78FD9AE95D99F8EDEAB94D5A08BCF9983C5846BB98167BB7F66
BB8069C3886DC7876AC88571CA8C71C78B6FCD8D73C78A71CE8B77CD8670CC8D76C88B72
C48768C5896CC3836FBE846FBE8569BB7F68B67D66AA765F9F725E96644E905C487F4E3E
74433361382A4C2D2242241A301D172514122016101B100F180B0C1A0E0E190D0F140C0D
0D0708030103050406160F10211517291A191C0F0B422A23A9827CDDD1D1E6DFDFE5DDDD
E5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DBDCECE5E6BBA7A96D53475B433B583D345C4139553D374E36305A433D
59423D523930432C253F251F41252138211C472F2A4C373057403956413B544038503530
50362F66443D6C4F41795749826152936857A66D59AB7F70BD8F7AB68975C1927EC7967C
C19784C0907EC69682CB9981D1A289D09484D4A28ACA9681C08D77B5785FA9755DAA715A
AC745EB47B61BB7C60BF7C69C38368BE8367C7866CBF8269C98470C6816AC6876FC2866F
BE8162BE8367BC7D68B77D68B67D62B47761AC755F9F6C57926755885743814F3E704234
65382B542F2443281E3A20182B1B151D110F1D140E180E0E16090B190C0D150B0D0F090B
07030500000202020418101126191A33211E2616105B3B33C7A6A5E9E7EBE0D2D3E6DDDE
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DBDCEEE9E9CCBDC0896C6169504A543B33563C34553E3750383258433C
56413B523A32462F284328213E242038211D472F294D372F5B433D58433D59443D523935
4F37325C403A62483D6E5144725549845E4F96634F987162AA7C68A27564A97C6BB0806A
AA806EAB7E6BB2816EB7816DC08E76C18774C2937BB98871AB7D69A06D5697685497624F
9C6550A06B55AA6E54B06F5BB4765CB1775BBB7B61B6795FBF7B65BB7861BA7B64B57B65
B3785BB2775DAF725CAC745FA97259A76D579F6A55926250865B4A7A4A3970433460362C
56302547282039211A321D172719131B100F1C120E160C0E13080914090B0F080A0C080A
080507050305040405170E0F20151635221D3E251D865D56D9C2C3EDEEF2DED0D0E6DDDE
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DBDCEBE5E5DACFD2A98E877C635F513A334E362E553E37563E3756413A
503D37533E354A342D462A243B241F3A231F48312A4E372F5E46405B453F5E484158413D
543C3759403B60473D6C51466A50467D5A4B8A5D4A866455946A578C61528C6456956757
8F6756926A589969589C6654A97560AE7861AA806AA37660926A598A6350845C4C825345
8A5643895948945E479C604B9F644EA1674EAA6D55AA6D54B07058AB6D56A86C55A26D57
A46C53A068509D634D9E695498644F97614C8F5D4B8557487A4D3D6B3D305E372B522D25
492A213A231D2E1B152C1B172417121B10101C100F140B0D0F06080D06080704060B0709
0F090C100A0B0D0809170D0C170F0F34201A613D35B58E89E2D4D6EBE9ECE1D5D5E5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE6DDDEE6DDDEC6B0B0917877533D3749322B553E385B433C533E38
4A38325441394E3932492E273A241F3D27234B342C5038305F49425D4841634B455F4B46
5B443E5A433D6349416E544A684F4678584A80594776594A805948764F43704E44795146
724F417856477E53447E4E3F8E5D4B97684F916C598B644F7A584A765A497250446E453B
77483771483C7C4D3B85503B8752408D5740955D489A60489D624B98614A925C478C5D48
925F498C584389533F8D5C488556458454417E4F40764B3F6D40325D32284C2C2345251F
3D251E301E1A2515112618172115111D11111C0E0F130B0D0B04060703050101030A0709
160F121D1213190F0F1B0E0C150E0D3A221C865A54D9C1BFE7E0E0E6DEDFE5DCDCE5DCDC
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE1D7D8ECE5E5D9CCD2A690925F48434C352E543E375C453E503C35
47373055443C513D364B312B3B2722412B274E372F543B33614B45604A43664D4763534C
614A435B463F664C456F564C684E467555477756456A50416E4B3D6341375A3E37624139
5A3D31624539684337643D3073483B7F564279594A74524166483D644F4261443C5C3A32
643B2D5B3930643E306E412F6F42337748347F4D3C86513C86533E83533E7C4D3A764D3B
7E503E7748377344327A4E3C72483A7046366C42366641355F3629502B223E241D3A201B
34221B291B181F110F2115151E13101C11121A0C0E110A0C0904060402040001030A0709
1A121423161523151227151124181652322BA87B79EDE8E7E9E5E5E1D5D4E8E1E2E5DCDC
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE0D6D6EDE6E6E3DBE2BBA8AD775E5A5A413B513B3557403A503A33
4B393256463F543F394D342E412D2747302C523B335A413A644D46634D45664E4865544D
634D465D4740664D466D5349694D446F50426F514464493C624236553830503832553A33
4A32295139305B3B3355362B5E3B32684639674B3F624337593C345743395339334C312A
5231274A2F284F32285935265A352960392A693F306E41316E43326E4533694131644032
694232633B2D5E382A64402F623B2F5C392D5C372C56362B532E2346271F352019331C18
2E1E18261A161C0F0E1B11111A110E180E1014090C0F090B0905070604060504060A0708
160F111E13112918143F231E4B33307F554FC49D9FF2F6F5E9E5E5E0D3D2E8E2E2E5DCDC
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE2D8D9EAE3E3E6E0E4CEBFC5957B79715550513B354F3933513A33
533F3857464055403A4E373149352F4C3530553F37624942664E47665048654E4765514A
634D455D4640634D45674C436A4A4168483A684B416244395B3D334B332C4F3933503932
422E2747312C553A344F362C50332D5437325A403755383152352E4C373148302B412A24
4328223D29223E2921472B20482B214A2C2154322654322757342858372A59382B55362C
5534275230244D2D234D3224533026492E254D2E24452C214828203E251D301E172E1A16
291B15251A161B0F0F160C0D170E0D120B0C0D06080C08090B07090C080A0E0B0C0C0909
110B0C160D0B2F1C175D37337D5C58AF8785D8BFC1EEEFEFE8E2E3E2D6D6E7DFE0E5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDCE6DDDEE6DFE0DED3D8B29A9B8A6D6B563F3A49342E533B34
5B443E58454055403A4F3933513D36503A3357423B684F49684F4668524A624D46634C45
614B445D453E5F4B4361453C6B473C60403260443D614036573B3346312B513C364F3B33
402D28402D2A523A374D392F462E2B442C2C5038314A2F2C4D3029432D2A3E292438251F
37221E34241D31211B39231C3A231B37211A42271E3C241D41271F452B214A2F25472D26
41271E43271E3E251E39251A46271E39231E40261D3522183D231D37241B2C1D162A1914
2518132519151C0F1011080A130B0C0C07090704050A07080E090B130E0F191213130D0B
120B0A150C0A3C25207D5150AB8A86D4BCBFE5DCDCE7DFE0E6DDDEE5DCDCE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDCE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE7DFDFE2D8D9E5DCDAE9E1E4CAB5B9A28789684E494B352F553C34
5D453F55413C543E394F3A3457433C533E3759443E6A534D664E4567514A5E4A43604740
5E48415D453E5B473F5B403769433858392B573D375E3C33543932442F2A533E374F3B33
402D2A3D2A2A4F3A384B3B333F2A2939242748312C402828472B263B262436231F32211C
2E1D1B2C1F1A271B172E1C182F1D172A1A15331E182B1A16311D1835211A3C261F3B2521
301D16352019311D182A1B13391F192C1C18331E17281911311D1A302119271A14251712
2014102217131A0E100D060710090B0905070604050B0809100B0C1812122016171E1310
2214112A19155939349D7172CCB3B0E8E5EBECEEEDDFD2D3E4D9DAE7E0E1E4DADBE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DBDCE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE7DFE0E1D7D8E5DBD9ECE5E8D9C9CDB9A2A5886A68583F38553C35
563F394D3A34523D374F3B355A463F56423B59453F68524C614B42634E465A463E5D443C
5A453E5E463F584139583D35643F355132274D352F56372F513731442E29523C364D3831
412E2C3A282C4935344738333925263220233F29273522223C24213420202F1F1D2E1F1A
271A19261A172116142618162819152316142A19152216122717142819142D1C172D1C1A
2315112A1A1526171320140F2E19152417142818121D120D251616281B161F14111D1310
170F0D1A110F160C0E0C05070F090B0A06070D080A110B0D110C0D1A13122316162E1D17
442A24583832855F5ABA9498DECECCEEF5F9EDF2F0DECFD0E3D8D8E7E0E2E4DADBE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DBDBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE6DEDEE2D9DAE5DCDBEAE3E4E1D5D8CCBABEAC90916D504A573E37
4C373044322C513C35503C355C463F57453E59443E624D465A463F5D484155413A59413A
57423B5F4940543B34563D365D3B314A2D24422C254C322A4D352F442B274C363148312C
412D2B38272E402D2D413130352122301E203622212B1D1C2E1C1C2D1C1D291C1B2B1D19
2317172015141D13122115142317152115142416132016112215122014101F130F211413
1B110F2216131E130F1D110E2415132014121E120F160D0B180F10201412150D0D160E0D
0E0A0A110A0B110A0C0D06080F0A0C0E080A191011191213140E0E1C1311241514432B22
704A43906762B4918ED2B9BCE5DBDAECEEF1EAEAEAE1D5D6E4D9D9E6DEDFE5DBDCE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE6DDDEE6DCDDDCCFD3CCB7BC8667615F463E
46332C402E28513C35523D365C443E56464057423B5B463F53423B57423B523D36574039
543F395F4A4150352E553D3754372E44282138241D412C2448322C432825452F2A432A27
402B2A36262F3625243A292B311D1E2F1E1E2E1D1D23181722151727191A251A19281B18
2016161B11121B10111E13132115152115152115132117132215131C110F150D0A180F0F
18100F1D13121A110D1D110F1E12131F1312180E0D130A0A0F0A0C190E0F0E08090F0A0B
0806070905070D08090F080B100B0D140B0E2617192318191A12112317132B18165E3E33
9A6F6BC09B99D9C4C3E3D9DAE7DFE0E7DFE0E6DEDFE5DCDDE5DBDCE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE4DBDCE6DEDEE5DDDFE2D8D9E7DFDFE6DDE0E1D6DDA1837D725750
503C3448342C523D36513C3558403A52433D533F385440394F3F3A534039523C3657423B
523E385B4940492E28533D374B31293E241F2F1E1737251F412D284025223D28243C2322
3D272634242C2D1D1C3322252E1A1B2D1D1B2819191E15141B1114231718221818261A17
1E1415190F111A0E101C11121E13152115161F13132419152518161D1211140C0B180E0F
1A11121B13131A110E1F12111C12141F1413150D0C130A0B0A0709150B0D0A06070D090A
0806080905080E090A140B0E140E10190F112D1B1C2A1D1C241715321F194025207F584D
BB9493DEC7C7EEEAE9ECEEEDE6E0E1E1D2D2E2D4D5E8E1E2E6DEDEE4DBDBE5DDDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DADBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE4DBDCE7DEDFE5DCDEE1D7D7E8E0DFEAE3E5EAE4EBBBA19D92756F
6E554D5E463E553E384D39324F3A34493B354F3C35513D3651403B55423D58413B5B453F
543E3954433C3F2822503B35422B2438201C2A1B162F201B38262339211F36231E341F1F
3522213021262518162D1D202A19192A1A192517181C12121B1114211516201617231715
1D1314190E10170C0E180E101C11131F13141D1212251A172A1B1B2216171B1212201313
2016171D14161F14132213151F1517201414170E0E150C0E0C090B140B0C0D0709100A0C
100B0E140C0F180F101B11141B13141E12122B19192D1E1B311F1A4C3026663F38A37C73
D1B4B5EADFDFF3F7F7EEF3F1E6DFE1DFD0CFE0D2D3E8E2E2E6DEDFE4DADBE5DDDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDCE6DDDEE5DCDDE3D9D9E7DFDFE9E2E3EBE5E9D1BEBDB69C99
967B747D615B5A433D4B373147342E40322C4B3A33503D3656443E5A48435F4943614A45
56403B4B3C3736241E4C38323A261F331E1A281A182A1C182D1E1D301D1C2F1E1A2D1C1C
2B1C1B2A1D1D1F141227191C2618172517162317181D11121F14161F1415201516201414
1D12141A0F11150B0C150C0E190F101B11121B10112419182F1F20281C1F281C202E1C1B
2A1C1E22171A271A1A24161A25191B2115161B1211190F12130E0E170D0E150C0C170E0F
1E141725191A26191924181A251919251613271613301E18442A216C483C92645DC4A5A1
DFCCCDEBE4E5EFEFF0EBEBEAE6DFE0E2D5D5E2D5D6E7DFDFE6DDDEE5DBDCE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDCE6DDDDE6DEDEE7DFDFE2D8D9D5C2C3
BBA3A09C817E664C484F3A3645332E3D2D284A3A33513E375B47415E4D4865504A654E4A
5A433E43363231221D4B373037231C311D19291B1C271A162417172718192A1B16271A19
2216152418151B110F2216172317162014132217181E10122317181E12141F13141D1212
1D11131C1112140A0B120A0D160D0E180E0F1B0F1024191A3323262F22273428303C2624
352426281B1F2F1F2227191E2B1D202316192116151F14161C14121C11111E13111F1314
2C1D203626263522222D20203220202E1D152715103821185E3B2D8D6457B78F88DBCDCC
E6DDDEE7E0E0E6DFE0E6DEDFE6DDDEE5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE4DBDCE5DCDCE7DEDFE4DBDCE3D9DAE2D8D7ECE8EBE9DFE2
D6C5C6B7A1A17C605D604945503D3746342D4C3B35513F385C46405C4B4765504A654E4B
5C4540423531362722503A343B261F331F1B2E1E1F2719161F1314211516261915231817
1C12112116101A110F1F14142017151C12112016171C0F112417181C11121E11131A1011
1C10121E1212150C0D120A0C130B0C170D0E1B0F1024181B34252933262E3C313D452E2C
3D2B2E2F2024352429291C2231212327191C291C1A261A1C261B17241816281A15291919
372526402E2B3E28273426233E27253D261A361E164D2E217F5442AB8377D1B6AFE8E9EA
E9E7E7E2DADADFD2D2E1D3D5E5DBDBE7E1E2E7E0E0E4DADBE5DBDCE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE4DBDCE5DCDCE7DEDFE3DADBE2D8D8E1D7D5EEECEFEFEAEE
E3D9DBCBBBBD9C7F7F8066636B544F6149415240394F3D3755403951413C5B47415D4946
5D4640493A374736315C453F4831293B26213623222A1B172014141F1314271916211816
1E13122116101D13101E13131F16141B11111C1314170B0E1D1213190E101A0F10190E10
190E0F1D12121A0F11130B0D110A0C170D0F1B101023171C322429342630403541453031
42303436252A38272D2B1F243324242E1E223123202F22222F211D30201E32211B321F1E
3C2827402D283E2824382721482E285032245835296F4638A67766C4A39ADFCFCAECF2F4
E9E9E9E1D8D9DDCFCFE0D1D2E4DADAE7E1E3E7E1E1E4DADBE5DBDCE5DDDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE6DDDEE4DADBE3D9DAE3D9D8EBE7E9EDE8EA
E7DFE1DACFD1BEA6A8A68C8C8E75738469615E48414F3D374B373143332E4C3A3453413E
5E47415645425D4A466C544E5B4039462F29412824311F1A2818172113142A1B19231915
2618162619132317132014132116141D1313190F1010080A130B0D150D0E170E0F180E10
150C0D1D1212201518170E0F110B0D1A0F111D131123171D2E212632242F41333F3F2E34
4434373C2C2F38282D2E22263325243724283A2A253829283726233D2A273B28203A2723
3C29253B26203B251E3D271F53352C67413583564B946A5EC8A096D7C1BCE4DBD9EAEBED
E8E5E5E3DBDBE1D4D5E2D5D6E4DADBE6DFE0E6DFDFE4DBDCE5DCDCE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDCE5DCDDE6DEDEE7DFDF
E7DFE0E5DCDEDBCDCFC8B5B7B0999BA78E8670554E55423C48352E3A2A2441302A4B3B38
60494264514D725D5B7A615D6B504A513A324D2E2539251F321F1B261617311F1E281B16
301F1C2D1D192C1D18251715241716211616180E0E0D07080C0708140C0E150D0E1A0F12
140B0C1D1313281B1F1D1313130D101F121621161324191F2A1F2331212C40313A392B34
44363940323237292C3125263325233F292E41302A41302C3D2B2849322F432E26432E29
3E2A2337221B3D261C472C2063423481544CAB7D74B2918ADEC9C6E3D9D9E6DFE0E6DEDF
E6DEDEE5DDDDE5DCDCE5DBDCE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE4DBDCE6DDDDE6DEDFE6DEE0E1D6D6E1D7D6
E5DCDCEBE4E5EDE9EBDFD4D8CAB8BFC3B0AA896A6468534D543F38402D2843312A4B3A37
614A436B57547C67667E6763735A555A423B563529422C263D2721301C1C39252530201A
3B262234221F35231E2C1C1A2A1A1A291C1D1D1111130B0C0F090A191012191112211317
190F10211617302228261B1A1B1317291A1F291D182B1E252B202432222C423036372B34
46383A463734392B2C362927362723452E3045332C47342D412C2B5037334A322949352D
442E2540251E4C3024603A2C7D57469E6B6AC7A39DC7B4B2E9E6E9EAE9EBE6DFE2E2D4D4
E3D7D8E7DEDFE8E1E2E7E0E1E5DDDEE4DADBE4DBDBE5DDDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE4DBDCE6DDDEE6DEDFE6DEE0E0D4D3DFD5D4
E4DBDBECE6E6F2F1F3E9E4E7DACED5D6C8C4A888858A726E755B545C433E56403955423E
614B4469555177616077615D7059555E48415B3B314B352E4830283D2624432D2B3A2820
422D283C27243E2B253623203222223626282C1A1A26181821141625191C24181A2C1C21
24171A291D20392A30332524291E2339262C35282239292F34272B3928304835383C3038
4B3A3B4D3C363F2F2D3F2F2B3F2C2648303046332C48332A412B284E352F4E33294E3830
50362B58352D6D493B87584A9F7868BA8B8FD8BFBDD5CDCCECF0F5EBECF0E6DEE2E1D1D1
E3D6D7E7DDDEE8E2E3E7E1E1E5DDDEE4DADBE4DADBE5DDDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE6DDDDE6DDDEE6DDDEE2D7D7E2D8D7
E5DCDCEAE3E3EEEBECEAE5E7E3D9DEE1D7D5C6ADACB19B99A0857E836764765B5469534D
644E48624E4B6954516A555068524F614B475C423E543F385239314D332F4E3633473129
4A342E452C2847332D432E293C2D2E4533363F292A3F2C2A3A282934262B3324263A272F
34242A34262D4332374032313A2C344A373D45352F4B383C423337443237523D3D48393D
533D3C553F374A34304A36314C322A4B322E47332B493027412A254A3129533529543C33
6343377B5049966D61AF8278C2A196D2B0B5E1D2D2DFDADAEAEBEEE9E7EAE6DDDFE3D5D6
E3D8D8E6DCDDE7DFE0E6DFDFE5DDDEE5DBDCE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDD
E5DDDDE6DDDEE7DEDFE7DFE0E7DFE0E7DFDFDDD0D2D3C3C5C6B1ADA79092987D76826862
6D55515E4C495D4843604C45624D4A65504E5D4B4C5E4B445D433C5D443D5C433D563E36
543E3852352F523D37523A34483B3C554245523C3C59433D543F3F45353C43313448343F
44323C3F303C4D3A3D4C3E3E4B3B4459474C53413D5C48485140434F3E3F5C4642564441
5C3F3C5D4238563A34573F375B3A2F50372E4B352D4E3128482E254B31275D3B2D5F443A
7B544A9E716DBA958FCEB0ABDCC9C6E2D4D7E6DEDFE6DFE0E6DFE0E6DFE0E5DCDCE5DCDC
E5DBDCE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DBDCE5DBDCE7DFE0E7DFE0
E5DCDEE2D8D9E0D4D4E3D9D8E8E0DEE9E2E4EBE9ECE9E1E6DFD5D3C3B4BBB69E9A9E837D
806763695553604A44644F4767524F6E585962565B695752674F4A6C554D6C534A664C46
624D4660413A5F4944614941544A4A625052624D4C6A544D65514F53434A503D40533F4B
503E4A493847533F4155474658454E6252545C484568524E5C4849584641624B44604A40
61403A63433861403861453D684135593E32563D345D3A305A3A2F5B3C31724A3B76564D
986C64BA9292D3B7B7DFD4D3EAE6EAEAEDECE7E4E6EAE1E2E2D5D4E3D7D7E5DBDAE6E0E1
E6DEDFE4DCDCE4DADBE4DADBE5DCDCE5DDDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DBDCE5DBDCE7E0E1E7DFE1
E5DCDDE1D7D8DED1D2E2D7D7E8E0DEEAE2E5EFF1F3F1ECF2EAE5E5D5CDD4CCB9B7BAA19C
9E858385706F7A615B7D655D7E67647D67696D646C756360725B5A78635D7E645B755B59
75605A71514A6E57547057516257576D59596D5856715C536C59565E4D525A46485B4752
58454F513F4B5540405849475D494D6352505D484369524B604A475C463F614A41634A3C
613F3763433768453A67493F6E473C674A3C6A4C43794F437B54487C584B92665898766E
B58B88CFB0B2DFCED1E6E6E7EDF0F5ECF4F2E7E4E7EBE0E1E1D2D1E2D4D4E4DBDAE7E1E2
E6DFE0E5DCDCE4DADBE4DADBE5DCDCE5DDDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DBDCE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDCE6DEDFE6DEDF
E5DBDCE3D9D9E1D6D6E4DAD9E7DFDEE8E0E2ECEAECEEE9ECEBE6E7E0DADEDBCECED2BFBD
BFAAABAB9798A08684A188819F86858F7B7D7F737E836F707D696C82706F907771856B6E
8B77748264607F686780676273636377615E775F5D735C556D5956695456624D4D624D54
5E4A4E5A444A56413F5B47435E4847614D475B443E654D446148415E443A5E473C614739
5F3F346343386E4A3D6B4C42724D45785A4C82615A9A6D61A1776FA37F75B48B83BD9E99
CEAFAFDCC8CAE4DADCE8E6E8EBEAEEEAECEBE7E1E3E9DFE0E2D6D5E3D6D5E4DCDDE6DFDF
E6DEDEE5DCDDE4DBDCE5DBDCE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DADBE5DBDCE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDC
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDCE5DBDCE5DCDCE5DCDDE6DDDDE6DDDEE6DEDFE7DEDFE7DFE0E7DFE0E6DDDEE4DADA
DCD0D2CDC0C3C4B0B2C4AFAABFA9AAA39193948592947C818979818D7D82A38A89947D84
A18E8F937A79917A7C907775876F70826A64826764765D58705A57775D5A6C56536C5658
68514E664D4B5B4541604942624A436149405D443A634A4165493F64453960473C63473A
61433767483D7754457453487957528C6D629C7A75B88F84C19D9AC4A9A5CEB2B0DBC6C6
E0D1D3E5DBDCE6DEDEE7DFE0E6DDDEE5DDDEE5DCDDE5DCDCE5DBDBE4D8D8E5DEDFE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDCE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDD
E5D9DAE5DBDCE5DCDCE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE4DBDBE4DBDB
E5DCDDE6DEDEE8E0E1E6DEDFE4DBDDE3DADAE1D4D4E0D6D5E3D8D9EAE0DFEBE5E7EEEBED
EEEBEDE4DEE4DDD2D7DDCFCCD7C6C9B7A8A9AB98A6A78E969A8C979C8E98B59FA2A5929D
B6A5AAA59293A48E93A28B8B9F81839479729375728267647B64628A6B657E66617D6564
7A5F577B5D546B534E70534B70554A6D50466B4F436E524A7455487550456E5247715247
70514477584E8A675886655A896B68A3867FB59693CEB0A7D8BEC2DACDCDDED2D5EDE5E8
EAEAEDE9E7E7E6DFDFE5D8D8E1D4D3E1D3D4E4D8D8E3DADAE6E0E1E6DDDDE5DFE1E4DADB
E5DBDCE5DCDDE5DDDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDCE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDD
E5D9DAE5DBDBE5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE4DBDBE4DBDB
E5DCDDE7DEDFE8E1E2E6DEDFE3DADCE3D9D9E0D2D2DFD4D2E2D7D8EAE0DEECE7E9F0EFF1
F3F3F5EDEBF0E8E2E8E8E0DFE4D8DAC9BDBEC2AFBABDA5AEB1A6B1B2A6B1C6B5BABAABB6
C8BBC2B9ABAEB8A5ADB7A3A5B89A9CAD928CAB8D8C9B7F7F937B7AA3837D977F7C967E7C
96796F96776C886E698B6B648C6E638A6960896A5F8A6C65917063946B618B6D638D6C63
8C6D6093756EA68679A4847CA48A8ABCA5A1CAB2B2DDCAC4E3D4DBE4E2E4E5E4E9F1F2F6
ECF4F6EAECECE6E1E1E4D8D9E1D4D3E1D2D4E4D9DAE3DBDCE7E2E4E7E1E3E6DEE0E4DADB
E5DBDCE5DCDDE5DDDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DADAE5DBDBE5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDC
E5DCDDE6DDDEE7DEDFE5DDDEE4DADCE3DADAE2D6D6E1D7D7E3D9DAE9DFDEEAE4E5ECE8EA
EFEBEDECE8EBEAE4E8EAE3E3E7DEE0D9CFD0D5C6CDD2C0C6CAC1C9CAC0C9D6CBCFCFC4CD
D7CDD3CDC2C6CCBDC5CCBCBFCEB6B9C6B0ADC3ABACB9A2A4B09B9CBBA09EB29E9EB19C9C
B39A93B3978FA9908FAA8C89AC9089AD8C89AD9089AD918DB2958CB5918BAF928AAD9089
AE9187B49A98C5AAA3C4ABA7C2AFB3D3C4C3DACBCDE4DAD9E7DFE5E7E7EAE7E7EBEEEEF1
EBEEF1E9E9EAE7E2E3E5DCDDE3DAD9E3D8DAE5DCDDE4DDDEE7E1E3E7E4E6E6DBDCE5DBDC
E5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDD
E5DDDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DADBE5DBDBE5DDDDE5DBDBE5DCDDE5DCDDE5DCDCE5DBDCE5DDDDE5DCDDE5DCDDE5DDDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDCE5DCDCE5DBDCE5DCDDE5DCDDE5DCDDE6DDDEE6DDDEE6DEDF
E6DEDFE7DEDFE7DFE0E7DFE0E7DFE0E5DDDDE5DADCE3D9DBE2DADCE2D8DBE3DBDCE1D9DD
E4DBDDDFD4D7DCD0D7DDD1D3DFD1D3DBCDCDD7C7CBD4C4C7CABBBECFBCBFCABCBFC8BABD
CBB9B8C9B6B5C7B2B5C4AEB0C8B1B1CAB0B5CAB7B5CBB7B5CBB9B5CEB7B4CDB6B1C8B3AF
CAB4AECEBDC0DCCBCADCCECFDCD0D5E5DCDDE5DDDFE7E1E3E7E0E2E6E2E3E6E1E2E6E1E2
E6E0E1E6E0E1E6DEE0E5DEDEE5DEDEE6DCDDE5DDDEE5DDDEE5DDDDE5E2E4E5D7D5E5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDD
E5DDDEE5DCDDE5DCDDE5DDDDE5DCDDE5DCDDE5DCDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DDDDE5DCDDE5DCDDE5DCDD
E5DADBE5DBDCE5DDDDE5DADBE5DCDDE5DCDDE5DCDCE5DBDCE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE4DBDCE4DADBE5DBDCE6DDDDE6DDDEE7E0E1E8E0E1E6DEDFE3DBDCE2D8D8E0D5D5
DFD3D3E1D6D5E4DAD9E4DBDCE5DEDEEDE5E6EEE8E5EDEAE8F2EAE7F1E6E3ECE2DFEEE3E1
ECE0DDECDDDEE8DBDEE9DDDDE9E1E1E9DEE0E4D9DDE6DBDDDDD2D5DCCFD5DBD0D5D9CED2
DCCFD1D8CBCFDBCACED6C7CAD9C9CDDCCAD2DCD1D2DFD1D0DBD1D0DCD1CEE0CDC9D9CBC7
DCCAC7DFD2D6E9DCDEEAE1E2EBE0E4EEE4E4EAE1E1E7DCDEE5D8D6E4D5D3E4D3D1DECFCC
E1CECCE2D1D0E4D3D3E3D7D6E5D9D8E6D8D7E4D7D6E4D6D4E3D3D0E1D7D6E2CECBE5DDDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDD
E5DDDEE5DCDDE5DCDDE5DDDDE5DCDDE5DCDDE5DCDDE5DDDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDCE5DCDDE5DCDDE5DDDDE5DCDDE5DCDDE5DCDD
E5DADBE5DBDCE5DCDCE5DBDBE5DBDCE5DCDDE5DCDDE5DBDBE5DCDCE5DCDDE5DCDDE5DCDC
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE4DBDCE4DADBE5DBDCE6DDDDE6DEDFE7E0E1E8E0E1E6DEDFE2DADCE1D6D6DFD3D3
DED1D1E0D4D3E3D8D7E3D9DBE5DDDDEFE8E8F1EDE8F0EFECF6EDE8F4E6DFEEDCD3F2E0D7
EEDBD3F0DAD6EDDAD8EDDDD9EEE1DEEEE0E0EADCDCEDE0DEE7D9D9E4D6D9E4D6D9E2D5D6
E4D5D5E0D2D5E4D2D2DFCFCFE1D0D3E3D1D5E5D7D3E7D5D0E2D4D1E2D5CEE6D0C9E1CEC8
E2CCC6E5D1D0EBD6D4ECD9D6EDD8D5EED7D2E9D4CEE4CBC8E0C8C0E0C3BCDFC2BAD9BCB5
DBBCB4DDBEB9DFC2BCDFC6C0E1C8C2E3C7C2DFC6C0E0C5BEDEC2BAD9BFB9DDC3BDE5DDDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DBDCE5DCDDE5DCDDE5DCDDE5DBDBE5DCDD
E5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
E5DCDDE5DBDBE5DCDDE5DCDDE5DCDDE5DCDDE5DCDDE5DCDD
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.535147 0.477324 0.988662 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -35 0 ]
[.5 1.0125 35 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(RGB) show
87.000 12.813 moveto
(18) show
99.000 12.813 moveto
(order) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
E1E1E1E1E2E3E1E2E2E1E1E2E1E1E2E1E3E3E1E3E3E1E1E2E1E2E2E1E3E3E1E3E3E1E2E2
E1E3E3E1E3E3E1E2E3E1E2E3E1E3E3E1E1E2E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E0E3E3E0E3E3E0E3E3E0E3E3E1E3E3E1E3E3E1E2E3E1E3E3E1E3E3DFE1E2DEE0E1DDDFE0
DDDFDFDFE1E1E0E3E3E1E3E4E2E5E4E8EAEAEAEDECEAEEEDEAEDEBE8E1DCE5D5C8E8D9CC
E6D7CBE6D7CDE6D6CFE6D9D2E8DBD4E8DBD5E6D8D3E7DCD4E4D9D3E3D7D2E3D7D2DFD5CF
E1D4CBDFD2CDDECFC8DDCCC5DCCDC7DBCAC4DFCEC3DECCC1DACAC0D9C8BED9C6BBD8C4BB
D7C2B7D8C4BADAC5BBDAC5BCDAC5BADBC4B9D9C3B8D5BDB3D3BDB1D3B8AED2B9AED0B4AA
CFB4AACFB4AACFB4AACFB6ACCEB6AAD1B5ABCEB6ABCEB6AACEB6A9C4ACA1D1C0B9E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E2E1E3E3E1E3E3E1E3E3E1E1E2E1E2E3
E1E2E2E1E3E3E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E1E1E1E3E3E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3
E1E1E1E1E3E3E1E1E1E1E2E2E1E1E1E1E3E3E1E3E4E1E1E2E1E1E1E1E3E3E1E3E3E1E1E1
E1E3E3E1E3E4E1E2E2E1E2E2E1E3E3E1E1E1E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E0E3E3E0E3E3E0E3E3E0E3E3E1E3E3E1E1E1E1E2E2E0E3E3E0E2E3E0E2E3E0E2E3
E0E2E3E1E3E3E1E3E4E1E3E4E1E4E4E3E6E6E4E7E7E3E6E6E2E3E3E0D3CDDFC4B2E2C9B6
E1C8B8E1C8B9E2C9BCE1CCC1E2CDC2E2CCC2E1CBC0E2CEC2E2CEC4E2CDC3E2CDC3DECBC0
DFC9B9DEC9BEDAC4B6DCC2B4D8C2B5D5BDAFD9BDABD8BBA9D4B7A8D2B5A4D0B2A2D3B1A2
CFAE9DCDAC9ACDA998CBA797CAA695CAA494CCA696CAA392CBA795CCA293CCA695CCA192
C9A292C9A090C79F8EC7A090C49E8DC89E8EC49F8FC59F8EC5A18DB6907FCBB5ACE1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E1E1E3E3E1E3E3E1E3E3E1E1E2E1E2E2
E1E0E1E1E3E3E1E3E3E1E1E2E1E3E3E1E3E3E1E3E3E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E0E0E1E3E3E1E3E3E1E1E2E1E3E3E1E3E3E1E3E3
E1E1E1E1E3E3E1E0E1E1E2E3E1E0E1E1E3E3E1E3E4E1E2E2E1E0E1E1E3E3E1E3E3E1E0E1
E1E3E3E1E3E4E1E2E2E1E2E2E1E3E3E1E1E1E1E2E2E1E3E3E1E3E3E1E3E3E0E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E0E0E0E1E2E0E3E3E1E4E4E2E4E5E2E5E5
E3E5E6E2E4E5E1E3E4E1E3E3E0E2E3DFE1E2DFE1E2DDDFE0DADBDCD9C6C0DBB6A0DCBBA5
DDBDA9DDBCA9DEBDADDDC1B3DDC0B2DDBFB2DDC0B1DCC2B2DFC5B6E0C3B6E0C3B5DCC1B3
DBBFABDBC0B1D6BAA6DAB9A5D3B7A6CFB09CD3AD97D1AB95CEA692CCA38EC8A18CCDA08D
C79C87C59881C1927CBE8E7ABC8D77BC8B77C18F7BC18F79C3947FC6917DC69681C89380
C59480C5917DC18F7AC18F7BBE8D78C18C79BD8D79BD8E78BE9077AE7F6BC8B1A8E1E3E3
E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E0E1E1E3E3E1E3E3E1E3E3E1E2E2E1E1E2
E1DFE0E1E3E3E1E3E3E1E1E1E1E3E3E1E3E3E1E3E3E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E0E0E1E3E3E1E3E3E1E1E1E1E3E3E1E2E3E1E3E3
E1E1E1E1E3E3E1E1E1E1E2E2E1E0E0E1E3E3E1E3E3E1E2E2E1E1E1E1E3E3E1E3E3E1E1E1
E1E3E3E1E3E3E1E1E2E1E1E2E1E3E3E1E1E2E1E1E2E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E0E1E0E1E2E0E3E3E1E3E4E2E4E4E2E5E5
E2E5E5E2E4E5E1E3E4E1E3E3E0E2E3DDDFDFDCDDDFDBDDDEDADCDED8C3BADBB59EDCBAA3
DDBBA8DDBBA7DEBCABDDC0B1DCBDAFDCBDAEDDBFAFDDBFAFDFC1B2DFC0B0E0C0B1DBBEAE
D9BCA9DBBDADD6B7A4DBB6A2D3B3A1D1AC99D4A893D0A68FCC9F8CCB9E89C79B86CB9986
C79782C5947EC18F79BE8D78BB8773B98672BE8974BE8B75C08E79C28D78C3917CC6907B
C38F7AC38C77BF8B75C08B76BD8A74BE8974BB8A75BB8A74BC8A70B48A77CDBBB4E0E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E2E1E3E3E1E3E3E1E3E3E1E2E2E1E1E2
E1DFE0E1E3E3E1E3E3E1E1E1E1E3E3E1E3E3E1E3E3E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E0E1E1E3E3E1E3E3E1E1E1E1E3E3E1E2E2E1E3E3
E1E1E1E1E3E4E1E2E2E1E2E2E1DFE0E1E3E3E1E2E2E1E2E3E1E2E2E1E3E3E1E3E3E1E2E2
E1E3E3E1E2E3E1E1E2E1E1E2E1E3E3E1E2E2E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E1E2E0E1E2E0E3E3E1E3E3E1E3E4E1E3E4
E1E3E4E1E3E3E1E3E4E1E3E4E0E2E3DCDEDFDADCDDDCDEDEDEE2E3DBC3B9DDB9A3DEBEA9
DFBFADDFC0ADDFBFB0DFC3B5DEBFB1DEC0B1DFC2B4DFC2B3E0C2B3DFBFAFE0C1B1DBBEAF
D9BEAEDCBDAFD9B9AADDB7A6D5B4A1D5AD9DD7A898D2A692CE9F8ECD9E8CCA9C89CA9887
C99887CB9A87C79684C49785C18D7CBB8C7CBF8D79C08F7DBF8E7BC1907BC1937FC5937E
C2907BC48E7AC08E79C18F7BC18F7BBE8D79BD8E7ABD8E79BC8B73C1A294D6CDC9E0E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E3E1E3E3E1E3E3E1E3E3E1E2E3E1E2E2
E1E0E1E1E3E3E1E3E3E1E1E2E1E3E3E1E3E3E1E3E3E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E1E1E1E3E3E1E3E3E1E1E2E1E3E3E1E1E2E1E3E3
E1E1E1E1E3E3E1E3E3E1E1E2E1DFE0E1E3E4E1E1E2E1E3E3E1E2E3E1E3E3E1E3E3E1E2E3
E1E3E3E1E2E2E1E1E2E1E1E2E1E3E3E1E3E3E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E2E3E0E1E2E0E3E3E1E3E3E1E3E3E1E3E3
E0E2E3E0E2E3E1E4E4E3E5E5E1E4E4DBDCDDD7D8D9DBDCDCE1E6E7DEC4B7DFBEAAE1C3B0
E1C3B5E1C4B3E0C3B5E1C6B9DFC2B4E0C2B3E1C5B8E1C4B6DFC2B3DDBFAEDFC1B1DABEAF
D7BFB3DCBCB0DBBBAFDDB8A9D6B3A2D9AEA1DAA89CD2A695CF9F90CF9F90CC9C8CC99889
CB9A8BD0A091CC9E8FCBA292C89486BD9487C19280C29687BF9080C09582C19785C59983
C29380C6917FC2937FC39582C59684BF937FC09482BE9381BE907ACFBDB4DFDFDFE0E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2
E1E1E1E1E3E3E1E3E4E1E2E2E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E2E2E1E3E3E1E3E3E1E2E2E1E3E3E1E1E1E1E3E3
E1E1E2E1E3E3E1E4E4E1E1E2E1E0E0E1E3E4E1E1E1E1E3E3E1E3E4E1E3E3E1E3E3E1E3E4
E1E3E3E1E1E2E1E2E2E1E2E2E1E3E3E1E3E4E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E4E1E2E2E0E3E3E0E3E3E0E3E3E0E2E3
E0E2E2E0E2E3E2E4E5E3E5E6E2E4E5DCDEDED8D9D9DCDDDDE3E8E8E0C4B6E1C3B0E2C7B6
E2C7BAE3C8B8E1C6B9E2C9BCDFC4B6E1C5B6E1C8BCE2C5B9DFC2B4DCBFAFDFC2B2D9BFB0
D7C0B8DCBDB2DCBDB4DEBAADD7B5A5DCB1A7DCABA2D4A99AD1A295D2A396CF9F90C99A8D
CE9D91D4A59AD2A59AD1AB9DCE9B91C19B91C49787C59C8FC19386C19A88C19B8BC69E89
C29785C79685C49886C59A88C89C8BC09986C39A89C19988C29784DCD5D1E6EDF0E0E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E4E4E1E3E3E1E3E3E1E2E3E1E3E3E1E2E2
E1E1E2E1E3E3E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E1E1E3E3
E1E2E2E1E3E3E1E3E4E1E2E2E1E0E1E1E3E3E1E1E1E1E3E3E1E3E4E1E3E3E1E3E3E1E3E4
E1E3E3E1E1E2E1E2E2E1E2E2E1E3E3E1E3E4E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E4E1E2E2E1E3E3E0E3E3E0E2E3E0E2E3
E0E2E3E0E3E3E0E3E3E0E3E3E1E4E4E2E5E5E2E5E5E2E4E5E2E5E5DFC2B1E1C4B1E2C7B5
E1C6B8E1C6B5E1C5B8E1C7BADFC3B4E0C4B5E1C7BBE2C5B8DFC2B5DDC1B1DFC4B4DBC1B4
D9C2B9DDBFB4DDBFB6DFBDB1D9BAABDEB7AEDDB1A8D6AEA0D5A89BD6A99BD2A595CDA093
D2A196D6A89CD4A79BD4AB9ED19E94C59C92C79889C79C8FC39487C19987C29B8BC79E8B
C39988C79786C59A87C69A89C89B8AC29A87C29988C39A89C79E8FE0DEDDE7EFF2E0E3E3
E0E3E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E4E1E3E3E1E3E3E1E2E2E1E3E3E1E2E2
E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E2E1E3E3
E1E2E3E1E2E3E1E2E3E1E2E3E1E2E2E1E2E3E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E2E2E1E2E3E1E2E3E1E3E3E1E3E3E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E3E1E3E3E0E3E3E0E3E3E0E2E3
E1E3E4E1E3E4DEE0E1DDDFDFE0E2E2EAEDEDEEF3F3E9EDEDE0DFDEDEBFACE1C3AFE1C4B1
E0C3B2DFC2B0DFC3B4E0C4B5DEC1B0DFC2B3E1C5B9E1C3B6DFC3B5DEC3B4DFC5B6DDC5B7
DCC4BADEC2B6DFC2B7DFC2B5DCC1B2DFBFB5DEB8AED9B5A7D9AFA2DAB1A0D4AC9AD1A799
D6A59AD7A89BD5A699D5A79AD2A093CA9A8FCA988AC9988BC59386C29585C49989C79C89
C39B8AC69886C59987C69987C69785C39985C09683C49987CCA79BE0E0E0E4EAECE1E3E3
E0E3E3E0E3E3E1E3E3E0E3E3E0E3E3E1E3E3E1E2E3E1E3E3E1E3E3E1E1E2E1E3E3E1E2E2
E1E2E3E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E3E1E3E3
E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3
E1E3E3E1E2E3E1E1E2E1E3E3E1E3E3E1E2E2E1E2E2E1E3E3E1E3E3E1E3E4E1E3E3E1E3E3
E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E3E3
E2E4E5E2E5E5DCDEDED8D9DADDDFDEF1F4F4FAFFFFF0F4F6DED9D8DCBDA8E0C3AFE0C3AE
DFC1AEDDBEACDFC2B1DEC1B1DEC0AEDFC1B3E0C3B7E0C3B5E0C4B7DFC6B9E0C8BAE0CABC
E0C7BBE0C7BAE0C6BAE0C7BADFC8BAE1C8BDE0C1B5DCBDAEDEB8A9DFBAA7D8B4A1D7AFA1
DAAA9FD8AA9BD7A798D6A597D5A495CF998DCE988CCB9688C99486C49283C79887C89A89
C39D8DC59A87C69A87C69886C49381C49884BE9380C69986D2B1A9E0E2E2E1E5E6E1E3E4
E0E3E3E0E3E3E1E3E3E0E3E3E0E3E3E1E3E3E1E1E2E1E3E3E1E3E3E1E1E1E1E3E3E1E2E2
E1E3E3E1E3E3E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3
E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E4E1E2E2E1E0E1E1E3E4E1E4E4E1E1E2E1E2E3E1E3E3E1E3E3E1E3E4E1E3E3E1E3E3
E1E3E3E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E3E3
E2E5E5E2E5E6DCDEDED7D9D9DCDEDDF1F4F3FAFFFFECEFF1DDD3CFDCBDA7E0C3AEDFC1AC
DEC0ABDBBDAADEC1AFDEBFAFDEC0ADDFC1B3E0C2B6E0C3B4E0C6B9E1C9BCE0CABDE2CDC0
E3C9BCE2C9BCE2C9BBE1CCBEE2CEC1E2CFC2E1C8BADFC4B5E2C0B0E2C2ACDBBBA6DBB6A8
DDAFA3D9AC9CD8A898D8A395D7A796D39A8DD1998DCD9586CC9586C69183C99886C89888
C49E8EC49B87C69A87C69786C3927FC69885BE927FC79A86D8BCB8E0E2E3DFE0DFE1E3E4
E0E3E3E0E3E3E1E3E3E0E3E3E0E3E3E1E3E3E1E0E1E1E3E3E1E2E3E1E1E1E1E3E3E1E2E2
E1E3E3E1E3E3E1E0E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E2E1E3E3
E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E4E1E3E3
E1E3E4E1E1E1E1E1E1E1E3E4E1E3E4E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E3E3E0E3E3E1E3E3E1E3E3E1E3E3
E0E3E3E1E3E3E1E4E4E1E3E3E0E3E3E1E3E4DEE0E0CFCECFDBCAC3DDBEA8E0C3B0DFC1AD
DEC1ADDCBFAEDFC1B0DEC0B1DFC1AFDFC2B5E0C2B6E0C3B5E1C7BAE1CABDE1C9BCE2CBBF
E3C8BAE2C8BBE2CABCE1CCBFE2CDC1E1CFC1E0C9B9E0C6B7E2C3B3E2C4AFDDBEA9DDBAAA
DEB1A4DAAE9CD9A998D8A496D9A898D49C8ED29B8ECF9787CE9887C99385C99886C89887
C49B8BC49B88C49987C59887C49582C69A87C09582C89C88DCCBC9E1E4E5DEDEDEE0E3E3
E1E3E3E1E3E3E0E3E3E1E3E3E1E3E3E0E3E3E1E1E1E1E3E3E1E2E2E1E1E2E1E3E3E1E2E2
E1E3E3E1E3E3E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E2E1E3E3
E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E4E1E3E3
E1E3E3E1E0E0E1E1E2E1E3E3E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E2E3E1E3E3E1E3E3
E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E1E3E3E1E3E4E1E3E3
DEE0E0DEE0E0E8EBECEDF0F0E5E8EAC9CBCDB7B4B5AAA2A2DAC2B7DEC0ACDFC4B2DFC2B0
DFC2B2DEC3B3E0C2B3DFC2B4E0C4B4E0C4B7E1C3B6E1C4B6E1C8BBE1C9BDE1C7BAE2C8BC
E2C6B8E1C5B7E1C9BCE1CABEE2CABEE1CCBCE0C5B6E0C5B6E1C4B3E0C3AEDEBFAADEBAA9
DEB1A2DAAF9DD9AA99D9A697DAA99AD49F90D29D8DD09989CF9A88CC9888C99987C89786
C39886C49A88C29885C49988C59A87C69B8AC49987C89E8CE0DADAE2E6E7DFDFDFE0E2E2
E1E3E3E1E3E3E0E3E3E1E3E3E1E3E3E0E3E3E0E1E2E0E3E3E1E1E2E1E2E2E1E3E3E1E2E2
E1E3E3E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3
E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1DFDFE1E2E2E1E2E2E1E2E3E1E2E2E1E3E4E1E2E3E1E3E3E1E2E2E1E3E3E1E3E3
E1E3E3E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E2E3E1E3E4E2E4E4E2E4E4
DBDCDDDADBDBEEF1F1F8FCFCEAEDF0B2B2B591898A857676D8B9AADFC2B0DFC3B3DFC2B3
E0C4B6E0C7B9E1C3B5E0C4B8E1C6B8E0C5B9E1C4B7E1C5B8E1C9BCE1C9BCE1C4B8E1C4B8
E1C3B5E0C1B3E0C7BAE0C7BCE1C5B8DFC6B4DFC0B0DFC2B3DFC2B1DDBFACDEBEA9DEB9A6
DDAF9EDAAF9CD8AA99D9A797DAA89BD3A091D19F8CD19C8ACF9C89CF9B8BC89987C89685
C39481C49987C09684C39A88C79F8CC59D8CC89D8CC7A08EE2E6E8E1E5E6DFDFDFE0E1E1
E1E3E4E1E3E4E0E3E3E1E3E3E1E3E3E0E3E3E0E2E2E0E3E3E1E1E1E1E3E3E1E3E3E1E2E2
E1E3E3E1E3E3E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3
E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1DEDFE1E3E3E1E1E2E1E2E2E1E2E2E1E3E4E1E2E3E1E3E3E1E1E2E1E3E3E1E3E3
E1E3E3E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E2E3E1E3E4E2E4E5E2E4E5
DADCDCD9DADAEDF1F1F8FCFBE4E7E99F9C9F786A6A715C5AD8B5A3E0C4B4DEC3B4DFC2B5
E0C5B9E1CABDE1C4B7E1C6BBE1C7BBE1C7BBE1C4B7E2C5B9E1C9BCE1C8BBE1C3B6E0C2B6
E0C2B4DFC0B2E0C6BAE0C5BAE0C1B4DFC2AFDEBBABDEBEAFDDBFADDABBA9DDBBA6DDB6A2
DCAD9BD9AE9BD7AA98D8A897D9A79AD1A292CFA08BD19E8BCF9D89D09E8DC79987C79683
C3907DC39886BE9582C29A87C7A18EC59D8DCB9F8FC6A190E2EBEEE1E3E4E0E0E0E0E1E1
E1E3E4E1E3E4E1E3E3E1E3E3E1E3E3E0E3E3E0E2E3E0E3E3E1E1E1E1E3E4E1E3E3E1E2E2
E1E3E3E1E3E3E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3
E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1DFE0E1E3E3E1E1E2E1E1E2E1E2E2E1E3E3E1E1E2E1E3E3E1E1E1E1E3E3E1E3E3
E1E3E3E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E3E3E0E3E3E1E3E3E0E3E3E1E3E3E1E3E4
E1E4E4E0E3E3E1E4E4DEDFE0C9C6C8988E8E7F6B69826964DAB7A5E1C4B5DFC3B5E0C3B7
E1C5BAE1CABEE1C4B8E1C6BBE1C7BBE1C7BBE0C3B7E0C3B7E0C6BAE0C7BAE1C4B7E0C5B8
E0C6B7E0C3B5E0C8BCE1C7BAE0C2B4E0C3B0DEBBACDCBBABDCBBAADAB8A7DBB7A3DBB39F
DBAE9CD7AE9BD6AD99D5A996D6A798CFA290CE9F89D09E8ACF9C88CE9E8CC89986C89583
C4907DC29783BF9481C29885C69F8BC59C8BCB9F8FC6A191E0E6E7E0E2E2E1E4E5E1E3E4
E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E1E3E3E1E3E3E1E3E3E1E1E2E1E3E4E1E3E3E1E2E2
E1E3E3E1E3E3E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3
E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E0E1E1E3E3E1E1E2E1E1E1E1E2E2E1E2E2E1E1E1E1E3E3E1E1E1E1E3E3E1E3E3
E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E0E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E3E3E1E3E3E1E3E4E0E2E3DFE1E1DFE2E2
EAEEEEE9EDEECFD0D1B9B7B8A59C9D988682967E78A68C81DDBCABE1C3B5E0C3B5E0C3B7
E1C5B9E1C8BDE1C4B8E1C6B9E1C7B9E1C7BAE0C2B7DFC1B3DFC3B7E0C6B9E0C6B9E0CABD
E0CBBCE2C8BAE1CBBEE2C9BAE0C4B5E2C5B3DEBBAEDBB6A6DBB7A5D9B5A4D8B19ED8AF9C
D9AE9DD6AE9BD5AE9AD2AA95D2A794CDA18ECB9D88CE9D89CE9A87CC9B8ACA9985C89583
C5927FC19681C19581C29681C49A86C69A88CA9E8DC7A191DCDAD8DFE0E0E3E8EAE1E5E7
E0E2E2E0E2E2E1E3E3E0E2E3E0E2E3E1E3E3E1E3E3E1E3E3E0E2E2E1E3E3E1E3E3E1E2E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3
E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E2E2E1E3E3E1E1E2E1E0E1E1E1E2E1E1E1E1E0E1E1E3E3E1E0E1E1E3E3E1E3E3
E1E3E3E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E0E3E3E1E3E3E1E3E3E0E3E3E0E2E3E0E3E3E1E3E4E2E4E5DFE1E2DDDEDFDBDDDD
F2F5F5F2F7F8BEBCBD958F918373729A8178B1948ACDB1A2E0C3B3E1C3B5E0C3B5E0C4B8
E1C4B8E0C7BBE0C3B8E0C4B6E0C5B7E0C6B8DFC1B6DDBDAFDDBFB3E0C5B8DEC6BAE0CDC0
E1CFC1E3CCBEE2CDC0E3CABAE0C6B5E4C7B7DFBBAFD8B2A1D9B1A0D9B1A1D5AB99D5AB98
D6AE9DD3AD9AD3AE9ACEA992CCA58FCA9E8AC99A86CB9B86CE9785C99A88CB9985C99582
C79481BF957EC49581C2937EC29580C69885C89C8AC7A190D7CBC7DEDEDDE4ECEFE1E7E8
DFE1E0DFE1E1E1E3E3E0E2E3E0E2E3E1E3E4E1E3E4E1E3E3E0E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E2E2E1E0E1E1E1E2E1E0E1E1E0E0E1E3E3E1E0E1E1E3E3E1E3E3
E1E3E3E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E0E3E3E1E3E3E1E3E3E0E3E3E0E2E3E1E3E3E1E3E4E2E5E5DFE1E2DCDEDFDADCDC
F1F5F4F1F5F6ADA8A97E7375725C58A38477CAA99CECCFBDE2C8B9E0C3B5E1C3B6E1C5B8
E1C4B7E0C5B9E0C3B7E0C3B3DFC4B4E0C5B6DFC0B6DDBCAEDDBEB1DFC4B7DDC7BBE0CEC1
E1D0C2E2CDC0E2CBBFE3C7B7DFC2B1E4C2B4DDB5AAD6A898D7A898D7A798D2A192D2A291
D3A798D1A795D2AA96CCA58EC9A28AC99B87C79884C99A85CC9584C69786CB9884C99582
C89683BF947CC69681C2927CC1917CC79682C79A88C7A08FD2BCB4DCD6D4E3EAECE1E6E7
DFE0E0DFE1E1E1E3E3E0E2E3E0E2E3E1E3E4E1E3E4E1E3E3E0E3E4E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E2E2E1E1E1E1E1E1E1E0E0E1E0E1E1E3E3E1E1E1E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E3E3E1E3E4E1E4E4E1E3E4
E0E2E3D9D9DAA29896877875866C66B49385D6B6A8F2D5C2E3C8B9E1C3B6E1C3B6E1C5B8
E1C4B7E0C5B8E0C3B7E1C3B2E0C4B3E1C5B4E1C4B7E1C4B5E1C2B6E0C4B7E0C7BBE1C9BD
E1C8BCE0C9BEE1C1B6E1BCAEDBB1A2E0ADA1D89E95D39587D39588D29285D19387CF9183
D19588D09788D29C8CCF9B88CB9C87CD9886C79886C89A86C99582C29482C89581C89583
C89683C0947DC79581C4927DC1907BC79482C69785C59C8BCDAEA3D6C6C0DFDCDBE1E3E4
E1E3E4E1E3E4E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E3E3E1E3E4E1E3E3E1E3E3E1E2E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E2E2E1E3E3E1E3E3E1E1E2E1E1E1E1E0E1E1E1E1E1E3E3E1E2E2E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E0E3E3E1E3E3E1E4E4E1E3E3DFE2E2DEE0E1E3E6E5E7EAEAE9ECED
C7C7C8B9B3B39C8B86A18D84AC9186C8A99ADCBEAFEBCDBCE2C6B4E1C5B8E1C3B6E1C5B8
E0C4B8E1C6B7E1C4B6E2C3B1E0C4B1E2C4B1E3C8B7E7CDBFE5C9BCE2C4B8E4C7BAE1C1B6
E0BCB2DCC2B9DFB4AADDADA2D79B90D9938AD2837BD07F75CF8177CB7A6FD1837BCD7F74
CF7D74D08479D38B7ED48F81CF9484D29585C79989C79B87C69681BF927DC3917EC79583
C89582C3947FC79481C5937FC2917CC79482C69583C29987C8A394CFB2A7D9C9C3E0DDDD
E2E6E8E3E6E7E1E3E3E1E4E4E1E4E4E0E2E2E0E2E2E0E2E3E1E3E4E1E3E3E1E3E3E1E2E2
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E1E2E1E3E3E1E3E3E1E2E2E1E1E1E1E1E1E1E1E2E1E3E4E1E2E3E1E3E3E1E3E3
E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E0E3E3E0E3E3E1E3E3E3E5E5E1E3E4DEE0E1DBDDDEE2E5E4EAEDEDF0F3F4
AFABAE9A8D8C988178BDA596D4B8AADDC0B1E1C6B7E2C4B4E1C3B0E1C6B9E1C4B7E0C4B8
E0C3B7E0C5B5E1C3B4E2C3AFE0C2ADE1C1ACE4CAB6EBD4C6E9CFC2E3C4B9E7C6B9E2B9AF
E0B0A8D9BAB4DDA89EDA9F97D2867ED37A74CC6A62CE6A64CA6D67C5635BD17570CC6E67
CD6760D0726AD47B72D9837AD28C81D79184C6998AC59A88C1957FBB8D78BE8C7AC69583
C79582C69582C79481C89582C3937EC79483C69281C09582C49886C99F8ED3B5AADFD6D5
E4E8EAE5E8E9E0E2E2E1E4E4E2E4E4DFE0E1DFE0E2E0E2E3E1E3E3E1E3E3E1E3E3E1E1E2
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E0E1E1E3E3E1E3E4E1E2E3E1E1E1E1E1E2E1E2E2E1E3E4E1E3E3E1E3E3E1E3E3
E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E0E3E3E0E3E3E1E3E3E3E5E5E1E4E4DEE1E2DBDDDEE1E4E3E7EAEAE8E9EB
9A92948875729B8074D6BAA7F4D8C7EDD2C2E4CABBDABCACE0C2AEE0C6BAE0C4B7E0C4B8
E0C3B6E0C4B2E1C1AFE1BEAADFBDA8E0BDA7E3C8B2EBD4C6E9CFC2E2C1B6E6C1B4E2B1A7
DEA59FD5B1ACDB9E96D7958FCF7A76CF6E6AC85E57CD635FC8645FC15851D1706DCA6560
C95954CE6660D16D67D87771D1837BD5887EC49386C39585BF937DBA8C75BC8A78C59582
C79481C89583C89482CA9886C59580C79584C6907FBF927FC1917DC4907CCEA495DCCDC9
E3E5E6E4E6E8DFE1E2E1E4E4E2E4E4DFE0E1DEE0E1E0E2E3E1E3E3E1E3E3E1E3E3E1E1E1
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E1E1E1E3E3E1E3E3E1E2E3E1E1E1E1E2E2E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E1E4E4E2E4E4E1E4E4E1E3E4DBDADDC0BCBE
8D8081957E78AC8F80DFC2AEF8DCCAF0D4C3E4C8B7DAB9A9E0C2AFE0C6BAE0C3B7E0C5B8
E1C2B4E1C2AFDEBBA8DBB39EDBB59FDEB9A4E0BFABE0C2B5E0C2B5DFB8AEDCB3A7DEA9A0
DCA09AD0A39FD79D96D5938ECE8381CE7E7BC86F69CF7674CB6F68BF635ECE7B77C76C68
C35F59C5645FC4655FC96964C5756FC5746CBF8377C08A7BC18F7AC0917ABF8F79C4957F
C7927FC89584C89684CC9B88C79782C89784C7907EC09280C18F7BC48D78CB9D8CD7BFB7
DED7D4DEDEE1DFE0E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E2
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E2E2E1E3E3E1E2E3E1E2E3E1E0E1E1E2E3E1E1E2E1E2E2E1E2E3E1E3E3E1E3E3
E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E0E3E3E1E3E3E1E3E3E0E2E3DDDFE0E1E3E4E5E8E7E9ECECDFE0E3C8C4C88C8283
887573B2998EC4A696E0C3AFEED1C0EBCEBBE1C2B0DDBAA8E0C4B3E0C6B9E0C3B7E1C6B8
E2C1B0E1BFACDBB29ED4A58FD7AA95DCB3A0DCB1A2D1A89DD3B0A3DAADA3CFA498DAA39A
D99F99CC9591D3A09BD39891CF9795D19C9ACB8F89D29793CF857AC07B75CC8E87C57C78
BB6E66BB6A63B4625AB45C57B56861AF5D56B76E63BD7C6EC58977C89882C4957BC4957A
C78F7DC89583C99886CE9E8BC99984CA9985C7917FC39481C2927EC6917DC99C89D0B0A3
D7C4BBD6D3D6DEDFE3E0E0E2DFE0E1E3E6E6E3E7E6E2E4E4E0E3E3E0E3E3E1E3E3E1E2E2
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E2E2E1E2E2E1E0E1E1E3E3E1E1E1E1E1E1E1E2E2E1E3E3E1E3E3
E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E4
E1E3E3E0E3E3E1E3E3E1E3E3DFE1E3D9DADBDEE0E0E7E9E7EEF2F1DAD9DFB6ADB35A494A
866D68D1B6A7DCBEADE0C3B1E3C6B6E4C6B2DDB9A6DEB8A5E0C5B7E0C5B8E0C3B6E1C6B8
E2C0ACE1BBA7D7A994CD9780D2A18CDAAF9DD8A49AC28E85C69E91D5A398C1948AD69E95
D69F98C98984CFA4A0D29D96D0ADAAD4BBBACFB0AAD5B8B4D49C8DC1958FC9A299C38E88
B48074B27169A56157A0524BA65C549A4741B05950BB6F61C88374D09D88C8997CC29375
C68C7AC89482C99B89D0A28ECB9B87CC9C86C8927FC69684C59683C89784C89B88C9A08F
CFB0A2CEC7CADEDCE2DEDDE0DCDDDEE5E9E8E6EAE8E2E5E3E0E2E3E0E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E4E1E3E3E1E1E2E1E2E2E1E0E1E1E3E3E1E0E1E1E0E1E1E2E2E1E3E3E1E3E3
E1E0E1E1E3E3E1E2E3E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E4
E1E3E3E0E2E3E1E3E3E1E3E3DFE1E2D7D9DADDDEDFE5E7E6EDF0F0CBC8D09F92993C2525
8D6F67EACDBBEFD1BFE0C3B1D8BCACDDBDA9D9B29EDFB7A2E0C6B9E1C4B7E0C3B6E1C6B7
E2BCA6DEB4A0D2A08AC78C75CC9481D3A494CE928BB5776FBD8E83D29B90B98B81D39D94
D4A199C8857FCEABA7D2A39AD2BEBBD7D4D3D3C9C4D8D0CAD7AD9BC5ABA4C9B3A8C39E97
B18F82AD7B729D685C9451489A554D8B3C36A74B42B56457C67A6ED09986C8987AC19170
C68A78C79381CA9D8BD2A691CE9F8ACD9F88C99581C89886C79988CA9C8AC89B88C49580
C9A08DC7BBBDDBD7DEDAD7DCD9D9DBE5E8E7E6EAE8E2E5E3E0E2E3E0E3E3E1E3E3E1E3E4
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E1E2E1E2E2E1E1E1E1E3E4E1E1E1E1E1E1E1E1E2E1E3E3E1E3E3
E1E0E1E1E3E3E1E2E2E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E0E1E2E0E3E3E0E2E2E1E2E3DFE1E3E0E2E3E1E2E3E0E2E3ABA6AD8271784E3332
A18277EFD2BEF1D4C2E1C4B1D8BBA9DBB9A4D9B19DDEB5A0E1C6BAE1C4B8E1C4B8E1C5B5
DFB39ED8A894CC9780C48670C38372C48B7DB9746FAF6860BC887DD1998DBE9084D4A49C
D4A39ACC918AD0B2AFD3A69CD6C3BFDAD9D8D5CBC5D8CCC5D6AB9ACAB1ABCCB9AEC7A7A0
B7968AB2877CA57B709B6358995A4F8B49429B4941A85F54B66C61C18272C08B70BF8E6F
C68C7AC89582CDA18DD4A893D0A48FCFA28BCB9984C89886C79A88CA9C8AC79885C3937D
C79985C5B2AFD4CED2D3CED5D8D5D9E0E1E1E0E2E3E1E3E3E0E3E3E0E3E3E1E3E3E1E3E4
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E2E2E1E3E3E1E1E2E1E2E2E1E2E2E1E3E3E1E1E1E1E2E2E1E1E2E1E3E3E1E3E3
E1E0E1E1E3E3E1E1E2E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2
E1E3E3DFE0E1E0E3E3E0E1E1E3E4E3E9EBEEE4E6E6D8DADDCCCCCF837C82655156775C58
BC9D8EE8CCB8EBCEBDE3C5B1DCBEABDCB6A2DBB39FDCB39EE1C5B9E1C5B9E1C6B9E0C3B3
DAA895D09B87C79077C2846FB97263B26F62A2554FAF6258C0877CD29B8EC89C8FD7B0A7
D6A69CD3A59DD5BAB5D4A89CD9C1BBDDD2D2D6C1B9D7BBB1D39F90D0AFA9D2B8AFCEACA4
C1988DBC9286B5948AAD7D719E65589361598F4F479A5F55A15E52AA6357B57762BD8A6F
C68F7DC89683CFA48FD6A996D3A995D0A58FCD9D88C89886C69886C89A88C69482C49580
C79884C6ABA1CDC3C3CAC4CDD5D0D7D9D7D9D8D7DCDEE0E3E1E3E4E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E4E1E1E2E1E3E3E1E1E2E1E2E2E1E3E3E1E3E3E1E1E2E1E2E3E1E2E2E1E3E4E1E3E3
E1E0E1E1E3E3E1E1E1E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E1
E1E3E3DFDFE0E0E3E4DFDFE0E4E5E2F3F4F8E7E9EAD0D1D6B9B6BB5D54584C3638A68983
D8BBA9E1C6B2E2C7B6E3C4AFDFC0ABDCB3A0DDB5A1DBB19EE1C5B9E1C5B9E1C7BAE0C0B0
D69E8DC88E79C1896FC28370AF6356A154498C3933B05E52C6897ED49E90D4AA9BDBBCB3
D8AA9EDBBBB2DAC2BCD6AB9DDDBEB6DFCACAD7B4ABD5A79CCF9286D7ACA6D7B5AED4B0A6
CC9A90C79D91C6ADA4BF988AA472629E7B728457508D60578D504494443CA96454BA8570
C59180C99784D2A790D8AA97D6AE9BD2A793CFA18CC89785C69784C69886C69180C69885
C79885C7A494C5B7B4C1B9C4D1C9D2D0CBCFD0CCD6DCDDE3E2E4E5E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E4E1E1E1E1E3E3E1E2E2E1E2E2E1E3E4E1E3E3E1E2E2E1E3E4E1E2E2E1E3E3E1E3E3
E1E1E1E1E3E3E1E1E1E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E0E1
E1E3E3DEDFE0E0E3E4DFDEE0E4E4E1F1F1F6DEDEDEC0BEC5A29BA13F3335452C2CCDB0A7
EED2BDDBBFACDBBFAFE2C2ADE0C0AADCB19FDEB7A4DAB19EE1C4B7E1C5B9E1C8BAE0BEAD
D29687C1836FBE846AC38675AD61559A4B4183312AB56557CD8E84D6A395DEB6A5DEC5BB
DAAEA2E1CCC2DEC7C0D8AE9FE0B9B0E1C0C0D8A99ED3978ACD897FDBA8A2DBAFA9D8B0A5
D49990CFA396D3BDB4CDAB9AAC7C6BAA918581615988645C81483C812C279D5248B67E6D
C28F7EC89784D3A78FD9AB99D8B29ED3A996D1A58EC89785C59683C49784C68F7FC89B8A
C89886C89F8AC0AEA6B9AFBBC9BFC8C9C1C6CAC4D0DADAE1E1E4E4E1E3E4E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E0E1E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E1E1E1E3E3E1E2E2E1E2E2E1E3E4E1E3E3E1E2E3E1E3E4E1E2E2E1E2E2E1E3E3
E1E1E2E1E3E3E1E1E2E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E1
E1E3E3DFE0E0E1E3E3E0E1E2DEDEE0D8D6DCB8B4B3A0999F86787C342324634744DCBDB2
F2D6C0DBBEABDBBEACDFBFAAE0BDA8DCB1A0DEB7A4D9B19EE0C3B4E1C2B6E1C4B6DEBBAA
D09384BF7F6ABF846BC88E7FB8796DA8665B965048C07B6DD3998FD8AB9DE0B9A9DFC6BB
DBB3A7E2CEC3DFC7BEDAB0A2E1B6ACE1B9B6D7A599D39687CE8B80DBA59DDAA69ED7A89B
D6958CD09D90D5B7ADCEA695B37F6FB496888F685F90696084493E77252293463DAD7263
BA8172C69380D2A48CD9AD9BD9B29FD6AB99D2A68FC89885C69683C39782C48F7EC89988
C89785C89C86C0A89CB5A9B2BDB0B7C8BDC2CAC4CFD5D3DBDFE1E1E0E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E2E2E1E1E2E1E3E3E1E2E3E1E2E3E1E3E4E1E3E3E1E3E3E1E3E3E1E2E3E1E0E1E1E3E3
E1E2E2E1E3E3E1E2E2E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E2
E1E3E3E0E1E1E1E3E3E2E5E5D7D6DDB5B0B78A7F7D7D6F736C565737202092746DDCBBB0
EBD0BADFBEACDEBEACDCBCA7DFB9A6DCB3A1DDB7A3D8B19EE0C2B0E0BFB3E0C0B0DDB8A7
CF9583BF7F6AC2866FCE998ACA9C8EC19186B78379CE988AD8A69CDAB3A6DFB8A9DEC2B6
DCB9ACE0C8BCDEC3B9DBB2A5E0B3A9E1B4ACD6A597D49D8CD19386D9A398D69D91D29D8F
D38F85CD9286D0A699C89584BA7E6FBE9383A46F64A070659151467328288C3E37A46557
B16F62C38E7BCF9F88D9AE9DDAB19ED8AD9BD2A68FC89886C79684C39781C2907DC79583
C89583C89A85C4A495B2A4A9AE9EA2C7BBBFCEC7D0D1CCD4DDDCDDE0E2E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E1E2E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E3E1DFE0E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E3
E1E3E4E0E2E2E1E3E2E4E9E7D0CFDB938C925D4B485C4648563635402321C5A49ADBBAAD
E3C7B1E1BDADE0BFAADAB9A4DEB6A5DCB6A4DCB7A4D7B39FDFC1ADE0BDB0DFBCABDBB6A4
CF9884C1806BC68A74D5A596DCC0B1DCBEB1D9B8ACDCB7A9DEB5AADDBCAFDDB7AADEBDB1
DCBDB1DEC1B5DDBFB3DCB3A9DFAFA5E0ADA2D5A395D5A392D39A8CD6A091D39284CD9181
D0887EC9857ACB9383C18272C27C70C78F7DBB766AB2776AA05B51722F2F8639329C594C
A75E53C08977CC9983D8AF9ED9AF9CDAAE9CD1A68FC89986C79784C29680C0907CC7917F
C99482C89986C8A290B0A0A09E8B8BC5B7BBD0CACFCDC5CDDAD7D8E0E1E2E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E1E1E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1DEDFE1E3E3
E1E3E4E1E3E3E1E3E4E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E4
E1E3E4E1E3E4E1E2E2E4E9E7CAC7D57E727847302A503432512B2654332FECCBBED9B8A9
DBBFAAE2BCADE2BFAAD9B8A4DEB4A5DDB9A8DCB8A5D7B5A2DEC1ABE0BBAEDEB9A8DAB5A3
D09C87C38570C98E7AD9AB9DE8D8C7EFDFD0F4E0D2E7D0C2E3C1B7DFC4B7DCB8ABDEBAAD
DDC1B4DDBBAFDCBCAEDDB6ACDFADA2DEA99AD4A394D5A795D5A090D39D8DCF8B7AC98877
CD8478C67C71C58371BB7464C67B70CC8A76CC7C6EC07E6EAD665B783D3B863B34985446
A2554ABE8673C9947FD7AE9CD8AC99DBAE9BD1A48DC89986C79684C1957EBF917BC68E7C
C99381C79988CB9F8BAF9D9A8A7573BFB1B4D2CDD0CCC4CBD9D6D7E0E1E2E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1DFE0E1E3E3
E1E3E4E1E3E3E1E3E4E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E4
E0E3E3E1E4E5E0E3E3E0E2E3C9C0C9867576634A416E504970484077554CF1D3C5DBBAAA
D9BCA8E2BCADE2BFAAD9B9A6DEB8A9DEBDADDDBAA9D9B9A7DFC2ACE1BDAEDFBAA9DAB5A3
D29F8CC88D79CB917DD7A697E5D0BDEFDECEF6E5D5EAD6C9E4C8BDE0C8BCDDBCB0DEBBAE
DEC2B6DDBCAEDDBEAFDFB9AFDEB0A2DCA897D4A392D4A592D5A190D29E8CCE8D7AC98A77
CA8778C57E71C1816DBA7565C57E71CA8974CD8171C38271B4726489514A924C429F5D4D
A55B4EBD8472C8917DD4AA96D7AA97D9AB98D0A28CC89684C69481C1937DBF907AC58F7B
C89381C79988CA9C88AE9C996E5D5CB2A4A7D6D1D3D6D0D5DEDCDDE1E3E4E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E4E1E1E1E1E3E3
E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E3E4
E0E2E2E1E4E5E0E3E5DAD7DCCABABC9E8781997F73A182759F796DA07F71E4CBBDDEBFAC
DBBCA9E1BCADE1C0ABDCBCAADFBDAEDFC1B1DFBDADDCBEADDFC4B0E1C0B1DFBEADDBB6A5
D5A392CE9683CB937FD29C8ADBB7A3E5CBB9ECD6C5E7D3C6E3CBBFE0C9BDDFC3B6DFBFB3
DFC2B6DFBFB0DEC2B3E0BEB2DFB4A4DBAA98D5A392D2A18DD4A08FD2A08DCE937ECA917D
C98E7AC58675BE8771BB7F6DC18272C58973C58473C08572B77C6A9E695AA46355AA6D5A
AC6B58BD8572C7907CD0A48DD5A895D5A793CEA08AC79381C3907FC1907CBF8F79C4927B
C69481C79987C69985AE9C9A524446A09396D8D3D6E2E1E3E4E5E6E2E5E6E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E2E2E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E4E1E2E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E3E3E1E3E3E1E3E3E0E3E3E0E3E4E0E3E4
E0E0E0E1E4E4DFE2E6D4CCD3CBB4AEB99C8FD1B6A7D7B8A5D1AD9ECAAB98D4C0B3DEC1AC
DCBBA9E1BDADE1C1ACDEC0AFE0C2B4E0C4B6E0C0B2DFC2B4E0C6B4E1C4B4E0C2B1DCB8A7
D8A899D4A18FCC9682CC907DD09D88DAB6A2E0C4B2E4CCC1E1CDC0E0CABDE0C8BBE0C3B6
E0C1B6E0C2B2DFC7B7E0C2B4DFB9A7D9AD9BD5A592D09D88D29E8DD1A38FCE9A84CB9984
C7947DC48F7ABA8C75BC8876BC8572BE8771BD8673BC8773BA8671B6826CB77C6AB77F69
B57C65BE8673C6907CCD9E85D2A693D2A38ECD9D89C7907EC18D7CC18E7CC08F78C2947B
C59481C69987C39784AF9C9B392F348F8386D9D4D7EDF0EFE9EEEEE4E7E7E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E4E1E4E4E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E3E3E1E3E3E1E3E3E0E3E3E1E3E4E0E3E4
E0E0E0E1E3E4DEE1E3D0C4CBCFB3A5D1B09EFCE0CEFFDEC8F6D4C2EBCCB6C7B5A9DEC2AC
DDBAA9E0BEAEE0C2AEE0C3B3E1C7B9E1C8B9E1C4B7E2C7BAE0C8B9E1C7B7E0C5B6DEBAAA
DBADA0D9AA99CE9A86C98A75C78873CFA28DD5B19EDFC4B8E0CCBEE0CABDE1CCBFE1C6B9
E1C0B5E1C4B3E0CABAE1C5B6DFBFAAD8B29FD6A794D09B86D19D8CD1A591CDA089CB9E89
C5997FC3957EB89079BD8E7CB78772B7856FB58772B98872BC8D76C79579C68F7BC28E76
BD8B71C08A77C7917DCA9A7FD0A390CF9F8ACB9A87C78D7CBF8B7BC18C7BC18E77C1957C
C39480C69986C09584AE9A992720267D7174D1CBCFF0F6F3EAF0F0E3E7E7E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E4E4E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E1E3E3
E0E3E3E0E3E3DFDDDBD3C4C6D5BAA9DCBEABFEDECBFFDBC4F8D3C0F2D2BCC8B3A7DEC3AD
DEB9A9E0C0AEE0C3B1E1C5B6E1C9BBE1CABCE1C6BAE2CABFE0CABCE0C9B9E1C8B9DFBEAE
DCB1A4DAB19ED29F8DCB8F7AC78771CC9A84D1A693DCBFB1DFC9BCE0C9BCE2CDC0E1C6B9
E1C0B5E1C4B4E0CAB9E1C9B9DFC3AFDAB7A5D7AB97D29E8AD19F8DD0A491CC9F89CA9E89
C3987FC2947DB88E78BC8D7BB68671B5846EB48671B98970BD8D76CB977BC9937EC5937A
C29178C4907DC99581CB9B81CEA08DCD9C87CA9886C78E7CC08C7BC08C7BC08D78C0957D
C2947FC49885C09684A9938F221A21675B60B8B2B6E4E8E8E2E5E5E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E4E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3
E1E7E7E0E2E2E0D7CFDAC8C3DCC5B2E0C6B5EBC6B2ECC3ACE7BFAAEBC9B5D0B5A9DFC3AE
DFB9A9E0C1AEE0C3B4E1C6B9E1CABCE1CBBDE1C9BDE1CDC2E0CBBEE0CABBE0C9BBDFC1B2
DDB6A8DAB5A1D7A695D09A85CB907ACD9883D2A08DDABAABE0C5B9E1C8BBE1CBBEE1C5B7
E1C1B5E1C4B4E0C8B8E1CBBCE0C5B4DEBDAAD7AE9BD4A391D1A28FCEA390CB9B87C89A85
C1947EC1907BB98974BA8776B6846FB5836EB68570BB886DBE8875C69178C58F7AC4937A
C5937CC89884CC9A86CD9F87CD9C8ACD9985C99784C6907EC18F7DC08E7BC08C79C1937E
C2947EC29683C29785A28982281C2154464E979296CFD0D3D5D3D4DCDDDEE1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E2E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E4E1E2E1E1E2E1
E1EAEBE0E1E0E1D1C2E0CCBEE3CFBCE3CEBFD5AC98D6A893D3A893DFBBACD7B5A9E0C3AF
E0B9AAE0C3AEE1C4B6E1C8BBE1CABDE1CBBEE1CBBFE1CFC4E0CCC0E0CBBDE0CABDE0C4B5
DEBAABD9B8A3DCAD9DD5A591D09A84CD9581D29885D8B5A3E0C1B5E1C7BAE1C9BDE1C4B5
E1C1B5E1C4B4DFC5B6E1CCBEE0C8B9E1C2B0D8B09FD7A897D2A491CCA18FC99784C69582
BF907DBF8B78BA8572B98272B7826EB5836EB8836FBD886BBF8373C08873C08A75C3937B
C89580CDA08CD0A08BD0A38DCB9987CD9784C89683C69280C3917FC08F7CC08C7BC1927F
C1947DC09481C399869C807633232544353D787275BAB6BCC8C1C3D8D7D9E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E1E1E2E3E1E3E3
E1E3E3E1E3E3E1E3E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E4E1E2E1E1E2E1
E1EAEAE0DDDAE2C9B5E4CBB7E6D1BEE2CEC0C29481C3927FC29682D5B0A2DCB6AAE1C4B0
E1BBACE1C4AEE1C4B8E1C8BCE0CABEE0CBBFE0CDC0E0D0C6E0CDC1E0CBBFE0CBBEE1C7B8
DFBEADD9BAA4E0B3A4DAAE9BD4A38ECE9582D29582D6B09EE0BDB2E1C5B9E0C8BBE1C2B3
E1C1B4E1C3B4DFC4B5E1CCBEE1C8BBE3C4B2D8B2A1D8AA9BD1A391CA9E8DC79382C4917F
BE8C7BBE8876BC8271B97E6FB7806CB5826DB9826EBE886ABF8072BC8371BE8773C3937D
CB9785D1A692D2A490D2A792CA9886CD9684C89583C79482C49380C1907CC08C7DC29080
C1937DBF9380C59B889A796C46302F412E35645A5CA69DA5BDB3B6D5D2D4E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E1E1E2E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E3E3E0E3E3E1E3E3E0E3E3E1E3E4E1E3E4
E1E1E1DFD3CCE0BEA9E2BFA9E1C1AFDCBFB1BE8C78C18F7DC19A86D5B0A3DEB7ABE1C4B0
E1BDADE1C4B0E1C3B7E0C9BDE0CBBEE0CDC1E0CEC2E0D0C7E1CEC3E1CBBFE1CBBFE1C7BA
E0C1B0DBBCA7E0B8A8DDB1A1D6A894D19987D39A87D7AF9CDFBDB1E1C5B9E0C6BADFC0B0
DFBFB1E0C3B3DFC4B4E0C9BCE0C4B7E2C0B0D7B1A0D6A898CE9F8CC79989C59080C28E7C
BD8B7ABD8675BD8371BA7F6FB67E6AB27E69B97F6CBF876CC18476BF8877C28D7AC79883
CF9D8BD4A896D2A692D2A794CA9986CD9785C89684C79583C59381C2917DC08E7EC28F7F
C2937EC09482C69E8BA27B6B64463E593B3C6A5552968B90B6AEB1D2CED0E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E2E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E3E3E0E3E3E0E3E3E0E2E2E1E5E7E0E5E6
E0D5D4DFC8BBDDB29FDDAE99D8A898D3A999C18B78C79685C9A996DBB6A7DFBAACE1C4AF
E1C0AEE0C4B2E0C3B6E0C9BDE0CBBFE0CEC4E0CEC3E1D0C7E1CEC3E2CBC0E1CCC0E2C6BA
E1C5B3DEBCAADFBCAADFB0A4D7AB97D39F8ED4A38FD8AF9EDFBEB1E0C5B9E0C6B9DEBFAD
DEBCADDFC2B2E0C4B4E0C5B8DEBEB1DFBAAAD6AF9CD2A392CB9987C39485C28E7EBF8C7A
BD8B79BC8674BD8671BB8270B37D68AF7B64B87D6AC08870C38B7CC69382C99885CD9F8B
D3A391D5A997D2A692D2A693CA9C88CD9A87C99784C89683C69382C4927EC0917EC28F7E
C3927FC29785C6A18EAE816E8760517D534C7F5C538A7E7FB3AFB2D1CBCEE1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E2E3E0E2E3E0E3E3E0E3E3E0E1E0E0E5E8DEE4E7
DFC7C6DDBBA8D8A695D69B89CC8E81C89080C28A78CB9D8CD0B6A4DFBBABE0BDAFE1C3AE
E0C2AFE0C3B4E0C2B3E0C9BDE0CCBFE0CFC6E1CEC3E1D0C7E2CFC4E3CBC0E2CCC0E2C5BA
E3C7B5E2BDADDEC0ACE2AFA7D8AE9CD7A797D7AF9ADAB1A2DFC0B1E0C6BAE1C5B8DDBDAA
DDB9AADEC1B1E0C5B4E0C1B3DDB8A9DCB3A3D4AC97CE9E8CC79281C08F80C08C7CBC8A78
BD8C78BC8574BD8872BC8571B27D66AD7860B87C69C18875C59382CC9D8CD0A190D2A592
D6A895D5A898D0A592D1A591CA9E8ACD9C89CA9885C89684C79382C69280C1947FC28E7D
C49280C49A88C7A391B98771AB7A63A46E5D97665681726FB1B0B2CFC8CBE0E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E2E3E0E2E3E0E3E3E0E3E4E0E1E0E0E4E7DDE1E3
DEBDB9DDB29CD59C8DD08D7CC3796DBE7D6BC48B79D0A393D6C1B0E2BFAEE1C0B1E0C3AE
E0C5B2E0C3B6E0C2B3E0C9BCE0CBBFE0CFC6E1CDC2E2CEC4E2CEC2E3CABEE2CABEE2C2B8
E3C7B5E3BCAEDDC1ACE2AEA7D9B19FDAAE9FD9B8A4DDB4A6DFC2B2E0C6BAE1C5B7DCBCA9
DCB8A9DEC1B0E1C6B4DFBDB0DCB3A4DAAC9DD3A993CA9986C48D7CBD8B7CBD8A7ABA8876
BC8B77BA8573BD8A72BD8772B27E67AE785FB97E6BC38B7BC79A87D2A695D5A998D5A997
D8AB99D5A797CFA491D0A490CAA18CCD9E8BCB9886C89684C79282C79281C1967FC28E7C
C49180C69C8AC7A594C28B74C68E72C3866EAD745F806C65B3B4B5D0CACCE0E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E1E3E3E1E3E3E0E3E3E0E3E3E1E3E4E1E3E3DFD7D6
E1BBB4E1B39ED59889CF8878C07467BB7866C48F7DD3A797D8C3B1E2C1B0E1C2B2E0C3AF
E0C7B6E1C4B9E1C4B6E1CABDE1CBBEE1CDC3E1CCBFE1CCC0E1CABDE1C7B9E0C6B8E1BFB3
E0C3B1E0BAACDBBDAADFAEA5DAB2A1DBB2A3D9BAA6DEB8A9E0C3B3E1C6B9E1C5B6DDBEAC
DDBAACDEC1B2E1C5B5DFBDAFDCB3A4D9AA9BD3A590C99884C28C7BB98A7ABA8878B88674
BA8975B88574BB8A73BE8A74B5816BB47F68BF8674C79283CB9E8CD5A997D7AC9BD5AB99
D9AD9AD5A796D0A391D0A390CBA18CCC9D8ACA9785C79684C79181C69081C1947FC18D7C
C3917FC69A89C9A697C48B74CF9378CD9277BA836D8F7268BCBABBD6D4D7E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E0E3E3E1E3E3E1E4E4E1E4E4E1E3E3E1E3E3E1E6E8E1DFDBE1CAC4
E3BDB1E4B7A6D49687D08978BF7767BA7B68C59482D4A999D8C0ACE0C1B1E1C3B2E0C3B2
E1CABAE1C6BAE1C7BAE2CABDE2CABDE2CBBEE1C9BBE0C8B9DEC6B7DDC3B2DDC1B1DEBBAD
DCBCACDBB6A9D9B7A7DBAFA2DAB2A0DBB3A5D8B8A5DEBBACE0C2B4E1C5B9E0C5B5DEC1B0
DEBEB1DFC2B4E1C4B6DFBEAFDDB6A6D8AA9AD2A18DC99884C28C7BB78A7AB88675B78472
B78774B48675B98974BE8B77BA8771BC8974C69080CC9A8ACEA290D6A997D7AD9BD4AB98
D8AE9BD5A895D2A390D0A290CCA08CCB9A88C99683C69582C68F80C48E80C1927FC18D7D
C2907DC59786CAA599C08873CC9078CB967CC1917CA57D71C7C1C0DDE1E4E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E0E2E3E1E4E4E3E5E6E3E5E6E1E3E4E1E2E2E1E7EBE1DBD3E3BDB1
E4BDAEE5BAACD29485CE8878BD7A68B97E6CC69B89D6AD9CDABEA9E0C2B2E1C3B3E0C3B5
E2CCBFE1C8BCE1CABEE3CABDE2C9BCE2C7B7E0C5B6DDC2B1DAC0AFD8BDABD8B9A8DAB5A6
D5B4A5D3B1A3D6AFA2D5AD9BD9B09ED9B3A4D6B4A2DDBDADDFC1B4E1C5B7E0C6B5E0C4B4
E0C3B6E0C3B7E1C4B8DFC0AFDEB9A9D8AA99D29E8BC99884C18D7BB48A7AB68473B6836F
B58472B18676B88976BF8D7AC08C78C59480CD9C8CD1A291D2A593D7A996D7AD9AD3AA97
D8AE9AD5A894D3A390D0A190CE9F8BC99886C79482C59481C48E7EC18C7FC18F7FC18C7D
C0907CC59383CBA59ABC8571C68975C6997FC79F8BBD897BD3C7C5E3EDF0E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E0E2E3E1E4E4E3E6E6E3E6E6E2E4E4E1E2E2E1E5E8E0D2C5E0AD9D
DFB8A5DFB6ACCB8E80C78575B77B67B5806FC9A28FD9B1A0DCBDA7DFC3B4E0C4B3E1C3B7
E2CCC1E1C9BDE1CBC0E3C9BCE2C7BAE1C3B3DFC2B2DCBFACD8BBA9D6BAA6D6B5A2D9B2A1
D2AEA0D0AFA0D4AA9ED1AD98D9AE9CD8B2A3D5B2A1DCC0AFDFC0B4E1C4B6E0C6B5E2C6B7
E2C6BAE1C4B8E0C3B8DFC1AFDEBBAAD8AB98D19B89C99783C08E7CB38B7AB48372B6826E
B38371B08777B78877BF8F7CC4917DCC9C8AD1A394D4A795D3A695D7A894D6AB98D1A995
D6AC99D3A791D3A28ED0A08FCE9D8AC89684C69381C49380C38D7EBF8B7FC18D7EC08C7E
BF8F7BC39182CAA39AB6806EBD8070BF967EC9A693CF9282DAC6C1E7F0F2E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E1E3E3E1E4E4E0E3E3E1DEDCDCC0B0D39B8A
D3A793CFA59ABC8374B4796AA87261AB7B6BCBA693DBB6A4DDBEAADFC3B4E0C4B4E1C3B7
E1C9BEE0C8BBE1C9BDE1C7B9E1C5B7E0C3B3E0C3B2E0C2AFDABDAADABCA8DBBAA7DDB5A4
D9B2A2DAB6A5D9ADA0D7B29CDAAE9BD9B3A2D9B6A4DDC3B1E0C3B5E1C5B6E1C6B6E2C6B6
E2C6BAE1C4B8E0C3B6E0C2AEDDB9A9D6AA98D09987C79380BF8C7CB58A78B48371B78370
B58472B18878B88878BF8F7CC4927FCC9D8CCEA192D2A695D1A594D3A591D4A895D0A793
D1A694D0A38FD19F8CCE9D8CCC9B89C79583C59482C39280C28F7FBF8C7EC18C7DC08D7E
BF8F7DC09385C7A097B07A69B77968BB9078C6A08DD19181D6B7ADE3DFDEE0E3E3E0E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E4DFE1E1DDDFDFDDDFE0E0E3E4DFE3E5E0D3CAD6AA99C28A78
C18F7CB88C80A873649B685C9566589E7364CDA895DDBBA8DFC1AFDEC2B3E0C4B5E1C4B7
DFC5B8E0C6B8DFC6B7DDC4B6DFC2B4DFC3B5E1C4B3E4C7B4DEBFADE1BFACE2C0AFE2BAA9
E2B8A6E7C0ADDFB1A3DEB6A2DAAE9BDBB2A1DDBCA9DEC5B2E0C6B6E0C5B5E1C6B7E1C5B4
E1C5B7E1C3B8E0C3B4E0C1ADDBB6A5D5A997CE9987C48F7CBE8A7BB88975B58370B88573
B78674B58878BA887ABE8E7BC19280C99A89C79A8BCDA291CDA391CEA18ED1A493CFA491
CCA08FCC9F8CCD9C8ACC9988C89A87C69583C49583C39281C29180C18E7EC18D7CBF8D7D
C08E7FBD978BC39D93A97362B3735FB78670BF917FCB8B7ACDA292DBC4BFE0E2E3E0E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E2E4E4DEDFDFD9D9DAD8D9D9DDDFE0DEE2E5DFC8B7D09682B17A69
AF78659F736593645581574E81594F926B5DCFA997DEC0ABE0C3B3DEC1B2E1C4B5E0C3B6
DDC0B1E0C4B5DEC2B2DAC1B3DDC0B1DEC4B8E2C5B5E8CBB9E2C2B0E7C3B1E8C7B7E7BEAE
EABEA9F2C8B3E4B5A6E5B9A8DAAD99DBB09EE1C1ACDFC6B1E1C8B5E0C5B5E2C5B8E1C4B1
E1C4B5E1C3B7E1C3B2E0C1ADDAB2A2D4A997CD9986C18A79BD887ABB8773B7836FB98775
B98875B78877BD887BBD8E7BBD907FC39686BD9081C69A8BC79E8CC79B88CC9F8ECCA08E
C59789C79A88C89987C99584C49785C49483C39784C29282C29381C2907DC18E7BBE8E7D
C18E82BA9B90BF9A8DA26C5BAD6B55B17A66B5806EC38573C38C76D2A89FE0E2E3E0E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E0E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E2E4E5DEDFDFD8D9D9D7D8D8DCDEDFDEE0E1DDB9A2CC8774A67060
9A625083584B7D53466A48416F4D47856357D1AB98DFC3AEE1C4B6DEC0B1E0C3B5E0C3B5
DCBDADE0C2B2DEBFADD7BEB0DBBCACDAC0B5DEC0B0E3C6B5DFBEACE5C0B0E3C2B4E3BBAB
E6BAA6ECC1ADDFB0A0E1B3A3D6A895D8AA98DEBCA7DABFAADEC4B0DEC3B2E2C4B8E0C2AF
E0C3B4E0C3B7E1C3B1E1C2ACD8B0A0D3A897CB9885BF8775BB8579BD8570B7826EB88775
B98874B98876BF897DBD8E7CBB907FC09282B88A7BC29586C39B88C29785C99B8BCA9D8B
C29284C49786C69786C89482C29684C49484C29885C19183C19582C2927DC08E7BBD8F7D
C18E84B99E93BC97899C6757A6654DAA6D5BAB6E5EBA7B69BA7A5FCA9084E0E2E3E0E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E0E3E3E1E4E4E1E3E4E1E3E4E1E4E4E1DBD8D7A48CCD8876A77364
844F42653F3766443A5A3C38634541785B52D3AD9BE0C5B0E0C4B6DDC0AFDFC2B2E1C3B4
DFC0AFE0C3B2DEBFACD5BBAAD5B4A3CFB2A5CFAE9DCAAA9BCCA99AD1ACA1C6A69ACAA598
C69F92C19C8EC5988AC7988AC79C8BCB9B8CCDA491CDA894D5B49FDCBEABE0C2B5E0C2B1
E0C2B4E0C3B6E1C3B2E1C2AED8B0A0D3A896CA9684BF8772BA8475B9836EB4806BB48270
B3826FB68775C08D7EBF907DC19583C29382C29381C89887C69B88C69A88CB9C8BCD9E8B
C69587C89B88CA9B88CB9987C59B88C69887C29886C09283BF9480C0917DBE8E7ABC8E7C
C08F84BA9D91BD97879B6A599F614BA66352A56353B36D5BB77257C7897BE1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3DFE0E1E6E9EAECF1F1EDF2F2E7EAE9E4D4CBCF8D77CF9080AF7D6E
6F41374729275035314E33325A3F3C6D534DD4B09DE1C6B3E0C3B3DDC0ADDEC0ADE1C3B2
E2C6B4E0C4B3DFC0ACD3B7A5D0AC9AC3A091BC9686A98679B38F81B7938C9F8076A9887D
9B7C79876A63A2776DA37569B58D7FBB8A7EB68574BC8B79C9A08BD9B6A2DEC0B1E0C3B3
E0C3B5E0C3B6E0C4B5E1C3B0D8B1A1D3A795C99482BF8770B88371B4806BB07D67AE7C68
AB7967B28674C09080C39380C89B87C69582CF9F8BD09D89CA9D89CB9E8CCD9E8CCF9F8C
CC9B8ACEA18BCFA18CCF9F8DCAA08DC89C8AC19886BF9282BD927EBD907CBB8E7BBA8D7C
BF9083BC9A8DBF97869B6F5E995E4BA25B4AA05A4BAE5E4DB77159C68A7CE1E4E4E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E4E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3DCDDDEE8EBEDF4FBFCF7FDFDEAECEBE5CBBBC57662D0998CB68679
5B342F2A15193C2829452B2D523A37644C48D6B3A0E1C6B4DFC2B0DCC0ABDCBDA9E1C3B0
E5CBB9E1C5B4DFC1ACD1B3A0CAA390B68E7CA97F6F8962579B766A9C7977785A53896B63
70595F4D38397F57507F5247A37E72AB786FA06657AB6E5FBD8C77D6AF9ADCBEACE1C3B6
E1C3B6E0C4B6E0C5B8E1C3B1D9B2A2D3A693C89280BF896EB7816DAE7D69AC7A64A87560
A37160AD8574C09482C69683D0A28BCA9781DCAB93D8A18ACE9D88D0A28FCE9F8CD0A08C
D1A08ED3A78ED4A690D3A594CFA592CB9F8EC19787BE9382BB907CBB8F7CB78F7BB98D7B
BE9182BE9788C096849C7364935C4D9D53429C5243A9503FB7715BC58C7DE3E5E5E1E4E4
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E4E1E3E3E1E3E3E1E3E4E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3DCDDDEE7EAEBF2F8FAF3F8F7E0DFDCE2BFABBE6856D1A095BE8F82
4E2C2B1809112D1E243D25284C34325F4946D7B5A2E1C5B4DFC1AEDCBFAADBBCA6E0C1AD
E6CCBAE0C5B3DFC1ACD1B29EC8A18DB18673A075647850468E685D8D6B6B61443D755952
55424E28171E68423C673B30977369A06C64915144A15C4DB67F6AD4A993DBBCA8E1C4B8
E1C4B8E0C5B8E0C7BBE1C4B3D9B3A3D3A693C7917FBF896EB58069A97B67AA7861A3705A
9D6A59A78170BE9683C79886CFA18BC7947FD7A790D19B84C89682CB9D8BC99B89CA9B88
CD9E8BD0A58BD2A48ED0A594CFA692CA9F8DC09685BD9281B98E79B88E7CB58F7BB88C7B
BD9181C09483BF94809974658C5A4D964D3E964D3EA74A3BB87461C48C7DE3E6E6E1E4E4
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E4E4DDDEDFD0CFCFBAB1AEDBB19BC26F5BD3A295C49284
4F2F2F180C16291C24352125462F2E624C48D9B7A3E0C3B2DDC0ACDCBFA9DBBDA8DDBDA8
E0C4B2DFC2B0DFC0ACD6B8A4CFAB99BE9682AE86748C64589D776A9776727051497E6259
604A523220246D483F6B3F33987368A06C62955849A76252BA826ED3A891DABBA6E1C4B6
E1C6BAE1C9BDE0CABFE0C4B3D9B4A3D4A794C79280BF886EB57F67A87964AA7962A36F59
9964549E7766B89282C2998ABB9382B38777AC8272AC7F6EAE7E6EB08678B68C7EB5897A
B38A7ABD947CBF9581C09887C49B87C29784BE927FBC907EB88C79B88E7CB48E7BB78C7B
BC9080C19382B78D7A906C5E84554A8C4C3F8D4A3DAD5747BC7B67C18474E2E4E5E0E3E3
E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E1E2E1E3E3E1E3E3E1E2E2E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E7EBEAD8D8D8BDB6B7A09597877472D0A08CC97E69D39F8FC79080
5736352318202B1E262F1F22402A2A6A524CD9B9A5E0C0AFDCBFACDBBEA9DCBEABD9B7A3
D9B8A6DDBEADDDBFACDDC0AEDABBAAD2B09DC6A391B18B7CB89284AF8D83916F6596776B
7D6161553F3D815B4E7D5145A0776AA77266A36B5AB57562C38F7AD3A993DABBA6E0C3B4
E1C8BCE1CDC3E1CDC3DFC4B3D9B5A3D5A996C89482BF8770B57F66A87862AC7A65A4705C
976150956A59B08B80BB998E9F7F759A766D71504A7A5A528B60568C685E9E7A709A7268
916F63A27C68A57F70A98574B58B76B78B77BB8C78BA8D7AB88B79BA8E7BB48E7CB68B7B
BC8E7FC09281AC8472835E537B4F45814D43844A3DB66C5BC0826DBD7A68E1E2E3DFE1E2
E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E0E0E1E3E3E1E3E3E1E1E1E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3EDF3F1CCCAC89B8C8C6F5A5C543735C28E7CCD8D77D09B88C78C7B
603E3D31262C3022292B1E213C2628745951D9BAA6DFBDABDBBEABDBBDA9DDC0AED6B19E
D1AC9BDBBAA9DCBEACE4C8B8E5CBBCE6CBB8DFC2B0D7B4A3D5B09FC8A695B59184B08E7F
9E7B727D625A997160936759AA7E6FB07B6BB4826EC48B75CD9D88D3AB95DABBA6E0C3B1
E0CABEE1D0C8E1D0C6DFC3B2D9B6A3D6AB99C89684C08672B57F67AA7860AE7C67A5725E
955E4C8C5E4DA7847DB29791836B67806563371E224A37386A433F6A4B458668627F5D56
70554D8864558C6A60927261A57B65AC7E6AB88771B88B76B88A79BB8F7BB48E7CB68B7B
BB8B7DBD907FA07969765047724941754F477C4C40C18271C48B74BA715DDEDFDFDEE0E1
E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1DFDFE1E3E3E1E3E3E1E0E1E1E0E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3EDF2F1B8B2B07B6565472B2E2C0908AD7969C6907CC48F7BBB8170
6343423C313534252C291E203A24267C5F55DABAA6DEBBA8DBBEAADBBDA9DEC1B0D4AE9B
CCA494D9B6A5DABBA9E6CABCEBD3C6F2DAC9EFD6C4F2D1BEE8C3B2D9B6A0D0A99AC39F8D
B78E7E9F7E71AB836EA57869B18270B6816EC0927CD09D85D5A994D3AD98DBBBA7E0C3AF
E0CCBFE1D2CAE1D1C7DDC2B1D9B6A2D6AC9AC99986C08675B57F68AB775FAF7D68A77360
965E4C885747A27F7AAD9591755F5F725C5E15010B2D2128553231533834745A576D4E4A
5A433E7754487D5C548466559B705AA67762B6846CB78973B88A79BC907CB58E7DB58C7B
BA8A7BB78C7A906C5F69443E68443D674C47754D42C89382C58C75B86954DDDFDFDEE0E1
E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1DFDFE1E3E3E1E3E3E1E1E1E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3DFE0E1978A8962494A3A1C1E2300008C5C51A57768A577689A695D
563C3D392F3332242B281E203922257D6056DBBBA6DEBBA8DCBFABDBBEAADDC1B0D6B29F
CDA594D5AF9FD6B5A3DDBEB1E4C8BAE6CEBEE6CDBCECCBB9E0BCACD3AE99CEA595BE9887
B78A78A67F71AC816CA57666AE7B68B47B68BE8E78D09E86D6AB96D4AD99DABAA6E1C3B2
E0CCBFE1D0C6E1CEC3DCBFADD9B3A0D5AB98C89B88C08A78B47E69AC775EAE7A64A7745F
9C655192604EA9837AB3968F856B677D666429141A3B2C305B3A36573B357055526D4F4B
5F46407A574A825F558A6A59A0735DA97A65B7856FB88974B78B79BB907CB58F7DB58D7C
BB8D7DAC83737D5D535D3D3A5D3E3957413E6F4B40C59684BF806BB9654FE5E7E7E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1DFE0E1E3E3E1E3E3E1E2E2E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3CCC7CC725D5C5036373B20202A0A0C673E39784F487F5A51704B46
422F3330272B2D2128281E213923267B5F55DCBAA6DFBBA9DEC0ACDCBFABDDC0AFD9B8A5
D1AB9AD2A999D1AE9BD0ACA0D6B3A4D0B4A7D1B5A6D5B4A5CBA89AC29B89BD9485AE8878
AB7C6B9F7467A477649E6C5CA6705EAE7360B7816DC99781D2A994D5AD9ADABAA6E1C4B5
E1CBBEE0CCBEE0C8BCDBBBA9D9B19ED4A895C79D8BC08F7CB27D6CAD765EAC765FA8745E
A46F58A26F5BB48A79BC9789A4807595786E583E3C5F4644714F476A4B40755651795A52
71534A8A6454936B5C997765AC7C67B2846EB98974B88B77B68C7ABA907EB58F7DB58E7C
BB917F9E7769694C465239395239354631316B483DBE8F7EB66D5BBA624DEDF1F1E4E7E7
E1E3E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E3E1E3E3E1E3E3
E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1DFE0E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E0E3E3B9AEB74D3131402628412826341A1C4222224B2827573C3A442C2F
2E2228261E23291E25291F213B2427795D54DBB9A5E0BBAAE0C1ADDDC1ACDDBFADDDBFAC
D6B1A1CFA394CDA794C39B90C89E8EBA9B8FBC9D90BD9D91B59388B2887AAD84769F796B
A070609A6A5E9D6F5E9964539F6855AA6C5AB07663C3917DCFA693D6AD9CD9BAA6E1C4B8
E1CABDDFC7B6E0C2B4D9B8A4D9AE9CD2A593C6A08DC09481B27E6FAE7760AB745AA9765D
AD7B61B3806BBF9279C59884C49684AE8B7A8B6B6187645A8866597F5D4C7C585286665A
8662569A725FA57865AA8472B88672BB8D77BA8C7AB98D79B58E7ABA917FB5907EB48E7C
BA947F8E6A5E553C3949363947343237222467433AB48675AB5849BA604BF3F8F8E6EAE9
E1E4E4E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3E1E3E3
E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E0E1E1E3E3E1E2E3E1E4E4E1E4E4E1E3E3E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E0E3E3AC9EA9341212341C1E452F2D3D282B260E12290A0F38242721141D
1E171F1F171C261C222C20233E272A765B53D9B5A1DFBAA9E1C2ADDDC1ADDDBFACE0C4B2
DAB8A8CEA394CCA592BB9187BF9181AB897FAD8C82AC8C83A7877DA87D73A37B6E967266
9B6B5D98685D9B6E5F9864539E6755AA6C5CAE7260C08F7DCDA694D7AF9FD9BBA7E1C4BA
E1C7BADEC2AEDFBDADD8B5A0D9AC9AD2A492C6A28FC19985B38075B17A64AA7258A9765D
B18167BD8A73C39375C7937BD7A28ABF957FB38D7DA87C6B9D7968946E5A865F55957263
9A7163A97F6AB3836DB88F7CBF8D7AC1947EBB8F7EBA8F7CB58F7BB99180B6917EB48F7B
B3907B7C5B52442E2F3F32383E2F2F2C171A69433AAC7D6CA2493CB85F4BEFF3F4E5E9E9
E2E4E4E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3E1E3E3
E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E1E1E1E3E3E1E2E2E1E3E4E1E3E4E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3B0A2AF32100F2F181A3F2B2939272B1E0B111F060D2B1C20160D16
18131B1F161A251B21302224432D2F745A52D3AE9ADDB8A6E0BFABDEC1ACDDC0ADE1C6B3
DDBDADD2AB9DD0AD9BC29B90C49989B08F85B19187B19288AC8E86AF887FAC8679A07F74
A77A6DA3786EA87C6FA37565A97666B47D6EB7816FC69988D0AC99DAB4A6DBBEACE1C3B8
E0C4B6DEBFABDEBBAAD8B39FD9AC9BD3A795C9A592C59C8AB8877CB6816CA8735CA4745D
A87862B27F6CB4846AB6836CC6937CB58A75B58D7CAE816EA57F6DA07964946C5DA27C69
A67C6CAF8470B68871B98D7CBB8A78BC907BB88D7DBB8F7DB68F7BBA9181B8907EB5907B
A17F6E664A44392628372C34372B2E2B1519784C41AE7867A0483AB6614DD6D6D7E1E3E3
E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E2E1E3E3E1E3E3
E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E2E2E1E3E3E1E1E2E1E2E2E1E2E2E1E3E3E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3BBB1BD3D1D1C2E1A1B3621222F20242112172411152B1C20170F17
18121A22181B251B21342426493435725951CBA491D9B3A1DDBBA7DEBFABDFC2AEE1C5B1
DFC0B2D9B7AAD7B9A9CFAEA2CFAB9CBEA196C0A297C0A398BBA098C09E95BE9C8FB2968C
BB9285B39188BB9387B48E81BA8E80C39688C59987D0A897D5B4A1DDBBADDEC1B1DFC2B5
DEBFB1DDBCAADDBAA9D8B29FD9AE9CD5AB99CCA894CA9E8EBF9084BC8978A877639E715E
9B6B5B9F6D5D9E715D9E6E5DA67866A07665A57D6DA77B69A57D6BA7806CA37A67AC846E
AC8372AF8572B38772B58776B18271B38875B38979BA8F7CB78D7CBB9182BB907DB58F7A
89695B50393631222530242F32282D30191D8A584AB17463A04D3EB16451B2AEAFD9D8DA
E0E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E2E1E3E3E1E3E3
E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E1E1E1E1E1E1E1E1E1E3E3E1E1E1E1E3E3E1E3E3E1E2E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3C6C0CB4C2E2D311F20301B1E281C1F291D202D1D202D1F221D141A
1A121924191C251C203926284F3B3B6F574FC19A87D4AE9ADAB6A3DDBDA9E0C3AEE0C3AF
E0C3B7E0C4B7DFC5B7DDC2B5DABDB0CEB4A7CEB4A8D0B4A8CBB3AAD0B4ACD0B1A5C4ADA4
CEAA9FC2A9A2CDAAA0C4A79DCCA69BD2AFA2D3B19FD9B7A6D9BBA9E0C1B5E0C4B7DEC1B1
DDBBACDCBAA9DCB9A8D9B19FD9B09DD7B09ED0AA97D0A092C7998DC29283A87B6A996E60
8E5E548C5C4F885D51865A4F855E508B6155946C5DA07665A57B6AAE8774B38972B78B73
B38B78B08675AF8773B08071A77B6AAA7F6EAF8674BA8F7CB98C7CBB9081BC8D7CB48D78
7151483B29292C20232A1E2B2E262D351E219B6353B26E5D9F5443AA67548D8385CFCBCF
DDDEDEE1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E2E1E3E3E1E3E3
E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E4E1E3E3E1E1E1E1E0E1E1E0E1E1E3E3E1E1E1E1E3E3E1E3E3E1E2E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3D0CED85A3E3D3826272E191D251A1C30262736292A30232524191E
1D131A271A1E261C213D282A5340406C564DB7907ECEA894D7B29FDDBCA7E1C4AFE0C2AD
E2C5BAE5CEC1E4CEC2E8D2C3E3CDC0DCC4B6DBC3B7DDC3B5D9C3BADEC7BFDFC4B8D4C2BA
DEBFB5CFBEB7DCBEB5D2BDB5DABBB1DDC4B8DEC4B2E0C2B2DDC2AFE2C5BAE1C6BADDC0AE
DCB8A9DBB8A8DBB9A7D9B1A0D9B29ED9B3A2D3AC99D4A296CEA294C89B8EAB82759A7166
8A5A5483544A7D544D795149704D427D544B875E51997060A27667B08977BB9178BC8D74
B48D7AAD8374AA8573AC7B6C9F7565A47969AD8372BA8F7CBA8B7DBC8F81BC8B7AAD8672
5B3C382B1D20291F22271A282C242D3923259E6554AB64549856449D64546D6061C3BDC2
DCDDDDE1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E4E1E3E3E1E1E2E1E0E1E1E0E1E1E3E3E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E0E3E3D6D5DE5E4341422E2D372023291D1F312728382A2B2F2224281C20
20151A281B1F2A1F23402B2B5542416C554DAF8877CAA38FD8B19EDFBCA7E2C5B0E0C3AE
E2C6B9E5CEC2E5CFC4E9D4C5E5D0C3E0CBBCE0CABFE1C9BCDECBC3E2CEC6E3CDC2DBCCC4
E3CAC1D7C9C2E1CAC2D9C8C0E0C5BBE2CDC1E2CCBBE3C6B6DFC5B3E2C6B9E1C6B8DCBFAC
DCB9A8DCB8A8DAB7A5DAB1A0D9B29ED9B3A2D5AE9BD7A79AD3A999CEA496B78E82A87E73
996C649163598A625A835D5378564A82584F865F52956C5E9B7062A88070B28870B2836C
AC8371A57A6DA67F6FAA796A9E7565A67A6AAF8274BA8F7CBA8C7DBE8F80BB8A789B7564
4E302F25191C281E21291B272D232C362224855247935146864D3F86574B605051B7B0B5
E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E4E1E3E3E1E2E2E1E1E2E1E1E2E1E3E3E1E2E2E1E3E3E1E3E3E1E3E4E1E3E3E1E3E3
E1E3E3E1E3E3E0E3E3D8D5DE5D413F4F3633432B2B3122242E24263726292D1F222A1D20
22171B281B212F2226422C2D5541406C544DA88271C49D89D9B19DE0BBA8E2C4AFE1C3B0
E1C5B6E3CBBEE3CCC0E5CEC1E3CDC0E0CBBEE0CDC2E1CBBFDFCFC6E2CEC5E2D0C7DED0C9
E2CEC6DCCEC7E1D0C9DDCDC5E1C9BEE2CFC4E2CCBDE2C5B7E0C6B4E1C5B6DFC4B3DCBFAB
DDBBA9DDB9A7D9B6A3DAB29FD9B29ED9B2A0D7AF9DD8AC9ED6AE9CD3AB9BC59C8FBB9183
B1877BAB7E71A37A6F9A73668F6A5D91675B8D665A956A5E926A5E9D7364A27763A27362
9F75659B7063A2786AA97A6AA07767AB7F6FB48278BA8F7BBA8E7EBF8E7EB78875856053
452A2B25191D291E212D1F272E232B2F20225F3732743C366E3F366A463F5C4B4CAAA2A7
E7EAEBE0E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E2E3E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E4E4E1E3E3E1E3E3
E1E3E3E1E3E4E0E2E3D7D4DB5D403D5B3D395037343A28292E22243724272C1E212F2022
26191D281B23352429432D2E543F3D6B534CA07C6CBE9683D9AF9BE1BAA7E1C3AEE1C4B1
E0C4B2E1C6B9E1C8BBE1C8BBE1C9BDE1CBBFE0CFC5E1CDC2E0D2CAE1CFC4E1D3CCE0D3CC
E1D2CAE0D2CAE1D5CFE0D0C7E1CBBFE1CFC5E1CBBEE1C4B7E0C6B5E0C2B2DDC2AEDCBFAA
DEBEABDEBAA7D8B5A1DAB39FD8B19ED8B09FD8B09ED8B1A1D9B29FD8B2A0D4AA9DCFA393
CAA392C5998ABD9485B28C7BA78072A17667926D6193675E886358906458916656926357
9166599165599E7064A87B69A4796AB18373B9827BB98E7AB88E7DBE8C7AB284716D4A42
3E2628281C1F2A1E2132222730242A291D1F361B1D54272756322D4D34325A49489C9498
ECF0F1E0E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E4E1E3E4E1E3E4E1E3E3E1E3E4E1E3E3E1E3E3E1E4E4E1E3E3E1E3E3
E1E2E3E1E3E4E0E2E3CEC9CF5B3F3B64433E5A403B412D2D2F21243923272D1E21322124
2A1C1F291C2538262A422D2E513C3A694F49967365B48C7AD3A995E0B7A4E0C1ADE1C3B1
E0C2AEDFC2B5DFC4B7DDC3B7DFC7BAE0CBC0E0D0C7E0CEC4E1D3CCDFCEC4DFD4CEE1D5CE
DFD4CCE3D4CBDFD7D1E2D2C9E0CCBEDFCEC4DFCABEE0C3B7E1C6B6DEC1AEDCC0ABDCBEAA
DEC0ACDEBAA6D8B49FDAB39FD8B09DD8AF9DD9B09FD9B4A3DAB4A0DAB5A2DEB3A5DEB09F
DDB7A3DAAF9DD2A896C7A18DBC9483B085749B776A9669618662588A5E52885D4F895B52
8A5E528D61559D6D62A97D6BA87D6EB78876BD837EB88E79B58D7BB98775A87C6A583734
3923272B1F212B1F21342527312328231B1E16050E39171C4025263624275846458C8285
E8EAECE0E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E4E1E3E4E1E3E4E1E3E3E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E2E3E1E3E3E1E3E3B6ADB1593D396346415D433E4732323325283B2529301F22312023
2C1D202A1D243824283E2A2B4C373561484287665AA37E6EC39A87DAB19DDEBEAAE1C3B0
E0C3AEDFC2B5DFC3B6DDC2B6DFC7BBE1CCC0E1D1C8E0D0C6E1D4CCE0D0C5DFD4CEE2D6CF
DFD5CEE3D5CDE0D6CFE2D4CBE0CDBFE0CDC3E0CABEE0C4B7E0C5B4DEC1AEDCBFAADBBEA9
DDBEAADDB8A4D8B39EDAB29ED9B09CD8AE9CDAB19FD9B4A2DAB29FDAB4A1E0B4A5E0B3A0
DFB9A4DDB3A0D6AB99CDA893C59B8ABA8F7DA78375A3766C946F6496695C93675994665C
95685B986B5EA47568AE826FAE8374B98A79BF867FB88E79B18A78AA7D6B936C5D4A2D2C
3421252C20232B1F223223262E212720191D0E030D2B1318321E21291D214F3D3D786C6D
CFCCCCE1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E2E1E3E3E1E3E3
E1E2E2E1E2E3E1E3E4968A8B583C375E45435B43404A36363A2B2D3E292C3421242E1F21
2E1E202B1E23352125392628463130573E3A77584F8F6D61AE8675D1A894DBBAA6E0C2AE
E1C4B0E0C3B6E0C4B7DFC4B8E0CABDE1CDC0E1D2C8E1D1C7E2D3CBE1D2C9E0D4CDE2D6CF
E0D5CEE3D6CEE1D3CAE2D5CDE1CDBFE1CDC2E0CBBFE0C5B8E0C3B2DFC2AFDEBEACDBBDA9
DCBBA7DCB5A2D9B29EDAB09DD9AF9CD9AF9CDAB19ED8B19FD9B09CD8B09EDCB09FDAAF9C
D9B19DD8AE9AD2A694CCA793C69D8BC09684B69180B48779AB8274AA7D6EA97B6BA87A6D
A87B6CAA7C6EAD8171B48875B5897AB98C7BBE897EB98D78AB847298706079584D412929
3120232C20232A1F242C20252A1E251F181D130B13251519291A1F241A1F443234655453
AFA4A2E2E4E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E0E1E1E3E3E1E3E3
E1E1E2E1E2E2E1E4E4756563543A345644445942404E3A39403032412C2F3924262B1D1F
301F212B1F22331E213322243F2B2A4C3531674A447B5D54997363C79E8AD7B5A1DFC0AC
E1C4B1E1C4B7E0C4B8E0C5B8E1CBBEE1CCBFE1D0C7E1D0C7E1D1C8E1D2CAE1D2CAE1D4CD
E1D4CCE1D4CDE1CFC4E1D4CEE1CBBFE1CCBFE1CBBEE0C6B7DFC2AFE0C3B0DFBEAEDABDA8
DAB8A4DAB1A0D9B19DD9AE9BD9AE9BDAAF9CD9B09DD8AF9BD8AC99D5AA9AD7AA98D3A997
D1A794D2A894CC9F8ECAA592C89E8BC79E8AC49E8BC69887C19685BE9280BF907EBD8F7E
BC8F7EBD8E7EB88E7BBA8E7BBC8E80B88C7CBD8B7CB88B77A47C6C8462555F433D392628
2F20222D2024291E25261D23251A231D171D1B151B21181C22171C21181D3C292C54403D
907D79E3E5E5E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1DFE0E1E3E3E1E3E3
E1E1E1E1E1E2E1E4E45B4744523832514243564141513E3D4635374330333D26292A1C1F
311F222C2021301C1F301F223B2627442D2B5B3F3C6C504A886355BE9480D3AE9BDEBDA8
E1C3B1E2C4B8E1C4B8E1C6B9E1CCBFE0CBBEE0CFC4E0D0C7E0D0C6E1D3CCE1D0C7E0D3CC
E1D2CBE0D3CCE1CBBFE0D4CDE1CABEE1CABDE1CABDE1C7B7DEC0AEE0C3B0E0BDAFDABCA8
D9B5A2D9AF9DDAB09CD9AC9AD9AD9ADAAE9BD9AF9CD7AC98D6A896D3A596D2A592CDA491
CA9E8CCCA28DC79A89C8A28FC89E8ACBA28ECFA893D3A590D2A591CEA28ECFA08CCE9E8B
CC9E8BCB9B8AC09883BE9280C09284B88C7BB98C79B386749A736471554A4A3331332427
2E21222D2025271D25211A222017221C151D211C211F1C1E1D151B20181C34222647312C
7E6661E3E5E6E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1DFE0E1E3E3E1E3E3
E1E1E2E1E1E2E1E3E3523C39523A345241425442435441404B3A3C4735373F2A2C2F1F22
3420232D20212F1C1F311F22392526402A29563C3A664A467F5C4EB78B77CEA591DBB8A4
E0C1AEE1C4B5E1C4B7E1C6BAE1CABDE0CABDE0CDC2E0D0C7E0D0C7E1D3CCE1D0C6E0D3CC
E1D3CCDFD3CCE1CCC0E0D3CDE0CABEE1CABDE1CABDE1C6B8DEC0AEE0C1AFE0BDAEDABAA6
D9B4A1D9AD9CD9AF9CD7AA98D8AB98D9AD9AD8AD9BD6AB96D4A795D2A394D0A390CBA28F
C89C8ACB9F8BC69A89C8A08EC99E8ACBA18ED1A793D4A590D3A591D0A38ED1A28ECF9F8C
CD9F8BCC9C8AC19984BF9481C09182B88B79B28875A87E6E8B6659624942422B2B2E2225
2C21232C2025241B241D171F1D15201A141C201B201D1A1E1B141B20191D2F1D21412823
897570E3E5E5E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E0E1E1E3E3E1E3E3
E1E2E2E1E2E2E0E1E2543D3B533C385741405343455742424F3E404A393B412E30362427
3621232F20222F1E203521243A26283F2A29553C3A6548447C594DB18370C89B86D8B39F
DEBDA9DFC3B2E1C4B6E1C6BAE1C7BAE1C9BCE0CCC0E0D1C8E0D1C8E1D4CCE1D0C7E0D3CC
E1D4CEE0D3CCE0CEC3E0D3CCE0CBBEE0CABDE1CABEE1C6B8DEC1B0E0BEAEDFBDACDAB8A4
D9B4A1D9AC9BD7AE9BD5A896D6A996D7AC99D8AB99D6AA95D3A694D2A292CFA390CCA28F
CA9C8BCC9F8BC89C8AC99F8CC99D8AC99C8ACDA18ECD9F8BCB9E8BCA9C88CA9D8AC99886
C79985C59684BF9481BD9381BC8D7DB88875AA81709973657A574D57403B40292A2A1F23
2A20242C1F232119221C151D1A131E19121C1C161C1B171D1B151B211C1F2C1A1E402723
A49694E2E4E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E2E1E3E3E1E3E3
E1E2E3E1E2E2E0DFE05A4140553F3C5B413D5143465943435342444E3E3F4432343E292C
392124312023301F223923263C272A3F2B2B563E3C6547447A584DAA7A68C1907AD4AC99
DBB7A4DDC1AEE1C3B5E2C7BAE1C4B8E1C8BBE1CABEE1D1C7E1D2C9E1D4CCE1D1C8E1D4CD
E1D6CFE1D3CBE0D0C7E1D3CBE0CCBEE0CABEE1CBBEE1C5B9DFC2B2DFBAACDFBDAADBB6A2
DAB4A2D9AC9BD6AD9BD4A694D4A794D5AA98D7A898D6A994D3A594D2A291CFA391CCA18E
CB9C8BCD9D8BC99E8BC89C8AC89B89C59786C89987C69785C29684C49481C39784C18F7F
C0917EBC8E7DBB8F7DB9907FB68876B68470A0796A8A675C6848414C373540292A281E22
2820252B1E221E17201A121A18121C17111B1912191B141C1C161C241F222C1B1F442B28
C1BBBBE1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3E1E3E3
E1E3E3E1E2E3DFDEDE5F47465541405C3F3A514345594344564547514242463738452E30
3C23263321243121243D25293E2A2D402D2D56403D6647457A594EA27262B98570CEA491
D8B29EDCC0AAE1C3B3E1C7B9E1C3B6E1C7BAE1C9BCE1D1C7E1D2C9E1D4CBE1D1C8E1D4CC
E1D6CFE1D2CAE1D2C9E1D2C9E0CCBFE1CABEE1CABEE1C4B9DFC2B2DFB8ABDEBDA8DBB4A0
DAB3A1D9AB9AD5AC9AD3A593D2A692D3A996D6A696D5A893D2A594D2A290CEA391CDA08D
CC9D8CCD9C8BC99F8BC89987C69987C29281C29282BF917FBB8F7EBE8D7BBD917FBC8979
BA8B78B58877B78A79B58C7BAF816EAF7D6A946F637A5C53593C3744303140292A271E22
271F262A1E211C161F19111917111B17101A170F161A121B1E171D272124301F22533A39
DBDBDCE0E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E2E1E3E3E1E3E3
E1E2E2E1E2E2DEDDDD5E4645534141573B375242435943445847485545464A3B3C483233
3F282A3320243223253F282A402C2F412F2F543E3C6548447B5B50996A5BB17D68C89A87
D6AD99DDBFA9E0C3B2E0C6B7E1C2B5E1C6B9E1C8BAE1CFC5E1D1C8E1D1C8E0D0C7E1D1C9
E0D3CBE1D0C7E1D1C8E1CFC5E1CABEE1C9BDE0C8BCE1C3B7DDC0AFDEB7A9DDBCA7DBB29F
D9B09FD8AA98D4AA97D2A592D2A592D2A896D4A494D4A792D2A593D2A390CFA290CEA08E
CC9D8CCC9C8CC89E8BC79785C69685C19081C19181BE907FB98D7CBC8B7ABD8F7EBC8879
B98A77B48776B48878AF8776A77B69A1736188665C6F514A5034313F2B2E3C2729271E22
271F262C1E221D17201A121A1A131C18111B140D15180F1A1F181E271E20382527715D5C
E3E6E7E0E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E0E1E1E3E3E1E3E3
E1E1E1E1E1E2DEDCDD5B4543513F404F373455403F5743445948485948494E3F40493435
432D2F322124352427402B2C422F30433131513B396348427C5C528E6355A97562C1907C
D3A794DDBEA9DEC2B0DFC5B4E0C3B5DFC4B8E0C6B9E0CDC3E0CFC5E0CDC3E0CFC5E0CEC4
E0CFC6E0CEC4E0CFC5E0CBBFE1C8BCE1C8BADFC6B9E0C2B4DBBDABDDB6A7DBBAA6DAB09D
D7AD9BD6A996D3A794D2A692D3A593D2A895D3A392D2A591D1A492D1A491D0A08FCF9F8E
CC9D8CCB9E8DC79C89C69584C69483C29181C09182BF9180BB8F7DBC8C7CC08F7FC08B7B
BB8C7AB68A78B28876A881709F74648D66577B5C54644842492E2D3C282C362428271F22
271F252E20241E18211D141D1E161E19131C120D16150E181F1920261A1C442F30968786
E3E6E7E0E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E0E0E1E3E3E1E3E3
E1E0E0E1E1E1DDDCDD5C48454F3F41473231573E3B5542435948475C4B4C5242434A3737
463234322124372628412D2D4431324633334F38376249427E5F54845C50A06E5DB88571
CFA08EDCBBA7DBC0ADDCC2AFDEC2B3DDC2B6DFC4B7DFCAC0DFCCC2DEC9BEDFCDC3E0CBC0
DFCAC0DFCBC0E0CDC2E0C7B9E1C6BAE1C6B7DFC4B5DFC0B1D8BAA6DBB6A4D9B8A3D9AE9B
D5A997D4A894D2A591D2A791D3A493D1A794D2A28FD1A490D2A492D1A591D19F8ED19F8F
CD9E8CCBA08FC79A88C69383C69281C39282C09283C09281BD907DBA8C7CC18E7FC28C7C
BA8C7AB68A78AD8674A07A69956C5E79594C6E524C5B3F3A442A2A3A262A302227271F23
271E243021251F19231F161F211A211B141D100C16120C16221C2328191B533C3CBCB4B3
E2E5E5E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1DFE0E1E3E3E1E3E3
E1DFE0E1E0E1DDDCDD614F4C4F4042423031583D385441425847465D4B4C5545464B3A39
4936383423263A2729402E2E4533334735354D37365F49407B5E547A554B946657AD7A67
C89785D9B5A3D8BCA8DABFABDDC2B1DDC1B5DEC3B6DEC7BCDFCAC0DEC6BADFCBC0E0C8BC
DFC7BBDFC9BDE0CBBEDFC4B4E1C4B8E1C3B4DEC1B2DEBEAED7B8A2DAB5A2D8B5A1D9AD99
D4A694D2A792D1A28ED2A790D3A493D1A693D1A18DD0A38FD1A391D1A591D29E8DD29F8F
CD9E8CCAA08FC69887C69282C69180C39382C09383C19382BE907DB98B7CC18C7DC28D7C
B88A79B38876A6806E967060886357674C426148445136333E27283724292C2026271F22
271E23302126201A23201721231B221A141D0F0C16120C16241D242F1C1E695251DBD7D7
E0E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1DFE0E1E3E3E1E3E3
E1E0E0E1E1E1DEDEDF6E5C5A524142433233573C375341425646445B494A5948484D3C3B
4937383B2A2C3A282A3D2D2D4332314635354D38385B463F7157506F4E47845A4EA0715F
BC8A79D4AC99D8B7A2DCBDA8E1C4B1E1C3B4E1C4B6E0C7B9E1CABEE1C7B9E1CBBDE1C8BA
E1C7B9E1C8BBE1C9BBDFC2B0E0C3B5E0C1B0DFC0B0DEBCACD9B7A2DBB5A2D8B29ED9AC98
D5A592D3A692D1A18DD2A58ED2A291D0A491CFA08CD1A18ED0A190D1A38ED09C8BCF9C8B
CB9D89C99E8CC69585C69282C59281C29382C09383C19481BE907CB98C7CBE8B7BBE8A79
B38675AA806F9A74648A645678564D5B423B553D3B462F2D352224302125281E24271E21
291E232D2025201A231D151F1E171F15111A120E1817111924191F3E29298A7978E6E5E5
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E0E0E1E3E3E1E3E3
E1E1E1E1E2E2DFE0E1806D6E574444473638543B375341425443435846475C4A4B4F3F3E
4937374332343A282B3A2A2B412F2F4534364D3A3B55413D634E4A664844724E46916859
AD7B6BCBA18DD7B09ADFBBA5E5C5B1E5C5B3E3C6B5E2C5B5E3CABCE4C9B9E4CBBAE2C8BA
E3C8B7E3C7BAE1C8B7DFC0ADDEC1B2DFBFADDFBEAEDDB9A9DCB6A3DCB4A1D8AF9AD9AB97
D6A490D4A692D19F8CD1A28BCF9F8FD0A28ECC9D8BD1A08CCE9F8ED09F8BCD9A89CC9885
CA9986C89A87C69284C69382C49382C19281C09282C09480BE8F7BB88C7BB98877B78674
AB806F9F75658B64577C564B6748435338354833333B28272B1D20291D21251C23251D20
2A1F22291D221F182118121D17121A0E0B1616111B20181F251518543C3AAFA6A6E6E7E7
E2E4E5E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E0E1E1E3E3E1E3E3
E1E2E2E1E3E3E0E3E3937F825F49484E3D3F523C395241425140415342435F4B4C514041
4836354B3A3B3A282C36262A3E2C2D4233354D3C3E503D3C5544435E434160443F826054
9E6D5DC29480D5A892E0B6A1E6C5AFE8C5B1E4C6B3E2C3B0E4C9B9E5CAB7E4C9B5E1C7B8
E3C7B5E3C4B7DFC5B1DDBDAADBBEAEDDBCA8DEBBACDCB5A6DDB4A3DBB3A0D7AA96D8A894
D6A28ED4A491CF9D8ACF9E88CC9C8BCE9E8BC99B89D19D8ACB9D8BCE9A86C99886C7947F
C79581C69582C58E82C59482C29482BF917FC09180BF947EBD8E79B78B7AB28573AF816F
A3796792695A7C544A6F4841573A384D302F3D2A2B32222322191C21191D211A21231C1E
2A1F22231B201E171F130F190F0B140706131D161F2B23272914156A514ED4D3D2E2E4E5
E1E4E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E0E1E1E3E3E1E3E3
E1E3E3E1E3E4E1E4E5A694996A5451554345513C3A5241424F3F40503E3F5F4B4C524243
4836355140413A292C3324283C2A2B4030344C3D3F4B393A4B3C3E574040533C3A74584F
8D5F51B48673CB9C87D9AD99E1BEA8E5C0A9E1C1ACDEBDA8E3C5B3E4C7B3E3C5AFE0C4B3
E2C5B1E1C0B3DDC0ABDBBAA5D8BCA9DAB7A4DEB9A9DAB1A2DCB2A1D8AE9CD4A490D4A48F
D39E8AD2A18ECD9A88CC9984C99987CD9A87C79887D19B87CA9A88CD9582C79683C4907A
C4927DC4917DC48B7FC49481C09481BD8F7CBF8F7DBC927BB98B76B38876AA806EA57A68
98705F855C4F6D463E623C37482F3045292A332224291D1F1B161A1B161A1E171E201A1D
281D201D171C1B141D0F0C170A0711050411221921362B2E361D1D846C68EEF3F3DDE0E1
E0E3E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E1E2E1E3E3E1E3E3
E1E3E4E1E3E4E1E4E5BAADB17B6765574444503C39514040513F41503E3F5C4748544445
4B3A395241413B292C3423273C292A3C2D304A3B3D493739483B3D543F404D3A39674E48
7A51479F7565B58A77C49A88CDAA97D4AE99D5B09CD4B19EDDBCAADCBDA9DEBDA7DDBEAB
DEBFABDCB9ABDABBA5DAB6A1D9BAA5DAB39FDDB7A6D8AE9ED9AD9CD2A591CB9B87CD9B87
CC9883CE9B88CB9682CB9581C99784CC9782C99684CF9884CB9786CC927FC79582C49079
C49079C4907AC48A7DC3917FBF927EBC8D7ABC8C79B78C76B28572AA7F6EA17765986E5F
8B6354775146603C365633303D272A3A22252B1D2023191D1712181814181B151D1C161B
21181D1511181410190D0C170C0A140B091421141B3A2B2D533B3AA08F8BF3FAFADEE1E2
E0E2E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3E1E3E3
E1E3E3E1E3E3E1E4E4CCC6C88E7E7F5A4542503C38513F3E544142513F40564243554546
503E3E513F3E3C2A2C3724273D282A39292C48383A4837394B3C3E523F414C3B3B5B4441
674640896359997566A88273B19181BD9785C59A87C7A291D4B09ED1AF9CD7B39ED7B5A0
D7B6A4D4B0A1D5B39ED7B19CD9B7A1D9AD9ADCB5A2D5AB99D1A795C99884C0917DC28F7C
C28E7BC7947FC8917CC9907EC9947FC9947ECA9481CB947FCC9483CC8F7CC89380C5907A
C38F75C48F78C3897BC08D7CBD8E79BB8976B88775AF8370A77E6C9F7363976B5C8A6054
7D55496A463D5436314A2C2A3523262D1C21251A1D1E151B16101717121818121B18121A
1811180D0B140B0B160E0E1912101A16111A1F0F143D2B2B776463BDB3B2EDF2F2E0E3E4
E0E2E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3DEDDDEA296995F4843533E3B523F3E574444534041503C3E574647
5443444F3C3B3E2B2C3A26283F282B3725294635374838394F3F405241424E3E3E523B3C
563C3B72524E7D60558C6B5F96786BA57E71B38372B89284C9A391C4A08DCDA793D0AA95
CEAC9ACAA696CEAA97D3AA96D7B29BD5A594D8B19CD0A593C89F8CBE8A76B38572B68270
B78472BE8B76C28B74C58979C7907AC48F78C9917CC58E79CB8F7EC98B79C8917DC58F7A
C08C71C28D75C08677BB8878BA8972B78371B2806FA679699B75669366588B5F527B5248
6F473E5D3B3549302D4027252E1F2222171D1F191B1A121A150D17171019160F19130E18
0F0A1305041004061210101B1A1822251D23200D11432D2C9D8E8DD7D6D7E3E5E6E1E4E4
E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E0E2E3E9EDEEB5AEB26B544D5A4642533F3E5945445341424C393A574647
5645474E3B3A402D2E3E28293F282C35232744333549393A5443435343455142424D373A
4B37396046466751497559507E62598F6A60A27061A88277BA9483B48E7DBE9786C39B86
BF9D8DBC9888C29D8CC89E8BCFA892CD9B8BCFA894C69D89BB9381B07D69A47967A77464
A87867B1806CB8816ABC8072C08872BC8770C48A75BC8772C68978C38573C28B78BF8B77
BA866BBC8770B98171B48171B2816BB07B6AA978689B6F618F6B5E85594C7D52486B443E
603A3450322F3F2A29362222291D201A131A1C171A16101A130B16150E18120C180F0B16
08051101010E00041013121C201C2631252A291315523B3ABDB3B3EAF0F2D9DADAE1E3E4
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E4E1E3E3E1E3E3
E1E3E3E1E3E3E0E2E3EBF0F0C6C2C683706C675454523E3D533F3E5240414D3B3C554546
5444464F3D3C443232402A2B3D272B3523274533344A393A5746465546475546464F3C3F
4B393C5842445F4B466C544D71585283615894665896756AA782729F7A6DA58174AC8675
A68679A68476AD8779B28877BB9480BD8C7DBD9885B48D7BA782739E7160936D5E946659
986A5B9D705FA6735EAC7365AF7A66AD7A64B77F6BB17D68BA7F6EB67C6AB5806DB1806D
AF7C64AE7B66AB7666A87768A57662A371619B6D5E8F6559825F54774D436D463E5D3936
53322F442B2A3524252F1F21251B1E18121A191419140E19110915110B160D09150B0915
070613040410030510150F181E17203525283E2829776362D0CACAEEF5F7D9DADAE1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E0E2E3E8ECECD4D3D6A1949379686B523D3D4D3837503F40514041534444
4F4142524241483738422D2E39262A3725294634354B3A3A5A494A5849495A4A4B554547
5140425743455F4C486B554F6B55507D5E5589615484695F916F6288665C896961916E62
8A6C628D6E63946F64966D60A27B6BA87B6CA684749E7A6A906F638967598160557F574F
865B4E865E528F62519663569968589B6B57A4715EA4715EA97362A67160A371609E7161
A0705C9B6C5A986758996C5D9468589264568B6154815B5176524868423A5B3A3550312F
472D2C3925272C1D20291C2121191C19131B181219110D180D07130C0813080612080814
0A0A170B0A150B0913180C131A10183723265C4647A39695DAD8D8EAEFF0DDDFDFE0E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E0E3E3E2E4E5E0E2E3BFB8BB8C7D84534040483433504041564646514242
493D3D5346444C3C3D45303237262A3A282C4836364D3B3B5D4D4D5B4C4B604F4F5D4F50
584849574647604E4C6B5853665350775C547E5E52735D557C5D5272524D6D524E765650
6D534B7458507A574F795249886155916A5B8E6F62876759785B54745D536F534D6A4945
734B426E4C45785144805346825649875C4A9062529564539766559465548F6151886153
8F6353875C4D84574A896152815A4E80574B7A534A7351486A443D5A36334A302D43282A
3C28292F212524171C241A211F171C1A131D18101A100C170A061208051003030F070814
0F101D15141D1610181E0D121A0C133B23267A6666CFCAC8E1E3E4E2E5E5E0E2E3E0E3E3
E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3DCDEDEE8EBEBD7D5DBA0949D5C4A4B4A36365141425848494F4040
463A3B5448474F404147333537282B3D2D304A3938513E3D6050505E4E4D645252635756
5F4E4E594A4A63504F6C5A56645250725A52745A5066544C6A4E455E42405640405F4342
563E395F464165443F613D386F4B447A594C775C5271554A634A4661524C5F4745583D3C
613E37583C3A6141396A44386B453C734C3E7B52458256478258498058497A5244745246
7C5449734C4170483D7653466F4C446D4A4069473F63463F5D38334D2E2D3C2727392225
322527271E231E13191F18211C161B1B131D170E190F0C1708051105040F01030E070914
1414201E1A2122181E2A141824141A4A3134998787F0F0EFE5E9EADBDCDBE3E5E6E1E3E3
E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3DCDDDEE9EDECE1E2E7B4ACB57362645845465140415443434D3E3E
483C3D5449485142434937383D2F324333354E3D3D57454462515161514F635252635756
615050594A4A62505068565365504E6A534B6B544D604D465F453F523A3A4E3B3C543C3C
493432503B395A3D3B5537335D3E3B664942664E48604741573F3D534644513D3D4A3435
5133304832324E35315738305839335D3D3466433B6B463C6C483D6B493E68453B62443D
67453E603F385C3B3461443A5F3F3A5A3D37593B37523A3651302D432929332224311E22
2B2124231C211B111919141D18131917101B120B170D0B16080712050611030612080912
14101B1D151B2A1C203E272A47373B6F5A5EB3A7A8F6F9F8E6EBEBDBDBDBE3E5E6E0E3E3
E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3DEE0E1E6EAEAE2E4E7C8C4CA9081846E5B5E523F414D3B3B4C3C3C
4E40415248485143444C3A3C47383A4A393B5241415E4C4C635250625251615151615352
5F4F4E594A4A604F4E63504D664D4A634B43644D495F474359413D4B36374E3C3E503C3C
433132473537553D3D4F3936503738533C3C594441533C3B4F3837493A3B4533353F2D2F
422B2C3C2B2C3E2C2B472E2B482F2C49302C533631523631553832563B34563A35523936
5136335034304B302D4B352F50343148312F4A312F422E2C452A2A3C27272E20222B1C20
261D20211B20191019130E18141018110C170D09140C0A15090814080A15090C170B0912
140B141B0E133221245841447365689C9093CAC5C5EEF1F1E5E9EADEDFDFE1E4E4E0E3E3
E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E0E3E3E2E4E4E1E4E4D9D9DDADA0A58573775642444936364E3D3D
5546485247495243444D3D3E504142503F4055454665535363514F6354525D4F4F5E4E4E
5D4D4D5A4A495E4E4D5E4947684B475C433C5D47465E4340543E3D453435503F404D3D3D
3F31333F3135513E414B3D3B443136422F364D3B3B4632364A32334030333B2B2F35272A
3524283126283024263825263826263624254029293A26273F2929422D2C463130442F30
3D2929402A293B2628372725432A2A3626283D28283223233A25283526272A1E21261B1F
221A1E211A1F18101B0E0A14110D160B09130906110C09140C0B160D101A11141F110E15
18090F1C0A0F3C282A735C60A19596CAC5C9DFE0E0E3E5E5E2E4E5E0E2E3E1E3E3E0E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E0E3E3E2E4E5DDDFE0DFE2E1E6E9EAC7BCC29D8C92634E524A3737513F3F
59494A5045475142434E3F4057484854434357484968575861504E6353525A4C4C5C4A4A
5A4B4B5B4A495B4B4A5A4442684844553C355540415C3F3D513C3C4133355142424C3E3E
3D31353A2E354D3E43483F3F3B2D343526324434363C2A32432D2F39272D3325292F2426
2B1F26292125241D222B1E232C1F22281B20311F23281B202E1E2231212438282A37262A
2C1E203321242D1E23271C1E372124291D22312022251A1C2F20252F2325251C20221A1E
1D161B1F191E17101B0A07110E0B160806110706100D0A150F0D1713141E1A1A241C151A
2412162915184F3B3D8F7B7FC7BEBDECEEF1ECF2F3D8DADBDFE0E0E2E5E5E0E2E3E0E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E0E3E3E2E4E5DDDFDFE0E2E1E9ECEDD5CED2B3A6AC7F6E7257434453403F
5442434A3D3E4F40414D3E3F5849495346465748496555565D4D4C6051505749495A4848
5748485B4B495645445641406143404E35314A38395439394D393B4030334E3E3F483A3B
3D3035372C3645383E423A3D3527312F212E3B2C3132242C39262B3222292C21272B2124
241C24221C211E181F241921251B2020181F271A2020171D25191E261A1F2A1E222A1D24
21171C281B2023191E1E161A2C1B2021181F26191D1B1318221820261D211C161C1A151B
16111819141A140E1A0A06120D0A160807130C0A150F0D18100E1817141C2019212D2123
412E31503C3F756566AB9DA0D9D4D3F4F8FBEFF5F6D8DADBDEDFE0E2E5E5E0E2E3E0E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E0E3E3E1E3E4DFE1E1E1E4E3E7EAEADCD9DCC5BEC3A2969B6B5858584343
4D3A3A4535354E3E3E4C3E3F5647485146475547485F5050584A4A5C4C4C554646584747
5445465A4B4A503D3D523F40583D3B472F2E3F2E30483334493739402D3147373A433336
3C2E343429373B2F363C333931222C2D202B33252C2A1F272D1F262B1E27271E25281F23
2019221D171F1A141D1F161F2118201E171F22171E1F181C22181D1F161C1F151A20151E
1B131A21181E1D151B1C131923171E1E161D1D1419150F1616111B1D161D120F17131018
0E0C15110D17100C180C08150D0C170B0A1614111C14131D110F181D141A27161C433130
665456817273A39999C5BEC0DFDDDDEDF0F2EAEFEFDDDFE0DFE1E1E1E3E4E0E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E0E2E3E1E3E4E2E4E5E0E1E2D7D5D8C6BFC4806E6E5F4948
48353441302E4E3E3E4C3F3F5546474F4849544546584949534647564747524243564545
5142445A4C4B4A36374F3F404E3736412A2B3426273E2E2F463537402B2F4131353F2C31
3D2D3334283832272E372B352F1F292D20282C1F27231B23221823261C26231C25271E23
1E182119131D19121C1C151E1F17201E17201E161E201A1E22181E1B141A160E1418101A
18121A1C161D1913181B131A1D141E1D151D161017110C150C0B171510190A09130D0C16
0808130B07130E0A15100A170F0E190F0D1A1E19251B1A2416131C25171A3017195B4340
8C7C7EB2A7A7CFCBCBDDDDDEE1E3E4E3E5E6E2E5E5E0E3E3E0E2E3E1E3E3E0E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E1E1E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E0E2E3E2E4E4E1E3E4DDDFDFE2E6E5E3E5E7E1DFE59888886D5857
4E3B394634325040404C3F405344454C46475142435243434E4445534445514041564545
4F4042574B4A432F314D3E404532323B26292C1F2134282B4031333F282D3B2B2F3B262D
3C2B323226372A20263225302D1C262D2026271B241E181F1A1320221A24201B24261C22
1D172018101C18101B1A131D1D16201E18201C161D221C20231A201B141B130C13160F19
19131C1A161E1914191D141C1A141F1D161D130F17100C16070814110C160606110A0A15
0607140906130E0B16140E1B13111B15111D271F292320291F1920332021412222765D57
AFA1A3DAD3D3F0F1F1EDF3F3E1E6E7D9DADADBDCDCE3E5E6E1E4E4E0E2E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E0E2E3E1E4E4E0E2E3DDDFDFE3E7E7E7EAECEAEAEEB0A5A58A7979
6959575A49495443444B3D3E4D3D3F463E3F4C3E3F4E40404E4445534647544445584849
5041435146463D2B2D4C3D3F3F2D2D362327291D202D2327372A2E37232A34262A332229
34252D2D2331231B212B1F2B291B24281D232319231B151D1913201E18221E1922221920
1B151F17101B160E1916101B19131D1C151E1A141C221C21261D251E182119141D1E151E
1E19221B17211D171E1E16201C17221E161F151119130E190A0B16120D170B09130F0C17
0E0D1A120E1A16111B18131F19141F1C141C291B232B20253022254A343261434196827D
C5BCBDE7E4E4F7FAFAF0F6F6E2E7E8D9DADADBDBDCE3E5E5E1E4E4E0E2E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E0E3E3E1E3E4E0E2E3DFE1E1E3E7E7E6E9EAE7E9EBC6C1C2ACA1A2
8F828177686A5B494B4D3B3D493839413536483C3D4C3F3F51454754494B594A4B5C4C4E
5344464A404237282B4C3C3D3C2A2A332126281D23291F242B21282D1F262E21252C1F27
2A1E26261E291E171E251C27241A2222192020182219131C1B15211C15201C16201D161E
1A141E18111C130C17120D1915101A18121B18121B201A222A2029241E29231F2D2A2026
2620291F1A25241C25201825221B261F17221A151D18121E13111A18111A140F1816101A
1A16221F1A25201A241E1924221A2324181B2A161A341F1F462F2D674F4B866E6CB6ABA8
D4D0D1E7E6E6EFF2F2EBF0F0E3E7E8DDE0DFDEDFDFE1E4E4E1E3E4E0E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E0E3E3E1E3E3E0E3E3E0E3E3E1E4E4E2E4E5E2E4E5DCDDDECEC9CB
B5ACAC95898D655154503D3F4734353F2E2F463C3C4C414155494A584E515F5152605153
564648433A3E3327294C3B3C3A2727322025291E27261C21211922241B23281E21251D24
201820211B201A141B201822201A211D161E1E192319121C1E18221A141E1B151F19131C
19131E1A131C120C16100B17130E1816101918111B211A242F252F2C25322F2C3D382B30
2F2831241D2A2D222D231B2A29202A221925211A211F18221D181E1E151D1F171C1F151E
29202B2F29312D252E25222B2E222A2F1F1D2D14143F211D5E3E37846C66AB9A97D4D2D2
E0E1E1E2E4E4E3E5E6E2E5E5E2E4E5E0E3E3E0E2E3E1E3E3E0E3E3E0E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E1E3E3E2E4E4DFE1E2DEDFE0DCDFDEEBF0F1E8E8EA
D4CFD0B1A8AD7562665C494B4D3C3D463333493E3F4E4243574A4B584F52615455615255
59494B40383C342B2D503E3F3C29293322272D212B251B211B141E1E1721241B1F201B22
1A141C1E181B1813191C161F1E1A201A141C1D182318111C1F192219131D1A131D17111C
19121D1B141D130D170F0B17110C17160F1919111B211927322833322A393A364A423438
382F392A222F332734261E2E2E252D261C28282026261D27271F23261B222A1E21281B23
3428323B3238392D342E292F3A2A313E2823391C1A4F2C2579564CA08A83CAC0BDEAEFF1
E7EBECDCE0E1D8DADADBDBDCE0E1E1E3E5E6E2E5E5E0E2E3E0E3E3E1E3E3E0E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E1E3E3E2E4E4DFE0E1DEDFE0DDDFDEEEF3F4EEF0F2
E1DEDFC5C0C492848779696C6657595D4C4C5144444E41425243444F4446584A4B5A4C4F
5A494A473E4243393C5A494946343438292C34252C281D221E151E1C151F251B201F1A20
1C151C1F191B1B151B1C151E1E191F19141D1A151F140D191B141E17101B18111B16101B
17101B1C151D18111C120E18100C1717101B1B131C211A292F2734332A3A3E384C42353B
3D343E312834352A362821302F262F2C202D2E262B2C242D2C23272E22293023262F2127
392A313D2F323C2B2E372A2C4732345036315538356A4B44987B72B8A9A3D9D4D2EFF6F8
E8EEEEDDE1E2D8DADADADBDCDFE1E1E2E5E6E2E5E5E0E2E3E0E3E3E1E3E3E0E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E1E3E3E1E3E4E0E1E2DFE1E2DFE2E2E9EEEEEAECED
E2E3E3D3D2D4B3ACAF9D9396877C7F7D71705E4E4E5042434D3C3C4435374C3C3D514346
5A494951474B564B4F6656575443444032343D2A2D2E2125261A211F151F281D23211A1F
231A20241B1F21191E1E161E1F181F1C151F18111B110A15140D18160E1A17101A18101C
150F191C161D1F182417121B110D1A1A13201D171D221B2B2B26323127393E37483D323D
403841372F39342B362B24312F272F322632342B2F322A3130272C372A3035282A36282C
3A2A2D3B27283E2727412A28543B386547457A5F5C89726EB7A6A1CCC4C1DFDDDCEAEFF1
E7EBEBE0E4E4DDDFDFDDDFDFE0E1E2E1E3E4E1E3E4E0E3E3E0E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E1E3E3E0E3E3E0E3E3E1E3E3E2E5E5E2E5E5
E2E4E4DFE1E2D4D4D5C1BDC0AAA2A79F97956D5A5A5546474A37363C2A2B4231324A3C40
5C4B4A5F53566C5F637365666353554A3C3D48302F3526292F21252417212E2128251C21
2D21262A1F25291F232319212218201F1822180F180F08130F0813160E19160F191B121E
150E181D171E271E2C1D171F14101C1E1624211A1F231C2D2724303024373F3443372F3D
423A433E363E342D362E28312E282F392C383A3134383237352C324134393C30303E3033
3D2C2C3B22214125214D2C2762463F7A5A5A9E8885A79B98D5D0CFDEDEDEE1E4E4E2E5E6
E2E5E5E1E4E4E0E3E3E0E2E3E0E2E3E1E3E3E1E3E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E0E3E3E1E3E3E0E3E3E0E3E3E1E4E4E1E4E4E2E4E4DBDDDDDBDDDD
DFE3E3E7EBEBEDF1F2DEDFE1C7C3C9BDB9B7816D6E635456513E3E3F2B2D423031493C3F
5F4E4D685B5D7A6C707B6D6F6E5F615345455037343E2E303B292B2D1D2636282F2C2124
37292D32242B33262A2A1E25281C24261E271D111A130C161009141A111D19121C211623
18111B2019222F2633251E25191523251D2B272024282131272531312436403340352D3E
453C44443B41362F36322C33312A3040313B4036383F373A3A3036493B3F433535463839
44312E4225234D2E285F393276594F917275BEACAAC2BEBDEAEFF1E9F0F2E1E6E7DBDBDB
DEDFDFE2E3E4E3E5E6E2E5E5E1E4E4E0E2E3E0E2E3E1E3E3E1E3E3E0E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E0E3E3E1E3E3E0E3E3E0E3E3E1E3E4E1E4E4E1E3E4DBDCDCDBDDDD
E0E4E4E8EDECF2F7F7E7EAECD6D5D9CFCECC9D8D8E8175786E5F5E57474955444555474A
61505066595B7565697466676C5C5F594A4B543E3C47373845323339282E40303537292B
3F3032392A2E3B2D3034262B2F242C322932291D25231B231F1821231B27221B25291F2D
211A26261F2B362C392E282F25202E322937312A2D342C392F2C37362A3A4638413B3340
4A3D444A3E413D32373B31353C2E314533394336364535363F2E324B383A4B37344D3D3C
513B37573A39694C467D5D56937C74AB9396D0C5C3D2D1D2EFF6F8EBF3F5E2E7E8DBDBDB
DDDEDFE1E3E3E3E5E5E2E5E5E1E3E4E0E2E3E0E2E3E1E3E3E1E3E3E0E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E1E3E3E1E3E3E1E3E3DEE0E0DEE1E1
E1E5E5E6EAEAECF0F0E6E9EADDDEE0D9DAD9BAB2B3A7A0A3968C8B7B6F73726464685B5C
65545561535668575A6959596555585E4D505645475142424F3B3B4937394C3A3C443434
47383842303244353740303338303841363E3A2D353A3034342D343029352E2731332A39
2E25342E27373E333E38333A332D3D4139443E3538443A433C36403E34404D3F45453B43
503F4450404147363946383A4A34334A34364735344B3230452D2D4D343255393354423F
624A46745A5A8C7571A08B86B4A6A2C4B8BADAD5D4DBDCDCEAEFF1E8EDEFE2E6E7DEDFDF
DFE0E1E1E2E3E1E4E4E1E4E4E1E3E3E0E3E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E1E3E3E0E3E3E0E3E3E0E2E3E1E3E3
E1E4E4E2E4E5E2E5E5E2E4E5E1E3E4E1E3E3D7D7D8CCCACDBDBAB9A09A9F9185867D7070
6A5A5D5D4E525C4A4C5F4D4D5F4F516451565A4F545D4F4E5B47475A4847594746544240
5143414D39384F40404F3D3D443E4551464D4C40475347484C444A3F3A453C353F403747
3D3445393144473B45444048443D4D514A534C4246554A4F4A424B48404755484B504648
564245574442533C3E5341415A3C375039364D373453312D4C2E2B4F322D5F3D345D4845
745A57927B7CAF9E9CC2BAB7D3D0CFDBDADBE0E2E2E1E3E4E2E5E5E2E5E5E1E3E4E0E3E3
E0E2E3E0E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E3E3E2E5E5E2E4E5
E1E2E3DDDFE0DADBDBDDDFDFE2E6E5E5E8E9ECF1F2E9EAEEDDDEDDC0BFC5AEA5A7948989
77696D63555A5B494A5F4E4C6252556C5B61615A64695C5C6754546B5A5769575364514F
5E514F5B46425C4C4D5E4C4B524D5461555A5E5158675A5960575B4E49534A424C4C4454
4C4053443B4F4E42494E4A525249585F565D584C4F635657574C5252494C5C4E4E5A4E4B
5C44455D47435F43425E494767453E59403A573E3B6039335A3A34593B356F4A406C5854
8A706FAE9B9ECCC2C2DCDEDEEAEFF1EBF3F4E4EAEBE4E7E7DBDBDBDCDDDDDFE0E0E2E5E6
E2E4E5E1E3E3E0E2E3E0E2E3E0E3E3E1E3E3E1E3E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E3E3E2E5E5E2E4E5
E0E2E2DDDEDFDADBDBDDDFDFE3E7E6E6E9EBF0F6F7F0F2F5E8EAEAD2D3D7C3BEBFADA6A6
93898C7F7478746667766967786B6E7B6D736E6A7575686B7161647668687A6966736163
7165666B57556C5C5E6D5B5B625A606D5E626B5B606F605E685D605C5159554A52574B59
5648564F425253444A554C51594C5762555A5C4C4D6655555D4D505949495E4D4C5E4D48
5E4342604743674946654E4B6D4C47664F4868514F76544D755854755C57896B638B7B78
A49191C3B7B9DAD5D6E6EBECEFF6F8EEF8F8E5ECEDE5E8E9DBDBDBDCDDDCE0E1E1E2E5E5
E1E4E4E0E3E3E0E2E3E0E2E3E0E3E3E1E3E3E1E3E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E2E2E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E0E3E3E1E3E4E1E3E4
E0E2E2DFE0E1DEDFE0E0E2E2E3E7E6E5E8E9EBEFF0EBEDEFE6E9E9DBDCDFD2D1D1C6C3C3
B4B0B2A49EA198909199908F988F938D8388807C8781757C7B707780757A8C7D7D817279
887C807D6B6C7D6D737D6C6D73676D776668756267715F5F6B5C5F68585D60515762525C
604E565B49525847495B4C4E5E4C526351525D494865514F624C4B5F48455F4C48614B45
5F44406449446E514A6B534F71545275625C7E6A6991777196807E978885A79490AFA6A5
C0B6B7D2CDCFDFDEDFE6EAEBEAEFF1EAF1F1E5EAEBE4E8E9DEE0E0DFE0E0E0E3E4E1E3E4
E1E3E4E0E3E3E0E3E3E0E3E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E1E1E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E1E3E3E0E3E3
E0E3E3E0E2E3E0E3E3E1E3E4E1E4E4E2E4E5E2E5E5E2E5E5E2E4E5E1E3E4E0E1E2DDDFDF
D6D6D8C9C7CBBEBABDBCB9B8B8B3B79E9A9E928E9A8D838C857F8989838B9E909390838F
9E939A8F7F848E7E878C7C7F85747A816E6E806A6D745F616F5C5F765F626B585C6D595F
6954566851535D4A4A624C4B634D4D634C4A5F4743654D4A664C47674742624B46654A43
62463F684B47765950725853745C5E857570948284AC9A95B6A8A8BAB4B3C4BCBCD2CFCF
D9D8DADFE0E1E1E3E3E2E4E4E2E4E5E2E5E5E1E4E4E1E4E4E0E2E3E0E1E1E1E5E6E1E3E3
E0E3E3E0E3E3E0E3E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E0E1E1E2E2E1E3E3E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E2E3E0E3E3
E1E3E4E2E4E4E2E5E5E1E4E4DFE1E2DEE0E0DBDBDBDADCDCDDDFE0E4E6E5E8ECECEDF2F3
EFF3F3E5E8EADCDDE0D9DAD9D2D1D5B0B0B3A5A2AC9D939F94919D96939EAFA5A9A096A5
B2AAB2A2959BA0929C9D8F9398858B8E7B7A8D77797C686B786467866C6D7A66687C676A
78625E78605D6955546E55526E56526B514E694F4A6C535072564E74514A6C544E70534C
6C514973575483695F7E67617F6C71988C89AA9C9FC3BAB5D0C9CCD5D7D9DBDCDFEBEEEF
EBF1F3E7EDEDE1E5E5DEDEDEDBDADADBDADBDEDEDEDEE0E0E2E4E4E1E3E3E1E5E6E0E2E3
E0E2E3E0E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E0E0E1E1E2E1E3E3E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E2E3E0E3E3
E1E3E4E2E4E4E2E5E5E1E4E4DFE1E2DEE0E0DADBDBDADCDCDDDFE0E5E8E7EAEEEEF0F5F6
F3F8F8EDF0F2E6E8EBE3E6E5DEDEE2C2C4C6B9B8C0B2ACB5ABAAB4ACACB5C1BABFB4AFBC
C4BFC6B6ADB4B3AAB3B1A7ACAFA0A4A59696A392949484888E7F829C8788928384928285
907E7B907C7983727386706F86726F846E6C836F6A85716F8A756E8D706B85726D87716B
85706A8C77769C8982998884998D92B0A9A8BFB7B9D3CFCCDDDBDEE1E7E8E4E9ECF1F7F8
EFF7FAEAF1F1E2E7E8DEE0E0DBDCDCDBDBDCDFDFE0DFE1E1E2E5E6E2E5E6E1E4E4E0E2E3
E0E2E3E0E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E0E1E1E1E2E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3
E1E3E3E1E3E4E1E3E4E1E3E3E0E2E2DFE1E1DEDFE0DEE1E0E0E2E3E5E7E7E7EBEBEBEEEF
ECF0F0E9ECEDE5E7E9E3E6E6E1E2E4D1D4D5CDCDD2C9C6CCC4C6CBC5C6CCD0CFD2C9C8D0
D2D1D5C9C5C9C6C1C9C6C0C4C5BCC0BEB6B6BBB1B4B2A9ACAAA2A5B3A7A9ACA4A6ACA3A6
ABA09FAA9D9CA29699A29394A49695A39395A39795A49998A89C97AA9995A49995A49794
A39792AA9E9FB9AEABB8AFADB8B3B8C8C6C6D0CED0DCDCDBE1E2E4E3E9EAE5E9ECECF1F2
EBF2F3E7EEEEE3E8E9E0E3E4DEE1E1DEE0E0E0E2E3E0E3E3E2E5E5E2E6E7E0E0E0E0E3E3
E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E3E1E3E3
E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E1E1E1E1E2E1E3E4E1E1E2E1E3E3E1E3E3E1E3E3E1E2E2E1E3E4E1E3E3E1E3E3E1E3E4
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E0E3E3E0E3E3
E0E3E3E1E3E3E1E3E3E0E3E3E0E2E3E0E2E3E0E3E3E1E3E3E1E3E4E2E4E4E2E4E5E2E5E5
E2E5E5E2E4E5E2E4E4E1E4E4E1E3E4E0E2E2DFE1E2DEDFE1DDDFE1DCDEDFDEE0E1DDDEE2
DFE0E2DADADCD8D7DDD8D7D9D9D7D9D6D3D4D2CED2CFCCCFC5C4C7C9C5C8C5C4C7C4C2C5
C5C1C2C2BDBFC0B9BFBDB6BAC1B9BBC2B8BEC3BFBFC4C0C0C4C1C0C5C0BFC3BEBCC0BCBB
C1BCBAC9C5C8D5D2D2D6D5D5D7D7DADFE1E2E0E2E3E2E5E6E2E5E6E2E6E7E2E5E6E2E7E7
E3E7E7E2E6E7E2E5E6E1E4E5E1E4E4E1E2E3E1E4E4E1E3E4E1E3E4E2E7E8DFDDDBE0E3E3
E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3
E1E4E4E1E3E3E1E3E3E1E3E4E1E3E3E1E3E3E1E3E3E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E2E3E1E3E3E1E3E3E1E3E4E1E3E3E1E3E3E1E3E3
E1E1E1E1E2E2E1E3E4E1E1E2E1E3E3E1E3E3E1E3E3E1E2E2E1E3E4E1E3E3E1E3E3E1E3E4
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E0E3E3E0E2E3E0E2E3E0E3E3E1E3E4E1E4E4E2E5E6E2E5E6E1E4E4DFE1E2DDDFDFDBDCDC
DADBDBDBDDDDDEE0DFDEE0E1E0E3E2E9EBEBEBEEEDEDF1EFEEF1EFEDEDEBE7EAE8EAECE9
E7E8E5E6E7E6E4E4E7E5E6E5E8E8E9E7E7E8E2E2E5E4E5E7DBDCDFDADBDED9DBDDD7D9DB
D9D9DBD6D4D8D8D3D9D3CFD4D7D2D6DAD3DADCDBDBDBDBDBDADBDBDADBDADAD8D6D5D6D5
D8D6D4DEDEE1E7E7E9EAECECEBECECEDEEEEE8EAE9E3E4E4DFDFDEDDDDDBDDDBD9D8D7D6
DAD7D6DCDAD9DFDCDCDEDFDEE0E0DEE1DFDEDFDFDEDFDEDDDEDDDCDEE0E0DCD7D4E1E3E3
E1E3E3E1E3E3E0E3E3E0E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3
E1E4E4E1E3E3E1E3E3E1E3E4E1E3E3E1E3E3E1E3E3E1E3E4E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E2E3E1E3E3E1E3E3E1E3E4E1E3E3E1E3E3E1E3E3
E1E1E2E1E2E2E1E3E3E1E1E2E1E2E2E1E3E3E1E3E3E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E0E3E3E0E2E3E0E2E3E0E3E3E1E3E4E1E4E4E2E5E5E2E4E5E1E3E4DEE0E1DDDEDFDADCDC
D9DBDBDCDDDDDEE0E0DFE1E2E1E4E3EBEDEDEDF1EFEFF4F1F1F3F1EFECE8E8E3DCECE7DF
E8E3DCE9E3DEE7E2DFE9E4E0EBE7E4EBE7E4E7E3E2EAE7E4E3E0DFE1DEDEE1DEDEDEDCDB
E1DCD9DED9D9E0D7D8DCD4D3DED6D6DFD6D7E2DCD7E1DBD6DFDAD6DED9D4DFD6D0DBD4D0
DCD3CEE0D9D7E6DEDBE8E1DDE8E0DCE8E0DBE4DCD6DED4D0DAD0CAD9CCC7D8CBC5D3C6C0
D3C6C0D5C8C3D8CAC5D8CDC8D9CEC8DACDC8D8CDC8D8CDC7D7CCC5D2C9C4D7CCC7E1E3E3
E1E3E3E1E3E3E0E3E3E0E3E3E1E3E3E1E3E3E1E2E2E1E3E3E1E3E3E1E3E3E1E1E2E1E3E3
E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
E1E3E3E1E1E2E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3E1E3E3
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.535147 0.97619 0.988662 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -53 0 ]
[.5 1.0125 53 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Decomposed) show
129.000 12.813 moveto
(18) show
141.000 12.813 moveto
(oder) show
165.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
E7DCDDE7DDDEE7DCDDE7DCDDE7DCDDE7DEDEE7DEDFE7DCDDE7DDDDE7DEDFE7DEDEE7DDDD
E7DEDEE7DEDFE7DDDEE7DDDEE7DEDEE7DCDDE7DDDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDF
E7DEDEE6DEDEE6DDDEE7DEDEE7DEDFE7DEDFE7DDDEE7DEDFE7DEDEE5DCDDE5DBDCE4DADA
E4DADAE5DCDCE7DEDEE7DEDFE8E0E0EDE5E6EFE9E7EEEAE9F1E8E6EFDCD6ECD0C3F0D4C6
EDD2C5EED2C8EDD1CAEDD4CDEED7D0EED6D0ECD3CEEDD7D0EAD4CEE9D1CEE9D2CEE5D0CA
E7CFC6E5CDC8E4CAC3E3C8C0E2C8C2E1C5C0E5C9BEE5C7BCE1C5BBE0C4B8E1C0B4E0BFB5
DFBDB1E0BFB4E3C0B5E3C0B6E3C0B4E4BEB3E2BDB1DEB7ACDCB8AADDB3A7DCB4A7D9AFA3
D8AFA2D9AFA3D8AFA2D9B0A5D8B0A3DBAFA4D7B0A4D8B0A3D7B1A1CDA699D9BBB3E7DEDF
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDDE7DEDEE7DEDEE7DEDFE7DCDDE7DDDE
E7DCDDE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DCDCE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DEDE
E7DCDDE7DEDEE7DBDCE7DDDEE7DCDCE7DEDEE7DEDFE7DCDDE7DCDDE7DEDFE7DEDEE7DCDD
E7DEDEE7DEDFE7DDDEE7DDDEE7DEDEE7DCDDE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDDE7DDDEE6DEDEE6DDDEE6DDDEE6DDDE
E6DDDEE7DEDFE7DEDFE7DEDFE7DEDFE9E1E2EAE2E3E9E1E2E8DEDEE6CEC8E6BFACE8C4B0
E8C4B1E8C3B3E8C4B6E8C7BCE9C8BCE8C7BDE8C6BBE8C9BCE8C9BEE9C8BEE8C8BEE4C6BB
E5C4B3E4C4B9E0BFAFE2BEAEDEBDB0DBB8A9DFB8A5DEB6A3DBB2A1D9B09DD7AE9BDAAC9C
D5A996D4A793D4A490D2A28FD1A18ED29F8CD3A18FD19E8BD2A28ED49D8BD3A18ED39C8A
D19D8BD09C89CE9A87CE9B88CC9985CF9987CB9A87CC9A86CC9C85BB8B77D3B0A6E7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDDE7DEDEE7DEDEE7DEDFE7DCDDE7DDDE
E7DBDCE7DEDEE7DDDEE7DCDDE7DEDEE7DEDEE7DEDEE7DCDDE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DBDCE7DEDEE7DEDEE7DCDDE7DEDEE7DEDEE7DEDE
E7DCDDE7DEDFE7DBDCE7DDDEE7DBDCE7DEDEE7DEDFE7DDDDE7DBDCE7DEDFE7DEDEE7DBDC
E7DEDEE7DEDFE7DCDDE7DCDDE7DEDEE7DCDDE7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDFE7DEDFE7DEDFE6DDDEE6DDDEE6DBDCE6DCDDE7DEDFE7DEDFE7DFE0E8E0E1
E8E0E1E8DFE1E7DEDFE7DEDEE6DDDEE4DCDDE4DBDEE3D9DBE0D6D8DEC1BAE0B29AE1B79F
E2B8A3E2B8A3E3B9A7E3BCADE3BBACE2BBACE3BBABE2BDABE5C0B0E6BFAFE6BEAFE1BCAD
E1BAA4E1BBAADCB59FE0B49ED9B29FD5AC95D9A98FD6A78ED3A18BD19F87CC9D85D29C86
CC9880C99479C48F74C18B73BF8970BF886FC48C74C48B72C79078CA8D76CA927ACC8F78
C99078C98D75C48B72C58B73C18970C48971C08A72C18A70C28C6FB07C64D0ACA1E7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DBDCE7DEDEE7DEDEE7DEDFE7DDDDE7DCDD
E7DADBE7DEDEE7DDDEE7DCDCE7DEDEE7DEDEE7DEDEE7DCDCE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DADBE7DEDEE7DEDEE7DCDCE7DEDEE7DDDEE7DEDE
E7DCDDE7DEDFE7DCDCE7DDDEE7DBDBE7DEDFE7DEDFE7DDDEE7DCDCE7DEDEE7DEDEE7DCDC
E7DEDEE7DEDEE7DCDDE7DCDDE7DEDEE7DCDDE7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDFE7DEDFE7DEDFE6DDDEE6DDDEE6DBDCE6DCDDE7DEDEE7DEDFE7DFE0E8E0E1
E8E0E1E7DFE0E7DEDFE7DEDFE6DDDEE3D9DAE2D8DAE2D7D9E0D7DADDBEB5DFB097E0B59D
E2B7A2E2B7A1E3B7A4E2BBABE2B8A8E2B8A8E3BAA9E2BAA8E5BDACE5BBA9E6BCAAE0B9A8
DFB7A3E1B8A7DCB39EE1B19BD8AF9AD6A891D9A38BD5A188D19B84CF9981CB977FCF957F
CA937BC99176C38C72C08971BD846CBA836CC0866DC1876EC28A71C58970C68E75CA8C73
C68B73C78970C2876DC3886FC0876DC1856DBE866EBE876CBE8669B78670D5B6AEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDDE7DEDEE7DEDFE7DEDEE7DDDEE7DCDD
E7DADBE7DEDEE7DEDEE7DCDDE7DEDEE7DEDEE7DEDEE7DCDDE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDFE7DBDCE7DEDEE7DEDEE7DCDDE7DEDEE7DDDEE7DEDE
E7DCDDE7DEDFE7DDDEE7DDDDE7DADBE7DEDFE7DDDEE7DDDEE7DCDDE7DEDEE7DEDEE7DCDD
E7DEDEE7DDDEE7DCDDE7DCDDE7DEDEE7DDDEE7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE6DEDEE6DCDDE6DCDDE6DEDEE7DEDFE7DEDFE7DEDF
E7DEDFE7DEDFE7DEDFE7DEDFE6DDDFE3D9D9E2D6D7E3D8D9E4DCDFE1BEB3E2B59DE4B9A3
E5BAA7E5BBA6E5BBA9E5BEAFE3BBABE4BBAAE5BDADE5BDACE6BDACE5BBA9E6BCAAE0B9A9
DEB9A8E2B8A9DFB5A3E3B39FDAAF9BDBA996DDA490D7A28BD39B87D29A85CE9782CF9480
CE947FCF967FCB927CC8937DC58974BE8975C28971C38C75C28A74C48C74C58F78C98F76
C58C74C88A72C48A71C58B73C58B73C28971C18A73C08A71BF886CC89D8CDEC7C3E7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDFE7DEDEE7DDDEE7DCDD
E7DBDCE7DEDEE7DEDFE7DCDDE7DEDEE7DEDEE7DEDEE7DCDDE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDFE7DCDDE7DEDEE7DEDEE7DCDDE7DEDEE7DCDDE7DEDE
E7DCDDE7DEDFE7DEDFE7DCDDE7DADBE7DEDFE7DCDDE7DEDEE7DDDEE7DDDEE7DEDEE7DDDE
E7DEDEE7DDDDE7DCDDE7DCDDE7DEDEE7DEDEE7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DCDDE7DEDEE7DEDEE7DEDFE7DEDF
E6DDDEE6DDDEE7DFE0E8E0E1E7DFE0E2D7D8E0D2D2E2D6D6E7E1E2E4BFB1E5BAA3E7BEAA
E7BFAEE7C0ADE6BEAFE7C2B3E5BDAEE6BEADE7C0B2E7BFB0E5BDADE3BAA8E5BCAADFB9A9
DDBAADE1B8AAE0B6A9E3B3A3DBAF9CDFA99BDFA495D8A28ED59B89D49B89D29884CF9482
D19684D59B8AD29A88D09D8BCD8F7FC29080C68E78C7927FC48C79C5917AC6937DCB957C
C78F78CB8D77C78F77C8917ACA927CC48F78C5907AC38F79C28C72D7B8AEE5DADAE7DEDE
E7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDFE7DEDEE7DEDEE7DDDE
E7DCDDE7DEDEE7DEDFE7DDDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDFE7DDDEE7DEDEE7DEDEE7DDDEE7DEDEE7DCDDE7DEDE
E7DCDDE7DEDFE7DFE0E7DCDDE7DADBE7DEDFE7DCDCE7DEDFE7DEDFE7DDDEE7DEDEE7DEDF
E7DEDEE7DCDDE7DDDDE7DDDDE7DEDEE7DEDFE7DDDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDFE7DEDFE7DDDDE7DEDEE6DDDEE6DDDEE6DDDE
E6DDDEE6DDDEE7DFE0E8E0E2E7DFE0E3D8D9E1D3D3E3D7D7E9E3E4E6BFAFE7BFAAE9C2B0
E8C2B4E9C3B2E7C1B3E8C4B6E6BFB0E7C0AFE8C3B6E8C0B3E5BDAEE2BAA9E5BDACDFBAAB
DDBCB2E2B8ACE2B8AEE4B5A7DDB19FE3ACA1E2A69CDAA493D79E8ED89E8FD59B89D09586
D5988ADBA193D8A193D7A696D49689C7968ACA937FCB9788C78F7EC79580C79683CC9A82
C8937DCD917DCA937ECB9580CF9883C6957EC99581C79480C7927DE1D0CCEAE9ECE7DEDE
E7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DFE0E7DEDEE7DEDFE7DDDEE7DEDFE7DDDE
E7DCDDE7DEDEE7DEDFE7DDDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDFE7DEDFE7DEDEE7DEDEE7DDDEE7DEDEE7DCDDE7DEDE
E7DCDDE7DEDEE7DEDFE7DDDEE7DBDCE7DEDFE7DCDDE7DEDFE7DEDFE7DEDEE7DEDEE7DEDF
E7DEDEE7DCDDE7DDDEE7DDDEE7DEDEE7DEDFE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDFE7DEDFE7DDDEE7DEDEE6DDDEE6DDDEE6DDDE
E6DDDEE6DDDEE6DDDEE6DEDEE7DFDFE8E0E1E8E0E0E8DFE0E8E0E0E6BDABE7C0AAE8C2AF
E8C1B2E8C1AFE7C0B2E8C2B4E5BEAEE6BFAFE7C2B5E8C0B2E5BDAFE3BCABE5BFAEE1BDAE
DFBDB4E3BAAEE4BBB1E5B8ABDFB6A5E5B2A8E4ACA2DCAA9ADBA394DCA594D8A08ED39B8B
D89C8FDDA396DBA294DAA698D7998CCC978BCD9482CD9788C98F7FC79480C99683CD9A83
C99581CD937FCB9580CC9681CE9782C8967FC89480C99581CD9A88E5DAD8EAEAEEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DDDEE7DEDFE7DDDE
E7DDDEE7DEDEE7DDDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DCDDE7DEDE
E7DDDEE7DDDEE7DDDEE7DDDEE7DCDDE7DDDEE7DCDDE7DEDFE7DEDFE7DEDFE7DEDEE7DEDF
E7DEDEE7DDDDE7DDDEE7DDDEE7DEDEE7DEDFE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDFE7DDDEE7DEDFE6DEDEE6DDDEE6DDDE
E7DEDFE7DEDFE5DBDCE4DADAE7DDDDEEE9EAEFF0F0ECE8EAE7DADAE4BBA6E7BFA9E7BFAB
E6BFACE5BDAAE6BEAEE6BFAFE4BCAAE6BDADE7C0B3E7BFB0E5BEAFE4BEAEE5C0B0E3C0B2
E2BFB4E4BEB1E5BDB2E6BDAFE2BCACE6BAAFE4B4A8DFB0A0E0AB9BE0AC99DBA793D8A292
DCA093DDA494DBA292DBA393D99C8CCF9588D09382CF9484CB8F7EC8907DCA9581CD9882
C89783CB947FCB957FCC9480CC937EC8947DC5917CCA957FD3A294E6DCDBE9E5E8E7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DCDDE7DEDFE7DDDE
E7DDDEE7DEDEE7DDDDE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DDDEE7DEDE
E7DDDEE7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DDDEE7DEDE
E7DEDEE7DDDEE7DCDDE7DEDFE7DEDEE7DDDEE7DDDEE7DEDFE7DEDFE7DEDFE7DEDEE7DEDF
E7DEDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDFE6DEDEE6DDDEE6DDDE
E8DFE0E8E0E1E3D8D9E0D4D4E5D9D9F3F1F2F6FFFFF1F1F4E5D4D3E2B9A2E7BEA8E6BEA7
E5BDA8E3BAA6E5BDABE4BCABE4BBA7E5BDACE7BFB1E6BEAEE6BFB1E5C2B3E6C3B4E6C5B7
E6C3B5E6C2B4E6C1B4E7C3B4E5C3B4E7C4B7E6BDAFE3B8A8E4B4A3E5B5A0DEAF9ADDAA9A
E0A698DEA694DDA391DCA090DB9F8DD49586D39484D19281CE907EC98E7CCC9480CD9682
C99985CA957FCB9680CB937FC98F79CA947DC38F78CB957ED9ACA2E6DDDDE7E0E1E7DEDF
E7DEDEE6DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DCDDE7DEDEE7DEDEE7DCDDE7DEDFE7DDDE
E7DEDEE7DEDEE7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDE
E7DDDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DDDDE7DBDCE7DEDFE7DEDFE7DCDDE7DDDEE7DEDFE7DDDEE7DEDFE7DEDEE7DDDE
E7DEDEE7DDDEE7DEDFE7DEDFE7DEDEE7DDDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDFE7DEDFE6DEDEE6DDDEE7DEDE
E8E0E1E8E0E1E3D8D9DFD3D3E4D8D7F3F0F1F5FEFFEDECEEE4CDCAE2B8A0E6BEA8E5BDA6
E4BCA5E1B8A4E4BCA9E4BBA8E4BBA6E5BCADE6BEB0E6BEAEE6C1B3E7C4B6E6C5B7E8C8BA
E9C5B6E8C5B6E8C4B5E7C7B8E7C9BBE7CBBCE6C3B4E5BFAEE8BBAAE8BDA6E0B7A0E1B2A1
E3AB9CDFA895DEA490DD9F8EDCA28FD89685D69586D3917FD1917FCB8D7BCE947FCD9481
C99986C99680CB9680CB937EC88E77CB947DC38E77CC957EDEB8B2E7DDDEE5DADBE7DEDF
E7DEDEE6DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DBDCE7DEDEE7DDDEE7DCDDE7DEDEE7DDDE
E7DEDFE7DEDEE7DBDCE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDDE7DEDE
E7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDFE7DCDCE7DCDCE7DEDFE7DEDFE7DCDDE7DEDFE7DEDEE7DDDEE7DEDFE7DEDEE7DDDE
E7DEDEE7DDDEE7DEDFE7DEDFE7DEDEE7DDDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDFE7DEDEE7DEDEE7DEDFE7DEDF
E6DEDEE7DEDFE7DFE0E7DEDFE6DEDEE7DEDFE4DBDBD8C8C8E2C5BDE2B9A2E6BEAAE5BDA7
E4BCA7E2BAA7E5BCAAE4BCAAE5BDA9E5BDAFE6BEB0E6BFAFE7C2B4E7C5B8E7C4B6E9C7B9
E9C4B4E8C3B5E8C5B6E7C7B9E8C9BBE7CBBBE6C4B3E6C1B1E8BFADE8BFA8E2BAA3E3B5A3
E4AC9DDFA995DFA591DE9F8FDEA491DA9886D79786D4927FD39380CF8F7ECE947FCE9380
C99783C99780CA957FCA947FC9917BCB957FC5907ACD9781E3C6C4E7DFE1E5D9D9E7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDCE7DEDEE7DDDEE7DCDDE7DEDEE7DDDD
E7DEDFE7DEDEE7DCDCE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDDE7DEDE
E7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDFE7DBDBE7DCDDE7DDDEE7DEDFE7DCDDE7DEDFE7DDDEE7DEDEE7DDDEE7DEDEE7DEDE
E7DEDFE7DCDDE7DEDFE7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDFE6DEDEE7DEDFE7DEDFE7DEDF
E4DBDBE5DBDBECE7E8F0ECEEE9E4E6D4C4C5C7ABAAB69B97E1BDB0E4BBA6E5BFABE5BDAA
E5BEABE4BEADE6BDACE5BEAEE6BFAEE6BFB1E6BEB0E7BFB0E7C3B5E7C5B7E7C2B4E8C3B6
E8C1B2E7C0B1E7C4B6E7C5B8E8C5B8E7C7B6E6C1B0E6C1B0E7BFADE6BEA8E3BBA3E4B6A3
E4AC9BE0AA96DFA692DFA190DFA493D99A89D79986D69581D49681D29381CE957FCD937F
C9937FC99680C7947ECA9580CB9680CB9782CA957FCD9A84E5D5D6E8E1E3E6DADAE7DDDE
E7DEDFE7DEDFE7DEDEE7DEDFE7DEDFE7DEDEE7DCDDE7DEDEE7DCDDE7DDDEE7DEDEE7DDDD
E7DEDFE7DEDEE7DCDDE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DCDDE7DEDE
E7DCDDE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDFE7DEDE
E7DEDFE7DADAE7DDDEE7DDDEE7DDDEE7DDDEE7DEDFE7DDDEE7DEDFE7DDDDE7DEDEE7DEDE
E7DEDFE7DCDDE7DEDFE7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDFE7DEDFE6DEDEE6DDDEE7DEDFE8DFE0E7DFE0
E2D7D7E2D6D5F0EDEFF9F9FBEBE9EEBFABAAA47F7C8F7069DFB5A4E5BDAAE5BFADE5BDAD
E6BFB0E6C2B3E7BFAFE6C0B2E7C1B2E7C1B3E7BFB1E7C1B2E7C4B6E7C4B6E7C0B2E7C0B2
E7BEAFE6BDADE7C2B5E6C3B6E7C0B3E6C1AFE5BBAAE6BDADE6BDABE3BAA6E4B9A3E4B4A0
E4AA98E0AA95DFA592DFA291E0A395D99C8AD69B85D79882D59881D49784CD957FCD927D
C88F79C99580C5927CC99680CC9A85CA9885CE9884CD9B87E6E1E3E7E0E1E6DADAE6DCDD
E7DEDFE7DEDFE7DEDFE7DEDFE7DEDFE6DEDEE6DDDEE7DEDEE7DCDDE7DEDEE7DEDEE7DCDD
E7DEDFE7DEDEE7DDDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DDDEE7DEDE
E7DCDDE7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DEDFE7DEDE
E7DDDEE7D9DAE7DEDEE7DCDDE7DDDDE7DDDEE7DEDFE7DDDEE7DEDFE7DCDDE7DEDEE7DEDF
E7DEDFE7DCDDE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDFE7DEDFE6DDDEE6DDDEE7DEDFE8DFE0E7DFE0
E1D6D7E1D5D4F0EDEEF9F8FAE7E2E6AE949288615C76584FDEB09CE6BFADE4BFAEE5BDAF
E6C0B3E7C5B8E7BFB1E7C1B5E7C3B5E7C2B5E7C0B1E7C1B3E7C4B6E7C3B5E7BFB0E6BEB0
E6BDAEE5BBABE6C1B4E6C0B4E6BCAEE6BCA9E5B6A5E5B9A9E4BAA7E1B6A3E4B6A0E3B19C
E3A895DFA994DEA592DEA390DFA294D79D8BD59C83D69983D59881D59A85CD947FCD917C
C88C75C9947EC4907AC89680CD9D87CA9986D19B87CC9C89E6E7E9E7DEDFE6DBDBE7DCDD
E7DEDFE7DEDFE7DEDFE7DEDFE7DEDFE6DEDEE6DDDEE7DEDEE7DCDDE7DEDFE7DEDFE7DCDD
E7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDE
E7DDDDE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDE
E7DDDEE7DADBE7DEDFE7DCDDE7DCDDE7DDDEE7DDDEE7DCDDE7DEDFE7DCDDE7DEDEE7DEDF
E7DEDEE7DCDDE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE6DEDEE7DEDFE7DEDF
E7DFE0E6DDDEE7DEDFE4DADBD3C0C0A586818D625B87655ADFB29EE7BFAFE5BFAFE6BEB0
E7C0B4E7C5B8E7BFB2E7C1B5E7C3B5E7C2B5E7BFB1E7BEB1E7C1B4E6C2B4E7BFB1E6C0B2
E6C1B1E6BFAFE6C3B6E7C2B4E6BDAEE6BEAAE4B6A5E3B6A4E2B7A3E0B3A0E1B29CE1AF99
E0A995DDAA94DCA892DBA58FDCA391D59E89D39B82D59983D59781D49985CE957FCD917B
C98C75C7937CC4907AC7947DCC9A84CA9784D19B87CC9D8AE5E1E2E6DDDEE7DFE0E7DEDF
E7DEDFE7DEDEE7DEDFE7DEDEE7DEDEE7DEDFE7DEDFE7DEDEE7DCDDE7DEDFE7DEDFE7DDDE
E7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDE
E7DDDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDE
E7DEDEE7DBDCE7DEDFE7DCDDE7DCDDE7DCDDE7DDDDE7DCDDE7DEDEE7DBDCE7DEDEE7DEDF
E7DEDEE7DCDDE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE6DDDEE7DEDEE7DEDFE7DEDFE6DDDEE5DCDDE7DCDD
EEE9EBEDE9EBD9C9C9C5B0AFB39591A37F76A4746BAD8678E3B7A5E7BFAFE6BFAFE6BFB1
E7C0B3E7C4B7E7BFB2E7C1B3E7C2B3E7C2B4E6BDB1E6BBADE5BEB0E6C2B3E6C0B3E6C5B7
E6C6B6E8C4B4E7C6B8E7C4B4E5C0AEE7C1ADE3B7A7E0B29FE0B29EDFB19DDEAC97DEAB95
DEAA96DBAA93DAAA92D7A68DD7A28CD39D86D19981D39981D4957FD19783CF947ECE917B
CB8E77C69279C79179C7917AC9957ECB9581CF9A85CD9D8AE3D4D3E5DBDBE8E3E6E7E0E2
E6DDDEE6DDDDE7DEDFE6DDDEE6DDDEE7DEDFE7DEDFE7DEDFE7DDDEE7DEDFE7DEDEE7DDDE
E7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DDDEE7DEDE
E7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DDDEE7DEDEE7DCDDE7DBDCE7DCDDE7DCDCE7DBDCE7DDDEE7DBDCE7DEDEE7DEDE
E7DDDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE6DEDEE6DDDEE7DEDEE7DEDFE7DFE0E5DCDEE3D9DAE4D7D7
F4F2F3F2F3F7CBB5B3A188858F6D65A47A6DBE8A7FD4AC9BE6BEADE7BEAFE6BFAFE7BFB2
E7C0B2E6C2B5E6BEB2E6BFB0E6C0B1E7C1B2E6BBB0E5B7A9E4BAACE6C0B2E6C0B4E6C8BA
E6CBBBE9C7B8E7C9BAE8C5B4E5C2AFE8C4B0E2B8A8DEAE99DEAE99DDAD99DAA792DAA791
DAAB95D7A991D7AB91D3A58AD2A187D09A82CF957ED1977FD3937ECE9681D0957DCE907B
CC9079C49176C9917AC78F77C79178CC937DCE9883CD9C8AE0C6C1E4D9D8E8E7EBE7E2E3
E6DBDCE5DCDCE7DEDFE6DDDEE6DDDEE7DEDFE7DEDFE7DEDFE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DDDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDFE7DEDEE7DCDDE7DBDCE7DCDDE7DBDCE7DBDCE7DDDEE7DBDCE7DEDEE7DEDE
E7DDDEE7DDDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE6DEDEE6DDDEE7DEDEE7DEDFE8E0E0E5DDDEE2D9DAE3D5D6
F4F1F2F1F1F5BCA19D886E6979574DAB7D6DD5A193F2CBB8E8C3B4E7BEAFE7BFAFE7C0B2
E7C0B1E6C0B3E6BEB1E6BEADE6BFAEE7C1B0E6BBB0E4B6A8E4B9ABE6BFB0E5C1B5E6C9BB
E6CCBCE9C8BAE7C7B8E8C2B1E4BEABE8BFADE1B1A3DBA491DCA491DCA391D79D8BD79E8A
D8A491D6A38DD6A78ED1A186CF9D82CF977ECD937DCF957ED2917CCB937ED0947CCE907B
CD917BC49074CB917AC88D75C68D74CC917BCC9680CC9B88DBB7ADE2D1CEE8E5E8E6E1E3
E6DBDBE5DBDCE7DEDFE6DDDEE6DDDEE7DEDFE7DEDFE7DEDFE7DEDFE7DDDEE7DEDEE7DEDF
E7DEDFE7DEDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DDDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDFE7DEDFE7DEDEE7DDDEE7DCDCE7DCDDE7DBDCE7DBDCE7DEDEE7DCDDE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEE7DEDFE7DEDFE7DEDFE7DEDEE6DEDEE6DDDEE7DEDFE7DFDFE7DEDF
E6DDDEE1D3D4B190898F726A8D675ABC8D7BE0AFA0F7D1BEE9C3B3E7BFB0E7BFB0E7C0B2
E7BFB1E6C0B2E6BFB1E6BFACE6BFACE7C1AEE7C0B1E7BFAFE7BEB0E7BFB1E6C3B5E7C4B7
E7C3B6E6C4B8E7BDB0E7B7A7E2AB9CE6A89BDF9A8FD99081DA9082D88D7FD68E80D58D7D
D89081D79381D89885D59781D1977FD3947ECC947FCD967FCE917BC8907ACD9079CD917B
CD917BC59075CC9179C98E75C68C73CC907ACC937ECA9884D5A99CDEC1B9E6D7D6E7DEDF
E7DEDFE7DEDFE7DEDFE7DEDFE7DEDFE7DEDFE7DEDEE7DEDEE7DEDFE7DDDEE7DEDEE7DDDE
E7DEDFE7DEDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDDE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDFE7DDDEE7DEDFE7DDDEE7DCDDE7DCDDE7DBDCE7DCDDE7DEDFE7DCDDE7DEDFE7DEDE
E7DEDFE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEE7DEDFE7DEDFE7DFDFE6DEDFE6DCDDE5DBDCEAE0E0EDE5E6EAE9EA
D1C1C1C6ACA8A98479A8877BB48B7CD0A392E4B8A8F0C9B6E8C1AEE7C0B2E7BFB0E7C0B2
E6BFB2E7C1B1E7BFB0E7BFABE6BFABE7C0ABE7C5B0EACBB9EAC5B7E8BFB3E8C4B4E7BDB0
E7B7ACE2BDB3E5AFA4E4A89BDE9589E08D83D87F74D67A6ED67C71D17568D67F74D37A6D
D5786DD77F72DB8578DB8A7BD4907DD7917ECB9681CB9780CB9279C58C75C98C76CC917B
CD917AC89077CC9079CB8F78C78D74CC907ACB907BC8947FCF9E8DD8ADA0E2C3BDE6D8D8
E7E1E3E9E1E2E7DEDEE7DFDFE7DFDFE6DDDEE6DCDEE6DDDEE7DEDFE7DEDEE7DEDEE7DDDD
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDDE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDFE7DCDDE7DEDFE7DEDFE7DDDEE7DCDDE7DCDCE7DCDDE7DEDFE7DDDEE7DEDFE7DEDE
E7DEDFE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDE
E7DEDEE7DEDFE7DEDFE6DEDEE7DEDFE8E0E1E7DEDFE5DBDDE3D7D8EBDFDEF0E8E9EDF2F3
BAA5A4A7867FA37A6BC49F8EDBB3A3E4BBABE7C1B1E8BFAEE7BFAAE7C1B3E7BFB1E7C0B2
E6BEB1E7C0AEE7BFADE7BEA9E6BDA7E6BDA6E7C7AEEBD4C0EECBBDE8BFB3E9C5B2E7B5A8
E7AAA2DEB6AEE3A398E09B8FD88177D8766CCF6759D1675BD0695FC86152D67168D06B5E
D26457D66E62DC756BE07E73D8887ADC8D7EC99682C99780C69176C28770C58773CB917B
CC907ACB917ACD8F79CD917BC98F76CC907BCB8E79C5907BC9947ECF9A87DBB0A3E6D1D0
E8E3E6EBE3E4E6DDDDE7DFDFE7DFE0E5DBDDE5DBDDE6DDDEE7DEDFE7DEDEE7DEDEE7DCDD
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DCDDE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DBDCE7DEDEE7DEDFE7DDDEE7DCDDE7DCDDE7DDDEE7DEDFE7DEDFE7DEDFE7DEDE
E7DEDFE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDE
E7DEDEE7DEDFE7DEDFE6DEDEE7DEDFE8E0E1E7DFE0E5DBDDE3D7D8EADEDDEEE4E6E6E7E9
A68B89926F65A57967DCB6A0F7D4C3F1CEBEE9C6B5E1B7A6E6BDA7E7C2B4E6BFB1E6C0B2
E6BEB0E7BFACE6BCA9E6BAA4E5B9A2E6B8A1E7C5AAEBD3BFEECBBDE8BCB1E9BFADE7ADA1
E5A099DBACA6E09A8FDC9187D4776ED26B62C95D4CD06156CD6157C25748D66C64CE6357
CC5848D36256D8685EDF7169D77E74DA8478C7907EC7927DC48F74C1866EC28571CA917A
CC8F79CD917CCD907ACF937ECB9179CD907CCC8C77C48E78C58D75C88C74D4A08EE4C8C3
E8E0E2EAE1E3E6DCDDE7DFDFE7DFE0E5DBDCE4DBDDE6DDDEE7DEDEE7DEDFE7DEDEE7DCDC
E7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DCDDE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DCDDE7DEDEE7DEDFE7DDDEE7DCDCE7DDDDE7DDDDE7DDDEE7DEDFE7DEDFE7DEDE
E7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DFE0E7DFE0E7DFE0E7DEE0E1D5D8C9B6B6
9979759E796CB68975E5BEA7FBD9C7F3D1BFE8C4B2E0B4A2E6BDA9E7C1B4E6BFB1E6C0B2
E7BDADE7BDA9E4B6A1E1AE97E2B099E5B49DE7BAA5E7BDB0E7BDAFE6B3A8E4ADA1E5A49A
E49A95DA9C9ADD9890DB8F86D57F79D67975CF6B61D6716DD26A61C46056D67670CD6860
C75C4FCB6156C96156CE655CCB7267CB7064C47E70C68673C68B72C58D72C48B71C99177
CC8E77CE917CCE917CD19681CC927BCE927DCC8C76C58E78C58C73C78A71D09984DFBAB1
E5D2CFE4D9DCE5DBDEE7DEDFE7DEDFE7DEDEE7DEDFE7DEDFE7DDDEE7DEDFE7DEDEE7DCDD
E7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DDDDE7DEDEE7DDDEE7DDDEE7DBDCE7DDDEE7DCDDE7DDDDE7DDDEE7DEDEE7DEDE
E7DDDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDF
E7DEDEE7DEDEE7DEDEE7DEDFE6DDDEE4DADBE7DEDFEAE3E3ECE8E9E1DDE0CDBFC39A7A77
936D67BB9384CCA08CE6BEA9F2CDBCEFCAB6E7BEAAE3B5A1E6BFADE7C1B3E6BEB1E7C1B2
E7BDAAE7BAA5E1AE98DBA087DDA68EE3AE99E5AA9DDD9E97DCAA9CE2A89CDD9893E39D94
E29894D98D8CDB9A95DC928AD8918FDC9596D78784DC8F8FD87E75C87670D48882CD7672
C26A5FC2655EB95F53B75A50BA6559B35A4DBE695BC47766CA8570CB9779C79273C99172
CC8B75CE907BCE947FD39A84CE947DCF957DCC8D77C8907AC78E76CA8D75CE9782D7AB9C
DFBFB5DCCED1E4DADEE5DBDDE5DBDCE9E1E1E9E2E1E8DFDFE6DDDEE7DEDEE7DEDEE7DDDE
E7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DDDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DDDEE7DEDEE7DDDEE7DDDEE7DBDCE7DEDEE7DCDCE7DCDDE7DDDEE7DDDEE7DEDE
E7DCDDE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDF
E7DEDFE6DDDEE7DEDEE7DEDFE5DCDEE0D5D5E6DADBECE4E3F0EEEFD9D7DDB9A9AD61443E
90655DD8B19FE2BAA6E6BFAAE8C1B0E9C1ACE3B5A0E4B49EE6C0B0E7C0B2E6BEB0E7C2B2
E8BCA5E6B6A1DDA58ED49379D89C84E1A996E39B96D0837ECF988ADE9E91D48585E0968F
E19794D87F7ED89E9BDC9690D9A7A4DDB5B5DAA8A6DCB3B0DC9688CB8F89D29D93CD8783
BE796EBA6B65A95E50A15146A95A4C9A4738B55646C16A58CE7E6DCF9F7ECA9973C78F6D
CC8872CD8F7ACF9681D59E87D0977FD1987FCD8E78CB927CCA927BCE927CCE9780CF9C88
D7AB9BD3C2C5E3D7DEE4D8DBE3D7D9EBE4E3ECE5E3E8E0DFE6DDDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DEDFE7DEDEE7DCDDE7DDDDE7DBDCE7DEDFE7DBDCE7DBDCE7DCDDE7DDDEE7DEDE
E7DBDCE7DEDEE7DDDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDF
E7DEDFE6DDDEE7DEDEE7DEDFE5DCDEDFD3D4E5D8D9EBE2E2EFEDEECCC6CDA38E9238241F
96675CEFC9B6F2CEBCE6BEABDFB6A5E3B8A2DFAE97E5B29BE7C1B3E7BFB1E6BEB0E7C1B1
E7B8A0E4AF9AD89C83CD886DD29079DD9C8DDC8686C36C67C5897BDA9689CE7A7CDF958F
E09895D97A79D8A4A2DD9B95D9B9B5DCD0CDDAC4BDDACDC3DEA896CCA69CD0AFA0CD9791
BC897AB7746DA36355964F449D5344893E2EAB4836BB5E4DCC7566D09A7DCB9770C68D68
CC8670CD8F79D09983D7A18AD39A83D39B81CE917ACD947ECD9580D09782CD9680C89179
CF9C86CDB6B7E0D2D9E0D2D7E0D3D6EBE3E3ECE5E3E8E0DEE6DDDEE7DEDEE7DEDEE7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DCDDE7DCDDE7DCDDE7DEDFE7DBDCE7DCDCE7DCDDE7DEDEE7DEDE
E7DBDCE7DEDEE7DDDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDE
E7DEDEE6DCDDE7DEDEE7DDDEE7DDDEE5DCDEE6DDDEE7DDDEE6DDDFB2A1A6886C6D4C312B
AB7A6CF3CEB9F4D1BFE7BFABDFB5A2E2B49DDFAC96E4B099E7C1B4E7C0B2E7BFB1E7C0AF
E5AF97DEA38DD29379C98268CA7D6AD18076C96768BA6058C48375D99486D1807FE09C96
E09B95DD8685DBABA9DD9F96DCBEB8DED5D2DBC6BEDBC9BEDCA694D1ADA3D3B4A6D1A199
C19081BC7F77AE7568A25E539D57478E473AA04437B0574CBC6859C77D6BC68767C48A67
CB8872CD907AD29D86DAA38CD69F88D59E84D1947DCE947ECD9580D09783CD937EC68F76
CC957ECBADA9DAC9CDD9C9D0DED0D4E6DCDDE6DDDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DDDEE7DEDEE7DCDDE7DCDDE7DDDEE7DEDFE7DCDDE7DCDDE7DCDDE7DEDFE7DEDE
E7DBDCE7DEDEE7DCDDE7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDD
E7DEDEE5DBDCE6DEDFE6DBDDE9DFDEEDE6EBE7E1E3DFD4D7D7C6C78E75766B4D4B7E564D
C69685EDC8B2EFCAB8E9C0ABE2B9A4E2B19BE1AE98E2AE98E7C0B3E7C0B2E7C1B3E7BEAC
E1A38ED6967FCD8B6FC88067C16B5CC0635BAF4947B65C4FC78275DB9587D79089E2A9A1
E09F96E19C98DFB3B0DDA296E0BCB5E2CDCDDFBAB3DEB5ABDA998AD9AAA2DAB2A8D7A69D
CB9286C68A81BE8E83B6766AA460509C5B4F98463FA5544FA75A4AB45950BD705BC28567
CB8B75CE927CD5A087DCA58FD9A58ED6A088D39980CE947ECC947FCD9580CC907AC89179
CC947DCBA69BD3BEBED0BEC8DACBD2DED2D4DED2D8E4DBDEE7DEDFE7DEDFE7DEDEE7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDDE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DCDDE7DEDEE7DCDDE7DCDDE7DEDEE7DEDFE7DCDDE7DDDEE7DCDDE7DEDFE7DEDE
E7DBDCE7DEDEE7DCDDE7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DCDD
E7DEDEE5DADBE6DEDFE5DADBEBE0DEF4F0F7E8E5E7D8CBCFC8AEB0664D4B4E332EB08278
DFB6A2E7C1ABE8C2B0E9BFA9E5BBA4E2AE99E3B09AE1AD97E7C0B3E6C1B3E7C3B4E6BBAA
DC9986CE8971C78467C77F68B85C4FAC4A41923229B55A4ACC8477DD988ADEA394E3B7AD
E0A498E4B5ACE3BCB7DEA697E5B8B0E7C4C5E2ADA6DEA096D78C80E0A6A1E1AEA9DDAAA0
D6938AD0968BCDA89EC99182AC6B5AA87466924A489C5252914D3C9D3C33B25C4DC08167
C98E77CE937DD7A288DEA690DCAA94D7A28CD59D84CD937DCB927DCB947ECB8D78CB947E
CD947DCCA08DCBB3AEC7B4BED4C5CDD5C6CAD5C7D1E2D8DFE8DFE0E7DEDFE7DEDEE7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDDE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DCDCE7DEDEE7DDDDE7DCDDE7DEDFE7DEDEE7DDDEE7DEDFE7DDDDE7DEDFE7DEDE
E7DBDCE7DEDEE7DCDDE7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DBDC
E7DEDEE4DADBE6DEDFE5D9DBEADFDDF3EDF5E2D9DACCB7BBB49292432E2B442A24D7AAA0
F0D0B8E2BAA5E2BAA8E8BDA6E6BBA4E2AD98E4B29DE0AC97E7BFB1E6C0B3E7C3B4E6B9A7
D8917FC77F67C48062C9816CB7594EA44239872C20BA614FD38A7DDF9D8FE3B49EE4C1B5
E1AA9BE4C9BAE7C2BADFA998E8B3AAEABABBE3A198DD9183D48378E6A19CE6A7A4E2A99F
DE928AD79D90D7B9AFD6A593B57663B38A7992515098535684453485281CA64A40BC7A64
C78B75CD937CD9A388DFA792DEAD98D9A48FD7A087CD937DCA917BC9937CCB8B77CE9782
CE947FCD9B82C5A99FC0AAB5CDBAC3CEBCC1CFBFCCDFD4DDE7DFE0E7DEDFE7DEDEE7DDDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DBDCE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DCDDE7DEDEE7DDDEE7DDDEE7DEDFE7DDDEE7DDDEE7DEDFE7DDDEE7DDDEE7DEDE
E7DCDDE7DEDEE7DCDDE7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDC
E7DEDFE5DADBE7DEDFE6DCDDE5D9DBDED1D7C6ACA8B29091996F6C34201C674239E3B7AC
F3D4BCE2B8A4E2B8A5E5BAA3E6B8A2E2AD99E4B39DDFAC97E7BEAEE7BEB0E7C0B0E4B6A3
D68F7CC47B62C48062CF8977C66E66B85954A4443FC97565DA9489E1A497E4B8A1E4C2B5
E2AFA0E4CCBBE7C2B8E0AB9BE9B0A6EAB3B0E19E92DC9080D5857AE59E97E59F9AE0A195
DF8E86D8978BDAB3A8D6A08DBC7966BC917E9D5A579F5B5A8846377A21179C3D35B56D5A
C17C6ACB8F78D79F85DFA894DFAE98DBA692D7A288CD937ECB917BC8927BC98B76CE9480
CE937ECD987EC5A396BCA4ABC3ABB1CDB8BCD0BFCADBCED7E5DCDDE6DEDEE7DEDEE7DDDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDCE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DCDDE7DEDEE7DDDEE7DDDEE7DEDFE7DEDEE7DDDEE7DEDFE7DDDEE7DBDCE7DEDE
E7DDDEE7DEDEE7DDDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DCDD
E7DEDFE6DCDCE7DEDEE8E0E0DDD1D8BFAAAE9A766D8E6662794E48351F199C6D61E3B6AA
EFCDB4E5B9A6E4BAA5E2B7A0E5B49FE2AE9BE3B29DDEAD97E6BDAAE7BBADE6BBAAE3B4A0
D5917CC47B61C78266D59483D79189D38380CA7372D99084E0A196E3ADA0E4B5A2E4BDB0
E3B4A5E5C4B6E6BEB3E1AD9FE8ADA3E9AEA6DF9E91DC9786D88D80E29D92E0968CDB9788
DB897FD58C7FD7A193D08F7CC27867C58E7AAF655DAB655E964D3F79221D95362EAB5F4E
B9695BC88A74D59A80DFAA96DFAD97DEA894D7A288CD947ECC927CC89279C78C75CD907C
CE917BCD967EC9A08FB99FA2B6999ACEB6B8D4C2CAD7C7CFE3D7D8E6DDDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDDE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DCDDE7DDDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDFE7DDDEE7DADBE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DDDE
E6DEDFE6DDDEE7DEDDEAE4E3D5CAD59E868766453A65413958332A3F2218CE9E91E1B5A7
E9C3ABE7B8A7E6BAA4E0B49EE4B19EE2B19EE2B29DDDAE98E5BCA6E7B8A9E5B7A5E1B29E
D5937DC67C63CB866CDBA08FE2BBABE4B7ACE4B0A6E5B1A4E5AFA4E5B6AAE4B2A3E4B8AB
E4B8ABE5BCAFE4B9ADE3AEA2E6AA9FE7A89BDC9E8FDB9E8BDB9585DD9A8BDA8C7ED58B7A
D78377D08072D28D7CC77D6AC87768CD8A75C27163B97262A7554A7B25258F3029A25443
AF584BC5856FD2957CDEAB97DFAA95E0A995D7A187CE957FCD927CC79278C68C75CC8D78
CE907ACD957FCD9D88B79B99A78682CEB3B3D8C4C9D3C0C7E0D2D3E6DCDDE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DCDCE7DDDEE7DEDEE7DEDFE7DEDFE7DDDEE7DEDFE7DEDFE7DDDEE7DEDFE7D9DAE7DEDE
E7DEDFE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDF
E6DEDFE7DEDFE7DDDDEAE4E3CFC2CF876D6C462D225131274D2A20592F21F0C7BADFB3A3
E2B9A3E8B7A7E8BAA3DEB39DE4B09FE3B4A2E2B39FDDB09BE4BCA4E7B6A7E4B4A2E0B09C
D59780C98168CF8A72DEA796E6D9BFEAE3C8EDE6CAEBCCBDE9BCB1E6BEB2E4B1A5E5B4A7
E4BBAFE5B5A9E3B6A8E4B0A6E5A89CE4A493DA9E8DDBA38EDC9B8AD99886D58674CF8370
D27F71CB7869CA7E69BF705CCC7768D2866FD07B67C37D65B56055852E3290322B9E4F3D
A94F41C3816BCF9078DCAA96DEA893E0A994D6A086CE947ECD927CC79176C48D74CB8A74
CE8F7ACD9580D19B83B69892927069CAACAADBC7C9D3BFC5DFD1D2E6DCDDE7DEDEE7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DCDDE7DEDEE7DEDEE7DEDFE7DEDFE7DDDEE7DEDFE7DEDFE7DDDEE7DEDFE7DADBE7DEDE
E7DEDFE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDF
E7DEDEE7DFE0E7DEDFE6DDDECFBBC48E706B684536744A3D734336834D3BF3D0C2E0B6A4
E1B6A1E8B7A7E8BBA4DFB5A0E5B3A3E4B8A6E3B6A2E0B4A0E5BDA6E7B8A8E5B5A3E0B09C
D89B85CE8871D18D75DCA290E5D0B5E9E3C5EDEDCCECD4C4E9C4B7E6C3B6E5B6AAE5B6A8
E5BDB0E5B6A8E3B9A9E5B4A9E5AB9CE2A490DA9F8BD9A18BDB9C8AD89985D48873CE8570
D08370CA7A69C67D65BE725DCA7A69D0846DD08069C68267BC6B5D9742429E413AA55845
AC5546C2806ACD8D75D9A58FDDA690DFA791D59E85CD927CCB8F7AC68F75C48C72CA8B73
CD8F79CD9480CF9880B59791755751BB9F9EDCCCCEDBCBD0E3D7D8E7DEDFE7DEDEE7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DCDDE7DEDFE7DEDEE7DEDFE7DEDFE7DEDEE7DEDFE7DEDFE7DEDEE7DEDFE7DCDCE7DEDE
E7DEDFE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE6DEDF
E7DCDDE7DFE0E6DEE1E0D2D7D0B5B6A58278A37866AB7A69A97161AF7662E7C7B9E3BBA6
E2B7A2E7B7A7E7BBA4E2B8A4E6B8A8E5BCABE5B9A7E2B9A7E5BFAAE7BBABE5B9A7E1B29E
DA9F8BD4927BD18F77D89783DFB49CE6CBB1EAD8BDEBD0C1E9C7B9E6C5B7E6BDB0E6BAAD
E6BDB0E6BAAAE5BDADE6B9ABE5B09EE0A691DA9F8AD89C85DA9B88D89C86D48E77D08C76
CE8973CA826DC38269C07B66C67E6ACA856CC9826BC48369BE7663AA5C54AE594EB16852
B36551C2816ACC8C74D69F86DBA38EDBA38CD49B83CD8F79C98C77C68C74C58B71C98D73
CB8F79CC957FCB957DB39792573F3BA78E8EDACFD3E6DCDFE9E1E2E8E0E1E7DEDEE7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DEDFE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DEDFE7DDDEE7DEDE
E7DEDFE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE6DEDF
E7DBDCE7DEE0E5DDE1DBC6CFD2AFA8C09686D9B19FDEB29EDAA796D4A58FD9BBADE4BCA6
E2B6A3E7B8A7E7BCA6E4BBA8E6BEAEE6C0B0E6BCACE5BEAEE6C1AEE7BFAEE6BDABE2B3A1
DEA392DA9C88D2917AD28C76D69881DFB29BE5C0ACE9C8BBE7C8BAE7C5B8E7C3B6E6BEB0
E6BCB0E6BDACE6C2B1E6BDAEE5B5A0DFA994DBA18BD69981D89A86D79E88D4967DD0947C
CC9075CA8A72C0886DC1846EC1816AC38369C1826BC1836ABF8269BC7D64BD7762BC7A61
BA775DC3826CCC8B74D39A7DD8A18BD79E87D29881CC8B76C68974C68A74C58A70C79073
CA8F79CC957FC8927CB398943C2B28947E7ED8D1D6F0ECECEDEAEAE9E2E3E7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDFE7DEDFE7DFDFE7DEDE
E7DDDEE7DEDEE7DDDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE6DEDF
E7DBDBE7DEDFE5DBDFD7BEC6D5AD9FD9AB96FCDECCFEDDC6F7D3BFEACBB3CEB0A2E4BDA5
E3B6A3E6BAA7E6BDA8E6BEADE7C2B3E7C3B3E8BFB1E8C2B4E7C3B3E7C3B1E6C1B0E4B6A4
E0A899DEA692D4957ECE866DCD836BD89C87DEA998E6BFB2E6C7B8E7C5B7E7C8B9E7C1B3
E7BBAFE7BFADE6C5B4E7C1B0E5BAA4DEAD99DCA38CD5977FD69985D6A08AD39B81D19A81
CA9577C99176BD8C71C28A74BC8369BC8167BB816ABF836AC08A6CC7986EC69170C58B6D
C08868C5866FCC8D75D09678D69F89D49A82D1967FCC8974C58773C68874C68A6FC69174
C88F78CB957FC5917CB29692281C1B816B6DD1C8CDF3F2F1EEECEDE9E2E3E7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DFE0E7DEDE
E7DDDEE7DEDEE7DDDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDF
E7DEDFE6DDDEE5D8D6D9BFC1DBB5A3E4B9A3FFDCC9FFDAC2F8D3BDEFD2BACFADA0E5BEA6
E4B5A3E6BBA7E6BEABE7C0B0E7C4B5E7C5B6E8C2B4E8C6B9E7C5B6E6C5B3E7C3B3E5B9A8
E2AD9EDFAD98D89B85D18B72CC8269D4937EDA9E8DE4B9ABE6C4B6E7C4B6E7C8BAE7C1B3
E7BBAFE7C0ADE6C5B3E7C4B3E5BEA9E1B39EDDA690D79A83D69B86D5A08AD29B81D09A81
C89477C79075BD8A6FC18873BB8268BA8066BA8169BF8368C18A6DC99B70C89573C89172
C58F6FC98C75CF9179D19779D49B85D3977FD0947ECC8A75C58873C68873C68970C69175
C78F78C9937DC5927DAD8F882217166D5557BFADAFEAE3E3E8E0E1E7DEDFE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DDDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDFE7DDDEE7DEDFE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDFE7DEDFE7DEDEE7DEDEE7DEDFE7DDDDE7DDDE
E6E2E3E6DDDDE6D3C9DEC4BDE1C1ACE6C2AEF0C2AEF0BFA8EABCA5ECC7B2D6B0A3E5BEA7
E5B4A3E6BDA7E7BFADE7C2B3E7C5B7E7C6B7E7C4B7E7C8BCE6C6B8E6C5B5E6C4B5E5BCAC
E3B1A1E0B19ADDA28ED6957DD18B72D3927CD99A86E1B5A4E6C0B3E7C3B5E7C7B9E7C0B1
E7BCAFE7BFAEE6C3B2E7C6B6E6C1AEE4B8A4DDA994DA9E8AD79D88D49E89D0977FCE957D
C69076C68B73BE856CC0836EBB8066BA7F65BB8068C18465C3856CC8916EC78F70C99072
C99073CE937CD2967ED39B7FD29882D2957ECF937DCC8B76C68A75C58973C58871C68F76
C78F77C7917BC7937DA7857B281A185A4143A48A89D9CACCDDCECEE3D8D9E7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDDE7DEDFE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDFE7DEDFE7DEDEE7DEDEE7DEDFE7DDDCE7DDDD
E6E5E6E6DCDBE7CDBCE4C9B8E6CCB4E7CAB9DCA791DCA38CD8A38CE5B7A6DCB0A3E6BFA9
E6B5A4E7BEA7E7BFB0E7C3B5E7C5B7E7C6B8E7C6B9E7CABFE6C7BAE6C6B7E6C5B7E6C0AF
E4B5A4DFB39CE2A896DBA189D6957CD3917AD7947EDEB09CE6BCAFE7C2B4E7C5B7E7BFAF
E7BCAFE7BFAEE5C1B0E7C8B8E6C3B3E7BDA9DEAC99DDA390D79F8AD29C88CF937DCC917A
C58C75C58770C0806ABF7D6ABC7E65BA7F66BD7F67C28463C47F6BC5856BC5866DC98F73
CE9178D39B84D59B84D69F86D19580D2937DCE927CCC8D78C88D77C58B74C58873C78E77
C78F76C58F79C8957EA17B6E33201C483033876A65C6B0B3D1BBBCDFD2D3E7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DCDCE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DCDCE7DDDEE7DEDE
E7DEDFE7DEDEE7DEDFE7DEDFE7DEDFE7DEDFE7DEDFE7DEDEE7DEDEE7DEE0E7DDDCE7DCDC
E6E5E6E6D8D5E6C5AEE8C8B0EACEB7E5CABAC98F78C98D76C8917ADDAA9AE2B1A4E7BFAA
E8B6A5E7C0A8E7BFB2E7C4B6E7C5B8E6C7B9E6C8BBE6CBC0E6C8BCE6C6B9E6C6B8E7C2B2
E5B9A7DFB59DE6AE9DE0AA94DA9F86D4917BD7927ADCAC97E6B8ACE7C1B3E6C3B5E7BDAD
E7BCAEE7BFAEE5BFAFE7C7B8E7C3B5E9BFACDEAD9BDEA694D69F89D09986CC8E7ACA8D77
C48874C3836EC17E68BE7A67BC7C64BA7E65BE7E66C38462C57C6AC37C69C5816CCA8E75
D2927DD7A18BD8A088D8A28BD0937ED2927CCD917BCC8F7AC98F79C68C74C58875C78C78
C78F75C58E79CA97809E7565482C26442B2C71534CB2979AC6ADADDBCDCEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DCDDE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DCDDE7DDDEE7DEDE
E7DEDFE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDFE7DEDF
E7DCDDE6CEC7E5BAA3E8BAA3E8BCA9E2BAABC48770C68A75C8957EDEAA9AE4B3A5E7BFA9
E8B8A7E7C0AAE7BFB1E6C4B7E6C6B8E6C8BBE6C9BCE6CCC1E7C9BDE7C6BAE7C7BAE7C2B4
E6BDAAE1B7A0E6B3A1E3AD9ADCA48CD69580D8977FDCAA96E6B8ABE7C0B3E6C2B4E6BCAA
E6BAABE6BEADE5BFAEE7C4B6E6BFB1E8BCAADDAD99DCA391D49B85CC9582CA8C78C78A75
C38772C2826DC27F68BF7B67BA7A62B77A61BE7B64C48464C67F6EC78170CA8773CE937B
D69783D9A48FD8A18AD8A38CCF957FD2937ECE927CCC917BCB8F79C78D75C58A76C78B78
C78F76C6907ACB9A83A677646841365B3835744F45A18584C0A8A8D9C8CBE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDDE7DDDEE7DEDE
E7DEDFE7DEDEE7DEDFE7DEDFE6DEDEE6DDDEE6DDDEE6DDDEE7DEDFE6DDDDE6DFE2E5E0E2
E7D0CFE6C2B5E3AD99E5A893E1A192DCA393C68770CC917DCFA38FE2B1A0E5B5A6E7BFA8
E7BBA8E7BFACE6BEAFE6C5B7E6C7B9E6C9BEE6C9BDE7CBC1E7C9BEE8C6BAE7C7BAE8C1B4
E7C0ADE4B8A4E5B7A4E5AB9DDCA690D99B87DA9F88DEAB97E5B9ABE6C1B3E7C1B3E4BAA7
E4B7A7E5BDACE6C0AEE6C0B2E5B9AAE5B5A4DCAA95D89E8BD0947FC9907DC88A76C48873
C28771C1826CC28169C07E68B87960B4775CBD7962C58468C88774CD8D7BD0927ED39A83
DA9E89DAA490D7A18BD7A28BCF9781D29580CF927DCD917CCC8F7ACA8D77C68D77C78B76
C88E77C8937DCC9C87B27D668C5B48804F45865748947873BDA9A8D8C6C8E7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDFE6DDDEE6DDDEE6DDDEE7DDDEE7DEDFE6DCDBE6DFE4E4DFE2
E7C2C0E4B6A1E0A08EDE9582D5877AD08B78C78670D19885D5B19EE5B6A4E6B8A9E7BFA7
E6BDA9E7BFAEE6BDADE6C5B7E6C7B9E6CAC0E7C9BEE7CBC1E8CABEE9C6BAE8C7BBE8C0B4
E9C3AFE7B8A7E4BBA6E7AAA0DEAA95DDA290DDAA94E0AD9BE5BCABE6C1B4E7C1B2E3B8A4
E3B5A4E4BDABE7C0AEE6BCADE3B3A3E3AE9DDAA890D39984CD8E79C58B78C58874C18670
C28770C1816BC2846AC18169B6795EB17457BD7861C6846DCA8E7AD29985D69D89D7A08B
DCA38EDBA491D6A08AD7A08ACF9A83D39882D0947ECD927DCD8E7ACC8E78C69077C78A75
C98E78CA9681CC9F8ABE8369B0765AA969559C614D886C64BCAAA8D7C3C5E7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDFE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDFE6DDDEE6DDDEE6DDDEE7DDDFE7DEDFE6DCDBE6DFE3E4DBDE
E6B8B3E3AE94DD9786D88775C97366C37963C98771D69F8DDABDAAE7BBA8E7BBABE6BFA7
E6C0ABE7BFB0E6BEADE6C5B6E6C7B9E6CAC0E7C9BDE7CABFE8C9BCE9C5B8E8C6B9E8BEB2
E9C3AFE9B8A8E2BCA6E8A9A1DFAC99E0AA99DEB49DE3B09FE5BEACE6C2B4E7C0B1E2B8A3
E2B3A2E4BCAAE7C1AEE5B8AAE2AE9DE0A896D9A48BCF957FC98974C28774C28672BF846E
C1876FBF816BC2866AC3836AB77A5EB27457BE7963C88774CD9680D6A28DDAA591DAA590
DEA791DBA390D59F8AD69F89D09C84D29A83D0947ECE927DCD8E7ACD8E79C79178C78A74
CA8D79CB9883CDA18DC8876CCB8B68CB8163B36F5685675CBEADABD8C4C7E7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDFE7DEDEE7DEDFE7DEDFE7DDDEE6D2D1
E7B6AEE6AF97DC9382D78371C56F5FBF745DCA8B75D8A390DCBEABE7BDAAE8BDACE6BEA9
E6C3B0E7C0B3E7C0B0E7C5B7E7C6B8E7C9BDE7C7BAE7C7BAE7C5B7E7C2B3E6C2B2E7BAAD
E6BEABE6B5A6E1B8A4E5A99FE0AD9AE1AD9DDFB6A0E4B3A3E6BEADE7C1B3E7C0B0E3B9A5
E3B6A5E4BDABE7C0AFE5B8A8E2AF9DDFA694D8A188CE947DC88873BE8672C0846FBE826C
BF856DBD816CC0866BC3866CBA7D63B97B5FC4816CCD8D7BD09A84D9A590DCA994DBA792
DEA993DBA38FD69F89D69E89D19C85D29882D0937DCD927CCC8C79CB8C79C79078C78974
C98D77CB9681CEA190CA876CD4906FD48E6CC07E64926E60C6B4B2DCCFD2E7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDFE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDFE7DEDE
E7DEDEE7DEDEE7DEDEE6DEDEE7DEDFE7DFE0E7DFDFE7DEDEE7DEDEE7E1E4E7DBD6E8C5BF
E9B8ACE8B4A0DA9180D68470C4735FBF7760CA907ADAA592DEBBA6E6BDABE7BEACE6BEAC
E7C5B4E7C1B5E7C2B4E8C5B7E7C6B8E8C6B8E7C4B6E6C3B3E4C1B1E3BEACE4BCAAE4B6A7
E2B7A6E2B1A2E0B3A0E2AA9BE0AD9AE0AF9EDEB39FE5B6A5E6BDAEE7C1B3E6C1AFE4BCA9
E5BAAAE5BEAEE7C0B0E5B9A8E3B2A0DEA693D89D86CE947DC78873BC8672BD826DBC8069
BD826CB9816DBE856CC4876FC08269C2856BCC8C78D29582D49D88DBA590DDA994DAA691
DEA994DBA38ED79F89D69E89D29B84D09680CE917CCC917BCB8B78C98A78C78E77C68975
C78C76CB927ECFA192C6846AD28C70D19372C68D73A97969D0BBB9E1DDDFE7DEDFE7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE6DDDEE7DFE0E8E1E1E8E1E1E7DFDFE7DEDDE7E1E7E7D7CDE9B9AC
E9B7A8E9B6A8D78F7ED48470C3765FBE7A64CC9781DCA896E0B9A2E6BDACE7BEACE6BFAE
E7C7B9E7C3B6E7C5B8E9C5B7E8C4B6E8C2B1E6C0B0E4BDABE0BBA8DEB8A4DFB4A0E1B09F
DBAF9FDBAB9BDDAA9ADCA894DFAB98DFAE9EDDAF9BE5B8A7E6BBADE7C0B1E6C1AFE6BFAE
E6BEB0E6BFB0E7BFB2E5BBA9E4B5A3DEA692D89983CF947CC68973B98672BB806BBB7E67
BA806AB6826EBD856EC48972C58870CB9078D39884D79E89D7A08CDDA58FDDA893D9A690
DDA994DAA48CD99E88D69D89D39A84CF947ECD907ACB8F79C98A77C68878C68B77C68875
C58B74CA8F7BD0A094C28069CB856ECA9576CA9D82C28474DBC1BFE6E9ECE7DEDFE7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE6DDDEE7DFE0E8E1E2E8E1E2E7E0DFE7DEDDE7DFE4E6CEBFE5A997
E6B29FE5B1A7D08A79CC816CBD775EBB7C66CE9E88DFAD99E2B8A0E5BEADE6BFACE7BFB0
E8C7BBE7C4B7E7C6BAE9C4B6E8C2B4E7BFADE5BEABE3BAA6DEB7A3DCB59FDDB09BDFAD9B
D8A99AD8A998DBA596D9A890DFA995DEAE9DDCAC9AE4BAA8E6BBAEE7BFB0E6C1AEE8C1B1
E7C1B4E7BFB2E6BEB2E5BDA9E4B7A4DDA691D79681CE937BC68A74B88672B97F69BB7E66
B87E69B5836FBC846FC48B74C98D75D19882D6A08DDAA38ED9A28EDDA38DDCA791D7A48E
DBA792D9A38AD99D87D69B88D49983CD927CCC8F79C98E78C88976C48777C68976C58876
C48B73C98D7AD09F93BC7C66C37B69C39377CCA48BD68D7AE2C0BCE9ECEDE7DEDFE7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDFE6DDDEE7DEDEE7DEDFE7DFE0E6DEDFE7D9D7E3BBAAD89782
DBA18BD7A092C17F6BB97561AD6F58B07762D0A18CE1B29DE4B9A3E5BEADE6BFADE7BFB1
E7C4B8E7C3B5E7C4B7E7C2B3E7C0B1E6BEADE6BEACE6BDA9E0B8A3E0B7A1E1B5A0E3B09E
DFAD9CE0B29FDFA899DCAD95E0A995DFAE9CDFB29EE3BFABE6BEAFE7C0B0E7C1B0E8C1B0
E8C1B4E7BFB2E6BEB0E6BDA8E3B5A2DCA691D69580CC8F78C58874BA8670B97F68BC7F68
B9806AB68470BD8470C48B74C98E78D19984D39D8BD7A28ED7A18DD9A08ADAA48ED6A28C
D7A28DD59F87D69B85D49984D19781CC917CCA8F7AC98E79C78B77C58876C68875C58976
C48A75C68F7ECD9C90B57660BD7461BF8B71CA9C86D98C78E0B1A7E9DAD9E6DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDFE5DCDCE5D9DAE5D9DAE7DDDFE6DDE0E7CEC4DEA592C78570
C98B72C18775AD705A9F655398624FA26F5BD2A38EE3B7A1E5BCA9E4BDADE6BFAEE7BFB1
E5C0B2E6C1B2E5C1B1E3BFB0E5BEADE5BFAFE7BFADE9C2AEE4BAA6E6BBA6E6BDAAE8B5A3
E8B49FEABDA8E4AD9EE2B39DE0A994E0AD9AE1B8A3E1C3ABE5C2AFE6C0AFE7C1B1E7C0AE
E7C0B1E7BFB2E6BEAEE6BDA7E1B19FDBA590D4947FC98B74C38673BD846DBA7F68BD816B
BB836CB98570BF8472C38A74C68D78CE9682CD9684D29D8BD39E8AD49C86D6A08BD59F8A
D29B88D29A84D39883D29580CE957FCB907CCA917BC88E79C78D78C68A76C68974C48976
C58A77C29384C9998CAF6F59B96E57BD8169C68B78D28672D69D8AE5BEBAE6DDDEE6DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DCDDE7DEDFE7DEDEE7DDDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE8DFE0E4DADAE2D3D3E2D1D3E6D7DCE6DBE0E5C3B1D7917BB67660
B5755BA76E5998604A855444845547956755D4A590E4BBA5E6BEADE4BCACE7BFAFE7BEB0
E3BBABE6BFAEE4BDACE0BDADE3BBABE4BFB2E8C0AFECC8B4E8BDAAEDBEABEBC4B3EDBAA8
F0BBA1F2C8AFE8B2A1E6B7A4E0A892E1AC97E3BEA6DFC5AAE4C5AFE5C1AEE8C0B2E7BFAB
E7BFAFE7BEB1E7BEACE6BDA6E0AE9CDAA490D2947EC78671C28373C1836ABB7F67BE836D
BD856CBC846FC28473C28973C28B77C8917FC38B7ACA9685CD9985CD9680D29B87D29B86
CB9381CC9580CE947FCF917CCA937DCA907BC9927CC78D7AC78F7AC78C76C68973C38A75
C68A7ABF9789C49586A76852B2674DB7745EBE7868C9806BC9886EDCA198E6DDDEE6DDDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DBDCE7DEDEE7DEDEE7DDDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE8DFE0E4DADAE2D2D3E1D0D2E5D5DAE7D9DCE2B49BD1846BAA6C57
9E5F4689544080503C6D4437724A3E885F4FD6A691E5BEA7E6BFB0E4BBABE6BFAFE6BEAF
E3B9A6E6BEACE3BBA7DDBAA9E1B7A6E0BBAEE4BBAAE8C2B0E6B9A6EBBBAAE6C0B0E9B6A5
ECB69DEDC1A9E3AD9BE3B09FDCA48EDEA591E1B9A1DCBEA3E1C1A9E4BFABE8BFB2E6BEA9
E6BEADE6BEB0E7BEABE7BDA6DEAB99D9A490D0947EC5836DC18171C28167BB7E66BD836D
BD856CBD846EC48575C28974C18B78C58E7BBE8574C69180C99681C8937DCE9784D09884
C78E7DCA927ECC927ECD907AC8927CC9907CC8937DC78D7BC6907AC88D75C68A73C28A75
C78A7CBD9A8DC19281A0644EAB6045B16853B46657C07662BC7757D18C7DE6DDDEE6DDDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE6DEDEE7DFE0E7DEDFE7DEDFE7DFE0E7D7D3DD9F85D1846EAC6F5B
884C3769392D6840315D382E6642377C5749D8A994E6C0AAE6BFB0E3BBA9E5BDABE7BEAD
E5BCA9E6BEACE4BAA5DAB6A4DCAF9CD6AD9ED7A895D2A493D4A492D9A79ACDA193D1A090
CC9A8BC89686CB9382CE9382CD9884D29685D49F89D3A38DDBAF99E2B9A4E6BDAFE6BEAA
E6BEAEE6BEB0E7BFACE7BDA7DEAB99D9A38FCF927CC4826ABF806DBE7F65B97C63B97E68
B87E66BB836EC58877C58B75C6917BC88F7AC78E79CD9480CB9781CB9680D09884D29984
CB917FCD9781CF9781D1947FCA9680CB937FC7947EC68E7BC48F79C68D75C38A73C18A74
C68A7CBF998BC292809F6651A45D42AC5E49AD5C4BB96854B86F4FCB8574E7DEDFE7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DEDEE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE5DBDCEAE5E6ECEEEFEDF0EFE8E9E4E7D3C5D5896FD48C79B47965
743C2D4A241E523228512F285D3C32714F44DAAC97E7C1ACE6BEADE3BBA7E4BBA7E7BEAC
E7C1AEE6C0ADE5BBA6D9B39FD6A792C99B89C4917CB27F6FBA8A78BE8E84A77A6CB08375
A17771906159A97263AC6F5DBB8977C28576BF7F6BC58472D29984DFB29BE4BBAAE6BEAD
E6BEAFE6BFB0E7C0AFE7BEA9DEAC9AD9A38ECE907AC48368BD7F69B87C63B5795FB37860
B1745FB7826DC58C78C88F78CE9780CC9179D49D83D7997FCF9981CF9A85D39984D49B84
D19783D29D84D49D85D59A86CF9C86CD9783C6947EC48E7BC28E76C28C75C08A73BF8974
C48B7BC19686C4937EA06B569D5B43A85640A75442B45A45B96E50CA8674E7DEDFE7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE2D8DAECE6E9EFFAFBF1FFFCE8F0E5E5CBB5C97459D69484BC8370
602E242B12113D241F47282255362D67483FDCAF99E7C1AEE5BDAAE2BBA5E2B9A3E6BEAA
EAC6B3E6C0ADE5BCA6D7AF99D19E88BB8A74AF7A658E5D4E9F7261A3756E7E55498E675A
76555552322F845346864E3BA87A6BB17467A5614DB46756C6856FDCAA93E2B9A6E7BFB0
E7BEB0E6BFB0E7C0B2E7BFABDEAE9BD9A28CCD8E78C48466BB7D65B27961B1765BAD7157
AB6B58B3806BC6907ACB927BD59E84D19278DFAA8BE09D7ED29A81D39E89D49A84D69C84
D69C87D7A388D9A289D8A18DD3A18CD09B87C6937FC38E7AC08B74C08A74BC8A73BE8974
C38D7BC49280C5927C9F6F5C975943A24E37A14E3AAC4D35BC6D53CA8875E8E0E1E7DFDF
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE2D7D9ECE5E8EEF7F9EFF8F5E4DFD4E3BFA4C1674CD79B8EC38B79
53262018080A2E1C193F221D4E312862453CDDB19BE7C0AEE5BCA8E2BBA3E1B7A0E5BDA7
EBC8B4E6C0ADE5BCA6D7AE97CF9C85B5826BA5705B7A4D3D91655592686164403578564A
5A40432716156A40336839269B6F61A5685D934F3BA75744BF7862DAA48CE0B7A2E7BFB2
E7BFB2E6C0B2E7C2B6E7BFADDFAF9CD9A28CCD8D78C48566BA7C61AD775FAF7459A86C51
A46251AE7C67C4917BCC947ED49E84CD8F75DBA688DA9678CD937ACE9985CF9681D09780
D29A84D5A285D6A187D6A18ED3A28CCF9B86C5927DC28E79BE8972BD8974BA8A73BD8873
C18D7AC58F7BC390799D705D9056439B4932994A35AA482FBF6F58C98874E9E1E2E7DFDF
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DEDEE7DEDFE7DDDEE7DDDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDFE7DFE0E3D9DADEC5C8CFA5A1E0AC94C86B53D99D8ECA8E7C
542924190B0D2B1A19371F1A472B2465483FDEB39DE6BEACE3BBA6E2BAA3E1B8A1E3B8A2
E6BFACE5BDAAE5BCA6DCB39ED6A691C4917AB5816B915F4FA173629D7269744C40825E50
654748331D1C7044366D3C299C6F60A5685B985540AE5D49C27C65D9A38AE0B6A0E7BFB0
E7C1B4E7C4B7E7C5BAE6BFADDFB09CDAA38DCD8E78C48466BA7B5FAC755CAF745AA76B51
A05D4CA5715CBD8D7AC89483C18F7BBA826EB57A6BB27965B47A65B5816FBC8776BB8571
B98672C28F74C4917AC5947FC9967FC8937CC38D77C18C76BD8871BD8A74B98A74BC8773
C18C78C68F7ABC89729467558852408F4936904834B2533DC3765FC7806CE8DFE0E7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DCDDE7DEDEE7DEDFE7DCDDE7DCDDE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEEDE6E6DFD3D2CDADACBA8588A36360DB9684D27662D99B88CE8B78
5B312C2515162D1C1B301C184226206E4E43DFB49EE6BBA9E2BBA5E1B9A2E2B9A4DFB29C
E0B3A0E3B9A6E3BAA5E3BBA7E1B6A3D9AB95CE9E88B98572BE8E7CB5887A986A5B9B7262
825C585A3933865644834D3AA57363AC6E5EA96751BD6F5ACB8972D8A48CE0B69FE6BFAD
E7C3B6E7C8BDE7C8BDE5BFADDFB19CDBA58FCD907AC58368BA7B5EAD7459B1765CA96C53
9E5A489B6550B58779C29386A67A6DA071647A46427E554C915B4C936353A375689F6E5F
966B5AA8775FAB7B68AE816BBB866DBD866FC08870BF8972BD8771BF8A74B98A74BB8773
C18A77C58F79B17F6A885A497F4C3B834A3C864734BD6653C67E65C37660E7DDDEE5DCDD
E6DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DBDCE7DEDEE7DEDFE7DBDCE7DBDCE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEF3EEEDD4C4C1AF827D844C4B632C25D18173D98272D79680CF8772
623A35332322321F1F2C1C163E231D775648DFB59FE5B8A5E1BAA4E1B9A2E3BBA7DCAC97
D9A794E2B5A2E2B9A5E9C4B2EAC7B7ECC6B2E6BEA9DFAF9BDBAB99CEA18EBD8B7AB78976
A5756A845C50A06C569B614EAF7A67B67663BB7C65CD856ED49880D9A78EE0B6A0E6BEAB
E6C5B8E7CBC2E7CCC1E4BEACDEB19CDCA792CE927CC5826ABA7B5EAF7457B2785FAA6D55
9C5745915944AC7F75BB91888A665E876059391B1C4C33316D40356F473A8B635A84584D
7451448D5F4B926556976E58AB765CB27A61BD8369BD866EBD8671C08B73B98A75BA8773
C08675C18D77A575607A4C3D754637774C3F7F4836C77D69C9876CC06D55E5D9D9E4DBDC
E6DDDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DADBE7DEDEE7DEDFE7DBDCE7DBDCE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEF3EEECC5ABA68B5C554E2521240B03BE695FD58177CB8A73C47A67
64403A3C2F2B3622232A1C163B211C7F5C4DE0B69FE4B6A2E1B9A4E0B9A3E4BCAADAAA94
D49F8CE0B19EE0B6A3EBC6B6EFD0C1F6D7C4F2D3BFF5CFB9EDBFADDEB299D6A592CA9A84
BF8875A57A67B37D64AC725FB77D68BC7C65C68D74D7987EDAA58DD9A991E1B6A0E6BEA9
E6C7B9E7CDC5E7CCC1E3BDAADEB19BDCA893CE957FC6826DBA7B5FB07356B37960AC6F57
9C58448C533DA87B73B78F887C5A567958530F05072E1F2055302755352A78564E714A42
5C40357A503E81584B88624CA06C51AA7359BB8064BC856BBD8671C18C74BA8A75BA8873
C08573BB88739568566B41346B40336A493D794937CC907AC9896DBD654CE5D9D9E4DBDC
E6DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7D9DAE7DEDEE7DEDEE7DCDCE7DCDCE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE6DBDDAA807B6E433B391B151505009B4E46B7655FAC725FA26255
573935392D28332121291B163A201B815D4DE1B6A0E4B6A1E2BAA4E1B9A4E3BCAADCAD98
D4A08DDCAA98DCB09CE3B9ABE9C3B4EBCAB9EAC9B7EFC9B5E5B8A6D9AA91D4A18EC4937E
BF846EAA7C67B27C63AC715DB37660B9775FC48970D5997FDAA88FDAA992E0B6A0E7BFAB
E7C7B9E7CBC0E7C9BDE2BAA7DEAF9ADBA691CD9781C68571B97A61B17355B2765CAC7057
A26049975C45AE7F72BB91878C665F84615B2812153C29295D372D5A382B745149714C42
6143377E5340865B4C8D6651A56F54AE765CBC8166BD856CBC8771C08C75BA8A75BA8974
C08975B17F6B8258495E3A315F3B2F5B3C33734735C8937BC57B63BE6146EBE2E3E7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DADBE7DEDEE7DEDEE7DDDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDED2C1C782534D56312B3B1E17230C0770342F88403C84554875453E
432D293124202E1E1E291B163B201B7F5B4DE1B6A0E5B6A3E4BBA5E2BBA5E3BBA8E0B39F
D8A593D8A492D7A994D6A799DDAE9DD7AFA0D7B0A0DAB09FD1A393C99680C38F7DB4836F
B17762A4705EA9725BA46852AA6C55B36F58BC7D64CF937AD7A58DDAA893DFB59FE7BFAF
E7C6B8E6C7B8E7C4B6E1B7A2DEAC97DAA38ECC9983C58A75B77964B17356B17256AD7055
AA6A50A86B52B88672C29382A97B6E9A74675D363661433D754A3D6E46367852497C5649
7450428E604B9766549D735DB1785FB77F65BE856CBD876FBA8872BF8C76B98B76BA8A74
BF8E78A373606C483C54373154362B4A2D266F4432C18D74BC6853BF5E43F1ECEEEAE2E2
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDE
E7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DADBE7DEDEE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEBFA9B1532C2541231E42251C351713451D1B52201D5A3930462826
2F1F1E281B182A1B1B2B1C173C211C7C5A4BE1B49EE6B7A3E6BDA7E3BCA6E3BBA7E3BAA6
DDAC9AD59F8DD3A38DC89688CF9986C19588C29889C39889BC8F80B98370B27F6DA37562
A46C579E6656A26A559D604AA2644CAD6952B4725AC88D76D5A28CDBA995DFB69FE7BFB2
E7C5B7E5C2B0E6BEAEDFB39DDEA995D8A18BCC9B86C59079B67A68B27357B07052AE7254
B27658B97C62C48E71CA957DC8927DB2877490645B8B60528D61508557437F55498A6252
895E4E9F6E57A9735CAE816ABD826BC0896FC08872BF8972BA8A72BF8C77BA8C76BA8A74
BD91789366555738304A3330493128391E196B402FB8836CB05541BF5C41F6F4F7ECE5E4
E7DFE0E6DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDE
E7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DBDCE7DEDEE7DDDEE7DFDFE7DFDFE7DEDEE7DDDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEB199A32C140E331A16482C2143221F230E0D250B0938221E211313
1F14142015112719182D1D1840241F79584ADFB19BE5B6A3E7BDA7E3BDA6E3BBA6E6C0AC
E1B3A1D59E8DD2A18BC08D7FC58C79B18577B3877AB2877AAD8274AF7969A876659B6E5D
9E67549D6354A069559D6049A1634CAE6954B26E57C68B75D3A28CDDAB98DFB7A1E7BFB4
E7C3B4E4BEA8E5B8A7DEB09ADEA793D7A08ACC9E88C7957DB77C6DB5765CAF6E4FAD7254
B57D5DC1866CC88F6CCA9073DB9E83C19279B38C76AD7861A275609A68508A5B4C986E5B
9E6D5BAE7B62B97F64BC8B75C48973C69076C08B77BF8B74B98B73BE8D78BA8D76B98A73
B68D74805749452C25412F2E402C252C15106D3F2FB17963A44732BD5B41F2EFF2EBE4E4
E7DFE0E6DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDDE7DEDEE7DEDE
E7DCDCE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DCDDE7DEDEE7DDDEE7DEDFE7DEDFE7DEDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEB59DA828120C2C171342271E3F231F1B0C0B1A09082B1A17150C0C
1910101F1310251817311F1A452925775749D9A993E3B39FE6BAA4E4BCA6E3BCA6E7C1AC
E3B8A7D9A696D6A894C89689CB9481B68A7DB88D7FB88D80B3897DB88375B38170A67A6B
AD7563AA7265AF7765AB6F5BB0715CBB7865BD7C66CC9480D6A792E0B09FE1B9A5E7BFB2
E6BFB0E3BAA5E4B6A4DEAE98DEA894D8A28DCEA18BCA9882BD8374BB7D64AE6F53A96F54
AD7459B77B64B98061BA7F64CC8F73BA866DB68D74B57C63A97A65A6745B996755A67861
AB7864B48068BC8368BE8974C08671C18C73BD8975C08B75BA8B74BF8D79BD8C76BA8B73
A57B656A463A39241F39282A3928242B140F7D4836B3745FA34630BB5D44DDD1D2E7DEDF
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDDE7DEDEE7DEDE
E7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DEDEE7DCDDE7DDDEE7DDDEE7DEDEE7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDFC1ACB7391D162C1813381E18321D1920110F23100E2B1A16170D0D
1A0F0F22151125181735211C4C302B755648D0A08ADFAF9AE4B7A1E4BAA4E5BDA7E7C0AB
E5BBACE0B2A3DEB4A2D6A99BD6A594C69C8EC79D90C89E90C39B8FCA988DC79686BA9083
C38C7CBC8A80C48D7EBE8778C48876CC907FCD937FD6A390DBAF9BE3B6A7E4BCABE5BEAF
E4BAABE3B8A3E3B5A2DEAD98DFAA95DBA792D2A38DD09A86C58B7DC2856FAE725AA46C55
A16652A46854A36C54A36953AC735BA7705CA97A63AF765EAA7863AD7B63A9755FB18066
B17F6AB4806AB88369BA836EB67E69B9836CB88571BF8B75BC8974C08D7AC08B76B98C73
8F635153352C32201B32212534252330171291523FB76F5BA54A34B66148BCA8A6DFD3D6
E6DDDDE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDDE7DEDEE7DEDE
E7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DCDDE7DCDDE7DCDDE7DEDEE7DCDDE7DEDEE7DEDEE7DDDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDFCDBBC54E2B24321C163118142919152A1A152E1B162E1C181D110F
1C0E0E2516122619163A231E513732725446C69580DAA993E0B19CE3B9A2E6BEA8E7BFA9
E6BEB1E6BFB1E5C0B1E3BDAFE1B8A9D5AFA0D5AEA1D7AFA1D3ADA3D9AEA5D9AC9DCCA89D
D7A597CAA39AD6A498CEA195D5A092DAAA9ADBAB97DFB29FDFB7A2E6BCAFE6BFB1E4BCAB
E3B6A6E2B5A3E2B5A1DFAC98DFAC96DDAB97D5A690D59C8BCD9485C98E7BAF76619F6956
94594A9157468C59488B56448B5945925C4B9A6753A8705AAC7661B4826BB9846ABD876A
B88770B5816DB4836BB57C68AC7761B07B65B4826CBF8B74BE8875C08C7AC18974B78A70
764C3E3C261F2D1D192C1B21302223371B16A45B47B86855A54E38AF634C967E7AD5C6C9
E4D9D9E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDDE7DEDEE7DEDE
E7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DCDDE7DBDCE7DBDCE7DEDEE7DCDDE7DEDEE7DEDEE7DDDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDFD7C8D2603A323B231C2F161325171332221B38251E331F1A261613
1F0F0F2817132719173E251F553D376F5244BC8B76D4A38DDDAD98E4B7A1E7BFA9E6BEA7
E7C1B4EAC9BCEACABDEDCEBEE9C8BAE2C0B0E1BEB1E3BEB0DFBEB4E5C1BAE6BFB2DABCB4
E5BAAFD5B9B1E3B9AFD9B7AEE1B5ABE4C0B1E4C0ACE6BDACE3BDA9E8C1B4E8C1B4E3BBA7
E2B3A2E1B3A2E1B4A0DFAC99DFAD97DFAE9BD9A892DA9E8FD49D8DCF9786B37D6BA16B5B
91554A8750408150437E4C3E744939844F408D5946A16A56A9715DB6846EC18C6FC2886B
B98972B37E6CB0806AB17663A4715CAA7560B17F6ABF8A74BF8775C18B79C18772B0836A
5E382E2B1A162B1C1728181D2E20233C1F19A95B4AB25D4CA04F3BA1614B735C57CAB8BC
E3D8D8E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDDE7DEDEE7DEDE
E7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DCDDE7DBDCE7DBDCE7DEDEE7DCDDE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEDCD0D9643E36462A22391D19291A1533231C3A271F311E192A1815
2111102917152C1C19412721573F386F5144B4846FCF9E87DEAD97E5B7A1E8C0A9E6BEA8
E8C1B3EACABDEACBBEEED0C0EACCBEE6C6B7E6C5B9E7C4B7E4C6BDE8C9C1E9C8BDE1C7BF
E9C5BBDCC4BCE8C5BDDFC3BBE6C0B6E7C9BCE7C8B5E8C1B1E5C0ACE8C1B3E7C1B2E2BBA5
E2B4A2E2B3A1E0B39EDFAD99DFAE98DFAF9BDBA994DDA293D9A492D49F8EBE8978B07969
A2655A985E4E905D508A57487D51408953448C59479D6654A16B58AE7B67B98367B87E63
B17F69AB7564AB7A66AF7561A3705BAB7661B47E6CBF8B74BF8876C38B78C08670A0715B
502D252517122A1B172A191C2E2022381F198F483F9A4A3E8C47368A5442634D48BDABAE
E7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DDDEE7DCDDE7DCDDE7DEDEE7DDDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDFE6DDDEDCD1DA613D3552322846282132201A30211A38231D2E1C172C1A16
2413112A1716311F1C432923573E366F5143AC7E69CA9882DEAD97E6B7A1E8BFA9E7BFA9
E7C0AFE9C6B9E9C7BAEBCABBE8C8BAE7C6B8E6C8BCE7C6B9E5CAC1E7C9C0E8CBC2E4CBC4
E8CAC1E1C9C1E8CBC4E3C8BFE7C4B8E7CABEE7C8B7E8C1B1E6C1AEE7C0B0E5BFADE2BAA5
E3B6A3E3B4A0DFB19CE0AD99DEAD97DFAD9ADDAB96DEA897DCA996D9A794CC9787C38B7A
BA8072B37867AA7465A26E5C96655398615093614F9C6454986553A36E5BA97259A86F58
A4715DA16B5AA87361AF7661A6735EB17B66B97E70BF8B74BF8A76C48A76BC846D8A5B4A
4727212517122A1B162E1C1D302020311D17652E2D78362F723B2D6D42355F4843B09EA0
EBE5E7E6DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DDDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DFDFE7DEDEE7DEDE
E7DEDEE7DEDFE6DDDEDBCFD85F3D345E3A2F53332A3B251E2F1F1A39211D2D1B16301C18
2716132A171836211E452A24563C346E4F42A47863C3927BDDAC95E7B6A1E7BEA8E7BFAB
E6BFABE7C1B3E7C3B5E7C3B5E7C5B7E7C7B9E7CAC0E7C8BCE6CDC4E7CABFE7CEC6E6CEC7
E7CDC5E6CDC4E7D0CAE6CBC2E7C6B9E7CABFE7C7B8E7BFB1E6C1AFE6BEACE3BDA8E2BAA4
E4B9A5E4B5A0DEB09AE0AE99DEAD97DEAB98DEAB98DEAC9BDFAD98DDAD99DAA596D59E8C
D19E8BCC9482C38E7DB98773AE7B68A8705D9869579962548E5E4E95604E97624C975F4D
956250966150A36C5BAE7661A97561B67F6ABE7E73BE8A73BD8A75C38873B78169724538
40231E2919142B1C1633201C32211F2A1A15381619562421582E245030285D4540A28F90
EFEBEFE6DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DEDEE7DEDFE7DEDFE7DEDFE7DEDEE7DEDFE7DEDEE7DEDEE7DFDFE7DEDEE7DEDE
E7DDDEE7DEDFE6DDDED3C4CA5D3B326640355C3D31442923301E1A3A201D2E1B16331E19
2B19152B181A3A2320452A245339306C4C409A6F5CB98873D8A58FE5B39EE6BDA6E7BFAB
E6BEA8E5BDAFE5BFB1E4BEB0E5C2B4E6C6BAE7CCC2E6CABEE7CFC6E6CABEE5CFC8E8D0C8
E5CFC7EACFC6E5D2CCE8CDC3E6C7B8E6C9BEE6C5B8E6BEB1E7C1AFE4BCA8E2BBA4E2BAA3
E4BBA5E4B59FDEAF99E0AF98DEAC96DEAA96DFAC98DEAF9CE0AF99E0B19BE3AFA0E2AD99
DFB59DDDAC97D6A48FCB9D86C18F7CB6806BA072619C65578C5E4E8F5A488C59458D5848
8E5B49925C4BA26959AF7962AD7965BC846EC27F76BD8A72BA8973BE836DAC79615A342A
3B201C2D1C162C1C1736221C33211D24181314060A39171641231C38211C5B423C937D7C
ECE6E9E6DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DEDEE7DEDFE7DEDFE7DEDFE7DEDEE7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DDDEE7DEDFE7DEDFBEA8A95B3A306542385E4135492E2835221D3D221F311C18321E18
2D1B162C191A3A211E4027214E332B6444388B6251A87A66C9967FDFAC96E4BAA4E7BEAA
E6BEA8E5BDAFE5BEB0E4BDB0E5C2B4E7C7BAE7CCC3E6CBC0E7CFC6E6CBC0E5CFC8E8D1C9
E5D0C8EAD0C7E6D1CAE9CFC6E6C8B9E6C8BDE6C5B8E6BFB1E6C0AEE4BCA8E2BAA4E1B9A3
E3B9A3E3B39DDEAE98E0AE97DFAB96DEAA95DFAC98DEAF9BE0AE98E0AF9AE4B09FE4AF9B
E1B79EE0B19ADAA793D1A58DC99783BF8B75AD7F6CAA71629B6B599C655299634F996252
9A64529E6654A9705FB37E67B47F6BBE8671C48177BD8971B68670AF79639768534B2B23
361E1A2E1D182C1C1833211B2F1E1C2116130C04072A1312331C172B1A16523934816662
D7C6C5E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDFE7DEDFE7DEDFE7DEDEE7DEDFE7DEDEE7DEDEE7DCDDE7DEDEE7DEDE
E7DCDDE7DDDEE7DEDF9F84805A392D60423A5D40364D332C3C2723402622361F192F1C16
2F1B162C1B18371E1A3B231D482D255A3A307B5445936958B4826CD7A38DE1B6A0E6BDA8
E7BFAAE6BEB0E6BFB1E5BFB2E6C5B7E7C8BAE7CDC3E7CCC1E8CEC5E7CDC3E6CFC7E8D1CA
E6D0C8E9D1C9E7CEC5E8D0C8E7C8BAE7C8BCE7C6B9E6C0B2E6BFACE5BDA8E4BAA6E0B9A2
E2B6A0E2B09BDFAD97E0AC96DFAA95DFAA95E0AC98DEAD98DFAB95DDAB97E1AC99DFAB96
DCAE96DCAB94D6A28ED0A38CCB9984C6927CBB8C78BB8170B17E6AB07864AF7762AE7563
AE7763B07765B37C69B9846DBA8472BE8873C48576BD8971B0806A9C6C577D5343422620
321D182D1D192B1C192D1D1A2B1B1B1F1513130A0B2514112B1714251714472E2A6D4F47
B79E99E8DFE0E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDFE7DEDFE7DEDFE7DEDEE7DEDFE7DEDEE7DEDEE7DBDCE7DEDEE7DEDE
E7DCDDE7DDDDE7DFE07B605957372A59403A5B3F37503730422D284229263A211C2C1A15
311C172D1C17341B17351F1A4127204F31276A463A7F594B9F6E5ACD9982DDB09AE5BBA5
E7BFABE7BFB1E6BFB2E6C0B2E7C6B8E7C7B9E7CBC1E7CCC2E7CCC3E7CDC5E7CDC4E7CFC8
E7CFC7E7CFC8E7CABEE7D0C8E7C7B9E7C7B9E7C6B8E7C1B1E5BDA9E6BEA9E5B9A8E0B8A2
E0B39DE0AD99DFAC96DFAA94DFA994E0AA95DFAC96DEAA94DDA792DBA693DDA691D9A590
D6A38DD7A48DD19B87D0A18BCD9A84CC9983CA9A84CC937FC7927DC48E78C48C76C38A76
C28A76C38A76BD8A73BF8A73C18A79BD8874C28774BC876FA87864875E4C623F343B231D
301E172D1D1A2A1B1A271A192617191E14131C11102216112313122115123D2622593C31
947970E9E0E0E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DDDEE7DDDEE7DDDEE7DEDEE7DDDEE7DEDEE7DEDEE7DADBE7DEDEE7DEDE
E7DCDDE7DCDDE7DFE05B443C543528543E39593D37533B3348322D452D293E231E2B1914
331C172D1D15311915311C173C231C462A215D3C326F4C418C5F4CC48F78D9AA93E4B8A1
E7BFABE8C0B2E7BFB2E7C1B3E7C7B9E6C6B8E7CABFE7CBC2E6CBC1E7CEC6E7CBC1E6CEC6
E7CDC6E5CEC7E7C6BAE6CFC8E7C5B8E7C6B7E6C6B7E7C2B1E4BCA7E6BEAAE6B8A9E0B7A1
DFB19BDFAA97DFAB96DEA893DFA893E0AA94DFAB95DDA891DBA48FD8A18FD8A08AD39F8A
D09984D29D85CD9581CE9D88CE9983D09D87D5A48CD8A189D7A18AD29F87D39C86D29B85
D09A84CF9884C4947BC38E78C58E7CBD8874BE8871B8826C9E6F5B7451404C302735211C
2F1E172D1D1B281A1B2216172114171D12122319152118121F111021151235201C492E22
7E635AE9E0E1E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DDDEE7DDDEE7DDDEE7DEDEE7DDDEE7DEDEE7DEDEE7DADBE7DEDEE7DEDE
E7DCDDE7DCDDE7DEDF513A3254362A553E38573E39563D364D373249312D412722301C17
351D182E1D16301914321C183B221C41271F58393068463C835846BC876FD4A18AE1B49D
E6BCA8E7BFAFE7BFB1E7C2B4E7C5B7E6C5B7E6C8BCE7CBC2E6CBC1E7CEC7E7CBC1E6CEC6
E7CEC7E5CEC7E7C7BAE6CEC8E7C5B8E7C5B7E7C6B7E7C2B2E4BCA8E6BCA9E6B8A8E0B59F
DEB09ADEA995DFAA95DDA691DEA691DEA993DEA994DCA68FDAA28ED79F8CD69F88D29D87
CF9782D19A83CC9581CE9B86CF9983D09C86D6A38CD8A189D7A28BD4A088D49F88D39B85
D29B84D09884C6957CC3907AC48D7ABD8771B7846DAC7A658F6250654538432922301E1A
2D1E182D1D1B2618191F13141E12151B10122218141F16121D11102116132F1B173E271C
8D7168E9E0E1E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DBDCE7DEDEE7DEDE
E7DDDEE7DDDDE6DCDD543A3356392F593E36563F3B593F38523B364D3631442B2638211C
381E19301D17311B16361E193C231D40271F57393167443B805644B67F67CE967FDEAE98
E4B8A3E5BEABE7BFB0E7C1B4E7C2B5E7C4B6E6C7BAE7CCC2E6CCC2E7CFC7E7CBC2E6CEC7
E7CFC8E6CEC6E7C9BDE6CEC7E6C6B8E6C5B7E7C6B8E7C1B2E4BCAAE6B9A8E5B8A6E0B39D
DFAF9BDFA894DDA994DBA48FDBA58FDDA792DDA692DCA58ED9A28DD79E8BD59F89D29D87
D09883D29A84CE9883CE9A85CF9983CE9883D29C87D29B84D09A84CF9881CE9983CD947F
CC957DC9927DC49179C28F79C18975BD846EAE7D689E6F5D7E53435A3C324126202C1C18
2B1E1A2D1C192316181D11121B10131A0F111E13101C13111C12102218142B19143C261D
AC918BE8DFE0E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDDE7DEDEE7DEDE
E7DDDEE7DDDEE6DADB5C3E37573C335D3D3454403C5B403A553F3A503A34462F2A412621
3A1F19321E18311C173A201C3D2420402821583B3268433B7D5544AE7760C68C73D9A792
E1B39DE4BCA7E7BEAEE8C2B4E7C0B2E7C3B5E7C6B8E7CCC2E7CDC3E7CFC7E7CCC3E7CFC7
E7D1CAE7CEC6E7CBC1E7CEC6E6C7B9E6C6B8E7C6B8E7C0B3E5BDACE6B6A6E5B8A4E1B19B
DFAF9BDFA894DCA994DAA28DD9A38DDBA690DCA391DCA58DD8A18DD79D89D49F89D29C86
D19884D29983CE9A84CE9882CD9782CA927ECD9580CB937DC8927CC9907AC8937DC68B77
C58D76C18A75C08B75BE8C77BB846DBB8068A475618E63536B45374F332B422620291B18
291D1B2C1B181F14161A0F10190F11180E101B0F0E1C11111C1311261C172C1914402A22
CAB6B3E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDFE7DEDFE7DEDFE7DEDEE7DEDFE7DEDEE7DEDEE7DCDDE7DEDEE7DEDE
E7DEDEE7DDDEE5D9DA64433C573E365F3C3053403B5C403B58423D543E3848342E472B26
3D211B341E19321E193E221E3F2622422A22593D3469443B7D5645A66F59BE8168D49F8A
DEAD97E2BBA4E7BEADE8C2B3E7BEB0E7C2B4E7C4B6E7CCC1E7CDC4E7CFC6E7CDC3E7CFC7
E7D1CAE7CDC4E7CDC3E7CDC4E6C7B9E7C6B8E7C5B8E7C0B3E5BDACE5B3A5E4B8A2E1AF9A
E0AE9BDFA793DAA893D8A18CD8A28BD9A48FDBA18FDBA48CD8A18CD89E89D49F8AD39C86
D19985D29883CE9B84CD9580CC9480C78D7AC88E7AC48D77C08A76C38973C28D77C18471
BF876FBA836FBC8571B98873B47D66B47961986C5A7E584A5B392D462D27422520281B17
281C1C2B1B171D1315190E0E180E10180D0F170C0C1B0F111E1513291E18311C17523831
E2D6D6E6DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDFE7DEDFE7DEDFE7DEDEE7DEDFE7DEDEE7DEDEE7DCDDE7DEDEE7DEDE
E7DDDEE7DDDEE4D8D962423B563D3759382D553F395B403B5A443F58423C4C38324A2E29
412420341E1934201A412520422924432C25573B3268443A7F57479C6752B67960CE9680
DBA892E3BAA3E6BEACE6C1B1E7BEAFE7C1B3E7C3B4E7CAC0E7CCC2E7CCC2E7CBC2E7CCC3
E7CEC6E7CCC2E7CCC2E7CABFE7C6B8E7C4B7E6C4B6E7BEB1E3BCA9E4B2A3E3B7A0E1AD98
DFAC98DEA691D9A590D8A18BD8A18BD8A48EDAA08DDAA28BD7A08CD79E89D49E89D49B86
D29985D19885CD9983CC937ECB927EC68C79C68C79C38B77BF8974C18772C28B76C28471
BE866FB9836EB98470B4836EAC7761A56F588C6253724D415131274128243E241F281B18
281C1C2D1C181E14151B0F101B1011190E10150A0B180D0F1F1614271B1639221C785850
E9E1E3E6DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDFE7DEDFE7DEDFE7DEDEE7DEDFE7DEDEE7DEDEE7DBDCE7DEDEE7DEDE
E7DCDDE7DCDDE4D7D85E423A533C3651332B573D365A3F3A5B453E5B453F503C364B312B
452925341E1936211C422822442B26452E27543830674439805949925F4CAE7159C68C74
D8A38DE3B9A3E4BEAAE5C0AEE6BEAEE6C0B2E6C1B3E6C8BDE6CAC0E6C8BDE6CABFE6C9BF
E6CAC0E6C9BEE7CABFE6C6B9E7C3B6E7C3B4E6C1B3E6BDAEE1B9A4E3B2A0E1B59FE0AC96
DDA894DCA58FD9A38DD8A28BD8A08CD7A38ED99F8AD8A18AD7A08BD7A089D59C88D59B87
D29985D09A86CC9782CB907CCB907CC78D7AC68D7AC48D78C18B75C18874C58B77C58773
C08872BB8570B6846FAD7D68A3705C91634E7F594B6844394B2B233D252237211E281C18
281C1B2F1D1A1F15171D11121F13141A0F11130A0B150B0D211614251813462C25A3807A
E9E1E2E6DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DBDCE7DEDEE7DEDE
E7DBDCE7DCDCE3D7D85E443C533C37492F28593B32583E395B453D5F4742543F394C342D
492E2A341E1939231E422A23462E2848302951352D654538815B4C885847A56A53BD8169
D39C87E1B6A1E0BBA6E2BEA9E4BEACE4BDB0E6BFB1E5C5BAE5C7BDE5C4B8E5C8BDE6C6BA
E5C6BAE6C6BAE7C8BCE6C2B3E7C1B4E7C1B1E5BFAFE5BBABDEB69FE1B19DE0B39DDFAA94
DBA590DAA38DD8A08AD8A28AD9A08CD7A38DD89E88D7A089D79F8BD7A18AD79B87D79B88
D29A85D09B88CC9680CB8F7BCB8E7AC88E7AC58E7BC58E79C28B75BF8774C78977C88874
C08772BB8671B2826CA476609869567D5543714F435D3B314627203B2320321F1D281C18
281C19301F1C2017182013142316161C111210090B12090B261817261712563831C9ACA9
E8DFE0E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DADBE7DEDEE7DEDE
E7DADBE7DBDCE3D7D8634B43533C37442D275A3A2E563D385B443C60484358423C4D372F
4C322E36201B3B241F422B24472F2949322B4F342C6345377F5A4C7D514299614DB2765E
CC937EDFB19CDDB8A2E0BBA4E4BEABE3BCAEE5BDAFE5C2B6E5C5BAE5C1B4E5C6BAE6C3B6
E5C2B5E6C4B7E7C6B8E5BFAEE7BFB2E7BFAEE4BDACE4B9A8DDB39BE0B09BDEB09ADFA892
DAA28CD8A28BD79E87D8A289D99F8CD6A28BD69D86D69E88D79E8AD7A18AD79985D79A88
D29A85D09C88CC947FCB8E7BCB8D79C88E7BC58E7CC68F7AC28C75BE8774C78875C78874
BD8671B8846EAB7C669A6C578C5F4E6A483964453B53332A40231D38211E2D1D1B281C18
291B18311F1C2117192114162418171B11120F090B12090B2818182E1A156F4D47E3D1D1
E7DDDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DADBE7DEDEE7DEDE
E7DBDCE7DCDDE4D9DA715851543E38452E2959392D553E3859423B5E46415C443F4F3931
4C332E3D26213C25203F2A23452E2748322B4F352E5E4235745448734A3E885645A46D56
C18671DAA892DEB29CE2B9A1E7BFABE7BEAEE7C0B0E6C2B3E7C5B8E7C2B3E7C6B7E7C3B4
E7C2B3E7C3B5E7C5B5E5BDAAE6BEAFE6BDAAE5BBAAE4B7A5DFB29BE1B09BDEAE97DFA791
DAA18BD9A28BD79C86D8A187D79D8AD6A089D49B84D69D86D59D88D69E87D69884D59883
D19882CF9985CC917ECB8E7BCB8E79C88F7AC58E7BC6907AC38C74BE8875C38673C38671
B8826DAF7C679F6F5B8E5F4D7C52445F3E31573A32472C23371F19321E1B291B1A281C17
2A1C182E1D1B2117181E12151F1414160D0F130B0D180E0E25161440261F96726CEBE0E1
E7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DBDBE7DEDEE7DEDE
E7DCDDE7DDDDE5DBDC856A6558413B4A332E57382D553E385640395A423D5F4641513B34
4B332D462E293C25213B2721432C2547312C4F3731583E34664A4169453A754B3D946450
B37762D29C85DDAB93E5B69EEBC1ABEBC0ADE8C2AFE8C1AFE9C6B6EAC4B3E9C6B4E8C4B4
E9C3B1E8C2B4E7C3B1E5BCA7E4BCACE5BAA6E5B9A8E3B4A3E1B29CE1B09BDEAA94DFA690
DCA089DAA18BD69B85D79E84D59B87D69D87D29983D79B85D39B86D59A83D39681D1947D
CF957ECE9580CC8E7CCB8F7BC98F7AC68E79C58E7AC59078C38B73BD8874BD856FBB836C
AF7D66A3715C90604D8152426B443956352B4B2F283D251D2C1B152A1A16261918261A15
2B1C172A1A18211516180F12170E100E090B190E1022151422141158382FBD9F9BEAE2E3
E8DFE0E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DBDCE7DEDEE7DEDE
E7DDDEE7DDDEE6DDDE977C7A5F474052393456392E543E39533D37563E39614743543D37
4A332B4D37313C252137231F402922442F2B4F3934523932584039614038634036865D4B
A46953C89077DBA38AE6B29AECC0A9EEC1ABE8C3ADE7BFA9EAC4B3EBC5B1EAC4AFE7C2B2
EAC2AFE8C0B2E5C0ABE3B8A3E1B9A7E3B7A1E4B7A5E2B19FE3B09DE0AF9ADCA68FDDA48E
DB9E87DA9F8AD59883D59980D19784D49983CF9681D89983D19883D4957FCF937ECD9077
CC9179CC907ACB8A7ACB907AC88F7AC48D77C58D78C49076C28971BC8772B7826BB37E67
A6765F9665518050407244375A372E4F2D253F2620331F18231712221712221716241913
2B1C172617141F1314130C0F0F090A0704072111132E1F1C221410704D43DDCDCCE8DFE0
E7DFDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DBDCE7DEDEE7DEDE
E7DEDFE7DEDFE7DFE0AB90916B514A583F3A55392F543E38513B36523B36624742553E39
4A332B533D373C252235211D3E2720412D294E3A354D36304D39345A3D36553930785445
925B47B9826AD2977FE0A891E7B9A1EABBA3E5BDA6E4B9A1E9C0ADEAC2ADE9C0A9E5BFAE
E8BFABE7BCADE3BBA5E1B59FDFB6A2E1B39CE3B4A2DFAD9BE2AD9BDDAA95D89F89DA9F89
D99A82D89C87D39580D2957CCF947FD3967FCD937FD79680CF9580D2917ACC917BC98C72
CA8E75CA8C74CA8777CA8F79C68F79C28B74C48B75C18D73BF866EB8836EAF7C65A97660
9C6D568859476F433464392D4A2C25462620351F1A2A1A141C130F1B130F1F1414211712
291A151F12111C11120F0A0C090507040206261414392822301D178B675DF0F0F0E4DBDC
E6DDDEE6DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DCDDE7DEDEE7DEDE
E7DEDFE7DEDFE7DFE0C0A8AA7E635D59413A52382F543D37533C37523B355E433F57403B
4E362F543E373D262236211D3E25203E29264C38334B342F4B3732563C364F372F6A4A3E
7D4E3EA4705DBB856ECA9580D3A68FDAA992DBAB94DAAD97E3B7A3E3B9A2E4B8A1E3B9A5
E4BAA5E2B5A5DFB69FDFB19BDFB59FE0AE98E3B29FDEAA97DEA996D8A08AD1977FD2967F
D2937CD49780D1927BD19179CE927CD1937BCE927DD4937CD0937ED28E78CD907AC98C71
C98C71CA8B72C98676C88D78C48D76C18972C18772BC886EB6816AB07B65A6735D9C6A56
905F4B7A4D3C613A2D5730263E251F3B201B2C1B15241612180F0D19100E1C11121D1310
221512170D0D150C0F0E090C0C070A0B06092211113B2922573830AB8981F3F7F8E4DCDC
E6DDDEE6DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDE
E7DEDFE7DEDFE7DFE0D3C0C3947A765A423A513830543B35563E38543C36593F3A58413C
523B34533C353E272238211D3F25203B26224A35304A342F4E3934543C374F38315F4038
6A43388D5F519E715DAE7E6BB78D79C3927DCC957FCC9E8AD9AC97D7AB95DDAE97DEB099
DCB29DDBAB9ADAAE98DCAD96DEB39BDEA894E2B09BDBA692D8A28DD0937BC68C74C88B73
C88A73CD9077CD8D73CE8C76CE9078CE9076CF9079D09077D1907BD18B75CE8F79CA8C73
C88A6EC98B70C88573C58975C28A71C0846EBC836DB47F68AB7A65A46F5A9B67538E5C4A
82503F6D42335633274C2A2036201B2E19162618121F1211170C0C180E0E190E10190F0F
190E0E0E070A0C080B0F0A0D140C0F170E101C0E0D3D2922845D55C7ADA9EFEEEFE6DEDF
E6DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDE
E7DEDFE7DEDFE7DEDFE4D8DAA991915E463C533B33553C345B413A553D3852393459423D
573F3A5139313F28233C231E41252138221F48312D4A352F513C36543E39503B34553732
583932764E45815D4D9067579A7463A97A68B97E69BD8E7DCE9F8AC99C86D3A38CD6A68D
D2A894D1A08FD3A690D7A78FDBAF95DBA08FDFAC95D6A08CCF9A84C6856CB98168BB7F67
BB8069C3886DC8876BCA8572CC8C72C88B70CE8D74C98B72D08B77CE8771CD8D76C98B73
C58769C6896EC48370C08470BE856ABC7F69B67D67AA76609F725E96634F8F5B487F4E3F
73423360372A4B2D2341241B2F1D182413122016101B0F10160A0C180C0E170C0E140C0D
0F0809050205040407130D0F1E13162718191A0E0B422A23AC8580DED1D1E8E0E1E7DFDF
E6DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DDDEE6DDDEEFE8E9BCA9AB6B51465A423B563C345C413A553E384D363159433D
59423D50372F412A243F251F41252136201C462F2B4B3630563F3955403B533F384F3430
4D342F64423D6A4D40775648805F51926757A66C58AC7E70BF907BB88A76C3937FC9977E
C39986C29280C89884CD9B84D3A48BD29685D6A48CCC9882C28F78B7785FAA755DAB715B
AD745FB67C62BD7D61C17C6AC5856AC08368C9876DC1836ACB8571C8816BC88770C48670
BF8263C08468BD7D69B87D6AB77D63B57762AD755F9F6B58926756885643814E3E6F4034
63362A532E2441271E381F172A1A151C100F1D140F170D0F14080B170A0D13090C0F090B
070406000003000104150E1024181A34211F23130F56362FCAABA9ECEBEFE1D4D5E7DEDF
E7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DDDEE6DDDEF1EBECCCBDC0896C626A514B543B34563C35543D374F383258423C
56413C523A32452F284227213E242137201D472F2A4C36305A423D58433D58433D523835
4D36315B3F3A61483D6E514473554A855E5097634F997163AC7E6AA37665AA7D6CB2816C
AC8270AC7F6DB38370B8836EC18F78C28875C3947DBA8973AC7E6AA26E57986955986250
9D6651A26C56AB6F55B06F5CB4765DB2765CBC7B62B67960BF7B66BB7862BA7C65B67C65
B4785CB2775DB0725DAC7460A9725AA76D589F6956936150875B4A7A493970423460362C
552F2545282037201A311C172618131A0F0F1B110E140B0E11060912080B0D060A0B070A
080407040205020205140D0E1E141636221E40261F835B54DAC3C4EFF1F5E1D4D4E7DEDF
E7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDEE6DDDEEDE7E8DACED0AA8F897E6461523B354D362F523C36543C3756403B
513D38543E374A342E452A243B232038221F48312B4E37305D46405B45405D474158413E
543C3859403B61483F6D52476D52477F5B4D8C5E4C886557966B598D61538D6558966959
8F6858926A599A6B5A9D6856A97661AD7862AB806BA37761946B5B8B6451845C4D835346
8A56448A5A49945E489B5F4B9E644EA0674EAA6C55A96C54AF6F59AB6D56A86D56A26D57
A46C53A068509D634E9E685498645096614D905C4B8557487B4D3E6C3E315E372C522D25
492A223A231D2D1A152A19172316121A0F10190F0E120A0D0E05080C0508070407090609
0C070B0C070A0A0609140B0C170F1037211D654039B48D88E2D2D3ECEBEDE4D9DAE7DDDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE8DFE0E6DDDEC8B3B3927A7A543D3848312B533D3759423C533E39
4B393455423B4E3933472D2738231F3B25224A332C4F38316049445E4842634B465F4C47
5B443F5A433E644A426E554A6950477A594B815A49775A4B805949764E43704E45795247
714F417855467E53457E4E3F8D5C4B966750916B598B64507A584B765A4A7250456E453C
77483871483C7B4D3B844F3B8652408C5740955D489A5F489C624C99614B935D488D5D49
935F4A8C57438953408D5C498556458454417E4F41764C406D41325D32284C2C24452620
3D261F301E1B2515122517172014111B1012190D0E100A0C0A0407070306020205080509
120C10190F11170E0E190D0C130C0D3A221D895D58DAC3C1E7DEDFE8E0E1E6DDDEE6DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDE
E7DEDFE7DEDFE7DEDFE3D8D9EEE6E7DCD0D7A690945E47434A332D543D385C453F513C37
47373156453E513D3749302B3825213F29264C352E533B34634C46614B44664E4964544E
624B455B4640664C456F564D684E467556497856476950426D4A3C613F36583D37614039
573B30604338664236623B2F72473A7E564179594A74524164473E634F4360443C5B3932
643B2E5B3931633D306D402F6E41337647347F4D3C87513D87533F8454407D4E3B774E3C
7F513F7648377344337A4F3D72483B7046376C42366741375F3529502A223D241D3A201B
34221C281B191F110F2015161D13101B1012180B0E0F090C080306040205000104080609
1710142215152415132614111F14144D2F28A97C7BF0EEEDEAE5E6E3D6D6E8E1E1E7DEDF
E6DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDE
E7DEDFE7DEDFE7DEDFE2D8D9EFE8E8E5DCE4BBA8AD775E5B5B413C533C37563F3A4F3A34
4A393356453F533F394C332E402C27452F2B503A325A413A654D47634D46664E4965544D
634D465C4741654D466C524A684C446E4F426F504464493D614237543730503833553A33
49322A5138315A3B3355352B5F3B3268463A684B3F624438583C3456423A5339344C302A
5230274A2F294F32285935275A352A60392B6A3F316E42326F44336F45356A4232654133
6A4233633B2D5F382A644030623B305C3A2E5C372C56362C522D2345261F341F19321C18
2D1E192519171B0F0E1A101219100E170E1013080C0D080B080407060306030406080608
140D101D12112B19164024204A33307D534EC39D9EF4F8F8EAE6E7E3D6D5E8E0E1E7DEDF
E6DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDFE5DBDCECE5E5E7DFE4CEBFC4967C7B735753533D384E38334F3933
513D3755443E543F3A4E37324935304C3531543E37614942664E47654F48634D47634F49
614B455C4640624C45664C43694941664739674A4061443A5B3E344C332D503934513933
442F2948322E563A3550372D51342F5538345B413855383251352E4C363147302B412A24
4328233D29223F2922482B21492C224B2D2355322754322857342859372A59372B54362D
5433285231254D2D234E3224533026492E254D2E24442B214627203D241D2F1D172C1915
271A152317151A0D0F140B0D150D0D110A0C0D06090C070A0A06090A07090B080B0A0708
100A0C170D0D321E1A613A377E5E5BAF8685D7BCBEEFEEEFEAE5E6E5DADAE7DFDFE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE6DDDEE8DFE0E7DFE0DFD4D8B49B9D8B6E6E573F3B48332E513A33
59423D56443F543F3A4F3A34523E38523B3657423C68504A664D46665049604B45614B44
5F4A435D463F604B4461463E6C473E5F40325F443D604037573B3347312C523C364F3B33
412D2A412D2C533A384D3A31462E2C442B2D503831492F2D4C2F29422C2A3D282437241F
36211E33231D31211C39221C3A231C37221B42271F3B241E41261F442A21492E25462C26
3F261D42271E3C241D38241A45261E38231E3F251D3421183B221E37231C2B1C16281814
231712221714190D0F0E0709110A0C0B06090804070B070A0C080B100C0E161012110B0B
100A0A140B0A3D2521805453AE8E8AD6BEC1E5DBDBE8E0E1E7DFE0E6DDDEE7DEDFE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE8DFE0E3DADBE6DDDBEBE3E6CCB8BCA3888A654B484A342F543B34
5D444054413C543E39503B3659443F56403A59453F6B544E644C446550495C49425F4640
5D47415E463F5D48415C41396B453B57392B573D385E3C34533833442F2B543E384E3B34
402D2B3D2A2B4F3A394B3B333D292937232747302C3E2727462A253A242334221F30201C
2C1C1B2A1E1A261A172D1C182E1C17281916321D182819152F1C17331F193A251F382320
2D1B16341F192F1C18271913381E192A1A18321D17261811311D1B30211A261915241613
1E1310211613180D100A04070E080B0704070604060C080A0F0B0D1510121F15171D1210
1E12102415125436329E7174D1B8B6EBEBF0EEF0F0E1D4D4E5DBDBE8E0E1E6DDDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE8DFE0E3D9DBE7DDDCEEE7EAD9CACEB8A1A586696759403B563D36
563F3A4C3A35523C374F3B365A464056423C59453F68524C604A42624D465A463F5D443D
5A453F5E463F58413A583E376440365032274D343055362F4F3631422D29503A354B3631
3F2C2B39272C483434453732372425311F233D28273421223B2321321F202D1E1C2C1E1A
2619192419161F15142517162618152115132818152115122616142718142B1B172B1A19
2114112919162416131F130F2D18162215142617121C110D231516271A161D13111C1110
160E0D1A1010150B0E0A04070D080B0804070C070A100B0D100B0D1711122216162F1E18
442A25573732835D58BA9397E0CFCDF0F6FBEFF3F3E1D4D4E5DADBE8E0E1E6DDDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDFE5DBDCE7DFDEECE5E6E0D4D8CCB9BDAC909170544E59413A
4D383244322D4F3A354E3A3459443E54433D58433E624C465B47405E494357423C5B433D
57423C5E4840533933553C365A3A31492C24412B264A30294B342E422A27493430462F2C
3E2B2A36262D3E2B2B3E2F2E331F212E1D203422222B1C1D2E1B1D2C1C1D281B1B291C19
2216171E14141B11122014142215151F14142215132015122315132013111E1210201314
1B11102115141D12101C110E2414141E13121D110F150C0B170E101E1212130C0D140D0D
0E0A0B110B0C11090D0C06090E090C0C070A160D10160F11120C0E1A1211241515462D25
734D47916864B38F8CD2B6B9E5D9D8EDEEF1ECECECE4D9DAE5DCDCE7DEDFE6DDDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DCDDE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDFE6DDDEE7DEDFE8DFE0E6DCDEDDD0D3CEB9BE886964604740
46332D3F2D28503B354F3B3559423D53443E56413C5B463F54433E59443E543F3959423B
543F3A5C48414D322C523B3650342C43272136231D402A2448322C422825442E2A422927
3F2A2A35252E35232439282B301C1E2E1D1E2D1D1D23191823151827191B241A1A281B18
1F15161A10121A0F111D12132014151F14151F13132117132215141B1110140C0B180E0F
180F101C131319100E1C100F1D12131D1212160D0D11090A0D080B160C0E0B06080E090B
0806080A06090D080B10080C0F0B0E110A0D2315181F16171810102116132A17155F3F35
9D726FC29E9CDAC5C4E4D8D9E7DEDFE8E0E1E8E0E1E6DEDEE6DDDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DCDCE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE6DDDEE7DFE0E6DEDFE3DADAE9E1E0E9E0E3E5DAE2A1837E70554E
4D393244312B523C36503B3557403A50423C533F3954403950403C55413B533D3858423C
523D385A4740462C26503B36472F283D231F2D1D1736251F422E294025233D28253C2323
3D282833232D2C1D1D3322272E1A1C2E1D1C28191A1E15151B111523171922181A261A18
1E1416180E11190E101B10131E13151F14161E12132319152417161B1111110A0A160D0E
1911121B131419100F1E11121B11141E1313130C0C11080B07050911090B0703060B070A
0605080804080E090B140B10130E10180E112C1B1C271C1C221615311E193C221E7E564C
BF9797E3CDCDF0EFEFEEF1F0E7E0E2E2D4D4E3D6D7E8E1E1E7DFE0E6DDDEE7DEDFE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DCDDE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE6DDDEE7DFE0E6DDDFE3D9DAEAE2E2ECE6E7ECE6ECBA9F9C91746F
6E554D5E453F56403A4E3934503A35483A354E3B36503C3650403C55423D57413C5B453F
533E3953433D3E28224E3935412A2338201D291A162F201B38262438212036231F351F20
3522222F20262518172C1D212A181A291A192417191B12131A10142014171F1618231716
1C1214180D11160C0E170D101A10131D12141B1112231916281A1A2015161A10121F1213
1F15171D14161E14132012151E14171F1315160E0E140B0E0B080B130A0D0B06090F0A0C
0F0A0E120B0F160E111A10141912141C11122A19192B1D1B321F1B4D3128653E38A37A72
D3B4B5ECE0E1F4F9F9F0F5F3E8E2E4E2D4D4E3D5D6E8E0E1E7DFE0E6DDDEE7DEDFE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE6DEDEE7DEDFE6DDDEE5DCDCEAE2E2EBE4E6EBE4E8D0BCBBB69B98
987C767F635E5E45414D393448353141322D4A39334E3B3553423D5746415C47415F4844
56403C4C3D383826214E39343D2721341E1B291A192A1C192D1E1D2F1C1C2F1E1B2D1C1D
2B1B1C291C1D1F141326191C2517182316162115181A10111C12151D12151E13151E1313
1B1113190E11130A0C130B0E160D0F190F11190F102117172B1D1F261A1E271B212C1B1C
291C1E21161A26191B22151923181B2114171B1212190F13140E0F180E10150C0E160E10
1C1317221619231618201518231719231513261613301E19472C246E4A3F936660C3A39F
DEC9CAEBE2E3EFEFF0EDEDECE9E2E4E5DADAE5D9DAE7DFDFE7DEDFE6DDDEE7DEDFE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE6DEDEE6DEDEE7DFDFE7DFE0E8DFE0E2D7D9D6C3C4
BEA6A39F8482684E4A4F3B3744332E3C2D284838334F3D375945405B4B47634E49634D4A
59433F4537343324204D38333A251E321E1B2A1C1D271917231617261719291B1726191A
2115152317151A11102115172217161E13132015181B0E112014171C10131D11141A1012
1B10131B101112090B10090C130B0D160D0F190E102217193021252E21283428313B2625
332327271A1F2E1E2325181E2A1C2023161A2217172015181D15141E13141F14121F1315
2B1C203424243220212A1E1E2F1F1F2D1C152614103821185F3C2E8E6659B9928CDCCDCC
E6DCDCE7DFE0E8E0E1E8E0E1E7DFE0E7DEDEE6DDDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDFE6DDDEE7DEDFE8DFE0E5DCDDE4DADBE4DAD9EEEBEEECE3E7
D9CACBB9A4A57A5E5C5D46434C3A3543312C4A3B35513E385C46405B4B4864504B644F4C
5C4541423532362823513B363C272034201D2E1E212618161C11131F1416251814211717
1B11111F151019100F1D12141F16151B11121E15171A0D102215171A0F121C1012180E10
1A0F121D1112130A0C10090C110A0C160C0E1A0E1022171B33242933262F3D323F462F2D
3C2A2F2D1E2435232A281C2330212427191D291D1C271B1E271C192619192A1B17291919
372527402E2C3E28273225233D27253D261A331C144B2C1F7E5240AC8478D4BBB4E9EDEF
EAE8E8E3DADBE1D3D4E3D5D7E6DCDDE8E0E2E8E0E1E6DDDEE6DDDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDFE6DDDEE7DEDFE7DFE0E5DBDDE4DADBE4DAD9F0EFF2F1ECF0
E4DADCCCBBBE9B7E7D7F64626A534F61494253413B503E3855403A51403D5A47415D4846
5C4541493A384635315C454048312A3A2522362223291A181E13141E1214251815201716
1D12122015101C12101D12131F15141A11121B1214150A0D1B1113170D10190E11170D10
180D101D1212190E11130B0D110A0C180D101B101123171D322429342631403542453032
412F3434242937262D2B1E253223252D1D223022202D21222E201D2F201F31211B301E1E
3A27273F2C283E2824382722492E2A52332658352A6F4639A57565C4A299E0D1CBEDF4F6
EBEAEBE4DBDCE1D3D4E3D5D6E6DCDCE8E0E1E8E0E1E6DDDEE6DDDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDFE6DEDEE7DEDEE7DEDFE6DCDDE5DCDDE6DDDDEDE9EBEDE8EA
E7DEE0DACDCFBEA5A6A78D8C8F7675876B64614A45523F3A4D393343332F4C3A3552403E
5C45405444415B47446A524D583F39442E293F27242F1E1A261717201315291A19221715
2417162518142216131F13132015141D1214180F1110080B130B0E150C0F170D10190E11
160C0E1D1213211519180F11120B0F1C10141E131324181F2E222732243040333F3F2E34
4333383B2B2E36272D2D212631232434222736272435272633232139272538251F372422
3A27243A25203C25203E282156372F6A443886584E966B60C79F95D7BEBAE5D9D7ECECEE
EAE7E8E6DFDFE4D9DAE5D9DAE6DCDDE7DEDFE7DEDFE6DDDEE7DEDEE7DEDFE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE6DDDEE7DEDEE7DEDFE8E0E1E8E0E1
E7DFE0E5DCDEDCCED0CAB7B9B29C9FAA918A72565056433E48352F382925402F2A4A3A37
5E4841624F4D705B5A78605C694F4A4F38314A2D2437231F311E1B2515172F1E1E261A16
2F1E1B2C1C192B1C18241616231616201517170D0F0D07090D0709150C0F160D0F1B1013
150C0E1E1314281B211E1415140D112013182217152519212B202531212E40313A382B35
44363A41323336292C3024263224233C282D3E2D283E2E2A3A282646302E402B24412D29
3D292336211B3C251D482C2164423683554EAD8078B4948DDFCAC8E5D9D9E7DFDFE8E0E1
E7E0E1E7DFE0E6DDDEE6DDDEE6DDDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE6DDDEE7DEDFE7DFE0E7DFE0E2D7D7E2D8D7
E6DDDEEDE6E6F0EDEFE2DADECEBDC4C7B4AE88686466514C513C363C2A25402E294A3937
614A446C57557D6868806965745B5758413A553327412B253C27212E1A1B3824252E1F19
3A252234222035231F2B1B1A28191A281B1D1C0F11120A0C0E080A190F12191012211418
180E10211617302229261A1A1A121729191F281D192B1E262B202532212D423037352A36
46383C473836382A2C352827352723432D3144322C45332D3F2B2A4E363348312949352E
442E253E241D482D225D382A7B55459D6A6ACAA6A1C9B8B6EBEBEFECECEFE8E0E3E4D5D5
E5D9DAE7DEDFE8E1E1E8E0E1E7DEDFE6DDDEE6DDDEE7DEDFE7DEDFE7DEDEE7DEDFE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDEE7DEDFE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE6DDDEE7DEDFE7DFE0E7DEE0E2D7D7E2D8D7
E7DEDEEEE8E8F4F3F5EAE6EADCCFD6D7C9C5A7878489716D755B545C433E57413B574441
634C4669555377616178625E7059555C4640593A314A342D472F283B2524422C2C392720
412C283B26243D2A253623213121223425272A191B25171820141624181C23181A2B1B21
24161A281C20382930312424271C2336252B34262237282F33272C3827304734383B2F38
4B3A3C4D3B373E2E2E3D2E2B3D2B26472F3045332C47322B412B294E35304E332A4F3932
52382E5A372F6D493C86584A9F7767B98A8DD9BFBDD6CDCDEEF2F7EDEFF3E8E1E4E3D5D5
E5D9DAE7DEDFE8E0E1E8E0E1E7DEDFE6DDDEE6DDDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDFE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE6DEDEE7DEDFE7DEDFE7DEDFE4DADBE5DCDC
E8E0E0ECE5E6EFECEDEAE4E7E2D8DDE0D5D3C5ABABB19A99A1867F8569677A5F596D5652
68514C63504E6A54526B565167524F604A475A423E543E385138314B33304D363346312A
49342F452C2846322D422D293B2C2E4332353D292A3E2B2A39272933252A31232538252E
32222932242B402F353D2F2F37293146333A41312D47353A4031354130364F3B3C46373C
523B3B533D364833304835304A312A4A322E47332B493128432B264B322B54362B573E36
67463B7F534D986F64B08379C2A096D1AEB2E1D0CFDFD8D8ECEBEFEBE9ECE8E1E3E5DADA
E5DBDCE7DDDEE7DFDFE7DFDFE7DEDFE6DDDEE6DDDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDFE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDF
E7DEDEE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE6DEDEE6DDDEE7DEDF
E7DFDFE8DFE0E8E0E1E8DFE0E7DEDFE7DEDFDED1D2D4C4C7C8B4B0AA93969B807A846B65
6E56535E4C4A5C47445F4B45604C49644F4E5C4B4C5E4B455D433D5D443E5B433D563E37
533E3850342F513C37513A34473A3C544245513B3D58423E523E3F43343C41303445313D
41303B3D2D3A49373B493C3C49384256454A503E3B5945464E3E414D3B3D59444154423F
5A3E3B5B4037553934553D375A392F50362E4B352D4E3128482E264B31275D3B2D60443B
7D554BA07370BC9792D0B2ADDDCAC7E3D4D6E6DDDEE7DEDFE8E0E1E7E0E1E7DEDFE7DDDE
E6DDDEE6DDDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDF
E7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDE
E7DEDFE7DEDFE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDF
E7DEDEE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDFE6DDDEE6DDDEE7DEDEE8E0E1E8DFE1
E6DDDEE4DADBE1D6D6E4DAD9E9E1DFEAE3E5EEEDF0EDE5EBE3D9D8C6B9C0B8A09C9E837E
7E65626652515C47425F4B44644F4C6D585962575C6A595469504C6E564E6C534A674C47
614C4660403A5E4844604942534A4B635153624D4E6C564E65525152434B4F3D41513D4B
4E3D4B473747523D4053464757454F6252555B484567524D5B4849574541614A44604A3F
61403A62423862403861453E694136593E32553C345C382E58382D58392E70483873534A
966A63BB9394D5BBBCE2DAD9ECEAEEECF1F0E9E5E7EBE1E3E3D6D5E4D8D7E6DBDBE7E0E1
E7DFE0E7DEDFE6DDDEE6DDDEE6DDDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDF
E7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDFE6DDDEE6DDDEE7DEDEE8E0E1E8DFE0
E6DDDEE3D9DAE1D5D6E5DADAEAE2E0EBE4E7F1F3F5F3EEF4ECE6E6D6CDD4CCB9B7B9A09B
9D8382856F6F7A615C7C645D7E67647E696B6F666E776563745D5C7A655F7F655D775C5B
76615C72514C6F58567158526257596E5B5B6D5858725D556B59575D4D535946495A4652
574450503E4B5540415849485C494F6453525E484569524B5F4A485B4640614A41624A3D
6140386443396A463C684A4170483E694B3E6B4D467A4F457B54497C574C92665897746C
B48986CEAFB1E0CFD2E8E8E8EFF2F7EEF6F5E9E7E9ECE3E4E3D6D5E4D7D7E6DCDCE7E0E1
E7DFE0E7DEDFE6DDDEE6DDDEE6DDDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DDDDE7DDDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE6DEDEE7DEDEE7DEDFE7DEDF
E6DDDEE5DBDCE4DADAE6DDDDEAE2E1EAE3E5EEEBEDEFE9ECEBE5E5DFD7DCDACBCBD0BDBB
BFA9A9AC9899A38987A38B84A18988927E818376818671737F6B6F847171927974876D70
8E787684656381696A81686475646678636178605E735D576D5957695457624E4E634E56
5F4A505B454D5843425C49465F4A4A634E4A5D4640664E47624A4460463D61493F62483C
60413765463B714D416E4F467550497C5D5186655E9D7066A37972A58179B58D85BD9E9A
CEAEADDCC6C8E5D9DBE9E6E7ECEBEFEBEEEEE9E5E7EAE3E4E5DBDBE5DADBE6DEDFE7DEDF
E7DEDFE7DEDEE6DDDEE6DDDEE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DCDCE7DDDEE7DDDEE7DDDEE7DEDEE7DEDEE7DEDFE7DEDFE7DDDEE7DEDEE7DEDEE7DDDE
E7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDE
E6DDDEE6DDDEE6DDDEE7DEDFE7DFE0E8DFE0E8E0E1E8E0E1E8DFE0E7DEDFE6DCDDE4D9DA
DDD1D2CFC2C5C7B3B5C7B3AEC2ADAEA69496978794957D838A79828E7E84A48C8B957E86
A38F92947B7B927B7E917877887172836A66826764755D596F5A58775C5A6C56546D5659
69514F674E4D5D4743624A44634B45624A435E453C644B43654A4165463B61483E64483C
61433868493F78554775554A7A58548E6F659E7D78BA9389C4A09FC6ADA9D0B5B4DCC8C8
E1D2D4E6DBDCE7DEDFE8DFE0E8DFE1E7E0E1E7DFE0E7DFDFE6DDDEE6DCDCE6E0E1E7DEDF
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDE
E7DDDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DEDE
E7DBDCE7DCDDE7DDDEE7DDDEE7DEDEE7DEDEE7DEDFE7DEDFE7DDDEE7DEDEE7DEDEE7DDDE
E7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDFE7DEDFE7DEDFE6DDDEE6DDDE
E7DEDFE7DFE0E8E0E1E7DFE0E5DCDEE5DBDBE2D5D6E2D7D6E4D9DAEBE1E0EDE7E9F0EEF0
F1EFF1E8E3E8E1D7DCE1D5D2DBCBCEB9AAACAC99A8A68D96988B989B8D98B59FA2A5929D
B7A6ACA59294A48E94A28B8C9F80829378719274707F646279615F8969637C64607D6463
7A5E567A5D536A524D6F524A6F53496C4F45694D426C5049725346744E436C51476F5045
6C4F4274554C886556846258866867A2857EB59695D0B3ABDAC2C6DCD2D3E0D7DAF0E9ED
ECEEF1EBE9E9E7E0DFE5D8D8E3D5D4E3D4D5E5D9D9E5DBDBE7DFE0E7DEDEE7E0E2E6DDDE
E6DDDEE7DEDEE7DEDFE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDE
E7DDDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DEDE
E7DBDCE7DCDDE7DEDEE7DDDEE7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDFE7DEDFE7DEDFE7DEDFE6DDDEE6DDDE
E7DEDFE7DFE0E8E0E1E7DEE0E5DCDDE5DBDBE2D5D6E2D7D6E4DADBECE3E1EEE9EBF2F1F3
F5F4F6EFECF1EAE3E9EAE1E0E5D9DCCABEBFC1AFBCBCA4AEAFA4B0B1A5B1C7B5B9B9AAB6
C8BAC1B9ABADB8A5ADB7A2A5B79A9CAC918CAA8D8B9B7F7F937B7AA3837D977F7C977E7D
967A7097786D886E698C6C658D6E638A6961896A5F8B6C65917063946B618B6D638D6C62
8C6C5F92736CA58477A38279A38888BAA39EC9B1B1DDCAC4E4D5DAE5E2E5E6E5E9F3F2F7
EEF5F8ECEDEDE8E2E3E6DADBE3D6D6E3D5D6E5DADBE5DCDDE8E0E2E8E0E1E7DEDFE6DDDE
E6DDDEE7DEDEE7DEDFE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDF
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDE
E7DBDCE7DCDDE7DEDFE7DDDDE7DEDFE7DEDEE7DEDEE7DDDEE7DEDFE7DEDEE7DEDEE7DEDF
E7DEDEE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DEDFE7DEDEE6DEDEE6DEDE
E7DEDFE7DEDFE7DEDFE7DEDFE6DCDEE5DCDCE4DADBE5DBDBE6DDDEEBE2E2ECE6E8EEEAEC
F0ECEDECE7EAEAE2E6EAE1E1E7DDDFD8CED0D4C6CED1BFC6C9BFC8CAC0C8D6C9CCCEC2CB
D7CCD1CDC1C4CCBCC4CCBBBECDB6B9C6B0ADC3ABACBAA2A4B29C9EBCA1A0B39F9EB39E9E
B49B95B39891AA918FAB8E8AAE918AAD8E8AAE918AAF938EB3968DB6928BAF938AAF9089
AF9187B49996C4A8A1C3A8A4C2ADB0D2C0BED9C8C9E4D7D5E7DCE1E7E4E6E8E5E9EFEDF0
ECEEF1EBEAEBE9E3E5E6DEDFE5DCDCE6DADCE6DDDEE6DEDFE7E0E1E7E1E3E7DBDBE6DDDE
E6DEDEE7DEDEE7DEDFE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDF
E7DEDFE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDFE7DEDE
E7DCDCE7DCDDE7DEDFE7DCDDE7DEDFE7DEDFE7DDDEE7DDDEE7DEDFE7DEDEE7DEDEE7DEDF
E7DEDEE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DEDEE7DEDFE6DEDEE6DDDEE6DDDEE6DEDFE7DEDFE7DEDFE8DFE0E8DFE0E8E0E1
E8E0E1E8DFE0E7DFE0E7DFE0E7DEDFE6DDDEE5DCDDE4DADCE3DADCE2D9DBE4DBDDE2D9DD
E4DBDDE0D5D8DDD2D8DED2D4E0D2D4DDCECED8C9CCD6C6C9CCBEC1D1BFC2CCBEC1CBBCBF
CDBCBBCBB7B7C8B4B7C6B0B2CAB3B3CBB3B7CCB9B7CDB9B8CEBCB8D0BAB6CFB8B3CAB6B2
CCB6B1D1BFC2DECCCBDECFCFDDD1D5E5DCDDE5DDDEE8E0E1E8E0E2E7E2E2E7E0E2E8E2E3
E8E2E3E8E2E3E8E0E2E6DFE0E7DFDFE7DDDFE7DEE0E7DEDFE7DEDFE7E2E4E6D7D6E7DEDE
E7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDF
E7DFDFE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDFE7DDDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDFE7DEDE
E7DCDDE7DDDDE7DEDFE7DCDDE7DDDEE7DEDFE7DDDEE7DCDDE7DEDFE7DEDEE7DEDEE7DEDF
E7DEDEE7DEDEE7DEDFE7DEDFE7DEDEE7DDDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDF
E6DEDEE6DDDEE6DDDEE7DEDEE7DEDFE7DFE0E8E1E2E8E0E1E7DFE0E5DCDDE4D9DAE2D7D7
E1D5D6E3D8D7E4DBDAE5DBDCE6DEDEEFE7E7F1EBE7F1EDEBF5EDEAF4E9E6EDE5E3F1E7E4
EEE3E0EEE1E1EADFE2EBE1E1ECE4E5ECE2E5E7DDE2E9E0E3E0D7DBDFD5DBDED5DADCD3D7
DFD3D6DBCFD4DECED4D8CACFDCCDD2DECED7E0D6D7E2D6D6DFD6D6DFD6D4E3D2D0DCD1CF
E0D0CEE3D9DEECE2E5EDE7E9EFE7EAF1E9EBEDE5E5E9DFE1E6DAD9E5D7D6E5D5D4E0D2D0
E2D1D0E3D4D4E6D6D7E5D9D9E7DBDAE8D9D9E6DAD9E6D9D8E5D7D6E4DBDBE5D2CFE7DEDF
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DEDEE7DCDDE7DEDF
E7DFDFE7DEDEE7DEDFE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDFE7DEDE
E7DEDFE7DDDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDFE7DEDE
E7DCDDE7DDDEE7DDDEE7DCDDE7DDDEE7DEDEE7DEDEE7DCDDE7DDDEE7DEDEE7DEDEE7DDDE
E7DEDEE7DEDFE7DEDFE7DEDFE7DEDEE7DDDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDF
E6DEDEE6DDDEE6DDDEE7DEDEE7DEDFE7DFE0E8E0E1E8DFE1E7DEDFE4DBDDE3D9D9E2D6D6
E1D5D5E3D8D7E5DBDAE5DCDDE7DFDEF0E8E9F3EEE9F2F0EDF7EFEBF6E7E2EFDED7F4E2D9
F0DED6F1DDD9EEDCDBEFDFDCF0E3E0F0E2E1ECDEDFEFE2E1E8DBDCE6D8DBE6D9DBE4D7D7
E6D7D6E2D3D5E5D2D3E0CFCFE2D1D3E4D0D5E6D7D4E7D6D2E4D5D2E3D5D0E7D1CBE2CFCA
E4CEC9E6D4D3EDD9D7EDDCDAEFDBD8F0DBD7EBD7D1E6CECBE2CBC4E2C6C0E1C6BFDCC0BA
DEC0B9DFC2BDE1C4BFE1C7C2E1C9C2E3C7C2E1C8C2E1C7C1E0C6BFDBC3BDE0C7C1E7DEDF
E7DEDFE7DEDEE7DEDEE7DEDEE7DEDEE7DEDEE7DDDEE7DEDEE7DEDEE7DEDFE7DCDDE7DEDE
E7DEDFE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDEE7DEDE
E7DEDEE7DCDDE7DEDEE7DEDEE7DEDFE7DEDEE7DEDEE7DEDE
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.03401 0.477324 1.48753 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -32 0 ]
[.5 1.0125 32 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(RGB) show
87.000 12.813 moveto
(6) show
93.000 12.813 moveto
(order) show
123.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
DDDCDADDDEDBDDDDDBDDDDDBDDDDDBDDDEDCDDDEDCDDDDDBDDDDDBDDDEDCDDDEDCDDDDDB
DDDEDCDDDEDCDDDEDBDDDEDBDDDEDCDDDDDBDDDEDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDFDFDDDFE0DEE1E2DFE2E2E0E0D7D0DFCFC2E0D2C4
DFD1C4DFD0C5DECFC6DED2C9E0D2C9DFD1C8DDCFC7DED1C8DACEC6DACDC5D9CDC4D6CBC2
D7C9BED5C8BFD3C4BBD3C2B7D1C2B8D1C0B7D4C2B5D3C1B4D1BFB3D0BEB1CEBBAECEBAAE
CDB9ACD0BBAFD3BEB1D3BFB3D2BEB2D3BEB2D2BDB0D0BAADD0BBAED0B9ADD0BBAED1BAAD
CFB9ACCFB9ACCEB8AACEB8ABCDB8AACEB7AACCB8ABCCB8AACCB8A8C6B4A8D1C6BEDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDDDBDDDEDB
DDDDDBDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDCDADDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDC
DDDCDADDDEDCDDDCDADDDDDBDDDCDADDDEDCDDDEDCDDDDDBDDDCDADDDEDCDDDEDCDDDCDA
DDDEDCDDDEDCDDDDDBDDDDDBDDDEDCDDDDDBDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCDADDDDDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDEDFDCDEDFDDDFE0DDDFE0DEDDD1C8DDC4B1DFC8B5
DEC8B6DEC7B7DEC7B9DECBBEDFCBBEDEC9BDDEC9BCDECBBDDCCABDDDC8BCDCC8BCD8C6BA
D8C4B4D8C4B7D4BFB0D6BDADD2BDAED0B9A9D4B9A6D2B8A4CFB4A2CDB2A0CBAF9DCDAE9D
CAAC99CAAC99CBAC99CAAA99C9AA97C9A997CAA997C8A794C8A996CAA694C9A997CAA794
C8A694C8A593C6A491C7A592C4A490C7A391C4A491C4A490C3A48DB99B88CBBBB1DDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDDDBDDDDDB
DDDCDADDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDCDADDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDC
DDDCDADDDEDCDDDBD9DDDDDBDDDCDADDDEDCDDDEDCDDDDDBDDDBD9DDDEDCDDDEDCDDDBD9
DDDEDCDDDEDCDDDDDBDDDDDBDDDEDCDDDCDADDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDBD9DDDDDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDCDDDBDCDDDBDAC9BFDAB79DDCBCA1
DDBCA5DDBCA6DDBDA8DDC2B1DDC1B0DDC0AFDDC0AFDDC3B0DFC5B3E0C2B2DFC3B2DBC0AF
DABDA6DABFADD5B9A1D8B7A0D2B6A1CEB097D2AE93D1AB91CBA58ECAA48BC6A188CBA089
C59C82C3987DC0957ABD9178BC9076BD8E74C09178BE8E74BF9378C28E75C2937AC38F77
C08E75BF8D74BD8C71BE8D74BA8B71BD8B72B98C73B98C71B98C6CA6795EC2AB9EDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCDADDDEDCDDDEDCDDDEDCDDDDDBDDDDDB
DDDBD9DDDEDCDDDEDCDDDCDADDDEDCDDDEDCDDDEDCDDDCDADDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDBD9DDDEDCDDDEDCDDDCDADDDEDCDDDEDCDDDEDC
DDDCDADDDEDCDDDCDADDDDDBDDDCDADDDEDCDDDEDCDDDDDBDDDCDADDDEDCDDDEDCDDDCDA
DDDEDCDDDEDCDDDDDBDDDDDBDDDEDCDDDDDBDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCDADDDDDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDBC7BBDBBBA2DDBFA7
DDBFAADDBFAADDBFADDDC4B3DDC2B2DDC1B1DDC2B2DDC4B2DEC4B3DDC1B1DEC2B2D9C0AF
D8BFABDABFAED6BBA7D9B9A4D2B7A3D1B19DD4AF98D1AC95CDA792CCA68FC8A38CCBA08C
C79F88C79E87C59B84C39A84C1967FBF947EC2957EC0957EC0967EC2947DC29880C4967E
C1947CC1937BBF927AC0937CBE927ABF917ABC927BBC9279BC9276B6947FCBBCB3DDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDDDBDDDDDB
DDDCD9DDDEDCDDDEDCDDDDDADDDEDCDDDEDCDDDEDCDDDDDADDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDCDADDDEDCDDDEDCDDDDDADDDEDCDDDDDBDDDEDC
DDDCDADDDEDCDDDDDBDDDDDBDDDBD9DDDEDCDDDDDBDDDEDBDDDDDBDDDEDCDDDEDCDDDDDB
DDDEDCDDDEDBDDDDDBDDDDDBDDDEDCDDDDDBDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDDDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDBC5B8DCBDA6DDC1AB
DDC1AEDDC1ADDDC1B0DDC4B4DCC2B2DDC2B1DDC3B4DDC3B3DDC3B3DCC1AFDDC2B1D8C0AF
D7BFAED9BFAFD7BCABD9BAA7D3B7A4D4B3A1D6AF9CD1AD98CEA794CDA692CAA38ECAA08D
CAA08CCBA28EC9A08BC7A08CC59986C09884C29882C29984C09782C19881C29A85C49A83
C19781C39680C1967FC19781C19780BF967FBE9680BE967FBE967EC2AA9BD3CAC4DDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDBDDDDDB
DDDCDADDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDADDDEDCDDDEDCDDDDDBDDDEDCDDDDDBDDDEDC
DDDCDADDDEDCDDDEDCDDDDDBDDDBD9DDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDDDBDDDDDBDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDFDEDBC2B3DCBDA7DDC1AC
DDC1B0DEC2AEDDC1B1DEC4B4DCC0B0DCC1B0DDC3B4DDC2B2DCC1B0DABEABDCC0AED7BEAC
D6BFB0D9BDADD9BCADDBB9A8D4B6A2D7B1A1D7AC9DD1AA96CEA491CEA390CBA18CC89C89
CA9E8CCEA290CBA08EC9A390C69886BE9786C09681C19987BF9481BF9881C09A84C39B83
C09780C4957FC19780C19882C39982BE977FBE9781BD9680BE947CCDBCB1DAD7D4DDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDB
DDDDDADDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDCDDDDDBDDDEDCDDDDDBDDDEDC
DDDCDADDDEDCDDDFDDDDDDDBDDDAD8DDDEDCDDDCDADDDEDCDDDFDDDDDEDCDDDEDCDDDFDD
DDDEDCDDDDDBDDDDDBDDDDDBDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDFDDDDDDDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDCDCDADEDEDCDEE2E1DBBFAEDCBEA7DDC2AE
DEC2B2DFC3B0DDC1B2DEC4B4DBBEAEDCC0AEDDC3B4DDC0B1DBBEADD7BAA6DBBEA9D6BBA8
D4BEB2D9BBABDABBAFDCB8A7D4B39EDAADA1D9A79CD0A593CD9E8DCE9E8DCB9C89C59584
CB9A8AD1A394CDA192CCA795C89587BB9788BE947FC09B8ABC917FBC9982BD9985C29C83
BE9680C5947FC19780C19983C69B85BD9880BE9882BD9781BC9078DAD2CBE3E8E8DDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDFDDDDDEDCDDDEDCDDDEDCDDDEDCDDDDDB
DDDDDBDDDEDCDDDFDDDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCDADDDEDC
DDDDDBDDDEDCDDDEDCDDDDDBDDDBD9DDDEDCDDDDDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDDDBDDDDDBDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDEDFDCDFDFDDDDDEDCDDDCDADBBFACDDBFA9DDC2AC
DDC2B0DDC1ADDDC1B1DDC2B2DBBFADDCC0AFDDC2B3DDC1B1DCC0AFD9BEABDCC1AED8BFAD
D7C0B3DABEAEDBBEB0DCBCACD6B9A6DAB6A8DAB0A3D3AD9BD2A896D2A895CEA490CA9F8E
CFA090D2A595CFA393CEA695CB9B8BC19989C39783C39A89C09482BF9882C09A85C39C84
C09983C49781C19882C29983C49A84BF9881BE9882BF9983C39E8BD9D3CDE0E3E2DDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDDDB
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDDDBDDDDDBDDDEDBDDDEDBDDDDDADDDEDBDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDBDDDEDBDDDEDCDDDEDCDDDEDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDEDFDDE0E1DFDCDDDBDCD8D3DABEAADDC0AADDC1AC
DDC1AEDCC0ACDCC1B0DCC1B0DBC0ADDCC1B0DDC2B3DDC1B1DCC1B1DBC2B0DCC3B1DAC2B2
D9C2B4DBC0B1DBC0B2DCC0B0D9BFADDBBDAEDBB7A8D6B4A2D6B09ED6B09CD1AC97CFA896
D2A595D3A896D1A694D0A694CEA08FC69B8BC79986C69A88C39683C19783C29A85C49C85
C09B86C39983C29A83C29A84C39983C09982BE9782C19A85CAAA9BDAD5D0DEE0DEDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDDDBDDDEDCDDDDDB
DDDDDBDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDBDDDEDC
DDDEDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDEDCDDDDDBDDDDDBDDDEDCDDDEDBDDDDDBDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDBDEDFDCE3E4E2E8EAE9E2E3E2DBD4CFDABDA6DDC1ABDCC1AA
DCC0ABDABEA9DCC0AEDBC0AEDBBFABDCC0B0DDC2B3DDC1B1DDC3B3DCC5B5DDC5B5DCC6B7
DCC4B5DCC3B4DCC3B4DDC4B5DBC5B4DCC5B6DCBEAFD9BBAADAB8A6DBB9A3D5B39DD4B09E
D6AA9BD5AB98D4A895D3A695D1A492CB9C8CCB9B8AC99987C79885C39683C49A85C59C87
C19E8AC39C86C39B85C39A85C29782C29A83BD9781C39C86D0B5AADCDBD8DEDFDDDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDDDBDDDEDCDDDDDB
DDDEDCDDDEDCDDDCDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDCDADDDEDCDDDFDDDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDDDBDCDCDADFE0DDECEDEBF8FBFBEEF1F1DAD1CCD9BBA1DDC3ACDCC0A9
DBBFA8D7BBA5DBC0ACDABEAADBBFA9DCC0B0DDC1B2DDC2B0DDC4B5DEC9BADDC9BADFCBBD
DFC6B7DEC6B8DEC6B6DDC9BBDFCCBEDECEC0DDC7B7DDC4B3E0C1AFE1C4ACD8BCA5D9BAA8
DBB0A2D7AE9BD7AB97D7A596D6AA97D29E8ED09D8FCC9986CA9A88C59383C79A86C79C89
C2A290C39F89C49E88C59B86C1957FC39B84BC967FC69E87D8C0BADFE2E2DDDDDBDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCDADDDEDCDDDEDCDDDCDADDDEDCDDDDDB
DDDEDCDDDEDCDDDBD9DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDCDADDDCDADDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDEDEDCDFDFDDDDDDDCD7D7D5D5D5D3CDCBC8D9CAC1DABDA6DDC2ADDCC1AB
DCC0ABD9BFABDCC0AEDBC0ADDCC1ADDDC1B1DDC2B2DDC2B1DDC4B5DEC7B8DDC6B8DEC8BA
DEC5B5DDC4B5DDC6B6DDC8B9DEC9BADECABADDC4B3DCC2B0DEBFADDEC0AAD8BAA4D9B8A5
DAAFA0D6AE9AD6AB97D6A696D5A996D09F8ECF9E8DCC9A87CA9B87C79785C69B86C69B87
C29E8AC29D87C29C86C39B86C29983C39C86BF9983C59F89D9C8C3DEE0DFDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDADDDEDCDDDDDBDDDDDBDDDEDCDDDDDB
DDDEDCDDDEDCDDDCDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDCDADDDDDBDDDEDBDDDEDCDDDDDBDDDEDCDDDEDBDDDEDCDDDDDBDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDEDFDDE0E1DFDADAD9C5C4C2B8B5B0B1AAA6D8C4B8DBBEA9DCC2AEDCC1AD
DCC1AEDBC2B0DCC1B0DCC1B0DCC2B0DDC2B3DDC2B3DDC2B2DDC4B5DDC6B7DDC5B6DDC6B7
DEC4B4DDC3B3DDC6B7DDC6B8DEC6B6DDC8B6DCC1B0DBBFAEDCBEABDBBEA8D9BAA3D9B6A2
D9AF9ED6AE9AD5AB97D5A895D5A896CFA08ECE9F8BCD9C87CB9B87C89A87C69B86C69A86
C29A85C19C86C09A84C29B85C39C85C39D88C29B86C5A08ADACFCBDEDFDDDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDDDBDDDDDBDDDEDCDDDDDB
DDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDBD9DDDDDBDDDDDBDDDDDBDDDDDBDDDEDCDDDDDBDDDEDCDDDDDBDDDEDCDDDEDC
DDDEDCDDDDDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCE1E3E1E8EAE8DEDFDEB2B2AF968F8A8D837CD7BCABDCC0ACDCC2AFDCC1AF
DDC2B1DCC5B5DDC1B1DDC3B3DDC3B3DDC3B4DDC2B3DDC2B2DDC5B6DDC6B7DDC3B4DDC4B5
DDC3B2DDC2B1DDC7B8DDC6B8DEC5B5DDC7B3DCC1AFDBC0AFDCC0ACDABEA9DABCA5DAB8A2
DAB09DD6B09AD5AD98D4A996D6A998CFA28FCEA08ACE9D88CC9C87CB9D89C69C86C69A85
C29781C19B85BF9983C29C86C49F89C39F8BC69E8AC5A18CDDDCDADEE0DEDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDDDBDDDEDCDDDEDCDDDDDB
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDAD8DDDEDCDDDDDBDDDDDBDDDEDCDDDFDDDDDDDBDDDEDCDDDCDADDDEDCDDDEDC
DDDEDCDDDCDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DCDDDBDCDDDBE8EAE9F7FAF9E7E9EB9A9C9B685F595C4E46D5B29CDDC2B0DBC2B0DCC1B2
DDC3B5DEC9BBDEC2B2DEC4B7DEC5B7DDC5B7DDC2B2DDC2B3DDC6B7DDC6B6DDC1B2DDC1B2
DDC2B0DDC0AEDDC8B9DDC6B8DFC4B5DDC7B0DCC1AEDCC3B1DCC3AFD9C0ABDDC1A9DDBBA4
DAB29ED7B29BD5AF99D5AB97D7AA9BCFA591CEA289D09F89CE9E87CFA28DC69D87C69983
C1937BC09A84BC9781C19D86C6A48EC3A18ECAA28EC5A38FE1EDEFDFE1E0DDDEDCDDDEDB
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCDADDDEDCDDDEDCDDDDDB
DDDEDCDDDEDCDDDFDDDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDBD9DDDEDCDDDDDBDDDDDBDDDDDBDDDEDCDDDDDBDDDEDCDDDCDADDDEDCDDDEDC
DDDEDCDDDDDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DEDFDDDEDFDDD8D8D6D6D6D4C8C6C4A29C96887B7287756AD7B8A3DDC2B0DCC2B0DDC1B2
DDC2B4DEC7B8DDC2B2DEC4B5DDC4B5DDC4B5DDC2B3DDC2B2DDC4B5DDC5B6DDC2B3DDC4B5
DDC4B3DDC2B1DDC7B7DDC4B5DDC1B1DDC2AEDBBBA9D9BAA8D9BAA7D7B7A3D9B7A1D9B39D
D8AD9AD5AE98D4AC96D3A994D4A896CEA38ECCA088CD9F88CC9C86CB9F8AC69C86C69883
C2957EC09A82BE9881C19A84C49F89C49E8AC8A08CC5A28EDCDDDADDDCDADDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDDDB
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDCDADDDEDCDDDDDBDDDDDBDDDDDBDDDDDBDDDCDADDDEDCDDDCDADDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DFE0DEDFE0DEC9C8C4BAB7B4AFA8A3A89B92A39185AA9587DABCA9DDC1B0DCC2B1DDC2B2
DDC2B3DDC6B7DDC2B3DEC3B3DDC4B3DDC4B3DDC2B3DDC2B2DDC3B4DDC4B5DDC4B4DDC6B6
DDC5B5DEC4B4DDC5B6DDC3B2DBBEADDDBEABD9B4A4D7B19FD7B29FD5AF9BD5AE9AD5AB96
D5A895D3A994D3A994D1A790D1A691CDA18CCA9F88CB9E87CB9B85C89C87C69A84C69882
C3967FBF9981C09881C19881C29B84C49C87C79E8AC4A18DD7CFC9DBD7D3DEDEDCDDDFDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDDDB
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDEDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDDDBDDDCDADDDCDADDDCDADDDCDADDDEDCDDDCDADDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDEDFDD
E4E6E4E6E8E7BBB9B59994908D817AA79386B7A092C9B09FDCC0ADDDC1B1DDC2B1DDC2B3
DDC2B3DDC5B6DDC2B4DEC3B3DDC4B3DDC4B3DDC2B3DDC1B1DDC2B3DDC4B4DDC5B6DDC9B9
DDC9B9DFC8B7DEC6B7DEC3B1DBBEABDFBDAAD9B1A2D5AC99D5AD9AD4AA97D2A794D2A792
D3A794D1A993D2AA94CFA78FCEA68ECCA18BC89E87C99E87CA9A84C59A85C79A83C69882
C49780BE987EC29880C0967FC09880C49A84C69E89C4A18CD3C6BDDAD6D1DFE2E1DEE0DF
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDB
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDDDBDDDCDADDDBD9DDDAD8DDDBD9DDDEDCDDDCDADDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDBE0E1DF
EEF1EFF3F6F7AAA8A56C66635E4E44A48775CFB1A0EFD2BCDFC4B2DDC1B1DEC2B2DDC3B4
DDC2B4DDC4B6DDC3B6DEC4B3DDC4B3DDC4B3DDC2B5DDC0AFDDBFB0DDC3B4DDC7B7DDCEBE
DECEBFE1CDBCDFC8B9DFC5B1DAC0AAE1BEACD9B0A2D3A793D4A996D3A794CEA18ECEA38E
D2A895D0AA95D1AE96CDAB8FCAA78BCBA38AC69E88C79F87C99984C29883C89982C69781
C69881BC977BC49780BF937BBE937AC59780C59E88C5A18DD0BBB1DAD7D3E2EAEBDFE4E3
DDDFDDDDDEDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDDDBDDDCDADDDCDADDDBD9DDDCDADDDEDCDDDCDADDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDEDEDCDEDFDCDCDDDB
D7D7D5D5D4D1ABA49D8E837A89776BB59A88D0B4A3E5C9B4DEC3B0DDC2B2DDC2B2DDC3B4
DDC2B3DDC3B4DDC1B2DDC1AEDDC1AFDDC2AFDDC2B2DEC3B2DEC2B3DDC2B3DEC5B6DDC6B7
DDC4B5DCC5B6DDBEB0DCBAA9D7B09FDBAC9DD49F91D19A89D19B8ACE9685CF9888CD9684
CF9786CE9A87CF9D89CD9C86CA9D86CA9A84C49A85C69C85C79882C19881C59780C59781
C59781BF977DC49780C2957EC0957CC59881C59B85C39E8ACCB2A5D4C5BCDBD6D2DDDCD9
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDB
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDBDDDDDBDDDCDADDDCDADDDCDADDDEDCDDDDDBDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDEDFDDDEDEDDD8D8D6
C2C0BDBCB6B1AC9F95A99A8DAD978AC4A998D3B7A7DFC3B0DEC2AEDDC3B3DDC2B2DDC3B4
DDC2B3DDC3B2DDC0AFDCBEAADCBFABDDBFABDEC1AFDEC4B4DEC4B4DEC1B3DFC3B3DDBFB0
DCBAADD8BDB1DBB6A8DAB0A2D4A395D69D90D09183D08F80CE8E7FC98879CF9082CB8B7C
CC8879CC8B7ACD8E7DCD8F7DC99480C9917EC29682C49982C59780C0977FC3957EC59781
C59780C1977FC49781C49881C1967EC59882C59883C19C87C8AA99CEB5A8D5C5BCDBD5D0
DDDDDADEDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDB
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDADDDEDCDDDEDCDDDDDBDDDCDADDDCDADDDDDADDDEDCDDDDDBDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCE1E2DFE3E4E2DDDDDB
ADAAA89D938CA59487C0AB9ACDB4A4D4B9A7DABFAEDFC3B0DDC1ADDDC4B4DDC2B2DDC3B4
DDC3B3DEC4B1DEC0ADDDBEA8DDBFA9DDBFA8DFC4AFE2CABAE1C9B9DFC2B5E2C4B5DEB9AC
DCB1A6D4B8B0D9ACA0D8A69AD09186D1887CCB7B6ECD7C70CA7D6FC47466CE8378CA7C6F
C97669CB7A6CCC7E70D08376CB8C7DCB8B7BC19582C39882C3977FBE967DC0937DC49881
C59680C39781C59781C59982C2967EC59782C49580BF9983C39E8AC8A491D0B5A6DAD0CB
DFDFDDDFE1DFDDDEDDDEDFDDDEDFDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDB
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDCDADDDEDCDDDEDCDDDDDBDDDCDADDDDDBDDDDDBDDDFDDDDDEDCDDDEDCDDDEDC
DDDFDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDCDDDBE6E7E3EDEFEDE9EAE9
94908F73645C9B8373DBC0A9F5D8C5E7CCBAE3C9B8DEC2B1DDC1ABDDC5B6DDC2B3DDC3B5
DDC4B5DEC5B0DFC1ADDFBFA8DFC1A9DFBFA6E2C9B0E8D6C6E6D2C2E2C5B9E9C9BAE0B2A7
DCA79ED0B5B0D8A095D69991CC7A72C96960C45D50C96259C4655BBD584CCF716AC8675E
C85D54CB6459CE6A61D6766ECF847AD1877AC19685C39883C0997EBC9579BC917BC39983
C59780C69782C59680C79A84C2957EC49681C3917CBC957FBD9077C18E75C9A18CDBCDC8
E1E5E5E3E5E5DDE0DEDFE1DEDEE0DDDDDEDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCDA
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDADDDEDCDDDEDCDDDDDBDDDCDADDDDDBDDDDDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDEDEDCDEDFDDDBDBD9D4D3D2BDBAB7
988F8A978579AF9786D8BEA8EACDBBE2C6B3DEC2B0DDBEACDDC2AEDDC4B5DDC2B3DDC3B4
DDC0AFDDBFAADBB9A3D8B29AD8B49DDAB7A0DBB9A4D9BCACDABFAFDCB9ACDAB7A8DBADA1
D9A79DCEAAA2D5A49AD49C92CE8D85CD8880C87C70CD8076C9796BC07065CC837AC6776D
C26E62C36F63C27064C47267C07C6FBF786BBA8574BD8C78C09179BE947ABE927AC2977E
C5957EC69782C69983C99D87C59981C69983C4937EBF9781C0957DC3947DC9A28ED4C0B5
DAD2CCDAD9D7DCDCDBDDDDDCDDDDDCDEDEDCDEDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDB
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDBDDDDDBDDDCDADDDDDBDDDDDADDDDDBDDDDDBDDDEDCDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDEDEDCDFE0DDD0CFD0BEBAB998918C
9B8C84B4A091C0A796D8BDA9E2C6B4DFC2AEDBBCA8DCBBA6DDC3B0DDC4B5DDC2B3DDC3B3
DDBDAADBBAA4D6B19AD1A68ED2A891D5AF99D4AA99CDA596D0AE9FD7AFA1CDA899D7A99D
D7A69BCDA097D3A79DD29F93CF9D96D1A19BCC958BCF988FCC8879C28479CA9287C5857A
BD7A6DBC786BB87467B66E62B37466AF6C5EB27666B8826EBF8A74C0927ABF9278C19579
C5937DC59782C79B86CBA08AC79C84C89C85C5957FC19882C29781C59882C8A18DCEB3A5
D3C2B6D3CDCBDAD8D7DBDAD9DBDBDADEDFDDDEDFDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDB
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDBDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDBDDDEDCDDDDDBDDDDDBDDDCDADDDEDCDDDCDADDDCDADDDDDBDDDEDCDDDEDC
DDDCDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDBDDDEDCDDDEDCDDDEDCDCDDDBDEDFDDE0E1DFE4E6E3CDCCCFACA4A5685E58
958176CEB6A4D2B7A4DBC0ACE0C4B2DFC1ACD9B7A2DBB7A1DDC3B3DDC3B4DDC2B3DDC4B3
DEBCA6DBB7A1D3AA92CB9A81CD9E87D4AB96D09F91BF8D80C59D8ED2A394BE9586D2A094
D3A397C99187CEA69DD09E92CFABA4D3B9B5CEAEA5D2B2AAD09685C3958BC79F92C28F84
B58475B37B6EAA7263A36355A567599D594CAC6354B57663C18571C6967FC19678C09575
C5927CC69782C89E88CDA38CC99F86CA9F86C69680C39983C39882C59983C79E89C8A592
CDB1A0CBC3C2D9D6D7DBD9DADBDBDBE0E2DFE0E1DEDEDFDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDDDBDDDDDBDDDCDADDDEDCDDDCDADDDBD9DDDDDBDDDEDCDDDEDC
DDDCDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDFDD
DDDEDCDDDDDBDDDEDCDDDEDCDDDEDBDCDCDBE0E1DFE6E7E4EEF1EECFCED5998E91281B14
8A7062EED1BCE8CAB5DFC3B0DDC2AFDFC1AAD6B19AD9B29BDDC5B6DDC3B3DDC2B3DEC4B3
E0BCA3DCB59ED0A38AC38B70C8937CD4A995D0958CAF7166B78879CB9585A97B6DCC9488
CF9F93C37C70C9A49DCD9D91CFBCB7D5D7D5D1CEC7D6D3CDD4A995C3AAA1C3AFA0BD9A8F
AA8F7EA67F72966C5B895244925748863E32A64C3EB26856C78170D09F88C69E7ABF956F
C6907AC69782C8A08BCFA78FCBA188CBA186C6967FC69A84C49A84C79B85C59B84C0947B
C59D85C1B8B8DAD5D9DDDBDCDCDCDCE4E7E4E3E6E1DFE1DDDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDFDDDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDDDBDDDDDBDDDDDADDDEDCDDDCDADDDCDADDDDDBDDDEDCDDDEDC
DDDCDADDDEDCDDDDDBDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDDDBDDDEDBDDDDDCDCDCD9D9D9D7D7D7D5AAA7AA897D7D5B4B43
A38979E5CAB4E2C6B1DEC2ADDDC1ADDDBDA6D8B39DD9B29CDDC4B4DDC3B3DDC2B3DDC2B0
DBB29BD5A992CB9C82C48D74C28B76C69582BD8277B47668BE8D7ECE9B8AB98E7ED1A295
D2A396CA9286CEADA5CFA194D3B9B2D7CDCAD1C1B7D4C0B7D2A18FC8A79DC9AEA0C49E93
B59180B2887AA881719E6B5B9C655493594B9F584AA96C5BB47564BA836FBB8B6DBC906F
C4907AC69882CAA28BD1A891CEA58DCDA48AC89B83C69A84C49984C59A84C59983C29880
C69E88C4B3ADD2CBCAD2CED0D6D3D4DCDBDADBDCDADCDDDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDDDBDDDDDBDDDDDBDDDEDCDDDDDBDDDDDBDDDDDBDDDEDCDDDEDC
DDDCDADDDEDCDDDDDBDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDB
DDDEDCDCDCDADDDEDCDDDDDBDDDDDBDDDCDDD6D5D3CDCCCBC3C0BF8884847A6D6A857168
B89F8DE0C5B0DEC3AEDDC1ABDCBFAADBB9A3D9B59FD8B29CDDC3B3DDC3B3DDC3B3DDC0AE
D7AA94CE9E87C7967CC48E77BD8470BA8472AE7165B87969C49283D09F8EC69D8CD5ADA0
D4A799D1A598D2B5ACD1A596D6B8AED9C6C1D2B7ABD2B2A6CF9B8ACCA69CCEADA1CAA397
BF9283BC9081B79384AF806FA4705E9E6F609A6253A16F5FA36A59A76B5AB17A61B98B6F
C28F7AC59881CCA38BD2A993D0A992CEA68ECA9E86C59A84C49984C49A84C49882C49A83
C79E89C5AEA2CCC1BCC8C2C5CFCACCD4D1D0D5D3D5DADADADDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDDDBDDDDDBDDDEDCDDDEDCDDDDDBDDDEDCDDDDDBDDDEDCDDDEDC
DDDCDADDDEDCDDDDDBDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCDA
DDDEDCDCDBD9DDDEDCDDDDDBDFDFDCE3E2E4D9D8D5C7C6C7B3AFAF625E5A5E4F4AA89085
CEB49FDEC4AEDEC3AFDEC0AADCBEA7D9B49EDAB69FD8B19BDDC2B3DDC3B4DDC4B4DDBFAC
D3A08BC6927AC08E72C28B75B47562A86959965447B67261C79081D19F8DD1A996D8B8AB
D5A899D6B6A9D6BEB4D2A998D9B9AEDBC4C0D3B1A4D1A798CD9787D1A99ED3B1A6D0AC9F
C89789C59C8BC4A89BBE9885A97A66A584758F6759956F60905C4B935042A76A55B7886F
C1917CC69982CEA68CD5AB95D3AE98D0A892CDA38AC69A84C49A84C49A84C49580C49A84
C69B86C5A795C4B7AFBEB6BBCDC6C9CDC8C7CDCACFD8D7D9DDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCDADDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDCDADDDEDCDDDDDBDDDDDBDDDEDCDDDEDCDDDDDBDDDFDDDDDDDBDDDFDCDDDEDC
DDDCDADDDEDCDDDCDADDDCDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDBD9
DDDEDCDBDAD8DDDEDCDDDCDAE2E2DEEFEEF1E2E1DFC3C3C7A29DA0332F2835251ED1B5A9
E9CEB6DDC4ADDDC3B0DFC0A9DBBDA4D7AE98DCB7A0D7AF99DEC1B2DDC4B5DEC7B6DDBDAA
CE9481BD836BB98466BF8672A65E4E8F4435752A1CB36552CA8C7DD19D8BDFB8A3DCC6B8
D6A999DECBBEDBC8BFD3AC99DDBBAEDEC3BFD4AB9BD09987CA9082D8ACA1DAB7AFD9B9AB
D39D90D0AB99D5C5B9D2B6A2AE8770AD9D8E806D60856E62754A3A7C30259D5748B68672
C29681C69B84D2AA8ED8AD98D7B49FD1AB96D0A88FC69A84C49A84C39A84C4927EC49B85
C59882C69F85BBACA1B2A8B1CEC4CAC6BDBEC4BEC8D5D4D9DEDFDDDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDBD9DDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDADDDEDCDDDDDBDDDDDBDDDEDCDDDEDCDDDDDBDDDEDCDDDDDBDDDDDBDDDEDC
DDDDDADDDEDCDDDDDBDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCDA
DDDEDCDCDBD9DDDEDCDDDDDBDAD9D8D1CED0BBB7B2A9A4A3928786443B3368554CCEB2A4
E2C7B0DDC1ACDDC1ADDCBEA7DBBBA4D8B29DDBB7A1D7B19CDDC1B0DDC1B2DDC2B1DBBBA7
CE9884BF876FBD886CC5907CB77E6DA96E5F985C4EBF8270CF9B8CD4A997DCB7A4DBC2B4
D7B0A0DCC6B8DAC4B9D6AF9EDCB8ABDDBDB5D4AA9AD19E8CCD9686D6A99CD6ADA1D3AD9D
D0988ACC9F8ECEB2A3C9A38FB3846FB29584937162957264885645803B30995747AF7C67
B98673C3967FCEA48AD6AD98D6B19CD2AB96CFA78DC69A84C49983C29A82C2937DC49883
C69882C69F87BFAA9CB2A8ACB9AEB0C4BBBBCAC4CBD4D2D6DCDDDADDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCDADDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDBDDDDDBDDDEDCDDDEDBDDDEDBDDDEDCDDDEDCDDDEDBDDDEDCDDDEDBDDDCDADDDEDC
DDDDDBDDDEDCDDDDDBDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDB
DDDEDCDCDDDADDDEDCDEDEDBD4D1D3B8B3B39A938C93888583746E52443B937D72CEB1A2
DEC3ACDDBEABDDC0AADABCA6DBB9A4D9B5A0DAB7A2D6B49EDDC1ADDDBFAFDDBFADDAB9A5
CF9B86C28A72C08C70CA9885C69987BF9181B58778CA9A89D4A89AD7B3A2DBB8A7DBC0B1
D9B6A7DBC2B4DAC2B5D8B3A3DCB6A8DCB7ACD3A998D1A38FCF9B89D4A798D3A494CFA391
CE9585C99584C9A391C39581B7816EB78F7CA47565A27665965F4E834439965545A9735E
B27966C1927BCC9F86D5AD98D5AF99D3AB96CEA68CC69A84C49883C19981C1937CC49781
C69882C59E88C3A897B2A6A6A59998C2B8B7CEC9CCD3D0D3DBDAD8DDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDBDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDBD9DDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDFE0DDCDC9CF9892936D645A70615B675249503E33BDA395D4B6A5
DEC3ACDDBBA9DDBEA8D8B9A3DBB6A3D9B7A2D9B7A1D6B59FDCC0AADDBBACDCBBA9D8B7A2
CE9B86C18870C28D73CFA28FD5B6A4D3B5A5D1B0A1D6B3A3DAB6A8DBBDAEDBBAAADBBFB0
DABDAEDCC2B3DBC0B1DAB6A8DCB3A4DCB0A1D3A694D2A591D19F8DD3A694D19B88CC9986
CE9181C78C7CC79682BF8874BE806FBF8D78B47968AE7967A165537E443A8E4C3EA06652
A76857BE8D77C99A82D5AE99D6AE99D6AD98CEA68CC69B85C49882C0987FBF937CC5947F
C69782C69C86C5A38FB0A29F948682C2B7B5D3CDCED1CBCEDAD8D5DDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDCDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDD9D7DDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDFDD
DDDEDCDEDFDCDDDEDCE2E5E1C4C0CD6F686A3024183F2C233F2417483025F1D1C1DBBBA9
DEC4ACDDB7A7DDBBA4D4B69FDBB1A1D9B8A4D8B6A0D4B59FDBBEA5DDB7A7DBB5A2D6B49D
CC9B84C0856DC48D74D7AE9EE8DCCAEEE2D2F3E4D5E4D2C2E1C6B8DECBBDDCBDAEDCBDAE
DCC6B7DCC1B2DBBDADDDBAAEDCAFA0DCA794D2A390D4AA94D4A591D3A490CE8F78C88D78
CE8C7DC58172C48670BA7865C67E70C98A73C87D6BBC7C68AE6A59764139813F32945441
9A5142BA8671C6947DD5B09DD7AD98D9AF9BCFA78CC69C86C59882BF987DBD947BC5917C
C79681C69984C99F87AD9E9783726AC7B9B7D9D3D1CDC5C7D7D3D1DDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDFDDDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDBD9DDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDCDCDAC8BFC38E827E6A5A4C745D51725547725A4BE1C5B5DABCA8
DDC1AADDB9A8DDBDA6D7B9A4DCB7A6DBBBA9DABAA5D7B9A5DCC1AADDBBABDCBAA7D7B5A0
CFA08BC69078C7927AD2A592DDC4B0E3CDBBE7D1C0E0CBBBDFC5B6DEC8B9DCBFB0DCBFB0
DCC3B4DCC1B1DBC0AFDCBCAEDCB3A2DAAB98D3A591D2A690D2A28ED2A48FCD947DC8927C
CB907DC48775C18B74BA806CC18170C38B73C1806DB9806BB073608A574A935545A06650
A46451BC8973C6967ED2AB94D4AB95D5AB95CDA48BC69983C39680BF967DBD937AC4937C
C59681C59A84C69E87AD9E976F635DB1A5A3D3CDCCD3CECFDAD8D6DDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCDADDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDDDBD8D4D3CCBEBAA8978D9A85759F86769C7E6E987E6DD6BDAEDABDA8
DBBEA8DDBBA9DDBFA8D9BCA8DCBCABDCBFADDBBDAAD9BDAADCC3AEDDBFAEDCBDABD9B7A3
D2A592CB9982C9967FCF9E8AD5B09BDBBDA9DFC3B1DEC6B6DEC4B6DDC6B7DCC2B3DCC0B1
DCC1B2DCC0AFDCC2B1DCBEAFDCB7A5D9AE9BD3A692D0A38DD0A18DD0A38FCD9881C89680
C7937DC38C77BD8E76BB8571BD8570BE8B73BC836EB8846DB27C669C6B58A26956AA755D
AD745EBD8C75C7967FCEA68DD2A993D2A790CCA189C59681C1947EBF947CBE9279C2957C
C49780C49B85C39C86AC9D965C54509D9392CCC7C8D8D5D5DBDBD9DDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDFDDDCDEDDD2CCCFCDBBAFBDA697C7AE9CC9AD99C6A694C0A590D2BCACDBBFA9
DABBA6DDBDA9DDC0AADBBEABDDC0AFDDC2B1DDBFAEDCC0B0DDC4B1DDC2B0DDC1AEDAB7A5
D5A997D0A28CCC9A83CC9781CEA089D6B49EDCBEAADEC6B7DEC8B9DDC7B8DDC5B6DDC1B2
DDBFB1DDC0AEDCC4B2DDC0B0DCBAA5D7AF9BD3A791CF9F88CF9F8BCFA38DCC9B82C89981
C4957CC29079B98F76BA8A74BA8871BB8B72BA8871B98A71B7876EAE8168B17C66B38167
B48167BD8C75C6957ECAA084D0A691CFA48CCB9F87C5937EBF917CBF927CBE9178C0967B
C29780C49B85C19A84AC9D9742403D8A8282CCC8CAE0E0DEDFE0DEDEDFDDDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDFDDDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDBDDE0DFDCE1E2CBC3CACEB6A2D7B8A1FFE2CEFEDFC5FBD8C3F1D4BACCBAAADBC1A9
D8B7A4DDBEAADDC1ABDDC1AFDEC5B5DEC6B6DFC2B3DFC4B5DDC6B5DDC6B3DDC4B1DBB7A6
D8AD9ED6AC97CE9E88C78C74C58B71D1A991D8B9A3DFC8BADDCCBCDDC7B8DDC9BADEC2B3
DEBEB0DDBFABDCC7B4DDC3B2DBBDA6D4B09BD3A790CC9A82CE9D89CEA28BCB9F84C79C83
C0997BC1957AB39176BA8F79B68D72B78B71B78D74BA9075BC9478C49B7BC2937ABD9073
BB8F70BC8A73C4937CC59979CDA48ECBA087C99C86C48F7ABC8E79BE8E7ABE9177BE987A
C0977FC49C86BE9781AD9F99222726757171D1CDD1EEF1EDE5E9E7DFE1DFDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDFDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDADCD8D3D1C4C3D3BBA8D5BAA5EAC9B5EAC7AFE7C4AEE4C6AFCFB9A9DCC1AA
DAB8A5DDBFAADDC1ADDDC2B1DDC5B5DEC6B7DEC4B5DEC6B8DDC7B7DDC7B5DDC5B3DCBBA9
D9B1A0D6AF99D1A38ECC967FC9947BD0A68ED6B19BDCC1B1DDC7B8DDC6B7DDC8B9DDC2B2
DDBEB0DDC0ADDCC5B3DDC4B3DCBEA9D7B4A0D3AA94CF9F89CE9F8ACCA28CC99C84C69A82
C0967BC09279B68E75B98C76B68A70B68A70B78B72BB8E72BC8F76C09477C08F77BE9176
BE9175C1927CC79881C99E81CCA28CCC9F87C89B85C5917CBE907BBE907BBE9178BF977C
C0977FC29A84C09983A9968D32302D6D6665B4AFB0D9DAD7DADBD9DCDCDADDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDDDDDAD6DDD1C6D7C4BCD6BEACD5BBA8DAB7A1DBB59ED9B59FDDBDA8D2B8A8DCC1AA
DBB9A6DDC0AADDC1AFDDC3B3DDC6B6DDC7B8DEC6B7DDC9BBDDC8B8DDC7B6DDC6B5DCBEAD
DAB5A3D6B19BD5A894D09E88CC9B82CFA28BD4A993D9BCAADDC3B4DDC5B6DDC7B8DDC1B1
DDBFB0DDC1AFDCC4B2DDC5B5DCC0ADDAB8A4D4AC97D1A38ECEA18CCAA18CC89A83C59881
BF957CBF9078B88C74B98974B6886FB5886FB78971BB8D70BC8C75BE9076BF8E77C09379
C2947BC69A83CA9D85CBA187CBA08ACB9D86C89B84C5947EC0927DBF927CBE917ABF967D
C0967EC19983C19B85A58F833F3832665B599B9593C6C5C4D0CECDD9D8D6DDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDE1E0DCDAD5DECCBBDCC7B7DCC6B3DAC4B2D3AB95D3A992D1AA93DCB9A7D4B6A6DDC1AB
DDB8A7DDC1AADDC1B1DDC5B6DDC8B8DDC9BADDC8BADDCCC0DDC9BBDDC9B9DDC8B8DDC2B1
DBBAA7D7B69FD9AE9AD3A68FCE9E85CD9B84D09E88D6B5A2DCC0B1DDC4B5DDC7B8DDC1B0
DDC0B0DEC2B1DCC3B2DDC8B8DDC3B2DDBEAAD5B09CD3A794CEA38EC9A18DC69983C49781
BF937CBD8E78B98A73B78672B5866EB3876EB68870BB8C6DBD8A75BF8D75C08F78C3977D
C79981CAA18BCCA189CDA58CC99D87CB9B85C69983C5957FC1947FBF937CBE907BBF957E
C0967DBF9781C19C859F86774037305248467C7773B6B4B6C6C2C1D5D3D1DDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDCDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCDADDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDBDDDFDD
DDE6E5DCDAD6DFC7AFE4CCB4E5D3BFE3D2C2CA9E86C99A83C79C84DAB4A5D6B2A4DEC2AB
DFB7A7DDC2AADDC2B4DDC7B9DDC9BADDCABCDDCBBDDDD0C5DDCBBEDDCBBCDDCABCDEC7B6
DDBFABD8BCA4DEB4A2D7AE98D0A288C9917ACC8F79D1AD97DCBBADDDC3B4DDC6B8DEC2B0
DEC1B1DEC4B3DCC3B2DDCCBCDDC8B8E0C6B2D6B4A2D7AD9CCFA891C9A28EC69884C49781
BE927EBC8D77BA8671B68370B5846DB2856DB6866EBB8B68BD8573BE8973C08F77C59B81
CC9E88D0AB94D0A68ED0A992C79883CA9883C59782C59781C39680BF947CBE907CBF9480
BF977CBC957FC19C86967B683B322A362D2D52504BA4A1A6BBB3B2D1CDCCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDADDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDAD8DCD0C7DCBCA7DDBBA5DBBBA8D8BBA9C89C84CB9E88CAA68FDBB7A6D8B6A7DDC2AB
DEBBA9DDC2ACDDC2B2DDC7B8DDC9BADDCABCDDCABCDDCEC2DDCBBDDDC9BADDC9BADEC4B4
DDC0ACD9BAA4DCB6A3D8AD9AD1A68ECD9A85CF9C85D4B09BDCBDAEDDC4B5DDC6B6DCC0AD
DCBEAEDDC2B1DDC3B1DDC7B7DCC2B2DDBEAAD4B19CD2A895CBA18BC59D89C39581C1947E
BD917BBB8C76BA8872B88571B4846CB1846AB7866FBD8D6FC08C79C3917BC5967FC89E86
CEA18BD0A993CFA58ECFA791C79B85CA9A85C69883C59781C39680C0947DBE927DC0947F
C0967DBF9781C39F89A2816D604C3F5E4A43716258A09998BCB7B5D2CFCDDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDFDDDDDCDA
DDD1CCDCC7B9D9B39ED8AD97D2A694CEA794C69882CCA18CCCAE98DBBAA7DAB9A9DDC2AB
DEBEABDDC2AEDDC2B2DDC7B8DDC9BADDCABDDDCABCDDCCC0DDCABCDDC8B8DDC7B8DDC2B3
DDC0ACDABAA5DAB7A3D9AD9CD3A993D1A28ED2A68FD6B29FDCBEAEDDC4B5DDC5B5DBBEAB
DBBCABDCC1AFDDC3B1DDC3B3DBBDACDBB8A4D3AD98CFA48FC89B86C19884C0927EBE917B
BB9079BA8B75BA8A72B98872B3846BB18369B8866FBF8F74C2927EC79883C99C86CBA18A
D0A48ED1A893CEA58ECFA690C89E87CA9C86C79983C59782C39580C2947EBF947DC0937D
C1957EC19A84C4A18DAC86718163508062548A71629B908BBDB9B7D2D0CFDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDE1E0DDDEDD
DDC7C1DDBEAAD6A894D49E88CB9180C79480C2927CCBA08CCDB49FDCBCA8DCBCABDDC2AB
DDC1ADDDC2B1DDC1B1DDC7B8DDC9BADDCBBEDDCABCDDCBBFDECABCDEC7B8DDC7B8DEC1B3
DDC2AEDCBAA7D9BBA6DCAEA0D5AE99D4A896D3AF98D8B3A0DCBFAEDDC4B5DDC4B3DABCA8
DAB9A7DBC0ADDDC3B0DCBFAFDAB8A7D9B29FD2AC94CCA08BC59681BE937FBD8F7BBA8D78
BA8E77B98A74BB8C71BA8971B18269AF8064B8846EC18F78C49782CB9F8ACDA38DCEA58F
D3A993D2A995CEA68FCFA690C8A089CB9E88C79A84C59883C49581C3947FBF967EC0927C
C2947EC39C86C5A490B68A72A57C63A177639E78648F8279BAB9B7D2CFCEDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDEE4E5DEE3E4
DEBCB5DEB398D39B88D08C75C37868BE7C66BD8973C99F8CCCBCA8DDBEA8DFC0ADDDC2AA
DDC4AEDDC2B3DDC1AFDDC8B9DDCABBDDCDC1DDCBBDDDCBBEDFCBBEDFC7B9DEC7B9DEC0B3
DEC6B2DEBAAAD8C0AADFAEA6D7B4A0D8B09FD6BAA3DAB3A1DCC0ADDDC4B6DDC2B1D8B9A3
D8B4A2DABEAADDC3AEDCBAAAD9B2A0D7AB99D0AA90C89C85C28F7ABA8D7ABA8C79B68A74
B88C75B88872BC8E70BC8B71AE8065AB7B5DB8806AC28E7CC69D87CFA893D2AB96D3AA95
D7AE99D5AA97CEA791CFA690C8A38ACBA08AC89B85C69A84C69581C69480BF997FC0907B
C3937FC5A089C7A894C38F75D09B7ACA9074B680667D7063B6BAB8D0CDCDDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCD9DCD3CE
DDBCB1DCB39DD09A87CC8D77C07D6BBB816BC0917BCDA591D0BBA7DCBEAADEC0AEDDC2AC
DDC5B1DDC3B4DDC3B2DDC7B8DDC8B9DDCABCDDC9BADDC9BADDC7B8DDC4B4DCC4B4DDBEAF
DCC0ADDCB9A8D8BBA7DCAFA2D7B29ED7B09ED6B8A1DAB7A4DDC0AEDDC4B5DDC3B1DABDA7
DAB9A8DBBFADDDC2B0DCBCABDAB4A2D7AC99D0A78EC89C85C1907BB98E7AB98B77B78A74
B78C75B68974BA8D73BC8C74B3856CB38569BD8974C59581C89F89D0A792D2AA95D1A994
D5AC97D3A994CEA58FCEA58FC9A18ACA9E88C79984C59883C49480C4937FBF977FC0917C
C2937EC49D87C6A794BE8C73C69175C28F74B6886F927A6BBDBAB6D4D2D2DDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDCD5CED9C4BA
DCBAACD9B29FCD9884C88C77BB7F6BB8836EC39882D0A996D4BCA6DCBFACDEC0AEDDC2AE
DDC6B4DDC4B4DDC4B4DDC6B7DDC7B7DDC7B8DDC6B6DDC6B5DBC4B2DBC1AFDBC1AFDCBBAB
DBBCA9DBB9A7D8B7A4DAB0A0D7B09CD7B19ED6B6A0DABAA7DDC1B0DDC3B4DDC3B1DBBFAB
DBBDACDCC0AFDDC2B1DCBEACDAB6A4D6AC99D0A38CC79B84C1917CB78E7AB78A76B78973
B68B75B48A76B98D75BC8E76B88A71BA8D74C1917DC89A86CAA18CD0A691D2AA94D0A993
D3AB95D1A792CEA48ECDA38EC9A089C89C86C69883C49782C3937FC2927FBF947EBF907C
C0937DC29A86C6A595BA8971C08B71BD8F74B88F77A48172C2B9B3D7D6D5DDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDEE1E0DDD2C7DAB7A8
E1BCAADCB5A3CE9784C88C78BA816AB6846EC49D87D3AE9AD7BDA6DCC0AEDDC1AFDDC2B0
DDC7B8DDC5B6DDC6B8DEC6B7DEC6B6DEC5B4DEC5B3DEC4B1D9C0ADD9BEA9DABEAADCB9A7
D9B8A5D9B9A6D8B4A2D8B29ED8B19CD7B3A1D6B7A2DBBFABDDC2B2DEC3B3DDC4B1DDC2AF
DDC0B1DDC1B2DDC2B2DCBFABDBB7A5D5AC97CFA08AC79A83BF917BB58E7AB58974B68972
B58B74B18B77B68D76BD9079BC8F77C1957EC69A86CCA18DCDA490D2A892D3AC96CFAA94
D2AB96D0A790CFA38DCDA28DCAA089C69A84C59781C39781C2927EC0907FBF927EBF907D
BF937CC29783C7A597B98971C18A73C0967AC09A84B58776C8BBB4DCDFDFDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDFDDDFE7E9DED1C1DDAA95
EAC2ABE3BCAED39985CD8F7BBB856AB6866FC6A38CD6B29EDCBEA6DCC1B0DDC2B0DDC2B3
DECABEDDC7B9DEC9BCE0C7B7DFC5B6E0C3B0DFC3B1DEC2ACD7BCA6D7BBA3DABAA3DCB7A2
D7B3A1D8B9A5D9B1A1D5B59CDAB19CD9B7A4D7B8A3DDC4B1DEC3B5DEC3B3DDC4B0DFC5B4
DFC5B6DEC3B5DDC1B5DCC0ABDCBAA7D5AB96CF9C87C69A82BE927BB18F7BB38873B68870
B48A74AE8C79B38C78BE937CC2957DCAA08BCDA593D1AA95D1A995D5AA94D5AE98CFAB96
D2AD97CFA78FD0A28BCCA08CCC9F89C59782C5957FC3967FC1907DBE8E7EBF907EBE907E
BD937AC29380C9A69ABA8972C48B76C4A082CAAA94CA8F7CD1C1BAE4EDEFDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDD8D2D9BFAECE9F8B
D1A892C8A293BA8774B27E6BA77761A87E69C8A58FD8B6A1DCBFA9DBC0AFDDC2AFDDC2B2
DDC7B8DDC5B6DDC6B7DCC4B4DCC2B1DCC1AFDCC0AEDCC0ABD7BBA6D7BAA4D8B9A4D9B5A2
D7B2A0D7B6A3D6AE9ED5B19AD6AE99D6B29FD6B6A1DAC0ACDDC1B1DDC2B1DDC4B1DEC3B1
DEC3B4DEC2B4DDC2B2DDC0ABDAB7A4D4AA96CD9C86C4967FBD8F7AB48D78B38771B68871
B48973B08C78B68D79BD927CC1957DC79C87C9A08DCEA591CEA691D1A791D2AA95CEA893
CFA893CDA48DCEA18BCB9F8AC99E88C59883C39681C29580C1927EBE907EBF917DBE907D
BE937DBF9685C5A295B2826CBB836CBC9277C09A84C48A76CAB0A3DCD4D0DDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDEDDDADACABED4AF9DC29480
BA907BAF8B7BA377659A6E5E946B599C7663CAA791D9B9A4DCC0ACDBC0AEDDC1AFDDC2B2
DDC4B4DDC4B3DCC3B2D9C1B1DABFAED8BEADD9BDABD9BEAAD6B9A5D7B9A4D5B7A4D6B3A0
D5B09ED5B39FD3AA9AD3AD98D2AA95D4AD9AD4B39ED7BCA6DBBFADDCC1AFDDC3B2DEC3B0
DEC2B2DDC2B3DDC2B1DDC0AAD8B5A2D3AA95CC9B86C2927BBC8D79B68C75B48670B58871
B48872B28C76B98D7ABD927CC0957FC49984C79C88CBA18DCAA38ECDA48ECFA691CDA690
CCA38FCBA28CCCA08ACB9D89C79E87C49984C29882C19581C0947FBE927DBF917CBD917D
BE927FBC9A89C29F90AB7C66B37B63B6876DB88D77BF8671C5A08ED5BEB6DDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDEDFDDDEDEDDD9C0ADCE9C87B38570
A77A649B776690695683605181605290705ECCAA94DBBEA8DDC1AFDBBFAEDDC2B0DDC2B2
DCC2B0DDC3B1DCC1AED7BFAED8BCABD6BDAED9BDAADCC0ADD8BAA7DABAA7D9BAA9D8B5A3
DAB3A0DDB7A3D6AB9AD7AE9BD1A994D4AB98D7B6A0D7BDA7DBC2ADDCC2AFDEC3B4DDC2AE
DDC2B1DDC1B2DDC1AFDDC0AAD7B2A0D1A994CA9A85C08E78BA8B79B88B72B4866EB68973
B48972B58C76BB8D7BBD927BC09681C49884C59A86C99F8BC8A28CCAA28BCDA38FCDA48E
C99E8BC9A08ACA9E89CA9B86C59C86C49985C19983C09481C09680BF937DBF917BBC917C
BE9181B99D8EBF9D8CA37560AC7459B17E65B3826CBE856FC19179CFA99DDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDCDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDCDCDADDDEDBE0E2E0DEE2E2D9B69CC7846BA1715B
93614A88634F7C5946694F426C5449846958CEAD98DDC3ACDEC3B4DABFAEDDC2B1DEC3B3
DBBEABDDC1AFDBBEA9D3BCABD7BAA8D5BDB0DBBFACE4C7B5DEBFACE2BEABE2C3B2DFBAA9
E6BCA6EEC3ADDEB09FE1B5A3D2A994D7AC98DDBEA7DAC3ABDDC7B0DCC3AFDFC3B6DDC1AC
DDC1B0DDC1B2DDC1ABDDC0A9D5AF9DD0A994C89A84BD8874B9887ABD8A70B5856DB78B76
B78B74BA8D75BF8D7CBC917BC09883C39883C29782C89E8AC6A28BC7A088CBA08CCEA28C
C79886C79D89C89D87C99882C29A85C39985C09B85BF9482BF9882C0957CC0917ABC927C
BF9083B4A194BB99879B6C57A46B4FAB745DAD7761BE876FBC7F60C8907FDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDEDFDCDFE0DEDEDFDDDCDCD9DDD6D0D3A68DCB8F78AB7C68
8459466E52436A4F4061493E6650457D6555D0AF99DDC2ACDDC2B0DABFACDCC0AEDDC1B0
DCC0ADDDC1AFDBBFAAD3BBA8D4B6A3CEB3A3CDAF9CC9AC99CAAB99CDAC9DC2A596C5A494
C19F8FBA9A89C09787C19886C49D89C89D8BC9A48ECBA993D2B49DD9BCA7DDC1B1DDC2AE
DDC2B1DDC2B3DDC2AFDDC1AAD5B19ED0A993C79983BD8A73B88876B7876EB2846BB2856F
B0846DB48A73BD907DBD937DC19983C19681C29782C59B86C39D87C59D87C89E8AC99F89
C59986C69E87C89E87C99B86C49D87C49A86BF9A84BE9481BD967FBD947CBC917BBB917C
BE9182B89E8FBB99869B705B9F6A50A66D57A7705AB87A63BB8063C79281DDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDEDFDDE0E1E0DEDEDCD6D5D2DCCCC0CD967FCD9682B38571
75514157413759453A57433A604B41766053D1B19BDDC2ADDCC1AEDABEAADBBFAADCC0AD
DDC1AEDCC1AEDBBFAAD3BAA6D2B29EC8AA98C2A28EB29483BA9B89BC9D91A78C7DAF9182
A1867C8E766AA68172A6806DB79380BC907FB88E78BE947EC9A48DD7B6A0DBBFADDDC2AF
DDC2B2DDC3B4DDC3B2DDC1ACD6B29FD1A893C79882BE8C72B78772B1856CAF8369AD8169
A97D67AE8871BC927FBF9580C19983BE947FC09781C29782C09882C19985C59B88C59C86
C29885C59D85C79D87C89D88C59E88C49B86BF9983BD9480BB947DBC937CB9917BB9917B
BD9281BB9C8ABB978399725E996750A06751A16853B37059BA7F64C59281DEDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCE2E3E1EAECEBE8E9E7DBDAD6DEC5B3C7826AD09C8AB98C7A
604236372A254337304A3A3356453B6A594ED3B39DDEC2AFDBC0ACD9BEA8DABDA7DCC0AB
DFC4B0DDC2AEDCBFA9D2B7A1CDAC97BE9C88B2907B947564A58675A68B82846D60947A6C
7A68655A4C45876759866350A88776AE8272A4735FAD7964BD9078D4AF98D9BCA8DDC2B1
DDC2B3DDC3B4DDC4B5DEC2AED6B39FD1A892C69681BD8C70B6866EAC826AAC8167A87C63
A37761AA8771BD9681C19781C69D86C0957EC89D86C69982C19781C39A86C59B87C59B86
C49B87C7A086C9A189CAA28DC8A28CC69E89BF9984BD9580B9927BBA927CB6927BB8907B
BC9381BE9A87BD98839A766294644F9C5F499B5E4AAC604BB87A60C3907EDEDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDFDDDDDEDCDDDEDCDDDFDDDDDFDDDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDCDDDBE9EBEAFBFFFFFBFFFDE9E8E3E4BFA6C06851D4A495C29685
462F28110C0D2826233B2F2B4B3E355C5048D5B69FDEC4B2DBBFAAD9BEA6D8BAA2DDC0A9
E2C8B4DDC3AFDDC0A9CFB39BC7A38BB18A729C76606B4B3B8769598A726F564439705C50
4842481514155F45395E3E2C95786A9C70638A513E975743AD775ED0A78DD7BAA3DDC2B3
DDC1B3DDC3B3DDC5B8DEC3B0D6B4A0D1A791C5947FBD8D6CB48669A68068A98064A2765B
9C705BA68873BF9B84C49982CFA48BC4977ED9AC91D2A085C89A82CBA08CCA9E89C99E88
CCA28CCEA78AD0A78ED1AA96CEA993C9A38DBF9A86BC9781B79079B7907CB2927BB78F7B
BB9581C39984C29B839C7D6890624F99554096533FA24B36B5745BC18F7CDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDEDFDDD9D9D6D4D3D1C9C7C4B7B0AAD2AD97C0755ECD9D8CBC8F7D
513932211C1B2F2B29392F2A493B3366574DD6B7A0DDC1AEDABFA9D9BEA6D9BCA5DABBA5
DBBFABDBBFABDBBEA8D4B8A2CFAE99C09D87B18F7A90705FA181709F847B7A6254897162
6B5B59423832775A4A75523F9D7C6CA376669A6651A86E58B9876FD1AA91D7BAA4DDC2B1
DDC4B5DDC6B7DDC7B9DDC2AED6B4A0D1A893C59680BD8D6FB48569A87F66AA8065A3775D
9C6F59A07E69B89581BF9A87B89580B18B78A78470A8836FAB836FAC8776B38E7CB28C78
AE8B78B8937ABB957FBD9A85C19C84C09982BC957FBA947DB69079B8917CB3927BB68F7B
BB9480BE9681B38F798E705D855D4B8B55438E5541AC614CB87B62BF8772DFDFDDDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDCDADDDEDCDDDEDCDDDDDBDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDFE0DECAC8C4B2ACA99D96928B7F78C29B87BD7E67C59784B68876
5941392C2826332E2C362F2A4639316E5C50D6B7A1DCBFABDABEA9D9BDA6DABDA8D7B8A2
D6B7A3D9BBA7D9BCA6D7BBA7D5B7A3CCAD98C2A38EAF8F7DB69583B09284977A6A9C806F
866E656553498A695787614EA47F6CA97B69A77760B58069C2957DD1AC93D8BAA4DDC2B0
DDC6B6DDC9BBDDC8BBDCC1ADD6B49FD2AA94C69882BE8D71B48469A97E64AB7F65A4785F
9C6E579B7660B1907EBB9B8BA68877A082727D6255856A5C926F5E9172629F80719D7C6B
957867A4826BA88672AC8B76B59078B89079BA9179B9917AB69079B9927CB3927BB5907B
BB927FBA937EA584708164547B57477E5445865643B4735EBB8168BC7F68E0E0DEDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDBD9DDDEDCDDDEDCDDDCDADDDCDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCE4E6E2C2BFBB94888371635E5C4A42B98D78C38B73C69782BA8874
624A4134322F34302F302D2740342D756153D7B9A3DBBDA8D9BEA8D8BDA6DABFAAD4B29C
D0AE9AD7B8A4D8BBA5DDC1AFDEC2B0DBBFABD4B8A4CDAD99CAA895C1A08DB1907EAE8F7C
9E7F70826A5C997660956D59A8806BAD7D69B2856DC18E76CB9F87D1AC94D7B9A3DDC2AE
DDC8B9DDCCC1DDCBBEDBC0ADD6B49FD2AB95C69983BE8C72B38368A87C61AB7F66A4785F
996953926B55A98A7DB79D928D786D8C756B483832584B4474564971594B88706485685B
7660528D6E5A927464977B66A78269AE866DB88C73B78F77B58F79B9937BB2917CB38F7B
BC927EBA927D9C7C69765A4B7152437355477C5543BC846FBF8A70BA765EE0E1DFDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDD9D7DDDEDCDDDEDCDDDBD9DDDBD9DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCECEFEBBFBBB6715F573B2520240900B3806AD1A086CD9C84C48C75
70564C3F3F3C353233282A24392E297E6757D8BCA5DABAA5D7BDA7D7BCA6DBC0ADCFAB95
C8A38ED6B5A1D6BAA5E6CBBAE9D2C3EFD8C4ECD5C0F4D4BEE6C1ADD7B399D4AC98C6A38D
BD957FA58673AD876CA67C67AF836BB28069C0977DD1A186D5AC94D0AD95D7B9A2DDC2AC
DDCBBCDED2C8DECFC3DAC0ADD6B59FD3AD97C69A84BE8A73B28165A87A5CAB7F67A47860
95634C865C469E837BB1A19C6D625E7064610100031E22244D342D47382D6B5C55664F47
4D42386F5444755D517C6651967156A1785FB5866AB58B72B58D79BA947BB2917CB18F7B
BD917EBC947D9375626B4E41674D4067584D715444C79B86C6977DB66C52E2E2E0DDDDDB
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDAD8DDDEDCDDDEDCDDDCDADDDCDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDAD9D89C948E67575044322C311B13906857A47B67A57F6C9A7060
5A474036373333302F2C2B263D312B7B6556D7B9A3DBBAA5D9BEA7D8BDA7DABFABD4B29C
CDAA96D4B29ED4B6A1D9BCACDDC1B0DBC2B0DAC0ADDEBEABD3B19EC8A58EC39E8BB69581
B08A759D7D6BA68068A07662AA7E67B07E68BA8D75CB9B82D2AA92D1AD97D7B9A3DDC2AE
DDC9B9DDCCBFDDCABCD9BDA9D6B39DD2AB96C69C86BE8E78B3836AAA7C60AB7D64A5795F
9B6C53946952A88879B59C9089746A857268382C27483F3A664B40614C3E776258775E51
675547826451886B5B8E735EA17B61AA8168B68A70B68D75B58F79B9937CB3927CB3907B
B8907CA98571806656614A405E493D5A4A40725443C0917CBC846CB76C52E2E2E0DEDFDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDBD9DDDEDCDDDEDCDDDDDBDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCCBC7C87D706A5C4D474939323927207152467D5B4D82665774584D
463B3630312D312E2D2E2D2740332D796455D6B7A0DBBAA5DABEA8D9BEA7DABFAAD7B8A3
D1B09DD2AF9DD1B29DCFB0A0D2B2A0CCB19FCBB09ECCAE9CC4A594BD9A86B79481AA8B79
A7816E997867A17C669C735FA67A64AE7C67B5876FC69881CFA992D3AF99D7BAA4DDC2B0
DDC7B7DCC8B8DDC5B6D8BAA5D6B19CD1AA94C69F89BF927CB3846FAD7E63AA7C62A5795F
A0735A9F745CAE8B77B79786A08272977C6E634F456B574C7B5E4F765D4B81675A84695A
7C635491715C9876629D7E68AB8269B0886FB78D75B78F78B5907AB9937DB4937DB4917B
B38E7A9878666D584B57473F55443A4E3E36735342B98A75B3745DB76C53E1E1DFDEDFDD
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDBDDDEDCDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDCD9DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCB9B1B558473F493C354639303A2A234D372F543B325E4B414D3E38
34302D2A2B272F2C2A2F2D2741332E796456D7B7A0DCBAA5DCBFA8D9BFA8D9BEA9DABDA8
D5B4A2CFA998CDAC96C2A091C7A28FBB9E8EBC9F8FBC9F8FB59788B08C7AAB88769C7E6C
9E76639671609B7560976C579F715BAA7660AF7D66C2957ECDA992D3AE9BD7BAA4DEC2B3
DDC6B7DCC4B1DDC1B0D7B7A1D6AE9AD0A792C5A28CBF9680B28471AE7E63A9795DA67A5F
A77C60AC7F66B89076BD957FBA937EA989748B6F60876A5A8A6D5B8469548466588C715E
8B6D5C9D7B63A57F68A88771B48970B78F76B78F79B8917AB4917AB8937EB5937DB6947D
B3917B8A6D5D59493E4C423D4A3F373E312B705241B58872AC644FB96A50E8E9E7E1E3E0
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDCDADDDEDCDDDEDCDDE0DDDDE0DDDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCA1949B2B130B34262144392E3C2E29221614221310322A261E1F1F
1D23232225202D2B282F2D2742322D796556DAB8A2DEBBA7DFC1AADAC0A9D8BDA7DEC4AF
D8B9A6CBA190C7A38DB18A7DB78B76A48577A7897AA78A7CA085779E7867997766886A5A
8F64518F65549169558D604A94634CA36B55A56E58BC8F79CAA792D4AD9BD6BAA4DEC2B6
DEC5B6DCC1AADDBDAAD5B49DD6AB97CFA48FC4A48EBE9A84AF8273AE7D61A87556A87A5D
B08767BD8E74C69977C89678DDAA8EC19B7FBD9883AB836C9D806995765D866454947964
9D7865AB876CB5896EB7927CC0927AC0987FB9937FB9937CB4937AB79380B6957EBA977F
B799807C6354433730403D3B3E39322A211D6B4F3EB08670A5513EBC684DF6F8F7E6E9E6
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDC
DDDCDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDADDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCB1A7AE3D261E392C2641352C372C272B211C2D1F1B372F2A262423
2124232527222D2B28342F29473933766354D0AE97D9B6A1DCBDA7DABFA8DABFA9DDC3AD
D9BBA9D1AC9CCEAE9AC09F90C49E8BB5998AB79B8DB79C8DB2988AB19081AE8E7D9F8576
A6806EA27F70A68270A17B68A87D69B38470B58771C59D88CFAE98D7B3A2D8BDA8DDC1B3
DCC2B2DBBFA9DBBCA9D6B39ED6AD98D1A993C7A690C39D88B78C7BB5876EAA7C61A67B61
A77E64AE816AB2896DB2866DBD927AAD8871A98672A27D679C7C67997A6292705D9C7D67
A07C68A9856DB0876EB28C77B68B74B89078B5907BB9927CB5927BB89480B7937DB4927A
9E826D69554940362F3C38383D3833322722765543AD7E69A15542B26850CFCFCDDBDBD9
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDC
DDDDDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDBDDDEDCDDDDDBDDDDDBDDDDDBDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCBEB7BD4A352C3C312A3E322A342C2730282333282338312B2A2724
2224222828242D2B2838312B4C3F39736253C6A48ED5B19CDABAA4DBBEA7DBC0AADDC2AC
DABDACD6B6A6D4B8A6CDB0A0CEAE9DC3A99AC4AB9CC4AA9BC0A89BC1A496BFA292B39B8D
B99787B29688B99889B39382B99482C19A88C39C87CEA995D3B49FD9B9A8DABFACDCC0AF
DBBFAEDABDA9DABBA7D6B39ED6AF9AD2AC97CAA893C89F8CBF9583BC8F79AD826AA47C65
A07761A27762A27B65A07963A37E699C79659B79669C79649B7A669E7D679C7A64A3816A
A4816CA8846EAC866FAF8873AE856FB18A73B28C78B9927BB7917CBA9480B8927CAE8D75
886D5C57483E3C342E3834343B3733372B257F5947A976629C5844A86851AEAAA7D1CFCE
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDDDBDDDCDADDDCDADDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCC8C4CA513B323A3029382C262E2B252E2A25312A25332E28252522
1F21202A28242B2B273D332D52463F716152BE9C86D2AE98D9B8A1DCBDA6DDC1ABDDC2AC
DCC0B0DBC0B0DAC1B1D9BFAFD7BCACCEB7A7CEB7A9D0B6A7CCB6AACFB7ABCFB4A4C5B0A3
CCAD9EC3ACA0CBAEA0C4AB9CCBAA9AD0B09FD1B19CD6B6A2D6BAA5DCBEAFDCC2B1DBC0AD
DABBA9D9BAA7D9B9A5D6B29DD6B09BD4B09BCDAB95CDA291C59D8CC39884AD86709F7A66
956C5C926A588D69578965538868558A685791705D9B78639F7B68A7856FAA876EAF896F
AD8973AA8671AB8871AE8470A7806BAA846EAE8975B9927BB8907DBB9481BB927CAD8C74
725A4B413931332F2A302E303735343A2D278F624FAB725D9B5A45A36B558C8682CAC6C7
DEDFDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDCDADDDBD9DDDBD9DDDEDCDDDCDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCD7D5DC59433A362E273024202628232C2D272F2E282C2B251F221E
1B1D1C2C2823292A2542362F594E466F6051B6937DD1AC94D8B6A0DDBDA6DFC3ACDDC2AB
DEC3B6E1CCBDE2CDBFE7D3C2E3CEBFDBC7B7DBC6B8DDC5B5DAC7BBE1CEC4E2C9BADAC9BE
E3C7BAD6C7BCE2C7BCD9C6BBDFC4B7E1CABBE1C9B5E0C5B1DAC1ACE0C5B8DFC6B8DABFAA
D8B6A4D8B7A4D7B8A3D6B19DD6B29CD6B4A0D1AE98D3A596CDA796CAA191AB8876977666
855C527C5747705044694A3D634A3A715144846350997862A37D6AB3907ABD987BBF9577
B9957EAD8977A98A74AC806C9E7965A17D68A88670BA927BBB8F7EBE9684C0927DB08E76
5A43382726212A292527262B32333440302AA9715AB2705A9E5F47A3715B645C56C5BFC1
DEE0DDDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDDDBDDDCDADDDCDADDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCD0CDD25A443B43372E3C2F29302D282F2E28342F292F2C26262521
22221F2D29252E2C28423630564B436D5D50AD8C77C8A48DD5B29BDCBAA4DEC2ABDDC2AB
DEC2B2DFC8B9DFC9BBE3CCBCE0CABBDAC5B6DAC6B8DBC5B6D9C7BCDECAC0DEC9BBD8C8BD
DFC6BAD6C6BBDEC7BCD8C5BADCC2B4DEC7B9DEC6B3DEC2B0DBC1ADDFC3B4DDC4B3DABEA9
D9B9A5D9B8A4D7B7A1D6B19CD6B29BD6B29ED2AE99D3A898CFA996CCA593B79280A98573
9C7567966F5E8C6B5B8565558063518664548E6D5A9B78649E7A67A98571AF8A70B0886E
AD8973A6816FA78570AC826DA27D69A8826DAE8774B9927BB88F7DBB927FB78D77987A65
5541372D2A252C2B262D2A2C333232392E28815848915C4B855340875F4E665D58B5AFB0
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDDDBDDDDDBDDDDDBDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCCAC6CA5B463C4E3F3547393138322C312F2938302B312C272B2824
2725222D2A27322E2A4237305449406B5B4EA58571BF9C86D1AD97DBB8A2DDC1AADDC2AC
DDC2B0DEC5B6DEC6B7DFC8B8DEC7B8DAC5B6DAC7BADBC6B8D9C8BDDCC9BDDCC9BDD8C9BE
DCC7BCD7C7BDDBC8BED8C6BADBC2B3DCC7B9DCC5B3DDC1B0DBC2AEDDC2B0DCC1AFDABEA9
DABBA6D9B8A3D7B5A0D7B29CD6B19BD6B19CD3AF99D3AB99D1AB97CFA995C29B8AB89280
B08A79AC8472A4816F9D7C699777639874629575639D78669A7866A17D69A48068A57D67
A37F6AA07B69A6816DAC836EA6816DAE8671B38878B8927AB68F7CB88E7AAE8771836756
4F3D35302C272E2C27312D2D333130332C27604438744B3E6E48396E4F42645C56A6A09F
DBDAD8DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDBDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCCCC8CB5E49405A473C5242383E352F32302A3C312C312C27302B26
2D29242E2A2937312D4439325549406B5A4D9D7F6BB99781D0AC95DCB7A2DEC1ABDEC2AD
DDC2AEDEC4B5DEC5B6DEC6B7DEC7B8DCC8B9DCCABDDCC9BCDCCDC2DDCABEDDCEC4DCCEC4
DDCDC2DBCDC2DDCEC5DBCBC0DCC6B7DDCABDDDC8B8DDC2B2DDC3B1DDC1AEDBC0ABD9BEA8
DABDA7DAB8A3D6B49ED7B29CD6B19BD6B09CD5B09BD5B09DD4AF9AD3AF9BCDA696C9A08D
C49F8CC19885BA9582B2917CAA8773A5816D997A689C766692726198736098735E98705E
977360977260A37B69AB836EA7826FB28A75B8877BB7927AB6917CB98D78AB856E6E5446
463630302C262E2C2736302D33302E2D2C263F2E2857382F583E335340375F554F999492
DEDEDCDDDEDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDFDDDDDFDDDDDEDCDDDEDCDDDEDCDDDEDCDDDFDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCD4CFD3624E446A5144604D4145393232302A40312D312C26372F29
332D272F2B2C3D3431473C35574A416D5A4E967A66B5937DD3AD97DEB8A3DFC2ACDEC3AE
DDC2ABDDC2B3DDC4B4DDC4B5DDC7B8DECABCDECEC2DECDC0DED2C8DECCBEDED4CCDFD4CB
DED3CAE0D3C9DED6CEE0D2C7DECBBCDECFC3DECABDDEC3B5DEC6B4DCC1ABD9BEA7D9BEA7
DCBFA9DCB9A2D5B29CD8B39DD6B29CD6AF9BD7B19DD6B5A1D9B59FD8B8A1DCB4A5DDB19E
DDBAA3DAB19DD4AF99CCAA93C19B87B58F7A9C7F6D997164876A5A8A645286624F855E50
8662518A65539D7363A9836DA78470B88D79BF877FB7947BB7947EBE8E77AB856D563F34
3B2E2A2F2C252E2C263D342D34302C272B2416141436201D3F322C342E2A594F488C8886
E6E7E6DCDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDBDDDEDCDDDEDCB3ADAD5E4B40634F445C4B41483D3538342F413530352E28352E28
322C262F2B2A3B312E42383150443B635246886E5DA28370BF9B85D5AF99DBBDA6DDC1AB
DDC2ACDDC2B3DDC3B4DDC4B5DDC7B8DEC9BBDECDC1DECDC0DED0C6DDCDC0DDD1C8DED2C9
DDD1C8DFD1C8DED2C8DED0C6DECABADDCCC0DEC9BBDDC3B4DDC4B1DCC0ACDABEA8D8BDA6
DABCA6DAB6A0D6B29CD7B19BD6B09AD6AF9AD7B09CD6B29ED7B19BD5B29DD7AF9ED6AD99
D5B19BD3AB96CEA793C8A58FBF9A85B8927CA88875A67E6E9979689B75629A7460987160
9973619B7462A67D6BAE8771AD8874B78E79BC897DB59078AE8C77A8806B92725E513E34
392F2A302C272E2C2836302B302D2B2629241E1C1A3525213A2F29332E295147417B746F
CBC8C4DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDC
DDDDDBDDDEDBDDDEDC978E8B5A483D5E4D445A4B424C41393E393343383339302B332D28
322C262F2C28382F2B3E342E493E365A4A3F7A6354917564AD8A75CDA690D7B7A1DCBFA9
DDC1ACDDC2B3DDC3B4DDC4B5DDC7B8DDC9BADDCDC0DDCDC1DDCFC4DDCEC2DDCFC5DED1C7
DDD0C7DED0C7DDCEC3DED0C6DDC9BADDCBBDDDC9BADDC3B3DCC2AFDCC0ACDBBDA9D8BCA5
D9BAA4D9B49ED6B29BD7B09AD6AF99D6AF9AD6B09BD5B09BD5AE99D3AE99D4AC99D2AA95
D0AA94CFA792C9A38EC5A38DC09A85BB9580B2917DB28977A98673AA836FAA836EA9806D
A8826EA9816EAD8672B28B75B18B78B68E79B98B7BB38D76A5846F9574617B61514A3B33
372F2A302D282D2C292F2D292C2B2A24272423211E322823342C27312D2849403A6C625B
B5ADA8DEDFDDDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCDADDDEDCDDDEDC
DDDDDBDDDDDBDDDEDC796E675746395A4E46594C4451453D433C37453A353D312C312C27
322C262E2C27372D2839312B4337305142376B56497D65579A7964C69F88D5B49EDCBEA8
DEC2ADDEC2B3DDC2B4DDC3B4DDC8B9DDC9BADDCDC1DDCEC2DDCEC4DDCFC5DDCEC3DDD1C7
DDD0C7DDD1C7DDCCBFDDD0C7DDC9B9DDC9BADDC8B9DDC4B3DCC1ACDDC0ACDCBCA9D7BBA4
D7B7A1D7B19DD6B19BD6AE99D6AE98D6AF99D6B09AD5AF99D4AC97D2AA97D3AB96D0AA94
CEA891CEA890C9A18DC7A58EC49E88C29C86BE9C87BF9581BA947FB8917CB9907BB88F7A
B78F7BB88E7BB38F79B6907AB7907DB7907BBA8F7BB48C76A07F6A826856634F433F352E
332E28302D2A2E2C2A2A2A282828292225232123202927222926232829243F3631584B41
988B83DFE0DEDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDBD9DDDEDCDDDEDC
DDDCDADDDDDBDEDFDD56483D534234554F4A594E47564B4249403A463C3740322D2E2A25
322B252D2C25362A24332C273A2F2946382E59463D665247836550BF987FD3B29CDCBEA8
DFC3AFDEC2B3DDC2B4DDC2B3DDC9BADDC9BADDCEC2DDCFC4DDCEC3DDD1C8DDCDC1DDD0C7
DDD0C7DDD1C8DDC9B9DDD1C9DDC8B9DDC8B8DDC8B9DDC5B3DBBFA9DDC1ACDDBBAAD6BAA4
D6B59ED6AE9BD7B19BD6AD97D7AD98D7AF99D6B09AD4AE97D4AA95D0A794D2A993CEAA93
CBA58ECEA88FC99F8BC9A791C9A38CCAA58ECDAB93CFA48DCEA48ECAA38CCDA18BCBA18A
CAA18BCA9E8ABC9A81BC967FBF9784B8937EBD957CB88D769D7C666E5B4B473A32332E2A
2E2D26312E2B2E2D2D2427272425271F23222026231F27211B1F1D1E2320342B273E2E20
725D51E1E1DFDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCD9DDDEDCDDDEDC
DDDDDADDDDDBDDDDDB5C4E44554539574D46584D47574B434D443E4A413B433731352E29
362D27302D26352C26382E293D322C4739305B493F695449846753B79079CCA790D8B7A1
DCBFA9DDC1B0DDC2B2DDC3B4DDC7B8DDC8B8DDCCBFDDCEC3DDCEC3DDD0C6DDCDC1DDD0C6
DDD0C7DDD0C7DDCABDDDD0C7DDC9B9DDC8B8DDC8B9DDC4B3DBBFABDCBFABDCBCA9D7B8A2
D6B49ED6AE9AD5AF9AD5AB96D5AB96D5AE98D5AE98D4AD95D3A994D0A693D1A892CDA791
CBA38DCDA68EC89F8BC8A38DC7A08AC7A08AC9A38DC99F89C79E88C59D86C79C87C59A85
C49A84C39884BA967FB9937EBA917EB48D78B18B75A7826D8C6E5B665546493B33322E2A
2E2D28302D2A2B2B2A2326252325261F22222024212025211F2220222622362D29493A2E
91837AE0E0DEDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCDADDDEDCDDDEDC
DDDDDBDDDDDBDDDCDA5F514856473D594B43574D47584B445148424E453F453B353C332D
3A2F29332E28352D273B302B40352E463A315B4A406B5549846754AF8872C59C85D3B09A
DABAA4DCC0ADDDC2B1DDC4B4DDC5B6DDC7B7DDC9BCDDCDC1DDCEC2DDCFC5DDCDC2DDD0C6
DDD0C7DDCFC5DDCCBFDDCFC5DDC8B9DDC8B9DDC8B9DDC3B3DBBFACDCBCAADBBCA8D7B7A0
D6B49ED6AE99D4AE99D3AA94D3AA94D4AC97D5AB97D3AB94D1A893D0A591CFA690CCA58F
CBA28DCCA38DC79F8AC6A08AC69E88C49C86C59E89C59B85C29A84C29882C29984C19581
C09680BD947FB9937DB7917CB58C78B08872A6836F9777657C61515E4E42493B33312E29
2E2D29302D292829292325242224251F22221F2320202421222522262924382F2A53453A
ABA29CDEDFDDDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCDADDDEDCDDDEDC
DDDDDBDDDDDBDCDBD95C4D44574A415B4A40554D485A4D46564D47524943483F39423631
3D302A362E29332D273D312C41352F443931594940695247806452A9816BBF937AD1AB95
D8B7A1DCC0ABDEC2B1DEC5B5DDC3B4DDC6B6DDC8B9DDCDC1DDCEC2DDCFC5DDCEC3DDD0C6
DDD1C8DDCFC4DDCDC2DDCFC5DDC9BADDC8B9DEC8B9DDC3B4DBC0ADDCBAA9DBBCA7D8B59F
D6B39ED6AD98D3AD98D1A893D1A892D2AB95D4A996D3AA93D0A792CFA48FCDA48FCBA38D
CA9F8BCBA08BC69F89C69E88C59D87C29984C49A86C29A84C09883C19780C19983C0937F
BE947DBB927DBA937DB7927DB38A75B1866F9D7D6A8A6E5E6C534552453B4537302D2C28
2D2D2A2F2C282427272023222022231D21211F221F1F2221232624272A25342B26524238
C1BDB8DEDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDC
DDDEDCDDDEDCDCD9D7584740584D455F493D534E4A5D4E485C534D564E484A433D493934
41302B392F2A312D2740322D42363141383058493F684F457C604FA27963BA886ED0A791
D8B59FDBC1A9DEC3B0DEC6B7DDC0B2DDC4B5DDC5B5DDCDC0DDCEC2DDD0C6DDCFC4DDD0C7
DDD2CADDCFC3DDCFC5DDD0C5DDCABADDC9BADEC9BBDEC3B5DCC1AFDCB8A8DBBDA6D8B39D
D6B39FD6AC97D1AC98CFA691CFA790D0A994D4A695D3A991CFA591CFA28DCBA28DC9A08A
C99D8ACA9D8AC6A089C59B85C59B87C09581C39682C09881BD9681C1957FBF9983BF907D
BD917AB8907BBD937EB8947FB38972B4856C9577657C65575A4439453A3442342D292B27
2B2D2C2D2B262024251E201F1D20211C1F211E211E1E2122252926282C262C241F4A3930
DCDCDBDCDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDADDDEDCDDDEDC
DDDDDBDDDDDBDCD9D75D4E46564B4458463C564C465B4E475B524B584F494E46404A3C36
44353039302A352F2941342E433832443A3356473E6650467B625297725EAF8169C69D86
D2AD97DABDA6DCC1ADDDC4B3DDC1B1DDC4B5DDC5B5DDCBBEDDCDC0DDCDC2DDCDC1DDCEC3
DDCFC5DDCDC1DDCDC2DDCCBFDDC8B8DDC7B7DDC6B7DDC1B2DABEABDBB8A6DABBA4D8B29C
D5B09BD5AB96D1AA95CFA690CFA690D0A993D2A693D1A890CFA591CFA38ECCA28DCBA08B
C99E8AC99E8AC59E88C59A84C59A85C19682C29682C09781BD9580BE937EBF9681BF907D
BB917AB68E79B58E79AE8B76A7806BA07862886D5D725C4F5541374339333E322D2A2C27
2C2D2B2F2C282226261F21211F22221C20211C1F1E1D20202427242C2C2640363071645C
D9D9D7DDDEDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCDADDDEDCDDDEDC
DDDDDADDDDDBDBDAD762544B544A4353443B574B42594D475A514A59504A5149434B3F38
46393439312B38312B413630453A34463C3554463D6552467A63538D6A58A57A63BC927C
CDA58FD8BAA3DBBEAADCC2AFDEC2B1DDC3B4DDC5B5DDCABCDDCBBFDDCBBEDDCCBFDDCCBF
DDCCC0DDCBBEDDCCBEDDC9BADDC6B6DDC5B4DCC4B3DDC0AFD9BCA7DAB7A4D9B9A2D8B19B
D5AD98D4AA94D0A892D0A78FD0A690CFA892D1A590D0A68FCFA590CFA48ECDA28CCCA08B
C99E8AC99F8BC59D87C59984C49883C19682C19683BF9781BD957EBC927DBE947FBF907C
B99079B38C77AE8974A5836E9C78648D6D597C63566854474F3D3441373239312C2B2C28
2C2D2A312D292326272123232124231C20211A1E1E1C1F20242624312E27524741948A84
D9D8D6DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCD9DDDEDCDDDEDC
DDDCDADDDCDADBD9D762554C5147414C40385A493F584C465A514A5C534C554D474D433B
4A3E3938312B3B332D433932473D36483F3752443C6453467B65568262519C735DB48971
CBA08AD9B9A2DABEA9DCC2ADDEC3B1DEC3B4DEC4B5DEC9BBDDCBBEDDC9BBDDCBBEDDCABC
DDC9BCDDC9BCDECBBCDDC6B5DEC4B5DDC4B2DBC1B0DCBFADD7BAA4D9B6A2D8B8A1D8B09A
D4AB96D3AA93D0A690D0A78FD0A591CFA892CFA48DCFA58ECEA590CFA68FCEA18CCEA08C
CA9F8AC8A08CC59C87C49783C49681C09682BF9683BF9681BD947DBA917CBF927EC0917C
B8907AB38D77AA87729E7D6893715E7B62506F5A4E5C4A3F4738303D3430352F2C2C2D28
2C2D2A332E2A2427282224242326251D2121171D1D181D1D222523302A245D4F48B8B2AD
DCDCDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDBD9DDDEDCDDDEDC
DDDBD9DDDBD9DAD8D66054494A433D433B355D483B574C465B524960565059514B50463D
4E443F362F2A3E3530453D354A41394A413A50423A6456477E695A77594A946B56AE7F66
CB9B85DCBAA3DBC0AADCC2ABDFC5B1DFC4B5DFC4B5DEC9BBDDCABEDDC6B8DDCBBDDEC7B9
DDC6B7DDC8BADFCABBDDC2B0DEC2B5DDC3B0DABFADDCBFACD5B8A0D8B6A1D7B8A1D8AF99
D3A994D1AA93D0A58DD0A98FD1A592CFA892CEA38BCDA48ECEA590CFA891D0A18DD0A18E
CAA18BC7A28EC49B86C49582C4947FC19682BD9583BF9581BC937CB88F7CC1907DC4937D
B9917CB58F79A887719978638B6B596856466351475140353F322C3A312E302E2B2E2F29
2D2D2938302C2629292526272729271F2222121A1C13181A1E22212C221C65534BE4E1DF
E0E1DFDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDBD9DDDEDCDDDEDC
DDDCDADDDCDADBDAD874675F564C4649403959473C574C465950485D534D5B514B51483F
4D433D3E36313E3530413932473E374840394F443C5E5144715F537157498563519E7761
B98D78CFAC95D4B59FD8BBA4DDC1ADDDC1AFDDC2B1DDC5B5DDC8B9DEC5B5DEC8B8DDC6B6
DDC5B5DDC6B7DDC7B6DCC0ADDCC1B1DDC0ACDBBEABDBBBA8D6B69FD7B39ED5B29BD6AC96
D2A791D1A790CFA28BCFA58CCFA38FCEA58FCCA18ACEA28CCDA38ECEA48DCD9F8ACD9E89
C89E87C79F89C49884C49682C39580C09580BD9581BE957FBB927AB68E7ABA8D79BA8C77
B08974A8836E9878648B6C597B5F50614E41584940493B32382F29342E2A2D2C2A2B2C27
2C2C28312D292427272123242125241A1F20171D1E1E2120282724463B33867B74DDDAD8
DFE0DEDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDBD9DDDEDCDDDEDC
DDDDDADDDDDBDCDCD986797460554E4E433D57473C564C46574E475A504A5C514B524942
4C423B453D373E36303E3630443B34463E384F453E594D4266574D6A5448765B4C906F5C
A9806CC39F89CDAB94D4B49DDABDA8DBBDAADBBFABDAC0AEDDC5B5DDC4B2DEC6B3DDC4B3
DDC4B2DDC3B3DCC4B1DBBEAADBBFADDBBDA8DBBCAAD9B8A5D7B49FD6B09BD3AD96D4A992
D1A48DD0A58ECDA089CEA289CCA08CCDA28BCB9F88CEA08ACCA18CCDA089CB9D88C99A84
C79B83C69B85C49583C39681C29580BF947FBD947FBC947DB99079B48C78B48A75B18671
A7826C9B78648A6B597D604F6B534759473B4E413941362E312C262D2B272A2A28282A25
2C2B272B2A272125251D21221D2121161D1E1B1F1F282926332D285D5149A59F99D9D7D5
DEDFDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDBD9DDDEDCDDDEDC
DDDDDBDDDEDCDDDDDB9588856659514F453F53463B564C46554C45574D475F534D544C45
4C423A4C443D3E36313A332E423932463E384F4640534840594F46624F46645045816655
9B735FBC957ECBA48CD6B19ADDBEA7DFBEA8DDC0ABDCBFAAE0C5B3E1C6B2E1C6B1DFC5B2
E0C5B1DFC2B2DCC2ADDBBDA7DABFAADCBBA5DDBCA9DAB6A3DAB49FD7B09AD3A992D4A891
D2A38CD1A48ECE9F89CEA087CB9F8ACDA18AC99E88CF9F89CBA08BCD9D86C99B86C79880
C69981C69982C59382C49782C19781BF947EBE947FBD967CB99078B48D78B18973AB836E
A17D67926F5B7C5D4D7153455A473D4F3D34413830373029282823272823262826272924
2D2C272728252024241A1F21171E1E0F191B1E2020302F2A352A23706158C9C7C4DCDCD9
DEDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDBD9DDDEDCDDDEDC
DDDEDCDDDFDDDEDFDDA696976959505046404E4339564D47524944544A4464554F564E49
4B4037554C453E363235302C3F3630453E394F48434D443E4A443E584A434F443C705D4E
8D6551B68B73CE9F85DDB098E5C3AAE6C2A9E2C5ADE0C0A8E4C8B2E7CCB4E6C9B0E2C7B3
E5C8B1E4C3B3DEC3AADDBDA5DABFA9DDBAA3DFBCA9DBB5A2DFB5A1DBB19CD7A78FD7A991
D6A58BD4A58FCF9F89CF9F86CA9F89CE9F88C89D88D29F88CB9F8ACE9A83C79A84C4957B
C5977EC6977FC69081C69984C29A84BF957EC19680BF997DBB9178B7917BAF8972A7826B
9C79638965526F4F4063453947393246332D342D272C29231E241F1F241E232625262822
302D27232623212423161D1F10191906121620212138352F312017826F64F5F9F7DFE0DE
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDCDADDDEDCDDDEDC
DDDEDCDDDEDCDEDEDCB4A9A97E716A594E4754483E554B45534A44554B455E514B564E48
4E443C534A4340373239322D403630423A354D46414D443E4F4842594B455348406A584B
7E5D4DA07C69B28D77C09B86C8AA94CEAC96D0AF98CFB09AD7B9A5D7BAA4D8BAA3D7BAA5
D8BBA6D7B7A6D5B8A1D5B49DD5B8A1D7B29CD9B6A2D3AE9AD3AC97CEA48EC79C85C89C85
C89981C99B85C79780C89780C69982C89981C59882CB9982C89A84C9957FC59680C2937A
C19379C2937BC18D7CC0937EBC937CBA8F79B98F79B48F75AF8871A9836EA17C67977460
8C6B577B5C4B64493D5941364337303D302A302C262927231E221F1E221F202323212521
2727231D22201A2020161D1F151C1D131B1C252321413B35584A439B8E85E9EBE9DEDFDD
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCC2BCBB91878363574E594C43544A43554B44554B45594D47574E48
5148415249414239333D332E4136303F37324C443F4D443D534A44594D46564B43645349
7056498C6F5F9A7D6AA78976AE9481B89884BF9B86C0A18DCBAC98C8AA95CBAD97CDAE99
CCAF9BCBAB99CBAD98CDAB94CFB099D1A994D3B09BCCA792C8A38EC19882B9917BBB8F79
BB8E77BE927BBF9078C2907AC1937CC1937AC2937DC4937BC5947FC5907AC2937CBF9078
BD8F74BD8F76BC8977BA8D79B78D76B58973B28872AB856EA3806B9C776394705D896756
7D5E4D6D5243594438503C323D342E342C282D2B252525221C201E1D211F1D21211D2220
1F2220171E1D141C1D161D1E191F201F22222B26234B433C7B706AB1AAA4E1E2E0DDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCD5D3D1A49C9A67594E594C4352473F564B44554B45544A43584F49
554C465248404339323F342E4235303A332E4B423D4B433C534B44574D47544B445A4B44
5C4A41765E53806A5A8D7463947D6CA48573B18873B39481C3A28DBE9D88C4A38DC8A68F
C6A894C4A390C7A791CAA68FCFAD95CFA58FD1AE98CAA38EC29D88B98E76AF8871B1856F
B28670B88C74BC8B72C08B77C19178BF8F75C4917AC19077C6907BC48D77C2927BC09078
BD8E71BD8E74BB8875B78A76B58A71B38670AE836EA47E699A7A66916C598865537B5A4B
6F51415F473B4D3C3244352C342F292826232728222022211A1D1D1B1E1E1A1E1F191E1F
171C1D0F181A0B1719131C1D1C21222828262A231E4E423A9F9690CECBC8DFE0DEDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDCDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDFDDDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCECEFEDB9B3B467574856483E4E433A584C44554B454E453E5A514B
5B524D51463D44393142342D43332F352D2949403A48413A534A44544C47524B444D403D
443B375B49446154476F5B4D7662548D6E5EA1725DA88574BE9883B5917CC09B84C7A087
C3A390C09C87C6A38DCCA48DD3AE93D2A28CD4AE96CBA28ABF9A83B48469A57F68A97B65
AA7E68B5886DBD896CC18775C59176C08E71C89178C08E74CA8F79C78B75C7937BC5937A
C08F6EC08F73BD8974B78874B6886DB4846DAC806A9F776492756287624E7E59496D4D40
604134503B313F342C372D252B29241B1F1E20251F1A1E20171A1C191C1E171B1D151A1D
0D15180411150010140E191B1D2224322E292419124A3A30CAC1BDF1F5F5DCDDDBDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCE5E7E5C1BDBD85786E6B5F59554A42564A43544A44514841574F48
564E49534A41483E3644373141353039312D4A413B4C443D584F4958504A574F48544945
4F453F5E4E4866584C726052766456896D5D97705C987C6CA888749F806EA58775AC8B76
A68B7AA68877AC8D7AB08C78B8967FB9907CBB9A84B28F7AA787749E7963937360946E5C
98705D9D7761A47860A97866AC7F67AA7E65B3826BAF8169B5826DB37F6AB1836DAE836D
AC8165AA7F66A87A66A57C68A27A63A177629A73608F6D5B8568577958486F514362473C
573F3448383039302A332C262928241D21201F231F191D1F16191B161B1C141A1C121A1C
10181A0C16180C1719191E1E2325253B3430463B35756962CAC4C1E7E9E8DDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCE0E1DFCAC8C69F97917F74715C504A564A42544A44534A44554D46
524C46544D454B423B463A344036313D35304B423C5047405C534C5B534C5B534C5A504B
574D465F514B685A50736255746357836A5B8C6D5B8A73639478678A70618D7466937867
8C75668E76679579699777659F806DA27F6DA387749C7E6C9176668A6F5D826858816253
8664538767568D6955936A58966E5A9670599F745F9E745EA27561A074609E75609A7561
9B745C97705A946C5994705D916D5A8E6A588A6756806353785C4D6C4F4160483C564137
4D3C3340352E332D272F2A262727231F21211E211F171D1E14191A141A1B10191B10191B
121A1C131A1B161D1D242321292928453C386559549B938DCECAC7E0E1E0DDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDFDFDDD8D7D5BCB7B58F86875D514A50443C514842554C46534B45
4E4A445650484F4740483D373C35303F36324B423B5248416157515F564F6057505F5751
5D534D5C514B665A517062566D5F547B65578067567868597E6757745D51725F55796256
715D507662557C62557D5F50886A598E6F5D8E7563876E5D7B6457766556715C506D5449
75564771574A795A487F5C49815E4D85624D8E6854916954926B56926B568E6954886856
8C695485634E835F4D8666538162507F5F4E7B5C4C735A4C6C50425D44384F3E344A3831
42373035302B2A27232928262325211F22221C1F1F151B1D1117191017190B16180C1719
101A1C171C1C1D1F1E28211E262322483B3781736EC5C0BCD8D8D5DFE0DEDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDCDDDBE8EBE8DEDDE0A0989E594C464539314D453F574F48504943
49474059554D534C474A3F3936332E4037334A413A544941685D56635952675C55656059
655B5558524C6459526D6359655B51736153746252645C4E6553445A473E5345405B4941
5141365A4B4060483D6043366E5042785E4C766051705D4C615047605A4E5D4F4857453F
63473A58443D624A3B694D396B4D3D7354407D5B47855E4A83604B83624D7D5B47755B4A
7F5E4C73544271513F795C487055476F53436B50426651445F42364D372E3D322B3C2F2A
36322D282A2721211E2326262024202023241B1C1F111A1C0E15170A1416031315051316
0D191D1A1E1D22211E281B151B151246322D9F8F89F9F8F5E5E8E6DCDDDBDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDBE3E5E2DAD9D9B0AAAD776B675F534D564D47564D46514943
4D494256524A524B464B423C403B36463E394F463F5A4F48655B54625952635953625B55
6158515A524C625850695E5467594F6C5A4D6D5C4F64584B635245584740564A435B4B43
51433A564A415F4B425D473C644D426A54486C5A4D6554475C4C4359514755494250413A
5742374F40395543375C46375E4639634B3B6C50416E51417054437055446C5141665143
6B5142654C3D61493A665040634C405F493D5E483C56473B543D3447362E39312A372D28
312F2A28292620211F1F22231D211F1B1F21181B1E121A1C1017190E17190B18190E191A
171D1F222321312D2A4639354B454270635FAEA39FEBEAE7E1E3E1DDDEDBDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDFE1DED8D7D6BFBBBC918784766B675F5450564B45524A43
504A44544F48524B454D443E49433D4C443F534A435F544D625951625951605751605851
5E564F5B534C60564E65584F68574D65534666564B635348604F4554463F574C45594B44
4E443C5147415B4B4459493F5947405B4B436152485A4B4256473F5048414D423C473D36
4B3C34453B34483C334F3E33503F355241355B463A5945395D483B5D493B5C483B57473C
584539574337524035534437564339504037503F36483C3348383141342D342E28312B27
2C2B272728251F21201B1F201A1F1E171D1E151B1D131B1D11191B121A1C131C1D171E1D
2223222A2826403A3661555176706D968E8CBEB7B4E1E1DEDFE0DEDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDEDFDDDCDCDAD2D1D1ACA2A28A7E7C60545050463F514740
534B45514D47524B45504741524B45544B45585049675C55625850635A525F57505F564F
5D554E5C534C5F564E60534B69554B5D4C3F5E5148604E44584A424C433C544B44524942
47403A48403D5549445048404A3F3B493E3C5248404B3F3A4D3F38453D384139343B3530
3B332E37332E36332D3E352D3F352D3E352D47393041362E473930473A31493C32453A34
41362E45382F3F342D3E362D4738303D352E40352E3630293C322D38322B2D2B26292824
2527232527241D1F20141A1C161C1D12191B11181B121B1D111A1B121C1D161F201A1F1D
24201D2A2420483E397A6C69A29B97C0BCBCD4D3D0DFDFDDDEDFDDDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDDDBE0E1DEE9EBEACBC2C49E91935C4E4A473C344D433C
554B464F4B46534C46534B455D554F5E554E5E564F71665F61574F645B545D564F5E544D
5B544D5D544C60574F5C4E466D544A554537574B465E494051443E433F3A524B454C4740
3E3B383E393A504846484941383535332E34433D383B323244363139302F352F2C2D2D28
292928272B262228252B29272B2A25272724302A262324212D28232E2A24332E29312C29
272520322B26292724252620362A252727242F2A2522231D2F2A282F2F29262824212421
1E231F2326221B1D200D151611181B0B15170A151811191C0F1B1C101D1E192223181C19
2016102217124A3C35948381D6CDC9F3F5F6EFF4F3DCDDDBDDDEDBDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDEDFDDE3E4E3CDC6C7ADA4A47F74725F544D594E47
564C464F4A44534B4551494359514B57504A5A524C675E575E554E6159515B544D5D534C
59524B5B534B584F47594D45624E445041364D443E54443C4E433D433C384D464049423C
3F3A373C383947413F43423D3833343530323E39353631303C322F352F2F322F2C2E2D29
2929282629262327252A28262B29262827252E29262828242F2A262D2A262F2C272F2B29
2827232F2B272A2824272722322A272828252B282422231E2827252A2B262024211E2220
1B211F1E23211A1D2011181A141B1D10181A131A1C171E1F161E1E1D232226272634332D
483F3B534B46746A65A79B99D2CCC8E7E7E7E7EAE8DDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDEDEDCDFDFDED0CCCCBCB6B59E9695746964645951
584F48504A43534B454F4842564E48514D465750495F57505A544C5E564F5A524C5C534C
5750495A534B514841564B4558473E4B3D34453D374A3F374A413B423A3647413C453D39
3E39363936393F3A383E3C3A373131353030393432312F2D332E2D312E2E2E2D2C2E2D29
2829282427252225242727262928262727252B28252A2A252F2B282B29262B29252C2927
2827252C2A282928252727242E2A282828262727232022202123232526231C201F1B201F
181F1F1B2020191D20151B1D171E1F141B1D1B1F201C22221C2221292926332E2A4F4840
6D64607F787499938FB9B2B0D1CECBDFDFDEE1E2E0DDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDEDFDDDAD9D7D0CDCCC0BABB857A74695C54
5349414A423A5149424C4640544C464C4B45554E4758514B56524B5B544D584F495A514B
544D4759534C4A40395249424E403844373139342E403932473F3A423734423C38423935
3E3836353339353331393737332E2F332F2E312E2E2A2B2A2928292B2B2B292B2B2C2C28
2427271F22231E21212223242426252325242324232729252A292623242320211F222322
2123222527262325222223222626262325241F21201A1E1E151D1E1C201F131A1B151D1D
111B1C141B1D151C1E161C1F161E20151C1E2022231F24241D22202F2A25392C2665564C
928884AEA7A3C4C1BDD2D0CED9D9D6DEDFDDDFE0DEDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDCDADDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDBE4E7E4E7E8E7E9E6E99689846A5A51
473B323E34294C443D48423C524943464842524B45504A44524F4A58514B554C46584F48
5149445A544D4236304C45404238313D312D2C292335332D453E394335323D37343F3432
3F373732313A2B2B293331352F292C322E2B2827282127261D212524272923282A2B2B28
202526191D20191D1F1C20221F23251E23241A2020242923232624181E1D111614151A1B
181E1E1B22231B211D1D1F201C21241D2121141B1B12181A0614181118190612150C1719
0714190A13180E181B161C21141E21141C1F2526271F26261A1F1D31271F3B22197A6254
BCB0ADE7DFDBF8F8F6F0F5F3E2E5E3DDDEDBDCDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCE1E3E0E1E2E1E0DEDFA9A19D8A7E78
6E645D5F564F5A514B514A44534B454A4842514B45514B45534F4957514B574F495A514B
544C4755514A423A34504842443A333D322E302C2833312C3C37333A302E38343038312F
3732312E2E33292A282F2E302D292A2D2B292727282025241F2225232627222728272826
2024251C1F221A1E1F1B1F211D21231E22231D2121252926282A292225271F2325242525
2327282126282327252123252226282225251C21201A1E20121C1E1A1E1F131B1B161D1E
151D20181E211B20221D22242024262224232D29272F2D2936332E4F443C614F4794847A
C0B8B5DDD8D5EAEAE8E7EAE8E0E1DFDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDFE0DDDEDEDCDCDADABBB6B3A69F9A
9088837D7571685E595A514C564D484E4943504B45514C45544F4956514B59514B5C534E
574F49514E49433D37534A44463C343C332E332E2B312F2B33312E322C2B34312D322F2D
2F2D2C2B2C2E2729272B2B2D2A29292928272627281F2223202325222426212526242525
1F23241E22221B1E201A1E201B20211E22231F22222528282C2D2E2A2C2E2B2F33302F2E
2C2F30262A2C2A2C2C25272A282A2B2627292326252124251C23222224241E22201F2222
2125262528282728272427272B2B2A2F2C27362D293E352E50453E6B5F56857670ACA39C
C7C2C0D8D5D2E1E1DFE1E2E0DEDFDDDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDEDFDDDEDEDCDDDDDCD3D1CFC6C2C0
B3ADA99991906F635F5B514C51484249423B4B48414E4A43544E4855514C5B544E5E5651
59504B4C4A453E3B36534A44443A3239312D322E2D2C2B282828282827272D2C272A2A29
2627262628262225232426272728262225242225271C1F202023241F22231F23241F2222
1E21222023231A1D1E161C1E181D1E1C20211F222125272A303032313236353A423C3936
343638292C2F303032282A2F2B2D2E28292B272A2825282A242926272727262825262625
2B2B2D303130302E2D282B2A322F2D383027382A2348362B66514586766CAA9F98CAC7C4
D5D4D2DCDBD9DFE0DEDFE0DEDEDFDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDBDDDEDCDEE0DDEFF3F2EDEDED
DCD8D6B8B0B3736461574A45453B353F332C42413A49463F534C4654524E5E5852615955
5C524D4344413738325249433F362E342E2A2F2C2F242624181D201B2021242520202525
191E1E1E231D1A201E1C20202127231A20201E2425171B1D1F22241B1E201C1F21181D1F
1C1F20212423171B1B11181A13191A191D1E1E212123262B343437393A404247544C453F
3D3F412A2D3238343A2A2D342F30322A2A2E2C2E2C2A2D2F2D2F2A2C2B2B2F2E292C2828
3532343D3C393B36332A2E2B37302E3F32233520144E30207B5947A28E81D7CEC8EFF3F5
E7EAE8E0E2E0DDDEDCDCDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDEDFDDE7E9E7E4E3E3
D8D5D2BFBABB9187847B716E69625D635A5456514B544F49564F48524D4959524C5D5651
5D534E4D4C484845415C534D4B423B3D36313832312D2C292425252324252C2A26262827
2425242628232326232324242528262024242124251A1D1F1E22231D20221E21221D2123
1D20222225251F2223181E20171D1F1F222422252427292F32333737373D41444D45403F
3F40413333363735392E3034313232302E3131322E2F30302F302C32302E33312B332F2D
3A36343F3A354138333B37314A403A55463B5A483F6D584C957E71B1A39AD3CDC8E5E8E8
E2E4E2DEE0DEDDDEDCDDDEDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCE1E2E0DEDEDC
D6D4D2C8C5C4ACA6A49B95928A8481837D7768605B5E58525A524C514B46564F485A534F
5E554F56524E56514D655B56564C46443D3840373335322D2F2C2A2B2928322F2C2B2C28
2D2C292C2C282A2B27292828282A282528282325251C1F211E21231F22241F2324222427
1F212323272726282B1F24241B21232426292629272B2D3231343736353C414148403D3F
4241423A3A3B38363831333534333236323435353134343232312E39343239342E3A3632
403935433A34483C354C40385C4F476B59517C6C658A7B72AD9F97BFB8B1D3CFCBDFE0DF
DFE0DEDEDFDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDFE0DEDEDEDC
DBDBD9D7D6D4CBC9C7BDBAB8AAA6A5A29E98756963605954574D46473F3A4C443D534C48
5E544E5D5854665E5B6F65606057524A433D473A3339342E352F2B2D282835312E2B2B26
322F2B302D2A2F2D292A2928282927252829212221191D1E1A1D1F1E21231E2122232528
1D20212327272C2D312427271C212526282D282B282C2E352E333634333B4240453A3A40
4544444140403737383335353434323A353839383338373434322F3E39363C362F403B35
443B3443342C4B392F5742376B584B7E67619F8F89A8A099CCC6C1D5D3CFDAD9D6DEDFDE
DEDFDDDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDCDDDBDDDEDC
E1E2E0E9ECE8F1F4F3E6E7E7D1CED0C7C5BF7F6E675E544F4C4038362B243C332B46403C
5D534B655E5A796F6D7C726E6D63604F48404D3C303C342E3A312A2C252535302E282721
35302A322D2B322E292A27272625242326271C1B1A1217181115171B1D1F191E1E242428
191D1D21262531323927292819202425282F282C272B2E37283035302E3A413E41323541
4847474948463337373336343234313E383B3C3B353A3B36333130433D3A3D3730453F38
453A2F3D281D472F205F3D2D775C4A917370C7B7B2CCCAC6F1F5F5EFF4F4E2E5E3DDDDDB
DDDEDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDBDDDEDC
DFE0DEE3E5E2E6E8E7DEDFDED0CECEC9C7C3998E89827B77736B645E56525D554F5E5853
665D5667605C726865756C666B615D58504A5347404A423C473E383E3735453E3A3B3731
423D373E38343E39343934323333323535362F2D2C2A2B2B27292A2A2B2E282A2B2E2E33
27292B2B2E3038373C313332292D3234353935353139393E36393C3A373E4843443E3E43
4D47464E4945403D3B3F3D3A413C36473E3D454039473F38413A354C423C4D4238524A42
584C425D4B436B594D7F685C938074A5918EC9BEB9CDCAC7E7E9E7E7E9E9E0E2E0DDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DEDFDCDFE1DEE0E1DFDADAD9D1D0CFCDCCC8B1ABA7A29D9B95908A817B797B746F736D68
7067626A63606E65617168626B625E6158555A524E564F49544A444F4844534B464B453F
4F49434A423C4A443F47413D40403F454343413D3D403D3B3B3B3B37383A35363738373D
34343835353A403D3F3B3D3C38393E424143403E3A464344414142433F424E4847484545
524945534A444C433F4B45404F433C5045404F463E53453C4F423C5648405D4D415F554D
6B5C547A69648C7D759C8E85ACA199B9ADAACDC6C3CFCECBE0E1DFE1E2E1DEDFDDDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDEDFDDDFE0DEDCDDDBD9D9D8D8D8D5CECCCAC5C2C2B9B7B2A39F9F968F8B837C77
736A6667605D655B56675E57665C58675D5B5E5A59615A5360544E5E564F5F564E5A5049
58524B534841534B46534A43484A4A54504E504B4B544F4A4E4D4B4243453F3F40403E45
3F3C443B394246424344464545444B4F4D4D4B4742524D4A4B4847494545534C48504B46
564943584B43564640554A445C483E57483F54473E5B433857443A5A473C685042665A51
79675F958582AEA29CBDB6B1CAC6C2D2CECCD8D7D4D9D9D6DFDFDDDFE0DEDEDFDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDFDDDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDDDBDEDFDDE3E4E1E4E6E5F1F5F5EFF0F1E5E5E3CACACCB4ADAB928A85
7269665D5553544943564B435B504C6A5E5F5E5F626C655C6C5E566F655A6B5E54695B51
60594F5A4C425A504B5D51484F5353635D5A61595B6C635A63605D4C4E5149484A46444E
4845513F3D4C4C46464C4F4F5250595E5A5956504C605851554F4D4E4C47584F48585146
5A47405C4B406049405F4F476A4C3D5C4839564439603C2D5B3F31593E2F714F3C695A4E
866F67B4A3A3D6CECBE5E8E6EFF3F4F0F7F6E6EAE8E3E5E3DDDDDBDCDDDADDDEDBDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDEDEDCE0E1DFE1E2E0E7E9E8E5E5E5DDDDDBCBCACBBCB8B5A7A29D
918B88817C7A7A726D7B736C7C74717F767674737679726E766C6878716B7C716A776B67
756F696E615A6D64616E645D6362626F67636C63636F665F6863605C5959575354565157
575057514B53564F4D5755535B555A635C595D544F655B545E56515B524C60564E61574C
614F476454496A554C68595070584D6C5D506E5F567B60547A655B7A685D8C74678A8077
9F8F89BDB1B0D3CDCADEDFDCE5E8E7E7EBEAE2E4E2E0E2E0DDDEDCDDDEDBDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDBDDDEDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDEDFDDDEDFDDE0E2E0DEDFDED9D9D7CECECDC6C3C1BAB7B4
ADA9A7A19E9C9B95929B96909A9492928D8C87868986807F817A7A837E7C8D837E857B7B
8A83818075717F76757F75707771717B716E786D6B746A656F68656C6463665F5E665E61
655C5D61585B615855635C58655C5C6A5F5C655A536B6059685D56685A52695D556A5D52
68584E6C5C5275625772635A77645D7C7066847771938177968780988D85A4958DA7A19B
B5ACA8C6C0BED3D0CDDADAD7DFE0DFE1E3E1DFE0DEDEDFDDDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDCDADDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDEDEDCDEDFDDDFE0DEDEDFDDDCDCDAD8D8D7D6D6D3D3D3D0
CCCCCAC3C1C1BCB9B7BBB8B4B8B5B4A5A3A29A989D928C8F89868A8C898C9D9592928A90
9E98999287869187898F8582897E7D867975827471786C677369667A6B68716765736768
7164606F615E675D576B5E586C5F5A6D5F58695B516E5F586F5F56715C516D5F556F5E51
6B594D705E547C6A5D78685E7B6B678A8077998D8AAEA29AB5ABA8B8B4B0C0BAB6C9C7C4
D1CFCDD7D5D3DADAD8DCDDDBDFE0DEDFE1DFDEE0DEDEDFDDDEDFDDDEDFDDDEDFDDDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDBD8DDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDFDFDDE4E5E2E9EBE9F1F4F3
F3F5F4EBEDEDE4E5E4E1E2DFDCDBDDBABCBBADABB29D969F8F909993939BAFA7A89F99A6
B4AEB4A4999CA2979DA094949B89888F7F798B797477686574666287706A7B6C687F6E6B
7B695E7C685D6A5D55705D53705D526D584F69564A6D5A51725D4F78594B6E5C4F715A4B
695647705C51816E5E7B695E7A6E6E968F87B0A5A5CDC9C3DAD6D7DFE4E4E3E7E9F2F6F6
F3F9FAEAF0EEE3E7E5DFE1E0DEE0DEDDDFDDDEDFDEDEE0DEDEE0DFDFE0DFDEE1DFDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDBD9DDDDDBDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDBDDDEDCDEDFDDE0E1DFE3E5E3E8EAE8
E8EAE8E2E3E3DDDDDCDBDCD9D8D7D7C1C3C1B9B8BCAFAAB0A6A6ABA8A8ACBBB4B3B0AAB1
BEB9BBB2A9AAB1A8ABAFA6A5AC9F9EA49893A1938F9488858F85829B8B87938884948986
92857D92837C867B75897A738A7B7389797286786E8A7B738C7D72907A6F8A7C718B7A6E
86776B8C7D749A8B7E96887F968C8BAAA39CBAB1AFCDC8C2D5D1D0D8DAD8DCDDDCE7E7E6
E8EAE9E3E6E3DFE0DEDDDDDBDDDDDADCDCDADDDDDADDDDDADDDDDADCDDDADDDCDADDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDCDADDDDDBDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDEDFDDDFE0DEE1E2E0
E1E2E0DDDDDCD9DAD8D8D9D6D6D6D5CACBC9C5C4C6BFBDBFBBBBBDBCBABBC6C1BEC0BBBD
C8C3C2C0B9B7BFB8B9BEB7B4BCB3B1B7AEAAB4AAA7ADA4A1A7A09DAEA3A0A8A19EA9A19F
A89E98A69C97A09692A19590A29691A19591A1968EA39891A49991A6978EA2978EA2968D
A0948AA59993B0A49BAFA49DAFA7A4BBB6AFC4BDB9CFC9C3D4CECCD5D4D0D8D6D3DEDCD9
E0DFDCDEDDDADCDBD7DBD9D6DBD9D6DCD9D6DBD9D6DBD9D6DBDAD6DAD9D6DBD9D5DDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDBDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDCDADDDDDBDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDEDFDCDEDFDDDFE0DE
DFE0DEDDDEDCDCDCDBDBDCDADBDBD9D7D7D5D5D6D5D4D4D3D3D4D3D3D2D1D6D4D1D4D2D1
D6D5D2D3CFCDD1CECED1CECBD2CDCBCECAC7CCC7C5C9C4C2C2BFBDC6C1BFC2BFBDC1BFBD
C1BCB9BFB9B7BCB5B4BBB3B1BCB5B2BDB5B4BEB9B4BFBAB5C0BBB5C0B9B3BFB9B2BCB8B2
BDB7B0C2BDBACCC6C0CDC8C3CDC9C7D4D1CDD5D2CFD8D5D1DAD7D4DAD9D6DBD9D6DDDCD9
DEDEDBDEDDD9DCDBD8DBDAD7DBDAD7DCDAD6DCDAD7DCDAD7DCDAD7DADAD7DAD6D2DDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDBDDDDDBDDDFDDDDDCDADDDEDCDDDEDCDDDEDCDDDDDBDDDFDDDDDEDCDDDEDCDDDFDD
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDFDDDDDEDCDDDEDCDDDEDCDDDDDBDCDDDB
DCDDDBDEDEDCDEDFDDDFE0DEE0E1DEE6E7E4E9EBE6EEF0ECF2F3EEF0F1EDE9EDEBEDEFEB
E8EBE6E9ECEAE7EAEBE8EAE8ECEEEDEBEDECE8EAEBEBEDEDE2E5E5E1E5E6E0E4E4DEE3E3
E0E2E2DCDEDEDEDCDFDAD8DADDDBDDDFDDE1E2E5E4E2E5E4E2E6E4E0E5E4E1E3E0DCE2E1
E2E3E1E7EAECEEF1F1F2F6F6F3F7F6F2F6F6EBEFEDE4E6E6E2E4E2E0E2E0DFE0DEDDDFDC
DDDFDDDEDFDDDEDFDDDCDFDDDDDFDCDEDEDCDEDFDDDEDFDDDEDFDDDDDFDDDBD5D0DDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDFDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDDDADDDDDBDDDEDCDDDDDADDDDDBDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDB
DDDEDBDDDEDCDEDFDCDEDFDDDEDFDDE2E2E0E3E4E1E6E8E4E8E9E6E6E2DDE3DDD5E5DFD6
E3DCD4E3DCD5E2DBD6E2DCD7E5DED9E3DDD8E2DBD7E3DDD8DDD7D3DDD7D3DBD6D2D9D5D0
DAD4CDD7D1CDD7CECBD5CBC7D6CDC8D6CCC9DAD1C9D9D1C9D8D0C9D6CFC7D6CDC4D4CCC5
D6CCC3D9D0CADED5CEE0D7D0E0D7D1E1D8D1DDD4CCD9CFC7D8CEC6D7CCC5D7CCC5D6CBC3
D6CBC3D6CBC3D6CAC2D5CAC2D4CAC1D6C9C1D4CAC2D4CAC2D4CAC1D0C8C0D6CDC6DDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDDDBDDDEDC
DDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
DDDEDCDDDDDBDDDEDCDDDEDCDDDEDCDDDEDCDDDEDCDDDEDC
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 1.03401 0.97619 1.48753 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -50 0 ]
[.5 1.0125 50 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Decomposed) show
129.000 12.813 moveto
(6) show
135.000 12.813 moveto
(oder) show
159.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
E6D2D4E6D4D5E6D3D5E6D3D4E6D3D4E6D4D6E6D4D6E6D3D5E6D3D5E6D4D6E6D4D6E6D3D5
E6D4D6E6D4D6E6D4D5E6D4D5E6D4D6E6D3D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D5E6D4D6E6D4D6E6D4D5E6D4D5
E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E7D5D7E8D7D7E9D8D9EAD9D9E9CDC9E8C5BBEAC8BD
E9C7BDE8C6BEE7C5C0E8C8C2E9C8C3E8C7C1E6C5C1E7C7C2E3C3BFE4C3BEE2C2BEDFC1BC
E0BFB7DFBEB8DDBAB3DDB7B0DBB8B1DBB5AFDEB7AEDEB7ACDCB5ABDAB3A9DAB1A5D9AFA6
D9AFA3DBB0A8DEB3A9DEB4ABDEB3AADFB4AADFB3A8DCAFA5DCB0A6DCAEA4DCB0A6DDAFA5
DCAEA4DCAEA3DBADA2DAADA3D9ADA1DBABA2D9ADA2D9ADA1D9ADA0D3A99FDDBBB6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D3D5E6D4D5
E6D3D4E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D4E6D4D6E6D4D6E6D3D5E6D4D6E6D4D5E6D4D6
E6D2D4E6D4D5E6D2D4E6D3D5E6D2D4E6D4D6E6D4D6E6D3D5E6D2D4E6D4D6E6D4D6E6D2D4
E6D4D6E6D4D6E6D3D5E6D3D5E6D4D6E6D3D4E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D2D4E6D3D5E6D4D6E6D4D6E6D4D5E6D4D5
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E7D5D6E7D5D6E7D6D7E8D6D7E6C7C1E6BAAAE8BEAD
E8BEAFE7BDB0E7BDB2E7C1B7E8C1B7E7BFB6E7BFB5E7C1B6E5BFB6E6BEB5E5BEB5E1BCB3
E1BAACE1BAB0DEB5A8DFB3A6DBB3A6DAAEA1DDAE9EDCAD9CD9A99AD7A897D5A594D7A495
D4A291D4A191D5A190D4A090D39F8ED49E8ED59F8ED39C8BD39E8DD49B8BD49F8ED59C8C
D39B8BD39A8AD19988D29A89CF9987D29888CF9988CF9987CF9984C3907FD6B0A9E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D4E6D4D6E6D4D6E6D4D6E6D3D5E6D3D5
E6D2D4E6D4D6E6D4D6E6D3D4E6D4D6E6D4D6E6D4D6E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D2D3E6D4D6E6D4D6E6D3D4E6D4D6E6D4D5E6D4D6
E6D2D4E6D4D6E6D1D2E6D3D5E6D2D3E6D4D6E6D5D6E6D3D5E6D1D2E6D4D6E6D4D6E6D1D2
E6D4D6E6D4D6E6D3D4E6D3D4E6D4D6E6D2D4E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D1D2E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D3D5E5D3D5E5D3D4E3BFB8E2AD95E4B299
E5B29DE5B29EE5B3A0E5B8A9E6B7A9E6B6A8E6B6A7E6B9A8E7BBACE8B8AAE7B9ABE3B6A7
E2B49EE3B5A6DDAF99E1AD98DAAC99D6A68FDAA38AD8A288D39C86D19A82CD977FD39680
CC937ACA8E74C78B71C4876FC2876DC3846CC7886FC4856BC68970C8856CC88A71C9866E
C6856CC5846BC38268C4836BBF8168C38169BF826ABF8268BF8264A97056CCA196E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D2D4E6D4D6E6D4D6E6D4D6E6D3D5E6D3D4
E6D1D2E6D4D6E6D4D5E6D2D3E6D4D6E6D4D6E6D4D6E6D2D3E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D1D3E6D4D6E6D4D6E6D2D3E6D4D6E6D4D5E6D4D6
E6D2D4E6D4D6E6D2D3E6D3D5E6D2D3E6D4D6E6D4D5E6D3D5E6D2D3E6D4D6E6D4D6E6D2D3
E6D4D6E6D4D5E6D3D5E6D3D5E6D4D6E6D3D4E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D2D3E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5E6D4D5E6D4D5E4BDB4E4B19AE5B59F
E6B5A2E6B5A3E6B5A5E6BAACE5B8AAE6B7A9E6B8AAE6BAABE6BAACE6B8A9E6B9AAE2B6A8
E1B5A3E2B5A7DFB19FE1AF9CDBAD9BDAA795DDA490D9A28CD59D89D49C87D09883D39683
CF9580CF947ECD917BCB907BC98C76C68A75C98C75C88B75C88C76C98A74CA8E78CB8C75
C88A73C98972C78871C88973C58871C68771C38872C38870C3886DBF8A76D6B2ABE6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D4E6D4D6E6D4D6E6D4D5E6D3D5E6D3D5
E6D2D3E6D4D6E6D4D6E6D3D4E6D4D6E6D4D6E6D4D6E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D2D3E6D4D6E6D4D6E6D3D4E6D4D6E6D3D5E6D4D6
E6D3D4E6D4D6E6D3D4E6D3D5E6D2D3E6D4D6E6D3D5E6D4D5E6D3D4E6D4D6E6D4D6E6D3D4
E6D4D6E6D4D5E6D3D5E6D3D5E6D4D6E6D3D5E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D4E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E4BBB0E4B39EE6B7A3
E6B7A6E6B7A5E6B7A8E6BAADE5B8AAE5B8AAE6B9ACE6B9ABE5B9ABE4B7A8E5B8A9E1B6A8
E0B5A7E2B5A7E0B2A3E2B09FDCAD9CDDA899DFA594DAA38FD79D8BD69C89D39986D39684
D29683D49885D29683D09683CE8F7DC88E7CCB8E79CA8F7BC98D79CA8E78CA907CCD907A
CA8D78CC8C77C98C76CA8D78CA8D77C88C76C68C77C68C76C78C74CEA092DEC0BCE6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6E6D4D5E6D4D5E6D3D5
E6D2D4E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D4E6D4D6E6D4D6E6D3D5E6D4D6E6D3D5E6D4D6
E6D3D4E6D4D6E6D4D5E6D3D5E6D1D2E6D4D6E6D3D4E6D4D5E6D4D5E6D4D6E6D4D6E6D4D5
E6D4D6E6D3D5E6D3D5E6D3D5E6D4D6E6D4D5E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5E6D3D5E6D4D6E6D5D7E4B8ABE5B39FE6B7A4
E6B7A8E7B8A6E6B7A9E6BAADE4B6A8E5B7A8E6B9ACE6B8AAE5B7A8E3B4A3E5B6A6E0B4A5
DEB5A9E2B3A6E1B2A5E3AFA0DCAC9AE0A79AE0A295DAA08ED79A89D69988D49683D19181
D39383D79888D49685D29987CF8D7EC78D7DC98C78CA8F7EC78A78C78E78C8907BCC917A
C98D77CC8B76C98C77CA8E79CC8E79C78C76C78D78C68C77C68B73D8B2A9E4CDCDE6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D5E6D4D5E6D3D5
E6D3D4E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D5E6D4D6E6D4D6E6D3D5E6D4D6E6D3D4E6D4D6
E6D3D4E6D4D6E6D5D7E6D3D5E6D0D2E6D4D6E6D2D3E6D4D6E6D5D6E6D4D5E6D4D6E6D5D6
E6D4D6E6D3D4E6D3D5E6D3D5E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D5D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D3D5E5D2D3E6D4D6E6D8DBE4B5A6E5B49FE6B8A6
E6B8ABE7B9A8E6B7AAE7BAADE3B4A6E5B6A6E6B9ACE6B6A9E4B4A5E0B09EE4B4A1DEB1A1
DCB4ABE2B1A3E3B1A7E5AEA0DCA996E3A399E29D94D89B8BD69584D69484D49280CE8B7B
D49082DA998BD69789D49D8DD18B7EC48D7FC78A76C99082C58776C58F78C68F7BCB927A
C78C76CD8A75C98D77CA8E7ACE917CC68D77C78E79C68C78C3876FE2C8C5EADEE2E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D5D6E6D4D6E6D4D6E6D4D5E6D4D6E6D3D5
E6D3D4E6D4D6E6D5D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D2D4E6D4D6
E6D3D4E6D4D5E6D4D6E6D3D5E6D2D3E6D4D5E6D3D4E6D4D6E6D5D6E6D4D6E6D4D6E6D5D6
E6D4D6E6D3D5E6D3D5E6D3D5E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D5D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D5D6E7D6D7E6D4D6E6D2D3E3B5A4E5B5A1E6B8A5
E6B7A8E6B7A6E5B7A9E6B8ABE4B5A6E5B6A7E6B8ACE6B7A9E4B6A7E2B4A4E4B7A6E1B5A6
DFB6ACE3B4A7E3B4A9E5B2A4DFAF9EE4ABA0E3A59BDCA393DB9E8EDB9D8DD89A88D49585
D89688DB9B8DD8998AD79C8CD49182CA8F81CB8D7ACC9080C98A78C88E79C98F7CCC927B
C88F7ACD8C78CA8E79CB8F7ACD8F7BC78E78C78D79C88E7ACD9482E2C9C6E8D9DCE6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D3D5E6D4D6E6D3D5
E6D3D5E6D4D6E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D5E6D4D6
E6D4D5E6D4D5E6D4D6E6D4D6E6D4D5E6D4D6E6D3D4E6D4D6
E6D3D5E6D3D5E6D4D5E6D4D5E6D3D4E6D4D5E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D5E6D4D5E6D4D5E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E7D5D7E8D8D9E5D3D5E5CDCDE3B4A2E5B6A2E6B7A4
E5B7A6E4B6A4E5B7A8E5B7A9E4B6A5E5B7A8E6B8ACE6B7A9E5B7AAE4B8A8E5B9AAE3B8AA
E2B8ACE4B6A9E4B6ABE5B6A9E2B5A5E4B3A7E4ACA0DFAA9ADFA595DFA694DBA18ED89D8D
DB9B8DDC9E8EDA9B8BD99C8CD79586CF9182D08F7DCF907FCC8C7BCA8D7ACB907CCD927C
C9917DCC8F7ACB8F7ACB8F7BCC8F7AC98F79C78D78CA907CD4A093E3CBCAE7D6D8E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D5E6D3D5E6D4D6E6D3D5
E6D4D5E6D4D6E6D3D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D5E6D4D6
E6D4D5E6D4D5E6D4D6E6D4D6E6D4D5E6D4D6E6D3D5E6D4D6
E6D4D5E6D3D5E6D3D4E6D4D5E6D4D5E6D3D5E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D5E6D4D5E6D4D5E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D5E6D4D5E7D5D6EADBDDEDE2E5E9DADDE5CAC8E3B39EE6B7A3E5B7A3
E5B6A3E3B4A1E5B6A6E4B6A6E4B5A4E5B6A8E6B8ABE6B7A9E5B9ABE5BBADE5BBAEE5BCAF
E5BAAEE5B9ACE5B9ACE6BAADE4BBADE5BAAEE5B4A7E2B1A2E3AD9EE4AF9BDEA995DDA596
DFA093DEA190DD9E8DDC9C8DDA9A8AD49284D49181D28F7ED08E7CCC8B7ACD907CCE927E
CA9481CC917DCB917CCC907CCB8D78CA907AC68D78CC927DDAABA2E5D1D2E6D5D7E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D4E6D4D6E6D4D5E6D3D4E6D4D6E6D3D5
E6D4D5E6D4D6E6D2D4E6D4D5E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D3D5E6D4D6
E6D3D5E6D4D5E6D4D6E6D4D6E6D4D5E6D4D6E6D4D5E6D4D6
E6D4D6E6D3D4E6D2D3E6D4D6E6D5D7E6D3D4E6D4D5E6D4D6E6D4D5E6D5D6E6D4D6E6D4D5
E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D5E5D2D4E7D6D7F0E5E7F6F6F9F0E9EEE4C7C5E2B199E6B9A4E5B6A1
E4B5A0E0B19DE4B6A5E2B4A2E4B5A1E5B6A8E6B7ABE6B8A9E6BAADE7BFB3E6BFB3E7C1B5
E8BCB0E6BCB1E6BCAFE6BFB3E7C2B6E6C5B8E6BEAFE5BBACE8B7A8E9BAA5E1B29DE2B0A1
E4A79AE0A492E0A18FE09B8EDEA08EDB9385D99386D58E7DD3907FCE897AD0907DD09281
CB9887CC9580CD937FCE907DC98B76CC917BC58B76CF947FE1B6B3E7D9DCE6D4D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D2D3E6D4D6E6D4D5E6D2D4E6D4D6E6D3D4
E6D4D6E6D4D6E6D1D2E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D4E6D4D6
E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D2D4E6D3D4E6D4D5E6D4D6E6D3D5E6D4D5E6D4D5E6D4D5E6D4D5E6D4D6E6D4D5
E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D5D6E7D6D7E5D4D5E1CDCEE1CACBD9C0C0E3C0BAE3B39EE5B8A5E5B7A3
E4B6A3E2B5A3E5B6A6E4B6A6E4B7A5E5B7AAE6B8ABE6B8A9E6BAADE6BDB1E6BCB0E7BEB2
E7BBAEE6BAAEE6BCAFE6BEB1E7BFB2E6C1B3E5BAABE5B8A9E6B5A5E6B6A2E1B19CE1AE9D
E3A597DFA492DFA18FDE9C8DDE9F8ED99585D79484D5907ED3907ED08D7CCF917DCF917F
CB9481CB937ECB927DCC917DCB8E7ACC927DC88E7ACE9580E2BEBCE7D7D9E6D4D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D4E6D4D6E6D3D5E6D3D4E6D4D6E6D3D5
E6D4D6E6D4D6E6D2D3E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6
E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D2D3E6D3D5E6D4D5E6D4D5E6D3D5E6D4D6E6D4D5E6D4D6E6D3D5E6D4D6E6D4D6
E6D4D6E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D5D6E8D7D9E3D0D2D3B8B8CBA6A5C19E9AE2BAB0E4B4A1E5B8A6E5B7A6
E5B7A7E4B8A8E5B7A8E5B7A9E5B8A8E6B8ABE6B8ABE6B8AAE6BAADE6BCB0E6BBAEE6BCB0
E6BAACE6B9ACE6BCAFE6BCB0E6BCAFE6BEAEE5B7A8E4B5A6E5B4A3E4B4A0E1B09BE1AC9A
E2A595DFA491DEA18FDD9D8DDD9E8ED89686D69482D5927ED4917ED1907ECF917DCF907D
CB907DCA927DC9907BCB917CCC917DCC937FCB917DCE9582E3C5C4E6D5D7E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D3D5E6D3D5E6D4D6E6D3D5
E6D4D6E6D4D6E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6
E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D1D3E6D3D5E6D3D5E6D4D5E6D4D5E6D4D6E6D4D5E6D4D6E6D3D4E6D4D6E6D4D6
E6D4D6E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5
E6D4D5E6D4D5E9D9DBEEE1E4E5D5D9C3A5A3AB807B9C776FE0B2A3E5B6A5E5B8A7E5B7A8
E5B8AAE5BBADE6B7A9E6B9ACE6B9ABE6B9ADE6B8ABE6B8ABE6BBAEE6BCAFE6B9ADE6BAAE
E6B9ABE6B8A9E6BDB0E6BCB0E7BBAEE6BDABE5B7A7E4B6A7E4B6A4E3B4A1E3B29DE3AE9A
E2A695DFA692DEA38FDD9F8DDE9F90D89887D79681D7937FD5927ED49381CF927DCF8F7C
CB8D78CA917CC88F7ACB917DCD9580CC9482CF9481CE9784E5D2D4E6D6D8E6D4D5E6D4D5
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D3D4E6D4D5E6D4D6E6D3D5
E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6
E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D0D2E6D4D5E6D3D4E6D3D5E6D4D5E6D5D6E6D3D5E6D4D6E6D2D4E6D4D6E6D4D6
E6D4D6E6D2D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5
E5D3D4E5D3D4EDE2E5F9F2F7E9E1E8AE8E8D7A514B64443CDCA894E6B8A8E4B8A8E5B7AA
E6B9ADE7BFB3E6B8ABE7BAB0E7BBB0E6BBAFE6B8ABE6B8ABE6BCAFE6BCAFE6B7AAE6B7AB
E6B8A8E6B6A6E6BEB1E6BCB1E7BAADE6BDA9E5B7A7E5B9A9E4B9A7E1B6A3E5B7A1E5B19C
E3A896E0A893DEA590DDA18EE0A092D89B88D79880D89580D6947ED89884CF937ECE8F7A
CA8972C9907BC58D78CA937DCF9A86CC9786D39885CE9987E7E4E9E7D8DAE6D4D5E6D4D5
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D2D4E6D4D6E6D4D6E6D3D5
E6D4D6E6D4D6E6D5D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6
E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D1D3E6D4D5E6D3D5E6D3D4E6D3D5E6D4D5E6D3D4E6D4D6E6D2D4E6D4D6E6D4D6
E6D4D6E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E7D5D7E7D5D7E2CECEE0CCCCD5BABBB48F8A9B6C64926A5FE0AE9BE6B8A8E5B8A9E5B7AA
E6B8ACE6BDB1E6B8ABE7BAADE6BAADE6BAADE6B8ABE6B8ABE6BAAEE6BBAEE6B8ACE6BAAD
E6BAABE6B8A9E6BDB0E6BAAEE6B7A9E6B8A6E4B1A1E3AFA0E2B09FE0AD9BE2AD99E2A895
E0A391DEA38FDCA28EDB9F8BDC9E8DD79985D5967FD6947FD5927DD49481CF917DCF8E7A
CB8A74C98F79C78D78CA907BCD9580CC9482D19683CE9885E5D3D4E6D2D3E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D3D4E6D4D6E6D4D6E6D3D5
E6D4D6E6D4D6E6D5D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6
E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D2D4E6D4D5E6D3D5E6D3D4E6D3D4E6D3D4E6D3D4E6D4D6E6D2D4E6D4D6E6D4D6
E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E7D6D7E7D6D8D7BCBBC9ACA9C09B96B88E86B48279B6897CE2B2A1E6B7A9E5B8A9E6B8AB
E6B8ACE6BCAFE6B8ABE6B9ABE6BAACE6BAACE6B8ABE6B8AAE6B9ADE6BAAEE6BAADE6BCAF
E6BBADE6BAACE6BBAFE6B9ABE4B4A5E6B4A3E2AA9CE0A797E0A897DEA593DFA491DEA18E
DE9E8DDC9F8CDB9F8BDA9D88D99C88D69783D2957FD4947ED3917CD1927ECF907BCF8E79
CC8C76C88F78C98E78CA8E78CB917BCD927ECF9481CD9784E1C5C2E4CDCCE6D4D6E6D5D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D3D5E6D4D6E6D4D6E6D3D5
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D4E6D4D5E6D3D5E6D2D4E6D2D4E6D2D3E6D2D3E6D4D6E6D2D4E6D4D6E6D4D6
E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5E7D5D7
EBDDDEEBDFE2CCADAAA988839E756BB6877AC79186D3A596E5B6A5E6B7A9E6B8AAE6B8AB
E6B8ACE6BBAFE6B8ACE6B9ABE6BAABE6BAABE6B8ACE6B7A9E6B8ABE6BAADE6BBAEE6BFB2
E6BFB1E7BEAFE6BCAFE7B9A9E3B4A3E7B3A2E1A79ADEA190DEA392DCA08EDB9D8BDB9C89
DC9D8CDA9F8ADAA08BD79E86D69C85D49781D1947FD2947ED3907BCE907CD08F7ACF8D79
CD8D77C78E75CB8D77C98C75C98E77CD907BCF9480CD9784DEBBB5E3CCCBE7D8DBE6D7D9
E6D4D6E6D4D5E6D4D5E6D4D5E6D4D6E6D4D6E6D4D5E6D4D6E6D4D5E6D4D6E6D4D6E6D4D5
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D3D5E6D2D3E6D1D3E6D1D2E6D1D3E6D4D5E6D2D3E6D4D6E6D4D6
E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5E8D7D8
F3E9EBF3EFF5BD9B98795B55684439B07B6ADDA496F6C9B5E8BAABE6B7AAE6B8ABE6B9AC
E6B8ACE6BAAFE6B9AEE6BAABE6BAABE6BAABE6B8ADE6B6A8E6B5A9E6B9ACE6BCB0E5C5B6
E6C5B7E9C3B4E7BFB1E7BBA9E2B7A2E8B6A3E0A79ADB9D8ADBA08DDA9E8BD79885D69985
D99F8CD7A18BD8A58CD4A285D39D81D39981CF947FD0957FD28F7BCB8E7AD18F79CF8D78
CE8E78C58D72CD8D77C88971C68971CD8D77CE937FCE9784DBB1A8E3CDCCE8E0E6E6DADD
E6D5D6E6D4D5E6D4D5E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5
E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D3D5E6D2D4E6D2D3E6D1D3E6D2D3E6D4D6E6D2D4E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D5D6E6D5D6E5D3D4
E1CCCDE0C9CABD97909B776F976B5EC18D7DDDA79AEDBFADE7B9A8E6B8ABE6B8ABE6B9AC
E6B8ACE6B9ACE6B7AAE6B7A7E5B8A7E6B8A7E6B8AAE6B9AAE6B8ABE6B8ACE6BBAEE6BCAF
E6B9AEE5BAAFE6B4A8E5B0A1E1A597E5A295DE948ADB8F81DA9082D78C7DD88D7FD68C7C
D88C7ED78F7ED99281D7927ED3937DD3907BCD907CCE927CD08E79CA8D78CE8D77CE8D78
CE8D78C88D74CD8D77CA8B75C88A73CD8D78CE917CCC9481D7A89CDFBAB4E5CCCBE6D2D3
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5
E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D5E6D4D6E6D4D5E6D3D4E6D2D4E6D2D4E6D2D4E6D4D6E6D3D4E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E7D5D6E6D5D6E1CECF
D0B4B4CCAAA6BD9288B58E83BA8C7ECF9D8EDFAB9EE8B9A8E6B8A7E6B9ACE6B8ABE6B9AC
E6B8ABE6B9AAE6B6A7E5B4A2E5B5A3E6B5A3E6B7A7E6BAACE7BAADE6B7ABE7B9ACE6B4A9
E6AFA6E2B2AAE4ABA1E3A69ADE988DE19288DA857BDA8378D98378D47D71D8857AD58074
D67D71D67F72D78375D78476D28978D28776CB8B79CD8E79CE8D77C98D76CB8B75CD8D78
CE8C77CA8D76CD8D78CD8E78CA8C75CE8E79CE8E7ACA917ED39F90DAAA9FE1BBB4E5CAC9
E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D4E6D4D6E6D4D5E6D3D5E6D2D4E6D3D4E6D3D4E6D4D6E6D4D5E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5EAD8D8EBDADDE3D4D6
BD9D9CAF867EB58779CBA091D8A99BDEAE9FE4B4A6E8B9A9E6B7A5E6BAADE6B8ABE6B9AD
E6B9ACE6BAA9E6B6A6E5B4A0E5B5A1E6B5A0E7BBA6E8C2B2E8C0B2E7B8AEE8BDADE7AFA4
E6A69FDEAEA8E3A198E19C92DB867EDA7C74D47165D67167D47167CD695ED87870D37166
D36B60D56F62D77368DA786DD48174D48173C98B79CB8E79CB8D75C78C73C98974CD8E78
CE8C77CC8D77CE8D78CE8F79CB8C75CD8D79CD8B77C88E7ACD9481D39988DBAA9EE4C6C4
E7D5D7E8D7D9E6D4D7E7D5D6E6D5D6E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D3D4
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D2D4E6D4D6E6D4D6E6D3D5E6D3D4E6D3D4E6D3D5E6D5D6E6D4D6E6D4D6E6D4D6
E6D5D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5E5D3D5EFDEDDF3E6E9E9E3E6
A4838280594EA87766E4B6A1F9D0C1EEC3B4EAC0B1E7B9AAE6B7A3E6BBAFE6B8ABE6B9AD
E6BAADE7BCA9E7B8A6E6B6A0E6B8A0E6B69EE8C2A7EAD1BDECCABBE9BCB2EAC5B1E8A99F
E69C96D9ABA8E1968DDE9088D37068CE6255C65743CE5A4CCC5C50C15140D66760CE5F53
CD5546D25B4BD76055E06B63D77A71D97D71C88E7BCA907AC98F74C58B70C58672CC8F7A
CD8C77CF8D79CE8B77D0907BCB8B74CD8B78CC8773C48B76C4876FC7856CD29783E5C3C1
E8DCDFEBDCDFE6D6D8E8D7D7E7D6D7E6D4D5E6D4D5E6D4D5E6D4D5E6D4D6E6D4D6E6D2D4
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D3D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D4E6D4D6E6D4D5E6D3D5E6D2D4E6D3D5E6D3D4E6D4D5E6D4D5E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D4D5E6D4D5E6D4D5E6D4D6E6D4D6E7D5D6E3D1D3DEC8CBCBAEAE
A8827DA5796CBD8B7AE1B4A0F0C4B5EABCACE7B8A8E6B4A4E6B8A6E6BAAEE6B8ABE6B9AC
E6B6A8E6B5A3E4AE9BE1A892E1AA94E4AC98E5AE9DE4B0A5E4B4A7E6AFA5E4ACA0E5A39A
E49B96DB9D9CDF9992DE928AD8827DD97C79D37168D8746FD36D63CA665DD77772D06D65
CB6358CD645ACB665BCE675EC97166C86E61C37A6BC7826FC98770C78A71C68870CB8D74
CE8B75CE8D79CF8F7AD2937ECE8E78CF8F7ACD8975C78D78C88B74CB8A74D29885DFB5AD
E4C8C5E3CFD1E4D2D5E6D3D5E6D4D5E6D5D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D4
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D5E6D4D6E6D4D5E6D3D5E6D2D4E6D4D5E6D3D4E6D3D5E6D4D5E6D4D6E6D4D6
E6D3D5E6D4D6E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D4D5E6D4D5E6D4D5E6D4D6E6D5D6E7D6D7D8C5C9C9AFB1AA837F
AB7F78C19486CD9C8BE1B3A1EABDADE7B8A6E4B2A1E5B09FE6B9A9E6BAADE6B8ABE6B9AB
E6B3A2E4B09CE0A692DB9C85DC9D89E1A392E19C92DC968EDCA396E2A499DE9792E39D95
E39A94DC9291DD9C96DE938BDB928EDE9494DA8884DC8C89D87C72CF7872D68680D17972
C86F65C76C64C26A5FBF6459BD695CB96254BE695CC37666C87F6CC88871C7886ECA8B70
CE8974CE8D79D0917DD49681D0927BD1927CCE8B76CA8E79CA8D78CD8E79D29784D9A99C
DFB7AEDCC3C4E2CED1E3D0D3E4D1D4E7D5D7E7D5D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D3D5E6D3D5E6D2D4E6D4D5E6D2D4E6D2D4E6D3D5E6D4D6E6D4D6
E6D3D4E6D4D6E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D4D5E6D4D5E5D3D5E7D5D7E8D8D9EADDDED2C3CAB69A9D77514B
A4736AD8AB9BDCAC9BE4B6A4E8BAAAE7B7A4E2AD9AE4AD99E6B9ABE6B9ACE6B8ABE6BAAB
E7B29EE4AC99DD9F8AD58F77D7937EDF9E8EDF908BD07D77D29185DD988CD3807FE0948D
E09691DA8280DA9B96DD928BDBA09DDFADAEDCA19FDDA6A4DB8A7FCF8984D3938BCF827D
C2786DBF6F69B3675BAB594EAD5E4FA55042B7584AC06A5ACA7A69CC8E75C98D6EC98B6B
CE8772CE8D79D1947FD69984D2947ED3957DCF8C77CC8F7ACB8E79CE8F7AD09480D29B89
D7A697D4B9BAE2CCD1E3CFD4E4D1D4E9D8D9E8D7D7E7D5D6E6D4D6E6D4D6E6D4D6E6D4D5
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6E6D3D4E6D3D5E6D2D3E6D4D6E6D2D4E6D1D2E6D3D4E6D4D6E6D4D6
E6D2D3E6D4D6E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D5D6
E6D4D6E6D4D5E6D4D6E6D4D5E6D4D5E5D2D4E8D8DAECDEDFF0E9EACFC7D2A08589251611
976356F3C9B6EEC1AFE8B9A8E6B8A8E7B7A2DFA792E2A893E6BBAFE6B8ACE6B8ABE6BBAB
E8B29BE4AB96D99881CB8167D08973DF9D8DDE8685BF625CC37D6FD68A7CC36365DB8781
DE918DD56D68D69896DC8F8AD9B2AFDBCECDDAC4BFD9CCC4DF9D8ECDA098CEA496CB8D87
B98374B3716CA061528F4A3E984E3E873A29AC442EBC5C4AD07768D29B7ECC976FC88B66
CF8671CF8D79D19682D89D87D49780D4977DCF8C76CF907BCD8F7BD0907CCE917BC78B72
CD937DCAAFB0E2CBD3E4D1D7E5D2D6ECDDDEECDCDAE8D7D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D5D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D3D5E6D3D5E6D3D4E6D4D6E6D2D4E6D2D3E6D3D5E6D4D6E6D4D6
E6D2D3E6D4D6E6D3D5E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5
E6D4D6E5D3D4E6D4D6E6D3D5E6D4D5E5D3D6E5D2D3E3CFD0E2CCCEB69BA0957272644038
B17C6EECC0AEEABCAAE7B8A5E5B7A5E6B39EE1A994E2A893E6BAADE6B9ACE6B8ABE6B8A8
E4A893DE9E89D59279CD836BCD7F6DD5857BD0706FC3675FCA8275D98F81CF7977DF958E
DF968FDD827FDBA19EDC958CDDAFAAE0C3C3DDB5B0DCB7AFDC9587D39C95D5A298D1928B
C38477BF7B74B47568A96054A55B4B9D4F42AA4C3FB55E52BE6A5BC57667C57F64C58566
CD8571CE8E79D39882DA9E89D79B85D69981D1907ACE907BCD8F7BCE907BCE8F7ACA8E77
CF947FCDA9A5DCC1C3DBC3CADEC9CEE4D1D3E4D2D4E5D3D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D5E6D4D6E6D3D5E6D3D5E6D3D5E6D4D6E6D3D4E6D3D4E6D3D5E6D4D5E6D4D6
E6D2D4E6D4D6E6D3D5E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5
E6D4D6E5D2D4E6D4D6E6D3D5E6D3D5E5D3D7E1CBCBDAC0C2D3B3B59A777688615E92655C
C59282E8BBA8E7B9A7E6B7A3E5B5A2E4AF9BE2AB97E1A894E6B9ABE6B9ACE6B9ABE6B6A6
E09F8CD8947ED08C72CD846DCA7768CC726AC15E5CC56B60CF877ADC9386D88C85E1A199
E09A92E19692DFA9A5DD9A8FE0ADA7E3BBBBDEAAA4DDA79EDA8F83D89B94DAA199D7978F
CC867BC9837BC3877BBC7467AF6555AB6356A8524AB05E57AE5F50B55A51BD6C59C28065
CB8570CE8E78D59982DB9F8AD99F89D79B85D3947ECE8F7BCD8F7ACD907BCD8D79CC907A
D09480CFA49AD6B7B5D2B7BED8C0C5DDC7C9DEC9CFE3D0D4E6D4D5E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D4E6D4D6E6D3D5E6D3D5E6D4D5E6D4D6E6D3D4E6D4D5E6D3D5E6D4D6E6D4D6
E6D2D4E6D4D6E6D3D4E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D2D4
E6D4D6E5D1D3E6D4D6E6D3D4E8D5D6EAD9DFE2CECFD4BABDC6A1A273504D6A443EB5837A
D9A997E7BAA7E6B9A7E7B6A2E4B49FE2AA96E3AC97E1A792E6B8ABE6B9ACE6BAACE5B5A4
DC9583D08771CA8468CB816CC2665AB95850A7433CC26657D18579DD9385DE9D8FE3ADA3
E09D92E3AAA2E2B2ADDD9E90E3AEA7E6B9B9E0A59DDD9B90D88B7FDD9D96DFA5A0DCA097
D58A81D18F85D09D93CB8B7DB56E5DB37769A15550A75B59995242A14038B45B4DC17D66
CA8773CE8F79D79C83DEA18DDCA48FD89E89D69881CE907BCD8F7BCD907BCD8B77CC907B
CF917DCF9D8CCEADA8C8ABB4D4BCC3D6BEC1D6C0C9E1CDD3E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D2D4E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D5D6E6D2D3E6D4D6E6D3D5E6D3D5E6D5D6E6D4D6E6D3D5E6D5D6E6D3D5E6D5D6E6D4D6
E6D2D3E6D4D6E6D2D4E6D2D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D1D2
E6D4D6E4D0D2E6D4D5E6D2D3EAD9D8F3E6EEE6D9DBD0B8BDB790923A2420361E18DDAAA1
EFC6B0E6BAA5E6B9A8E7B6A1E4B39CE0A490E5AD98E0A591E6B7ABE6BAADE6BDAEE5B3A2
D78A78C57961C17A5CC87C68B3514498382A77230EBA5C48D28175DD9283E3B399E4BDB0
E09F91E4C4B5E5BEB8DCA290E7B0A7E9B8B9E29E94DB8D7ED5857AE4A09AE7ABAAE3AEA3
E09089DC9F92DBBCB2DCAC99BA7A67B992809656569B575B7D4031832616A94A3EBF7C68
C98D77CF917BDAA085E0A390DFAA97DAA18ED89E86CF907BCD907BCC907BCC8874CD907C
CE8E79CE957CC4A299BC9EA8D2BCC5CDB3B7CDB4C1DECAD3E7D5D7E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D1D2E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D3D4E6D4D6E6D3D5E6D3D5E6D4D6E6D4D6E6D3D5E6D5D6E6D3D5E6D3D5E6D4D6
E6D3D4E6D4D6E6D3D4E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D2D3
E6D4D6E5D2D3E6D4D6E6D3D4E3CFD2DBC4C8CCAAA6BD9695A878764E3029744940D9A69C
EABEA9E6B7A4E6B7A5E5B49FE4B19CE1A894E4AD99E0A793E6B7A8E6B7AAE6B8AAE4B19F
D78E7BC87D65C67E62CF8572C86E65BC5B56AC4944CC7567D99084E09D90E3B09BE4B9AC
E1A598E4BDB0E5BAB2DFA596E6ADA3E8B2AEE09E92DC9384D78B7EE19E94E3A09ADFA195
DC8C83D79386D8A79CD59887BE7766BE8A78A55E59A75F5C914B3C8B2E24A7483DBA705D
C37B69CC8C76D79A81DFA390DFA793DBA18ED89C85CF907BCD8F7ACB8F79CB8874CD8E7A
CE8E79CE947EC8A094BD9DA3C3A4A8CEB1B3D3BAC4DDC8CFE5D3D4E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D2D3E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D3D5E6D3D5E6D4D6E6D4D5E6D4D5E6D4D6E6D4D6E6D4D5E6D4D6E6D4D5E6D2D4E6D4D6
E6D3D5E6D4D6E6D3D5E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D4
E6D4D6E5D3D4E6D4D6E7D4D5DDC7CCC5A7A9AF857CA87A7598655E5D382FA26F65D9A69A
E6B9A5E6B4A3E6B6A3E3B29EE4AF9CE2AB98E3AD9AE0A996E5B7A5E6B5A8E5B5A6E3AF9D
D8917DCB8068CA8167D48D7BD6897FD27F7ACC7170D98C81DE9D92E3A79BE3AF9EE4B6A9
E3AB9FE4B8ACE4B7ADE1A89BE6ABA0E7ACA4DE9D90DC9787D98F81DF9C90DF988EDB9789
D9897DD48A7DD4978ACE8978C27665C28472B2655CB0665EA1544591342EA5463CB46754
BD6D5DCA8772D5957DDEA38FDEA591DCA18ED79C83CF907BCD8E7ACA8F78C98973CD8C78
CF8E79CE947FCC9D8FBC9B9EB28E8DCCADAFD7BFC6DCC6CCE4D1D2E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D3D4E6D3D5E6D4D6E6D4D5E6D4D5E6D4D6E6D4D6E6D4D5E6D4D6E6D4D5E6D1D2E6D4D6
E6D4D5E6D4D6E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5
E6D4D6E6D4D5E6D4D6E8D7D7D6BFC8A787877F564A81544B75463C5B3327CA968BDEAB9D
E7BAA5E6B1A1E6B4A0E0AF9BE4AC9BE2AC9AE2AD99DFAA97E5B6A2E6B1A4E5B0A1E1AD9A
D7917DCA7E67CB8269D99786E0AA9CE1A79EE0A19AE2A79CE4ABA0E5B3A7E4B1A2E5B5A8
E4B3A7E5B7ABE4B5AAE3ACA0E6A89DE6A599DD9B8CDC9B89DB9485DE9B8CDB8F81D78E7E
D88679D18173D18B7AC97D6BC87566C9826FBF6C5FB96C5EAD594B8D322F9C3C34AB5A48
B35B4DC7826DD29079DDA491DFA490DEA38FD79C83CF917CCD8E79C98E76C88972CE8A75
CF8D79CE927DCE9987BA9896A27A76CEACACDCC3C7DAC1C7E3CECFE6D4D5E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D2D3E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6CFD0E6D4D6
E6D5D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D5D6
E6D4D6E6D5D6E6D4D6EADBDBCDB6C57C5E5D301C1341241B3B1E144F2819F5CABCE4B1A1
E7BAA4E6AC9FE6B19CDDAC97E4A799E2AE9CE1AC98DDAB97E4B49DE6ADA0E4AB9ADEAA95
D5917BC97B63CD836BDFA595E7D9C1EAE2C8EDE7CBE9CABBE9BCB1E6C1B5E5B2A7E5B3A7
E5BCB0E5B6ABE4B3A5E6AFA6E6A498E49D8CDB9988DC9F8CDD9A89DD9988D78470D2826F
D88274CE7668CD7C67C26E5BD07367D27F6AD07461C4735EBB5D51862E2E8F30279D4937
A44637C37C67CF8A74DEA694DFA390E2A592D79D83CF927DCE8E79C88E74C68A72CE8773
D08C78CF8F7BD1947DB8938E8F675FD3AFADE2C9CAD6BBC0E0C9CBE6D4D5E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D5D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D3D4E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D1D2E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D5D6
E6D4D6E6D5D6E6D4D5E5D2D3D1B5BC9B7773774D3E8051447C493B834C3BE8BCAFE3B2A1
E6B7A2E6AFA0E6B39EE0AF9CE5AD9EE3B1A1E3AF9EE0AF9DE4B7A2E6B1A3E4AF9FE0AB98
D89682CF856FD08770DB9B8AE3BCA7E7C7B2E9CDB8E8C1B4E7BBAFE6BEB2E5B5A9E5B4A8
E5B9ADE5B6A9E4B5A7E5B2A6E5A99BE3A190DB9B89DB9C87DB9886DB9987D78975D28874
D48574CD7D6CCA806BC37562CA7767CC806ACA7663C27761BC66589C4340A3443DAB5A47
B05848C57F6ACF8B75DBA08CDDA18DDEA18DD69A82CE8F7ACC8C77C88C74C68971CC8973
CE8C78CE907BCE937EB7938E7C5751BD9A99DBC3C6DCC4C8E3CECFE6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D5D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D3D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D2D4E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D3D5E1CACDD5B4B3B48C83A97867AE7869AB7061AA6F5EDEB3A6E3B3A1
E4B4A1E6B1A1E6B5A1E2B2A0E5B2A3E5B4A5E4B3A2E2B3A2E5B9A6E6B5A7E5B3A4E2AD9B
DB9B89D48F79D38C76D89481DEA692E2B4A1E6BBA9E7BCAFE6BAAEE6BCB0E6B8ABE5B6A9
E5B6AAE6B6A8E5B8A9E5B4A7E5AC9DE2A493DC9C8ADA9984DA9684D99986D68D79D28B77
D18874CC816EC6836DC47B67C67A67C78069C57965C27A64BD705EAC5850B1594EB56954
B86855C6816CD08C76D89C84DB9E8ADB9D88D59780CE8C78CA8A75C88A73C78870CB8B73
CD8C77CD907CCC927DB6928E694843A98787D5BDC1E0CBCEE4D1D2E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D5D7E5D4D7DBC2C8D6B0A8C89B8DD3A292D5A18FD39989CE9885DAB2A5E3B5A1
E3B19EE6B3A2E6B6A2E4B4A3E6B6A8E6B8A9E6B5A7E5B6A8E5BAAAE6B8A9E5B6A6E3AD9D
DE9F8FD99883D5907AD58D77D79680DFAA96E4B5A2E7BCB0E6BEB1E6BDB0E6BBAFE6B7AA
E6B5AAE6B6A6E5BAAAE6B6A9E5AF9EE0A593DC9D89D89580D99582D89884D5907AD18E78
CD8B73CB8670C2856DC37F6BC37E67C48168C37E68C28067C07C65BA735FBC6F5EBD765E
BD765DC6816CCF8B75D4967BD89C88D89A83D3957FCE8975C88773C78772C7876FC98C72
CB8D77CD917CCA907BB5938E4E3430967678D3BFC4E8D7D9E8D7D8E7D5D7E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D5D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D5D6E6D5D7E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5
E6D4D5E6D6D9E4D7DCD4B8C3D7AB9AE2AE97FFDCCCFFD9C2FCD3C0F0CFB6D4B0A3E4B7A1
E0AD9CE6B4A2E6B7A3E6B7A7E6BBADE7BCAEE7B8ACE7BAAEE6BCADE6BCABE6BAAAE4AD9E
E0A396DEA38FD6937FCF826BCD8168DA9F88E1AF9BE8BEB3E6C2B5E6BDB1E6BFB3E6B8AB
E6B4A9E6B5A3E5BDACE6B9AAE4B39EDDA692DB9D87D59079D79380D69883D4957BD0927A
C98F71C98B71BC876DC3856FBF8268C08168C0836AC2866BC38B6DC7986EC68D6EC48769
C18766C5806ACD8973CE8E70D69A86D4967ED2927DCD8571C58470C78471C7866DC78E71
C98D76CD927DC78D78B595912C1C1A7F6567D3C6CEF3E9E8EDE0E1E8D7D9E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D5D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D4E5CECDDABABDDBB1A1DFAF9CF0C0AFF0BFA9EDBBA8E9BEA9D8AFA2E4B7A2
E2AE9DE6B5A2E6B7A5E6B8A9E6BCAEE7BCAFE7BAAEE7BCB1E6BDAFE6BDADE6BBACE4B1A2
E1A798DEA591DA9985D58C76D28A72D99B85DFA693E5B7AAE6BDB1E6BCB0E6BEB1E6B8AA
E6B4A9E6B6A5E5BBABE6BAACE4B4A2E0AA97DCA08CD89580D79582D59783D2927ACF9079
C98C72C98870BF846CC2826DBF8066BF7F66C08169C38468C4866CC68D6CC6886DC6886C
C6886BCB8873D08E78D29378D59883D4957ED1917CCD8773C78672C78672C7876FC88D73
C98D76CB907BC88F7AB28C853B262279595AC0A4A7E3CFD0E3D0D2E5D2D4E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D5D6E6D0D0E6C7BFDFBBB5DFB4A4DEB19FE3AC9AE4AC97E1AB97E4B3A1DBAEA1E5B7A2
E4AF9FE6B6A3E6B7A7E6B9ABE6BCAFE6BDB0E6BCAFE6BFB4E6BEB1E6BDAFE6BCAEE5B4A5
E3AB9BDFA793DE9E8BD9947FD59179D89882DD9F8BE2B1A2E6B9ADE6BBAFE6BDB0E6B7A9
E6B5A8E6B7A7E5BAABE6BBADE5B6A5E3AE9CDDA28FD99985D79783D39783D1907ACE8E78
C98A72C7866FC1826BC17F6ABF7D65BE7E65C07F67C48366C5826CC6876CC7856DC9896F
CB8B71CF8F7AD3927CD4977ED49681D4937ED1907BCE8975C98874C88872C78770C88C74
C98C75CA8F7ACA917CAF857A482D28724F4FAD8886D3BABBDBC4C5E2CDCFE6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D4E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6
E6D7D9E5D0CEE6C2B4E4BDB0E4BDABE3BBAADCA18DDC9F8ADAA08BE4AFA0DDAB9FE6B7A3
E6AE9FE6B7A2E6B7A9E6BBAEE6BEB1E6BFB2E6BEB2E6C2B8E6C0B4E6BFB1E6BEB1E6B8AA
E4B09FE0AC97E2A492DC9B87D7947DD6917BD9947FDFAB99E5B5AAE6BAAEE6BDB0E6B7A9
E6B5A9E7B8A9E5B9AAE6BEB0E5B9AAE5B4A2DEA694DC9D8BD79985D29784D08F7ACD8D78
C88973C6846EC27F69C07C69BE7C64BC7C64BF7D66C48263C67F6BC7846CC9856ECC8D74
D08F78D49782D59781D69B83D2927ED4917CCF8F7ACE8B76CA8A75C88972C78672C88B75
C98C74C88D78CA917CA97C6E492C265E3C3B8F6963C5A8ABD2B7B8DFC8CAE6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D2D3E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D2D3E6D4D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D5D6
E5DCDFE5D0CFE7BEA7EAC4ABEACCB6E8CBBAD3937DD2907ACF927BE3AA9DDFA89CE6B8A4
E7AD9FE6B8A2E6B8ACE6BDB2E6BFB3E6C0B5E6C1B6E6C6BEE6C1B7E6C1B5E6C0B4E6BDAF
E5B5A4E1B29CE7AA9AE0A58FD99880D18771D4866FDAA38FE5B1A6E6B9ADE6BCB1E7B8A9
E7B7AAE7BAACE5B9AAE6C2B4E6BEB1E9BCAADFAA9ADFA393D89E89D19886CF8E7BCD8D78
C78874C5826EC37C68BF7866BE7A63BB7B63BE7C65C4815FC67B6AC77F6AC9846ECF9178
D5937FD8A18BD89C86D99F8AD08E7AD38E7ACE8D79CE8C78CC8C77C78A72C78573C88A77
C88C73C58A76CA927D9F715F4427213E242363433BB5959AC8A7A8DBC3C4E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D4E6D4D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5
E6D0D2E6C6C0E5B29FE6B19DE5B0A0E1B1A1D1917BD4947FD39C86E4AD9EE1AC9FE6B8A3
E7B1A1E6B8A4E6B8ABE6BDB1E6BFB3E6C0B5E6C1B5E6C4BBE6C1B6E6BFB3E6BFB2E6BAAD
E5B6A4E2B09CE5AC9BE1A391DA9B85D6907CD8927CDDA693E5B3A6E6BAADE6BBAFE5B6A6
E5B4A6E6B8A9E5B9A9E6BDAFE5B8AAE6B4A3DDA694DB9E8CD49782CE9380CC8B78C98A75
C68772C4816DC37E68C17B67BD7A62BA7A61C07C65C68365C9826FCC8772CE8B76D1947D
D79782D99F8BD89B85D89D88D0917CD3907CCF8E79CE8D78CC8B77C98A73C78873C88976
C98C74C88D78CC9580AB77646A4035673F3A80564BAF8D8CC9ABABDCC4C6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D5D7E6D2D4
E7C6C5E6BDB2E3A896E3A18FDE9A8CDA9C8CCF8E79D59783D5A490E4B0A0E3AFA1E6B8A3
E6B4A4E6B8A7E6B8AAE6BDB1E6BFB2E6C0B5E6C0B4E6C2B8E6C0B4E6BEB1E6BDB1E6B8AB
E5B6A5E3B09DE3AD9CE2A394DC9F8ADA9885DB9C87DFA896E5B4A7E6BAADE6BBADE4B4A3
E4B2A3E5B7A7E6B9A9E6B9ABE4B3A4E4AD9CDCA38FD89A87D1917DCA8E7BC98875C78671
C48570C3816CC38068C27D68BC7A61BA795FC17C66C8846BCB8774D08E7AD2927DD49781
D99A85D99E8AD79B85D89C87D1947ED3927DCF8F7ACE8D79CC8B77CA8A74C78974C88874
CA8B75CA8F7BCD9784B57C688B57478A564C976556A9847FCAAEADDCC5C8E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D7DAE6D4D7
E7BDBAE6B4A3E09D8CDF9280D78578D28877CB8772D49684D5AA97E5B1A0E5B2A3E6B8A3
E6B7A5E6B8A9E6B7A9E6BDB1E6BFB3E6C1B7E6C0B5E6C1B8E7C0B5E7BDB1E6BDB1E6B7AB
E6B8A7E5B0A0E2B19EE5A498DEA491DD9E8DDDA590E1A998E5B5A6E6BAAEE6BAABE3B2A0
E3AEA0E4B6A5E6B9A8E5B5A7E3AE9FE2A897DAA18BD59682CE8C77C78976C68572C3836E
C3846EC27F6AC48268C37F68BA785FB8765AC17A64CA856FCD8D79D49581D69884D79B86
DC9E8ADB9F8CD79C87D89C87D19680D4937FD0907BCE8E7ACD8B78CC8A76C88C75C98773
CB8A75CC927DCE9A87BF8069AE715AAB6B5AA96D599B776EC7AEADDBC4C7E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5E5DADFE5DADE
E7B2AEE6A990DD9080DA816DCC6D5FC5725DC57F6AD29584D5B2A1E5B4A1E8B6A6E6B8A2
E6BBA6E6B8ABE6B7A8E6BEB1E6C0B3E6C3BAE6C1B6E6C1B7E7C1B7E8BDB2E6BDB2E7B6AC
E7BCAAE7B0A3E1B6A2E8A49EE0AA98E0A697DEB09BE3A899E5B6A5E6BAAEE6B8A9E1AF9B
E1AA9AE2B4A2E6B9A7E5B0A3E2A898E0A191D9A087D1927DCB8571C28370C3826FBF7F6B
C1826BC17D68C58467C48067B7755CB37153C17661CB8473CF927ED89E8BDBA18EDBA08C
E0A490DEA08FD79D88D89C88D19882D49681D1917CCF8F7BCE8B78CF8A77C88F76C98671
CC8976CE9681CF9E8BCC856BD89270D48568BF765A866559C4AFADDAC2C6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D2D3E6C8C7
E7B2AAE4A994DA8F7ED6826EC97262C47662C98772D69A89D9B29FE5B4A2E7B6A6E6B8A4
E6BBA9E6B9ACE6B9ABE6BDB0E6BEB1E6C0B5E6BFB2E6BFB2E6BDB0E6BAACE5BAACE6B4A7
E5B6A5E5AFA0E1B19FE5A59AE0A896E0A696DEAD99E3AC9CE5B6A7E6BAADE6B9AAE2B2A0
E3AFA0E4B5A5E6B8A8E5B2A3E2AA9BDFA291D99C85D1917CCA8672C18471C2816EC07F6A
C0826BBF7F6BC38369C5826ABC7B62BC7A5FC67F6BCE8A78D19480D89D89DAA08DDA9F8B
DDA28EDC9E8CD79B87D79A86D19781D2937FD08F7BCE8E7ACD8A77CC8976C88C75C88672
CA8975CD927ECF9C8CC78269CF886BCC8469C07D659B6F62CAAEACDDC8CBE6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6CBC7E4B9B3
E6B0A4E2A896D68D7BD2826EC57562C17964CC8D79D99F8DDCB29FE5B5A4E6B6A6E6B8A6
E6BCACE6BAADE6BAADE6BCB0E6BDB0E6BDB1E6BCAFE6BCAEE4BAABE4B7A7E4B7A7E5B1A3
E3B2A1E3AF9FE1AD9CE2A698E0A694DFA696DEAC98E3B09FE6B7A8E6B9ACE6B9AAE4B5A3
E4B3A4E5B6A8E6B8A9E5B4A4E3AC9CDFA290D89983D0907BC98772C08471C0806CC07F6A
BF816BBD806CC1836BC5846DC18068C3826ACB8774D1907DD39683D99C88DAA08CD99F8B
DCA18DDA9D8AD79A85D69985D29680D1917DCF8E79CD8D79CC8976CA8876C88A75C88673
C98974CB907DCF9B8CC37F68C98168C7846BC2846DAD7769CFADAAE1CCCFE6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D7DAE6C8C0E4ADA1
E8B2A3E4AB9CD78D7BD1826FC37660BF7964CD927EDCA491E0B39FE5B6A6E6B7A7E6B8A9
E6BDB1E6BBAFE6BCB0E7BCAFE7BCAFE7BBADE6BBACE6BAA9E2B6A5E2B4A2E3B4A2E5AF9F
E2AD9DE2AE9EE1AA9AE0A896E1A694E0A999DFAD9AE4B4A3E6B7AAE6B9ACE6BAA9E5B8A7
E5B6A9E6B7AAE6B8ABE5B5A4E3AD9DDEA28FD89681CF907AC88772BD8471BE7F6BBF7E68
BE806BBA816EBF826DC68670C5856DCA8B75D0907DD59784D69A87DB9E8ADCA28ED8A08C
DBA18DD99D88D89984D59784D39680CF8F7BCE8D78CC8D77CB8875C98676C88875C78674
C88973CB8D7AD09B8FC37E68CB806AC88C71C9907ABE7D6DD4B0ACE4D5D9E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D5D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5E6D5D6E5DDE3E6C8BAE4A18D
EEBAA6EAB3A7DB8F7DD58672C47B60BF7C65CF9884DFA896E5B49EE5B7A9E6B8A8E6B8AC
E6C0B6E6BDB1E6BFB5E8BDB0E7BBAEE8B9A9E7BAA9E7B8A4E0B29EDFB29BE3B09BE4AC9A
E0A999E1AE9DE1A799DEAB94E3A794E1AD9DE0AD9BE6BAA9E7B9ADE7B9ACE6BAA9E7BBAC
E7BBAFE7B9ADE6B7ADE5B6A3E4B09FDEA18DD8927ECF9079C78772BA8571BC7E69BF7D67
BD806BB78270BC826FC78873CA8A73D39683D59B8ADAA08DDA9F8CDEA08CDDA490D8A18D
DBA38FD89D86D99783D59683D49580CD8D79CD8B76CB8C76CA8674C78475C88674C78675
C68971CB8876D19C92C37E69CE806DCB9779CFA38BD48572DBB7B3E8E5E9E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6CDCCE3B4A6D79582
DB9D89D49789C37D6ABB7461AF6D57B1735FD19A86E1AC99E5B5A1E4B6A7E6B8A8E6B8AB
E6BDB1E6BBAEE6BCAFE5BAACE5B8AAE5B7A7E5B6A6E5B6A3E0B19EE0B09CE1AF9CE2AB99
E0A898E0AC9BDFA495DDA792DFA390DFA897DEAC99E2B6A4E5B7A9E6B8AAE6BAAAE7B9AA
E7B9ACE6B8ACE6B8ABE5B6A3E3AD9CDCA08DD6927DCD8B76C68571BD836EBC7D68BE7E68
BD7F6AB9826FBF8370C68873C98B74D0927ED29684D69B88D69C89D99D88DBA08CD79E8A
D89D8AD69A84D79682D49581D2947FCD8E7ACC8C78CB8B77CA8875C78675C88774C68674
C68874C88C7CCE988CBB7862C57862C6886ECA8F7BCD806DD7A49BE6CACAE6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D4E5BFB7DFA495CC8A77
C78470BD7E6FAD6D5AA364539C614FA46C59D39D88E2AF9CE5B6A4E4B6A6E6B7A8E6B8AA
E5BAACE6BAACE5B9ABE2B7A9E3B5A6E2B4A5E3B3A3E3B3A2DFAF9DE0AE9CDEAD9CE0A898
DEA695DEA997DCA092DBA390DBA08DDDA392DDA996DFB29EE3B6A5E5B7A7E6B9AAE6B9A8
E6B8ABE6B8ABE6B8A9E6B6A3E1AB9ADBA08DD4917DCB8872C58370BF816BBC7C66BE7E68
BC7E69BB816DC28371C68872C98B75CD8F7BCF9280D49784D39985D69A85D89C89D69C87
D59986D49883D59681D39380D0937FCD8F7BCB8E79CA8B78C98A76C78774C78773C68674
C78876C58F80CB9587B4725CBC7059C07B64C4806EC97B68D19586E1B3AFE6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D3D5E6D4D6E6D6D7E6D4D6E3B6A5D9917EBD7A66
B36F58A86C589A5F4B8C55468A5648996654D5A08CE4B4A0E6B7A7E4B5A6E6B8A8E6B8AA
E5B8A8E6B9AAE4B7A6DFB5A6E2B2A3E0B3A6E3B2A2E5B6A5E2B09FE4AF9FE1B1A1E2AA9A
E3AA97E4AF9BDEA293DEA594DA9F8BDDA190DEAD98DEB59FE2B9A5E5B8A7E7B9ACE6B8A6
E6B8AAE6B7ABE6B7A7E6B6A2E0A898DA9F8CD3907CC9836FC38070C18069BD7C65BF7F69
BD7F69BE826DC48372C68872C98C78CC8E7BCD907DD29583D19884D39882D69986D69A85
D29482D29681D39480D3917DCE927DCD8F7CCA8F7AC98A78C88B77C88974C88772C58773
C78778C29286C89383AD6B55B56950BB725CC07564C97A66CB8670DB9E95E6D4D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D2D3E6D4D6E6D4D6E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E5D2D3E6D4D5E7D8DBE6D8DCE1AE92CE7B61A86752
9A5A3E91594185503B724537764A3F8D5F4ED7A38FE6BAA4E7B9ACE3B5A6E6B8AAE6B9AB
E3B4A3E6B7A7E3B4A1DCB2A3E0B0A0DEB3A8E4B4A4EABEAEE7B4A4EBB4A4E8BAADE8B0A1
EFB39CF1BFA7E4A799E5AD9EDB9F8BDFA28FE1B69FDDBCA3E2C0A8E5BAA8E7B9AFE6B7A4
E6B7A8E6B7AAE6B7A4E6B6A1DEA594D89F8BD18F7BC67E6BC27E71C57F66BE7B63C0816C
BF816AC2836CC78373C58771C98D7ACC8E7ACB8D79D09481CF9883D09580D49683D69883
D08E7DCF9380D1937ED28E79CB907CCC8F7CC9917CC88979C88E79C98B73C98771C58873
C8867ABD978CC48F7FA3624DAD6145B66853BB6959C87B66C17656D08675E6D4D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D5D6E7D6D8E6D5D7E5D2D3E6CCCADD9B84D3856FB4725E
8D4F3A7A45387345366A3E3370453A865A4BD9A591E6B8A4E6B8A9E3B5A4E5B6A6E6B7A8
E5B6A5E5B7A7E4B5A2DCB1A0DEAC9AD8A89AD8A493D4A090D5A190D8A194CD9A8DD09A8A
CB9486C68E80CA8C7DCC8D7CCD9380D29282D39985D59E8ADCAA95E2B29FE6B7A9E6B8A6
E6B8AAE6B8ABE6B8A8E6B7A3DEA796D99E8BD08E7AC6806AC17E6CBF7D64BB7A61BB7B65
B97963BD806AC68574C68974CA8F7ACA8C78CB8D79CF917CCC937ECD937ED19481D29580
CD8F7DCF947ED0937ED2917DCC937ECD907DC8907BC78A78C68C76C68A73C58771C38773
C78779C19487C48F7DA36651A85F46B1624DB46251C36E5AC37659D08878E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E7D5D7E8D8DAE6D5D6E3CACAE6C1B9D98A76D68C79BC7A67
80443563332D633A2F61382E6941367F5649DAA793E6B8A5E5B7A6E3B4A2E4B5A3E5B6A5
E5B7A6E5B7A7E4B5A2DCB09EDBA896D29F8ECE9784BF8878C5907FC79287B38073BA8778
AC7B739C685FB27666B47361C08877C68576C5816ECB8775D59884E0AC98E4B5A5E6B8A8
E6B8ABE6B9ACE6B9ABE6B7A4DEA897DA9E8AD08D79C68169C07D68BA7B62B8785FB6765F
B4725EB87D68C58876C88B76CA8F7BC88A76C98C78CC8D77C98D79CA8F7CCE917FCE917D
CA8E7CCD937CCF937ED0937FCD947FCD917DC88F7AC68A77C48A74C48873C28772C28672
C68878C49182C48D7BA26854A25D46AA5B47AD5C4ABE6450C3755BCF8877E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D5E9DADCECE5E7EAE3E2E5D2CEE6BCACD17761D89281C28270
6C342A421E1B4C2C25542F275F3A30744F44DCA995E6B8A7E4B6A4E2B4A0E3B39FE5B6A3
E7BAA8E5B8A6E5B5A2DBAD99D7A28EC8927EBD8470A06959AF7B6AB280789161549E7062
865D5B673E39935C4D935743B17C6DB87769B06754BB6C5BCA846FDDA58FE2B2A0E6B8A9
E6B8ABE6B9ACE6BAAEE6B8A6DFA997DA9E8ACF8C77C68266BE7C64B57861B6775DB17159
AF6B58B47C68C68B78C98D78CF937DC98A74D0947DD18F76CA8D77CC917ECF917ECE917C
CD917ED0977ED29780D39885D19884CE9480C78F7BC58B77C28872C28773BF8772C18672
C58978C7907EC68E7AA36C589D5A45A6533EA65340B55640C17056CC8674E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D5D7E6D4D6E6D4D6E6D5D6E6D5D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E5D3D5EDE2E5F3FCFFF1FFFBEAE7DCE7B99FC56246DC9A8DCA8C7C
51231C150707311C1844241F54342A66463DDEAC97E7BAABE3B5A2E2B49EE1B09AE5B6A1
EABEADE5B9A7E6B6A2D8A993D19883B88069A56C566F42338F60509568645D3A30795246
54393B190D0C673C2F6435229F6E61A5665A8F4934A04D38B86B54D99D85E0B09BE6B8AC
E6B7ABE6B9ACE6BBB0E7B9A8DFAA98DA9D88CE8A75C68363BD7C5FAF755FB2755AAB6B51
A86352B17C69C8907BCC8E79D89B82CE8C73DFA689DF9676D09179D29685D49480D2957E
D49885D69E82D89E86D8A08ED6A08CD19985C7907DC58C78BF8670C08673BB8871C08571
C38B78CB8F7ACA917AA5735E995844A24B329E4933A74328BE6951C98673E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E7D5D6E3CECFE1C8CADBB8BAD09E9DDDA18EC96A54D69383C68473
5D2D2629131238211D42251F5231286F4C42DFAD98E6B7A7E3B5A1E2B49EE2B29DE3B19D
E4B5A3E4B5A3E4B4A0DDAE9AD9A490C9937EBC846F9B6554AB7766AA797185564A926658
76504E4C2C28814F3F7F4733A77263AD6C5DA45C47B4614EC57B66DAA088E0B09BE6B8AA
E6BAADE6BCB0E6BDB2E6B8A7DFAA97DA9E8ACE8C77C68366BD7B60B1755CB3755BAD6D53
A86250AB735FC18A78C98F7EC28A78BB806EB37668B37865B57864B67C6CBD8373BB816F
B8816FC18970C48B76C68F7CCA917BC98E79C58B76C38A74BF8670C18772BC8772BF8572
C48977C78C78BC85709865538E5240944B39964B37B55641C27158C87C69E7D5D7E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D2D4E6D4D6E6D4D6E6D3D5E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E8D6D7D8BBBBC89D9BBA8182AB6866D28B7DCB6F5ECF8C7BC17C6C
64352F361D1C3C24213F251E4F2E26775246DFAD99E5B5A3E2B4A1E1B39EE2B3A0E0AD99
E0AD9BE2B19FE2B29EE0B19FDFAC9BD6A38FCD9884BB8372C08A79BB877AA36E5FA67665
91635C71463E955E4C925642AD7463B3705FB26B56C2735FCD8973DAA18BE0B09CE6B8A8
E6BCAFE6BFB4E6BEB4E5B7A5DFAA97DB9F8BCE8E79C78268BC7A60B2745AB4755BAE6E55
A7614EA66B56BB8576C69082B07D6FAB77698B524C8E5E549D63539C6756A87567A77161
9F6D5CAE7861B27B68B5816DBF856EC1866FC38770C28771BF8570C28872BC8772BE8572
C48876C28975AF79668B594A834D3C864B3C8E4B39BF6755C4765EC6745FE8D6D8E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D1D3E6D4D6E6D4D6E6D2D4E6D2D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6ECDCDCD1B3B0AC78728B4F4D743730CB7A6ED3796BD08C79C57B6A
6B3F373E27243D252439221B4929227E5749E0AF9BE4B3A0E1B4A0E1B39EE3B5A2DDA894
DAA492E1AE9CE1B19DE6B7A7E6B8A9E4B5A3DEAE9BD8A290D49E8CCA9684BD8574B88472
A974688D5E51A46B55A0614EB17662B7725FBC7A63CD826CD4947EDAA28CE0AF9BE6B8A6
E6BEB1E6C2B9E6C1B7E4B6A5DFAA97DBA18DCF8F7AC78169BC785EB17257B4745CAE6D55
A45D499D604AB38074C39289996C63976A61532B2961403C7E4A3E7C4E3F92655A8F5D51
80564897644F9C6959A1715CB1785FB77B64C18269C0846DBE8470C28972BB8773BC8572
C48775C28874A5715F804F407A48387B4B3E854A39C67966C88067C36B54E9D7D8E6D4D5
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6CFD1E6D4D6E6D4D6E6D1D2E6D1D2E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6F4E7E5CDB0AB845147421C171B0901C76B5EE38B80D7917AD27F6B
764D434636303F2728321F1842241D875C4DE1B29DE3B09DE0B39FE0B29EE4B6A5D8A08C
D29885DFAB98DFB09DEEC1B3EFCABDF5CFBEF2CCBAF8CDB9EDB8A6DFAA90DDA28FD09983
C88A75AE7D68B77C62B1715DB87962BC765FC98D73D9977DDCA38BD9A28CE0AF9AE6B8A4
E6C1B5E6C8C1E6C5BCE2B6A5DEAB97DCA38FCF8F7BC77F69BB775BB06F52B4745DAE6D56
9F57438E523BA87972BF95927A56527D595500000027191A522C244E2E2375524A6F453D
56382E774A3A7E5246855B479E674CAA6E55BE7C60BE8168BE836FC38971BB8773BA8471
C68774C48A749C6A58744436714334704E417A4938CE927CCD8E73BF6247EBD8D9E5D3D5
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D5D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D0D2E6D4D6E6D4D5E6D2D3E6D2D3E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E3CFD1B2847F7949404F272033140CA2564BB8655DB17362A66356
613E36402D273C252435211A462620845B4CE0AF9BE4B09DE2B49FE1B39FE3B5A4DDA894
D79F8EDEA796DDAB98E2B1A4E5B7A8E4B8A8E2B6A6E5B5A4DCA796D29A85CD9381C08B77
BB7E6BA77361B0755EAB6B57B3735EB9735EC3836BD3917AD9A08ADAA38FE0AF9BE6B8A7
E6BFB2E6C2B8E6C0B5E2B3A1DFA995DBA18DCF927EC7846EBC7860B37256B4735AAE6E55
A6604A9D5E48B17D70C1918794696091675E4020205135326F41356B413381584E805348
704A3D8B5A47926051976954AB7057B3775EBF7F66BF836CBE8570C28973BC8873BC8672
C18673B37B67895B4C6A4037673E32653F357C4937C88873C67963C06248EAD8DAE6D5D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D1D3E6D4D6E6D4D5E6D3D5E6D3D5E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6D4BCC19460596C4038562D25411D1681423A8F48418E5A4C804B42
4F312C3926213A242238221B492822825A4BDFAD98E4B09DE3B4A0E2B49FE3B5A2E0AE9A
DCA595DCA594DAA895D9A598DCA898D6A697D4A596D5A494CE9A8BC78F7CC18977B4806E
B27664A36D5DAC715CA76854AF6F5AB8725DBF7C65D08E78D89F8ADCA491E0B09CE6B8A9
E6BDB0E5BEB1E6BBAEE1B09DDFA793DA9F8CCF9580C88873BC7A65B67459B37158AF6F55
AB6750A96952B7806EC28C7DAA776AA1726570403C744C448552448051408A5C508E5E50
8559499B6651A16B59A6745EB47860BA7E66C0826BC0856EBE8670C28974BD8874BD8772
BC8571A26D5C774D40603C365E3A2F59332A7D4837C2806BBE6854C06248E9D8D9E7D5D7
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6
E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D2D3E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6C3A6AE683931563029512D23421F19592B25622C2668403657322D
3D262233211B38221F38221B4A2922825A4BE0AD98E5B09DE5B5A0E2B5A0E2B4A1E3B3A0
DEAA99D99F8FD6A28ECC9589D19785C59385C69586C69586BF8D7EBB816FB57D6CA67362
A76B59A06656A56A56A1614CA86751B36C56B8735CCB8B75D69F8ADCA492E0B09CE6B8AB
E6BCAFE5BAAAE5B7A9E0AD99DFA491D99D89CE9883C88C77BB7A68B77459B26F53AF6F54
B17056B5745CC1866DC68C76C28875B27F6C966258915F519562518F5D488D5B4E956655
946352A77059AE745EB17D67BD7F67C0846CC08570C18771BD8770C18975BE8974BF8A73
BB8872946252633E3455373354342C48261F7B4635BD7E69B65945C26045EEE0E3EAD9DA
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6
E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D2D4E6D4D6E6D4D5E6D6D7E6D6D7E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6AA8A9324100A391E184D2F2246231D26100E250E0B39211C261514
2718162B1A1536201D38221B4B2822825A4CE3AE9AE7B19FE7B7A2E3B6A2E1B3A0E6BAA8
E2AE9ED49787D09984B98074C0816DAD7B6EB07F71B08072AB7A6CA86D5CA26D5C8F6050
965B48975B4A995E4B9456409A5942A9614BAC644EC48570D39D89DCA393DFB09BE7B8AF
E7BBAFE4B7A2E5B2A2DEA995DEA18ED79A86CC9A85C6907BB8786AB67358B06B4CB17053
B97D5DC6846BCF906DCE8E6FE4A186C89277C0927BB6795FA67560A06B528F594A9D6F5B
A66E5CB57D63BF7F64BF8873C88871C88E76C28976C28973BD8971BF8976BE8B75C28D76
BD907886584A4A2D26493230482E26321812754432B87D66AB4831C55D41F8F1F5EEDFE0
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D4E6D4D6E6D4D6
E6D2D3E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D3D4E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6BB9DA63F1F1740231C4A2A2041221C3218143417133F251F2F1A18
2A19172F1C1636211D3D251E512E287F594AD9A48FE2AC99E5B39FE3B5A0E3B5A1E6B9A6
E3B0A1DBA293D8A492CA9488CE9382C08E81C19184C29184BD8D80BE8476B98373AA7A6B
B17463AE7365B27665AE6F5DB3715EBE7966C07B67CF937FD8A490DFA99AE1B3A0E6B7AB
E5B8AAE4B5A2E4B2A1DEA995DEA390DA9E8BD09C88CC927FC08172BF7C64B47157AF7057
B1735AB77660BC7E63BB7C63C7876FB67D67B07D69AD725BA5715DA46E579B6553A5735D
A9725FB27A63B97D64BB826EBF816BC1866FBE8572C28873BE8872C18977C08974BD8871
A87763734A3D482C25452D2D462D283A1D16824937B77360A94C36BA5E45DAC4C5E4D1D3
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6
E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D3D5E6D4D6E6D3D5E6D3D5E6D3D5E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6C7ACB5512B2245261F48271F3D211B381E193C1E19412720331D19
2C1917321D1836211D41272056342D7C5749CF9A85DEA793E3B09BE4B49FE4B6A2E6B8A4
E4B2A4E0AC9EDEAE9DD7A598D9A394CD9E91CEA093CFA092CB9D92CE988CCB9688BF9083
C68B7CC08A7EC68C7EC28677C68877CE8E7ECF907DD89F8CDCAA96E2AEA0E3B5A4E5B6A8
E4B5A6E3B3A1E3B19FDFA995DFA591DBA28FD39E8AD19583C88A7AC68570B77760AF715B
AB6B57AC6C58AC705AAA6E58AE735DA76D5AA46F5CA86D59A56F5CA9725CA66F5AAC7760
AD7663B17964B57C65B87E69B87B66BB806ABB826FC28872BF8772C28977C18873B7826C
946151623D32452A23412929442C2840201A8B4C3CB46A59A54D39B05E48BC9F9CDAC5C7
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6
E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D6E6D3D4E6D2D4E6D2D4E6D4D6E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6D2B9C359312843261D42211B37201A37201A3A201B3C241D2E1A16
291614341E1835201C4629225B3B347A5648C7927DDBA48FE2AE99E4B39EE6B7A3E6B8A4
E5B6A8E4B5A8E3B7A9E2B5A7E1B2A4D8AC9FD8ACA1DAAC9FD7ABA1DBABA3DAA99BD0A59A
D8A295CFA197D8A297D19F93D79E91DBA496DBA693DFAB9ADFB09DE5B4A7E5B8AAE4B6A5
E3B1A1E2B09FE2AF9DDFA895DFA692DDA593D6A18DD69888CF9383CC8D7BB87A66AB6F5B
A060519D5F4D975E4D935A48935C49965C4B9B6552A76C58A9705DB17A65B47C64B87F66
B57F6AB37B68B47D67B77A66B17661B47A64B77F6BC28872C18674C48A78C48773B6826B
7E4E404B2E253D251E3A2325402A2844221B9D5443B66554A54F39AC614B9A7B76D3BCC0
E6D5D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6
E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D5D6E6D4D6E6D2D4E6D1D2E6D1D2E6D4D6E6D2D4E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6DFCBD663382F3F241B381A15301E1836221B38231C35201A291713
251210361E18321F1A4B2B2461443C775647BF8974DAA18CE1AC98E5B39EE7B9A5E6B8A3
E7B9AEE9C2B6EAC4B8EFCABBEAC5B8E4BDAFE4BCB1E6BBAEE3BDB4E9C3BFEBBFB3E2BFB7
EBBEB3DDBDB6EABDB5E0BDB5E7BAB0E8C1B4E7C1AEE8BBAAE3B7A4E9BBB1E7BCB1E3B5A2
E1AC9CE0AD9DE0AE9BDFA794DFA894DFAA98D9A490DC9B8ED69D8DD39788B67D6CA36A5A
905047854C3D7846397140316C402F7C46388E5844A66B56AF715EBC8571C68E71C88A6D
C18B75B77E6DB37F6AB67662A86F5BAB725DB17B67C38772C48575C78C7BC98874B7856D
63382D2F1C16331F19301C1F3C28294A251EB8604FBE6251AA523BAC67516D524CCDB5BB
E7D6D7E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D3D4E6D2D3E6D2D3E6D4D6E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6D9C3CC633A304C2C2346241E39231C38231C3D241E38211B2F1A16
2C1614361E1A37221D4B2C255F4138765345B6826ED19A85DDA793E4B09CE7B8A4E6B8A4
E6B8ABE7BEB1E8BFB3EBC3B5E8C0B3E3BBAEE3BCB1E5BBAFE2BDB4E6C0B9E7BEB4E1BEB6
E7BCB3DEBCB5E7BDB5E0BBB3E5B7ADE6BEB1E6BDACE6B8A8E3B7A5E7B9ACE6BAABE3B4A1
E2AF9DE1AE9CE0AD99DFA794DFA793DEA896DBA490DC9E8FD89E8ED69A8AC28776B57968
A9685CA16453975F509159498B574592584898624FA76B58A96F5CB37A66B97F66BA7D64
B67E69B07665B17A67B67763AC735FB27763B77D6BC28872C18574C48876C0826DA26E5B
5F362C35201935201A3620203C282642241D8F483F9D4F438F473590554470534DC0A5A8
E5D3D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D3D5E6D3D4E6D3D4E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6D3BBC3643B3158342A522D254127203B241E41261F3A221B351E18
311A16371F1B3C241F4C2D255E3E36755043AE7B67C8927DD9A38EE3AE9AE6B7A2E6B8A4
E6B8A8E7BBAEE7BCB0E8BEB1E6BDB1E3BBAEE3BDB2E4BCB0E3BEB6E5BEB6E6BFB6E2BFB7
E5BDB4E0BDB5E5BEB7E1BCB3E4B7ACE5BDB1E5BBACE5B7A8E4B8A6E6B8A9E5B7A7E2B4A1
E2B19FE2AE9BDFAB98DFA894DFA793DEA794DCA491DCA191DAA08FD89E8DCC9180C38775
BD7D6FB77867AF7564AA705EA26B58A46857A06A57A96C5BA56C5AAC725EAF745DAF725C
AD7461AB705EB07664B67964AF7663B77C67BC7D6EC18871BF8573C18471B87C678E5B4B
59322939221B37211B3B23213C27243C221B6B35307F3E36783D2F77453870514BB29596
E3D0D2E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D5E6D4D5E6D4D5E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6D4BEC5673F35643C315C372D472B233B251E4527213B221B3A211B
361E19381F1D4126224E2E275E3F35754F42A67561C18D78D8A28DE4AD9AE6B7A3E6B8A5
E6B8A6E6BAADE6BBAFE7BCAFE6BDB1E5BEB1E5C0B6E5BFB4E5C3BBE6C0B7E6C4BDE5C4BD
E6C3BBE4C2BBE6C4BEE5C1B9E5BCB0E6C0B6E6BEB0E6B8AAE5B9A9E5B7A6E3B6A3E2B4A0
E3B29FE3AE9BDFAA96E0A894DFA793DEA693DEA593DEA694DDA592DCA592D79C8DD29584
CE9483CB8D7CC48A79BD8672B47C69B17562A46F5DA76A5B9D6756A26755A26853A26653
A16856A26755AC705FB57964B07865BB7F6BC17D72C08871BE8773C2836FB47B6479493B
4F2B2439221A37221B3F26213C262237211A492221612D276133285D352C694A44A58888
E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D5D6E6D5D6E6D4D6E6D4D6E6D4D6E6D4D6E6D5D6E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D5D8C7CF6B43397346396843364E2E263B251E4927223B211A40251D
3C231B392020472A265031296040367650439F705CBD8A74DAA38FE6AE9BE7B9A4E7B9A7
E6B8A3E6B8ACE6BAADE5BAADE6BDB1E7C0B4E7C4BBE7C3B9E7C8C1E6C2B7E6CAC5E8CAC4
E6C9C3E8C9C2E6CCC8E8C8C0E7C1B4E6C5BCE6C0B5E6B9ADE7BCADE5B7A3E2B49FE2B49F
E4B5A1E4AF9ADEA894E1A995DFA893DEA592E0A795DFAB99E2AB96E1AE99E4AA9DE4A897
E2B39CE0A996DBA693D2A18BC8917EBF8470A67462A36659925F4F9359478F58448E5545
8F5847945A49A76859B27863B17A66C1836FC87C76C08972BF8A75C7846EB47C635F352A
44241E39211938221B462A213D26203120181E0D0E3C19164928203E231E62453E967D7C
ECDEE2E5D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D5D6E6D5D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6
E6D3D5E6D4D5E6D4D6BFA2A36740356C443965413652322A422A234A2A253F231D3E231C
3C221B39201E4427224C2D265939306D473B916352AB7967C8907CDEA590E3B39EE6B7A4
E6B8A4E6B8ACE6B9ADE6BAADE6BDB1E6BFB3E7C3BAE6C3B9E6C6BFE6C3B9E6C7C1E7C8C2
E6C7C1E7C7C1E6C8C1E7C7BFE6C0B3E6C3B8E6BFB4E6B9ACE6BAAAE5B6A4E3B4A0E1B39E
E3B29EE3AC98DEA893E0A793DFA692DFA592DFA693DEA895E0A793DEA895E0A596DEA391
DCA893DBA28ED69E8BCF9C87C8907CC28773B27D6BB17364A46E5CA66A57A46955A36655
A36956A66957AF7261B77D68B67D6BC0836FC57F74BE866FB7826DB176629C67545A3329
42251E39221B37221C3F262039231F2F1E182712123C1D1943251E3D231E5B3C36896863
D6BDBCE6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D4E6D4D6E6D4D6
E6D3D5E6D4D5E6D4D6A6837F643E3267433A63413756362E482E274C2D2743261F3D231C
3C221B39211C42251F482A2253332B643F338458499A6A5AB7806BD69C87E0AD98E5B5A1
E6B7A4E6B8ABE6B9ACE6BAADE6BDB1E6BFB2E6C3B9E6C3BAE6C5BDE6C4BBE6C5BEE6C7C1
E6C6C0E6C6C0E6C4BCE6C6BFE6BFB2E6C1B5E6BFB2E6B9ACE5B8A7E5B6A4E4B3A1E1B29D
E1B09CE1AA96DFA793DFA691DEA591DFA591DFA592DEA692DEA490DCA391DDA290DAA08D
D8A18CD79E89D29886CE9984C9907CC58B76BC8673BC7E6DB47B68B47864B47863B37563
B27764B47664B67B68BB816CBB816EBF846FC28172BC836DAF7A669E6956865646533027
40251E39221D37211D39221E35201E2E1C182C17153A1E1A3D211C3A231D53352F7A564E
C1A29EE7D5D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D2D4E6D4D6E6D4D6
E6D3D4E6D3D5E6D4D686635B603B2E63433C63423A5A3B324D322B4E302A4627203B211B
3C211A38211B41221C43261F4C2D255A372C754B3E875A4DA46E5ACF957EDDAA95E4B4A0
E6B8A5E6B8ABE6B8ACE6B9ADE6BEB1E6BFB2E6C3BAE6C4BBE6C5BDE6C5BEE6C4BCE6C7C0
E6C6C0E6C7C1E6C2B8E6C7C0E6BFB2E6BFB3E6BEB2E6BAACE5B7A5E5B6A4E5B2A2E0B19C
E0AD99E0A794DFA793DFA490DFA490DFA591DFA692DEA590DDA28EDBA08EDCA08DD9A08C
D69E89D79E88D29784D09B86CD947FCB927DC8927DC98B78C38975C28772C38671C18471
C18571C18471BD8470BF8671C08674C08671C38572BD826CA975618C5E4C6D4438492A23
3C241C39231E37221F341F1C321E1D2C1A172B1815321D17321B17321E19492C26634034
A38179E8D6D7E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D1D2E6D4D6E6D4D6
E6D2D4E6D3D4E6D5D75B3E355C38295E443E63433C5F403852362F4F322C492821371F19
3B211A3721183F20193D211B43251D4F2D22613C326E483D8C5A47C88E76DBA894E4B5A0
E7BAA7E7B8ABE6B8ACE6B8ACE6BFB2E6BFB2E6C4BBE6C5BDE6C4BCE6C7C1E6C3B9E6C6C0
E6C6C0E6C7C1E6BFB2E6C7C2E6BEB2E6BEB0E6BEB1E6BBACE4B5A1E6B7A4E6B1A3DFB09B
DEAB96DEA492E0A692DFA38FE0A38FE0A591DFA691DDA48EDCA08CD99D8CDB9F8AD7A08B
D49A85D79E86D29582D29D88D19983D39B86D6A18BD79B85D59B86D29983D49883D29882
D19783D19582C49078C58C76C88D7CC18975C68B73C0836DA5725D7751404F30273D231E
37221A3A24213822212E1C1B2E1B1C2918162A1B16291B142514112819143C221C412619
74554AEAD7D9E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D2D3E6D4D6E6D4D6
E6D3D4E6D3D5E6D4D563443B5E3B2E61423B61433C604038563A335336304C2C263F241D
3F231C3A221A3F211A41241D472820502F25643E34724A3F8E5C49C1866FD59C87E0AD98
E5B5A2E6B7A8E6B8ABE6B9ACE6BDB0E6BEB1E6C2B7E6C4BCE6C4BCE6C6BFE6C3BAE6C6C0
E6C6C0E6C6C0E6C0B5E6C6C0E6BFB2E6BEB1E6BEB1E6BAACE4B5A3E5B5A3E5B2A1DFAE9A
DFAA96DFA492DEA591DDA18DDEA18DDEA38FDEA490DDA28DDB9F8BD99C8AD99E89D69D89
D49984D69B85D19582D09985D09681CF9681D19985D29580CF9480CD937DCF937ECD907C
CC917CCB8E7BC28C76C28974C28775BD836EBA816CB07764956351704A3C5231283C241E
37231C39231F34201F2D1B192D1A1A2917162A19152A1A152917142C1C163F231D503125
9B7970E8D6D8E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D2D4E6D4D6E6D4D6
E6D3D4E6D3D5E5D2D468463E5F3D3262413860433C6141395A3E37573A344F302A452821
43251E3C231C3E221B44261F492A23503026644035744A3F8D5D4AB97E68CE927BDDA691
E3B09CE5B6A6E6B8AAE6BAADE6BBAEE6BDB0E6BFB4E6C3BAE6C4BBE6C5BEE6C3BBE6C6BF
E6C6C0E6C5BEE6C2B8E6C5BEE6BFB2E6BEB1E6BEB1E6B9ACE4B5A4E5B2A2E4B2A0E0AC98
DFA996DFA391DDA490DCA08CDCA08CDCA28EDDA18EDCA18CDA9E8BD99B89D89C88D59B87
D49784D59984D09581CF9682CF947FCD927ECE9480CD917CCB907BCA8E79CB8F7BCA8B78
C88C76C68A76C18974BF8773BE826FBA7E68AF7865A16D5B8656466843375230283A241E
37231D39221E311E1D2C1A182C19192817162917142A19152C1A162F1E1841251E5C3A2F
B89792E7D5D7E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D4E6D4D6E6D4D6
E6D3D5E6D4D5E5D1D265423A603F366540355F433D63423B5F433C5B3E3851342E4B2B25
46261F3F241D3D221B4727204A2B244D2F26623F3572473D895A48B27761C88870DAA18D
E1AD99E4B6A3E6B8A9E6BBAEE6B9ACE6BCAFE6BDB1E6C3BAE6C4BBE6C5BEE6C4BCE6C6BF
E6C7C1E6C5BDE6C3BBE6C5BEE6BFB2E6BEB2E6BEB2E6B9ACE4B6A5E5B0A1E4B29FE0AB97
DFA996DFA38FDBA390DA9E8ADA9E8ADBA18DDD9F8DDCA08AD99D89D89A87D69A86D49984
D39583D49683CF9581CF937FCE927ECB8F7BCD907DCB907AC98E7ACA8D77CA8F7AC98976
C78A74C38874C38874BF8874BC806BBA7C65A6736094635476493A5C3A304F2C2537221C
36231F38221C2E1C1B2A18162918172716152816132918152D1C18311F193C211B58392F
CEB2AFE6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6
E6D4D5E6D4D5E5CFD1613D3562423B693F325D433E66443E6549435F443D533932522F29
4A261F42251E3B221B4928214B2B254B2D25613E3571443B855645AA6F5AC27E65D99D89
E0AB96E4B7A1E7B9A9E7BCB0E6B6AAE6BAAEE6BBAEE6C3B9E6C4BBE6C6BFE6C5BDE6C7C0
E6C8C3E6C5BCE6C5BEE6C6BEE6C0B3E6BFB3E7BFB3E6B9AEE4B7A8E5AEA0E4B39EE1A995
DFA996DFA28EDAA28FD89C88D89C87D99F8BDC9C8DDB9F89D89B88D89884D39884D29682
D29381D39381CE9680CE907CCE917EC98B78CC8C79C88D78C68C78CA8B75C88E7AC78574
C68770C08571C68975C18A76BC7F68BD7B629E6D5B855A4D623A2E4E30294C292132201B
35232036211A291A192715132615152614142815122716162E1E1A31211A321B154C3129
E5D2D4E5D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D4E6D4D6E6D4D6
E6D3D5E6D3D5E4CFD166433B5F4139623C315F423B64433D64474161453E573C3553322B
4D2A2442261F3E241D4A2A234D2D274D30275F3D3370463B845847A06754B8775FCF927D
DBA38EE2B39EE5B7A6E6BAABE6B7AAE6BAADE6BBAEE6C1B7E6C3B9E6C3BBE6C3BAE6C4BC
E6C5BEE6C3BAE6C3BAE6C2B8E6BEB1E6BDB0E6BCAFE6B7ABE3B4A3E4AD9EE3B19CE1A894
DEA693DEA18DDAA08CD89C87D89C88D99F8BDB9C8ADA9E88D89B88D89985D59884D39682
D29481D29482CE947FCE907CCD8F7CC98C79CB8C79C88D78C68B76C78975C88C78C88673
C48670BE8470BE8470B7816DB07661A96E589163537C51445E372C4D2E2847282234211C
35231F38221C2B1B1A2917152917162615152614122615142D1D1935221B4A2B247E5850
E3CFD0E5D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D2D4E6D4D6E6D4D6
E6D3D4E6D3D4E4D0D16B49415E3F385C393061403862423C63463F63463F5B3F3855352D
502E2843261F41261F4A2C244E2F284F322A5D3C326E473B83584996604EAE6F59C68872
D69B87E1AF9BE3B4A2E5B8A7E6B8A9E6B9ACE6BBADE6C0B5E6C1B8E6C1B7E6C2B8E6C2B8
E6C2B9E6C1B7E6C2B7E6BFB3E6BCAFE6BBADE5BAACE5B6A8E1B29FE3AD9CE1AF9AE0A792
DDA390DCA08CD99E8AD89D87D89B88D89E8AD99B87D99C87D79B88D79A85D69784D59682
D29481D19582CE937ECD8F7BCD8E7AC98C79C98C7AC88C78C68A75C58874C78976C78673
C28570BC826EB77F6AAE7865A56D5A96624E85594B72493C5833294A2C2642272135221C
36221E3A221D2C1C1B2A18172A19172615152313122515142D1C1839231C5F3B33A57D76
E2CECFE6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D2D3E6D4D6E6D4D6
E6D2D3E6D2D3E4CFD16B4B425A3D3655362D633F3461423B63473F6648425F423C573830
54332D42261F4428224C2E2750322B51342C5B3A316E483B845A4C8C5847A66852BE7E67
D39681E1AF9AE2B5A1E4B8A5E7B9A9E7B9ACE7BAADE6BFB4E6C1B7E6BEB4E6C1B6E6C0B5
E6BFB4E6BFB5E7C1B5E6BCAEE6BAAEE6BAABE4B7A9E5B5A6E0B09CE2AC9AE0AE99E1A691
DDA18EDBA08BD99C87D89D86D99B88D89E89D89A85D89B86D79B87D79C86D79784D69683
D29581D19683CD927ECD8D7ACD8C78C98C79C88B7AC88C78C58A74C38673C88875C98673
C18671BC836EB37D68A7735F9C6655855745795044663F34502D244629243E252036231D
36221E3C241F2D1D1C2C19182D1B192716152012112212112C1A173820196A433BC8A5A2
E5D2D4E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D1D3E6D4D6E6D4D6
E6D1D2E6D1D2E3CED0674A405338324D302A663D3060413B64473F6A4C45634740593C32
58393440241E472B244E322953362E54372F59382F6E4B3B875E50804E3F9E614BB7745C
D2927DE3B09CE2B6A2E4B9A3E8BBAAE7BAADE7BAAEE7BFB4E6C0B7E6BCB0E6C1B6E6BDB2
E6BCB0E6BEB3E7C0B4E6B8A8E7B8ADE6B9A9E3B5A5E5B5A4DEAE98E1AC98DFAE99E1A591
DC9F8BDAA08AD89A84D89F86DA9B89D79E8AD79982D69A85D79B88D79E88D89784D99785
D39782D09885CD917DCD8B79CD8976C98C79C68B7AC88B78C58973C08573CA8674CC8874
C28773BD8570B07E68A16E59946150714C3C6B463D59362B49272043262339241F37241E
36221D4026212F1E1D2E1B1B301E1B2818161C10101C0E0E281714301A136E4840EBD8DA
E9D7D9E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D1D3E6D4D6E6D4D6
E6D2D3E6D2D3E4D0D17E5D545F423B52352E623D3160423B62453D6648426447405A3D34
573831482B24472B254B2F2750332B52352E5939316846397A55497A4C3F8E5846A76D57
C3836ED8A28DDDAB96E1B19CE6B7A5E6B7A8E6B8A9E5BBADE6BEB2E6BBAEE6BEB1E6BCAF
E6BBADE6BCAFE6BDAEE5B6A5E5B7A9E5B6A5E4B4A4E4B1A1DFAC97E0A996DEA893DFA28D
DB9C88DA9D88D79883D89B83D79986D79B86D59781D79883D69985D79A84D69581D59480
D1947ECF9480CD8E7CCD8C79CC8B77C88B77C68A78C68B76C38871BF8471C38370C3826D
B97F6BB17864A26E5A95614E8454466B4436623E3551312741241D3D231F36211E34221B
36221C3A221E2D1C1B2A19182B1A18231414201212281614311C19502F27986D67E6D0D1
E7D6D7E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D1D3E6D4D6E6D4D6
E6D3D4E6D3D4E5D2D3916E69694A43573932603D3160423B60433C63453F6547405C3F37
5637304F322B472B25472C254E302950342D593A336242376F4D4374493E7F5042996552
B37561CD9480D7A08BDEAA95E3B3A0E4B3A2E4B5A4E3B6A7E6BBADE6BAABE7BCACE6BAAB
E6BAAAE6B9ACE4BAA9E4B4A2E3B5A5E4B3A1E4B2A2E2AE9DE0AA96DFA693DCA38DDC9F8A
DA9A85D99B86D69681D69880D59683D69883D49580D79681D59683D69580D3937FD2907B
CF917ACF917CCD8B7ACC8C78CA8B77C78A76C68A76C58A74C1866FBD826FBD7F6BBA7C67
B07763A56D5994604E88544475483C633B3058362D4A2C233A211B37201B331F1C32201A
35211B351F1B2B1A192616162616151F1212251413321D1A3B221E6B443BB8908CE3CDCE
E7D5D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D1D3E6D4D6E6D4D6
E6D3D5E6D4D5E6D3D5A07D7B6E4E47583B345C3B305F423B5E413A61433C6848425E413A
55372F563932482B254429234B2E274F332D583C355D3E3563443C6B453B6D463B8A5C4B
A56854C58A74D59A83DFA691E6B49FE7B4A0E5B6A3E4B5A3E8BBABE9BDAAE9BCAAE7BBAA
E8BBA9E7B8ABE5B9A5E4B39FE3B5A3E4B19EE5B2A1E2AC9BE2AA97E0A692DC9F8ADD9E89
DB9983DA9A85D69580D7967FD49581D69681D2937FD89580D49682D6927DD2917DD08E77
CF8E77CE8F79CD8979CD8D79CA8D78C78A75C78A76C58C73C2856FBD836FB97F69B47A64
A9735D9B64518653427A4839643C325933294B2D2540261D311D17301D17301D1B301F18
36211B311C192A1918231515211312190E0E2815143A241F39211B7E554BD7BBBAE5D2D3
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D1D3E6D4D6E6D4D6
E6D4D6E6D5D6E6D5D7AE8C8E6F5048593C3558392E60433C5B3F395D40396D4A4560433D
54362C5E423B482B263F2520482C244F332E583E38563933533933613F38593931795243
965A46BF8169D7957BE6A690EDB9A2EEB9A1E9BCA6E8B7A0ECBEABEEC2ADEEC0A9EABEAB
EDBEA9EBBAACE6B9A3E5B49EE2B5A1E5B09BE8B2A2E3AB9AE7AB9AE3A794DF9D87DF9F89
DE9B83DD9B87D79581D8957DD39480D79580D1927FDB9580D49581D7907AD0907BCD8B72
CE8D75CF8D75CF8678CF8F7BCB907BC88B75CA8C77C88F74C4876FBF8772B78069AF7962
A47059915B487745356C3B2E512F274E2A213C221C351F17281913281A132C1B192F1E16
39231B2E1A162B18171F12131A0E0E0F08092B1614402C232E1A138D6559F4F3F5E7D7D8
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D2D3E6D4D6E6D4D6
E6D4D5E6D5D6E6D5D6BF9FA188666063443C5D3D335E413A5D40395E403A67464060433D
583A315C40384A2C274327214A2C254B2F2A573B35563932583D3662413A5D3D35744D41
875343AA725FBC836DCA917DD1A08BD7A28DDAA48FD8A692E0AF9CE0B09CE1B09BE0B09D
E1B19EE0AD9EDEAE98DEAA94DEAE99E0A793E2AC9ADCA492DCA18FD79A85D0927BD1917C
D18F78D2917CD08D77D18D77CF8F79D18F78CE8E79D48F79D18F7BD28B75CE8C77CB8970
CA8970CB8971CA8373C98975C58973C3856FC28570BE846CB87E68B27964AA725DA16956
96604D8451406C3F3162372B4C2C2545251F3A221B321D172717132818132A18172B1A15
301C182716142415141F12131F11111D10112E19164B3129643F36AA8279EDE3E5E6D5D7
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D4E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6CDB1B39D7C786C4C436242385D3F385E40395E403A63433D60443D
5B3D365B3E364B2E274629224A2B25482C275639335639325C403962433B5F40386E493F
784C3F966456A47360B17E6CB88977C28E7BCA907CC99785D5A18FD29F8CD5A28ED7A490
D5A592D5A090D5A38FD6A08BD8A691DA9F8CDCA693D59D8AD19885CB8E78C38771C4856F
C4846EC88872C9866ECB8571CA8973CA8971CC8974CD8972CE8A76CE8671CB8873C8866F
C6856BC6856DC57F6EC3836FC0836CBE7F6ABB7D69B47B65AD7561A56C599E6552935C4B
88534277473862392D5931274629223D211C3620192F1A17261512261613271615271714
2917152112121E12111F1212231414281817341C1856382F8E625BC29D98E8D9DAE6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6DFC9CBB091906F4F446142395B3D356041395E403A5E3F3961453E
5F423B5B3D354C2F274829224B2A244428235437325438315C403960433C5E4139644039
6540377F53498960509769599E7362AD7A69BB7D68BD8978CD9784C7937FCE9984D29C86
CE9E8CCE9887D09D88D39C86D7A48DD89A87DAA48FD39985CC937FC4836CB97E67BB7A65
BB7B65C2826AC58168C8816ECA876FC8856CCC8771CA866ECE8672CD836ECB8772C9866F
C68467C5846BC47E6CC0806DBE8068BC7C66B67964AD735FA36F5C9A624E925A48854F40
794536693C2F5631274D2A203E241E321B18301D16291715241211251312241313221413
211211190E0E150D0D1D1111251616311D1B301A1458372EB38782DAC0C0E7D7D8E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D2D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D5D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D5F3E6E8C2A8AC6C4D405C3F365638306242395E403A583A34634640
6447425B3B324D2F264B2A224C29243D231E52352F51362F5C40395D423C5B4139573632
4D312B643F396A4A3D7651437E584B946455A96852AF7B6CC78E7ABD8873C8917BD0967D
CA9A88CA917ECF9984D39A84DAA68BDA9785DCA58ED49881C89079BD795EAF755DB2715A
B3745EBE7E63C57F62C97E6DCD876DC88468D0886FC8856BD28571CF816CCF8972CD8972
C88565C8856BC6806BBF7F6CBE7E64BD7A64B47661A76D5A9A6B588F5844874F3E764235
683729593025492920402319341E19251412291A13241313210F102311122110101E1011
160B0C0E08080A0606180F0F2718183A231F24130D503027D6B5B4F2EDF2E6D3D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D5D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6EDDDDFCBB2B5906E6376554E5E3F376040385D40395B3D3660443E
5F443E5C3F3651332B4D2D254A2A2542272253363055393261443E61453F60453D5E3F3A
593A3468443D6F4E427A55487E5A4D9163549F6652A17263B27D6AA97564AF7C6BB6806C
B08170B17D6DB78270BA816DC28B75C38572C48F7BBC8571B17D6AA76F5A9D69569D6452
A16652A66C57AD6E56B26E5BB6745DB4745ABC7861B8765FBE7763BC7560BB7963B77963
B5765BB4745CB1705CAE725EAC7059AA6C58A369569862518F5D4C824E3D7846386B3C31
5F3529512E2543261E3C211B321E182715142918132213131F0F0F2010101D0F101C1010
190D0E150C0C150D0D2214132C1A1A452925522F27875B52D7B8B8ECE0E4E6D4D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E9D7D9D4BDBFAD8B858B696566463F5F3F385D40395D3F395E423C
5C413B5E423A5437304F2F28492B25462A25543731593C34664841654841654841644640
61423B6947407150457C584B7D594D8C605195635193695A9E6E5C95655697695C9D6C5D
986A5B996B5CA06D5EA26B5AAA7462AC7462AD7C6AA674619B6B5C9365548B5E4F8A5749
905948905C4C975E4A9D5F4CA0634FA0654EA96954A86953AC6B56AA6A55A86B56A36A56
A46951A1654F9E614E9E66529A624F98604D935C4B8A5849825141764436693E3160362C
563228482B233C221C38201B301C172816152716132112121D0E0E1D0F0F1A0E0F1A0F0F
1B0F101C0F0F1F12122C1917311E1D51312B774B43B0847EDBBEBEE8D8DAE6D4D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E7D6D7E1CDCFC9ACAB9B7C7C654640573A325A3E375F413B5C413A
583F3860463E583C3551322B452A25482C275437305B3E366A4D46684B446A4C45684D47
6749426547406F4F4679584C76544A845B4D895D4D825D4F885C4C7E52467C544A83574C
7B524580584A86574A885444935E4E986552976A59906452835A4E7E5B4C79524676493F
7F4B3C7A4C40824F3E89513E8B53418F5742985D499B5E499C604B9B614B975E49925E4B
965E498F58438D5441905B488A57458854438451417D4F4176453667382D593329532E25
4B2D253E2520341D18321D1B2D1B152817162614131E11111B0D0D190D0D140C0C150C0D
1A0F102011112515132D19152B1A1953312A95645ED4B4B2E3CDCEE7D6D8E6D4D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E5D3D4F0E1E2E4D3DCA98F955F423D492F28563B3461443D593F38
533C35624B435C423C53352E402822482D2853372E5D3F3670534C6C4F4770514B6C564F
6D514A6147416D4F4877594E6F50477C57497D58486E51436E493B633D345B3C35633F37
58372C624236673F34673A2C7646388154407E574778534268473D68504366453D603B34
6C3D2F613A326B3F3172422E7442337D493587503D8F533E8D56408C584286513D7F513E
8854417C4A367A473482523D794B3C7849397445376F463A67382A572C2346281F45251E
40282132201C2A17132D1B1A2A19132918182411121B0F10170B0B130A0A0D08080F0909
170E0F231312291713281510190F0D4C2A23B1807DF6F3F5ECDFE1E5D3D4E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D5EBDBDCE2CED4BAA0A482605C6948425F423C5F423B5A3F38
563E375F47405C413A5537304A312A50332E583C3463453D6E50496B4F476C4F486B514B
6A4E476348416C4D45725349704E457550427652456E4D416C473B613D355F4038634139
5939305F4037674138653E326C4238734A3E744F436E493E65423962463D5E3E3759372F
60372D58362E5E392D653B2C673C2F6C40307545367847367A4938794A39754737704638
7447376E41316A3E2F6F45346D4134683F32673D30603C305C3329502C2342261F40231D
3B241E311F1B2A17142817172617132415152111111C1010190D0D180D0D150D0D180E0E
2013132B18163B221E512E28573A3684554FC19493EEE2E3E9DADBE6D4D5E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D5E8D7D8E1CDD0C9B0B49E7B79835F5A694A445F413A5C3F38
593F395D453D5B403A5739335338315639335C4038694A426C4E476B4E476A4D46694E47
684B446548416A4B446E4E45714C426E493B6F4C416C493E69453A5E3C3460413A614139
5739315A3C3764413B613F35623D36643F3A6A473D6340385F3C345A3D3656373151322B
53312A4E312951322958342959352A5B362B643B2F623B2E673D30663E30653D30613C32
613A2E60382C5B352A5D392C60382D59362C5A352A513227512E264A2A223D241D3A201B
36211B301E192916142414142415132012121F10111D11111A0F0F1B10101C1111201412
2A1918341E1B4C2E2973464288625FAD7F7CCFA9A9E8D7D8E7D6D7E6D4D5E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D5E7D5D7E4D2D4DBC6CAB79799967371694A45583C355A3D35
5C403A5B433C5C413A593D365C403A5E403A61453E70514A6B4D456C4F48684C45684C44
664A43664840684B436A4940734A4067423467463E69443A6140375638315D41395B3F37
50352F5135335E3F3B593E355334305232325C3D3554343056342D4F322D4B2F29452B24
442923402922402821472A22482B22472A22502E25492C23502E255030255231274E2F29
4B2C224F2E24482A22472C20512D24462A234A2B223F261D45272241282036211A331D18
2F1C172E1C182614141E10101F12111B0F0F1A0E0E1C10101A0F0F1C1111201414221512
281715301B1853322D8D5C5AB38D8AD1AFB1E0C7C8E7D6D7E7D5D6E6D4D5E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E5D3D5E8D7D8F0E2E4D1B9BFA7888A6345404C322C553931
5F413B58413B5C413B5C413A664B45674A42674C457A5B556B4D446D5149664C44674941
654942674940684D4465433B764A3F5E3B2C5F413B673F365A3A334D342E5B413A553D34
48312C472E2F593D3C513E35422A293C24274D322C4428274D2C254226243E252037221C
331F1B31201A2C1D18341F1A351F19301D1739201A2C1A15361E183720183D241C39221E
301B153B211A321D182D1C143F2119301D183820182A191139201C39251D301E172B1915
2818132C1B16241314150B0B1A0E0F140A0B130B0B1A0F101910101A12112416151F130F
1D100D20120E53312BA67475E0C4C1F0F0F5F1EDEFE5D3D5E6D4D5E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E7D6D7EBDADDD5BDC1B8999B8C696669494263433B
5F423B583F395C413A5A3F3862474060463E63484171534C674B436A4E47644942664941
63474065484062443C62423B6B433959362B5739335D39315738324D312C563B35523731
48302C452D2E5136344D37324228283E2627482E2A4026254528243E25233B242138231D
331F1C301E1A2D1C18331E1A341F1A311D19371F1A301D1838201B36201A38211B37211D
311C1738211C331E19301C163B201C311D19351E182A1813311C1A34201A2A1915281714
2516132818152313131A0E0E1D1111190E0E1C10102013131F13132618172F1C1B3F2720
54342E623E38875B56BA8B8DDDC2C0EAE0E3ECE1E3E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E7D6D8D9C2C5C7ABADAD8A89815E576F4E46
61443D593F385D413A593E375F433D5B423B60453E694C45644942674C45634841654841
61453E6448405B3D3560413A623D335432294E322B54342C5436304C2F2A5136304F322E
482E2B432B2E492F2D48312F4126263F2625422A273B24223D23223A232238232137221D
311E1C2E1C1A2C1A18311C1A321E1B311D1A341E1A331F1A38211C341F1B341E1A351F1C
311D1935201C321E19311C18371F1D311D1A311C182917142A19182E1B18251613251514
2214132415142213131F10112013131E1011241414261716261716311F1C3B23205C3B33
805651956964AF8380CBA3A6DDC3C3E6D6D8E8D9DBE6D4D5E6D4D5E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E7D5D7E2CFD1DAC2C5CCAFB2936E68735249
5A3F375138305A3F38563C355D413B5640395E433D624740604740644A4361453E644740
5E423C63494154352E5B3E3757362D4E2D254329224A2E2651342E4B2D284C312C4B2E2A
472D2B3F292E3F2826422C2C3D23233D25223A242233201E321E1E35202033201F35211D
2E1C1B2917172816152B19182D1B1A2C1A192D1917301F19331E1B2C1A172817142B1917
2A19172E1C1A2C1B162C18162F1C1B2C1A182817142313121F12122615131C100F1E1211
1B10101D11111E11122011132014141F11122A181728191826171535211C3E231F724A3F
A77875C29996D4B4B3DFC4C6E3CECFE6D5D7E7D6D8E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D2D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5EDDEDEEEDFE2ECDDE6A27F79715148
4A322B402A23543A335138315B3E38503E375B413A5940395B453F6147405E423B62443D
5A3F39634A424B2C25563B344B2E26462621341F183F28204F342D4C2B26472C28492927
482D2C3B262E35201E3C272A391F203B2420311D1D2B1C1A2617182E1D1D2D1E1E34211C
2A1A1A2313142312122615162918192818172415142E1E182D1B19211312170C0B1E1010
2014132417172416122614142517172616151D100F1B0E0E100A0A1A0D0D100809150D0D
110A0B130A0B180E0F2111141E13141E1112301C1A2A1B19221412341F18381D17865649
CDA1A2EED6D6F5F4F5F2EFEFEADCDEE6D4D5E5D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D3D4E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E9D9DAE9D8DBE7D5DBB7959297736C
7A59516A4B436447405A3F395C403A533E375A413A5A413A5C453F60474160443E644741
5E423C5E463F4C2F28593D374D302846282239221C3D2620452C28432623422924422624
402726382427331F1D392325361F1F36201E301D1D2A1A182918192D1B1B2C1C1C301E1B
2919192615152413132414152717172817172716152F1E1A321F1E2C1A1A2919182E1A19
2D1C1C2B1B1B2D1C192C18192C1B1B2C1A192616142413141C11112413131C10101F1312
1F1314221415251616281618291A1A2B1918361F1C37231F4027225A39306F423CA6766D
D1AAABE7CECEEDE3E4ECE2E3E8D8DAE6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E7D6D7E6D4D6E4D1D4C9ABA9B5938F
9F7C768C696473534D6447415F433D563F385A413A5B413A5D453E5F4741624640654943
60443E5B443E4D322B5C40394F31294628233C24203B251F3D26233B22203E26213B2422
392321352221311E1B352021341F1D321E1C2F1C1C2918172A18192B191A2B1A1A2D1B19
2918182817172514142314142515152817172817162F1E1C3622223421223724263B2322
372424311F1F342120301C1E321F1F301D1D2D1B192B19192618172C1918271715281817
2A1A1B2F1D1C301D1C2E1C1C34201F38211D3E231F462B255C39327A5248986762BE9590
D7B5B6E3CACBE8D8D9E8D9DAE6D5D7E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E7D5D6E6D4D6E6D3D6DEC7C8D3B7B7
C0A19EA785847A5854634741573E38503832543D37583F385D433D5E4741644943674B47
63464055403A48312A5C40394C30284227213B232235211C311E1C311C1B37211C33201E
2F1C1B301E1A2B1A172E1B1B301E1B2C1A182C1B1B251414291818281717291818281716
2716162918172313121F12122112122615152817162E1D1E3A25273B272B412E35472D2A
402A2C3421223B2527321F22362222321E1F311F1D2F1D1E2E1E1B301D1C2F1D192E1B1A
3420213A26243A232132201E3B24223F261E3C211B4C2D23714639956A5EBC918DD7BBBB
E1C9CAE5D1D2E7D6D8E7D6D8E6D5D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5E7D6D7F4EAEEF1E4EB
E3CFD1C2A6AB7C5A575C413C48332D402B254B3630523B345C423B5E4743684E476B4F4B
6548424D3935412D275B3F38472C243D241F3922242D1B182113132515152D1B15291A19
2214132818112315122515142B1C17241514281919211011291818241414261515211212
2514142A19171F1010190E0E1C0F0F2212122716152D1B1E3E292C4230364B3C4A573933
4932363522254129303522283A252734202236232134222336241E35212039231D351E1D
3F282847312C452B2733241F40262344281B311A114C2A1C83503BB08376DEC7C1EDEDF2
ECE2E3E8D8DAE6D4D5E5D3D4E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5E7D5D6EDDFE2EADADE
E0CBCCCAAFB29F7B798766627457526E4F486046405E443D60443E5B433E624841664B47
66494357413D523B35664842553730472B2641272636211D2E1B1A2D1A1935201B2F1E1B
2D1B19301D172C1B172C1A192E1D1A2A19182A1919231213281717261616271616271616
2715162C1A192917172214142112132917172C1A18311F223C282B402C334B39434F3434
4B34363E282A412A2E3825283C26263A24263A27233926253925203C25233D261F3C2422
432B29492F2A4A2E28442D2754352F603B2E663C327A4C3FA67262C1978EDDC4C0E9E0E3
E9DBDCE7D6D8E6D4D6E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5E6D4D6E9D8DAE6D4D6
DFCACBD3BABCBB9999A9888698787592716A74554F694D476448415A403B5F443E634944
684A445F48436147426E514B60413A4F322C492C293E272238221F341E1D3C252034211D
36211E36211C34201B321E1C321F1C2F1D1C2C1A1A2614152817172918182918182C191A
2817172E1C1B301D1F2919182516172F1B1D301E1B3622263C282B3F2A314B373E4A3235
4D3537452E2F412B2D3C28293E28273F27293F2A253E29273C2622422A27422922442B27
492F2B4C2F2A51322B55362E68433B7A4D438F5E569C6E64C19289CFACA6DEC5C3E6D7D9
E7D6D7E6D5D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E7D6D8E6D4D6
E4D1D2E0CCCDD7BEBFCAAEAFB89A9BB2928C805E576A4F485E433C4E3630543A345B423E
674A43664D49705451795B566B4C46543831503028422A233D2520351E1D3E262333211B
3A242039231E38221D341F1D311E1C2F1D1D2918172213122213132717172717162D1A1C
2615162D1C1B3622252E1C1B251718311D1F32201C3723293A272A3E28304B353B442F36
4F383A4C3534402C2D3D2A293E2926442A2C432D27422D283D2724482E2A462B244A302A
4C312A492B245030265D392E764C408E5B54B2817BBA928DDABAB7E1C8C7E4CFCFE6D6D8
E6D5D7E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E5D3D4E6D4D5
E9D9DAF0E2E2F4ECEFEBDEE3D9C3CBD3BAB68A635D654B4550373037241E3F2A244D3733
6548416E5450816565856864775955593E35563224442B2341271F331C1B3D26242F1E16
3D26203A23203B241E331E1C2E1B192C1B1C221211190E0E160C0C2214142114132D1A1C
2112122B1B193A272D311F1C221618311D2132211B36232A3524273A242E4A33373B2A36
513C3D533E3A3D2C2B3E2B273C2924482D304630284530283D26244D332E472C244E352D
4B30263D211845281C603626805240A06664D3ADA9D4C0BFF0EEF3F2EBF1EADBDEE6D3D5
E6D4D5E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5E6D4D6
E7D6D8EBDCDCEDDFE2E6D5D9D9C2C8D5BDBAA8827D8F706B805F586A4B45684A43684D48
70524C7056527B5E5C7E615C75575362463F5E3C3454383051332C482C2A4E3330442C24
4C322C482D28482E28432A263E2827402A2A392221351F1F321E1E342022321F1F392326
321E1F362323422C313C282634222541292D3F2A25442E33412D30442C3351383A463239
563C3C583E3949323049332E4A312B5033334F362E50352D4A2F2B56383157372D5C3F37
634136693F36774D418E5B4EA37466B88282D6B3B0D7C0BFEBE0E3EDE0E4E8D8DAE6D4D5
E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5
E6D5D6E8D7D8E8D7D9E3D0D3DBC5C9D9C2C0C09F9CB0918FA5847E916F6C8A68627F615C
7B5C56735956775A577B5D577557536B4E4966474361443D5F3F395B3B385E403B563A33
5A3E385536315438335236314B34345037384D31314C312F482F2F422C2F402A2A442B31
40282C402A2E493235473130432E324E35374B332E50373A4C36374C3438573D3D513A3C
5B3E3B5D4039553835543A35583931593A36573C335B3B325838315F3E366742366B4A41
7951478B5C569E7067B07F77BE948BCB9FA0DABBBADAC3C3E8D7D9E9D9DBE7D5D7E6D4D5
E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6
E6D4D6E7D5D7E7D6D7E5D3D5E2CFD1E2CECED9C1C2D1B8B9C8ABA8B29394A5837E90706B
7F5F5A7056536D514C70544D6F524E6F5351684F4F6B4F49694A43694A44694A4464453E
6347405E3C365C403B5C3F38533E3F5E44445C3F405F433E5A403F4D373B4A33344B323A
493239452F374F37394F3B3950393F5A4143553C375C4240553D3D523A3A5C413D59403C
5F3E396141385E3C365D4039643E345F3E355B3D355F3B305D3A31613D33704638714F45
885C51A87774BF9591CFA9A5D8BAB8DEC3C5E3CCCDE2CECFE7D6D7E7D6D8E6D5D6E6D4D5
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D5D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E5D3D5E6D3D5E7D5D6EBDBDBECDCDFF2EDF2F3E7EEECDCDDD2BFC7C1A2A0A07E79
7D5E5A654C4A5A403A5B423B6147436F555665565A725B5473544D775B5072544B705048
684E4664403961464264483E57494A6A53526A5051745A506E5553544348533D3F513844
503B47483241543B3B5645445C464E6651505F4642694E465D454358413B61453D62473A
633D35654135673F3567453D714234623F305A3B325E35295B382B5B3729744635734F44
966359C39799DEC3C6E9E0E1EFECF1EFF2F2EBE1E3EBDCDEE6D3D5E5D3D4E6D4D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D5E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D5E6D4D5E6D5D6E9D7D8E9D8DAECE1E4EBDCE1E6D4D4D4BFC5C9ADABB59692
9F7F7C8D716F866662876861886A66886C6D7C686E83686480615E83666187665F81605C
81635E7B544F7759567859516C5859775C5B765858785C54725856654D5162484960454E
5F464E593F4A5F4443614B48654B506C5250664A456E514A674B486448426A4B436A4D40
6A453C6E493E744B41724E467A4D4278524478544B865549865A4F885C509A685B9A7369
B2827BCCA4A6DDC2C4E6D6D6EADFE2EBE4E5E9DBDDE8D8DAE6D4D5E6D4D5E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D3D4E6D4D5E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D5E6D4D6E7D5D6E7D5D7E8D8DBE7D5D8E3CFD0D8C3C6D3B8B8C8ACAA
BB9E9CAE9292A98987A98A84A889879D8183927A819275758C6F708F7271997873917070
9778768E68658B6B6A8B6A658067678467648262617F605A795D5A75585A705454705259
6E51556A4D536A4D4B6C514E6F52527355526E504975554F71524D714F4873534A735347
724D4377524780574C7D584F8458518A6458926B64A4746AA77A73AA8077B68880B9948E
C79F9CD5B3B5DEC5C5E4D0D0E7D7D9E8DADBE7D7D8E7D5D7E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D2D3E6D3D5E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D5E6D4D6E6D5D6E6D5D6E7D6D8E6D5D7E5D2D3E1CED0E0CBCCDEC8C8
D8C1C2CDB6B9C9ADAEC8ADA9C5A9AAB19799A48C969F8085947A81977E83A989889E7F86
AA8D8F9E7C7B9B7D7F9A7A789273748F6F6B8C6A6781625D7C5F5C82615F7A5D5B7B5D60
795A5877575670524E73544E74555075554F71514876564E76554D79524876554B775448
734F4479544A875F52835D53885F5B98746AA8817EC0958DC69E9DC9A8A4D0AEACD8BBBA
DDC3C5E2CACCE4D0D1E5D3D5E7D6D8E7D8D9E7D6D8E7D5D7E6D5D7E6D5D7E6D5D7E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D1D2E6D3D4E6D4D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D5
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5E6D3D4E6D4D5E7D6D7ECDCDCEFE2E4F5EBEF
F6EDF1F0E4EAEADBE0EAD9D8E5D1D6C4B1B3B79EADAA8A969784929C8894B99CA0A88E9E
BCA4ADAB9094AA8E95A88A8CA57F7E97756F93706A7F5F5B7B5D5A8E676082635F846663
816055825F5371544C76534A7654487250466E4D427251487754477D5042745347765143
6F4D3F7653488A6454855E53866463A4847BBE9A9BDBBEB9E3CBD2E4DBDEE6DEE4F5EDF4
F0F3F9EEE8E9EADDDFE7D7DAE6D6D8E6D5D7E6D6D8E6D6D8E6D6D8E7D6D9E6D7D9E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D5E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6
E6D1D3E6D3D5E6D4D6E6D3D5E6D4D5E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5E6D4D5E6D4D5E6D5D6E9D8D9EBDBDDEEE0E3
EEE1E3E9DADEE5D3D7E5D2D2E1CDD0CCB8BAC3ABB6BB9EA7AF9AA5B29CA5C5A9ABBA9FAA
C7AEB4BBA0A2BA9EA3B99C9DB79494AF8D89AC89859F7D7B9A7A78A6807C9D7D7B9E7F7E
9D7A729D797191716B947068967168946E67926D639570689872679C6E63957166976F63
936C60987269A88072A57C74A58080B89891C8A6A6DBBDB9E0C6C9E1D0D1E4D3D6EEDDE1
EBE2E5EADDDDE8D6D8E6D3D5E6D3D4E6D2D3E6D3D4E6D3D4E6D3D4E5D3D4E6D2D3E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D2D3E6D3D5E6D4D6E6D3D5E6D4D5E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D5E6D4D6E7D5D6E8D7D8E9D9DB
E9D8DAE5D4D6E2CFD2E2CFCEE0CCCED4C0C1CEB8C0CBB1B7C4AFB6C5AFB5D1B6B6CAB0B6
D1B9BBCAAFB0C8ADB1C8ACACC8A8A9C3A4A1C09F9EB99997B39594BB9896B49695B49696
B4938EB3918CAC8B88AD8985AF8B85AF8A85AF8B83B18D86B28E86B58B82B18C83B08A81
AF887EB38E88BF998FBE9892BE9A9AC9AAA5D1B1B0DCBEBBDFC3C4E0CAC9E2CBCCE8D2D3
E7D5D7E7D3D3E6D0D1E5CFCFE5CFCFE5CFCFE5CFCFE5CFCFE5CFCFE4CFCFE5CECEE6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D2D4E6D3D5E6D4D6E6D3D4E6D4D5E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D5D6E7D5D7E7D6D8
E7D6D8E6D4D6E5D2D4E5D2D3E4D1D3E0CDCEDECBCEDECACCDCCACDDCC8CBE0CACADDC8CA
E0CACBDCC5C6DAC3C8DBC3C4DCC2C4D9C0BFD6BCBDD4B9BBCDB4B5D1B5B7CDB4B5CBB3B5
CDB2AFCBAEADC8AAABC7A8A7C9AAA9CAA9ABCBAEAACCAFACCDB0ABCEAEA9CDADA8CAACA7
CCABA6CFB1B1D9BBB7D9BDBBD8BEC0DEC7C5E0C8C7E3CBCAE4CCCDE3CFCFE4CFD0E7D2D3
E6D4D5E7D3D3E6D1D1E5D0D1E5D0D0E6CFD0E5D0D1E5D0D0E5D0D1E4D0D0E5CCCBE6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D3D4E6D3D5E6D5D6E6D2D4E6D4D5E6D4D6E6D4D5E6D3D4E6D5D6E6D4D6E6D4D6E6D5D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D5D6E6D4D6E6D4D6E6D4D5E6D3D5E5D3D4
E5D3D4E6D4D5E7D6D7E7D6D8E8D7D8EEDDDEF1E2E0F4E8E6F9EBE7F8E8E6F0E4E6F4E7E5
F0E2E0F0E2E4EEE0E5EFE1E3F1E5E8F0E4E8EEE1E7F0E3E9E8DBE1E8DBE1E6DADFE5D9DD
E7D8DCE3D4D9E5D2DAE1CED5E4D1D7E5D3DDE8DBDFE8DCDEE8DDDFE6DDDEEAD9DAE3D9DB
E9DADBEAE0E9F2E8EEF3EFF3F4EFF4F5EEF3F0E7E8EADDE1E9DBDCE7D9DAE7D7D8E5D5D6
E6D5D6E6D5D7E6D5D7E5D5D6E6D5D5E7D3D6E6D5D7E6D5D6E6D5D7E5D5D6E6CBC9E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D3D4E6D4D6
E6D5D6E6D4D6E6D4D6E6D5D6E6D4D6E6D4D6E6D4D6E6D5D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D5E6D4D6E6D4D6E6D5D6E6D4D6E6D4D6E6D4D6
E6D3D4E6D3D5E6D4D5E6D3D4E6D3D5E6D4D6E6D4D6E6D3D5E6D4D5E6D4D6E6D4D6E6D4D5
E6D4D6E6D4D6E6D4D5E6D4D5E6D4D6E6D3D5E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D5E6D4D5E6D4D6E6D4D5E6D4D5E6D4D5
E6D4D5E6D4D6E6D5D6E6D5D6E7D5D7EAD9DAECDBDBEEDFDEF0E0DFEFD9D6ECD3CEEFD5CF
ECD3CDECD2CFEBD1D0EBD3D1ECD5D3EBD3D2EAD1D1EAD3D2E5CDCEE5CDCDE4CCCCE2CBCA
E3CAC7E1C7C6E0C4C4DEC1C0DFC3C1E0C2C3E3C7C3E3C7C2E2C6C1E0C5C0E1C2BCDEC1BD
E1C1BCE3C5C4E9CAC7E9CECAE9CDCBEBCDCBE8CAC5E4C4C0E3C3BEE3C2BDE2C2BDE2C0BC
E1C0BCE2C0BBE1BFBAE0BFBBE0BFB9E2BEBAE0BFBBE0BFBAE0BFB9DCBDB8E1C2BFE6D4D6
E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D4D6E6D3D5E6D4D6E6D4D6E6D4D6E6D3D5E6D4D5
E6D4D5E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D5E6D4D6E6D4D6E6D4D6E6D4D6
E6D4D6E6D3D4E6D4D6E6D4D6E6D4D5E6D4D6E6D4D5E6D4D6
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001T1P00`40o`000?l0003oooooobgoool0
0?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool0
0?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool0
02Koool03]kOh=kPh=kPhMkPh=kQh]kPh=kPhMkQh]kPhMkQh]kQh=kQhMkQh]kPh0?NhN80=moQh]kQ
h]kPhMkQhMoRh/3Rhn3RhmoRh]WM`=[Lg=WKg=SMgMgOh=oRh^;Zj>W^kNSZjN;B`^KGbN?Db>CEbNCH
d>KJdnCBd>KKe>?Idn;Gd]oFd>7Dc=k@b=g>a]c?bMc0a=k>`m[;`]W2_=S6_=K3^=74^]W4^]W4^M30
]M:j/=2j[/2dZ/^`YL^aY/b`Y/feZ/feZL2dZ/beZL^dYl2XUMoQhP04g^7R00SNh>3NhN;NhN;Nh>3N
hN7Nh>7NhN;Nh>42g^7R00?Nh>7NhN;NhN800]kQhP03g/7Pg^7Rg^3Q00;NhN8Noooo00[Uf]_Uf=SU
fmcUfm_Ug=gUfm_UfmcUg=gUfmcUg=d2iMcL00?Ug=gUf=SUg=d01>GLg@07iMSLiMcLi]gMi]gNi]gO
iMgMh]SH00;Qe]H0:n3Hf>?JfnGMgNgRh>gZj?3Vhn[8`>kB`nc?`^W0aN_CbncFc^SA`>cGcnWDc^S@
c^G@bnO?anC<`>?:`^;:aN78`>G:_^77_N32/N31]]nn/^2o]>:o]>:o/^2hX=^eZMVeY]RPXmFZW]F[
W]JYP=N_XmN`X]:_XmN_XMF_Wl:SQ005iMcM00SUf=WUg=gUg=gUf=WUg=cUfmcUg=gUfm`2iMcM00?U
fmcUg=gUg=d00^GLg@03iMSIiMcMiM_L00;Ug=dXoooo000Voooo00kNgn3N`L3Nh>7Ng/3Nh>;Nh>3N
gl3NhN;Ngl3NhN;Nh>3Nh>7NhN;N`>05g^7R02oNh>;NhN;NhN3L`L3L`<7Nh>70h>30h>72hN;0h>3L
h>7Nh>70h>30a^3H`L7@P83JPjCKQ:30P:7K`830Rh30P830`H70a8C1`83H`H7JRJS@P:3HPJGBPjK0
X83@[8;1X870X831X8C6SXW0P029QQ:8QA20P128P170QH30P038P835P864T0V5S``00X:<2003P8h9
PH08P88X00GNhN800mk1h=kQh]kQhP02g^3P00?Ng]oNhN3N`>000]kQhP03g/3Pg^7Rg^7R00;NhN80
1Mk0`]kQh]k0h=kQh=kQhP0Noooo00kUf]_Uf=SUfmcUf=[Ug=gUfmSUf][Ug=gUf][Ug=gUfMcUfmcU
g=gUf]P7iMcM02gUg=cTf=STf]SUf=cTf=cUfl3P`<3T`<3Tf=SUf=cP`<3P`L36d=;4P836PXkPP:?P
P:7PQ:SRPZ[QP:SQR:_P`;3PR:cPQ:WQP:C0P:3P]8kH/Y30ZH3FYhCCXX;1PH3BS8G4RX30P131P0B?
P020P034S070P@W0P0S0T@S:T0[0R034RP@00/280003`HX1`XT0T0PR00GUg=d02>GHfNGLgNGLgNGH
f>GKf>GHf^GLg>GJf`;Ug=d00nGJfnGLgNGLg@02iMcM00GUf=SUg=gUf]_Ug=cUg=d0:?ooo`009_oo
o`0:g]oPg/;Pg^3Qg]kOg^7Rg^3Qg]oPg^7Rg]oPg^7R0]kPh003g^7Rg^3Pg^7R00CNhN80==oPh]oQ
h]kQhMc0`=gOgmkQhN3Ph>;Ui^;Vi^3Pi=oRh]kPhMSJg=SJfmOIfm20V=VgXM^iY]ZhX=Zm[mVk[=Vh
[=Vm[=fo/=fn[]Rl[=NjYm6aX]RdX=2aW/6QT<fSSLZMRL2IQ<RGQ<BEPH:0M;^:M[R5L;64L;b:M;j=
N<61N<JAO<:@Nh69L;j:MK^8L[V1L;V9LkZ:L829=@GNhN800mkPh=kQh]kQhP02g^3P00?Ng]kNhN;N
gn000]kQhP03g]oPg^7Rg^7R00;NhN801Mk0`]kQh]kOh=kPh=kQhP0Noooo00kUf]_Uf=WUfmcUfM[U
g=gUfmcUf]_Ug=gUf]_Ug=gUf=WUfm_Ug=gUf]/7iMcM03;Ug=cTf=STfM[UfmcVgL3Xh>7XhN;Vg/7V
gMgUfmc0e=OPe=KMe=OHZY;N/i_P]J30]8?P^JWP]ZK1/:CP^:KS^jWT^ZOO^:GM]J3I/8?O[iSF[9KD
XHSBWhG?VH78UGc=Tgg9TWW1RVBnQfjjPVVfP6ZoQVc2RW74RW7;SGC6SGC1PV31QffnQF^mQ6RmQV^m
QVREQRh5iMcM00SUf=WUg=gUg=gUf=cUfm_UfMWUg=gUf]/2iMcM00?Uf]_Ug=gUg=d00^GLg@05iMSH
iMcMiM[KiMSLiMcM02Soool002Koool02]kOh=kPh=kPhMkNg]kPh=kQhMkPhMkQh]kPhMkQhP;Nh>00
0mkQh]kPh=kQhP07g^7R03;N`N3Ngn3NhN70h^;Pi>CPhn?0h^3Qi>COhN;Bd=3Ff=WJg^3HP:3K^jKL
_J_L_JSL`;?J_JoH_J3L_joM_k3L_:cG^j_E^Z_@/:;I/j7A/9gAXI3>XXk:VhW0TX37UH?6UH?3TP?0
Th2mRGRcR72mSGZlS7VnP7[4Tgg0Sg^2S76oSGVnSGVkR72jS7NjRW:DS83NhN44g^7R00SNhN3NhN;N
hN;NhN3Nh>7Ng]oNhN;Nh>02g^7R00?Nh>3NhN;NhN800]kQhP05g/7Pg^7Rg^3Pg^3Pg^7R01koool0
3^GJfnGHg>GKg>GIfNGHg>GLg>GKg>GLgNGKg>GLgNGHf>GKfnGLgNGKf0SUg=d0:nGHf>GJfnGLgNKL
gNOOgnKNgnCLg^OOh>GLgMc2d=oBdn3Ig=jbT>6gX>:hYN:hY>:l[>6hZ>6hX^:jZN>kZN2hY=jfYMbf
Y=^aQ>2_V]N[UM64P=>NQ]2GP/ZD0<bAO<^ANlB3N<F@NL66L;Z6H<6:L/28L/>:L/V?MLF<Ll:9H@02
`hYa00G0PF2nR72nQf[4Ph;Ug=`01>GLg@08iMcLiMcMiMcMiMcLiM_LiMWJiMcMiM_K0^GLg@03iM_K
iMcMiMcM00;Ug=d01NGHfNGLgNGKfnGHfNGLg@0Xoooo000Voooo00[N`>3Nh>;Nh>3Ng]kN`>3NhN;N
h>3NhN;Nh>3NhN82g^3P00?NhN;Nh>3NhN801mkQhP;Nh>00<=kQh]kPh=kPh=c0`<30`>?Vi^3Pi=7@
d=;Hf<;Th=b0X<32YL32/L31/<30^=c0//30/<70/Mg0/=V0X=NlX=Fl/=RhX=RaYM6aX=:PP=2PT/20
Q<20P<2BQLVHPL24R/6PTLB@PH6@0<2AQKf21Kj@P<2HP<2A0/2@0<2@PL>DPX6@0;b@P86@0<62P=kQ
h@CNhN802=kPh]kQh]kQh]kQh=kPhMk0h=kPh]kPh@;NhN802]kPhMkQh]kPh]kQh]kPh]kPh=kQh]kP
hMk1h=kQhQkoool02^GJfnGLg>GKfnGIf>GHfNGLgNGLg>GLgNGLg>GLg@;UfmP00nGLgNGHf>GLg@07
iMcM03;Ug=cUfmSUg=gUf=cTfMcPfM[Pf<3XhN;Vg^30`<32d]3Q`n7RP:3PP:SUPJ3PP:3U`;3Q_:3T
P:3UP:?T_:cP^:3L/J;K^:70]:3Q/:3HX9W0X83@X83BV8K@T83=TX34T8;@P837Q874Q`[0P@;2T@K2
RWG4T038T035P7C0P7C3T038TP?0P032Q032P730P8WUg=`4iMcM00SUg=cUg=gUg=gUg=cUfmcUf]_U
g=gUf=`2iMcM00?Uf=cUg=gUg=d00^GLg@05iMSLiMcMiMSLiMSIiMcM02Soool002Koool01MkPhMkP
h]kPhMkOh=k1h002g^;R00ONhN;Nh^;NhN;Nh>3Nh>7NhN;Nh>002=kQhP04gn3Rgn7Qgn7Rg^3Q0]gP
h00[g>3Pg^7Rgn;ShNCTh^GUh^KV`<6bhLNfh<Jh`<B`h<Njg/>e`<BdhLFigL:efL2`fL6del:jf;nd
gKfbf;Z[g;2YeJnQe:RLd::Dbj2Cd:6Ge:RNe:fQdJ6FaYZ0aYbA`IB7`9R3a9j:`9V8`I60aI^:aib;
`9V8`IZ:aIj?aLk@00GNhN801=kPh]kQh]kQh]kPh0;Nh>400mkQh=kQh]kQhP06g^7R00GNh>;NhN;N
hN;Nh>3NhN807_ooo`0>iM_LiMcMiM_LiM[KiMSIiMcMiMgMiMcMiMgMiMcMiM_HiM_LiMcMiMWL2>GL
g@;Ug=`0;nGLgNCHg>CKfnCJfnCKf>GLgNKMg^OO`>SQhNWQhNJ0ZnS2[nO1/^K0X^O2]>Fo[nK0Y^O0
/nBm[n2kZ]nl[]jm]>6jXNBh[=jeYN2QXMbZV]^TUMRPQM>KS=RMSmVTUm^XV]VLSlbAQ<jHRLR?Ol2D
P<^IP/NDP<RA0<bFP/jGPl2DP<RFP/bJR>3:b008iMcM00CUf=cUfmcUfmcUg=`;iMcM00?Uf=WUg=go
ool09oooo`009_ooo`05g^7Qg^7Pg^7Qg^3Qg^3P00GNhN801=kPhMkQhMkQh]kPh0SNhN80==kPh]oQ
h]oQh]kPhMgPh>3Rhl31`MSJfmgOgn3Ti>__l=oPh=f4X=o5/]o3/mc2/=k3]Mg1/=k0/Mo3]]g2]Mc0
]=_5]m[4^]g2/=k2]][1/mb0/=NeYmR_X]6PPLnWV]BUVmBXVMBYW=:RULVHPLRISLBCQ/6@PLFLR/6K
RlBHP<FIR<FGQX:@Q<>IQlZUV^3Rh=kRh]kQhMkQh0;NhN801mkQh=kQh]kQh]kPh=kPhMkQhMkPh005
g^7R00?NhN3NhN;NhN400mkQhP03g^3Pg^7Roooo01goool01NGKg>GLg>GLg>GKg>GHf005iMcM00CU
f=cUg=cUg=gUg=`;iMcM033Tf=cTfm_VgMkRe]OPeMGTf][Ph^;^jngWfm[T^j7V`:_V_jcT_:[U_jkS
_:[T_J7V_[3S_JkRP:3R`;;Q`;GP_[3T_K3Q_:gT/J3N/:7OZi_0YI3GXY?KXI?IXICKY9GIWHk@U83?
UHG;Sgo2T0;<V8;8Uh?:U03;UH3<Tgk0T7c9UH3AXI;Pa<WUgMgUg=`3iMcM00OUg=cUg=gUg=gUf=WU
fmcUg=cUf=`01NGLg@03iMcLiMcMiMcL00?Ug=d00nGHg>GLgOooo`0Woooo000Voooo00_NhN;N`>3N
h^;Nh>;Nh>3NhN;NhN3NhN;NhN3NhN;Nh>000]kQhP03g^7Pg^7Rg^7R00KNhN80==kQh=kQh]oQh]kP
h=cPh>;UiL30`=;De=[Lf>3`lNGPhMS@a=R0Y=b2Z=b0Z=R0X=R0[MRnZ=b0/=g0/=g2]=c4/<38^L30
^/30^=o2^=g8^/30P=R0X]bfZ=20X=2TX=:XPMBPT=BPT]:RTlb@R<VAQ<6CQ<2@PLJAP<2LR<2HQ<2E
Q<2@082@0LB@PM2ZY=g0`=kRhmkQhMkQh0;NhN801mk0h=kQh]kQh=k1h=kPhMkQh]k1`005g^7R00?N
h>3NhN;Nh>400mkQhP03g^3Rg^7Roooo01goool01nGLgNGHf>GLgNGLgNGHf>GLgNGLg003iMcM00CU
f=cUg=gUg=gUg=`8iMcM03;Ug=cUg=gUg=gTf=cUfmSXh>7P`<3H`<3Re]C`h>3Ph>?P`/;0]83P^JCR
^:;0/:3R^J3R^:CP^:ST^:SP_:kT`;3Ta;GU`[CT`K3T`[;T`;3TP:;Q^:CR/Z;0XH3KX9W0X9;HX83J
P8_IWXS@T830P@3=SWc8P7S<T@78V8C0U7k8T7c0SG30P73:T7cDX8kTf<3UgMh2iMcL0^GLg@07iMSI
iMcMiMcLiMSIiM_LiMcMiMSH00GUg=d00nGHf>GLgNGKg005iMcM:?ooo`009_ooo`0;g^;Rg]oPg^;R
g^;Rg^3Pg^7Rg^7Qg^7Rg^7Qg^7Rg^3P00;NhN800mkQh=kQh]kQhP06g^7R03;NhN3NhN;NhN;OhN;N
hN;OhN;Oh^;NhN7Oh^?0a<C:bL_Gal3IPJCL_j_L_Z_H_J[L_ZkL_jgL`;;N`K;NaKSN`;[PbKgQakS0
`;SOb[gPc;oNa[ONa;GP`[7KP:CK^:SL[j7FY93EXI;EYIG1V8[<U8C;UHG7TX36UXG2VXW2THC3UXC1
Th24TPG5VHGJbLOJ`L3NhN44g^7R00ON`N3NhN;Nh>7Nh>3Nh>7NhN;N`N001MkQhP03g^3Pg^7Rg^3P
00?NhN800mkPh]kQh_ooo`0Moooo00_Ug=gUf]_UgMgUgMgUf=WUg=gUg=cUg=gUg=cUg=gUf=`00^GL
g@03iMcLiMcMiMcM00KUg=d00nGLg>GLgNGLg@03iMcM00OTgMcUg=cVgMkRf/3Da<CO`[[P]:000^:j
Y00Rh;RUh[VXh[ZVh;R/i;b/iL2biL:dilFfj<:bi/:bi/JgilNiiL2ai<2_ikf[h;VPhKBQhZZJg::0
fif;fj6=eIB3dY1ldI5mcH9ic99naiJ1`95lb99mahmh`8=hbiEnhLC1hM;D1NGLg@07iMSIiMcMiM_L
iMSIiM_LiMcMiMSI00GUg=d00nGHfNGLgNGKf`05iMcM:?ooo`009_ooo`05g^7Rg/30g^7Rg^7Rg^3P
00;NhN801=kQh=kQh]kQh]kPh0gNhN80=]kQhMoRh^3Shm[LgL;8bNgalNKZjh:5QZJOX=Jn/mV0X=bo
[]g0/=W1/Mg1/mg2/]k2]Mo3]]o7^]o0^>36^^33]Mo2/Mk8_=o8^mc1/Mk3]Mo2/Mb0Z=biYmb^Wm2X
T]NSU=RWV=2LS<jHQlbIQl:FQ<JFQL6FQL2@Q<:HQ/>HQ/2BP<FLRMgHfMc2`]kPh=oRh]kPh]kQh]oQ
h]k1h=kQhP;Nh>000mkPhMkQh]kPh005g^7R00?Nh>3NhN;Nh>000mkQhP03g^3Rg^7Roooo01goool0
1NGLgNGHfNGLgNGLgNGHf@02iMcM00CUg=cUg=gUg=gUf=`=iMcM037UfmcVg=cVg]oQe]ORa/O`k>kY
i^S4Q8>cV9CN^JgR^J3S^jOS_:WP_:[S_:cT_JcT_JkU_joV`kCT`K;W`[CW_joVPZ?U`kGV`kGTQ:3U
_jkV_J_P^:3S]:7SZISMX8?MWhgNXY7@V8GDU7oBUGo0TGg<TWg7TWg0T7c8U7o9U7k8TP7;V8;TdmCR
e=CUfm_UgMd00nGLg@07iMSIiMcMiM_KiMSLiM_LiMcMiMSL00GUg=d00nGHg>GLgNGKf`05iMcM:?oo
o`009_ooo`08g^7Rg/30g^3Pg^3Qg^3Pg^3Qg^7Rg^3P0]kQhP03g/3Pg^7Rg^7R00WNhN80==oPh]kQ
hMgPhL3Rh>;Ui=KHf<C@d?ChllSQi10310ARE]J`X=c0X=g0/=c0/=g0/=k1^=o4/]k4/>76^N38_<30
/]k2]Mc0/]b4/=g1^=b2/]R0X=b0XMR0[=RhX=RdX=RXV=2XT=2PUmRWVl20P<nLR/fLRLB@PLJEP<6@
082@P<6IQlF0RL2HR<F1P>3Pi=c0`=k0`=oRhmkPh@;Oh>801mkPhMkQh]kOh=kPh]kPh=kQh]kPh005
g^7R00?Nh>3NhN;Nh>000mkQhP03g^7Pg^7Roooo01goool00nGLgNG@f>GKf003iMSL00GUg=gUf=SU
g=gUg=gUf=T03>GLg@0ciMcLi=_Li]cMi^3Qg]3@c/30l?3bh/SPP0004510gK20h;bXi;bZi;fRi82P
i86`i<2`i82`i/:ci/Bfi8:Pi;bPi;^/h;ZRi82bi;RPh;2RhK:Sh;RP`[>0hZ:JhZJAgZ2@gZ6@`:>D
d9R0eIR0diR1`900c95haha``91jaiD0b9R4b920biR0iLGPi=;BiM[JiMgNi=cL00;Ug=d01nGHg>GL
gNGJfnGLgNGKf>GLgNGLg005iMcM00?Uf=cUg=gUfmP00nGLg@03iMcLiMcMoooo02Ooool002Koool0
2=kQhMk1`]kPh=kOh=kPhMkPh=kQh]k1h0;NhN800mkPh=kQh]kQhP0<g^7R02oNhN3Oh^;Oh^;0hN3L
g]o4`/@@2P63JfGI]ZCM`[CN`[KOa;WO`KGOaK[Oa[_N`[;N`[KNaKWN`[3Ma;OMa;KN`K?NaKSM`K;L
PJ[J^Z[I^jWA]J;H/YoH[I_E[9[DZIODYiS:PX7>WX[=VhS4V8C6UH;2T7b0U870V8C4WX_1Vh_5XY;N
iNO0h>7OhN801]kQhP05g^3Pg^3Rg^3Qg^7Rg^3R00GNhN800mkPh=kQh]kPh@03g^7R00?NhN3NhN;o
ool07Oooo`08iMcMiMSIiM[KiM[KiMSLiM_KiMcMiMSI0^GLg@03iMSIiMcMiMcM00cUg=d0;^GLg>KM
g^GMgNG0`N?IfLnk_800FHUWFmnbWNBn[^Fm/>Fo/nJ4/NK1]>K2]NB0/>Fn/>G0/nF0/>Bo/NBo/>B0
YNG0/^Bl[>2dX>6eXn2fX/2aVmn^V=nYU=RXT=ZUT=^RTM2JP=BIPm>GP<6@1<bAN/R<M<B@NLJDOL^J
Pl2CPl^MRnCPh^CM`0OUg=d00nGJfnGLgNGKg007iMcM00?Uf=cUg=gUfm`00nGLg@03iMcLiMcMoooo
02Ooool002Koool02=kQh]k1h=kOh=kOh=kPhMkOh=kQh]k1`P;NhN800mkPh=kQh]kQhP09g^7R03CN
h>7Oh^;Phn?L`<7JgMgYkNg0`<:h]kVQVIZ@Mg6SRGoK^j_N`[CN`[KOa;SO`;CNa;ONaKWL`;7K_K7L
`KGLa;SMbKcNbkcO`kSPb;[NaKG0Q:CI^:OI^:K@/8GF/9gF/9kB[Y[?ZIC>YI?8VhC<W8O=VHK8V8;6
U8;4TGfoU030UH72VHG0V8S5XI7Jf]W0h>7Oi>GNh>3Lh>02g^7Q00GOh^;OhN;Nh>7Nh>;NhN401mkQ
hP03g^3Pg^7Rg^7Q00GNhN8Noooo00SUg=gUf=WUf]_Uf]_UfmcUf]_Ug=gUf=P2iMcM00?Uf=cUg=gU
g=d02NGLg@0di=SLi]gMi]kOh=WHhmOGk^WZb<S8a;6_/9:=W6QUZhAeh[NTi;b^iKj`iKnbi86`iKna
iL2biH2ShkRZhkb^i82bi<Bfi<Jfi<:`i/Bdi<6_hX2XgkBPg[BNg:6Fg:bEg:bFf:^Be:F<eJ6;d984
diMoe9Eo`942cI1jbXefaI1haY5ib9EnbY20c9f:h]GCi<C4iMoPiM[Ki=SI0^GKg005i]gMiMcMiM_L
iMcMiMcL00OUg=d00nGHg>GLgNGLg005iMcM:?ooo`009_ooo`0;g^7Rg^7Pg^3Pg]oOg/30g]kOg^7Q
g/72g^7Rg^7Qg^3P00_NhN80==c0h<3Rh^7Ti=[0`=KHf>7alJ2TX88@409RDX000<6:X<32/=k0]=k0
]mo0]]k0/=g0/=c0/]b4]=Rj[=Zm/=S4/=k<P=o@`>38P>72/mc1/<20X=BPP=2RPM2PP=6QT=2WV<2T
T<RPP<23R<B@P<RHP<VDP<2HP<NDPLB@0H2@0<2AO82@NlB@P<F0P=2;Pl30`=oUi]gNg]c0`P;Nh>40
1=oRhmoRh]kPh]kQh0;NhN800mkQh=kQh]kQhP03g^7R00?Nh>3NhN;NhN801MkQhQkoool02nGLgNGH
g>GJf>GJf^GHf^GIf^GLg>GHf>GLgNGLg>GHg00;iMcM03OTf]SVgMcWgn3Pf=SQd=7bhO20P8210PB0
CD2010S0P93UP:3U_JkU_[3U_k3UP:3T_:WT_ZgUP:3R/:KP^:[TP;3T`;SUb;_V`;3W`[3SPJ3QP:3H
Xi3IXhW@P83AR87AX93DX830PX3=Vh3<T7[0U7SAT7W:T03=T7S8P7S0P736SGC4P7?8T@38V83HQX3P
`<3Uh>7TfMWQf=[UfmcTfmcVg=h00^GLg@03iMcLiMcMiMcM00KUg=d00nGHg>GLgNGLg@05iMcM:?oo
o`009_ooo`;NhN801]kPhMkOh=k0`=kOgmkQh]k1h0kNhN804=kQh=kQhMkQhMoPh^3Shn3Si9BBTHEg
M8I^Ii6DP?7D`^77^=k2]=o4]mk3]]k2]0;N`[407mo0/Mk2]=k1]Mk3/mo9_=o8_=k0]=nk[MZ`XMJ<
P=6CQ]6CQl2AQ<j@P]2DR<6BPlfJQlVKQ/6GQ<JIQLNDPL2@P<JDP/JEPXB@0<:AO;n?NLBBP<>KR/^/
X=70V@02gn;S1MkQhP05g^;Rg^7Pg^7Qg^7Rg^7P00GNhN800mkPh=kQh]kQhP05g^7R7_ooo`;Ug=d0
1^GKg>GJfnGHf^GIf^GLgNGHf@kUg=d01>GHg>GLg>GLg>CLg0;Vg]l0:hb0P8ibJHmYFif>8?K@_^O2
/^Bm[^Fo/NFn[nFmX>FmZ^BnZnF0[>Fn[^Fm[^F2/>G4]^K4]^B4Z>JgYn6ZVlB1R]R>OmV>P=F<O=F<
NmN?PMFAP=>EP<nFO/6CO<bEOLf@NLB0N<b@N/bAN/20L<R=M<F;LLZ2N<VGP]>WVLBDTP02iMgN1NGL
g@05iMgMiMcLiMcLiMcMiMcL00GUg=d00nGHg>GLgNGLg@05iMcM:?ooo`009_ooo`0:g^7Rg^3Pg^7R
g^3Pg]o0g]oPg^7Rg^3Pg^7Rg^;R2mkQhP0lgn;R`N3Pg=oPf]gMa>3Pjno`bLW;UH4aVhQoZXn5bH2B
jlnmh<Fdg/:egl>gg/:fg/2eh<>ag/:_`L:UiLbni<Rkh<:ah<6eg[bafH>Yg:bQeIV>d808cW]ac7ed
bP1Xc7ebcG]b`h1hdi21cIB4`920a9Z7`YAoP8ihaIB2aYF2`900a99n`91ka9>1`9N5aJ2@aH20g]gM
h>KW`>3Qgn;Sgn?SgL3Pg^7Rg^;Rg^7Rg^3Q1mkQhP03g^3Pg^7Rg^7R00GNhN8Noooo00SUg=gUf=cU
g=gUfm_Uf=[Uf]_Ug=gUf=`>iMcM03CUgMgSf]_RemSS`<3[k>kBa<B0:R:SPgJcRW[0XH?ab[SW`:kU
_Z3U_k7U_K3U_ZoV_Z[T_JWTQ:SXb[OYa;KVQ;7V_:oV]j_P[Z;RYi[MThOG2@7DMf[DN6g@L67BNF_E
Mf_B1W7KRg_DT7g8TX39Ugo8T7O2R73;T7[<TG[4P73:SWK6S7?:SgS6Tgk=VhW0PYcUf=SVhN?Pg<02
i]gN00GTf]cUfmgUgMgUg=gUfm`01nGLg@03iMSLiMcMiMcM00GUg=dXoooo000Voooo00[NhN;N`L3N
h^;Nh>7N`>3Nh>7Nh^;NhN3NhN;Nh^87g^7R02SNhN7NhN;NhN;NhN7Oh^;Ph>CHg^3Hf]S2h^3Pi>B8
PH>0002@X8;2TX30`830PJ7N`:cN`;3N`kON`KCN`:70P:WL^j;0P:3XdL7PbH30P:;0YZCIXXC@P83@
THC007C0@43:H630H4F2@432I632@E;2H63@1G42`80001K0T82lTWbbR732U835T834T830U872T034
T02lT@21T0C0P03H`/CPh^70h>3Ohn?Ph>CLg/3Nh>;Oh>;NhN;Ngn05g^7R00?NhN7NhN;Nh>001mkQ
hQkoool02^GLgNGHf>GLgNGHg>GJfnGKg>GLgNGLg>GLgNGMg@[Ug=d0;^GLg>KMgN30`>;Hf>3De>S0
`>3RhJ62QH0009NAR=6@X>20XLJdX>BiX>F0/>Fn/NFl[^FlZ>BhX>2bQNB0X>[@_>c1^NJ0X>BRQ^69
U/20PMZ9Q=80I<14@<mRD<aQEL18@<aQE<10A=1P@<1bH=D8L/240<FB0<:0LH60HLR@N<^1N<R0NLb@
N0;8P7002/2=L<B0M<:10N30`NK0a>30`>KNg^KNgn;HfnCKg@;Ug=d00nGJfnGLgNGLg@03iMcM00?U
g=cUg=gUf=P01nGLgBSoool002Koool01mkQh]k1h=kRh]kQhMk0`MkPhMkQh@0?g^7R03C0h^;Ph^?O
h^;0`/Bl^K^8Ngb43`3M`Jggfl[RaHCE]JGM`:gN`;3Na;OO`K;LP:KI/YgJ]9o0P:CO`[KO`KCH/:?L
YYgIWIO4V9;BTH_;PWk4K6;<MWC9KfR<HUC5JfNoG5K2Heg6J6?4MFj406>oRg^oSgZlPGS2U7k5TGk6
U8?:VXS5UX;4QP:nTGjoSg_0S0?D_KCLeM;LgN02gn;R0]kQhP03g^7Qg^7Rg]oP00ONhN800mkPh=kQ
h]kQhP05g^7R7_ooo`06iMcMiMSIiMcMiMcLiM[HiM_L4>GLg@0di=cLi]gNiMgNh=C0a[>cUGE`UPQU
i;fWn]S7hl60g;2Ni;^WiH2`iKnaiKb/hKBPh:jFh;2Hh[B4i[f`i[b^h:25hj6FhINAf9F4fHb3dgeg
a6QDeG5]d6YQ`615bfMOa5Y<b61DcFAJbW5V`71PaHMcaH]b`8Q`b91fbhefc91kd9J0bi9jbH9da8ef
a8]caXP0gKN^hm3<h=SH0^GMg@CUg=d00nGJfnGLgNGLg@05iMcM00?Uf=cUg=gUg=d01NGLgBSoool0
02Koool02]kQh]kPh=kQh]kQhMk1`MkPh=kPhMkQh=kQh]kPh@[NhN80?MoRh]gPh]W0`>?UiNOZj/31
`HUoPH5^K8B6P^34/>oC`/[1[MRfYMk2/Mk0/=k4]n31[mVbR]:USmJ/U]beX]6ZWm:`Y<RPP]RPUmJL
U/2AQM2ESlbET/R8Q]2FTlf5NXP90/9jMKQ[H[16@;9JE;EWHJQ:A;emK/B:N<2@0l6DNLB>NlJDP<bN
RlNHPl2@1<6CP<6AO/B@0/f]X=G3^]CB`]kOh=cOgn7Ui=oRh]kPhMkQh]kPh@07g^7R00?NhN3NhN;N
hN801MkQhQkoool02^GLgNGHg>GLgNGLg>GHf>GKfnGKg>GLg>GLgNGKg0[Ug=d0?NGMgNCKgN3Bd^WQ
h>_Vil;2`YMhM8aWH8R1PNO0Z_??_^F9Z=nbW^BmZ^F0X^G0/NJlZN2XQMZPQmbXSn2QP=fQVM^[W<26
T>6JTN2ET=21PMV?R=F?S=20P=^?SmMoML840<]eKl1WG810B[IHCKYTF;=8B<AiI/Z6LL:@L<N@LL^:
Llf2N=:IPlfDO<Z4M<N?N<J>M/R4LmFXVMjn]<?8dNCJfnCIf^SPgnKMg>GKg>GLgNGKg007iMcM00?U
g=cUg=gUg=d01NGLgBSoool002Koool01MkQhMkQh=kPh=kPhMk1`P02g]o000?Nh>7NhN;N`<000]kQ
h0GNhN80@=kRh]kQh]kPh=oRh]cOh=;De>CViNS^kX60P4882X1YI<B0X]k0/<21X<60P=bhY=k1/=k1
]=k5]/2kXM20P<640<21P<20P84@1hB@P820P=2LU=20TLB0P=20T<2YZ<20P=:4P]2<R820P<2<Qk0>
0X10@9EABX1DA8000;9S@L81I<FA0<2AL<B:N<2@P<2PP<RHP<:@0L:EPL6APl2@P<>EPLRPP/20P=?@
fM;Cf>3Pi=oRhMkPhMkQh=kPhPGNhN800mkRh]kQh]kQhP07g^7R7_ooo`05iMcLiMcMiM_HiM_LiMSH
00;Uf]X00nGHg>GLgNGJfP02iMcL1nGLg@0miMSLi]gLhm[M`=3@j^7Pk>SYP820@00TQ61H`860i;jZ
aH2R`822hK2LiH2RiKbPiL2Pi;:4`820`81XdH`0`820`0D0aHP:`0@0gYJ0`92@d0@0f9B4d:2Rf820
fH2^f8J0`8B0b8J0_@QXX410P514R514PT00P4Y8bWAUb81`aHeXbhA`c800e820`Y02`800b95ib91k
c902aI40aXR2`824`<K@`M;Dj^3Pi]gLi=_LiMcL013Ug=dXoooo000Voooo0]kQhP0:g^3Pg^3Qg/7P
g]oOg]oPg^3Pg^7Rg]kOg^3Pg^3Q1MkQhP0mg^7Qg^7Rg^3Pg^3Qgn7Q`<;QhN?Th>?T:2@PCC<aXH=g
hM64g/:`d[JUeZB0g[JQglFjg/>fg/BdgK:M`XDB`HA^_h1_]0IX[6IM^HMlSI24djJMdjBKbi20dJRM
e<C0d<S0e/c5e:bJbK>PaZVR]YV<X0QaVVAIUeY?QdP1YEeB]6]O`81`_Xi`a8aj`X20dZNBcZ:>bH20
aiR6aYV8`9B1`I9maIR4`X21d<cCeM?Gg/7Pgn;R00;NhN800mkRh]kQh]kQhP03g^7R00?NhN7NhN;N
h>801mkQhQkoool2iMcM00[Uf]_UfmcUf=WUf][Uf]_Uf=WUg=gUfM[Uf=cUfm`5iMcM03gUg=cUg=gT
f=WUfmcUg=cRf=cWgn3Vgn202B1=<RZ]Nfga`83U_Z[J/IkLZY3U/Y_U`;?U_[3U_jkS[YKAP@C7P6K8
NVO4HV:gGUG2PWCAP83OWYOOW9KHR8?LX9OK`;WHaY;Jb[gKYiC@YZ3@Xi_1Th>/06RRGeBLEdN9@S2_
EDZkIeO626S4RVO;R7;0T03HXh_EWXO3U03=U7k<UH3<T075SWG:U7g8R8CGalkLc];Uf=WUgMd00^GL
g@03iMgMiMcMiMcM00?Ug=d00nGLg>GLgNGLg@07iMcM:?ooo`009_ooo`03g^7Rg^7Pg^3P00;Nh>00
1MkOh=kPhMkPh=kQh]kNg`02g^3P1MkQhP10g^3Qg^7Qg<72gMkOhN;Qh>WZfmgPcm7C0T`0LeMC_In@
j<fhh<>`ekZWek2Lfk>OglBig/B`gl:bfJNEa8X4_h5/]FeNS4Q9ZEaB_HEj`9R=e[2Xe:NLd::GdjZN
f<>mdLBDeKbcdJ2A`;:PcJnV`9b@/YB3ZGeaVVAFR4a4UeaBX5aAXF10_8Y_aHmmaX62e:RDdJRDbX26
aYN5aIR6a920`YAoa9J2`X23b<;<d/kEe]GDg^3Sh>?Tg^3Rg^;R1MkQhP03g^3Qg^7Rg^7R00ONhN8N
oooo00cUg=gUf=cUf]_Ufm_Uf=cUf]_UfmcUf=WUg=gUfM[Uf=WUfm/5iMcM03kUfmcUg=cTf=STfM[X
gMcYiNCQf=_Ib/`4@4IjDdW7V8O^bK;W_Z[N]J3NZIGR[YSV`;?UP;3U_J_PXhk1PFc5OFBmIeNYA42a
F4W4P7;@TH3QZZ;OX9O0UI;MY9OO_[O0T8KL]jcIVh_HYJ3FZJ3:UXV4S8:dMVZQGdjD@@bSDD^VFDRd
D532QVO:S7G4T@;JY8gHY8g@V0K=Tgg;U7k9T037T7S:TW[0YIS?_LKHbM3Ld=3TfmoVg]l7iMcM00?U
fmcUg=gUg=d01nGLgBSoool002Koool01MkRh]k0h=kPh=kPh=kPhP03g^3P00CNhN;Ngl3N`N3Ngn05
g^7R043Ngn3NhN7L`<;Lg=kPh<32`<2@T/2IV9e04120Q2?8T:S0Q:3P`:c1PJ[H/X3AX9cO`[3N`;3N
_:c@UHB0P6R2P6B]HE20402P@U32QPC@P83HP;7@ZX;HP;3DZIkJ]ZKDP8SAQhS9P0K@Y:3@X:30Th30
P828QX2QL6200023@U20@0B0002`16Z3P7[0QX;FZ93DX9W0X836UXC3U870P034V874UX60P820/834
QL30`<3Hf>7Ph>CNh>;NhN05g^7R00?Ngl3NhN;NhN801mkQhQkoool03>GMgNGHfNGKf>GKf>GLgNGK
f>GLg>GHg>GLgNGHf^GHfNGJf`GUg=d0>^GJfnGHg>7Hf>?GfNSLf/32`<R0T820PT00284T4<n6Xl20
X>2lX>>hY>2PV<2XU>BnX^B1/>BbXM>@1L00H<41I;1J@8000;90@<:2M<20P>2fX=nPV>20X=bPUnB`
X>20P=V1P]:0Ml2PP<2RP=2ARL20R<:0P:5R@800@9Q@A894<H081;X0H<28L/B20mbTP=RXT]20P<bB
O<R@N<R0L<RD0LRBO<20P<2S]0;0P<001<;@g>KN`>CLg>GLg0GUg=d00nGJf^GLgNGLg@07iMcM:?oo
o`009_ooo`09g^7Rg/7Pg^3Qg^3Qg^3Rg^7Qg^;Rg^3Qg^7R00?Nh>05g^7R043Ngn3NhN;L`<;Nh>3M
gMjBQ8ZITiV0LgHP0@7L_[Cae/3F^:SM_JSQ_ZWL/Z3F[YcN`K;N`KCL^JS>TX>m16W7Sh2hNVj0@4Zo
O6kAVHoFXXCMa;WI/jK0a83H[Z3O/ZWEXY;AThG<QggAXY[DY9OCTXW2T8[<Xi:bOVj400R?JEn3BCd3
0R2ZL66hOg30PP_G[9[G/Ik@X8S6UhC3U870Q036VHS7UhF7Ph6dZ;6l/;O0P<3Cd=WMgmoNhN;NhN45
g^7R00?Ngn3NhN;NhN801mkQhQkoool03>GLgNGHfNGKg>GKg>GLgNGLg>GMgNGKg>GLgNGKfnGHfNGJ
f`GUg=d0@>GJfnGLgN7Hf>GKfn?HfL60PZb:RY=ZIR456^Bi[O?E_=jdX>BiX^NjXn:RV=fZUNFm[>Fl
[^>eX]F>Nl00H<j:MlM`J:93@/UfI]VDR>2TP>;0/n2^Wn6:/=nZVNN]Xn2;SMZ=OMB2M^2JU=nMTMf;
Pm6@P=FNRk]hIY`@EIiKFXQ6=Q0K4;9ZF;mjJ<:>1=jWTmj]Um:PPLbCO<V@NL20L<fDP<fCOLB25;^S
Z/>[/<bhR=W;e>CJf^GLgNGLg0GUg=d00nGJfnGLgNGLg@07iMcM:?ooo`009_ooo`05g^3Qg^3Pg^7Q
g^7Qg^3R00;NhN801Mk1`MkQh]kPhMkPh=kPh@05g^7R03oNh>3Nh^?M`N3QiNCFemj1<C1eIf]TCTl@
40SO_kC[dK_I^ZSJ^ZGN^JKH/Z7E[icM`:kL_Z;K]jG=Th:016O=VXc9WI20P07=VH[GYI_H/Z3L`;GJ
]j[L`KCI[j?N[jGDX83BV8W>Sh?DV8C@VH_BRh;0P837U8BjOVnT40FOLFF>D4D58B:QHeF^KV71SP?G
[IcH/9g@Y8[6V8G5UH;0QGc6U8C7UH?2PH2`XjR_Wj?0PHc<am3If=WLh>001]kQhP03g^3Qg^7Rg^7R
00ONhN8Noooo00CUfmcUf=WUg=cUg=`3iMcM00GUf=SUg=gUfmcUf=cUfm`01NGLg@0oiM_KiMgNi=SH
in3Og=;HUB4WQUmJLDQ13@P0iK^^kljeh;BPhKFNi;BOh::Hg:^Ei;bXi;RYhK:Odhmj`P16eIJ4ei>:
`P@0f964h:2EhZB0hkb^hK:Sh8B`h:^LiZZOb8Z1fY>2eXUl`928fY>4fXEld80Ad8ml`WUXQP1LZVMO
U4`n4188ZEe<^6QIa8X0gZVEgZbFe:63c9=mbi5kaX5dcI1lcI5kb9D<^9jP^9^K`KB4dl;:h=?Di=SI
00KUg=d00nGKg>GLgNGLg@07iMcM:?ooo`009_ooo`09g/3Pg^3Pg^7Rg^7Rg^7Pg^7Rg^7Pg/70g^7R
00?Nh>84g^7R043NhN3OhN3Nhn?Nh>3Rj>O9am000P1@00E@<280013B/ZS0PZ30P:S@/:?H/:?J]:3D
/H3L`:[L^:3H]:;<TX:0063BX9?0`838T831Q:S0/Z3HP:3H^:[J^Z3H^:3J/:;L[J;@X83BX8CAV8[0
P0;3R7O:PG;000200630O72206:`N6^9@U00922HD4RREdB0P0?D[9WFZYW8X8S6T8G6UX>0T7S4P7[6
TX30P82/W9Z81020P878`<WFdmCL`N06g^7R00?Nh>3NhN;NhN801mkQhQkoool01NGJfnGHg>GLgNGL
gNGLg002iMcM00?Uf=SUg=gUg=d01^GLg@;Ug=`0?^GNg^CLf>SPh/C3a0000D0f95@Q80P00<2`X<N0
R^2`X=bbW>2^W>2`P=b/T^>kXN6dX=jPV=2BNl00H=RPQ>2BZ^20P>20X^FYX>2PX>>bX>:`Z>2`X>2/
X>6XVL24P=R1R=RBP=220<:1L=40I<09H8M`B<QhJ<80H81bHZ50@00P885@0ZY@@<20HmRXU=bRT=B0
P<f@O<b@Nl20L<V8Llb>N<b@0;BHTX000LB0P<6l`mg>cnCHf@KUg=d00nGLg>GLgNGLg@07iMcM:?oo
o`009_ooo`0<g]oPg^7Rg^7Rg^;Rg^7Pg^7Rg^7Qg/32g^7Rg^;Rg^3Rg^;R1MkQhP0ng^;Rg^7Rgn;R
g^7Ra[k814A3L5=;LTa3L515e[NVe;NSh82YekRUfkFWfkVSf;RVg<6[g;RXf;BRd9n;`H1he:BEhljl
i<C6j=K9h/JkfX6Yg;V/fkncf[RXg;N]g:nQdZ2BdJFBdj:@c8d:aXYgb8IfPP1P^7ET`gi`b81b`X=a
/g9TPDA0WUi>Y5a>PH1`dJRDeJVFa:23aYF3a9>1_I1i`XiiaY9o`9R7[IbHKEaKT8>2dloCfm_K1mkQ
hP03g^;Rg^7Rg^7R00ONhN8Noooo00cUf]_Ug=gUg=gUg=gUg=cUg=gUg=cUf=WUg=gUgMgUg=gUgMd7
iMcM03cTg=cTg=g=^/8<B2QgCCmgAcR0D0;L/Z3L/IcX^:CN]9oR/J3R]:3O/ioS_:GQ]J;O[i_FVhC0
R73KX8kSck?XhLC[dlCX`[GPP:?T/jKT^ZgQ/ZCS/ZORZY_0PX3GXH_JWHWBR@3=QG3>PVk0N62mLEc:
NVW@P6S6PfRlK5jH@0BUFDF/EdK1P63HY8gKYHoDQ83<TG_:SgW2S778RW7;SWS<U02dUi1eEe6JRXcJ
b/kReMH7iMcM00?UgMgUg=gUg=d01nGLgBSoool002Koool00mkPh=kPh]kQhP04g^7R00GN`^3NhN;N
h^;Nh>;Nh^801=kQhP10g^7Pg^;Rg]oPgN3PemGJa[JiV01bXX=fX7]_X80dfK^Ye[RUh82XfK^YgK^]
gKbPfkf]gL:_gKb/fKFTdj>Bb982d9Z9f[RTi<V8i]C8hL^og<2dgKf`gL2eg82QgKb`g;>Sd:6Ad:6=
dZ2?c80<ai1laXeiPhAT^Ge[_h5a`HA`_hEb]ge/X6AEZFeJZVYGP89`cZ><djND`8J1aY:0`Y1n_H1h
`I1ia9:0aIR5[IbID4A5PIBFhN3RhnGV`>3P4=kQhQkoool00nGKfnGLgNGLg@04iMcM00?Uf=WUg=gU
g=d01^GLg@0oiMcLiMcMiM[Ki=cNgm3EcK6cX7AP[GaZZg=SX4PTgkNRg[:Ni[>Th;JRi;JVhk>RhKRV
i;jXi;RQh;6MfIn:d89deYJ1gkJLhLb0j]72ilNii8>Vi;RZi;^_h;BSi;NZhjjLf8B0eYf5f9b8dX/5
cXaecHUa`81T_WUTaGeYbH=Ya8AY_WQU[41@/FQB/VA@`81Pe9j4fJ>=dX:2c8ihb8af`HQ`ahaabXih
biAm/iNBEcljRI23iMcNj>7R017Ug=dXoooo000Voooo00?Nh>7Nh>;NhN801=kQhP03g^3Pg^7Rg^7P
00;NhN04g^7R043Nh>7Nh>;Ng=kL`>31`/78/J22P87BTXC@SIc0P87LPZSH^JSLP:SLP:;N`;3NP;30
`[3NaK?N`;3H/Z3@Y9W0P832RWC4R030P830`83NbKk0b83N`[3N`;G0`;3N`K;L^:;@X97>V830W8c0
P838V834T020P72jQW6`Q76`Q62bQW2hPW240660366c26B4P739V830X870P835SGbnRGRnS7:0TGS1
Th20T82YV90V3R40003/l>?Yh>32h>06g^7R00?NhN3NhN;NhN801mkQhQkoool00nGHg>GLgNGLg@04
iMcM00CUg=cUg=gUg=gUg=`5iMcM01[Ug=cTg=cUf=WTf=WBQ<C3Z8J@P83JT8;AQI30P83P^JCP]J3T
/jCP^:?TPJ3TPZ;TP:CU`:7TP:3P/J3MXi3@P071Q6G4P030P83TR;02i<2a02CUP:?T^:oTPJ3UP:gS
/8?HX83ET03EV8CBP030T@38T728P630PV60P6R00620P6RoP6R406642V2i1TC0P63@T7SDP8;@T03;
RGC4PG34R6;4PG38SgS0T7V`U88X2@R0@43Qh>_/j^SP`<4@iMcM:?ooo`009_ooo`ONhN801MkPh]kQ
h]kQhMkQh=kQh@07g^7R03gL`L3A`/CC^JSJWXcog<Gfdko3P:;N`jgO^Z_MP:cOa;GPb;_O`;WPb[kN
b;_N`;SM_JgJ/:?@SXW9SGS4Pfk8P0gI^jkMb;_0bH3Oa[WP`;G0`[3Ob;WN`ZoAXXG@WH[?WXg:QH;9
WXW2VH21Q7RjSGbdQG2RP62fQVfkRgC1TWS4Tg[0TGO0T039Vh7<WXc8TXC4SGbnRgZnS7:oUGg0Tgn2
U8>VTHhO61lT4AGTjNWRi^KNh>801]kQhP03g^7Qg^7Rg^7R00ONhN8Noooo1nGLg@03iMcLiMcMiMcL
00;Ug=`7iMcM03gTe=CH_KoJ]:;RVH?ofl?gd[c8P9SU_ZKT]ZCT^:7U_joVa;GV`;7VaKSU`kCU`[;S
^:OQ[9gFRH;?RG3:OfKAQ@7Q]ZOT`kGT`;;V`[?V_:oT`:?Va;;T_ZS0XY3GVH;EVXG@PH7?Vh78UGR5
P731RG>jPFN`OVFmP6K0R6_1TV;7TG74Sfk8P73@UgWBVXC0TWc;RGC4Qg;4R6;5TGG6SgO0T7R[SHHQ
5QDY0@CZiNGXhN7Tg=`01^GLg@03iMcLiMcMiMcM00OUg=dXoooo000Voooo00?NhN;Nh>3NhN801=kQ
hP06g^3Pg^7Rg^7Rg^7Rg^7Qg^7R0]oQhP11g^7Rg^3Pgn7QgnKVg/32f<O1flFahLR`k/J_il2/b86T
g/:]g[VZg/2PglFhglVlglRhglc1g/Vmg/6jgL2`fkBVeJB0cIN2ah]fb905ekNWgLBggl>jglFggl2e
`<BdglZkg/Fde:b:dj:@cj6?b8>1aiZ6_iEn]h1a^HMg]8A^/X1^^8M/_8Mca81``i=j`i=l`i:1c9j6
bi^9`Y20a8mm_hel_XQh_i=m`9=mP9B0WhR18aTO1P04dM;EeMCEf/72013NhN8Noooo00?Ug=gUf=cU
g=d01>GLg@03iMWLiMcMiMcM00KUg=d0@>GHf^KLg>GQh^C@b=g3^n31Z^34/?;2Zn^nYl24T^BmY^Fe
Y>FiY>K1/^K4]^K0]>K7^nG4]nC0/>BkZ^6_X=VPR=BCN/j7K]21M]jaX>Bo/NG3/>K0/NJk[^C0X>K6
]NC1[/2XQ=VNRMJMQl>G2LfFO/FAMXF4HKn3K[Z0I[QoIKn2I<64J/J@KLR@L/R@Ll6AO=:JO]6GPL6B
O<Z;MLF9M<B0L<F?M/J?M/B@N:F4NRDH5P@<0=_<c]g>cn3HfA3Ug=dXoooo000Voooo00?NhN;N`>3N
hN801=kQhP03g/3Pg^7Rg^7R00;NhN804]oQh]oRh]oQh]kQhMkPh>3Qh=oXj=k0P<;9]N3>^X2009B7
4965P=2PX=k2[]jhZ=k2Y=o6^@;Nb;`0<=c<`]g:_]g8^=c0/]^cZM2PP=2QR/20P/:@P=F`P]fl/=k0
/Mk0/=j0/=c0/=k:_=k6^<20P=BPT<2PP<2@0/240;V:NKR0H;L0H;@1JK20K;b8J[b1L[R0L<6AN<2D
0l20PL2PP<R@Q<:DP/BA0L2@O[b8N<21OX2BO82@P9YjI@0R840@6::BX8:0P=;0`13NhN8Noooo00?U
g=gUf=WUg=d01>GLg@03iMSHiMcMiMcM00?Ug=d0@nGMgNGLgNGLgNGHf^KLf>CPi>C0P>;5Y^38/l21
4<:30<J02<2QP>FmX>FdXnFlX>C0/NG0]^C4/>C8_>C4^>C0]>Bm[N2bX<2PT=R8Pm2C0m2@N=R/TnBb
Z^F0/>BiZ>Bj[>2lZ>C4]^G0//BXP=bPP]BLP<200<:0L<62LH00H;eiHKQjHKQlI<:4H/1lJ/04J<2<
LL6@M=20PMB0P<2@O/2@Nl^=LL2<M/20L<J9M/B>M<240:1cI00P1000082@Tl2ZZl30a00@iMcM:?oo
o`009_ooo`03g^7Rg/7Pg^7R00CNhN800mk1h=kQh]kQhP07g^7R03oOh^?Oh>3LTHSP_ZWO`:jAQ2:i
RGNkUH;0ZJ3O`ZkN^j_O`ZKNb;_NbKcNb<3Mc/GNc<7Nb;kOaKSN`:oH^:3L/J;EZYKAW8SE[igN^joN
`;OM_ZgM_JoM`;3Nak[M`[G0[XkDYYO<WX_0Q@FoRgZkRGRkP6>hO6fdOFVaOVRnQfboPgFjPWG4UX3<
VhW@YI7@YY?8V8K2UH75U8;4Th20P7c0SWk0TWf4U82QNf]WBD19516@QX^aZJc>`L804=kQhQkoool0
0nGLgNGHfNGLg@04iMcM00?Uf]SUg=gUg=d01nGLg@0oiMgNiM_Ki8R0ikZRik^XX80X_hA^`i1i`ZB6
iKfXiKJTiKjPiL>eiLBfi<2ji<VoiLNkiLFhi/2bi;^XaK60hZfKfjJ>d9R0g:^Fi;NYiKjai;VWi;RX
i;RZiL:di;f_`ZV0fZ:@diV3b81faHMb`HE``@1R_GUT^WUP]WYPa8ASaGm]a09Pc91heIF2d:68ej:<
cYAn`I1ibi1jbXmia8QdaXYfaXie`902YWQSK4@gD@T4W81o_:>SaLC8013Ug=dXoooo000Voooo00?N
hN;Nh>3NhN801=kQhP19g^3Pg^7Rg^7Rg^7Rgn7Rg^7Qg^3Qg^7Qg^7Rg^3Pg>?Ug]CCfX6EfZfIeJRH
T80@_i1o`j>Ae[2Pgl:]g[f/g/6`g/Rlg/Vmg/g2glo6h<g3h<R0hLJjhLFbg[fZh;6VeZbId:2@ejnN
g[f_g/Bgg;b[fkZ[g<2`g/>fg;b_e:R9d::AbIR6`801_H]i^hYh^hA`^H1^/GaVY7UP_XI_`8Uj`I20
bYf9d:6?`ZF@d:FBaiZ7`i24aYF3aI>1PY5n`8im`I9n`824[81]RF9ANU98PgMi[JV[c<30013NhN8N
oooo00?Ug=gUf=WUg=d01>GLg@03iMSHiMcMiMcM00;Ug=d0A>GLg>GKg>GKgNGLgNGI`>?MgnG?c^20
T>>XT]nQT/200/J;Ml^NRLJTP^FnYnFiYNFlZ^C3]^C5]nG8_>G;`>K9_NK6^^O1]>O0[>BhY>F]WmbX
T]R1R=f[UnBhZNFo/N:hY>:eYNBjZ>Fo/>>gZL2PP=JNR/nCO/28LL>7LL66L<60J;mlI[MhG[=`@<>3
IlN5L/Z8N=6HPMRLR=6PR]JQRlfFOl6@O<bANl^?NL2=M/J:MLN>M/:@1K5lIHmMB812@hebKKRSXLG0
`A3Ug=dXoooo000Voooo00?NhN7Nh>3NhN801=kQhP19g^3Pg^7Rg^7Rg^7Rgn7Rg^3QgMoPg>3Qg^7R
g/34f/74g8F1d824`hX9`0X0P01P`H61aX2Q`82Xg/:]g/2Pg/2`g<Rlg/Zn`<c0h<35hLc1h/R0h/6h
h<Re`82Ph:2PejjId::0fK2Qg/2`g/B`f[bYf[RYg<2`gH2`f[:Pd:20b9V2`840^8Qh^HQ`^8ah^81a
^X1`[gUTX710P89``920`820`j2AdZ:@`::0c::0`9f8b920aYF3a921P900P8ah`Y5o`820P89`P@YR
P0100FaTX:2Tc<32013NhN8Noooo00?Ug=cUf=cUg=d01>GLg@03iMSLiMcMiMcM00;Ug=d0A>GKg>CH
f^GKg>GLgNGI`>;Df>F0/l20QMF00/05Hl00H<N1Q=2`RN2`X>FmY^BlX^FlZ>C0]>C4/>C8_>O:PNS8
_>S0/>R0/>[0[^2hX>2XX=bXU=bPP/6PV^BiZ>F0/>6gXn6`X^20Z>BhZ>2PP<2PP<:@0/R9L<20L864
H<28H820J<20J;EhG;1`@/:2H<R5N=22P=2PP=ZRP=20R=BNPLbIPL2@0<bAN<b<NL20L<B8L<R=MlRD
P8B2J800@8I4@8AX@KRTX/B0`13Ug=dXoooo000Voooo3MkQhP13g^7Pg^7Qg^7Rgn;RgMKDgkZcdi>9
cXQh_W=VP180eJZJf/Fc`X:`g/:^g/Jeg/>dg/RlglZmglR0gl^oglVlg/Fgg[jbg/:`fKVXgJbSejnN
d:RPfkNXg/:bg/B`fkj/fkZ[gL6`gKb^f[:Sd:29aiN3`8]j^8Qh]hId^8Ue/89`_8Ye/h5[/0ASaI62
bIj<eJRHe:^IejfJ`Z:5cZ6>bJ2;b9B0aYF2aHn0`900_hek`I1na860`X]dbi5fR89TT7=Y^kble<72
013NhN8Noooo3NGLg@13iMcLiM_LiMcMiMgMiM3?i[J]`8:2eX=a`fmNS0AHfjJDg/:^iKZYiKfXiL:_
iKjPiLBfiLFgi/Jhi/JiiLBfiL6aiKV/iKfZaKBRhjNLgZZGgJ:Hh[:Qi;f/iL2Rh[VUh[FUhX2[i;NX
hJjLeJ22cI=laXMb_HA`_H=/_hE]_89[`XI]^GeRP05:bhajciZ4f:R@fZRBgJZCd828e9f7cib4`900
c95kbh]h`X1`aHUcb8afb820bHM/dHm]U0iSU6mQa[Jc`LcA013Ug=dXoooo000Voooo00?Nh^;NhN;N
hN802=kQhP15g^7Qgn;Sh>CTgn;Rgn7Qg^34hL_5hK^_`YB4chMf_GAUQA01eJ^KfL6^`<2ag/:aglVj
glBhh<RkglVlg/2ig<Fffl>df82]f[NZekVYe;:QeZZMeZnNe;6SfkVZgL2bg/Bdg<2_g;f`gL2bgKf]
fkFUd:28aiN3_h]j]85a]H=a]HIb/X5d_Hag^HMaPX01biZ:cJ:@ejZHe:^If:jKd:>5cj6?bj2;`I23
a9B1a8ioPX5n_hal`8ml`8B0`8Qcbi1h`91mYWiab<C4fn3P013NhN8Noooo2nGLg@15iM_Li]gNi]oP
iMgMiMgLiM[2j<K0ikJZ`I0OeX=_`g1MR11LfjNDg[fXi;bZiKfZi/Fdi<2`i/Bei/Bfi<:ahl2`hKj^
h;RPhK:Sg[BSg:bLgZFEgJZGfZ2Lhk>Si;^/iH2PhkbYhkVYi;fPi;RWh[2NeHB0cI=kaHMb^81P^gmX
^h5Z^81/`hQ_`8=Y`8EXdYJ2dij9g:R@fZNBgZZDdX:8eIf8dI^4cI00bi1ibXYg`8UgaHQdaX]ebX4A
aXA[dHe``91`ZWYZdKjlh=c0013Ug=dXoooo000Voooo00?Nh^;NhN;NhN802=kQhP16g>3Qh>?Ph^KW
hN3T`>7Qg<30`ZbB`;:Q`801a89b/GQVP008e:bId;RPg<2`g/:bh<^0gl2lh<2jglFhg<2`fKfZe;RX
d;2PeJ62cZ22`:RLcZVFeJfId;20f[RXgKj`g/2`g/6ag/2`g/2dgKj]g;RQ`8R0aiJ2_Xaj/85`]81/
/81PYX1d_Heh`85h`H00d:2Ad:BAe:2@d:RDd:ZHd:20`:20cIf:`920`Y80`8em_HQl_hQl_8ik`820
/0AQP0QUP800S842d<30`>3Pgn7R3mkQhQkoool00nGMgNGLgNGLg@08iMcM04GTfmcVg]oWh>;Vh=oU
gMcT`83PZHGRY870Q2C20VR1M5f8403HZ9CN/87P_:_U_ZgVa[ST`;3W`[CV`;3Q^JSQ^:?L/:;JXH3L
Z9SDXYS@X9C@Y8kLZ9CHZ9SR]:CT^J_TP:3TP:gT_:;U_:3T^JOR]:3DP83<TW[4R7:`162jO6B`O62d
P6c0RG32RG30P03IQ8WAX8cHX83AXX3LXY3HP83DW87CVH38P7S8SWS0RGC1P7C5R7C0RW?0P1200672
0FS2P031QG30Ph7Pb<T04>GLgBSoool002Koool<g^7R04CNhN7Nh>;Oh^?NhN;HW8WAVXW@YI6:PA:b
N6VWLV62807H/j7I^ZKJ`;;O`[KOakcN`;SOaKSOa;KN`[3N`ZoI_:[H^JKK]:?G/J7@Y8CE/IcH[I_G
/:3K`[3N`[CN`;CPaKGPa;SN`;CN`:gK^JS4R8O5Th2nS7^bPFNePVnbPW6`QWJlSG[2TGo9P8;@YYC?
Y9?@XX?=Y97?YI?>Phc=W8_:VXS1T831TGo0SWjmRgfnS7fmSWb4ThB]N6NdMfN4P0KATh;E]jg0`<0@
g^7R7_ooo`cUg=d0A>GLg>GLgNGMg^GLgN6@QMJFPMRORL0P0[QdH:e_F80G0=j_V^2eWn6jZ>Fn/>G3
]^G2]>G0/^Fo/>FlZ>FmZ=nhXl2dX>:`WMf/V]jPV=^]UMjYU=bQVN:nZNFm[NF0[^K0[nK0/^BlX>Bl
Y^:dXM244<b?N<B8LkP4Ik]nIkQoJ;F3Kl:9L/R=Mm2HP=JRSMJPS=21R=BPR]JPS=BJQ=>HPm2FP<V0
NLN=N<J:M/67MLB8ML>:M<2:3K=dG[]cGhR80=Z>N^2aY^3Hf13Ug=dXoooo000Voooo00?Nh>7NhN;N
hN802=kQhP16h>?Sg=kOfM[Kg=oPg>7Se822`8Qf`91lX@@0VVULU6MHRR@4f[VVg;j/g<2`g/:fg<:f
g<Bfg<>fg/>d`LFdiLVfgl6^hL2Qi;bZhkZWh8:UgkRTfZjKf;6Pg/NcglJfg/BdglBbglBfg/2cg/2/
fKFU`8R6`Xil_HYk]81U]hEb]HIc/8Ia^haj_Hmn`928b9n?bJ2?bH20bj6>aib<b9R8bIN6aIN5`Y21
`I60`91o_hai_Hem_XenPIB0YW5P/75N/H00c8ilc:6Af<2Qg^7Q3mkQhQkoool00nGKg>GLgNGLg@08
iMcM04KVg]kSfMWRe=GUem_Uf]k4PhG6Q6g9Rg:20E:OIE:IHe2080cQ]9oS^JKQ^j[U_K3S_JoTP;3R
_k3T_ZkV`:3ZaK3U_:SP_JCZ]jCY]YoTPH[R]YoQZYCPZX3Qa:cT`ZoTP:3V_jcV_k3U_:3T_:KP/IkB
Q139RWC3QW>i16FlPFZjPf^hP671R7;3RgK8T83>VhS@VhO@V83AW8O>V8G0T83?Tgk<Tgg8P7[7SGS6
S7O5R773RGG4RGK1T8:/KENgK5J1P6SDRGCFW8WTVISUg=`?iMcM:?ooo`009_ooo`04g]o0g^7Rg^7Q
g^7Q1mkQhP16hNCTf=cLd=CDf=WLg=g2b800X75PR6500T1004Q004Q7P20Fg8:Xg/2bg82`g/6af[b[
f82Pd82Sf82Q`8BPb<6b`82Ph82PhH2ZhkRP`8:1a[:PdJR@`820f8FQfl6U`<2`g/2Pg/2`g/:`g/2/
d::2`824P89`^X1h/81P/8Me/8Qd/81`^Xaj^8am]800P9>1`9V2P920b9b:P962`9B4a9>0`9F2`920
`961P921P85h^8al_hf0^920P6UHXV94X010P0APP@QD`820g^7Q3mkQhQkoool01>GJf^GLgNGLg>GL
g0OUg=d0A^3O`>;Hf<30`>C@f>CFfL200:9UEYEPA81020E510121X000>2hXnBm[>2hZ>Fm[>6aX>2h
X=biZN2dXL20X>F8Y>2fX^20X>RdX>6dP>20P>:YQ/6PPL2UP=Z2X>24Y^20X>BlZ>Fl[>FmX>FlYMbX
V=203<:2H<20L800H[b3KKb4J820H<28L[j9MH20L<630/6D0/2A0<jHP<F0N/R@O<R?N<JAN/20N<J=
N<B>NLB9L<28M<F9N82@P:9U@:1RA;1P@8T0BX46A<206>GKg0oUg=dXoooo000Voooo00?Ngn3NhN;N
hN802=kQhP15gn7Rgn;Rgn3RhNCUgmWF`840Y79RPdm1H04`F3`hHDE0D0P@g/B`glBffH2Pg/:bg;n^
g82Pd[VYdk:Qb:^3aZNHb:NGa:6HbJBGa9jBQ9>8aYN:aYb;bX>;bZJBd[>NfX2Pg/6_g/6bg/:agl6]
eZjO`8F1_8Ia^8=d/81Y/X9`/X9_]8Qf_Xml_iB1`920aYN6a9^8`9R3bij;a9F6`9Z0bIR6`iZ8`9N4
_i62_I>0_81h^Xek_hj3^9B0VV]JWf9;X61@[VQF/ViDa85Q013NhN8Noooo00?Uf]_Ug=gUg=d02NGL
g@14iMgMiMcLi]oPiMC@d8@1ZViJR4`gH00PG3P^ID8gDP02iKnYiKn_h;RXiKf/hkZWh;VPfKFRfZjJ
e::Ccj6@dJ:?`j2@d9n?biZ:`i:2cI>2cIR3dIJ0dJ:;fJjGhKRRi;bYi;b/iKf[iKbVg:ZHaX0:`X9Y
_Wm/^7aP^7iW^7mWP81Va8]daI1ja8ihc9=obYN0bY20dIZ4bY5nc9J0d9AobIJ0`Y=maHej`hmh`8Q`
`8UdaHYkP90:X6MAYEi2ZEQ0]6A?/fa<`H1@4>GLgBSoool002Koool00mkPhMkQh]kQhP08g^7R04OK
gMkSi^OYh_3Xk>cQdl[8RG:ZNV]]?cI2921<<c5H?c]30PSOaK;N`k?H_ZcO`[7PaK?LPZ3?]J?<Z9Jf
TX2TPWF^RgjC3@2VQW^INWN0H6:QM6NcRgf`P7:iRGO6Wh[D]J3N`K;N`K?N`[3O`JkF[io1PX2lQfnf
PG2RO6:/NfNZNVRbP@32Tgo9W8S2PX3BWh[;Wh[<WXc?X8c<W8_=X8c?Whk9XHk0U8:nTX:kTGfhSWRh
SG^nSh>hTXBJKenHGT^0DD2XFDRbK5C0PV3Oh^;OhN803]kQhQkoool00nGKg>GLgNGLg@08iMcM04KR
f=WYhN?Xh>3XkNOTd/?APV>`MV9c>b]08@=@;bML?3592P3U`:cU_ZgP^:CU_Z_V`JgQ^Z3F/9cCXhk0
Q@2]Nf^fQgBT202^PG:PMFn8HD2[KUbiQgF00F33PW3@V8;2/8SU_JcU_:gU_:cV_JSMZiS5P@S2PfNl
OVR`N4:bMenaMF20PFS8SgS?VH34P03IVh7@Vh?@V8CEWHGBV8CAW8GEVhO?WHO4T0C4SW[1SGJ2RW2n
RG?3S7_0T0FOJeNMFd:UD3f^ET2eJTc6PU3VgMd?iMcM:?ooo`009_ooo`04g^3Rg^7Rg^;Rg^;R1mkQ
hP17f=SKiNWZhO3`b<S2h8Z[P000/8@0D2@/2000028X@C0b@000glBcg<2Pf;RPgL2/hlZhg82Rc[6N
aj2=X01P0T10QV56040014Q0B41<2000IA00P75PP410XDi@]81Td:R1gl:eg/:eg/2`gl:`e[2P`H0B
_HQ//01XX71PXVAIPV1GY0@0aY63`J68a800b822aYF1`821`824`828`::8`:6@c:BAR9B4^920/Hei
/8aj]XQj_960_902TW9PP5Q8T440YThl/6I2`X1R`>?Sgn7R00SNhN800mkQhMkQh]kQhP03g^7R7_oo
o`;Ug=d2iMgM1nGLg@16gmCFj^CVk?3PhM34hX^T`P80P81U@BTQ0000@200AC0X@00HiX2]h;VPh;20
i;VQjLJbi;^Te:bGcY^5Y0103510TFIF040024E8ET14000000PQPVI8Q400XD96QP5T`J21iKjQiKfQ
iH2Pi;fZgJbJ`803`XAU^7QPX710Y61@XV9@P01Pc940dX24`800`YEg`i00`900aYD4d9B1d820d869
dJ28a904`8ah_HUa^8Qb_81b`8ei`840VfmHQ512P4P`Z4T`P61@b81Ri]kN2NGLg@03iMcLiMcMiMcM
00?Ug=dXoooo000Voooo0]kQhP;NhN48g^7R04CQiNG:c<bf[J[K/Ic28AC5ThE@<2l83@@e8RE5;be2
103N`K7K_Z_I^Z3K^jOO`k;M`:3E]jC>ZiR/Q@2<IERLMVX4D41kH5MNBE0P1R9X?S6ELFJB@T2VHU:i
PVk@XX3O`kGOaKWNb;cN`[;G]:;0PA>mQffcOVJPL66PKUREHU6A4071VHZiTX6RP72YOVf/OFfTQ7Fc
R7RbRGViT02mUXK2VXF0T0:iSgbfRgRbS7^eRgZjSgnfP02>Jef1E4V8C3j]FDRlOV^PPF@@g^7R7_oo
o`cUg=d0A>OPhL30`LfRWN2^ULP>1<^?O5L[90`923TP6TT/8d@07>FmZ^:jY>2aX>6fX>Fo[>BiX=^c
WMFVTH20J99PCj5cHAA09h1LCfA6Ab8146/k:9Y]GXA46JiMBL5mIMJPRNFn[nG0/nG0/>Fn[=f_VlV0
1<>3IKQjGZYaF:IZCiiKBZ0<F<REPkn>N[00JK5hI;=iI;61I;Z4L;R5LL60LL>BO/RFOL:0L[n;MKb7
L;R8Lk^7L/2;MhB8L9AWE8IA?h18=KAE?/EiH/J0C13Ug=dXoooo000Voooo00CNh>3NhN;Nh>3Nh>07
g^7R04OVjn[Ifm^PT965LVoAXHc08P3:U8=F=SHR620_8290:RY140CM_jgJ_J[H_JSG]J7G^:KL_ZcL
`:kI^j_1X92_RW^gTXB<30:BMFUiGem=60QiCd:MMfZPH42cLf71SGS@XH7N`[;Nak_Nc<;M`[;G]J;2
PH2nQVncOVJRN62QKeZCGTf00EJgUhfKOG<6@T9gF529GUB9J4jHLVN@Kf>QNf2VPg>bRWBaRGJhS7Vf
RWNbSGZeRgZiS7f/P7:3GU=jCdJ0BP:fK5_0QG2LFdWMgn3NhN403]kQhQkoool01>GKfnGLgNGKg>GK
g0OUg=d0AncViMoGeHZ0RJ5RGMbIQM8I0]:?Ne`a;2HD4c8N64<W84`20NBjYn2iXl2hXMjaV]ncX>>h
Y>:lZ>2gY<R:P;V4LKj>Ni88FIUaH81JE`@D081;=j=cHj=TCKa]F<V8L=JQR^Fm[>G2]NG0_>Bn[=f`
VlR42<B2IkUjGJadF:M[DI]GAY00AL2BQJ=hJaQ5@7aDBXmJBX9Q@im]GYI[FZ9bAZeoJ[V5Jk^5KKj8
LKb6KkR9L[Z7L[n8MH:0HXUJB7m<?818=;mWDlN1J<1A@>CJfnGLg00>iMcM:?ooo`009_ooo`04g]cN
g^7Rg]o0g]o01mkQhP17j>;PP8Z820020`P4P@ITP8P0Q`i/GCdl820P:1hP>B@VD1P0g;RRf;fYf;bX
d:2H`:BCd[2Ph/Nah<20`<:0aH6Pa86?P8B0[8T:T0Q`0018P6I0Z01_X01X`8T1`X:0d:R4g/:^g/Rl
gl30fL2Re[BPa820_XA`/gmVZ7A0XW50T5a8P018ZY2>065P400002@P@00`00P2KTe2D4I00411PF50
Pg10X0AP]XQa]XUh/8ah]HQj^8UkP0Q8ID05HD00I4U0`85``XQ`T41@g=kOg^3Q00KNhN800mkPh]kQ
h]kRhP05g^7R7_ooo`04iMSHiMcMiM[JiM[J1nGLg@17l>[Y`8B0000090d4T05AaP1``0QRH3Tc<000
:A`D?20IEQ08hkFQgkRR`;:PfJRDd8N4`:60j<:`jLBdhH20dHZ@b:V8P808Q801XP1PP410R61<Y7QX
P09P`81Zd88:d:F0iKfXiLBfiLZ0h[bYgK2JbH0@a81X^7]MX71FZ6eEV510R500/8b524AD00P0028P
A00P000804Q0H4<40402PV55X6AAX010_8AY_8EP^8Q`^XQb_XEbP050JT0`HT0c04Pd`PaP`HEXX4I4
hmWJi=_L00SUg=d00nGMgNGLgNGLg@03iMcM:?ooo`009_ooo`04g]gNg^7Rg]oPg]oP1mkQhP15gMoP
ThJ480P88P00R5U?X7ATUfMKDcXk<B@R9ahP=b8UF244g;VWf[jZfH2Ye;6Nbj>BdZ60f[b_hLJiiLbl
j/bjgkf/`:J@_IV7]XYhXX1QYGMW[G]X/@aXcYf5e:ZEd:R0g/:`g/Zmg/g0f[j/e[:O`XV0_XUh/WiY
ZG94YgEPW6MBP059/IB<Q6YV:0@0>B/^F3TeA18@Jdi9GDDo05I1R6YHWg9LX01T]XUd]HYh/Hil]8ak
^Hem:`1BFc`iG3hhA40n`iF3_7eWXf5600;NhN4>g^7R7_ooo`04iMSIiMcMiM[KiM[K1nGLg@15i=[K
YWaf:00@5PH0VD]4X69LWf1CECPc<20P:Q`E>b0JPAD=hkFPh;VS`[RPfjbGdij;fZR@hKNXj<:cjLRa
k/VeiKRWdJ62aIAn_hE^X7eP[G9M/gMPP05@e9UnfJN>f:2@iKfZiLJgiLRkhKVUgJjHb8F0a8E`^7YQ
/7=D[G5GY65:R5e0^Y24S6IN000@?2TWG3H/D102Kd]1H48f1E8;SFI@Y6iCZ@12_8E[^hI`^HYd^XQc
_hUeP5Q8GSX`H3/^DP@`ai=j`WUPZ61100;Ug=`>iMcM:?ooo`009_ooo`04g]gNg^7Rg^3Qg^3Q1mkQ
hP17blO;KUUH214@9`P9Hc/fM4Q7KDU4@Blb8B0X9ahP>28UFR05gKZXg;n[f[jZekJTcZRGcZ:@cJZO
e;:Td;JXeKNWbjZKPiF2/8Yj[Gi/XGQPX6mMYW5MYP9Pb9R2dJRDdjR0gl:dglZmg/>if;ZWeZnM`8F0
_Xil/Ge[[7IMZ7IOYG9JX05I^iN9Xh1e4S<ZFTA2K4a4H4<<M5I?K4m7QF1@UgESZG]V/81P]hYe]8ai
/H1m/Xak^Y5o1TQ1DCThDCTeA00`^i1o/f]IY611hNGUgn;S00KNhN800mkQh=kQh]kPh@05g^7R7_oo
o`04iMSIiMcMiM_LiM_L1nGLg@17d/76OU1840`580/5KS8/P1@4Ld@lA2dY<0H0:Q`F>b0JP1@=i;FQ
hk^Uh;ZTg[:MeZ:?e:61eJFHg:fLek2Rfk>QdZFD`Y01]hIa]7YSZ7A0YfYDZfeE/Fi5cYAjeZF=f:2B
i[j]iLFgiL:dgkJQgJ^Fb820a8Yd]WUS/G1E[W9F[6eAZ@EB`Y>2ZG]^630SGT4kLTPkH402N5=7L4do
P4A0W79K[gMM]0AP_HI]^XQa^HQe^HQc_hih840PE3L_ECH[B00Q_hie^VMA/Da0j>3Pi]gN00KUg=d0
0nGLg>GLgNGKg005iMcM:?ooo`009_ooo`05g]kNg^7Pg^3Rg^3Rg^7P00KNhN801:RQY0@@1@040381
2P800000@@8430h0204002P083PP8U0@0=jhZ=o1[=R0Z=Z0X=>VQ/RPT82BR8NBPZV8P:b=PJB42:01
H81aJ81R@IQP@9QVEImYEJ1T@8:@O/bVTmBXP=o3/Mk0^=b0X=JdPmNXV/20P82@P;00I:1`@:1dG:aj
H;20H<2@0<2EPX00F81RB85PA`10@89R@89@@800@:21LKB1LKR0L;R<N;>>N[6@0;6=N[22N@0:00Pb
<0@`8B000:04I:582:16@^?Win7Ti@06g^7R00?Nh>3NhN;N`>001MkQhQkoool01NGIf>GLg>GLgNGL
gNGLg006iMcM04NcR:8@10@001010Q8440P000040@@P01@R410Z710181a000WT]J;T_:KP^:CP^:3J
X9O@P8S0QH36R0:0P0R3R0R/P`2P0626LD>PJU20H520HT^TIDfQH530S7K@X8SHX83V_[7U`;;PP:CL
XYSMX932P834Q7ReN6BPH4:ZLE2cLeV00631Q734T7b00528ET20E4l0@420H524C4V0H42XP662P664
P62nR72iRW:hS72`R7:dPG000012<2i08BDX0@2a0F2T@@2T@P3Yh^;Wgn001^GLg@03iMSLiMcMiM[K
00GUg=dXoooo000Voooo00GNgn3Nh>3NhN;NhN;Nh>001]kQhP17[J6]<Q4@;@P9>RX^7@`@2P@050`E
5a<J0A80;R8T@Rh_D0PAfkNUg[jYf;n[glBafkb]`:RH`9^?`IN7[8b0[8j5Z8^2ZHAeWWicYGU/X7=/
XGATZ7IU/@1/a9R7cZZHf;6Qgl:hgL:ef;VYe[6Nej^J`:BA`i^9]XIkY018X79KYGIPX@9X]85[aI9k
]8]d/8=`Yh5_P6a6XgiZYge]YX1a^Hil^XYi/X1h^Hil]8ik/900/hmkWgm]9@80=R`d=B/^:0@0[7MU
WdPkTD14gn7Rgn;R00KNhN800mkPh=kQh]kOh005g^7R7_ooo`05iM[KiMSLiMcMiMcMiMSL00KUg=d0
Ak>LYbXD30@84T8U81`=2`P91aD<2a/A420@1S8O6DH[9EH00>:bW^BiXn:jY>K0Zn:gY]2PTLNFR<VB
OkB8N;B9O;26NK01I:EiJZaeHjQ`I:Y^FZmaFkQhI<^COmFUTL2XQ>Fn/^Bm[n:aX]b]UmfWTlF1R<VG
PKb2LjQ/@JI]DZ]bEkEj@[UnH/^>LK>7I;QoIJamIhQRE:QjHZaiIKB1JKn:ML26LH28L;n:M;V:Lkb<
L;R;LjEkI2X46CXY:STX8b`01k9cGJ=6<9]>@>GLgNGMg@06iMcM00?Uf=WUg=gUf]/01NGLgBSoool0
02Koool01MkPhMkPh=kPhMkPhMkPh002g^7R04_NhN3NhN;NhN;NhN:f[;Pl71/T0P<a92LP4aLP300C
3ADG4QT34`0c92I8=3E8003G/Z3J^JGIP:SOa;3M`;;E/:S<[J3;Z9VjW92kWY>fVi>jV8:]TXRgSX:V
P8B`RgjgRgg0U8C=YYGB/Z3LP:7M`KCL_[3J^:3F/9gG[I_2XY38WHfmSX>P062JKU^GJ5RIK5RLKE^W
NFJR062/P6fYPFnR16V_Qg2_QgB`R76eR7RaQ7:aR72iSWbeS7^hSP2dT7Z9JE/082@_9C0`:2d<60^_
Lf6OCCfa907Hf=[Kg]h01]kQhP03g^3Pg^7Rg^3P00GNhN8Noooo00GUfmcUf=WUfmcUfmcUf=T00^GL
g@1;iMcLiMcMiMcMiMcM_JNb>1`D:00A=b4K8A8?80X45@`;6Pl>8106=R8KC34[@aD0gJjIhKFOh[RR
i[nZi;^/g;:Pe:NIdj:A`929`iR;_iJ:`Y:0]Xeo`8UiPH9h^hAd`HEdbX1le:6=fJfIh[6Ri;b^hkVY
h;:PgJbFgJVDd::0cYV5`hYkP0A6X6UBWVA?XF=BXVUB[WAKZP15]G]R[geVX01P]H=X]H=]/XAY^hA`
]h1Z/HAP_X]d^hQc_XY`^HecSfAA4R0;<R8U=2DS41D0]VmIY4Tc]200g];EhmSH00KUg=d00nGHfNGL
gNGKf`05iMcM:?ooo`009_ooo`05g^3Rg/7Pg]o0g]o0g/7P00;NhN80BmkQh=kQh]kQh]kQh<68aDT^
;B01020H6R068202800B61XA620H03@P:48k>b401<2UTMB`P=Z0Y=k0[<31/L30P<31PL2:[LR0Y<V1
Y<J1X<R0XL2ZX<ZSTH6RT<2PT<2SR<20T=J0X=>0Z<30/=R0X=ZbZ=R`Y]N`W]NQW<2PP<20T<20PX00
091PAXQLD01@@09DC090@@E2@H9XAZ1dHZ60L;R8LK68LJ20L:T0HHIdHJ00H;R>N;2:N;R80::4L54@
22P0824J:2PT;1000:MRDYE@@PP00<:9`]SJfP06g^7R00?Nh>3NhN;Nh>401MkQhQkoool01NGLgNGH
fNGJf^GJf^GHf@02iMcM04_Ug=cUg=gUg=gUg=g0Q<10:24`010P4Q4S018P01084@<140lP410k91eB
>30104C@X83L[9;P]83U_:KTP;3PR;3PR:W6QZK0Z8c0[8k@Z9;2Z831X8W0X8;0X832TH3BT8K0X874
/8W1]:3TP:3Q^Z;P/J7P/X3LZi3MZICDX83@V8W2Th201022I52CD4V0D421D449B@B4@T2PHEBVL4:`
P6RnP6RaP66P06RUM62TL4:P062nRW2lQWB0P72WPV1P22h/110X600P828T002WB424CSP6@dS1P8WP
e=@01^GLg@03iMSHiMcMiMSL00GUg=dXoooo000Voooo00GNh^;Nh>3Ngn3Ngn3Nh>001]kQhP17e]GN
GdE30A0R9QXL<RTZ<24T:QlQ81HK8`03?b/[E491:P14b::>e[2MgH:Vg/6]h<Fhh<k2im?5i<o3`<Zm
hLZmg/c3h<c0fL[3h<Roe<S0e/JogL>j`<R0hLFfgLBb`<B`f[jZf[RWf;NTf;2Oek6Mdj20eJJIdJRH
Q8:0YgicV6aTP69HPUiDMEE:P5=>T6QKUFaOY0E][X1YYh1_X7QXYWMWVg=SX@5Q^8ik^8]m^8QfVWAS
C30_81T0:A/V;2</0@44TE55Q4ho0e10][2egn;S00KNhN800mkPh=kQh]kQhP05g^7R7_ooo`05iMgM
iMSIiM[KiM[KiMSI00KUg=d0Amc@fFM1>0P<02LI4cHV7C@P0BhK5R@C42XI4D<Y8EPo=b<0A<jMQ]b/
U^:fR>FlY^K0/NW8_>g?_nW;_NC6/NO6]nC7_N38_=o6_NS4^L;3^mg1^NBn]>G0/>O0/>?0[>G0/>6i
Y>6cXL6bPMj/V=f]U]ZXT]^QT]RSTI:92;1iJJ9UFI1L@8]HBGa@@85B@9QSDIeXE:80I;EkH:ilIZQ`
H:acGZ5_FJ5eH;j:Lkj7MH:2Ij1`FTl]9B@D4R/I72lQ8@X069U:?Xa8=P51@Kf[[^KMgP06iMcM00?U
f=cUg=gUg=d01NGLgBSoool002Koool00mkRh]kPh=kPh002g^3P0]kQhP1<g^3Rg^7Rg^7Rg^7PfMSQ
GdA2@2<P;b4R;bHW:24R;B0R8QLK9`8P@Rd]E4908P11`ib8f;2M`8:Vg/:^glBdh<R0i<k1h/g1h<b3
hLc0h=38hL70gM39hLo6`<32g<g5glVnh<b4h<Fgg/FdgL>`f[jYfkZXdk2Rf;6Oe[6MeJ20eZ^MeJfL
`8R@^Y23/8IkX7Q^UW9URVMKQ61DSVEJRfEIV6EQWW1OVg9SUVEPYGMWW7ATX01T]hij^8am]HQeQ61C
@RPZ8AT0;AhV;R@[420PLc/eKT0fB408ZJ:Vinc]g^7P1MkQhP03g^7Pg^7Rg^7R00GNhN8Noooo00GU
g=gUf=cUfm_Ufm_Uf=`01NGLg@19iMcLg]CMID0gA20Q<AlH<b<K<0HH<AdG9A@A8`0DABXSF3lf;511
bIR1gJbFi;JPiKfXi[n^j<Jhj/Zkj<Vki/RhilRji/_2h<S1hlc4il[1h<[1h/RoiLBhi/Rhil2ai<2^
i;j/h;VShKFR`K60gZfHgJbFg:RAgJNFfjVEb8N0`h]j^WmbX7=TWfaKTF9@Q5a8UV1@TV1>QV1GYFaE
X6iJQ61FZg=NXg5KZ7UT_HYb_XUePH1URU]9ABHP91@B<1`L<B4P8P`8NSH_Lc`]C480[ifOk>OZiMcL
00GUg=d00nGLg>GLgNGLg@05iMcM:?ooo`009_ooo`05g^7Pg^3Rg^3Pg^3Pg^3R00;NhN80C=kPh]kQ
h]kQh=kPh<?4b5P0>440<04X:BdP828082lP8R@H7200840/;4<k>@12@;200=6VT/20X=k2/=k0X=c0
/=_1/=c0^=k:Q=g=`=oBb]g2`<3@c=gBb<;@`<7@`=o8_]k8P=g2]]k4]=R1X=RmZMblZ]B`P=RbW]JP
W=J]W=N`X=2aW]2PP<ZSTLRPPX:0P8:92J4@08P2@8AP@HAPD8Q0D8U0DH]PDhQP@Z1iJ:5hJ:60L;N=
NK:<N:00H4P803PQ9R8L034P9S0P:0003101140P9@0408PAPNCPh=kQh0gNhN8Noooo00CUg=cUg=gU
g=cUg=`3iMcM02CUg=cUg=gUg=cUf=cA`<10>2A002048@@P7QTX010b7QPQ418P01Q4:R1B>2<0@0:2
P73DXhCT/83U_ZST_:;PP:3RP:CT`;;T`83Tb;STcLCTb8CUc/OTc<CP`<3PbL;Tak7T`[3T_:3UP:h2
h;RR02KR^:30Y93O[IOMZYGLZ9CMZY[N[930X930S8S=TH[0P026P02Z2F20H42DH528G4Z0@425FTV@
@D^0@4R/LD:UL4B0062mRG6hRG22041B12Pk81`Y618d81Pc81d0000H005190@@00R020SYh>3Tg=`=
iMcM:?ooo`009_ooo`05g^7Qg^3Rg^;Rg^;Rg^3R00CNhN80BMkPhMkQh[>Z[UHj=T1404Lc<c4S9BP2
8BhO8BXL7b4483dZ:dXf=015@J5lKL:IQ]R`RMk2[mk1[Mb1/=Zo/mc5^=k0Q]g=a=oBb]g2a>3DcMgC
c<;Dc>7Cb]o;_Mc8P=g2]Mk3/]R0Z=VmZ=^mZM:aPMRaWMN^VmJPV]JcXMRaWMR`X=ncX=njY=FPPL^V
T/BKRJ24M:9fK9=`I91QF99VG9AXFh9QAZf2Kjf2M;F0N;N=N;29Mh1XBdP];3@R9BP18S4T9RhQ9P`1
22XC634M80PL87IZJ/g9b@0>g^7R7_ooo`04iMcLiMcMiMgMiMgM1NGLg@19iM_LiMcM^jFVF3P]A48e
Bc0Y=24L<00D<AdG;1XE:08I@BLPCS<Z040@YgQUb9En`ZR2iKfYi;bVhkR/hKZ]hl2bi<60i<RmiLg4
i<R6ilo8i<k6h<30j<k4iLNgiL:bi;f_iKj/hKVRh;RRh[RR`:2DgjfFgJZDg:VDgJjJgjfFa:2Hhk2J
hKRN`::Acj>;bYR2[H1UZW5RVf]IV652VF9BVVEBR61E/giW]7m[PH1`_HUa]HI_QV52Bb/R>1lJ;A`H
=28K<AlL00@2:a@B<a`F01XDP6EOeLC300kUg=dXoooo000Voooo00GNhN7Nh>;Nh^;Nh^;Nh>800]kQ
hP1<g^3Pg^7Rg^3Pg^3QThR8ECXeF402BSLf>2T[<24S;1hP;AhP808Q=bHWA30_E1H8SVaP[HIebJ61
g/6]gl:^g<2dg<6egLNkg/26g/k5gm79g]32h=C=g]?<`M38h=?<gl^mg/Vmg/>fgL:`fH6YfKbXfKZV
dK20f:nLejjKd:2Ie[6NejjKdZnMfZnLfK:Md:2Dc:RCaij<P921]8MiZX=dX7QXYWU/YgY[Z01Q/hQe
]8Uj]HQh^8ahZhAb5e10?RPX<B4S:04P;24U:QhU40P@8Q@I9aXN0A0EI5EC[:6O`>3R3MkQhQkoool7
iMcM02WUf=cUg=gUfm_Ug=bMPgiH>2]N@31>=2`k9b4f1@4_71D`71HX71Pk8ae8;BEJ4`BCJENdPVc0
XHcU_:OU_JST_:kS_:oT`kCU`X3UbKoVc<?TbL7WclOTc/KPcL?WclKVa[OUa;;T_joT_J[R^:CO^:7P
]Io0[93NZiD00]jYU00QgJbGgZZD`:Z@gjbFgK2GeJ66dJB=cIZ5PXAi^h=a/Gi[[G1P[GES[GIR/7AP
^HA]^XEbPHA`_HQ`/81Z7453@BHN=1lH;A`I;alJ;A`K000291@@:aLC0102KE17]IbGi=cL00gUg=dX
oooo000Voooo00?NhN;NhN3NhN000]kQh0;NhN808mk0`]kQh]kOh=kPh510@U0j=51004`h>0H`<00P
82XL7c0P8R00028P83/S8T0006QA@81T@H200=bkX]o2/<30/=k4/Mk:_=k8P=o?a=k>aMk0`=kAb=o@
b]g0P=kBc=o8_Mo8_=k5]P02g82/02OH^:K@]:3@X9SFZISG[9S@[9SDZY;DXi30XI30X937Q8;0P830
XH;6W8W0P8;2P831Q82<P02<S0Z:S0V0PP2hPW^jP82bR7R`P7:0L6<0000`92L]8B8P02@P6R8P6200
504N61X241d000100Rb0J670hN003MkQhQkoool00nGLgNGLg>GLg002iMcL0^GLg@1;iMSHiMcMiM[K
iMWHFT0HD3LZD00`D3<R@B@U0202;AXD<Q`@81PD<P0A0R00@P0P04Q1SF18`8P0h;:Pi[jZi82`i86a
iLB`iL2`iL[0iLR1i<S0i<c4iLc4hL20i<c7i<BgiLB`iL2`h[RVh;2Pg[JPg::Hg:RDg:6AgZ2BgZR@
f:6@f::0d820d8B8a8:0`820cH22cIR1`820a809aX48`8P0`8P2`HP0P802PXY``8QhP81`/X9[R6Q2
0000<R8L<1lG:1PJ81<A814A010@810@8Q@@8000Bc0RP6Q@00kUg=dXoooo000Voooo00GNhN;NhN3N
hN7NhN7NhN000]kQhP1<g/32g^7Rg^3Pg^3PDC`iDS/fD452DT0nBc`m1b8T;QlR=24S;000<1lR>BDV
52PXI4Y5OE]>Q80@fKNSg/2]`<2eh<JjglVlg/V0glo6g/k5gl;1gM7:gm7;gL2:gM;<g/VmglVlglFg
g;n^gX2/f;VUe[>PeZbKeJVGeZZGeZbHe:VEdZFDc:22ain<a9R6`YR0aIn<aYb9`:20djF@e:JBd:2?
cin<cIn;`IR0_I>1_Y61/8=`YWe]RFEH@@P1;R<U:b4S8a/T71LO6aDO0Q@07A/N71HL8AT0?bPSQgA_
`>7P3MkQhQkoool00nGLgNGLg>GLg002iMcL0^GLg@1;iMSIiMcMiM_KiMSIDCXbEcP[ES``ESdeCcTb
@R0P<QdG>1hH<1XD<adG?2<L@2P>JDLlPUM5TX08h;>LiK^Wi[nQil:di/BfiLB`iL[0iLVoi<R6i<c5
i/c5hLB0i<g6iLBgiLFfiL6ah[^WiK>PgkBNgJjIgJ6DfjB?g:J@gJRBfjF>fJ6=dYb2ciZ4c9=nb9<0
c9Z4c9R1aX21f:::f:><e:29dib6dYb4aI04`hmja8ej]8=PZgYUSV5?A00Q<R0J;QlH91TH7a@D7Q8E
118@81PB7a<A91PD?RLLS75W00kUg=dXoooo000Voooo1mkQhP1<g/72g^7Rg^3Qg^3PDS`iDS`hDD90
ED91Ccm0@BP`=B@V=R4S;P01<b4T>BDW4BPXHTM4N5M;QX04e[:Nfk^X`<:ah<JiglJjglRjglo6g/o6
gl;2g];;gm?<g<30g];;g/Vmg/VlglFhgL2_g[b/fKNSek>QeJVJdjNEdjREeJVHe:RDdJBCc:60b9n<
aYV8`9Z8aYf;aYb9a829cIn;c9n<bYb9bIV6aiZ5Q9B0^i:0^helZ81UV7=UN5I<52TX:R0T:B4T81TR
6A@L618L618J6aTN6QDJ8QX1?BDPX9:@`>3R3MkQhQkoool7iMcM04cUf=SUg=gUfmcUfmQC>S5F>Bi@
?S9I?cQB?3I5920i8A`i7aPa6a@f7QTl8ae08Q1WA3]mE4:45FCL[IOR]j7T_:[W`K?V`KCT`K3Ubl7U
b/7Vb/3TcLGUc/OTa87TcLGUa;OUa;KU`;7S_:WT/:GO/YgN[Y[LX93JXXkJY8kHY97KY8cGX8cBW83?
VXC=U83;UX3=VH?=Uh70V8;BW8CAVhG0VX3>UGo=UWk1T7W1SWW1RGB/16FMKeamDd=0910^7QT/7aXQ
5A4L4A4K4183410O5A8L4Q0T6QDj9A^XSXKTg=`=iMcM:?ooo`009_ooo`ONhN80C=k0h=kQh]kQh=c0
`EQ11U8n>5100UQ0@510@T0000@Y83PQ8B0083PR83PQ:1@0:657A75ABJ01HL2ST=2`P<20X>34^>30
]L30^=o@a]oAb=o@`]kBbmoDc/30`=k@b=k:_Mk8_=o0^=g1/Mb`X=VaPMRbX=2XV=2TT]2TTM2PU=2P
T]2TTl2PP<R0S<VIR<2LR<JHPLBHP<2@PHB6182508200;V7N;J0MK20L;::NZF0IH00H0Q3D4480@8P
82HN82HP90P@01P@61HA6Q0041P@61PD62@00D0X8iB@UmkQh0gNhN8Noooo1nGLg@1<iMSIiMcMiMcL
h=7HA08bESP`E00`G40jD04h@30R@2@P>20I<1`@>b4J02D2@2PPHD@kO5A1Q010d8J1`:2Ah;VPil2b
i[fQi<2`i/_0i/c2i/[0iLc4i<o8i<R0i<S0i<FgiL2fiKj`h;b[h;2Ph:2IgZjJf:2Bd:28d:2:f:20
f:28eZ2;dYb8d9R4`I:0`960c9D1b9@1`81i`X9dQX1c`81`QH=VQ8ATP81T^89b/`1TP0103D11B00U
@R00:1PG:A`K01@@6`0>6@l0600:710A618081PE@2XQaY20iMcL3NGLgBSoool002Koool7g^7R04cN
h>3NhN;Nh>7L`<1NB4IA@41B0P=H@dAFATM00@A8<S<n9bT`828o:BXo;2i0<2aUB4AkFe2@J4S6VHKD
[9SJPJ3Na;GN`KCOa;SNc/CNd<ONclKOd<ONd/[N`<KOc/?NbKcN`;[N`[KK_jkH/:3I/IgG/9k@ZIK@
YI;@Y97@Xi3BYY7@Y9;0XY3>X8k<WXg4W8S5UhG4UHFmSWniSGbdRWV`R7>hQGJeR7F`Q7B/QWFUNVN7
HT1]DDU?=30j:2XV7R4U7bH<5b0J4QXI51`A0A<G3aTM61dT121aGUgSi^ONhN0=g^7R7_ooo`OUg=d0
C>GHfNGLgNGKg>7Be6A4?5Dm=U00:Ea0>eY3?DP0<T`_:D4U7c@1648V848Z940Y86U5>h1HAiEQD/bE
OmZWTN2iX>Fo[nFl[NG0/^G9_nG;`NG:`>G;`^G=a>C:`>K9_NG4]^G2]>Fm/>:jZ>2`PMn/U]f[UmRU
P=NPR]JPR]23S=RRR]JPRmBNR=BLQm:JQ/6HPL^COLZAOL6:Mkn8M;^6L;f0Hkj1K[^4KKN0K;:2KJ]f
GhARDg9=@58a9`8Q0bPL5bTM6`lE41d@3a`A4A8:01T=3alF4b024GYID^WQhnCHg0gUg=dXoooo000V
oooo1mkQhP1<g/7Pg^7Rg]oPf/30FdM4D451A00bEd=3F4Q7B0P9BCDe@Bd_<B0S@2//@Bl`@C8aHdU2
OEeBR650_hmkdJJCfh2Xfl>bg<2bg<2fgL_2gLg4gLW0g/g3gLg5g/c0glZnglNkgLBhg/6cf;bYf;2T
f:nLeJbJd:2Ad:FAdJBB`Z:@d:F@d:BB`:20cj2?bij=`Yb8a9B3a9>2_Hl0^him]Xaj]8Qh_8Qh]hUg
XXIdYX1_WGAS2TADHdM1B2h/<R0X9QhR9AhU3@0Q7ADM7QPO2@0@50dG81`R0@P<UHN6i>SYg^7P3MkQ
hQkoool7iMcM04cUf=WUg=gUf]_PdM9P@c]E?CMA<B1K@3YLACi@13E=<R]5:R@`0AQ3:B95;2I5:2MX
ACV2FTV2DDS5Rg?FXXcQ^:3R_Z_S_:cP_K3Ta[cTb;kT`;cUb;gTbKoUb;cUaKSV`kGT`;7T_:gO]j?P
/9cOZYCKZ9?BX8cGXH[GX8[@PXWGX8WFWh_DW8SEVhOAVXG0V83:T7_:Sg_1RgS1RWFmQg:0P732Q72m
QFnaPVb/OFNRL5X@@4UWA3Q<;28i8P8Y71PX71XP5Q8P4Q8R5A@@0@0F2`dU61H22@:SPG_ZhnGUg=`=
iMcM:?ooo`009_ooo`ONhN80<mk0`]kQh]kNg][J`5]8@411@d0P8U50@U18AU10@4Pa<40b=30P800]
;4<`<4@`<4510GULD`14@:80H<BFQ=2`X]R0Z=_0/=R0/=c0^]c8P=c0P=k1^]c0^]c0P=k2/<31/Mg0
/=fmX=JaX=2dX=N/V=:PT]2PP=6VT=:PT/6PP<nRS]2RT<24P<2MSLZMR<2@Q<B@P<BAP002P92001Jj
PGb1R7S0RGR`RWVP062DL622H5AP@49@=S818R8P820V7b8V7R800200420R628:01@B31DQ7b@14A:A
TI32h>4>g^7R7_ooo`OUg=d07NGHf>GLgNGIf>3@dT9005Dn>40X854n>5Q4?40004de;4PR:C00648Z
8TH^840`:694=@9IBP10@;00B<:@1=b`P=jhXn2hZ^2h[>?1/>34^>30/>G0/002i<2`02cTPZ3VPK7T
P:3P^:;L/9S0XYSLXI3HX8_@P83GXXSHP8_EP83EWX3FWXSFP83DVH3@V83:T0K:S7[;SGS0S7S4P7S0
RGB6PG36P72nQW6P0620I5N3BDAP@01B<b1191dP000Y7A0X71PP41PS51@V6A00008@2P/Z6QP00036
RX;P`<4>iMcM:?ooo`009_ooo`ONhN80Bmk0`]kQh]kNgmcM`6]IEe51@T0a<U51@EE5A5Q8B4/l>TPg
>3TX:3`/;48a<D4`=EU5?VmFC`9:AYiaG[Z:N=:TP=^mYmo4/Mo2/Mk5]mo8_=o0^=o6^Mo5]mo0^=g0
[mk1]=b0[mbjZ]NeX=2`PMN[Um:TT<6PP=2TSM2QTLb3P<nPSLjPS/b0RLfJRLVKR<B@P<BBPLBAP86C
P/6EP[nAOKR<O;j;N[>7MHX0I8UTEWMFCE81>TH_;3@S92L092HO8BPO8R0081`F7ahH7a0161LC6R@J
7`TX8^?Sh]gOh00>g^7R7_ooo`OUg=d0BnGHfNGLgNGIf^7Bf6mFCUDn>40Y:5Dn>5U2>Ue404li<4dd
;S`P0ClZ8TH_9dT`:Ui1=7ACAP=21:=]E/66L=VPT^6hXNJoZnFl[>G0/NG4]^C1/^G2/nG1/NG1/n>l
Z>Bl[^2hZN:fY=faVMfPT]jWT=VPRMJ0PMJPQ]JMRM6KP=FLQMBLQmBDP]>FP/nFP<R81<Z=N/Z=N<F?
N/NAN/B=MHB8M<>8L[R3KI1`@hiPC7aBA5Lh<4T/8cPP6B8L62TL5R/M62<H61lC5B4E51D=3QX@3bLG
51PT3>WNg^CJfP0>iMcM:?ooo`009_ooo`ONhN80Bmk0`]kQh]kOh=c0h7aZJUI3@d@d<E50@E92@UA2
@Tdn?DPg=P0P83PZ:d0_;d@`<EA1?69>BF18@I1YFJelJl:PRMjkYN?5/N34/=o4/n78^^31/=o6^>36
]L34/=bnZm^o/=blZM^gYmVdXM2TP=NZU]>SSl:4PLjQR/bNS/R0RLnNRl^NS<RHPLVFQ<NHQ<6@P/BB
PL:BP;nBP;nEP;j@NkR8M;N7MJ^1KhYTAG]FBfI8@d8`<3/X9b/N820L82DN82XP8`TI8ALB71DA60P0
520K82@D5a0X9^GWimkQh@0>g^7R7_ooo`OUg=d0BnGHf>GLgNGJfnCJf85WHEQ1>TT`;5@n=eHo>413
0E4k<d/d;0DU83`W8D@]9DLb8EPm<fI:@651>9EUD;AgHM29Q>FfW^[1Zn;0[NK0[NS4]>30/>G1/^O1
[nC0X^:iYN:jZN>aY>6cXMn`VmbPT]fUSmZNQm20P=FLP]>IQ]2HP=JJQ=:JQ=2@0/nBNlfDOLR4N/Z>
NLR>NLF<N<FAN<B<Lkf1L;b4KJmnIh1PCH5B@F]4>D8`:3hV7BdL5B8J5RPL5BdN620D41T@4AL>3``0
0BDG5B8D41@P3>[RhnGLg00>iMcM:?ooo`009_ooo`03g^7Rg^7Pg^7R00CNhN808Mk0`=kQh]kPh=kQ
h80DPDU0@D000510@4h004800490@40f=@PX:34U:3TX:00`<DXh>T040U000090A8U<D8200=BRP<B0
Y<:4X=^1Y^33/^30XMc1//31/<22X=RhX=2hZ002f;2P02SJ/:3@X83BXX;APHS0P838V8;1V8;0TH3?
V838VH;0T830T7S1T030P032TX20TP2hP7RhT7VbRG2P062P06N1J4D0@0QP2016:RP0820P00<04AP0
400P61dX024040002A080100000S82PQ01D0@430h>7Oh^8>g^7R7_ooo`03iMcMiMcLiMcM00CUg=d0
BnGHf>GLgNGHg>CLg8@A44]02E0085<m=U0l=48805@l<4X`:00T834P7P4X840P848`<4P0<400<01D
@H18@h:00<FPRN>fR>20X>:eX>62X>20X>B0X>20Z>2jX>2bPMjeXN2`P<2/V>2/V]:0P=R2QM:HPM2@
0=6@N/2B0/2@0=J@0<jD0/2@N<V<LLV0L<R0L<R>N<B>N<28L<2;LH61K:00H:9dAX1TE0A006019DXU
900P020040@C0@0@028H42XJ5P0@40882@P00000130P020040U8@>?K`>GMgP0>iMcM:?ooo`009_oo
o`03g^7Rg^3Pg^7R00CNhN80BmkPh=kQh]kRh]kRh[Z^/WUUI4H40E10?e10@DX625=4AD/j>A0003<T
9c/Y:PT/<4Pg>DLk?D0h>6E=AgQ@AY40I<:HQ/ZYUM:]V=>aWMblZMVlX=^nZmfnZmRhXMRfXMNiYMRb
Q=J^WMN]W<20P<^JQ/^GPlRAP/ZDP<NFPl:DP<fGPlVFQL:@0L>@NL:@N<::NL6@O[fAOKZ8N;B:M:n4
LHQdI9I]GHURDe@<15@c;c`W:BT2828I7AHB61<D61`G6b4H710@60/<5PX:500143LY:U8k>J6AR=_O
h=oQhP0>g^7R7_ooo`03iMcMiMSLiMcM00CUg=d0B^GHfNGLgNGMgNCLgL6YZgeRFe81:U@m=U@m=e80
=5Q0>dhg;a@V8CLQ7ClV80`X8D/e;d/h<THd9FY9?Ga=?J44BLVDO]6TSMZXTMV/U^:gXn2hX>:iYN>j
YL2dQ=naV]jeW/:PU]fYUmfXUM2F2M:FO]6CNm2A0=2@N<fBNl2@N=>CNlnBOL20L/V<LLR<L<R2LLN<
Ml>=ML20L;Z6K;F0J:Ab@i]YE8iNBV48:5L`9ClU7b`04BDG4QT@3AP@0QlD42<F4Q0<30h:2``72@42
03TW85Hh;j21PN;IfPoUg=dXoooo000Voooo00?NhN;Nh>3NhN801=kQhP1;g^3Pg^7Rg^;Rg^3RcLO:
RgalB@@0DD0oE4=3D002EDE6Ccln42X/=B@W?2PZ02PXAcPiBC`m@3/0FD90IDDoP614Yh5b/I60Q9:4
aj:Adk6NdK2LekJQekNTd;21ek:Mf;NQdjB0e:ZIdJNERI00`Hml`Xmkai1kb8mmai=o`9<0bI=nbY>2
`X80a91i`Hid`XQc_Xel_8ih/81d[X9_YGe/U6=2R61CO5E8@0D`BB`Y<b8U91P07ADK5A0G418I5a8I
5a0F2PT@3PlI4Q4L5a0D>RPXM65OZK6`gN3Qg^7Q00kNhN8Noooo00?Ug=gUf=WUg=d01>GLg@1;iMSL
iMcMiMcMi=cLe<74TWQcD00XESdeF40iD3``FD8lDc`d52@P>B8M@2HP2R@PBcD_CCTcA3P`GSlfJD8f
S51<[GeY]hah`91lcIj:fJbGeJbEg[:Jg;>NfZ^Hg:jFgK>K`:N@fZJBf::>`81cb8]cah]ccH5ccH]f
cI1gc91`cXmgchmk`8Y`bHabahY/`85Sa8Ud`HY`_81//gmVZWYTPf1@SUa9PU0nA04RC2XO=R0J81PB
81<@60d<60006Q0?60h=3@484P`>5`h@6000>RLOPE]Bb:2Zi=_LiMcL00kUg=dXoooo000Voooo00?N
hN;N`N3NhN801=kQhP1;g^7Pg^7Rg^7Rg^3Pa<S:ThB@@002Dd00EdA1@000ETI7DD5402PX>20P?BP[
020P@3PhA0=0@000@38jA3PjH4100TYA5V1:P01PYX84Qh:0P801`8Z5S8R:R820`8R0a:2@`820`X60
PI:0X01PY01PY@APP01PPPQaQHMaP81PPXA``HQf`81`PHY`^85PP81P/81`/81RX01PP6UPRV560490
JT08H0<d220Q=R<P:1dP0Q0H410H50`F400H00XF10010000418L01PT80@0@B`ZV8Z8`<30`>;Rg^7P
00kNhN8Noooo00?Ug=gUf=WUg=d01>GLg@1;iMcLiMcMiMcMiMSLh<G0XhN8@003F3ddG40h@30`FT<m
F40h@2PP?24M@BDQ0208B3HPDP0`D00`D3D`D38Q04@044M0PV12P6Q1Z@i`SHl:P804aHH<`H24`800
`h61dJ:1d820`821`8T3P@11ZW52Z018P01PR0AQ`X1PQ81PQh9Qb81`a81P`89RQ85PP05P]PAX]PEP
X7E0RVAGTV9DP4@0L48dI00S@2P00R0H81TE0100600>40T840P<10P91@<00000400@814B0000@RXS
PH8T`<31i=gLiMcL00kUg=dXoooo000Voooo00?NhN;Nh>3NhN801]kQhP19g^7Qg^3Qj>k^aL;60U10
DCdlDSln@000E4I6DTA5@S8`?bX[>bLZ0B8SBCXiEdI6EDI6CS`oBSXlF4=4JeA<KeQAP61GTgAZY81a
P01PZXAcY8EgX89d/8If^I9o^h<4/XajYH5aT61MTVEHUVUJP69LZW9T[WUUY7YP/7aX^Gm]]7aX[gm]
[GaTZ75UYWMXXgERPV10SFEIPEiCI4@2G3TfDc<_024P;b0Q91/N4A4H4`hH4@XD0@TD2PTE1PHB0`@@
5Q4H7ALP<2<VN6ETc/W:`M;Eh>;Sgn7R00kNhN8Noooo00?Ug=gUf=WUg=d01nGLg@17iMSLk^WYc;g0
2D10E3/cES`dD3PbF4<lET4k@RXP@bPQ?R@P0249CCL_Fd<mF40mDSTeCcLb@40hKU54LUE9Q49?V75R
ZWaXX7AP/81ZZX1^XP1Z]h5]`8if`8=`^HQaZgeYP6QDUf9?W6E@X6YD/6mK]7IL/G=1]WUO_g]U^WQP
]G]U/gQKXW9L[7AOZG9IQfQETV9@QU]:L48`H3H/ES0U0B00<QdG9aTC610>5P`>4`P910P:30P:20D7
10055`h?81DF=20MQUeFfL;3c<3@i]gN00oUg=dXoooo000Voooo00?NhN;Nh>3NhN801mkQhP16g^7P
iN[Ze=CG5P80Cc`lBcPgDD51DTA4CD10A`4g@Rd^>2HY12@PBSXiFTU9DTQ8E4E7Cd11E494J5A>Ie=>
05a@PFMNSfiPQV1KSfaPR6]QP6aPU6]OXGYZY@=SWGYYSFiRP4IDOEI=Q5Y=Q41@UV=EVFQGP61FXg5M
ZW=RX71OW75PWg1KTVABV6eMTfQHPV1DP5]@M557@P0aCS0^AR`[:0@6:AdQ8AXM61<J4@hH3@PC10D@
20TE2P`I20PD60dD6@lG4002Y9NEfm[K`LS;0]oQhPkNhN8Noooo00?Ug=gUf=cUg=d01nGLg@16iMSL
jnGUf/oB:087DCXcCSH^E3hgET4jD3dg@S@UARXT>b@O224:CSL_GTI0FT01F44mE3`g@40iK556JU16
25Q:QVAEU6YGS61BUFMGSfMFT6QHW6IDZGEPZP1PXgIPTVYIP410PU=5RUI3P5Q0W61;WfA>X6E4ZVeD
/71HZ6aDXVeGY6aCP610WVUDV6A?Qd58QEM8NTdmBSDPDRdUBBXQ:P<E;1/G91LB610050/=3`H81@@0
2`L93`T<00P95`d<5`l?820@]Hj9h]CFhL744>GLgBSoool002Koool00mkQh]kPh]kQhP08g^7R04KK
`<76h^:0481@2`a2<3=@@41=0@54>CU00014<34`8RP08210>SQIC4a0@411ATADADA0@41XF55SDTm`
F41QD4=ZC451@41DA4944`]0@41P4PT7@4@0B400A4QRBT90@4112@1P2P50001YA002APT0@020A4:0
AT00@400@48:@T02@000@D40BT9Q@01Q@0Q803089R01824`920000024`4J41X@01P03A011Q4000`7
21@@4@40404:11012140003:b<;Ph>70`<3NhN4?g^7R7_ooo`_Ug=d0;^3Ef>C5a80045<80dP`:U00
<50l<48`<400<4TP8cXT0P0P850h<459@418@D=3A4500T900FiDB6Q>AP1@@69@@01924000611058=
0F1006@<<0982a50@010@F98261004`0<V@89D08<0A0:`M200E0089028A22P100PA=219@20100PQ<
2080@0005VI1=Dd0800P000P6c@P6P0@020@5@0A41P0014:30T41P0000X72A82404000<400@81002
0<W0Yn7Ph>30`>GLg0oUg=dXoooo000Voooo00?NhN;Nh>;NhN801mkQhP16g^3RfM_Lin_[U:2TLF5T
ETA4@P83C3dmAc`lD410BCLh?C0b@S8dETA3H51?@U10HUMEH51?@410J5MCI55>JUA9Gda6GTDo@CXi
Dc`lB3@bBCTiDcLcFchjI4Q2GdI0ESlmD0@4B3@dCc<`A30`ECP_ESPbA04bJDDkJDLlHD0hGd<lID@m
FcXcGd@iGCljD3PfDCXeD30]0R8Q<1lR:R4S0Q0061<L61<I4P0B30/F1`LB00HA20XC514K110J?2DX
ASLj8`P9m?Ogi>WZ`<304=kQhQkoool;iMcM04KPe]K]i^JSR:1gGUYJ@C]A031@>S=;>C9D1SU==2i1
;BM2<21J@CYTCDIRC41UE4eSCDI4AD1]DdUYCDA_D41TBCaR@SI@>31E>S=:<RUA>C1E=R]N>c9P@SUR
@cMI?3AC0C5<<BYB<BM:8RQI=BIJ=BUP>B1^@C5^@c9X@C5T@39Y@S92>2QT@2mR>bmL<BaF=R]C;R<4
81Tc71P^7QP42PHK4A4J4@h@200?2@/91@L410H:1`PF3a48410o8ai;<c145@obm_GYiNGP`/;Ug=`?
iMcM:?ooo`009_ooo`03g^7Rg^3Rg^7R00SNhN80AM_Mg^CXj<34b8ioPf]HFT`i?4`m?Di2@e52@4/j
>dDh>D000Ee<Bf9BD61ADF5DDem@Cd10BF9@CFI>BV=<@5i7@UM0?4Pa=4dk>d0`<40d=4`h=Ddf=U43
054k>Thh=d@c<Cd];T4[:cP[:4@]:DD^:d0U850e<58g<E@j=54i=U0f<TP`;4Xe;Tlc<D0`;T4^:dDZ
:RTP8R/M82DN8@0@018?61@@60084P/950T94`P<40X;4a<;4`P=05@m@75SI8b0P>galN;Wil34a00@
g^7R7_ooo`_Ug=d0AN;HfN[ShlJPa9EkNG5ED44i<E4j<e<o>5E004hg<DTe;d@e<699@VI>AfA0@6EA
BV==AD54@6M<@fY:@FQ80694>E/m<d/a850i<T8^9dD`94lf;50c;E00<UDh<E8e;TP`8D4Z94<X8S`Y
84L[84P[8D0P85@b9eLd:5P`:UDf;5Dd9d0P84db95<`9TT^94D/8DPX83045BhJ5RTK5@4:1QH<3AL>
3@0220`82@/72@`820`92A4;30H<0edg<geLF8R7PNk_knSRhn;F`00@iMcM:?ooo`009_ooo`;NhN09
g^7R0470h>3K`<;0`<20VZ>30150001003i@B4Q0@418?3a41D10001RDU9QD410@41KBdYHBTUHBDQH
@41U@T9@001H0ca@?3a00018?3`l<3088011?3X28C@0830283908S0`820T828P820P020R128T820P
020X120^2B008204820/2R4P0R0V10@28R0P020P000Z82DP000P61d04aX0400:21002AH20@0:218<
2A@2400@1A0501000@0=FUb1T9000/30`003gL;3`<7Pg^7R00oNhN8Noooo0^GLg0WUg=d0ANGLg>;H
f<30`8:@VH852D04254h=5U4?U0004lh<541=500<VQ3BF1>A410@V14@418@5U10T50=6U3>4008400
<U@i<T0P8Tlk<d0]:00X84Ti8`HZ:@0P840X:4DP808P030Q72H06R0042P062X14`8042P05045600P
00<U80055P0062P14P076000420043416200420A420@400040400Q0920040@X0200920020Q810080
000001eAD8R2P<24R<OB`>CIf^C0`00@iMcM:?ooo`009_ooo`03g^3Qg^7Pg^7R00SNhN80AN7TiM[L
gLCPc=C>d[:W[5A1@E4o?U=2@dT004`n?eM9B510@6AEEEe>C5I1B5Q7AUI8B510@EA0?f12?TPe<5<j
>Ddj>d0a04Pk>cda=@@X=T8k?CDX<BXP838U;CPW:b0P8BXQ92@L908I0R<J8B@L820H01lH7B@I7R8K
0RXN920H720H01hF6R/K824H7A/D624I80@E01XF6aDA5a036PX74P`;5P<840l>60l?600A02/O8Cl]
;e0U::^NXMOCd^3bl=CFemcMg/75h00@g^7R7_ooo`03iM_LiMcLiMcM00SUg=d0ANOOh>7Gf>C1b=W9
cKVRY@PZ:5Dl=EHo>D0h=4lk=EY6?e10>fQBC65;@T961Ue4?5Y5?UQ0>EPm=F@o=D4`9eHg;e4g<D0/
84dh<D4^;0PP94Lh<cTU9S8P8cDR8S`T8B@002hO6RLJ6B0B52HH5RPI5B8@528F4RLG52PH52dL6R<E
4B8B4B0D3bhI5B0@41dB3BDF5PP@41dC41L?3A803P`51`l92`P00Q4;3A4<3@8B4RhM5d@Z900H4[ZD
V=k>c>c`l=k?d>?Hf>C0`P0@iMcM:?ooo`009_ooo`03g^3Pg^7Rg^7R00SNhN80AN3ShmcNglCPh=cJ
g<Joa28D45E1?d/i>44d=4`o@5M9BU10B5i@D5I9B510@UE4A595AE0<2U90@5Pn>`LP84Pd=4Th>D0X
<D@d=cd`=C@P<3dd>S4S;B0P:bPO9b`N9R8N9BPO8b0J8QP@7AhG7b0I804@7QdH720G7AhD6AlE7QTC
6@0@61XC628G7Q`D6A@?5QDB6a0@61<A60d<500850/74``<5`035A@E7a4A6P@D6T0^;6=ADR<@4<K1
`n3OgnSQh]SKg=cNgl3Ph00@g^7R7_ooo`03iM_KiMcMiMcM00SUg=d0ANKNg^;If^30`>7Ef<bj_R`@
05Ln=d`g<40`950l=Ea6?e54?V9=AUY6?eE005U1>UM2>e@905Hm=Udk<D8/94`b:Tde;d@R8DPa;44]
:`0U;44a<3DQ8S0282/M72hL72TL6B/M6B<G5`0A424E52<G5B0D420F4B8E4P0@024D4a/A3`8B0adA
3R@E4`0@0QH=2aP?400401H>3@h:2Q4:20d620l:30P001TB4a@>3P@A44<[8W1:@i010]:i_>GKf^SZ
h>7Ee^CIfNCJg00@iMcM:?ooo`009_ooo`03g]oPg^7Rg^7R00SNhN807]kPh<3QhM_2`/3Ph<30a0@8
04a8@DLd<44094P1@590@D10@550@410@D00@5A0@410@T000410@TH`<00Q834X:P@`<P0R93PT83PX
<20P830T92`L820080804P009@0H82@L81`@010A61TA71`F01`@004H7B0H010441H06AHA610@61PA
61PD7A0@5@0=5@@85@4040T950H840P040894@8060@20000800@000005126HPH6X20P<W@dN3Ti<30
`<;Ph]kPhMcPh00@g^7R7_ooo`03iM[KiMcMiMcM00SUg=d0ANCHg>CLg>3Hf>KLgLC=`8020596440`
940T850l=5Q0>U820510>D<2>U80<5M0>E0n>400054m=d0a:0000@4T140P:00P800R8P0S8R@4138P
8B0H6RPH608@508A520@620J400D51P041`A4P0A5@4A420A4B0@4Q@001P>3aP@0QPA01d@0A`B4100
01<:2PX220000@d82PP600P000@82Q0:0003028H600B4@0005hH0IX40l20PN38b>K0h>3@`>30`>CJ
g>CHf@0@iMcM:?ooo`009_ooo`03g^3Pg^7Rg^7R00SNhN80AMkPhN3Si=[0`N3Ui>CXjJ2PYHYjNVQI
Ee51@4Xl?4/l?D4n?de0?de3A514A5M8BE11@a0214/n?ch^;RD182/S9S@Y;C8Q:C8Q:38T:b0282XO
:RPK8b<I8QTE71PC7adH824I81/E7QD061HA6aTD7APD728M8BLN91P@0AdF7QdI8QPG01hF81`G8Q@A
618>6@X;5@484`h<5`h=6Q406QLC7aPE7`PD02XP92lQ8d0309J3OlBl_NCPh>kemMoUi]G@d>?Vi^3S
i=gPh00@g^7R7_ooo`03iM[KiMcMiMcM00SUg=d0ANCKg>ONgn7De^SPgn[SiJZPRI9eKfiECE@6>4di
<Tlj=4Th=E4m=U50>e10>E]5?e@n>A@0850k=D8[92P052lP6cPV8c0Q7S@O7cDR8B001RdM82XI6B0B
61`B4Q/A520D5R<G5AdC514<01P>41`A4adB42DJ5bXK6`8B4R0C4b0F5adD4R8C5AlE5`0411D<3P`9
2`@3210:310;3Q0<01/A51/C50X@42dN6c4O6T@`8:=lLm6d]N;GenkclNKOhL3@`nSRh^KNgnCHf@0@
iMcM:?ooo`009_ooo`03g^3Qg^7Rg^7R00SNhN80AMkQhMoRhmc0`^3Ti>?Wj<O0a:bQXXb0OeA5AdXi
>THf=PPd=4a0@557B518CEa>Ce93A@@V04Tj>cTX:24082LO8bXQ9b`192/N9BPN9@@F22@K9R<J8B0H
81TD7A/F8A`G81dG7QXE7a00518>6AHA6aPC724L8b/R:R0O:2TP9RHP:@@H9B0I9B4L9APD01LA714@
614>41D@6QXG8b0L9AhL9R8K920@6S8N7T</:@A<@KN/Z]GBdnKPh>W^k^3TiMSKf>7Ti=oRhmkPh00@
g^7R7_ooo`03iM_LiMcMiMcM00SUg=d0ANGLg>KMg^7HfNOOgnWRhl6TZKJLVIIkM5Q16D/g<DLd;T0b
850m=UI4?UY8@f5:AEI0>`8T5T`h<SXV7b0J62XL62dN7B0L62dL72/L6`XD42LI72HH5b4G41dA4QlD
5P0D520D51dB510;01D<3QT?41/@42@I62lO82PL02hL6bXL7R8B6R@F6RDI6`4@41T?4Q<>3QD<31L>
3ahD5b@I62@H6RDI6BDF4c0N64@Z8@107<BUXMo<cN_Th>_[j^KOh>;Ee>OOgnKMg^GHg00@iMcM:?oo
o`009_ooo`03g^3Rg^7Rg^7R00WNhN80A=kPh<3Qh=kPh<32`l34a<C0`8:8R@0404h834Hd=@0T9Da2
@5A:B410D61BE510B00P84Pi>38P924082@H800B0P@H020I8QX@700@01`A0QdJ81P@01P@71lJ81PD
018@71P@7A00400<410=4A00620J9B0P<28P03HS9bLX<202820J:RPP:00H00@D800D004@6PHA020P
8B0P8RHP;BXR82P000dP15PE1X020<;2`^3Rh/30`<32`]kPh<3Ph=cPh=kPh=kPhQ3NhN8Noooo3>GL
g@13i=SLiMcLi=WLh]SJh<S1`L;2TX601000@0P4@34V020PDCh`F4I0A410IDi:F4400200@38`<b8L
81PH9aPF11<D810@8aPA018A01000Q@D81LD010@700@81LH710@610@710B50004PX<4PT<40`091PJ
<24P820P12HT=B0V80008AP28@4P8A0@1Q0D110B010@2A4@90DP020R920P<R0P90@@2200GQ00P@00
b<W8h<G6`/30h=;Ei=WJiL30i=SIiMSL017Ug=dXoooo000Voooo00?Nh^;NhN;NhN802=kQhP15gn7R
g^3Q`>7PgMoPfmgMbM3Bk>oagmgOP820NFY]IUMIC413C410DD=3AT10FDa?FDU:@3T0FDQ8AC<c=24X
:1dQ7QHN11@07Q/P6aHL6Q4K6aHN71TO61@L50hI6QDN410K5Q0K5Q0J4a4L4@dH3``F4@<J7aTX;RLc
<2P9@3Dk?CDn<2Pd9b4`;bL_:R0X:b@/;2@W;B8P;b8W>2/a>2/R=RT[AC4bA30TJ4Y3V7edT860kOCf
i^c]dMCFemOHg]oOh^CVgMoPg^3Qg^3R013NhN8Noooo00?UgMgUg=gUg=d02NGLg@13i=_LiMcLhm[K
h]SHh<C5kn[^hmWKR3/mP6ISJeA?@401CcdgED0iDD40GDU6GDI0@C8aG4DoB34Y<R8P:Q/G81@D1a4D
8APF7Q<B0A8@7Q<C7aHD614@5`/>7A8C60h@6@h@6@h?608@4`/=4@X<4`008aLL<R@Y02@0AC0a@S0d
<2DX:alT<b@T808P;b8R;b4M<20J<QlN?2PW02PP>2LQB2hXD30PKdHhYWMVa8>:k?;djNWY`LS9h=7B
i=[Jin7Qi=[KiM_L017Ug=dXoooo000Voooo2mkQhP14gn7Rg^7Qg^3RgN3Pg=oO`lc<jNc]hnCUU86@
W9:EQGYmFTY8C3m0BSTi@S@dD4=6FTY:DTU0IeMHE4A402<T;R4U9A/Q1QH381/P8Q/P81TN7AHN7QPN
4Q4J3`TD4`dG50hH5PlK50hG61D05Q4J3``G4a4I7aTY:BDa<2H8?38l?cQ1=2`a:R@a;RP`<2Da<bdc
<BX^<2TP=bT]>R/^>20P?bPVDCPeHTA0QW1[^:NRcLK2jNo`i>WYf<31fM_LgMoPh>?Tg^3Qg^7Q4MkQ
hQkoool<iMcM04?Ug=cTg=cTf]_SfM[S`LS]j>[Wgn6JQX2VS8b>MG<4B45??CM;=c50<RAC@CiNAd5D
@49/E4iK@3U0:20a7aXX61LP4a0S6ADV61HR4A<P51<Q5Q@I0a0@20XC2`dE30hH3Q0E30d0410G3PlA
2`dH0a4S5ad^8BH082lo;SA4=3Lh:2d^8RHc9B@b820h:BPg9R<i:20j9b<l:BDk900m9amC=B`3@06D
JUk8X9K4`ISZjngXiNGQd=7ReMKTf]_Vgl3TfmcUg=`04NGLgBSoool002Koool00mkQhMkQh]kQhP0:
g^7R0]kPh00Y`>7Q`<70`<C4`N3P`L70V9ZLPYn40000@dA0@000028RBC`0G4a8A414L69UH5A0@000
=2LP:R8Q8@0P900Q920T80@P8APP8QTP10000@@B004@400H6A004`4B000011D440@210008@0P920^
8200=Bhl@CY2020d008P:300500P<3X`>3<Q=00b<0@`<00Q;00P84/X96104A000:BHTLC:c<34a<32
`=c0`/3Ph<3PhMkPhMcPh=kPhQ;NhN8Noooo00?Ug=cUg=gUg=d02^GLg@10i=SLi=cLi=cLh=C0hMOF
iMc0`L30b9B@P9RK0000@48<@3DX020PBcX`H4Q2H450NV51He10@00P02@6<0L180@4800B<0H0900H
91@@818B00000@<83048400200<B40/0008011<B4`4@0A0@81P5:P0P020P<B/dA30h020P<24V<RDS
0B0P@C0/0BPX@28P@B@Y12XQ0200@2PPHD84P000PY22b<30h/W0h]CDh]KHh<30iL30iMWLi=SI4nGL
gBSoool002Koool00mkQhMkQh]kQhP09g^7R04?OhN;Nh>3Oh^?PhnC0`L3Gf][LhN7VhN;Uj>[De=R<
S8b1MWU^H5iB@T1BADMNCTeT@4QbIFI[GEm@2`a7>3U4<S8i82@g:RXo<38h:Bhc9RX_9B`P2B0S6b8N
5b0P6b@X7R`Q6RDT3BT^:BlU82lb:bPd;CT^;3H4:00j<d18?D<8<P0k<SDk;S51<S14=CHn;S5:<35:
>cU>>CA020IlGUJCOGF;Q83@dM7/m?K8h>;Gf=OJg=cPh^?RiNKOh^?Mh>3Oh^;OhN804MkQhQkoool0
0nGLg>GLgNGLg@0:iMcM047Tf=cVgMkVg]oPe<3OeMCTfm_Ph>;Yi>OJc]F0R8B:LVieFeAD@3QE@SiQ
BdAQ@D1gHEe`FEEJ205;=Bi8<2P1920j:212;BPl8b@f8b0b8R8T0PPV61PQ51HT61P/724T5aXY220c
9B@Y7R<a820i:Bld9b/8830l<3Q;>S/=;2@o;b/o;2I0<218<bY1:bQ><BU>>31@=R]80BV7F4ZON6RH
RhgEcLc/l?GRc>3QdM7Se]OP`<;WhN7UgMkTf]_UgMd04^GLgBSoool002Koool=g^7R047NhN3Oh^;O
h^?J`<3JgMgNhN;Pj>3VjN_Mgn6JTi6WX:>DRhYXH61SEUMPD557D51WF5QTEEMFA41A@T9??3]9<SU4
=3=6>3M0<310<C8h<CP09CDi<CDc;C@]:34c:cX^9cH^8@0i=Sdd;cl2>0Q5?DHk>44<0414?DE?@4E0
0P96>C]9=C=0=C99<Bm2;2]2<S1A?caNAT80DTBNRXFcYj;0TICKg]kXko75h>CJfm_LgMk1h>3Pi>CO
h^?Nh>7OhN804]kQhQkoool=iMcM043Ug=cVgMgVgMkReMKRf=OUg=cZhn3ZiNOSfMk0QHBaViVPQGh2
@dAYDdeTCTQPA45ZEE1XDTm0@PID?cQB>C5<<R=7<BU:=2i582Q3;RTl;Bh58B8o;2Xj:2T`928j9bld
92X08RE0<S4j;3A0=Be;>3a2<cM0<3E8>CeC?Ca0=31:=S5<<RY3<RY9<2M1:RE2<BUD?3=S@cLB@46_
PWS2XIK0T93Of][ZjnkPaL[SeMKSf=SVg<3VgmoUgMkUfm`CiMcM:?ooo`009_ooo`03g^;Rg^3Rg^7R
00_NhN82g^7P03G0h>70h>3Oh>;0`<30a<CQi>C0a<30`<RHTI28PX0A2@QPB4Y0B410@T14AE91@412
BTQ0@T90@412@0i@@458001<30U13D50@410B41:A4P800110D0<0D<00494@T1024Q0A412A592A410
@4Q@B4YB@4A@0@9@@41013Q2031A<BE:;298001:B4@2D52861RHTI72blc0`<3Qi>D00/30`006`>7P
`>3Pg<7Pg>3Pg^7Pg^3R4mkQhQkoool00nGMgNGLgNGLg@0;iMcM03kUg=cUf=cUf<3Ug<3Ug=cPd=3S
fL3P`<31`<31`LC6TH6041:20600AD50@41PC4ER@4Y0@4Q8@d15@`Q<@0Q630I030100@1020102PQ0
0018@0e44@m00@10=0]0<PP1<0141PI80DA0@0A8@4Q@@4500P10@41003Q003111CE802E0=21<<218
:RE0025FA0PHA42B403>T8?8`<;Ra<CR`N3ReL3Pd<3T`<3Tf]cTf=STf=WUg=`DiMcM:?ooo`009_oo
o`kNhN80?mkQhMkPhL3QhN7TiMoQh];Df=[MgN7Ui>CThNkam>KYjL6BUjjWYi>:SW9TH7EYIgM[KVQS
L79VJFeOHW1VI71OHFmTI6QBE6aKFV1IGfQH@6eNGFMLGe50D5M<FEI8ET90@EA<D5Q;ET11B6EEE5e=
CeQ9B5e=Aea2@4A6@6=<B6Y:A69=A7ABC7AHD`18A8]mNZFCTl2DT>CYj^gdmn3Ph^?VimOHf=S0`>;U
i^3Ti=c1h=gPh=kQhMoRhP0Cg^7R7_ooo`kUg=d0?nGLg>GKg>G0`>OOhNGLgL3Ad>;GenSPg^[PhO7/
l^[UiLB9U;ZQW9j5P`1PBgeUGGiWI6eTJ7ESH79KFWQPFGEKFGEPFV1A@71GDF9GEfeHD75LDfaIEUY4
@5]7DUQ5Ce40@5Q9Aee9CD50@6UBBf1:Ad120F=:?64o=f11<VM9?fi7?69807U?@g]DB110B9QfK[F;
R<n0T>KVing`mNCTh^_PhN7BdN3@d>OQh^KOh>CHf>CJfnGLg>GMg@0CiMcM:?ooo`009_ooo`03g^3Q
g^7Pg^7R00cNhN80?]kQhL3Qh>3ShmkQhMSJg=cOgn3Thn3Vin[]knOZj]CB`<O5aKFa/h6<P9J>S9B<
S`P0Q7ibNGQ]M0QcLWm_MXEjOGYYH7]ZJg1UJWAPIG1NGFYLGTM@E61AFUi<E514@5U:Bea:Cd16A6=?
C61:B5a1@5m9@Ue1?655@6Q?BVe@CW54A8icK9=mNhB0PZjVY<2g^=?>`>GZjnW^l>7Vj>7TiM[Kfm[1
`^3Si=oShmkPh=kPhMkQhMoQhPCNhN800mkQhMkQh]kQhP0<g^7R7_ooo`03iM_LiMcLiMcM00cUg=d0
?NGLg>CLg>KNgnGKg>7@d>CJfNOOg^SPh>kYk>_Vil3:c]:o_KnZZj26P:68PIn6Q@mcO8=_L7eYK81`
HHE[KX]gM09PH81WHW=SHgM1G7=LEFeIEV14A69=E5i:CU902U]7@ei8Ad541VE=A658@Ei4>657>Elo
=692>6]<@W9=A@10B9Y]HJ5gKj0;0KfNVLj_[lC8b>SVj>_Zk^;PhnWOh>;FeN3DeNKOgnKNg^CHg>GK
g>GLg005iMcM00?Ug=cUg=gUg=d03>GLgBSoool002Koool00mkO`=kPhMkQh@02g^7R00CNh^;NhN7N
hN;NhN44g^7R00?NhN3NhN;NhN800]cPh00gg^7P`>7P`>7Pg^3P`<32`<30`LC5`>3Pb<o@`LK@P820
T9FDQ8b@PX21RH2;Q125Q820SX64TH2@P120R0/AP`8836QXLDYPJ4A904Q0JT1:H4=D@410H491HDQ0
@D10H4A0HDQ0@410Hd50HD@<0490L45004]CP000P9J@P8B0P920`<S9b<K@`>3P`L;4`<31fL30gL71
`>3Q`<30g>3Pg^3P00;Nh>84g^7R00GNh>;NhN;NhN7NhN;NhN400]kQhP03g^7Qg^7Rg^7R00CNhN80
0mkQhMkQh]kQhP0Noooo00?Uf=[Uf=cUg=`00nGLg@03iMcLiMcMiMcL00OUg=d2i=SI03OUg=cP`<3T
g=gTfMgPd=3Pe]GSf<3R`<3Tb/S<`<34P834ShRGP8R0P82438282860282448BPQ8Z00Q200`670@20
H602AD1`@480@41/A41XDDI2@D1P@D9P@491@01R@T1T@@QP@01Q@P9P@@@2@004@DP9@d200028P8C0
W8;0P839a<3P`<7P`/CUf<3Pe=;Pd=3Qf=ST`<7Tf<3Tf=WUf=`02>GLg@03iMcLiMcMiMcL00;Ug=d0
0nGLg>GLgNGLg@04iMcM00?Ug=cUg=gUg=d0:?ooo`009_ooo`03g]kOg^3Pg^3Q00cNhN80?=oQh]gP
h=gPhMkQh^3Ri>3Si=gOh=CHf=OIf=[LgN;Ti>gcm?7fmn7Xh^7Ti=cMh823QK:]]Z^/]H2XP;B`_<?0
a[2X];2X[:jPYJ2BU9>5R8eoPY23P921Q8inNX1bL8A`KXAbKX1/JX=aKhQeKX=`JHEaK8AaJh`909V:
QYV?UK6XZ];?cMcKg^3Pj>ofn>gfn>3Vh=cNg]SIfMSHf]gPhN;Wj<;Ri=gPh=kPhMoPh]oRhQGNhN8N
oooo00?UfM[Uf=WUfm`03NGLg@0ki=SIi=_KiMcMh<32i]kOhm[Lh=3@gmCBh]OHj>38l>oalo?ej>;P
j>3Oi=SJ`:fj_JF^/JJaPZB`^Z^fb;_2^:6/]j>U^9ZLZH2<VgmoTg]jP`=lUWilUWU_P6IXRf]TS6iS
R6Q0RVaUTG1SP6UQSFaSS6ePPPAXY8AlY8Z:R:2PgL[4hmCKi>3PlO;fk?Cfh^3Pi=SIhMCCh=3@hm_L
in;Ti/3Pi=[KiM_LiMcMiMgM01GUg=dXoooo000Voooo00?NgmoNh>3Nh>400]kQhP03g^7Qg^7Rg^7R
00SNhN80>mkQh=kQhMkQh/3Rh=oRh]gOh=SLg=[MgMcOgn3Ph>S]k^__l>3Xj^CWj>7SiL74d<S7c<G7
cL30a<W9d];Bel72b/G1aLBm`KR`];2X[:RPY:2QX:VQY:VOWZ2DV:2BTj:EU:6BU::GUjFKUj2HUJ6F
Tj:GTZR@XKRa/;Re^l30`=cOgn;Uj>CXkN_bm>Wbm>7Uj=gQhm_Ogm[0`]kRhn7Vil;Ph=kPhMkQhMkQ
h]oQhP04g^7R00?NhN3NhN;Nh^803]kQhQkoool00nGJf^GHfNGKg002iMcM00?Ug=cUg=gUg=d02>GL
g@0iiMSLiMcLiMcMi]cNiMgNi=[Lh];BhMOGhmWJj<C4k>SZkn_]j>3Xj^?SimkPdLK0d/36b/79`/39
clC=elgCc834c;boc[Ji`Z2/^J:T/9^L/X2N/IbL/iZCXI2?ZXb9[929[H29[I6=/YF<YI2:[I29[Y67
Q8Z0a:^W`Zncd/31i=[IimoUinOZk^kajnkahN3RiMcMhm[IhMSHi=gNin7Si/34iM_LiMcL00KUg=d0
0nGLg>GLgNGMg@0>iMcM:?ooo`009_ooo`0>g]oPg^3Pg^3Pg^7Rg^7Pg^3Qg^;Rg^7Rg^;Rg^7Rg^3P
g^3Rg^7Rg^3P0]kQhP0hg^3Rg^7Rg^7Rg>3Pg^3Qg^3P`>3P`>7R`>;PfL30`<;3`<70`<30`N3Q`N3P
`>3Pb<cPb<kQ`<30`lSRa>3R`<30`/;0`<C0a<30`<30`/30`<30`L32`YC0P86@T8B8U8JA`8BD`9BE
`IJD`92@TI28TXZ8`<30a<C4a<K2`>3Ph>3R`<G3`<30`<C2`LC2`<30g<33gl;1g<30g<;2f/32`<C0
g^3R1mkQhP05g^3Pg^;Rg^;Sg^7Rg^;R00;NhN800mkRh]kQh]kQhP02g^7R00?Nh>3NhN;Nh^800]kQ
hQkoool01^GJfnGIf>GJfnGLgNGLg>GKg0OUg=d00nGLg>GLgNGLg@03iMcM01oTf=SUf=cTg=cT`<3P
`<7Tg=gRf=SPe=G6d]?Pd/3Tfl3Ug/3T`<CQb<SRb/CP`<3P`L7T`=g8d=K9dM79`L70`<34`<G8TYC8
P9G8RY38RI30PXC4QX38PH78P9000/^AT00;`820b8>7b826b830b<32b<34h<30il32iL32i<30a/70
00;P`<001^7Fe^GHf>C@e>CDe>7Ad>32`0SUg=d01NGHg>GLgNGMg^GLgNGMg@02iMcM00?UgMgUg=gU
g=d00^GLg@03iMSLiMcMiMgM00;Ug=dXoooo000Voooo00WNgn3Nh>7Nh>3Nh>7NhN;Nh>3NhN7NhN;N
hN401=kQhP0lg^3Pg^7Rg^7Rg^3Rgn7Rg^7Rg>3Pg^7Qgn;Rh>7Rh^GVh>?Sf=c0emSIeMOGf=SHg=oO
g^;Qj>3/k?;`k_7^i>30j^GLi^3IiL7Ii^;NjNGRhN3Pj>GRhMoMgmcHgM_Igm_Hg=3@fm?CgMGE`M7F
h=[EgMWEgM33fM?>f]7<`];@iMkJi]kIhMSCfm7=elg7e<S1cl6ld<:ld/22e/_6f<k8d<c7e/_5dlS1
a<30gn;Rgn7R0mkQhP04g^3Pg^7Rg^7Rg^3P2mkQhP03g^3Pg^7Rg^7R00;NhN8Noooo00WUf]_Uf=cU
fm_UfmcUg=gUfm_Ug=cUg=gUg=`01>GLg@03iMSLiMcMiMcM00?Ug=d0=NCJf>GKg>KMgNK0`NSPhNKN
gn3Be=oCdmkAdN3@dn?IfnGMgN7Xj?3_k?K]j>C4do;PenkKdn3Jd>gMfNkQg^[0`>gPg^OIfNCFfN;E
e^CEeN3Bd=o?cn7@dn7AdNOEd>;DdN;@b>7>b>;<a^7@d>cIe^gHeNSD`^C;b>38`<32^=Vl]M^l]=f2
^=o6`>78`/?6`>35_]k2^]V3^NGMg@04iMcM00CUf=cUg=gUg=gUf=T;iMcM00?Uf=WUg=gUg=d00^GL
gBSoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00_ooo
o`<0001Zoooo0030oooo00<0003oooooool0JOooo`00=Oooo`<00002oooo00<0003oooooool00P00
00;oool400002_ooo`800004oooo0P0000Coool200000oooo`@00003oooo100000;oool300000_oo
o`@0000[oooo100000Coool300000oooo`<00003oooo0P0000;oool2000000Goool0003oool0003o
ool00`0000Coool200000oooo`<00004oooo0`0000?oool400002?ooo`800004oooo0P0000Coool2
00001?ooo`@00002oooo0`0000;oool400009_ooo`00=_ooo`040000oooooooo00000_ooo`040000
oooooooo00000_ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo
00000_ooo`040000oooooooo00000oooo`030000oooooooo00;oool010000?ooooooo`0000;oool0
0`000?ooooooo`04oooo00<0003oooooool0;?ooo`040000oooooooo00000_ooo`030000oooooooo
00?oool00`000?ooooooo`03oooo00@0003oooooool00002oooo00L0003oool0003oool0003oool0
00000_ooo`040000oooooooo00000_ooo`030000oooooooo00?oool010000?ooooooo`0000Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000;oool010000?oo
ooooo`0000;oool010000?ooooooo`0000;oool00`000?ooooooo`04oooo00<0003oooooool09_oo
o`00=_ooo`<00003oooo00<0003oool000000P000005oooo0000oooooooo000000[oool01@000?oo
ooooooooo`000002oooo00@0003oooooool00002oooo00D0003oooooooooool000001?ooo`040000
oooooooo00000_ooo`@00003oooo00<0003oooooool0;?ooo`040000oooooooo00000_ooo`@00002
oooo00<0003oooooool00oooo`040000oooooooo00000_ooo`070000oooo0000oooo0000oooo0000
00;oool010000?ooooooo`0000;oool00`000?ooooooo`0300000oooo`@00002oooo00@0003ooooo
ool0000:oooo00D0003oooooooooool000000_ooo`040000oooooooo00000_ooo`040000oooooooo
00000_ooo`030000oooooooo00@00003oooo00<0003oooooool09_ooo`00=_ooo`040000oooooooo
00000_ooo`030000oooooooo00?oool300003?ooo`040000oooooooo00000_ooo`040000oooooooo
oooo0P0000?oool400000oooo`<00003oooo0P0000?oool40000;?ooo`040000oooooooo00000ooo
o`800004oooo0`0000?oool200000_ooo`<000000oooo`000?ooo`0400001?ooo`800003oooo1000
00?oool200001?ooo`<0000;oooo00@0003oooooool00002oooo00@0003oooooooooool200001?oo
o`<00003oooo0P0000?oool400009_ooo`00=_ooo`040000oooooooo00000_ooo`030000oooooooo
00?oool010000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`00017oool0
0`000?ooooooo`0foooo00@0003oooooool0000eoooo00<0003oooooool01_ooo`040000oooooooo
00000_ooo`040000oooooooo00002oooo`030000oooooooo033oool003Goool400001?ooo`<00000
0oooo`000000000200002_ooo`800004oooo0P00017oool20000=oooo`@0000eoooo0P0000Woool2
00001?ooo`80000;oooo0P0003;oool00?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]
oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]
oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]
oooo000Voooo00[QhN7Qh^;QhN;QhN;Qhn?QhN;Qh^;Qhn?Qh^;Qhn<2hN;S00?Qhn?Qh>;Qhn<00n7S
h`?Phn<0:^7Shn7Rhn7Shn7ShmkPh=gOh=gOgl3QhN7Si>;Ui>SXj>[^kN[]jn31b>SIc>KGbnKFcNKI
d^SKe>3HdNOLe>CIdn?Gd]oEcn7Dbmk2b=g<aMc=am_:`=k<`M[:`=W0^]S4^mO2]mS4^][5_=[5^]W0
^=Fm/m>m/M:h[]2dZP;?]:X01/nf[<jfZ/2dZljfZ/jfZL20X@GQhn<02>7Qh^7Shn7Shn7Qh^7Rhn7R
h^7Shn7RhP;Qhn<00n7Rh^7Shn7Sh`02hN?S00?QhN7Qhn?Qh^800^7Shakoool03^OLgNOLg>OLgNOL
gNONg^OLgNOMgNONg^OMgNONg^OLg^OMg^ONg^OLg0?Wg]h02NONgnONg^KLg^ONg^ONgnOLg^ONgnON
g^GHg002i=[J02?Ug=cWg]oXh>3]hNK^j^Waj>K/d<;`e<K]d/G/d<S]e<g^em3/d/3]em3Ze<kYd<kU
d<[WclKTb<3Sb<3Rb<;Q`H3UakcQaK_P`;3P_kGO_K7PP;CS`;KS`;CP_;7N]jcL^:[L/:OI[j<00]R_
XP06fK2Uf;2Sdj2Tf;2Sek6QbJ:A0^ONg`?Wg]h02>OLg>ONg^ONg^OLgNOMg^OLgNONg^OMgP;Wg]h0
0nOMg^ONg^ONgP02imkN00?Wg=cWg]kWgMh00^ONgRSoool002Koool03^7QhN7PhN7Rh^7PhN7Sh>7P
h^7PhN7Shn7PhN7Shn7Rh>7Rh^7Shn7Ph0;Qhn<00n3Shn7Shn7Sh`03h>?S03?Ph>3Ph>;Phn?Ph>3P
h>7Ph>;Ph>3Qhn3Ph>30h>;1a^32`l30P830RJC1R:S0R:S1`870`8;0P830`X;2a8CP`H3L`H3KRJWB
P:3HP:C@PZC1X83@Zh74YX30X831X837S8G1P02:QQ:8Q1F0P130Pa33Q1G4P078PH31P831P031P124
S0R0S0R5SPR4P0F042SQhn?Phn<00n7Sh`03hN3QhN?ShN?S00;Qh>800n70h>7Shn7Qh002hN?S00?Q
hN3Qhn?Qhn<00^7Sh`05hN3PhN?ShN7PhN;ShN?S01koool02^OLgNOJg>OMg^OHg>ONg^OLgNOHg>ON
g^OHg>ONgP;Wg=`00nONg^OLg>ONgP06imkN00GVg=kVf=cVg=cVg]kVg<000^30`00/h=k1imkNi]cN
h<30hL72h=KH`828h8B@h82Qh82Rh8B/hHR/h8:Xh8VXh<2`h8R^h8BYhH2P`828h;B>f;2@dJR1eZJ2
dj21`821dXb4a8R0`8@@`883TH40P804`8X2`X08`802`8`8`I08`8P0a8/0`8T0`8P0`8X0`8`5T00P
imkO1>ONgP08imSLimkNimkNimcMimcLim[HimcNimcL0^ONgP03imcLimkNimkN00;Wg]h01NOJf>ON
g^OLg>OLg^ONgP0Xoooo000Voooo0^7Qh@08hN;RhN3PhN?ShN;RhN7QhN?ShN7QhN?S0^7QhP04hN?S
hN7RhN?ShN?S0^3Sh`?Qhn<01N3Shn3PhN3Qh^3Shn3Pi002h^GU02cPh>CQhn?Ph^?LgMoKgMkJg=kH
PI[L^Z?M^jSL^:?M`;7L_JoL_JkM_joO`K;0`;3K_ZkI_:WB]JCK]Z;C/j7@Z97@YXo<Whc3VX3;VHK7
Uh;1Q7RnSGRkQg>hP72nRgG0SWW2PGS6T7_3SgZ3R7G0RgJmRWBjR7BkRWBlRW24RSCPhn<4hN?S00SQ
hN;Qhn?Qhn?Qh^;QhN;Qgn3Qhn?QhN42hN?S00?QhN7Qhn?Qhn<00^7Sh`05hN3QhN?ShN7QhN;RhN?S
01koool03^OLgNOLg>OMg^OKfnONgnOMg^OLg>ONg^OLg>ONg^OLg>OLgNONg^OLg@CWg]h3imkO00GV
gMkVfMcVg=gWg]kWg/000^SPh@0;imk0imkOi]gNh]SJh]OIh=OJgK2Eh;FMh[NRh[NPh[^[00;R^:P0
7^:jZ>Fm[>BhZ>2iZ=ngXl2`Q^6aVmR_V]2PPMFQR=6KQ<^A0LnEOlZCNl60L/29LKf4K822K<67K/::
LLB8L<Z<LlJ;Ll:1H<>8Kl27KH24K;j7K;j6JIF680GWg]h02>OLg>ONg^ONgnOLg^OLgNOJfnONg^OL
g@;Wg]h02^OLgNONg^ONg^ONg^ONgnOJg>ONg^OLgNOLg^ONgRSoool002Koool03^7QhN7Rh>7Rh^7O
h>7Rh^7Rhn7Rh^7Shn7Rh^7Shn7Ph^7Qh^7Shn7PhPOQhn<01N3Shn3Qh^3Qh^3Shn7Sh002hN?T02GQ
hn3QhnCPh^?Hg=gLg]kNh^?IPJ7N_ZWO_jgOP:3O`kGN_k7N`;3O`[?P`[?0PJ7K_ZoI_ZkH^J[M]jKE
]:7EZ9SBYY;>Whk8W8S:V8O9V8O3TXC4UhG1SGbkS7S0SgfoSW_1T7_5Tgk2T7_0SWP00/6?N`05_8ah
_Hii_8]c`820h>?S00CQhn<02>7Rhn7Shn7Shn7Rhn7Rh^7PhN7Shn7QhP;Qhn<00n7Qh^7Shn7Sh`02
hN?S00GQhN7Qhn?QhN;QhN;Qhn<07_ooo`0>imcMimcNimgMim[KimcNimgNimcMimkNimcMimkNimcL
imcMimkNimcL1NONgP06imkOimkNimkNi]cLi]cMi]kN1NONg`0Si]gOh]3AhmSIi=cOh;BAi;VSiKZW
iK^PiKj_hk^[i;VXiKf/i[f/i;RXh;VYg[VX`[2Qhk>OfZnKfJ2@ej:;di^7`Y:0ciB0cYAobi9lb9=m
aHUdPXUa`hae`XYda8a`bHmfaHad`8Y`00;5Rg<01<28LL2:LKn8K<R5P0GWg]h02>OLg^ONg^ONgnOL
g^OLgNOKg>ONg^OLg@;Wg]h02^OLgNONg^ONg^ONg^ONgnOLg>ONg^OLgNOLg>ONgRSoool002Koool0
2^7Qh>7Ph>7Qh^70h>7Qh>7Shn7Rh>7Shn7Rh>7Sh`;Qh>800n7Shn7Ph>7Sh`04hN?S00GPhn?Qhn?Q
hn?Ph^3Ph>800^3Sh`09h>;Sh>;Rh>3PhnGTh>CTd=SHf=cLhN3P`82P00;P`k008n30/>30^=o0]>30
/>34/=o2/=b0X=RnX=N0/=RhX=bhZMJaX=RPP=2PT<62T<20P<VHRLZHPL20P<6RT<R@P82@P<2DQh6@
P<2@P<BHPL:CP<2@1<6@P<2DP82@082AP8:@0<B5T>3Sh`04hN?S00SQh>3Qhn?Qhn?Qh^?Qh^;QhN3Q
hn3Qh^82hN?S00?Qh^;Qhn?Qhn<00^7Sh`05hN;RhN?ShN;RhN7QhN?S01koool01^OLgNON`>OLgNOJ
fnOLg>ONgP?Wg=h01NONg^OLgNOLgNONg^OLg008imkN00?Wg=kWg=gWg]h00^KLgP0^i]gNi]g0j>3P
imoPh=3@h]KFhN7Pi;ZPhH:Ph8:Th82Ph<2bi;fPh82Ph82`iKf/h;RXgkRYgKRPh;2Xh;6SfJ6L`Z20
f:22eIZ8d9R0`9B2dI20d820d8B2a8H9`X00`i88a8aha900b900`8=h`85db940bY00`800`h@0`X1`
`828imkNimkO0nONgP08imk0imkNimkOimcNimgNimcMimkNimgN0^ONgP0:imgNimkNimkNimkNimkO
imcNimkNimgNimcLimkN:?ooo`009_ooo`0>hN;RhN?PhN;RhN3QhN7QhN?ShN?ThN?ShN?ThN?ShN3R
hN;RhN?ShN;P1N7Sh`06h>?ShN?ShN?ShN?PhN;RhN?S0n3Rh`;Phn<0:N7Ti>;UiN;TiN;UiL70/N;7
]N76^>74/>77^]o3]>34/N;5^=o2]Mg0/=_1]=W2^Mfo]=nm/MVjZmbaZ=J^X=FXVm:QTLfPTm:QU]BP
V=B[W]6NU<FHP<NLSl>DQl2IPlNNRl>IR<FBQ/JJRLRKR/:HP<>JRLNNSn3>d003h>?S0^7Sh`03hN?P
hN?ShN?S00?Qh^8<hN?S00?QhN;Qhn?oool07Oooo`05imcMimkNimgNim_LimcM00;Wg]l01nONg^ON
gnONg^OLg>OMg^ONg^OLgP07imkN0^ONg`03imgNimkNi]gN00?VgMh0:^KNg^OOgnSPh>SOh>SPh>J0
Z^S2[nS1/^30X^S2]>Fn[^J2YNS0/^Fm[n6lZ^6m[]nm]>2jX>FhZmnfYNBPX=bZV]^SU=RPQ=>KRmRL
SmVRU=ZVV=NIS<bDP/fGR<V?Ol6DP<fJPlVEPLVA0<bFPLjGP/RD0<VEPLfJR>3:b0SWg]h01NOLg^OM
g^OMg^OLg^ONg`02imkN00GWg]oWg]kWg]kWg]kWg]l00^ONgP03imkOimcLimkN02Soool002Koool3
hN;S00?Qh^;Qh>;Qhn<01>7Sh`04hN;RhN;ShN?ShN;S2N7Sh`0ahN;ShN?Sh>?Sh>;ShN?T`>3PgMoO
h>;Rj^7QjNg]h=oN`8>/hLBah<>bgl:`h<Beg/6``L2ahL>fgl>eg/6dgLFgg<Bjg/:fgl:eg<6bg[RT
fKFWfJnRd:20dJNIeZFJeJ2IeJNJdZ2CbYR:bIR;aI>6`961aib9`i^:a9R6aYV7aYN5`921a9V7c:NK
h>3PhN?S00CPhn<01n7Rhn7Shn7Shn7Qh^7Rh^7Rhn7RhP05hN?S00?Qh^?Qhn?Qh^<00n7Sh`03hN;R
hN?Soooo01goool3imgN00_Wg=gWg=cWg]oWg]oWg]kWg]oWg]kWgMcWgMkWg]kWg=h02>ONgP0bimkO
imgNimkOi]cNi]gNimkOiM[Li=[JimgMk^3Pk>SZim[Ji;^Pikn[i[n/i;bZi[n_i;bZiX2Qikn`iKj_
i82Phl2bh[ndi;b`i[f_h[b/i;2Xgk2Ph:^K`:BAf::Bg:2CfJ2@fj>CfIb<`960ciB4bhmnb901cIR2
b9N3biAoc9B0c9=n`91lbYEodj:Dh<C8imkO1>ONgP04imcNimkNimkNimcM0^OMgP09imcLimkOimkN
imkNimkOimkNimcNimkNimgN00;Wg]h00nONgnOLg^ONgP0Xoooo000Voooo00GQhn3Qh>3Qhn3Qh>3Q
h>800^7Sh`04hN?PhN?ShN?ShN;R2n7Sh`03h>?ShN?ShN?S00;Phn<0;N;TiL34a=3If=cNg?3dl>3T
l=cAb<21X<31[=k0Z]R0X=j1XMk0[<30/^33]>34/L30^>38P>31^>30^>34^/;8P>30P=b4Y<:0X<20
X=>VX=RZPm2PV=2QUMFTU<2HS<VDP<RDQ/2@P/RHR<2LS<BJQlJ@Q/2B0HB@0<JHQ]2`Z<3P`^7Si004
h>?S00OQh>3Qhn?Qh^?QhN7Qh^;Qhn?Qh>401N7Sh`03hN3RhN?ShN;R00?Qhn<00n7Sh>7Shoooo`0M
oooo00_Wg]kWf=cWg]oWg]kWg=cWg]oWg=kWg]kWg=kWg]kWg=h00^ONgP03imcNimkNimkN00KWg]h0
0nOLg^ONg^ONg`02i]cN02oX`>3P`<70d=3Tf=7`l?3Qh>CTa<;R^:3T_:KT_:3P^:3T^:ST^jKT_:3V
_ZkVPK7T`;3P`;;P`KCP`;CW`k3U`K3VP:CQ^:SP/:;0YH31XX3PXYSLX93LP83HPXg@U8CAT070T7k8
Q03=U839VHC8U03;Tgk8SW72Q738UGkHZ:;T`<3Wg]oWg]kVg]h00^ONgP07imSLimkNimcNimcLimgN
imkNimSL00GWg]h00nOLg>ONg^OLg005imkN:?ooo`009_ooo`05hN?ThN7QhN?ThN?ThN7R00GQhn<0
0n7Rh^7Shn7Sh`09hN?S0n3Sh`;Qhn<0;n3Shn7Ph>7Shn3Shl3Ph<o>cm_:`l22X=o1[Mk1[Mb1X=k0
/Mo1[l32]>33]N77^^78_>;;_n?8^^;8^>7<_n;=`N39PN36]n;3/l24ZMfjZ]jaY=RXV=RTU]VXV=2H
S/nGQljHQlV@Q<RHQlBKRlBIP<FHQlBEP/2@P/RLR=c;bL34a>3Shn7Shn3Sh`02hN?S00OPhN7Qhn?Q
h^;QhN;Qh^;Qhn?QhN401N7Sh`03hN7RhN?ShN7R00?Qhn<00n7Sh>7Shoooo`0Moooo00kWg]oWg=cW
g]oWg]oWg=gWg]kWgMkWg]kWgMkWg]kWg=kWg]oWg]kWg=h8imkN037Wg=kWg]oWg]kWg]kWg]oVg]kW
g/3Wg]oVg]kTf]_Hb<SRaKgR^:;U_JOT_:OP^:;T_:[U_JWT_:3V_joW`[CWa;3YakWYa;CX`KCWakWX
bK_V`;?V`K7X_jgP^Z3S]J?T[9gOXI7NWhoNY97BT8KDTWoCTh3>Q7k>Th39Uh?8U@3:U7o9TG_1T7[=
Uh7Sa/CUfL401NONgP07imcLimkNimgNimcLimgMimkOimcL00GWg]h00nOLg>ONg^OLg@05imkN:?oo
o`009_ooo`05hN?ShN3PhN?ShN?ShN;R00;Qhn<01>7Rhn7Shn7Shn7RhPcQhn<2h>?S037Qhn3Qhn?N
h>38h>3]l?3Uj>Z1P8FZXZ;J`[ON`:3O`[3O`[;0`[?O`[CPa;CP`;KQa;KQb;_Q`KSRb;cRa[SQ`KCQ
b[kRb[kPa;CPaKKQa;?0Pj[N^ZWN/J;HZYWIYYOJZI[@WH3@VHW?VXS8V838UhK3V8K0V834VHS5VXO4
VH;8WXcPf][2a/OPh^;Qhn?Phn<00^7Sh`03h>7Rh>?ShN7R00;Qh^800n7Shn7Rh^7Sh`04hN?S00?Q
h^;Qhn?QhN801N7Shakoool03>ONgnOHfNOMg^ONgnOLgNOMg^ONg^OLg^ONg^ONgnOLgNONg`_Wg]h0
6^ONgnKNg^ONgnONgnCKfnC3b?3/k^WTi/B0P;JKUn6m/>BkX^FmZ^FnZnBl[>Fn[^Jo[^Jn/>No/>O3
]NO0]>S3]^S1/^O0/>O5^>S5^0;V`K005nNo[N:jX>BfXnB/Vl2RT]nQT=nTTm6HP=JEPMBFPL:A0LfC
OlVCOl6D0<ZEP<^FP<ZE0/fJQ>GEe^30`^OMg^ONgnONgP02imkO00SWg=cWg]kWg=gWg=kWgMgWg]oW
g=cWg]l2imkN00GWg]oWg]kWg=cWg]kWg=d00^ONgP03imkOimkNimkN02Soool002Koool02>7Shn72
`^7Ph^7Rh^7Rh>7Rhn7Shn7PhP;Qhn<00n7Qh>7Shn7Sh`0:hN?S03?Phn?Ph^?Ph>CRi>CJg=c8d=3h
o?SPiN0@0001E5;H/J;0`;3O`[7Pa;3P`;7Pa;SQa[SPa;7PaKSQbKcQ`;3P`;3P`[C0`;;PaKSP`K3N
P:3NPZ?MPZ7H^Z3L/:;L[I[@ZYSHX9OHX9[1P83AW8[?W8W0V870UX73T060T832VX37PHc0WHc6X83R
h^S0`<3PhN7QhnCPhn000^7Sh`07h>;Rh>?ShN7QhN?PhN;RhN?ShN;P00GQhn<00n7Rh^7Shn7PhP05
hN?S7_ooo`0;imcNimSJimcLimgLimcNimgNimkOimcLimkNimkOimcL00[Wg]h2imkO037Vg=kVgMkP
g/3Wgn3Pe]OPa<Cin?[Sh>J00006D4WN/8CT_JSU_JgVP;3VP:3V`;3W`K3WP;7W`K;Wa;KWP;3VP;3V
_:kTP:3V`;CVP:;TP:3T^JWT^:?P/:3P/83PZ930X93NXY30XYC@V83FV8;EV874T0C=T7c8S770T038
UX3<V8G0V8C<V87VhN7V`<3Vg=d01>ONg`07i]cNimkNimcMimkNimcMimkNimcN00GWg]h00nOLg^ON
g^OLg@03imkN00?Wg=kWg]koool09oooo`009_ooo`08hN?ShL?PhN7RhN7RhN;RhN7RhN?ShN7Q0^7S
h`03hN7RhN?ShN?S00SQhn<3h>?S033Qhn?Phn?QhnCQi>CPh>3Ngn39a/PH2PR2JFCJ]jG1`;GP`kOQ
aK[Q`;SQa[_Qak_P`k?P`kOPa[[Pa;;PaKSPa[OP`;CQak[P`[C0Pj3L^j_L^j[J/:?K/ioK[YcF[9WE
ZIKFYiS>PX3@WX[?W8S8V8C8UH?4T7f2U872V8G6Wh_1W8_6XI7Pi^OPh>3Qhn@2hN?S0^3Sh`;Qhn<0
1N7Qh^7Sh>7Rh^7Shn7Sh005hN?S00?Qh^;Qhn?Qh^801N7Shakoool02nOMg^OJfnOLgNOLgNOMg^OL
gNONgnOLg>ONgnONg^OLg00>imkN02kVg]kWg]oWgn3Vg=kTf]_C`<250P67IE[O/YkU_joV_[3W`;CW
QK3W`KGW`kGWP[7W_[7W`KCVP[3V`;;V`K7VPjKW`[CV_JkT]Z3S]ZCR]j?P/X3Q[iWPZIGLZ93KYHoL
Xi7AVX3EVH?EUh74T@G=TG_9S7G4T7S7U7g<VXC0ThC<WH[UhN;VgL02imkO0nONgP05imkOimkNimcM
imkOimgN00OWg]h00nOLg^ONg^OMgP03imkN00?Wg=kWg]koool09oooo`009_ooo`08hN?ShN3QhN7R
hN7QhN;RhN7QhN?ShN7Q0^7Sh`03hN;RhN?ShN?S00KQhn<0=N3Shn7Shn3Shn3Shn7Shn7Si<3PhMoR
h^[^k/W0`;Vg^:FLWI060:J<PMflZn33]N33]n75^N70^>76^N77^N32/]o1/mo3]n36^N3:_N3;_>38
^^;9^^34]L:1X]^fY]^gYMRaQ=R_W=V^WMB^V]:ZUM:WU<V1R<jMRLjJQlRIP<REPlFBOl6DPL:FPLBJ
Q/:JR<NQTMcJf<?Ph>7Ui`02h>;R0^3Rh`;Qhn<00n3Rh^7Shn7Rh`07hN?S00?Qh^;Qhn?Qh^<01N7S
hakoool00nONg^OJg>OLg@03imcM00GWg]kWf]cWg]oWg]kWg=`01^ONgP03imkOimkNimkN00;Wg]h0
=>KLg^ONgnONgnCLg>OLgNkYjlW9bLF`[k>ETJ1dHZf6N>>gYNJo[nJo/NO0/nN4/^O1/nO2/nJ0/>Jk
[NFn/>K0/nK5]nK6]^34/>O4]>G0[^>1YN2bWn2bW]jPUMj[UMjZU]ZZT]NVSMNRS=6IP=>IPMBEOl6D
0/jANl^>MlJ@NLNAN/VEO/^@PLfMR^?Ddn33`^OPh^KMg^KLg@;VgMh2imkO00?WgMkWg]kWgMh01NON
gP05imkOimkNimcNimkNimgN00GWg]hXoooo000Voooo00CQhn?Qh^;Qh>;Qh>42hN3P00GQhn?Qh>7Q
hn?Qhn?Qh^<02>7Sh`0gh>?ShN?Sh>?Sh>;ShN?Th^CUg<32f]cLl?GdX:2P50<A0U1@P800c86Ph<2a
h<>dh<BhhLB`h<6`h<2b`<Bd`<2`gKb^gKja`<B`h<c0hL30h/R0hl:b`<:aa82Pd:20dJ20d:60d::@
dZJHd:2@c:62b:2:`9R0bIZ4c9F4`920bIF2`9B1Q9@0`Y9l`940`920aj20dXR4`<34hNKPgn3P`N7Q
00;Ph^<00n7Si>7Shn3Sh009hN?S00?Qh^;Qhn?Qhn<01N7Shakoool02nONg^OLg^OLgNOKg>OHg>OK
g>OMg^OJg>ONg^OMg^OLgP06imkN03WWg]oWg]kWg]kWg]kVg]kVg=kWg]oP`>3Pf=[PeMKdl?:0XI60
2049ADF0007@R9SPPZCV_ZoWP;;W`;3VP;3V_Z3VP:3VPK3T]ZST^:STP;3Vb;[Vb;SQ`;SX`;3TPZ_P
P:3JY97LY97@PH3BQX3HX97FXH3AXH;2PH;0T031UGkBTGc0T03>T7_<T7W0T730SGG6PG3<T03<V8S0
QX7P`LSVh>?VfmSUf=`00^KMgP;Wg]l01NONg^OLg^ONg^ONg^OLgP03imkN00?Wg]oWg]kWg=h01nON
gRSoool002Koool2hN?S00KQh^;QhN7Qh>3Qh>7Qhn?QhN4>hN?S0n3Sh`0^hN3ThN?Th>;SP9RBQgQe
QVaVU9:0l]G2hlRihL>fhLFhhLBgh<6`hL>bh<BchLBdhLBehL:fh<BchLVmhLRlh<6fhKb^fk6R`8b1
diF7diF8d9:5ci63dIF8d9B8ci^8bib7aIR6b9Z6bIF2`9B0b9F3b9J3`9@1a99m`I1kaYB0aIb;cJjS
e/C00^7Si003hN?PhN?ShN?S00;Phn<00n7Si>7Shn7Rh`07hN?S00?Qh^;Qhn?Qhn<01N7Shakoool0
3>ONgnONg^OMg^OLg>OHg>OKg>ONg^OLg>ONg^ONgnONg^ONg`SWg]h2imkO00?Wg]kVg]kVgMh00^ON
g`0;i]gNXI20Sg9ZSFMJX8dPmm6njL>cikn`il2biknaiX2`00;V_j`05^O0X>No[nNn/>J3/NO4]nO3
]^J4/>NgYn:[W<J8RmV@PMZ@P]2<0=F=OMR@PM2@PMFGPM6GOl2DO/fFOljANlR@N0;=TG/01lB@LLV>
MLJ<Llb@N/ZHQ=FYW<K1T005imkO0^ONgP05imkOimcNimgNimkOimcN00GWg]h00nOLg>ONg^ONg`05
imkN:?ooo`009_ooo`08hN?ShN;RhN?ShN7RhN3QhN7QhN?ShN;R3>7Sh`0fh>?ShN?ShN3Pgn;Rg^3Q
hn;PjNc]alO8V8>2XHf4[966b:R:jlflh/JdhL6`hLFhh<BhhLBfh/>ah<Bah/2ailfoiLVlh<BhhL6f
h;bbg82XgJfRei^@d8<:d7mech5g`@9[cGmdcgedd81he8n1ciB4`Y61ai^7aYJ1Pi1laiF3b9F2`i@1
aI=o`Y5laYB2`YV7b:>DbH23h=gMh^KXhN;S0^7Ti005h>;Rh>;ShN?ThN?ShN;R00OQhn<00n7Rh^7S
hn7Sh`05hN?S7_ooo`0<imkOimcNimgNimcMimSLimcMimkOimcMimkNimkOimkNimkO2>ONgP;Wg]l0
=>KNgnKLgNGKg>SPh>[Yj]71`H24::R7NkB;O<2PP?39]^S1[^N0/>O0/^Jo/^N1/>NoZnJoZnO0X>[;
^N[5]nR4/>Nm/>Ng[>2]X>BXVmjERL0=0=IjK]IlLM1eH==jKMEhKM<5L=^:NmB@OL>@0<^GP<^BNL6<
M<bANlfAN/R@LL^?N<N=M<R@N/RDOlnNSL21X>KHf>OQhn70`P;Wgml01NKLg^KMg^ONgnONg^OMg@07
imkN00?Wg=cWg]kWg]l01NONgRSoool002Koool02^7Shn7Ph>7Sh>7Rh^7Qh>7Ph^7Si>7Rhn7Shn7S
i0WQhn<2h>?S03WQhn?Qh>CNh>3KgMkPh>3PhN2:PXB8002DX8KDV8;0`832Q:CP`Z3Pa;3Pa;SP`kKP
`:3PPZ[0P:SPP:3[e<KYcl;R`;3R/JO0X8SAP8CBUHO20WK0BT3<HTC8I4O1@438I639@D30H63H0g3@
P074P031T821TGfhR734UH;7U830U838T8;1T@36T020T0;0T0C0P03La<7Ph>;0h>3Qi>CRi>CNh>3P
h^<00^7Sh`03hN7PhN?ShN?S00GQhn<00n7Rh^7Shn7Sh`05hN?S7_ooo`04imkOimSLimkOimgN0^OL
g006imkOimcNimkNimkOimkNimkO1NONgP0mimgNimkNimkOi]kNimkOh<30iM_MhmOHh<30i>;QXX60
P01Qa9J0di23h82Ph;NVi[fRiX2`i/2bi[j`iX2Xi[ZPi;VRiX2Pjm20k/^mj8BPijFPiJ20`820`967
d05V`410d65B`65G`410`6=F`410d612`71Qd0Q``800`I80a85d`8APbY5jc81hbH1hcI5jbH5`b81`
a81h`HAd`800i<30j>3Rh/30imoOimoPi=_Li]gN00;Wg]h00nOLg>ONg^ONgP03imkN00?WgMkWg]kW
g=`01nONgRSoool002Koool01^7Shn7QhN7Shn7Rhn7Ph>7RhQ3Qhn<04n3Ph>;Ti>7Ti<72a<2l_Xf0
PH@>0=o2[_SLb^30PmZiZN32[n32/^35^>72]<22Z=^cW]^eWl2iX002h<:e01oL/:KNZJ3LX9[@PIKE
Thk>Ph78KVW?MWC;KfR>HeK7K6S3GeW4I5o9JFC5MFn506C0RW_1SgZ0PGS4UGo7TWo8U8C<VhS7Uh;0
T0C0TX31Sg_0S@SG_kONemCN`>001^7Sh`03hN7RhN?ShN?S00GQhn<00n7Rh^7Shn7Sh`05hN?S7_oo
o`0:imkNimcLimkOimgNimcLimgMimgNimkOimkNimkO2nONgP0eimkOimk0imoPimoPhMC0bKJfVGUe
UPUTiKjWnmW7h<2bh;BRi[fYiX6`i/2bikf]i;BQhJjGh[2IiK25ikf`ikf_i:6PiJBJi9ZEf9R@fhn6
eGmiaVUQeW5]dVYQa61@cFQPaea?bF5FcVELbg9W`71PaXIcaX]ba8U`bI5gc8igcY5ldIJ1c99kc81d
aHihaHac`8P0gkZaiM;?i=WL00;Wg]l01NONg^ONgnOMg^ONg^OLg@07imkN00?Wg=kWg]kWg]h01NON
gRSoool002Koool02^7Shn7Rh^7Rhn7Rhn7PhN7Qh^7Rh^7Rhn7Shn7RhPWQhn<0>n3Shn7Shn3Rhl73
h>GXinW/k<S0`8b2PhQeLh20Q^33[nkA`>72/=fjZ>34/n32/N76^>;1/<6bS=BUSmNZUMbaX=6XWM>`
XlZTP=ZSV]VOVL20TM>HTLnGUL6<R=:GTln5N/0:1LElN;]^I[1R@[ALEkEXHJM<@[elK/F9Ml2@0/BE
N/N?OLR@P/jNRlVIQ<:A1L>DPL:BO/2@2M2`XmO4^mKC`^3Ph]oPhN?Vi^;Ti002h>?S00?Qh^;Qhn?Q
hn<01N7Sh`03hN;ShN?ShN?S00GQhn<Noooo00[Wg]kWg=cWgMkWgMkWfMcWg=gWgMgWg=kWg]kWgMh7
imkN043Wg]oWg]kWg]kWg]oVgMkTf]_Zhn?/j>W1WL2JNWNCKFN8P8CV_ZWbcKcWRZ;S]J7V_jgVP;7W
`K;W_J[QZX3KX8OMYXkQZYWMWYOLZYc0R93SWICRV9CIR8CLTX[HTHoDQHCLShoHOWG0003=MW;2JUn0
AE:gFU2jIEVbB4W4MfK:QG33TW79TG;<RgG>T7_CVXC>U7g<QGG8T7[7SWK:Q@3GZicO_kG4b]3UfmgU
fmcYh>7XgmoVgMkWg]kWgMh5imkN00?Wg]oWg]kWg=h01nONgRSoool002Koool01>7Shn7Sh>7Ph^7R
hP?Qh>400n7Rh^7Shn7Ph002hN;S1N7Sh`0FhN?ThN?Sh>;ShN?Sgn7Rd<30iN7Vk?3`PX2@6040Q6eP
`82Qh<>a`8BT`820g[2Ph<Bah<2`hLJ`hX2T`:20aH@00/20P00XP0H5Q8j1P820dYbDe86Hb800dX6B
d:bZ`820d920e8b9`H20`hj0/800P610P518PUA4P000/FA1`09T`9P0`95`aXQh`920d::0bY^2b900
`924aI20b920`820bJ20`X20f]G0f=WJi>SPh^GSh>;Sh>?ShN?P1N7Sh`03hN?ThN?ShN?S00OQhn<N
oooo00GWgMkWg=kWg=cWgMcWf]`00^OHg003imcLimkNimSL00;Wg=h5imkN0^ONg`0li]cNimkOiMcN
`=3@j>3Rh>c^P82080@NT6EL`824i[jZb82P`H20i;2Ji/2`iX2`il2`h;RP`8B0a81Yd900`824`01V
aHP:`000`9B?h92Df000g9:@fJ6Tf824f860g820`8B0cHN1_0UZX410P454RE94P000PDY8c7AT`91`
aXeXc81``800eH22d983`800bI1lb900`980b908ahR2`8:0h=3Ch=?@j>3Sj>3Ni]gN1nONgP03imkO
imkNimkN00OWg]hXoooo000Voooo0^7Sh`03hN7RhN;RhN7P00;QhN400n7Qh^7Shn7Ph@02hN;R1n7S
h`0kh>7Rh>;RhN;S`>3ShN;Sh>;SPR0XCS<bXH9ghM22hLBaf;^YfK64g[FPhLJjhLBhhLFegk>Nb820
a8I``h=bP01][fQP_8QmT924e:BLe:>J`92:djJLe/>od<W0f<c5eZ^Jb;6ZajNP]iJ:X0=`Vf=HVEY?
RdU0Z5mD]VaQ`89`_hi_aXajb860e:RCd:B?bh20b9R6aiZ8`YR0`i=maiV5a8:2dlkEf=GIh>3QhN?S
00;Phn<00n7Si>7Shn7Sh`0=hN?S7_ooo`;Wg]h3imcM00OWfmcWg=cWg=cWg]kWfmcWg=kWgMh01NON
gP03imgNimkNi]cL00;WgMh0>nCLg^OMg^KMgh0P94`a:j]jK?30^NNoZmneX/:TU>B`VNO1]>N0/>O0
[nF_Um:32LV2J<YmJ/40H;YPF<B3MM601^2LU^2KUMV2PMfOU]bn^=[4T]_9_]bVU=6TX]6QVL6@PJae
H:9NDieGAh14<[1GC;aXFLH5HlB:Il^8L/2@0]ZSS=JOR=6D1<jDO/fEP<2C0/J?M/bEO/Z9RMW9d=k@
e>KLg>ONg^ONgnONg^ONg`05imkN00GWgMkWg]kWg]kWg]kWg]l01NONgRSoool002Koool00n7Shn7R
h^7QhP02hN;R00GQhN7Qh^;QhN;Qhn?Qh>400^7QhPGQhn<0?^7Rh^7Shl3PhN3QhN?Thn3Ri]SJgLc<
c`5@0WMLF;bMS^S<^>?5/MbnZmRbP]bcW^75^N74^N33/mZXUL2@1l:4KkUbHj95@ZmRF<27O<2HS]N`
YmJVW=6PUMBXW=W1^mC0T=Nk/M>OT=2XZLj/Y<6HSKB@PZemLIiUF8=1@IYOEJ5NDZ1S@[f:KlJ?OLR4
PmJYU]>YUL25R<RHQ/JHQ/2@P<BEP<NHQ<B3PL[4cMG@emSGf=kPhn7Si0OQhn<00n7Rh^7Shn7Sh`07
hN?S7_ooo`05imkOimcNimcMimcMimcN00?Wg=d01>ONg^OKg>OLg>OLg@GWg]h0@>OMgNONg^CJg>KK
gNWOg^GPhmoDemO6a`Y5@WiFCLJFQNg8/>W0Zn:iY>2PV>:^V>O0/nO0/^Nn[>6SS/B2KlR0Il5[G811
@kILClN2MM>@PN:YXN2OU/6@T=fRU^2l]L:8PMjeZmZIR]RRX=NVWL^BQXJ:PKIfJZAPD9Q23jEDCjMJ
B[A@D<:5Il^;MLB01=bUSmVUS]:0P<jDO/bDOlb@0<RANLbDOL>VV]2nb=[;d]kBd>CKg^ONgnONg^ON
g`GWg]h00nOMgNONg^ONgP07imkN:?ooo`009_ooo`06hN?ThN7PhN3RhN;RhN?PhN3R0^7Rh004hN?S
hN3QhN7QhN7Q1N7Sh`0ohN3QhN?S`<?PgmkPi>CP`<30`934X9:Q1000Q823b9:Y`8JPh/2]`<2Zg;60
f[6NhLBahL2hh82PdYJ5P81X`X9`[F5DP000/4ABa8P4e8:0fXBcf:Z2`820d:ZM`;R``820dHN8cH06
dj2Pd;2Ta9R@`X60SHR:Y71RP040R61DPD04P000/PAP`840`8N0f:ZAd::J`:60b9N5a9J0a800`9R0
`9R4`8B0PJV0`HW0`<30f=SQh>CThN?P00KQhn<00n7PhN7Shn7Sh`07hN?S7_ooo`0<imkOimcLimcM
imcMimkNimcLimcNimcMimkNim_LimcLimcM1NONgP10imSLimkNi=[KiMSKj/3Lh<30b8>;P8:@@000
T88Pd92Ph82Pj;fPi;^Th:2Hh:bGih2ai/2`i[VRf946a01P`@5X/5Q>P000/41:`81e`820h86Uh:2H
h82PgZ2@h;2PhX20g822e800h:20`:R0eY::`820`862Y692P010V59BP4DdP0P0P01T`HYe`888gZJ@
g:R@dH24cI=mbY1ibH1`bY@2c9Am`820`:2da831a8C0`]3Mh=oPimkNimcN1NONgP03imSLimkNimkN
00OWg]hXoooo000Voooo00WQhn?QhN7Qh^;Qh^;Qhn3Qh^?QhnCQh^;Qhn<00n7QhPGQhn<0?n7QhN7S
hl7Ph>3Qh]kNh9RDT:2IWhIhO2031=bm/_;F`=^nZ=noZ^2mZ=baX=VaW^33]>70]]jkZ]2CQ;l4J/R>
OkQiKH10B<1kKM>ISl2YRMo6^m^cYl;6P]Z`X^6f[<6QT=>FQlj;P=ZTW=NXVmJES=2EP<jVUK=oKh@0
291YH8A9?Q<48:ebHkZ1L/:0P=V]VmVbWm:RRLRHQLJFPl270/RIR<RGQL28Q;FY/[f`]lR4`]GCfmoQ
hN3Sh`06hN?S00?QhN7Qhn?Qhn<01n7Shakoool03>ONgnOLg>OMg^OMg^OLg^OMg^ONgnOMg^ONg^OL
gNOLg>OLg@GWg]h0@>OLg>ONgnGJfnKLgNGIflJ0P;:@TIU_K2@06>>g[??D_>:hY>FjXnJhX^2QVMn/
UnNn[^N0/>BfXmJ?O<@0H/n9MlI^IZ105<UeIMZDRN2PPNC2]N:_X>C0^>2[VnV`Y^2BT=b@P=F5N^FN
T^2QUMn>Q]RCR=JPSKaiIY`@EYmKFXQ6=aPQ5KE]F/5lJ/>?0=nXU=n^V=>RP<fCO/^ANlR2L/jDP<jC
O/F05[bTZl>[/L2hR=_>enGLgNKNg^OMgPGWg]h00nOLg>ONg^ONgP07imkN:?ooo`009_ooo`05hN;R
hN7RhN;ShN;ShN?P00;Qhn<00n7PhN7Shn7RhP02hN;R1N7Sh`0ohN7RhN?Sh>7Qh^GUemKMP30eOFmc
K5IG4R0Pg;^`jm2jg[j/g;bWgkVVg;>Qf;6Nh<:`h82`gKRWciF3PPIZcYV:bYb>PH40cYR:f:JLf[2P
g/:fg;V/`<2hfk:Uh;>Y`:B4e9f<dI>6d86@dYf?dhn5`8:0b9F4^Wi_Y0<0X71UTE5602PPY6EG/FmR
`hh8fJjMf[6Nd:B;b9R6aiJ4`Y01aiF3b9F3`825/ZBY[YjRaX>@dLcDgMcMh>;S00KQhn<00n7Rh^7S
hn7Sh`07hN?S7_ooo`0<imgNimcLimgNimgNimkNimgNimkOimWLimkNimgNimcNimgN1NONgP0oimcM
imkOi]cLj>3PgM7HVR8/SVIRNDi850d1hkJZklfdi;RTh[NPiKBOhZ:IgZfGi[fZi[^XhkBPeI5la09P
eIB3ei69`P<0fI24h:6Fh:FPi;f`hkBUi8BbhJfOj:fSbHj0g9N6f8f0h9B0fiN8fhUoeH0Cd8ml`WQW
Q@AHZfENUTdo4B8<Zem>^FUK`8X0gjZFgjfGeZ20cIAnc99l`81acI1lcY5kbH0>^InR]YVJa8:8elO?
hmOHi]cN00KWg]h00nOLgNONg^ONgP07imkN:?ooo`009_ooo`03hN7PhN;RhN?S00CQhn<00n72`>7S
hn7Sh002hN?P1N7Sh`0ohN;PhN?Th>;Pi>WW`<OA0000D0@0D28T@000fKRY`hNPh;bXf;RTg[BUg;2P
ek62g/6Y`;RPf[BP`9R4`81PdJ6Db<21`820a920`X6Rg82Rg[RQg86`g82Pg;:XgjfP`:60eJ>@dH20
`X00bH01`81h`000P@1P`WQ`P01PP7IZX49A02TPV514XUA2P803d:jLf:bHd:B8b9V6aiJ4P900aX1l
bI20`820X820RP43P820c<C9f=K@h>7R00KQhn<00n7Rh>7Shn7Sh`07hN?S7_ooo`08imcLimcNimkN
imkNimcNimkNimcNimSJ2NONgP0oimcNi]kOi]cLj^CSaL;51P@0@@4QB28P0080`K6Sh86Sh;2P`;2L
i;2Nh[20gJ2Hi;bTi;2Ph;2LeI<0`01PfZ26hYV[h:20hH2ThJbPi;2Pi;2Si;R[h;2Xh:2Ri:RL`821
fh::f960d800aH=`dP=a`01PQg18b7MX`01QPG1PYD10020PPT@1ZDQ1`81Xg:ZFgZRA`:24cYAncI9l
a81`b8Q`cX1j`I40]YR@PP00b820dh35`=3Bi]cL00KWg]h00nOLg^ONg^ONgP07imkN:?ooo`009_oo
o`03hN7QhN?ShN?S00CQhn<01N73h>7Shn7Si>7Sh>7Si004hN?S043Phn?PhnCPhn?Ph>7Ph^?9`<T2
@41^D4U`B41aDDCK^Z[I_:SR_:SI^JKN^:WL^:WI^JOO`Zc1^:SJ]J?BWhc8PGWGYYOUd;gVa<CZe/WT
b;g0R;3N^jkN`[KM_:kO^JoN/:;DX9;DYI;EXI32S0S9RWO:QgS1066jMFG5OW78PG33PW6dLVB0@4:O
GDfUFdj8P73DZYKGZYO@XXS8UXC6U861T7S5Sg_8Th72V8R^W9U^GEbBP8?Fd=GNg=gQhn06hN?S00?Q
hnCQhn?Qhn<01n7Shakoool03>OLgNONg^ONgnONgnOLg^ONgnOMg^OJfnONg^ONgnONg^ONg`GWg]h0
@>ONgnONg^ON`>KMg/nka0Q08WA:?G=3=X=00^2fY>6fXNRcY=neX>FcXn2`X^2dX>FmY^F`X>2`W=RK
QL28LMbRT>G@]NWQa>cDa>W4]nB2X^FfZ>Fm/>6`Z>FdZNF[W<:4P=VQRm^LR]280Lj5L=23L<9hHKib
GLYjJM20JLJ2Ika[GII00ZEHAJaEA/20H=VUSmfVT=F6PLfBO<^?N/B<L<Z;Llf?NLf@P;FGTGEGDIR<
S]_;d>?Gf>ONg^ONg`GWg]h00nONgnONg^ONgP07imkN:?ooo`009_ooo`03hN7RhN?ShN?S00CQhn<0
0n7Qh>7Shn7Si006hN?S043Phn?PhnCPh^;Ph>GJemc:^[bH1`6QPWFONFfPBc7N_jcK_:WQP:WL_:[O
_JkOPJ7L_ZgOa;31P:7K]ZGEXi;:TP?BW8[K]j?T`X7WdlKSbko0`KCO_k?O`[KNP[3P_[;O]:CAXY3B
XHgDX8o2P0c:TGg9SWZ4QW6kOfg1PW;5P7?0QG:gO6Z4HE2ZKEZ/JeR5P73@Y8gEZ9G4X8;7Th73T7n1
P7S4TW_6U876VHF^W9YBA4J0TiKRhN?TiNKPhN8@hN?S7_ooo`0<imcMimkNimkOimkOimkNimkOimkN
imcLimkNimkOimkNimkO1NONgP10i]kOimcMi]kPh=;Gd;FfX@1PZgYYZG5QYdHPhk^Vh[NRik>Th[RT
i[RXiKRSh[VWiKnZiKVShK:NfYn;d89cf9N3gkBLh/Rajm31jLNiiXF`i[Z]i[f`i;RXi[V[iK2N`8J0
f9b5fY^8d8`6d8afcXUc`X9Y`7]VaWiZb81Xa8=Y_WISZUQ4/FQB/fEA`81PeYn6fj>>d8>0cHmibHag
a8Q`bHecbhmib9Em/iNBEclkPXj2i]cOjN7Rh<30imkO1NONgP03imkOimkNimkN00OWg]hXoooo000V
oooo00?Qh^;Qhn3Qhn<01>7Sh`03hN3PhN?ShN?S00;Qhn<2h>?S0^7Sh`0Ah>?Ph>?Th>3P`>3Pd<C3
bk2TT826eiR0d8B2`820g/2/g;ZYh82/`<2Sh<:`h<2``/:`00;P`;00;MbhX]RXP<20P<R0ML280<20
P<C4P>3<P>38^N32/>30]<30/^30]=niX]2PT=2IP=2LS<20P<^HP<F@OH20L;b8M;B5L[B4H;R0L[R4
L8H0J88>H;D8HH20L<RJ1M2RT<20P<N0O869N<2<L<2DN<6DP<2AQ:jHVB4P90401>3`hnSPh>3Sh`0@
hN?S7_ooo`03imgNimkNimkN00CWg]h00nOLg^ONg^OLgP02imcN1NONgP0oi]kOim_HiMS0dhK6d:f8
`824gY26dX>F`820i;bTh[JSi[RPi;ZXiX:Rh82Ph8:Ti/6RiX6Ph;:P`:2@d800`XATa801`820h8Rb
i/2hil2`iX2`i[RPiX2PiX6PiK2Pf:60e941d9R4d800d900b91eP81P`81TP85XP81PPH=ZP89XQ11P
Q0YQP018`81Td99hd869d900c8Uda85`a8QPaY1`b8mh`91l/Y2@:0P8P414l>3Pk>SXhL;200KWg]h0
0nOLg^ONg^ONgP07imkN:?ooo`009_ooo`OQhn<00n7Ph>7Shn7Sh`06hN?S03oPhn?Qhn?Phn?0`L?C
a<KE^ZWLWX_oflChdl30TZCN`jgN^JWP`:3QaKKQbK_Q`[SRb[oPb[cPb;WO_ZkL/JCBTHc;Sg[7Qg70
PX3L_k7ObKcPbH3Qa[WQ`;GP`;3QbKWO`joBXhGBWX[AWhg0Q87:WXW3V7n0Q7RlSG^fQW6dQ62iRG2m
SGK9Tg[5Tg[2TGS0T07;Vh7>X8g8V8K7SWc0S7_0S7S0UGg2U7o0T8BYThlR6R4P4R3Tj>SRiND04N7S
hakoool00nONgnONg^ONgP03imkN00KWg]oWg/3Wg]kWgMkWg=kWgMh5imkN0^ONg`0li=SFfKo1fkFS
i9R1om[2n=>mch2PiKjVi;FSi[ZSil2`ilBeh<2dj<JiilFfi/6ciKVXhZfNf8V0dH]bc89Yd98<i;V[
i/Bfil2bil6cik^_i/2QilBciKjY`J:@eiZ3eY^6d820d9Z1b9AgQH1U`HQc^h9X^X1P_h=X`HY]b95`
b95baHm_bH1adIMie9^5d9Anc8YeaHQcaXQ`aY5eahmh`I9m[Hn88QLF;@D7j^?Sj>3Q1nONgP03imgN
imkNimkN00OWg]hXoooo000Voooo00?Qhn?Qh^;Qhn<01>7Sh`03hN;PhN?ShN?S00KQhn<0@>7Rh^7S
hn7Win32`][8`mc5/^36/>c3[>NoZ/21XMo3[]niZN31Y>76^N7:_>79_N7=`^3;_^38^mo1/]ffZ=:T
PM2JQL^@N/20PMZjZn35^N78^^75]n71]N30/>7;_>35]=J/R]BSTM6RSlZ3P<RJQL6DOX60L;Z7M[J4
KkB1H;^8KKj8MLB1N<BCN/FCO<RHQ<fOQlfLR/VAQ<J@O/6?OL2<NL6CO/:DO/:FPJ:9PRPL8A@21/o@
dmGCe<31`Q3Qhn<Noooo00?Wg]oWg=kWg]h00nONgP03imkOimcNimkN00?Wg]h2imkO0^ONgP10imcM
imgNi^;Si]79g/BmhL6/h<:^l;nXj[bUa82RiKjWiKBSi[fUil:cilFgilBgilRli/Jhi/BeiKb/hk6Q
`:2:eYEmdH]bdI84hKFTi/2cil>ail2aikb_iX>RilJfi/6^a:R4fYj:eif8d9H9cYEmaY1fQX5P`8=^
^h1V^P1P`HAU`hE/`85PbI1bbI1c`Y9ldi]odYR2`Y5lc8]faXYeaHQaaXmfahmgai5iYhEk:1XH0001
fL[<gLk>hmSH4>ONgRSoool002Koool00n7Shn7Qh>7Sh`04hN?S00GQh>3Qhn?Qhn?Qhn?Phn<01>7S
h`10hN;PhN;QhN[Zh<60h<Rfh/6l`8B0`X0C`X22e;2Ph<2Ph;VXh<2PhLRhh<Zlh<V0h<34h<c0h<Zl
h<B`g[ZY`:20d:BAd8:4`920d;22h86`h<2hhL2ahL6d`L2dhLbnh<Ri`820d:RCd:2A`820a942_X1i
^81`^@9R]h1//89/_8QZ_h1bP81a`i=ib9F0`:20d:>0bYR6b9B0aY20`940`81h`900`I1mP920V01T
0R0U@00DXYBTR862`<;04>7Shakoool00nONgnOLg>ONgP04imkN00?Wg=cWg]kWg]h00^ONgP;Wg]l2
imkN043Wg<3Wg=cViNKV`83Pb;3Rc;C0PQ38P@C8P@S0X83V_jSP]:CWP:3W`;CWaK3V`;SVbX3V`;SV
a;3V`:;T/JC2X9C0X83BU@C@T7[LX9CV^:cV`;3W_JgW_:kUPJ3W`;SV`k70[8SLXY3FWhS0P038PG;4
R7C0062nN6:lO6BhOVC2Q6;4O6[106S8SW72T7S@P83@PX;@T@30T7S<SGS8SG74R737S737SgC0Q020
LF@080@00022T9;0ZJc3`<8@imkN:?ooo`009_ooo`03hN?ShN7QhN?S00CQhn<00n7PhN7Shn7Sh`02
hN?S0n3Sh`11hN?Sh>?PhN?ThN7Q`9:8h[nYhL6_W8```Hmm`IZ6e;2ShLB`hKf]hL2`h<Vmh<^nh<c0
h=37hLk3hL^ohLNjh<6``;RPgK6QeZRDdIR7ejnLgkfah<Bhgl2`gkna`<2`h<Vlh<Bg`X2PeZRHcYn<
aI20`Xil_H]j_H9a^Wm_]WiZ/7iX_hM/`HAfPXQbaiR3cif;d:2BdZNDbYV6b9J4aiF3aI>1`81l`Xmo
`Y=n`9B2XW][I4HnB14@UX^@]Zja`<;0013Qhn<Noooo00cWg]kWg=cWg]oWg]oWg]kWg]oWg]kWg=cW
g]kWg]oWg]kWg]l4imkN0^ONg`0nimcMi8Z3j;ZSj;bY`88PaXYeb9Ena::0iknYj;RWih2Pi/Bgi/Jh
i/Rhi/c1ilVmilJjil:di[fZh;>PhjfJg:B<d9D0g:ZFi[R[i/2`i[bZi[Z[i;j/ilBfi[nab:b8g:>A
e9^5b8@0ahYe`hMb`P9X_g]W^WYR]WYPa8ATaWm^`X5`cY=keYN3f:2:f:><ciEo`Y9lc95kbhmiaHQd
ah]hahmf`Y02YWMTJ44fD0P5XHF4`:RX`LS:1^ONgP03imkOimkNimkN00OWg]hXoooo000Voooo00?Q
hn?QhN;Qhn<01>7Sh`03hN7RhN?ShN?S00;Qhn<4h>?S043Ph>;PiNKPeMCMP9_M[YWHZ9S1RAS7UXG9
ZIKK/ZCQa:oQ`:kP`;;PbKgPbkoPc/3Qd<OQc/?Pb<3Ra[[QaK?N_:[O/:CGZiO@PhkH[ikO_[7Pa;WN
_jgN_:g0`;3PaKSN_[7FZXSBXi;;VHO2Q0BoS7ZmRgVlQW2kPW2cOFRXNF30R733Rgc0T83=Wh_CXi7@
X9;BYY?:W8S9TXC8UX?6Th;0T7k2Sgk3TWo2PHB^PFj7H55mD42:OWnc[k;1`l8@hN?S7_ooo`03imkN
imcLimkN00CWg]h01^OLg>ONg^ONgnONg^ONgnKNgP;VgMh0@NONgnKM`>GPh^O@cn:0TNFXTn6QT/B3
4<bAOLnSSn2aX>NoZ>NkZ>Jn[>K5]nK7^NK9_>O;`NO9_^36^^S1]>O0[NB`Y>F[WMbVT=RKP=j[UnFi
ZnK1/nBjYnBgYnB0[>K0/^FiZ/BPQ=RNRm2DOlR0M<B8Ll:7LL20J<1nJ;QiH;Aa@<F4J<R7M<20N]>J
PmZNRM:PP=NRRlnGPL:@0<fAO<b?N/:=MlN;M/R>MlR@1K9mIXaKB817@9AhLkfYZ<36b006imkN00?W
g]oWg]kWg]h01nONgRSoool002Koool00n7Shn7Rh^7Sh`04hN?S00?Qh^;Qhn?Qhn<00^7Sh`14h>?S
h>;Sh>?Sh>?Ph>3Pg>3SgXF0d820d8T8`0P1P000`860d82P`82Ph<>^h<2Rh<:`h<Vlh<Roh<c2h<34
h/k0h/R0h/2hhlNe`82/hZjWf:2Ld:20f;2Rgl2`h<B`g;bXg;RX`<2``86`g;2Pd:21bYR4a800P8P0
^8Q`_8Q`^81`_8E`/WaVZ7Q0`HQaaI:2`820d:6Bd:RA`:2@d:B@bX28b9R0b9J4ai:2`900`Xila920
a820P8=`PPYRP0A4P61U/K2``<304>7Shakoool00nOMg^OLg^ONgP04imkN00GWg=kWg]kWg]kWg]kW
g]l00^KMgP12imgNimkOi]c0i=_2iX20`820f8D0`@=R`01Pd9R5d;6:i;2Pi[nWiX2Yi[bPi/Ffi/Ni
i/R0ilZ1j<Rlj<Bhj82`jL>_h;RPh:RPgZRA`:2@h:2KiKbXi/2`h[RPh[6Pi82Zi;RXhZ:1`:20`i44
bHQ``81`PHAP`8MPP81Z`H5X]WQN/711`8ATb8H0dX21dZ20g:>0d820eX28`9R0d902c99mcHija81`
ahYdb8ahb820R8=XP098P050P6A4_:RX`<344>ONgRSoool002Koool;hN?S0^3Sh`0chN?Sh>?Sh>?S
hN?PgmOFhK^d`I28chQh`7AWP0QTdjNGf<>ah<2`h<>_h<NfhLB`hLZmhL^nhLb3hLc0hLZmh<JhhKnc
h<>a`;RXgjjUf[:QfK:Rg[RYh<>chLB`gKj/gKZ/`<6`gkf_g;>TdJ2@bIR4`Xak^8Qh^8Id^XUe^81`
_XYd]H5[]0IPai:3bij<eJRCeJ^IfJfJ00;@Xi003/^QS<REP<NFQ<NAPL2@0L6=O<>AOl22PLB;M<nC
N8R2IHmbJ;bj^l30`a3Qhn<Noooo3NONgP13imkOimkNimkOimcNi];AikJ^a8>2eh=aaFmORP1Ef:>@
g;j[h;fXi[jYi/>`il2`ilFgilJhil6hilNjilFgi/:bikZ]i[j[h;2TiJVOh:fJ`JB0i;>Si[j]il2`
hkVUhkJUi82[iKRXhZnMf:20cYAmb8QcP8AR_X9/_hE]P81X`hI/^WeSP05<cHekd9Z4f:6@fjNBgZVC
dX>9eYj9dIb5d900cI9lc8ai`h1hahUdbHegbX20bXM/e91_`0iTTViPa[Bba<kB013Wg]hXoooo000V
oooo2n7Sh`03h>?ShN?ShNCT00;Qhn<03N76b>7:a>>m/LBFQ]29N;mgIh0@0=BYVMS0[>31/>33/^7:
^^76^P02h/Zm037PbK[Pb;WNa[OM`K3N^jgL_:cI]Z7K[j;J/Z3H/:GN^jcP`[CPaK7N`K3N_[71`;CO
_ZoM]ZK@X8S9V8C2S7^`PW2gQ7:gQgB`P7BnRgNjQg64P03<VX[>XY3FZI?DZiSH[Y_@X93@XY3<X8c9
TX36UH;6Sh30PP31SGg2T7g0QH30R7?<T7S1T7bUOG77`L31hN004>7Shakoool01>ONgnONg^ONgnON
g`?Wg]h01nONgnONg^ONg^ONg^KNg^ONgnOO`002imkN047W`LCXaKoY^:c8T83FQ734Len:463JYI;N
^jKV_:SV_ZcWaKCW`;CXaKOWa[SPa;3V`k?T`K7P_:ST]ZOR]jKP/J3RZY_P[I[0XikU]ZGV_JkV`J?T
_:WU^Z[UP:3U^JSS/Z3HQ8;>U7g7R7>lPV2lP6VmPVbhPFc4Qfo0PVW0Q6SBUH;DWHSIXI3JYY7NZICC
PhSFWXWBVhC0T03<TG_;RgS1RW36RGG7S7K;P1;6Q6[BS730PG:YNFW@^kWQg=oWg]l03nONgRSoool0
02Koool00n7Si>7Shn7Sh`08hN?S023Ph^?Qi>CSi>KPh>CQh^;P`<3P[I74^:C0P836P72eNV2000S@
XH3H_:70`;3P`kGRc87Qb83Sb;cR`KS0`;;LPZ3HP:W@/:3H/:3@Y:3@X83A[ISIX9c@/:3LP:gO`;@2
h<Bd02?P`[;P`;3O`:oN^JS@RXS9T830S7R`P7:fPVjaP72`P7JoSGS0P7S0P83@XY7BY97FZ93AZ9G@
[9SAX83@X83>WH[0T834T830S7j1R7k0S7b0P7S0PH:dP624P720P0:=P0;Ba/7Qh>004>7Shakoool0
1>ONgnONg^ONgnONg`OWg]h0A^KMg^OOh>SQh>O0gnONgNK0Q>6YQ>2bR<208<B0H85fGXP@0=bXT>2h
X>Bl[>JoX>37^NO0/>W4]^S0]>20X>2hX/2cX=b`P<6PVmRYV]RPT=RXT=nYT=b/V>BhX>Jk[>J0X>21
X>J0/>Jn/>FiZNBeX=20P<j@N<J8L;P0H;]nI[P0J;B0K/B9L<68L<200=:2R=6PS=bPPM6TP=VQT=R0
P=JIR=2HP<b0N<V>N<R8M/B0L<B8M<B;L<204800H<<1J<200/:4L<;0_>38c>ONg`oWg]hXoooo000V
oooo3>7Sh`;Phn<0@n7Ti>3Shl30T=>KR]>WThb14;AiJZQbHH/R0m^fY=fnZ/30]>73]n79_^38^N77
^N75]n33/^32[mZmZ]ZhX=feY=VbX]RTX=NbW=Z^VmVbX=g3/N33]N74]^;6]^;6^^30/>32[]fiZM28
P<NCP;n<O;B2L;N3L;F4L[28N;n?O<BBOlb1P=:VUM6UU=2PTM2WTm6VU=23S<jMS<bKRLFDP/>BP<:?
Oh6<O<2=O[n?OL20QK1jJKMiJ8:02=6APMJg[N33`^3Sh`0?hN?S7_ooo`_Wg]h0ANONgnKMg^ONg^OO
h>KNgn>IP]RGP]^QRl4P0[UeHJe_F90Q0>6bWNBiXnBn[NNo/NO4^>O0]NO2/nO0/NJn[>JmZN2hXn2e
X>>`W]n]W<2PVMb]UN2YUMnRW>>oZnJn[nO0/>S1/>S1]>Jn/>JmZ>>eX]B4P<b?N<F8M;P6H;aoJ;V0
J[B4L<B;M<V>N=6IP=NRS]NQSMRPR]JRS=NRSMBKQMBIQ=6GPLR1N<V>NLN;MlB8M<F9M/B:MLB<4;Ef
H;edHHZ80=V<N>2aYn3Jf00@imkN:?ooo`009_ooo`03hN;RhN?ShN?S00SQhn<0A^7Si=oQhMgO`>3S
i=oSiL22R<::N<6?O:P009]XG9EVF8`P1=fkZ=o1[l30/N74]mo5^<36/=g4]]o2]<70/NC7]=jo[N20
[>:jZN:hY/N0XMjfX]Z^VmV`XMk5/^36]^34]N75]>75]n33/>31[M^fYLB9QlB?O;j:Nk21L;R5LkN6
M;28N;j>Nl6BP<6JRLfRTLfSTL2PP/nTTLbPSlbLR<bIR<RJQlBEPl>BPL:AP<6<O;n=OL2>Oh6EPjUc
H[=cGkN0L<^;N/fRT/30Xn3Sh`oQhn<Noooo00?WgMkWg]kWg]h02>ONgP16imkOiMcLiMWJimgOi]gP
aXB0ahE`bH]bP@1@WfECV69?PR<:hkNQiKbYi;f/iknaiL2bi<6`hkn`iKj]iKn]jL:^i;ZVi[VRj;FS
j;BOh:f8h[>Mh:VDh:R2hL>[iL:_i/2Qil2^il2ai[jRi[fWhK6Od8@@bH]d`hIc^0AX_H5[^h=/^HA`
`hYdaXehc9J0dYf;dij:e822eIn:dY^8dYR0dYF0cYEobY1hb8iiahehaXQda8UfaHYg`964[fmI^FiG
Q85XdXIbeYf:i9bJi]kN2NONgP03imkOimkNimkN00?Wg]hXoooo000Voooo00?Qh>7Qhn?Qhn<02>7S
h`0Oh^CTg]oOd=SHg=k0g^3Q`800X71PRV100D1004100DU7P24@g/2Zh<2b`<2`h<>dg82Q`82PdX2`
fH2P`/2`h<:a`X:Ph<2`hkZZh[ZP`82PhK6PdZRA`820fXJP00;0`;009N30XN30]>33/>30[=R`X<28
Q862LKV0N;60H;R7MKV8M;68L;f>N;V@Oh200<:@P/>JR<2CP<R0R/2BP<2@P<RDP<2FQ<2@P<2@P/2A
P<20NKb>OL6>P;RBP81TDjAQAJ00@X81HH88E/20P>3Sh`0?hN?S7_ooo`04imSLimkNimgNimgN1nON
gP16j=oPi=[Jh=3Bi=GHi]W0`801XVA0U5E2P4001D@40406P0@0i;ZUi[jPi;RXi[jPhkVRh;RT`;RY
hK>Rh82Rj<2`h;VRh82PjK:Ph;:1h821h[24`:22`:20g8BRh<6Yh82Ri[jYi[j]i[jPi[fV`:ZHd8@@
aH9Q`85aP01R_8=]_HE/P8AP`XU``8]`P81``Y20bI21`980d9R4`h81b900cI1hb99lb91hahejaX1j
`8Q``XYeaXYhP920X612XV15/610`01RR016`80Hi]gN2NONgP03imkOimkNimkN00?Wg]hXoooo000V
oooo00?QhN7Qhn?Qhn<02>7Sh`15h>?ShNCThN?ThNCThM_HaH04Yg=TQ4m2I0@bFS`hHdE1D0TBh<F`
h<BfgL2RhL>dgl2_`8>PeK^ZeKBScj:5bZZKc:VJ`:B0bZFHaYnB`IR:aiR:aib;bH20cJRDeKBO`8:Q
h<:ah<:dh<>bhL:^f;2P`X24_hMb^XAe/81Z]89`/h9_P8Ed_i1m`IF3`Y>0b9R7aY^8`YR8cIj;aYF7
b9^8biV7aI^8`YR6`9:3_iB0P81h_8il`8n4^9F1VfYIWf5;Y6=B/feK]g9G`H5S013Qhn<Noooo00?W
g=gWg]kWg]h02>ONgP16i]kNimoPimkOimoPimOCdH@4[6mKR4`gJ00QGCP^IT8gF040i/2Zi[n`hKVY
ikj]iKbYi;ZTf[JTg:nLeZRDdZBCe:BBbJ6BdJ2@c9Z;b9:2cY>2cIR4d9J1dj>=fjnIh[VTi[jZi[j^
i[jPikfWgZ^IbH8<a89Z_h1]^7aQ^GiX^7iVPH1VaH]eaY5k`8ihcIB0biN1`920dYV4bi5ocIN1dIAo
bYJ0`i1naXika8mi`XQa`HYdaXYlPY20WfIAY5e2[5a9^FQD^6m?`hADimkO3nONgRSoool002Koool0
0n7Rh^7Shn7Sh`08hN?S04GOh>7VjN[/l?3Wj^WTe<_?P02_OFi_@CM08B5><c9J?ca440gQa[?P`k?L
`:gQ`k;Ra[C0`:3C]jG@[9Z0P82YQWVcSh6GP0BYR7fKO7V2HV6SMFVeSGnbP7BlRgW9X8_HP:3P`k?P
`kGP`;CQ`k3H/J71Q82oQg2hPg6`06>^O6R[NFN0P033Th38VhO6UH;@WHW:WHW9WXc?Whc<Vh[>XHS?
Whg:X8g0V8:oTX:mTWjiP7RjSGboT8>lTXBKKejIGT^PFTZ^GTfgLEW0P6@04>7Shakoool01>OMg^ON
g^ONgnONg`OWg]h0A^GKg>[Ui^cPknSYi>OCaMB8JKAiIG@l;D8P254_:5dl<U0<1>O1[>Jn[N2kYnNn
[>O1[^B0Y=VcWmJWT/2A2;9oKkZ:N:H:1;23MJ5gLH1P@Ja_GK^9Mh85H/F4L]:IQ<BbR^Jn[NJn[nJ0
X>NnZMj/V/R02/B3J;eoJK1h@k=hH;5dGhF0J<R?N<jGP<BA0MNIOlnIPL>HQ=BKQ=6GPm2MQ=FJQ/nL
Q/BD0/B>Nl:>M/28LKn9M<B;Nl2B1Z1[EYeK@j1D@;AJAKU^D<:6E>ONg`oWg]hXoooo000Voooo00CQ
hn3Qhn?QhnCQhn@7hN?S027LgMkPj^W`n?3Pc<SPRj^0002fQP1:92/800058BQ0<394003Qa;CO`:3H
P:3P`J3Tb;S0`J3A/X38XH2P1608@4J:H4P0@041BD9@@4h8011W4P23LV20@4BQC4fd36;@Z8000^70
/00?h<B`hL2afK:R`800_hU^]H1YZ7QPX710PF10P800aY22`:2;`800d860b9B000;0P8P04/60R]2T
P=2UU<nTT/2FQ;bBP;V0N;2>N;R<NkbAP82DP9Q`I81HCIA00Z50>k1`@L24I>7Ti0oQhn<Noooo00CW
g]oWg]kWg]oWg]l7imkN04ORd=S/i>SPl?3Pd<CQRjC00020Pg109R0800078014<2Q001SW`:kU_:SP
/J3T_:;Z`;3TP:CG[Y71W82Q040:C@bAH440@008ATYB@440000022:8JV61@06TAdB606;0X83W_k3W
_[3VP;3W_jWN[YS9P0S4Q6JjO66PL46XH56PHU2006;8T7[DWXC1PP30U7S0TP30T83@U83BV8C@X83@
XHcCX8c0TPC2SWR0RG20R72lR731SG[0P02MH5b@D4>0B32XB2FlKE38P63WgmoWg]l02>ONgP03imgN
imkNimkN00?Wg]hXoooo000Voooo3>7Sh`14hNCTd<k?^[6^fk6K`R8Aa9:4Cbl_20`4=B4UARl^@0@0
h<>bgL2/f;fXgKfXh<Bbgl2Pe[RTcj^I[XH0S6AHWGMZ4510OV9IH4YB800TJclcV7=XP4Q0Yf9B^X9^
dZR0hLBfhLJjh<Rmh<BcfKBSa8:0_hQ^]GmWZ7UPXfmIVFADV182`YV:^i>2X89b[7m^[Wi^/8Ah]HUj
/hYj_I@0`9R7a9^7PY84_91n^8ai/8ih]hak_920PH42T6aNQ5E:S4Pm[EM7_7]W`8AT0^3Sh`kQhn<N
oooo00CWgMkWg]kWgMkWgMh7imkN04GWg]oWgn32`LS?YJ7P[9C82@;:SWaD:B@92PTg7aY7:bA401gV
_ZcS^jKP^:7S^:;V_jcU_:;L/ikFYY64PFZAGdnQLf8D@422GU1UAdP`11A]?2VLKf20@42^GDW2O6G0
XX3W_k3W`KCWa;;V_jgO/9c8PPS4Q6JjNen/M5RWJe6PGDbU0ES8U8?1Sg^`0VZbNFFdNVFdPFJkQG6i
QW;0PG35U7o9UWo0PGC1S7JmR76iRWBlQg?1S7R4RG:DIeF8DT20B3BbDcg3MUo0P6004>ONgRSoool0
02Koool01>7Qh^7Shn7Rh^7RhPOQhn<0AnO[j]SHf:2DUhMdL]2PS<4N2LN@P5Lf=B<H82lO8T0Z:TP@
1>30[mbo[=RnZMVgXmVhY]fn[=g0[]ZkZ/:PTK6;O;RBQ84=0IIgJgeQH@4K37eAAJ1gJZ=R@[EeH/>?
N]:YP^33]>78_>7=`mo4/mVeXl20P[n7L;EoIZQhH:A`G9MQD90:0;^ISYmoMA1@B7YJDX]PEXaXD9Yb
J95_Hj1lH:V5M;F;M[>8L;Z=N[R;NK2>N;J;Nkb>Oh2008=NDg]?AH180KI/Fl22KJ5RH=oQh^3Sh`0>
hN?S7_ooo`04imcMimkNimcMimcM1nONgP17kNKVgm?BR8F8Xf=PfiJ4d180cX]hFc4/9A@B<1`H@RHP
CP@2i[^Yh[^Uh;VPgk:Lh;>PhkRThk^WhKJSb8Z0^HEb_XilT0QJVg9RPUaH0Q00PddjYG=SZ6I@_FmJ
bhUb`:B<i[n]il>filRmiKn]gk6LbH0:aH=X^W]NXGAHZFaCWUY8T@E@`Y>6YWY]8410OUE<TE]<Pf50
WfiOUV]JZ7=8[X5[^hI]P81P_hUb_HMa^HYd^hMc`HYgP@mXR5Y9Od`kPT8d_FICaWiU`eA0iMcMi]kN
00SWg]h00nONgnONg^ONgP03imkN:?ooo`009_ooo`04hL30hN?ShN3QhN3Q1n7Sh`17kO;aR8:00`04
1040P0QX`800Ph1`H080<20P:AhP>2@PD1P0g[VXfkjZf82Pe:2J`:B@f;:Pi<RhhL>4`/:0dY2R`82B
P820P8h=UPYb2@10PF19X09PP01X`8T5aHV0dZV0h<>Qh<RnhM30gL:`fKJR`820`8I`]GmPZW10YG90
U5i<P0A0X9FA0D]70002224X@08a00P0KDa2D44<0410P691PG10X0AP/8Ub^8Yi/81h]8Qk^XYiP018
H406H401I4a0`880a8QdV45Dg^3Qh>?S00SQhn<00n7Si>7Shn7Sh`03hN?S7_ooo`04im[HimkNim_L
im_L1nONgP17lnk/a820000180P1T05C`H00a09RH00`<082:1`F>R4L@1@8i;2PhKRTh;RRf:RDd8N4
h;20jLBbj/21h8:0eHnIbJ^9Q800PXP4Y@1PP4Q0R61>YgQPP0APaH1^d820`:20i[jYi/FhilS0h;bX
g[6Hc80@a89X^W]NX710Z6eEW514P540/h68249F0@0031<PA@0U000:04Q0E4040402P698X6A@X010
_8AZ_HIaP8Q`^X1c`8AaP@10JT0dHD0cH4Pda11XbH5/P450i=_Li]cN00SWg]h00nONgnONg^ONgP03
imkN:?ooo`009_ooo`04hMoOhN?ShN7QhN7Q1n7Sh`15gn3QUhZ98PP:8`00S5aAYGMXVVUMES`m<2@S
:1hP>B8UFB06g[^Xg;n[fH2Pe[:OcJFDe:F3gKjai<Rji/blk<^ih;b/`ZBA_YR7]hYhY05PYGIV[W]X
]0YXd9j6eZ^Fd:R0hL>bh<bohL32g;n]fK>P`8^8`8Yh]7iY[794YgAOW6EAP01:/iJ?QF]W:@@0>b``
FcXfD14@KDm;GdI00UM0RVYIX7=MX@1U^8Ud]h]i/H1l]Hel^hem;05CGCdjGChiAd40aIJ4_h1[XFE7
013Qhn<Noooo00CWfM[Wg]kWg=cWg=`7imkN04KVfmfZP7/X0a4E1@2KCTJTH5nRHUEG>CDa8B0Y6aHj
81^1503T]Z7R^ZCQ^:3L[ISDX8gLX9SS^J_Y`kCZb;7_bKGU^:K@X834TgjoQ6jRO6>/LEfcMV200E3E
VGoJZ8o0X83W_j_WakWWbH3R^ZON[i[9QX76QG6iNV6`LUB/L5NRH4V6G42kTHN<IUl0014l:BUM=be@
40UaC49Q@cL6Dd2=IU6UKeB/04BmQFblQg60R7FjRGC0RGF0F4UN>S5O>bmC1378Tg_5Nf>ZH4;Wg]l9
imkN00?Wg]oWg]kWg]h00nONgRSoool002Koool01>7Oh>7Shn7Rh^7RhPOQhn<0B<c7c79MG10P82X:
36Ln>GQ:@71;AT8_<b0Q:2PN8CTS9UPJ1=nkZMk0[=b0ZmVhYM6[V]2XVM2/X=JcY=2dY]FdYL^XVX2@
PJj8N:]lJhAdI9i/G:I`GZH1H<VGPM:YU=2XP^74]N7;_^38_=^kZMVaW/B8PL2?O;9mK:afGZQdGZA_
F:0:FKbGRJB0MA0h;5m6A75?Af12@7UJDW5CBX9PE9UgIJalIk20I;R;MkJ<N[20O;F>O;^AO`Q4@58i
>E8i=D80<Kj?O[I]FjQP@NCWin7Shn3Sh`GQhn<00n7Rhn7Shn7RhP05hN?S7_ooo`04im[KimkNimgN
imgN1nONgP17d/77PU==4Q038``7L3@_P408MDDn@bdY80@0:A/F>b0KHA80iKJSi;^Uh[^Ph;>Of:FC
d:2@eZNIgJjMej2Pf[2OdJ>C`HH0]8=_/GMRX71JY6QBZVaE/6e0ci=jejF=fZ2Cikn_ilJhi/B`hKNR
gZbGb862aHYe]gUT/G9F[G1EZVY@Z09B`Y>2ZG]^63@VHD<mMDXmJ480O5I9M512QV10WG=M/GQO]PET
_HM_^XQb^HQf^XYd_hih840PE3LaE3H[BP@R`Hed_6QC/Da2j^;RimkO00KWg]h00nOLg^ONg^OMgP05
imkN:?ooo`009_ooo`05hL3PhN;ShN3PhN3PhN;S00GQhn<0BN3ShjR>X@@@400003@820820P000P04
3@h2200D02P08CXT8U0A0<2jZ>30[Mf1[<24X=:`X<bQT8>AP8R@P:R80:b<PJF32:00HYI`HX1P@9QX
G9QTDiiPEJ1P@<21OLfVT=2XQ>74^>72^<20Y=R`X=V/V<:PP<2@PK80IJ1`@:UfGJ41HH60HLF@0<B2
P881H81TBXQPB0A8@8AR@X9P@X00@:R4L;R4LX24L[R=N;F>N[2@0;B>N;:@N`@800Tb>0HT8R020:@4
I:982:10@>CXjN3Ti>3Sh`05hN?S00?Qh^;Qhn?QhN001N7Shakoool01NOJf>OLg^ONgnONgnOLgP06
imkN04RaRJ4010@000010Q<130T00000008?51@P4A0Y710081a040[T]Z?V_JOS^:KRP:C1X83@P8W0
Q0S5R020P022P0R/PP2P0623I424I5B0H5BMH4RPH4bPH530RGCAXXcIX83W_k3W`KCTP:3N/9SNXI70
P835T7VfN6RPH42/LUB`M5R0163:T778TP600529H420HD00@428HU:8C4Z8HT2/PF24P6?0P6:oRG2h
RW:jS72hRW2dPG0000108b10820X002`0F2PA@2`@43Xi>CWgn3Vg]h5imkN00?Wg=cWg]kWg=`01NON
gRSoool002Koool01N7QhN7Rh^7Si>7Si>7RhP06hN?S04N`XZlb40l_20Pi9b/N2a4;100F3AHH4a/5
4P0`8RA3;Bm@2Q;M^:KP_j_L`:cQa[?M_Jg@ZIW2Vi34VHV`PHFaTXR/SXJ/P7VPOgBWNVfPN6jSMFFY
MVJd0Fk6VHS@[9WJ]:CQ`kSPa;KN^j[H/ioI[9_1YI35W8ZhQgbP0DbTM5fXN6:`16RfPfc6TgbeR7B^
PFjUOff0J4BRO6VVO6bVP72iSGbkRWRhP7VkSgffSg^hT02eT7^QOfhP0P0g;3@g:bhX106^N6NPB3ZF
@4GQhn?Qhn@01^7Sh`03hN7RhN?ShN7Q00GQhn<Noooo00GWg=gWg=kWg]oWg]oWg=h01>ONgP17imkO
imkN]IfX:18<00LB?b<O6``;2PP05@`<6A0@1A0@<AlJABTUD@41hk>Oi[ZTh;bVil6/hkRWd:2Db9J9
biB1/8Qm^8f0/hUm/85`YWY[[GESZW9UZfmK/75L^GQTc9B0eZNBh;25iknbi[n`h;:TgZjHgZRDb:29
bYR2_H=dZVe0ZFmD[GAI/@1P^WmTc8mc/XAT]GaSZGYUP6AAYWQQZgQT]81X_XUd`8IaPHQa`8]e^X]d
_Ha`^X]cYG]U:0@J>BPZ>BPT:@06/gAOXdH`VE5000;Wg]l6imkN00?Wg=cWg]kWg=d01NONgRSoool0
02Koool01N7Rh^7Qh^7Rh^7Rh^7QhP06hN?S04Nk/Kdm7A`V008_82@Q4QLP400G3aLH4QXP604d92I9
=3E2017I/j7M^jONPZ[QaK7O`;;A/JS?[Z;?Zib0X9K0XiRkX9R0W8FbUXbkTXFcTH2dSX6jSX31T83@
Z9OE]:7LPJ7O`[GN_k7M^:SH/YoI[Yc4Z93:WXjoT8BX0F2NLEjKJe^NHEfNKUfVN6JPM6FWNfVUOF^S
06B/Q6j/Pg:SQG:eQgJaPW6cR76jSgbgSGbkT02eSgZ9JE/@82@`92lb:2d060RaM6>PCCj`907If=[P
h^801^7Sh`03hN7RhN?ShN7R00GQhn<Noooo00GWgMkWg=cWgMkWgMkWg=`01>ONgP19imkOimkN`Jbg
>AdF:1P@<QdI814?8a065`d=6Pl?810A=B4LC30[D008gjnJi;NQi;RTil2[iK^/`;2ReZVKeZFDaYb0
b9j@`i^?`Y24^Y23`halQ8P0_XMha8Qfc91oeZ>@fjnKh;BSiKj_i;Z[hk2RgZfHgjZEdZ>0d9Z6aH]m
PP1:Y6aEXFIBX6QDXfUC[7=KXG10[gINZWQSZG53/H1V/GmZ/81X^X=^]WiY^85P_h]e_8Ud`8Ub^Hac
Sf=A4R08<R4U=2DS418B]fmKYDXd]200gm?Fi]gM00KWg]h00nOLg>ONg^OLg@05imkN:?ooo`009_oo
o`05hN?PhN7QhN3QhN3QhN7Q00;Qhn<0Bn7Rhn7Shn7Shn7Shl30b4P^;B00020H7204820180@@6QPB
62@H03TP:4<0000@1<BXT=:bPl20X>32[N31//34P<S2PL:=P<R0X=20X<V3Z]20X<B0X<jZUL2XX<2U
ULRRTM20P<22X]V2ZN30/=c0X=bhZ=RhX=VaP=V`W=2PP=2PT/J0Q80209QPH8YJE01D@01@B@1<@010
@H1`H:1bHZ21L;B9L;29N:20L:00H8MaH:00H;Z?O;R8O;R00:B4L54@22P0828J:2`T;A000:9TE9QD
@0P00<>9`]cLg006hN?S00?Qh>;Qhn?Qh^801N7Shakoool01NONg^OLg>OHg>OHg>OLg002imkN03KW
g=kWg]kWg]oWg]k5R<10:R0P010Q4A4R0Q4P010440<L3PhP418j8AiA=C80003@XH70XISP/:3V_Z7V
P;3PP;3QS:kQR:S0P:33[Z3C[:30P838Z9C5X8O0X838XHC1X8;0P836/8c3]J3PP:3P^:?R/Z;P/:3O
[9SO[9KAX93@W8_4U8F11021JE:@DDZ0D40:A0@0B@60@42PH5:XL442P81Z01>hPG2`06RaM62TLD2P
062oRWBnP7G0P72`PV1F22hX010X604P82<P6`2`B4BPCSP0@430P8SPf=P01^ONgP03imcLimkNimgN
00GWg]hXoooo000Voooo00GQhnCQhN;Qh>7Qh>7QhN801N7Sh`18h>?Se]GNGT=10R0Q:AdO<BLX:28P
:1`P81DJ:1/3@2/[ED91;015bZ>?f;6N`XBPh<>^h/JiiLk0jMC5iM33h<ZlhLVlg/_3h/c2flc4hl[1
`LS2fLS0h<Fkh/b1hlJfglFch<Jhg;n/g;VXf;2Pf[6PfK:NdJ:2ejNJdjVIQXB2Z7icVFaTP69HPeeC
N5I:PUQ2UFaNVg1RX81`/X=/[8=aY7Y]ZWUZWWEUYP9P^Xml^Xam^XX0VgETCS0_81P0:A/W;B</1084
Te56QTdo0511]k2ehN?T1^7Sh`03hN;RhN?ShN?S00GQhn<Noooo00GWg]oWg=cWfmcWfmcWg=`01^ON
gP17g=3II3hf00P0:AXE<b<L<0HI:QPE8A4@:1@A@BLQEclh9014cij7gZfGh82Qi[jXj<6cj/Zlk]30
j/bni/BailBgi<Jmj<R1hLNojLFkb<Blgl>ki/2filRdj<6aiL2/h<6bh[^Uh[BRh;>0gjfIgjjHfjV@
gJ:CfJBBU8T8/7UYXVEJT5a0RUM8OE50R554WFIDXF]HZ0=W^7iS/GmYZg1T[gEQXg1KX7IP_h]d_hQf
`89`X75KD2dU81<B:QTL;R0R20PIVTXnS4Lf0TA0_J^^imkO00KWg]h00nOLg^ONg^ONg`05imkN:?oo
o`009_ooo`05hN?ThN;RhN7RhN7RhN;R00;Qhn<0C>7Sh>7Shn7Shn3ShmSEgUe1?d<R8c4R92hT9RD6
82XM828G6bP2848/;EE1@2P0@LBMRMVaWN20Z>73/>75]^?8P>G>`N?=`>39P^7;_mo?a^;0aMk@bN;>
a/30`Mg=aN79_^;<Q>;5]n36]<74/]boZmfkZMV`XmZbWmVbW]6RP=R/W]J^W<68Rk^APk67Nj=jHIYc
IXmZGH5VFYEZGY9ZGX1cH:9cHYmeIH9`HZUjJZ1gIj02J;Z?NkZ>O[N8M8EPDdDZ:b4H0BdO9bhS:`lP
8W@l=Vho=TQ23:ZRYnOZjn3Rh`GQhn<00n7Rhn7Shn7Sh`05hN?S7_ooo`05imkOimcNimcMimcMimcN
00GWg]h0BNKLg]cAfV4m=D8P838P6S0Q6RP05B`J5R@C4B0G54<Y8eLn=Ra@@LZHP]j]Un2gXNNoZNO0
[nW6^>_:^nS8^^K0^>O6^NG:`N39`>C;a>S:`N39`>?8_nO4^>O8]^S1/NK1[^F0X>:jYN>fXl>`P>2]
VMj]UmfYT]jXUmbYU/R7Q<>;N[Z0LZ9`IJ9^G9IUDi1Q@9aTE9QUDj5RFJQ_F:AaGJ1S@:mfHJIcG[5j
H;n;M;n:MXB0I8YKBTLW8B0C4RhL7C0P824<1GPf;g8k;De00K2NX>_UinKLgP05imkN00?Wg=kWg]kW
g]l01NONgRSoool002Koool01N7Shn7Sh>7Rh>7Rh>7Sh002hN?S04cQh>3Qhn?Qh^?Ph^36`<]I03U0
0300:2T^82@P024R820R61dP0212;Bi@?3P0@42dQ0;AZI7PP:CQ`;7P`:;1`;71`;?1`KSP`83Pc<3P
d/S1`<CPdLc1d<S0d<3Pd<7Pb;k1bXCP`;OPa[C0`:;L_Z[NP:SH/83J/ioH/9cHX9cH/:7H/83@X83>
X9?8Xh:0P822P0VTP0:0162BHD20HUR0A420@e:0AU20H42XNFVPNFZaP7:hSWR`S7VP16180P0h8R0X
704`82L`82P00@`@1`A082@0002<P83Xh>3Ph^<=hN?S7_ooo`04imcNimkNimcNimcN1NONgP1:imcN
i]cNdlC8GCT`@00P024281hJ:00D<1`H8a0A8P00ABXTDSP`04Q0PH1cf:B5i;20ikn[i[jXiH6Qi8:`
iL2di/20i/Rli/g4i<Z0h<30iLg5h<30h<W2i/Jhi/2hi[jai/6_h;RPh[ZPi;VUa:20h:jHgZbFgZR@
gZbH`:fH`:60`8b8dIB9`8@0RHD2P0]XP011V61DS5i>Q410QEQ8Q490PT10[W1PZG5QP0AR_8Yb^8Qa
P01QDP@X020L:1PD<R0L<R4M000040@0@2844000PPd@k>;Yi]cN3NONgRSoool002Koool01N7Shn7S
h>7Si>7Si>7Sh004hN?S04WQh^?Qhn>f[K5I?CU1@P17<S8c9BP`1B0a82</7B0X120n:R]<=cD1@4:S
OVk3VXOJ/8SQ`k3P`jkO`[CM`[KOak_Q`<3Pd<KQe<c0d<CRe/oOeLkPe<gRe<_PcKoPb8;Pa;OPaKCL
PJ[K_ZWM_Z[H/8CJ/YkI/9cHX9cI]:;J/Yo0]:7P/j3O^JCDXh3=Z9?5VhZRPgFSMVbDKfBBHERDIUbE
J5^0HDR^PVn^PgBiPWVhSWVaRWR2K4U:;B`d8BDX028b8bH^8BL00@d[4aPb7R497B5hK6g?c<`03^7S
hakoool01>OMg^ONg^ONgnONg`GWg]h0BNOMg^ONgkjXZE/j<4A0<4T^:3DR7C40638N62dK5RP16T0W
8Dhc:`104:QjI/VFOlBXQ>NnZ^JnZ>FlX>Bm/>G2]>O4P^K;`>O?a^C;`>SAbNG@b>;@`^W?a^K8^NK0
^>Jo/NK0[^2hX>6iXn>iXl:RV>2^Umn[U]jXT=j_Vn2^V>2PV^B_Vn6gW/2QT]6USLVGPjd;I:YaHY][
FIQQ@YURDYYTDXQPE;=nIkAoJhB0LKf9LKJ6L8MX@d/[8cHN6R`L63<Q6blN70040bXC4S<L5`8H585V
H]O6a@0>imkN:?ooo`009_ooo`OQhn<0C>7Qh^7Shn7Rh^7Rh9J:RePl=eY1@4Xf=SX[;C@Q92hO8BhN
82408CTV:4Ha<5LH2Xm]HJj6MM6XQ>32[^74/>30]]o4^>3:_N70`>7Aan;Cbn3@bN;Fcn3Ec^7Bb^;E
cN7=_n39P^35^>33/]j2[=^mZMbkYmR`P]Z`WMV_W=RQW=RaWmV`W=R`W]Z_W=VaWM2VT<bWTlJMRh2@
P;B7NJ^2M:QiJZQjKJQkK:P0H;B8MKF9N[R8N[V=N:^4LQQ@@44Y:C4P8bP082`P9BXN9A<84BDE6BTJ
7`@B56EDDjnTX^3Ph0gQhn<Noooo0^ONgP;Wg]l3imkN04cWg=cWg]kWg=gWg=jOQ81J>Be0@39=<b`l
9b<01P0_71H_6aHT6QPk8ae8;BEJ402CJERdPVc1XX3V_JSW_j[V_[3U_k;VaKOWb8;Wc<7Xc/GVcL?X
dL[Vd<SQ`<7Xd<SWb;[W`;SV`;;V_jcT^:3P^J;R]Z32X9?P[9KOZYG0Z93N[ISOZiG1Z97OZiKL[YKD
XXC@Xhc;VHB2P7RkPG2aOVZPL62^MF>^Mf>`M66iQ6fjQ7:4P7:mRG6`P6XL@4=29R0b7APY71T]7AX[
6a/C00<U514[5a@51P1]CdNgWYWPg/07imkN00?Wg]oWg]kWg]h00nONgRSoool002Koool7hN?S02SQ
`>3Qhn?QhN3Qh>1AAD1@>31@@410>SU0<381820Z71l`7b0P000`0R0k8R90001XD428Hd62Q83NP:SQ
`;7Pa;3Pa;SQb;kP`8CPd<OPd<3Qd<3Pd<cQd<SP`8CPe<cQb[kQb;cPa[ON`:k0P:3J_:SH/:3HX802
fJbJ00gHX9S@[9S@Z93@X931X970QXC0P838X8;8WX[0P8;2P830Q86>P0000Xb>2P0CP8P2^X80P8:0
^8Qh/89dP71T0000<B@P;R0R8@0T81PR818R01@10APL01DH8004A00/46AQhN7P00gQhn<Noooo00?W
g]kWg=kWg=h00^OLgP;Wg]h0C>OJf>ONg^OLgNOL`5]065@e:500<50c<40P:00Q02PH534L5b0H5C4L
4P0S040086m8@Ha>B<200>BhXNNoZn20/>K0/^O6^>K2P>O8`^K8`NO8`>K>`>O=a^G2P>K0b>O5^>K6
/>O0/NBlXNBhZ>2`X<2aVL2XT=jXT=nXT<2XU=bXT=VTP]RPP=65P=21Q<20PL21R<bHP<20P<R12LN0
2<2<0<::1<2:182008>:L<6:N820L;R2K8QX@00@034Q720N5bPH6R8B4B0D4@0@420@40<A424004T/
81AQD>70`0gWg]hXoooo000Voooo1n7Sh`0IhL?PhN?ShN7RhN7RDS`iDSXdD412E450BcXl1b0T;alR
=20S;@01<AlR>BDV@2PXITY6Oea>QX4AfkRTh<6^hLBehLJjhLZmh<R000;Pd<L0<N7@a>3Cc>7Cc<70
`>3CcN3:_^7:_N76^=k0[^21[]ZjY]VdXMV]W=NZV=R[V=R]V]J[U]BWUM2ST<^RSlRLR/:JRLRPS/VN
R/6QP]BUT=>UTM2RS/nOS<fORl2HP;nDPL2AP[28LJQnKX]VFD890RhR9B`Q8b@091dG7adE800@01dJ
7Q/D6b0I0D4X8hUeL>7Qh@0=hN?S7_ooo`05imkOimcNimgNimgNimcN00;Wg]h0C>OJf^ONg^OLgNOL
gE4j<U@f:UDn>5Hm=Tdg<T4Q830L5cDM620I538L63/R740Q46Q6?8=HAYB12^6dWNJlZ>NoXNO2]>O5
]nK0]>O;`^K;`NO:`NK>a^O>anG6P^K>b>O5^>O4]nO2/^BlZ>JhZ>2eWmj`V]jXUMfVTMjVTMjYT=bV
SmZRS]JOR=:MQlnGP/2@PLjKQ/nIPm20Q=RQRMNRRmB0R=>KQM:KQ<2@1<>@N/B=N[F4HJajIHmRD441
830N6RdN62@H6AlC51hB5@8@41lF4QdA424B4chW78eaJ>70`0gWg]hXoooo000Voooo1n7Sh`0IhN3Q
hN?ShN;Rh>3RE3dkDc`hDd50Ed92Cci0@2P`=R@W=R4S;`0P=B4T>RHX5BPXIDQ4O5U=P8<0f;>Og[fY
`L2bhLJjhLNjh<R000;PdLP0<N7@a>3Cc>7Dc^32`>3Cc>3;_^3:_>76^=k1/<2l[=ZhY=VdXM6/VmFX
U]JYU]2XVMJZUM>VU<:RT<bRSlZLRlRLR/VOS<VMR/V0R/fORl^NRlZLR<VHQ/NIQHFDP;fCPKb=OJR0
L9UcIGYGCD00:RXO8bXP920I8Q`E7AXC7QPB71/G7A/E6b0H7T0W8jBFU>3Ph00=hN?S7_ooo`03imkO
imkNimkN00CWg]h0C>OJg>ONg^OMg^KLgE@j<eHi;e0n<UTo>58k=T@R83PQ73PN6C0I5SHN6C`S7D0Q
4FM4>h1FA8HFImj^V>BhXnFnX>O1]>O2]NK4/^O<`^K<`^O;`^K>anO?b>K8Q>K>anK6^>K4/>O1/^Bl
Z^BhX>2cWMn_VmfXU=^TSm^USmfVT]bUS]VRSMFNRM:MQm2HPl:HP<jJQLnIPl:HPm:KQ=2JQ<jHPLfD
OlbEOL2@NL:?NL69MJ`4J9i_GGiC@d0T82`L62/N6R4D61dA4Q/@4aX341`C4A`B428H53`V7JbARn3N
`0gWg]hXoooo000Voooo1n7Sh`1<hN3RhN?ShN;S`<;0FT50E@40D040FD=0DT14@08012PP>24T<00P
>B4P?28X000XI4M4NUQ<P01Pa:BAf;:4`<2Ph<NhhL2`hL2hhM77hM;9hM38hMC<hMK?h=30hM;9h<bn
h<ZnhLBigl:bg[RXfkBPf[2Pd:RJd:B@d:J@d:2@e:R@dZFD`Z:@c:2<b9b8bIb;b9R2`9V1`920QY45
PXH4P800P8UiP85h/8Qa/H1kYX1VP01P2TA@B0P1@20P81hR800T21H0610H410H4@0@6Q0H71HL8040
@2XX`I^Hh>;S3N7Shakoool7imkN04cWg=cWg]kWg=kTf=Y40SAG?39@031H@3Y@0SQ082118R0h0AT`
710j81`m9210:21X@3]mE4B6043@Qh;0XIGP^:CX`[3WP;3W`;3Wc<3WcL3Wc<;WclOWdL[Wb<3Wc<CV
akWVa;SW`;?U_JcT/:3QXI[0[Y_HX93HX8cHXXWHX83HY8cHXHc@W8SBW8KAV8C2V83<T83<U830P030
PGG0PWC0P730P765QFJ0P66hR7>`16B0040>@49;0BE2820X6a0X71P8410H3P0H3Q0@300H0A4L4A4P
6110:232UY;Vg=h=imkN:?ooo`009_ooo`OQhn<0:>7Qh^7Shn7Rh/30`5i6AE=1@E820eU3A5Q7B401
14Pb<clX:S8P93lX:T0/;d0^;6E8A7]KD95XB<RJQmJ]VL23X>36]n72]N70^>7?aN7Ab>3@`>7AbN3C
bn7@`>7?aN7:_^38_>73]mg0[mbdXM^bWmV`Wm2ZT0;BYI808]2PU=BWT]:UTl:RT<jPS/bMS<RLR<NG
QLJFQL6@PKj@OkV=O;b;N[b8NKV:MkB0L:n7MZMkJH1R@6mABU0d<C`S:2LN8RLO9P`F81XB6QXC7101
4AP?6QlH7R04875MG>?Vin3Rh`gQhn<Noooo00CWg]kWg]oWg]oWg]l3imkN02SWg=cWg]kWgMkTf=QR
@S]F?CMA>2UK@3]JA3m8031:;RU1920d01Q19B12:BA3:21XA3YoEdNDHD3>UX3KZ9;R^Z3V`K7W_ZoW
`K3Wb/3Wc<;Wb<;Wc<?Wc/KWc<;Wb[oWa[SVa;KW_[7S_:WP/Z3Q[ISO[9SHY902f:6;02;HX8cJXX_G
X8cDWXWDVhKBVHG1V87<Tgk;TWk6S7W3RgNoRGC0Pg;2Q76nQVniP62dPfj/Mf64HU1bCD5A<BL080@X
6aPX71`<510K3a0K414A2P0H3@lO5Q@Q0QAhF53YhN?Vg=h=imkN:?ooo`009_ooo`OQhn<0C>7PhN7S
hn7QhL30`5]5@e4o@4D0=5M3A5U8B4P8@4Td=D<];c0P940[;48_<44a<F=8@WaLDXQQ@<6@O=>WU=b2
X=o5]>33]L34^>3=`n3?aN3=`N3>a>3?a^3>a>3;_n78_<70^>32]=^mZmVbY]Z`WMN]Vm:QU=:VT]>U
Tm:PT=:UTM6TT]2PPLnOS/bMS<>LRLJEQ<JDPl2AP;nAP;^?OH2<O<2;Nk^<N[:8L:R1L9mdI0U4E6A8
@TT^;C@P:2LO8RLO9@h081dD7AhF7Q0151D>61lI80@:49J7Q^?Vin3Rh`gQhn<Noooo00CWg]kWg]oW
g]oWg]l3imkN037Wf]cWg]kWg=gTe=QN@SYC?3IA<B9J?cYKACi@13I;<B]5:BDd01Q2:294:bI4:21W
A3V0FDV2DDS6S7CHXhgP^:;U`:kV_ZkV`;;Vb;gVb/3Vb;gVbKoVb/3Vb;kVa[WW`kKV`K3V_JkQ^JCQ
/83P[9KMZ9CHXHgHXX_HX8cAPh[HXH[GX8_EP8SEVhOBVHG0TX800/^@O00IaXeja8eh`H]e`HQdaHMc
`8Qb/XAP[GeXXg1L4D5:J4@iBb/S=B42:1`H:1`K3aDB7A4B7a<D4PX15@/=8AHD10P1Xh1jjN7Ri]cN
00gWg]hXoooo000Voooo1n7Sh`0ZhL3PhN?ShL3P`L31@4Q4C`10@30`E412F416D410BS8a@38`<20P
@2`/A34bA30`@TU0NUiD04A0Z01Qb824f82Pf8:[g<:ag<2dg/:0glS0g/20h<R0gl:0`<V0`<B`hLBh
`<2`gX2Pd;RRf;2PfJbIe:2Dd:20dZN@djBC0]2PP00Pd:2@d8B0d9n?cIj<`X20aY:2aY20`9:2`9:0
_91mP8Ql`Xal^8QhX81PP71PP61FH410DCHb128X820P9alR9ahP000P01H18AXP00@D4P`F81`P010@
V9BCh>3Ph>?S3N7Shakoool7imkN04_Wf]SWg]kWf]SSd=Q2@01C?3M0:21@?3QKA3a0001<=2e88RX`
01Q2:R16;RQ0<2QQAC01FT`0@42`04S0T0K0/83P^Z3T_ZSP_:3U`;;UaKSU`;3V`[;U`[3V`;3TPZ;W
PK3TPJ3T^JSL/Y_0/9SOZ93JX83@P83HXXSIP8c@P83FP8SGWX[GPH3GVXSBVXG0T03;SW_;S7S0SWS4
SWS2R7F6P7C0R7B0QW2P0620I428BDIP@05A<b108`0P0@0X71PX61PP5aPP41@P41H00@8B2@/P6106
0031P87PgL003^ONgRSoool002Koool7hN?S04[Q`n3Qhn?Qh>30`<5^G5YB@D93<3=C@D9FATAIB4Q=
?3]9=cPj:2Pm;Be3<S54<31KASmaEe04BTJPLEnlRWW@Y83L_JSQa;7Q`;CPakWQb[kQ`kWQb;[QakWQ
b;_O`[3P`kG0`;3N_:cI]j;H/8;I[9SEYI;AX83BYHkBXY70X83AXHk@XI3@P8[?W8_;WHW0U8C6TX;5
TX70Th;1U86nT7bhR7RnRWVcQWF:06B:I5IhETeA03]6;bde8R@P02@W7R4Y7R<P024M5AlN5al@01PG
4ATT6Al::BSViND?hN?S7_ooo`OWg]h0B^OJf^ONg^OKg>CHf75HDE@n>44X:EDn>5U2>ea40Dli<D`c
;S`T83lZ8dD^9dP`:Ui2=GADB0121:A]E/66LMZPT>:iXNNoZnN0X>K2/nO5^>O2/nO3]>O2/nO1]NFm
Z^Jn[nBiZ^BgYMnbVl2PTmnWTMZQRm60P]RQQmNMR]B0P=JMQ]FMR=JHQ=FHPm6HP/bA1<^>Nl^>NL2>
N/J@N/><M8:0LL>6LKR2KHm/@hiOCGaBA5Lj<4L/8cLO6B0J6RPL5bXL620E61hB5AlD51893AP>3RDF
500R3>_Ph@oWg]hXoooo000Voooo1n7Sh`1;hN3PhN?ShN7Q`N3PP6e^EdA4A38`Dd52E4=3F493Ccln
BCLg0R0P>RX[@Bl_AC0bED4mHdi:HTQ4TFQI[G][`j28gk^UiLFahLBah/FehlZli<Vhh/RjhlRghL2b
gl2]g/6bgkj/gKVYg;JSf:B0fJ^GeZB@d8J0dJ:;cin?`82:dJ2<cYn>`9Z9c9R5bYV6`9:4aY>2a9>2
`9:0`9B0_Xmk^8Qc]hIdZh1_RfA5O5I;IdQ3@30a>bPW:adP8A`Q9AdP:QlR2APP618M5a8J1P4B81PO
9ADH12@Ri^OWh^CU00kQhn<Noooo1nONgP1;im[JimkNimcMiMWLQFYUF44k@S0/EChhET0iFT81DC/d
Bc<]12@Q>bLQ@b`UAc4PF3hdITY1HD4hU6A@/gMRd8R1iKJNjl6[j<2]j<6_jLJfj<B`j<BdjL>ah<:`
iKbWi;b/iKRPhkBShK:L`:2@gjJ@g:29dX61eij4eI^7dYV3ei^5di^6dI:1dIAmciEnc8@0bhmkbHmj
a8ihaI1h`h]c_H1T^h=/[geVP61<PE92Jd@i@RDX?BDM;1/E8QP@9QXE:a`G810@60lB5`h@20P08QDD
8Q@A61P;j^;Sj=oP00kWg]hXoooo000Voooo00?Qhn?Qh^?Qhn<01>7Sh`1<hN3QhN?ShN;Rh>3PPQB0
BT10@000DT52@@10D080D411B3He0000<R@X?2PY@30d@3Th@@@2@0000414S4eAP800`:B1h8BXh<2P
`X6Ph<6ah<2Qh<B`h/Fa`L2QfKRPf;bXf;2Pf;6Rg;2Qd:20d:24dX::`820c9R0b9R3`9R1dIV2bYR8
`922a91ja901a800a9B0`9B0P840_91j^HY`XX1RY@1XP717040:HPP1@2X`0B0P80030Q0H010081PL
:1dP01000``A2P<@00018R<V81@E0410`>3Qh>3Ph>?S3N7Shakoool00nONg^OLg^ONgP04imkN01[W
f]cWg]kWg=kVg<23411;@D1@>B1D?SQA>CI00P1D?35:<b/09B0e8Ad08B10:210<31803100300E460
BD>0P0;PX93TP:7PPJ3T^J42j<2Q033UPZ;XPZ_PP:3Q/8?1/:;P/832XI_RX9W0PX3HQ8SIVX;@T83@
T@31U0C0T07@T831T830TG[9P7;8P778P73:P7S0SgS0RG30P7:2P62P062QMV24I5H0@01P02E:92@4
100R6Q004`82400P4A8Y61D4410320`90@80000X200P5100@43Pfl3VgMkVg]h=imkN:?ooo`009_oo
o`03hN?ShN;RhN?S00CQhn<0;^7Qh^7Shn7Si>7Pi;Z]/G]WIE040550@54o@E0625A4AD/j>A8103@S
9c`Y:PPY<4Tg>DPk?D@j06M>B7YAAiD0ILBJR<fZUmBPV=BaW]flZ]bmXMfnZmjoZmRiXMZfXMVjYMRc
Q]R^W]V]W<:1PLfKQlbHPlZBP<^EPLVGQ<RFP<nHQ<^GQ/B@0P;4T7T07<B0N<>AOknBO[b<N;N<M[:5
LZ1gI9Q^Gh]SE60@1UHc<3dW:RX082<I7ALB61PD61`F6b4H7A@@60d<5``:504043X[;E<k>Z2:R]kQ
h^3Rhn3Sh`gQhn<Noooo00?Wg]kWg=kWg]h01>ONgP0^imcLimkNimkOimk0`:RZOV=MD00ZE3dgDc`g
DP<eEd0kCSH_52HR=R4M?RDP32PRBc@_BcLbAS@VJTXnODhnX01<bYF0djJ?fZV@fZfGhkNSh;RPhkVU
i;ZU`[B5gk6KgkFOh::HgZZGgZVFd80:dYIodY=ld980dI5icY9l`99ie9=ld9=n`81h0/V<L@0Lb89b
b8eha8ef`H5b_8Q^]X5ZX7=5W6YFT5m;H0P/Ec0V?RDO:00A91HB60l=61027A<@8QDB5@`=3PT<30L:
0P01>bTREcP`Xh60i=cLi]gNi]kN3NONgRSoool002Koool00n7Shn7Qh^7Sh`04hN?S04cQh^;Qhn?Q
hn?Qh>3<a/R>OWm@101A?ciD@D9@0T1EADI@?Sh@:R`g92Lm:2X8:2Q8=cU;?3i0>`5KA45WAT29HD2X
PW>aTH65TXG7XY7D/9kAXicG]J3G]ZCD/83G/IcI]j7HYH;EZiWAYiG0T0C2Sgc2SW_0T7c9T7k9U7o8
U03;U7o<U8?8P`35T7[3SgG0RGS0SGbmSWVhPGB_Pg2WOVbGHd2:H5AmEDU01S5:;2Xe8bHU604N5A/F
41L@4QPH4QXH4AP92a@>3QTB41XF0A0m:b]gI6>]/[;PhnCPh^?Phn<=hN?S7_ooo`03imkNimcLimkN
00CWg]h0BnOLg^ONg^ONgnON`=?0`iAjMU00<5@k=EHn>50l<UQ1?58k=18T83PQ7ClU80XT84Xd;dhi
=4@h<Em0>6Y3>8aADJinJkN=NL2@OLbNR]V/UmFZUMj`VMbbWMZZV=b]U]jcVl:PT=^VT]RRSL20L<R;
LlR:Llf0Llj<M/j@N<j@L=2@Mm6@Nl2;LLZ<LlR:K/R1L<F9ML::LH20K;AoJ:]jIH1WDXiLBX9@?d@2
8d`Z83HP6bHH4QlB4AL<31P>01T?3aT>3P`02Pl:3A@<3a@>03dY8XAMELN/ZNKNgnKMgP0>imkN:?oo
o`009_ooo`03hN?ShN7QhN?S00OQhn<0B>3RhlS=cZ26T480058o?U54A40005M6AeA1A00X:3XP:3lX
:0@Q8DPh>4@3@400040c>48d>F10@0A9D1IPBH00H:R218R0PHB00<2:Q8j<R820P<2:P/NPT/20P<25
PHRCP:00H:H0H:00HX20H8B0L<20LX20L8B6L<:9N<21L8F;LX24HH20L;20L;:1HZ00H89YHH]QAP50
@6]02602=00P8@0R82PM800A618@6Q495Q0060<:40P04@00010@600H8R01048Y:9f2PL30`^7Pi>3S
h`kQhn<Noooo00?Wg]kWg=cWg]h01>ONgP1;imcNimkNimkNi]cNi<S8Z861@P00E3`dF44j@30`FD8m
D@8h020P?24N@BDQ0208BS@PD3``D00`AC@`B30R040044I0P5A1P610[0i`SY0:P804`8H<`XR4`820
aH>4djB1dX24a820`XX0P018Zg53Z@19P01P`0ARa8AR`85P`H=R`85ab85P`89`QH9QP01PP0AP]PER
Y7E0RV90TV9FP480Kd0dH`8R@2@000@C:QP@01004`d050P840P<10P91`0000004@`0110B0009@R8S
R860`<31imkOi]cN00kWg]hXoooo000Voooo00?Qhn?QhN;Qhn<01>7Sh`19hN?PhN?ShN?Sh>;Sjo3`
a/;60e14DShmDcln@000EDE6E4A6A30`@2X[?BL[1B<TBSTjEdI6EDI6Cc`oBcTlF494K5A=LEQBP61H
UWEZYh9bQ@1T[8IeYXIiY8A`/XQg^iB0_HP5]8ekYh9cTV50U6IIV6YKQ71N[7=U[gYVYGYP/GeX^Wm^
]01X/H1][gaTZW9VZ7MXYGIRPf50SfEIPUmDID@2GCTfDc8_120P;alQ9A/N610H50hI4@TE0@TD2`TE
1`HC00@@5@lH7QLP=20XMf=Rd<[:b=3B013Qhn<Noooo00?Wg]oWg=cWg]h01nONgP16i]gNlN_/c;g0
2412E3/dES`eA3PbF48lET4l@2XP@RLQ?R@Q1b08C3H`FT8mF4<mDSPeCCHa@@PhKU54LeE:QD90VG5S
[7iZXWAT/X5/[89`X0=P^8=^`Hmh`X1e^XUc[7iZP6QEV69@WFIAXVaD/6mL]7IM/790]WUP_g]V^WQP
]WaU]7QL/79M[7APZG9JQfU@Tf5@Qe]:L40`H3H/EBlU1B00<A`G9QPC6P4>50/>4@H9000:2`L:20@7
008550d>7Q@F028NPe]Df/?4hM3D0^ONg`kWg]hXoooo000Voooo00?Qhn?Qh^;Qhn<01n7Sh`17h>;S
j>c/e=?F8@03DSdmCCPgD010DdA4Cd52@080@Rd^>BHZ1R@QBcXjFTU:F4Q9EDE7DD12Ed10JeE?JeE@
2D1DQ6UOTFmRR610TFiRRVaRQ6iPUVePXW][X01TWWYZT6mSPF1AOeM?QU]>QT9@UV=FVFQHP65FY75N
ZG=RXW5PWW5QX71LV6AHVFaMU6QHPV1DPE]AMU98B08`D34_Abd/:0DP:A`Q8ATL618I4@dH3@LC200B
20PD2PXG2`PA60`C6Q0H5086XiJEf]SHb<o@h>?S00oQhn<Noooo00?Wg]oWg=kWg]h01nONgP0Ci]cN
kNOXf/k@:P@1DS/eCCH_D3`fET0kDCdh@3@VABXT>b<P220;CSL`GDI0FDE0F44nE3`h@D0k009]DTL0
<`aJC8QUEiI[FHeQD9IYFHmXF99ZF9eXEZUfHJT0HZ=gHIA[Fh14@H=CAXYFA81JB9]OBiiTCZ1TA:U/
E:m_FJQ]EZ9]EjA/Dh1P@9iXE9QTD910BHEGB7]=?T`f858]9DTZ8RP25BXI5b<F4QP?018:3@h520@4
00T62@`72`P621@;31L?42D06KB=R>;BdnC9b>OMg^ONg`0>imkN:?ooo`009_ooo`03hN?ShN?PhN?S
00OQhn<03^3Shl34a>3Rhh0@P510@4Pd<U10@450@40h>D0004D`<3LP:PPP844j>@90@400=T57D5Q8
B410@6QHDVABD71HD69DA6Q<@410@5I2@4@B2D10064@20Q1A018@055B61:A410@4P9164:0T000010
009420100814@h90@@10@010@Pa0@@100011@P58A01206=024P0<@PP8@4P830P8@@000@H8A`F6100
600<5`P4400000L850@@000@00X440044PP01<30b>7Qh<30`0;Phn<>hN?S7_ooo`03imkOimkNimkN
00CWg]h0=^OLg^ONg^ONgnONg^3H`>K4aX0@45@504Pa:E00<54l<D<a<400<T4P8cPQ0@PQ84<h<618
A418@4A4AT901D1006iDB6Q0AP1@@F5@@P18240<06500E4;0610068:;`142Q10@010@6102V1004X1
<6@8:448<0A0:`I000A5089A28A2301000E<21=A2P1000Q<2@100@1006I004d1808080002S@R700@
020E5P0@41P00P0830P01P0010P42A80408010001A<410P02=32`N;4a^30`002i]kN3^ONgRSoool0
02Koool00n7Shn7Sh>7Sh`08hN?S04GLgMkYkNbPX:EcHVAHADI@@45=?Si8?3e@@419=cPm;c92<CEG
ADARDE5QD49SEeIQD510@41XEU=UD4iZD4UPCDIOACm2>SQD?3a9=39@>CUE=c=M?S]VB41PAd5G?ceA
10A:=3EA<c18<31G>31H>C=40C1[ASa/B3eX@CYRA3eWACi0>c1QA3YO?cYH>CMB>SIA<2d3820a7R8[
8B@3404I51dH4aTB01<=2aH81a811Q082A8D41/8500n9bY7=c/S0PSfnOSVjn_3`L800^3Sh`kQhn<N
oooo1nONgP1;imcNimkNimkOimkOh]SIknSXXHRTMeiKFd4lDS`bCcXdBSTcDPDiC3<^@2`W@2XRFT4j
IDe7HTa0IEA=Hde6A4E0K59:J4a4KT10I4TmHD8gD30`ECXcBC8ZD3PaECD[Gc/bJ48jHT@hF3`dDP0`
C30ZDS0WBR8XFCDWFSDZH3TQKT8bKd@cJT0`ID4cJT8c@cPXI40`HS/`G38/ESH/DRdS10HI<Q`H;AhI
0@T66Q0B6A0>4`P03@P;20@70P0620H850d@2A0@@2@PBS<`@A4>m?Shj^KWh<31imkOi]kN00kWg]hX
oooo000Voooo2n7Sh`15g^3Qi^[Z`<C2T864KU]N@3/1C3`lCT11D410C3XlAcPj@P41GTa<He9@H51A
HE=BGdm>@4Y:He1=ITe:H4U1GdM3FD4mBS@fD3`l@c4bACDeCcTfD3LhD@@0Dc`kCcPg@C8a?bd_@R//
?2PXAbh[B2l/@C0PDSHaECPbESXdDSTfDCHc@30PBcD_D3@aB34_@Rh/ABXZ;20R:a`P9QdP0A004`hH
510H0@PD30XE2@PD20PE2`TB50/D4P00F454LfEXR821k_7aiNWZ`<C400;Phn<>hN?S7_ooo`[Wg]h0
A^ONgnGKg>cUiLJOa9IlNg=GDd8h<4li<e4m=e@4>Thg<TTe<4@d<F59@VI>Af5=@6=?BF5;AD14@6I<
@fU9@FI20654>U/n=40a954i<d@_:D0b950g;E4d;e40<5Dh<U4e;T@`8D4Z94<X8cdY8TP[8DT/8T4P
8e@b:5Ld:5Tg:U@f;E@c:40Q8Dhb95<`9TT^94@[8DHW82d45B`I5BLJ5@851A@;3AD=3@4220`72PX6
2@X02@X7210:318<264j=giNFhN4Q>o^kn[Ui^GJfQ3Wg]hXoooo000Voooo00?Qh^?Qhn?Qhn<01n7S
h`17h>?Sh>3Q`<CP`<30QJ20Q@0B@080@3dmDD18D410C3d0D410D010H5=@HE1>@410G4Y:F4U9FTY8
FT12J4Q4E000G0<0D3`l@000C3`l?C4a0201B3dk024d020b128b@R0S020Q9B@R8@@P800P:0@R:0HR
000P:08P;PPP020P12HP;0PP000P9`@40b0P800P8080:R0P800P8QXN018J010J2P8@00TF000@30PD
30TF010040@@000620080eQPPIBDb<30`<31`^3Ph>3Qh>?S00oQhn<Noooo0^OLgPWWg]h0AN3M`>3J
`<;0`8BHW8<82T00250j<5U005@0>40j=504>500<6Q@BVA<A410@452@5e2@D100410>6Q5>UL08400
=5<h<d0P84hk<40]:P4X:4Tj<@@X:00P80PW9D@Z8@0P030P72@06R0042T062X0500042P050445`00
0@0P82d2500462004P06620042@043406R00420@408C400400X40@08200400P02P`82A000Q420102
00@0081@D828P/20`>30`>GK`>30`00@imkN:?ooo`009_ooo`03hN;RhN?ShN?S00OQhn<0An3Shn;T
iMgOgn3PhMG>d[>V[5M2@5=0?eA2@dX004dn?eQ9BE=0@6EEEUe=C411@5Y8B5M8B591@5I1@653@4X`
<E@i>Ddi>d0`<dPj>cd`=@DX=T8j?CDW<B/P838T;3TV:b0P8B/Q92@L908H0B@I8BDK820H020G7BDI
7R8J0RXM924G720I01hF6R`K820H7A/C628H80@D01XE6aHA61046PX64Pd:5PP24@l=610>600@02dQ
8d4^<E0T9Z^MX=WDdnC`l]SJfmkOh>3PhN3Sh`0?hN?S7_ooo`03imgNimcNimkN00SWg]h0>NSOh>?I
fnK5b=W:c[RQY@108eHm=UHo>T0h=Dlk=UY6@510?6QBC61:@T941Ue4?EY5?eQ0>UPn=fA0=T0`85Df
;dlf<D0X8D/f<Cl/:`PT94Dg<SLT9C488c@Q8S/S8B0N02`N6RHI6@@A52DG5RHH5B0@4B4E4RHF52<H
52/J6B4D4B0@4QlC3bdH5R8E41`A3B<E5PDB41`A41H>3A0000X41`d82`P40P0240/=00`2418_7QQ4
:RD35A2jTiOPclgPl_?Qe=CUf]_P`<3Wg]kWg]l>imkN:?ooo`009_ooo`03hN7RhN?ShN?S00OQhn<0
A^3Shn7Si=oQhN7Ph]cIg<Fn`b8@65Q3@ddj>T@d=4`n?eI7B556@5m@D5Q:BUA4A5Q7AeA5AU09258o
@5Pm>`L^84Pc=4Tg>D0U<4<c=S`^=30Y=S`c>C4R;24P:2XO9bdO9R<N9BPO8b0I8QPD7AlF7b4H808G
7QlH728H7AlD620E7Q/C6P4@6Q`C6B<G7Q`D6AD?5QHA6a065A<@60h<5A0<40`85@d<5`0051@C7A4?
60DD64<a<6IDEX4@4LFn`=oMgNSPh]gOh=oQhN3Sh13Qhn<Noooo00?Wg=gWg]kWg]h02>ONgP15imkO
iM_Li<G6h=CHc;Vm8100FD4jCCPbA38UCSXdFD@nD4<lHTa6FdM0ET00Fd<mEd8lDPP0EC`fFSXa@BPT
BS0YBc@^@20PARl/?R/Z=R8Y?Rl^<alQ900P:a`M;Q/M:1PI:A`I8QHG6Q0@81@D8QDE0Q@@81DB8aDC
018@81<D6a4@0A0@714>91@D71425@`;5`h@4P0050d=3PX;4@T<30H93PT<10D05PlA4P`>010AARdU
Lde7T@P4d[JiiMWHk>cPi=WJiMcLi]cN013Wg]hXoooo000Voooo00?QhN7Qhn?Qhn<02>7Sh`15h>;S
h>3P`<34h>3P`lG0P0P0CDQ0B34`@000C3l0DDA5@410D451@TA5D411ETE5@D10@P00CCi0A38b008Q
=2P[@34c020U>b@Q?2Tb820P<R4`;A`P900P0QP30Q0P81PT9Q`R710P610H614L7AHP710081P08QP0
4P@@400H618H610H6A0H61@N400E40`D10PD000@20PD000@208@40XC0`0I10400`0P5Q400000DT50
S20RP861cM7BhN;T`<30h>7Rh>3Ph>;S013Qhn<Noooo00?Wg=cWg]kWg]h02>ONgP11i]cNi]g0h=[0
h<30bL33P00PH4E0A34P020P@3/eDD0hD00hD40iD40lD00hF48hD3dh@000D3/f@2@X00410204@28X
020P024S?BPX8044<B0S81PL:1TH0Q4@0a4@810H81XH7Q@F600@6A0C010E7Q0@8A4A81DD400040`>
604@610071026A0@40004@P:1@0900002P4:00@8200840P00`X000001a@D010@808@GQH4WA87`8B4
i=3@il3200;P`<000nKM`>KLg^ONgP0?imkN:?ooo`009_ooo`03hN7RhN?ShN?S00SQhn<0AN3Rhn7T
i<32`n?WinOZk:2PY8YiNFUIEe11@4/m?Tdm?d@n?di0@4i4AE14AEQ8BE11@a4214`m?cl];B0182dS
9cLZ;S@R:S<R:C@U;B438B/O:bTK920I8a/E7ATC81hH8R8I81/E7aH06AH@6aTC7APD728L8BHM9AP@
0AhE7QhI8QTG01hF81`G8Q@@6A<>6@X;5P894`l<5`h=6Q806QPC7aTD7`P@02/P9C0R9D0009J2OLFl
_NOPh?3fm^;Wj=WJf>?UiN7Ti>3Rh`0@hN?S7_ooo`03imcMimkNimkN00SWg]h0ANKMg^OOh>;If^[R
h^cVijR6S95dKfiECEI0>Thi=50j=DPj=50l=U10?5E0?5]5?e<n>A8084hi=D4Z8bP052lP6cPV930Q
03DO83DR8RD01R`M8BXH6R0B6A/B4aX@500D42<G5Q`B510<01L=41X@4aT@42<I5RPJ6P0@4QlB4alE
5a`D4R0B5AhD5aH211@;3P/82`<22@l:30l:3Q8:0AX@51TB50PA42/M6c8O6dD`::=jL]>d]NCPhO3e
lnSRi>;De>SPhNOOh>KLgP0@imkN:?ooo`009_ooo`03hN;RhN?ShN?S00SQhn<0AN3Shn7Si<3PhN?W
inKYj/K1`ZbQXXn2PE=8BTdk?DTh>D0d=4`o?e55Ae18Bea<CU=4AP800T`l?C`Z:R018RTO92/Q:2`1
92`O9bXN9PHF22DL9b@J8R0H81TC71/E8A`D81dF7QXD7Q00518=6AD@6QPB6b0J8RXP:B0N:BXP9RHP
:@@H9B0H9B8K9QXE01PB7Q<A6Q0161H@6QXF8P0J91hI928J8b0@6S@O7dH_;@I>B;J[Z=C@dNORh^_`
l>?Wj=c0gn7Ti>7Si>3Sh`0@hN?S7_ooo`03imgNimkNimkN00SWg]h07nKNg^ONgnCLg>[Rh^_Ti/2T
Z;JKV9QlMUi1@4di=4Pe<D0`8Dhk=E=2?EA6@Em8A5I0?0PT84hi=3dW8B0J6BXL6BdN7BlL62dL7B/K
70TD4BHI72DG624D41X@4@02718E02@N4a<K4A<A2P0C2`hF3@lI3a0Q5aL[7AlV6P0/6a`Y71hP41XR
5ATS61/1418I3a<D3Pl@300F3Q0L4aLR5QPP5APS5aTR51<`7QU7;2@2@R33XioNbL[[h^3]kNcYh^CU
f=[WgmoWg]oVg=h@imkN:?ooo`009_ooo`03hN?PhN?ShN?S00SQhn<2h>?S01OPh>31h>32a>30`<38
b<ZDS80100A@2@]5=3D0821<@45EB4Y0@51PD55@@4P082Q0>S`h8B4P024T624140804P4P6B000P0@
000X010201XP6100610L7QPR610L4A4L6A8L4P0D00/G4@`@400I8APT8R0S8200020`:2Pa800P8QXZ
:20X800P1QPR1AP20Q002142820R:B0P920[:R8P:0003b05F1H4P000`<;@h>7P`<30`/74h>3Qh>3P
h>;S0^3Sha3Qhn<Noooo3>ONgP0Oi]cNh=k0iMcMi=[0h<;0a<?4V8:320@0C@83A38T020P@C``F4A0
@410H4e8F441020P@CPb>2D080019QPF010C010@814B0A4A01000A0D0QHD014@6P`@81@G008H0100
81X04Q000109314:310<028G6C0P8B0P808V9C0R9b@2020H0R00820@420A60DD408@40TA4B<4800P
82840Rd71B0440PP65h@08000<S=c>;8b>30`>30`NKL`>30`0;Vg=hAimkN:?ooo`009_ooo`03hN?T
hN?ShN?S00WQhn<0@^3Shn3Ph=oPhMkOh<cCe>k`l^7Ngh20Q7UYK6IGFE54A4i1@U93A4Q0@UY<CeY9
BT<h05Y9BDHd=30Q;2PM8QhE7P@A01lJ81`E71/A6a`E7QhI7aPD7A@=6A/D7Q0@6aH@6aL@6aPA718>
610<5a<@624J:BlW=38X248e>cdd?S4X=2PQ<2lV;b`P:B`T;B`S9b0R82lQ9cTZ<C`[8SLZ;4Lb=50`
<FY;A9QkLYR0P^ofn>S^k]S0`][Kg=oQhN;Ui>3Rh`;Phn<@hN?S7_ooo`03imkOimkNimkN00SWg]h0
@^ONgnKMg^ON`>GKgNCJfn3:d?7/l>CJg8Pj?7mTHVYCCd510U0n>5E0>U100Ee8AUa5@D0`<5a5@4Pa
:S8P8RTJ61hC50@@520G5QdB4P0@41dB4alE51X@41D:3A/A4a4<41L=41P=41T241<;3A4:31P042<G
7C8T:@0T04D`<T4_=3@T:B/N9C8S9B0082dQ8RhP7B4P6c0N7SXW9chX83PW8TT^:U0a8Vm6>JEeIL20
RNgdm^_Zjn3Ce>?Ee^KLg>SPh@;VgMhAimkN:?ooo`009_ooo`cQhn<0@N3Shn7Sh>3Qh]oQh/WRh^[/
kN;Shi>0Q9fCUXMlOea0@512@ddl?4@d=E53AUY9BE13BfIFEeA3A00R92hQ9BHJ8@PE0b4J7b<J820I
7QhF7QlH7aPA6a4:5A@=61H06QP@71D?6A`@11LB6a4=6QPC028K:b/V<S0W23db?D0h@C@[<2/T<BlW
;c0R8S8Z<C0W;3DX83HX;3XZ;CXW844Z:5@k>617A8UbK[NVXLc4`>[_lNO[jl34a=gOgn3Qh^7Si002
h>?S4N7Shakoool00nONgnONg^ONgP08imkN04?Wg]oVg]kWg]kVg=gUg=gTbLW]j>[Wg^2JQHJWSHb?
MWD1BTAB?cY=>C=0<REB@3iLAD1@A41ZDTeH?cT49R0_7QXV5aLP4Q4R5aDT5aHP410O4a<P5A@H0Q0@
20/C2`hE300I3Q4F30h1414H3a4B2`lL410T61l^8RL0830o;SA3<cPb8b`]8BHa8b@d8R@e9bHc8b4h
9@Dg928j9b@h9B0n:25F=bl2@0RFJf37WiG5V9;/k>kZinSTfM[UfM[Vg=gWg]oVgMh04^ONgRSoool0
02Koool00n7Rhn7Shn7Sh`08hN?S00?Phn?Qhn?Phn<00^3Ph00B`<30`/G5`^3Pa<30`9g0PX:10@00
@DA6@3Hf020PB3`0G4Y8B410LfEVHU=1@004=2HP:b4Q0R@0800/9B4T80@P8QPQ81PP00000`PB00P@
400H0A82400H00001AH541000000800Q9b@`0200=Bdl@3Q012008RPa82PP020`>38b<20b030`1S0a
120/020PCBPRHT0?4000PYZH`<31`<30`/72`/G5h>3Ph>3Qh>3Ph>;Sh>?ShN?Sh>?S4>7Shakoool0
0nOMg^ONg^ONgP02imkN00?Wg]oWg]kWg]h01NONgP;Vg=h0=nON`>30`>30`NKM`<34`<:BV8:LQ000
04I1340d9P0X84Xh=d18@610@01PA61;@T00804S1C060B0002HJ42X40R00020B4R0@4P010@0220`0
21000P4@410<000200H@41004B0A424H82/P9@0P830Z=4@`>00P830P9S0T8`0P80@R:3XX8T0P844U
:0@X8@0P04PX86101800082@Q<_:b002h<3100?U`<3P`<3P`<000^KLgQ?Wg]hXoooo000Voooo2n7S
h`12h>?ShN?Sh>?ShN?ThNCT`L34fmgMh>CTh>GTin[/e]GISHb<PGEhKUmNEDA1EDM:HE1@I459M6IW
K5aOD0X8AcLhAC8c020T=bT[?c0b>BPP=2H[;b@/80TP8a/S7aPQ8Q/U:Al]8AXV9P`Y;RP_9B0^<2PU
=2`i;b`g1RP0>c=0BSe42381>c4e?2ha@C8`ACDf?bhbBc0`CCdlDC/g@@P0OEeFTgadP862d]7BkoKh
h^?Pfm_KgMkOhN7Qh^GUhN?Th>;S0^7Sh`03h>?ShN?ShN?S00kQhn<Noooo00?WgMkWg]kWg]l02NON
gP11imkOi]cNimkOimoPh]K0h]SGimkNi>3Pj^KZg<oFQh64RG5]ME]DE44jEdA1Hda6HD51N69NL5UE
F080BS@]AblX0R@T>BLP@B`X>B8T=R<Q<B4R80439ALH81@F81PH:a/Q91HJ:0PP<B@T9a`S=2@R=bP_
<bL/02@`>blhBcXl32XV?Bh[?B/VAB<PAc8[@B/YCS4PCcTbDSP^B04/QUQ:WgMWVHZ=e/g=k_;gj>7P
hmGEiMWJh<31j>3QimkOi]gN00;Wg]lAimkN:?ooo`009_ooo`gQhn<0@>3Shn7Shn7Shl3Ph=kQhN7U
iNCPh>KYj]gNh9RBTJNPXiJ<Rg9TH6QKG6EDEF1CDVUIFFEEF5I5@552@Tlk>dPb>4@d=4Lh>40`<T0`
<cP`>00T=3X`=3@]=20Q<C<Z>BhU=2hS=SPc>S<]?@0a04@j@c`f@0`d@4Dk@e0oA4000DHh>TXd<d8d
=4/b<4D];DD`<UA2?f9:APA@D:2;Q[BVX/2@T=_Lg>[_lN3TimkOgmoPhN7Ph>7Ti>7Shn3Sha?Qhn<N
oooo0nONg`?Wg]h00nONgnONg^ONg`03imkN047Wg]oVg]kWg]oWg]oTf]_Ug=cXh>3/i>CZi>ORf=g0
PH>aVYVQQWl0BD5]EU9XDDaRD49[EU5WDTm0@PID?SQA>359<S16<BY9=2m482Q2;BTk;2h1820n:bXi
9bTa8B0h9Bhb8RT0924m;blg:C50<BQ7=CY0<CE1<3A6=caB>c]0<C18=C1:<BY2<RY9<BQ3:bI0<R]G
?SIWAS/H@dB`PgW2X9K1P8;Of=S/jnoXhN3Uf][UfmcWgMkWgmoWg]oVgMh00^ONg`;Wg]h00nONgnON
g^ONg`02imkN00?Wg]oWg]kWg]h01>ONgP03imkOimkNimkN02Soool002Koool00n7Si>7Shn7Sh`0:
hN?S0n3Sh`;Ph>40=n7Ph<30`<34aN3Ri<30`<S:c9fJVH20Q1@00698CD10@5m<C492DD10@4U<C4=4
A4Q0@TA0@511@DP004h<2D0<A410@4=2B414BPP00404A0`0@@00@4A0@409B410@452Ad90@T10@516
B5A0AE400U91@D84=T00<40a8DPZ84T004a8A01@Ah020<2JU/;0`L32`>3Si<;1`L30`>3Qh^3Ph@02
h>;S0n3Sha;Qhn<Noooo0nONg`?Wg]h00nONgnONg^ONg`02imkN00?Wg]oWg]kWg]h00^KLgP0ih<30
h=k1i]gNh<30h=[0hL3O`/30a<C3`92@P800Q0=TKTA2A410Gd]4H4a8@418BTU4BD0<B408AP`7@@`0
@000@0P0@`X8@000B48>@18A@000@C49@30;02D0@@@4@@12@000@D14BPQ1@@00@48o@00j@00`@@Df
B04V@3@PC30XB2PT@00PH40:5413P1<@`9:9c<[6h<30hl33h<31i<31il30i]g000?Vg=h4imkN0^ON
g`05imkNimkOimkNimkNimkO00KWg]h00nONgnONg^ONgP0Xoooo000Voooo3^7Sh`;Phn<0>N3QhN;T
iN3Rh]SJfmgOgn?Wi^3Pho3bmNSZj/:BUjfVYY>9S7ATH7IYIgQ[KVYXLGEXJg5QI79XH7=QHg5UIVQD
E6eKFf9JH6UJH6mPGVQMH5A0D5M;FEI8ET=0@UE<DEU<Ed14B6IEEEe=D5Q9B5i=B5i3@V11@VE>Bfe<
Af11B7IDCGEHE058@h]kN:BATL:ET>K[k>ofn>CXj>GXjM_Kfl31`>;UiN7Ti002h>;S00?Phn?Qhn?P
hn<04^7Shakoool3imkN00?Wg]oWg]kWg]l01nONgP0mimkOi]gNi]gNh<30j=oPi]gNhM7BiM[Jj^;P
hN3Ulnkdk>KVa8VD^J2KWH>2065<O6AMOVMTKV1ZMfESM5eLNVEMMeaKMV5LHU14LEQBHUMIK5QHLUeE
JeUGFDA1FTIBEdA@D011F4U8G4U?A410JE9;GdY8@D90HTXmHD0hH48hJ4Y1L4PnJDT6NTm5NeA944I8
UgA/]8V6`8n@j>SXko;gj>KQk>?ThmKEi=CDin3QimoPi]cN00;VgMh00nONgnONg^ONgP0AimkN:?oo
o`009_ooo`03hN;RhN;ShN?S00_Qhn<2h>?S03OPhn3QhnCPh^;N`>3Ph^;SinKQj>3[kNoVjNWBd=76
`l>d/;:0T86IT8nHSi>00821MGakL7N0MGR1LWV8O81mJF1mK6ecIfeeHV1aGem[G5mPD5ERDUaPCUIH
@D1KC4iNC591@D1UDDmRC4]OB41QBdEOA41T@D1[DdmaE59dHTRAMg6FP7j7P82_YZG0][OBc<oVj^_Z
ko7Ph>7Tj>WNh>30h>000^7Si0?Phn<DhN?S7_ooo`06imgMimcNimkNimkOimkNimkO2NONgP0hi]kN
imkNimkOi]gNi=[Hi]gMj^;Qj^?UknW/jnGUf/?8d;fk_jVYX8R1Xh^4XHV8PWJ1QW5cOf]_P75`Qfe`
SWQfP65RPFQTMFAVN610LeeGKEUGH4A6HdiFGdY@F450G4U6GdY:@DI0ITi7HTY4H40mHTPlH44gHD@1
KTm6ME1914E@WG1VXgUbYH41_IjJcZj]a<38jNKWk>__jNCVj^?TiM_Ki=[K0^ONg`04i]cNi]gNimkN
imkO4nONgRSoool002Koool00n7PhN7Rh^7Rh`0<hN?S03SPhn?Ph^?Phn?Phn3Ph>3Qh>C1h>32`<32
a<C0a>3Ph>3=d]?6d]20P82HV9R@TIF0P82=Phb44HV0P820PXFBPY:0482<31>010Z0HVQdB65XA4L2
@41/@DYX@5I8@41RA49RA411@49T@D1RA4IP@49P@T1P@0T0@D1b@45dC5200020VYF@R8R0U932c/o9
d=;1h>72a<C2`<30`<30h>3Ph>3PhN02h>;S0^3Sh`03hN?Sh>?ShN?S00?Qhn<00n7Rhn7Shn7Sh`0<
hN?S7_ooo`03imSLimcLimgN00;Wg]h01>ONgnOMg^ONg^OMgPOWg]h3i]cN00?P`<3Wg/3Ug<000^30
`00_h=W0h<30h<S@dL7@`8:0`I62`XV>P820Q0f2R0V0P0b0QA:4XhJ0P08@P0P4R002PV1PMDA0JD1H
0410KDA1J516@411HT90Hd=1@400I411H490H402I404H4<0044414180TQ4P0@0T9>9`826`820d<S8
h<;@h/38h=S0h=G0hL30iM_Ki]g0i/3000;Vg=h8imkN00?WgMkWg]kWgMh00^ONgP03imgNimkNimkN
00CWg]h00nOMg^ONg^ONgP0Xoooo000Voooo00?Qh>3QhN;Qh^<03N7Sh`0gh>;Sh>?ShN?Th^CThNCT
gn7Rf/30f]cLgMoPh>SVl?GfloShi>3RhnKUg]kRP830/ZbeZjZdP:Re]:nla;o6/ZR`/JN/[j2TXI:D
U8B8SWn2T8>0TX:5T7ikP71aQW1_QW9_P6iXQG5_RWE^QG1YQg5[QG1ZS042VHR4VHfB/:6Xdlo<gM_N
h>7XlOOhkoOjh^7Pg^3PfmcLfm_0gn7Qh^GVh>CT00;Ph^<01>3Shn7Shn7Shn3Sha?Qhn<Noooo00KW
fmcWg=cWgMkWg]oWg]kWg]l5imkN00?Wg]oWg]kWg]h00^ONg`0gi]cNi]gNimkOh<3PimkPiMcMh=7B
h]OFi=[Kk>7Ql_7cmOCfj^3Qj^7PiMWL`:jl_:B^[jB`PJFa^JZfb;[1^:6]]j:U]iZLZ868VgmoTg]j
P`=lUgimUWY`P6QYS6aUSFiSR6Q1RfaUTG1SP6UQSFaRS6aOP01TXh9iXhR8R:6@gL[4i=GJi>3Qlo;g
k_Ghj>3Qi][KhmKFhM3BiMcMj>3Rh<3100;VgMh00nONg^ONgnONg`04imkN0^ONg`kWg]hXoooo000V
oooo00?Qh>7QhN;Qh^800^7Sh`03hN;ShN?ShN?S00SQhn<2h>?S03GQhn?QhnCQhn?Ph^;N`N3NhN3P
h^?Uhn?[k^o/l?3Qi>WSi^KQh^C1a=39a/c4a/_0a/39b=3BdMG0`LW6`<C5_<2j/;BbZJbZXZFPY:2/
XjJ[X9nRU9RRTiBTUYFSTiFTVIRXW9NPVIFTUiBSUi:XSX^h[jfh/kS0a/3Lg=_Qh^CQjNS/lO;[l_?S
j>SPhnCNhN70h>3Phn?RiNGPh>000^3Sh`KQhn<00n7Rhn7Shn7Si00>hN?S7_ooo`09im_LimcMimgM
imkOimkNimgNimkOimkNimkO00;Wg]h01NONgnONg^ONg^ONg^ONg`02i]kN0nONg`0ei]cNi=SHiM_K
i]gNj>;Pk^[/l>c]j>;Rj^7QimgOd<K0dKo6bKo8`/38c/;;elcAc834c;^ncKJi`Z2/^Z:T/YbN/860
/ijN]9^EXY21Zhj:[Y6:[82:[i>>/iJ=YY::[i29[i67Q8R0`jRT`Zf`d<28i=OEimcQh>CPkng`k>ka
jN;Qi]kOiMcLi]SLi]kOin3Qil73i]gNi]kNimkN00;Wg]l3imkN00GWg=kWg]oWg]oWg]kWg]l00^ON
gP03imkOimkNimkN00CWg]h00nONgnONg^ONgP0Xoooo000Voooo00?QhN7Qh>3QhN800^7Sh`04hN;R
hN?ThN?ShN?T1>7Sh`03hN;ShN?ShN?S00?Phn<03N3Rhn3Shn3Rh>3Ph>3Qh^7Pi<30`<;4a<;1`L;0
a<3Ph>3Sh<3Ph002c=7Q02G4`<38c>37h>30`<C0a/78`<W2`/34a<O1a<O0`<34`<71`L;0T9RAQY31
T9;0T9[0`<30`L30P930U970U930`<32a<C3a<S0h>3Ri>C2aLK0`<30alK2alK0`<30a<CPh<C1`<31
`/C0`LC0`<001>3Sh`CQhn<01N7Rh^7Shn7Ti>7Shn7Si002hN?S00?QhnCQhn?Qhn<00^7Sh`03hN;S
hN?ShN?T00;Qhn<Noooo00?Wg=cWg=gWg=d00^OLgP04imcLimkOimkNimkO0^ONgP03imkOimkNimcN
00CWg]h0;NKNg^KLg^KNg^KLg^30`>30`NON`>3H`>30`N30`>3H`>GK`>KNg^30a>38b>78b>31`>31
a>C3`<30`<[0`>30a<30`<30`L2F`L2D`<R@Ulf@T/R4U<20P/R1T/20Ul2@T<jDT<2@T<R@P/2@P<20
`<c7bLg1`>70`>S0hN30`>G0`>32`002h<3000KTfL3Wfm[Pf<3Vf=SUe]KT`/05imkN00SWg=kWg]kW
g]kWg=cWg]oWgmoWg]kWg]l2imkN00SWg]oWg]kWg]kWg]kWg]oWg=kWg]kWg]l2imkN:?ooo`009_oo
o`06hN7RhN;RhN7RhN;RhN?ShN7R1n7Sh`03hN;RhN?ShN?S00;Qhn<0;>3Shn3Rhn3Shn7Si>3Ti>;T
iN7Si=c0`M[Lg=WKfmc0`=oQh^7ThnWQkNodlO7clNSPb>cWgnSSg>7Rg^WTh>_Wi>?Sh>[Wi>?Pgn7N
g]kLfn7LfL3Af=cDdmkFe/;Den7Ke]oJe]k@d=_Dd=cCc^3HdnSQgNSPg>30d]kDd=[@b]S8a@;Ca/00
1m38`MS=b=W>b=S=b=S=amO<aM;8a002hN?S0^3Sh`05hN?ShN;RhN?ShN?ShN7R00_Qhn<00n7Qh^7S
hn7Sh`02hN?S7_ooo`0:imcMimgNimcMimgNimkNimcMimgNimkNimgNimkN0^ONg`03imkNimcNimkN
00;Wg]h0=^ONgnKNg^KMg^ONg^ONgn30h>SOhNONgn3IfN;Fe^7EeN7Hd^GLgNOOg_3XjO;`kOO_jnK6
`_CRfO3Ne^3LfNoOg?3Sh>32`NoRhNSKg>KHfnCGenKGe^3BdN3?cn;AdnC@e>OFd^CEd^?A`>;?b^C>
bNC@dngLf^oKf>3CdNK>bn;;a>36P=c0^]k0^L70_N77`^79`^70`^77`N36_l33P@;Wg]l3imkN00SW
g=kWg]kWg]kWg=gWg]kWg]oWg]kWg]l2imkN00?Wg]oWg]kWg]h00^ONgP03imcLimkNimkO00;Wg]hX
oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool00;ooool3
0000J_ooo`00`?ooo`030000oooooooo06Woool003Goool300000_ooo`030000oooooooo00800002
oooo100000Woool500000_ooo`800004oooo0P0000?oool400000oooo`@00002oooo0`0000;oool4
0000:oooo`@00004oooo0`0000?oool300000oooo`800002oooo0P000005oooo0000oooo0000oooo
00<00004oooo0P0000?oool300001?ooo`<00003oooo100000Ooool500000_ooo`800004oooo0P00
00Coool400000_ooo`<00002oooo100002Koool003Koool010000?ooooooo`0000;oool010000?oo
ooooo`0000;oool010000?ooooooo`0000[oool01@000?ooooooooooo`000002oooo00@0003ooooo
ool00002oooo00D0003oooooooooool000001?ooo`040000oooooooo00000_ooo`030000oooooooo
00Coool00`000?ooooooo`0/oooo00@0003oooooool00002oooo00<0003oooooool00oooo`030000
oooooooo00?oool010000?ooooooo`0000;oool01`000?ooo`000?ooo`000?ooo`000002oooo00@0
003oooooool00002oooo00<0003oooooool00oooo`040000oooooooo00001Oooo`040000oooooooo
00002_ooo`050000oooooooooooo000000;oool010000?ooooooo`0000;oool010000?ooooooo`00
00;oool010000?ooooooo`0000Koool00`000?ooooooo`0Voooo000foooo0`0000?oool00`000?oo
o`000002000000Goool0003oooooool000002_ooo`050000oooooooooooo000000;oool010000?oo
ooooo`0000;oool01@000?ooooooooooo`000004oooo00@0003oooooool00002oooo100000?oool0
0`000?ooooooo`0/oooo00@0003oooooool00002oooo100000;oool00`000?ooooooo`03oooo00@0
003oooooool00002oooo00L0003oool0003oool0003oool000000_ooo`040000oooooooo00000_oo
o`030000oooooooo00<00003oooo100000;oool010000?ooooooo`0000[oool01@000?oooooooooo
o`000002oooo00@0003oooooool00002oooo00@0003oooooool00002oooo00<0003oooooool01000
00?oool00`000?ooooooo`0Voooo000foooo00@0003oooooool00002oooo00<0003oooooool00ooo
o`<0000;oooo00<0003oooooool00_ooo`800004oooo0P0000?oool400000oooo`<00003oooo0P00
00?oool40000;?ooo`040000oooooooo00000oooo`800004oooo0`0000?oool200000_ooo`<00000
0oooo`000?ooo`0400001?ooo`800003oooo100000?oool200001?ooo`<0000:oooo00<0003ooooo
ool00_ooo`800004oooo0P0000Coool300000oooo`800003oooo100002Koool003Koool010000?oo
ooooo`0000;oool00`000?ooooooo`03oooo00@0003oooooool0000:oooo00D0003oooooooooool0
00000_ooo`030000oooooooo00ooool00`000?ooooooo`0foooo00@0003oooooool0000eoooo00<0
003oooooool02?ooo`050000oooooooooooo000000;oool00`000?ooooooo`09oooo00<0003ooooo
ool0<?ooo`00=Oooo`@00004oooo0`000003oooo000000000080000:oooo0P0000Coool200004Ooo
o`80000goooo100003Goool200002Oooo`800004oooo0P0000_oool20000<_ooo`00ooooobgoool0
0?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool0
0?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool0
0?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo000Voooo00GMg=[Mg=_MgM_MgM_M
g]`00]gMf`07gMkLgMgKgMkLgMkHgMkKgMkLgMcK00SMg]`00mgLf=gNfmgNg006gMkL02SO`=cQh]oR
h^30al3Pd/COdLCN`<CNd/WPd/WM`L3NdLSJc/KHcLCFbl;GbKkA`;_C`[OA`[S@`;GC`KCA_k?0^Z3>
^Zk=^Jc@^Z7C_k?B_[;B_;3@^Zg@^jk@^JcA^Zg?^Jc>^:S>^:_=^:[</:[<^:[<^:S0Q:P5gMkL00SM
g=SMg]cMg]cMg=SMg]_MgM_Mg]cMgM/2gMkL00?MgM_Mg]cMg]`00]gNg003gMcHgMkLgMgK00;Mg]`N
oooo00GVd]CVd=GVdmCVdmCVe=H00^KCe@07i]CFi]?Ei]CFi]CDi]CEi]CFi]3E00SVe=H01>K@e>KD
eNKDe^KDe0;Ve=D0:nKDe>KDe^KDe^3EenWHfN[IfNS5RN[8_NW7_N34P>S8`^W8`n35`NO7`^?3_n32
_]o1_>2o]mfj/=fg/=^h/MZe[]jg[=beZmZaXMV_Y]V_XmZ`Z=jdZmjcZ]n`Z=b_YMb`Y]bPY=f_YMb^
Y=R/X]Z]XmV]XMVYX]V]XMV]X=6YUP05i]CF00SVd=CVe=KVe=KVd=CVe=GVdmCVe=KVdmD2i]CF00?V
dmGVe=KVe=H00^KDeP05i]3Di]CFi]?Ei]CDi]CF02Soool002Koool03]gLf]gHf=gMfmgLf]gNg=gM
fmgHf=gNg=gHf=gNg=gLf=gMfmgNg=gLfPSMg]`00mgHf=gMfmgNg006gMkL02?Lg=SL`=WL`=[HP83L
R:7LR:CLQ:3L`[3M`K3L`:cL`k3L`;70`;3H`:[HQ:C@P:3@]J3B]:30X83@Z83;Y8;0X839X8W0S830
P1R8P1R8P1J0P128QQB8PA30P132QaC0QQB0Q126QA000X204003P8@@PH@<P0T000GMg]`02=gLf=gN
g=gNg=gLf=gMfmgHf=gNg=gLfP;Mg]`00mgLf]gNg=gNg002gMkL00?Mf=SMg]cMg=X00]gNg1koool0
3^KBe>K@d>KCeNKBd>KDe^KCeNK@d>KDe^K@d>KDe^K@e>KCe>KDe^KBe0SVe=H00nK@d>KCe>KDeP03
i]CD0nKDeP0Xi]3DiM;Eh=;DhX20h;:9h;:=iK20iH2Qh86Qi[JPiX6PiK^Th;RPhKBSh;2<`:20`J60
fZ20d::0f:28dHR2`H00dhB0a88@`80@a800`XL<`80<`8@;`XP0`800`H@<`X48`H08`889Sh40PX08
Sh00Sh04P0001NKDeP08i]3Di]CFi]CFi]3Di]?Di]3@i]CDi];@0^KDeP03i];@i]CFi]CF00;Ve=H0
1NK@d^KDe^KBd>KDe>KDeP0Xoooo000Voooo00kMg=[Mg=SMgM_Mg=[Mg]cMgM_Mg=[Mg]cMg=[Mg]cM
g=SMgM_Mg]cMgM/8gMkL00?Mg=SMgM_Mg]`02MgNg00Ufh>RgKnWgKnZgKnXgLBcgL:bgL2`gLBbg/Bc
g<2`fL2_f;n[d[^VfKVTd[NSd:6HdJbEcJNBb::<bj2<ain8aIZ4`iZ4`IIoPYAn`9En`9In`Y00a9In
`IAlPI9j`9=l_Y9j_91j_99i_99fPY@c00GMg]`02=gLf=gNg=gNg=gLf=gMfmgLfMgNg=gMfP;Mg]`0
0mgMf]gNg=gNg002gMkL00GMg=SMg]cMgM[Mg=SMg]`07_ooo`0>i];Di]3Bi]?Ei];Ci]CDi]?Ei];C
i]CFi];Ci]CFi]3Ei]?Ei]CFi]?D2>KDeP03i]3Bi]?Ei]CF00KVe=H3i]CE02GT/I3U]IoV]J;V]J7V
^ZcU^:[V/:SV^Z_V^ZcV^:SR]ZSQ]J?2/HOQ[icK[I_HY93IXXcEWHW@V8?CUX??UH3=T7[;T7_9S7K0
R7G8RgG8S7K8RW3;S7G8RW?1R738RG?5R772P733R733R6fFPR801NKDeP08i]3Di]CFi]CFi]3Ei]?E
i];Ci]CFi]?D0^KDeP03i]?Di]CFi]CF00;Ve=H01NK@d^KDe^KCe>K@e>KDeP0Xoooo000Voooo00kM
g=[Mg=SMgM_MfmWMg=SMg]_MgM_Mg]cMgM_Mg]cMg=_MgM_Mg]cMgM/8gMkL00?Mg=SMgM_Mg]`02MgN
g007f8FPgL6[gL6^gL6PgLBdg<:bgL:`00;M`k<07=c0XMS0[mNo[]6lZmVjYm>gY=BSP=6]V<jWU<RR
P/ZPSLZPS<VPR/NPS<FIQ/2HP<:IQ<2GP/2HPLBJPl6GPL6F0<6GPL6GP;jF0;jFOkjFO/::P0GMg]`0
2=gLf=gNg=gNg=gNf=gMfmgLf]gNg=gMf`;Mg]`00mgMfmgNg=gNg002gMkL00GMg=SMg]cMgM_Mg=SM
g]`07_ooo`0>i]?Di]3Di]?Ei];Ci]3Di]CEi]?Di]CFi]?Di]CFi]3Ei]?Ei]CFi]?E2>KDeP03i]3D
i]?Ei]CF00WVe=H09NBcT>JgXnJgY^JgX>Jj[NFhZ^BhZ>JiZnFiZnB`Z>6fZ>2eYn2`Xn:`Wmb]W=fP
T=ZSSmNMRm:HP=>FQ=:FPm2@PM2FPlj?OLR>N<Z?NlV=NLZ0N<f@N/Z=N<R<M/Z=N<Z=Ml2<M/J<M/N<
M<j0T005i]CF00SVd=CVe=KVe=KVe=GVdmGVd]CVe=KVdmD2i]CF00?VdmGVe=KVe=H00^KDeP05i]3D
i]CFi]?Ei]3Di]CF02Soool002Koool01MgLf]gNg=gMfmgJf=gLf005gMkL0]gMf`03gMkLgMcHgMkL
00SMg]`00mgMfmgNg=gNg005gMkL02SLg=SLg]cL`/3HP:;M`:cL`;3L`:3Na;CHP:3L`:3M`;3HP:3@
P:3F^ZSD_[3H^:WH^:3D/X;@X83@X9;<Q87:P830U83:VXS0X838Xi30T8J0U030VH:lT060V832V8>0
UX30U031V8;2VH2lT02mUX2lT7S0P809gMkL00CMgM_MgM[Mg]cMg=P2gMkL00?Mg=SMg]cMg]`00]gN
g005gMcHgMkLgMcHgMcHgMkL01koool01NKCe>KDe>KCeNK@d^K@d004i]CD00GVe=KVdmCVdmGVe=KV
d=@02>KDeP03i]CDi]?Ei]CF00GVe=H09NKDeNC@dNKDe^K@dnB`P^J`Y>J`Z>J`X>Jj[N2dX>B`X>J`
Z>BdX>2`P<2`XMbdZN2`X>6^X=bXT^20T=R0R]J@P=B@P<210M2@P]2@P=2IQL69O/28L<R00/F2L<20
N<R@N/6<M/R8M<Z>N<b0N002aXa`00?2Pf?0P83Ve=H01>KDeP08i]CDi]CFi]CFi]CDi]?Ei]?Di]CF
i]3E0^KDeP03i]3Ei]CFi]CF00;Ve=H01NK@e>KDe^K@eNK@e>KDeP0Xoooo000Voooo00GMgM_Mg]cM
gM_MfmWMg=P01MgNg0;MgM/00mgNg=gLf=gNg008gMkL00?MgM_Mg]cMg]`01MgNg00Xg]oLgMkLgMcJ
fKnXgL:/gL:`gL6QgL:bfkn]g<2SgL6ag<2_f82Zf;n]el2cf[jPg;b/e[VVf[2PdjfKdZRF`Z2@bYn>
cj2@`Z6AcZJEbi^;`I61`iZ9`9B2P9R0`ib4`9V3`920`YV3a9Z4_YR0_iV3`ij;`<?02=gNg003gMcH
gMgKgMgK00cMg]`00mgLf=gNg?ooo`0Moooo00[VdmCVe=CVdmGVd]?Vd=CVe=KVeMKVe=KVeMKVe=H2
i]?E00?Ve=KVd=CVe=H02>KDeP03i]?Ei]CFi]CF00OVe=H09^KBdn6eX>JhYNJgZ>BgX>JhZnBeY^B`
Y>JgZNBfYn2dY>6eY]nf[>>dXNFbY=n_W^2QP=bSTm^NS]RHR=BEQMRFR=RIR=NLS=BAP/Z=0<b@P<V:
N<R>N<bBNlR?N/R<N<^?N/f?NlN<N<R>N/fDP^39a0OVe=H01^KDeNK@e>KCeNKCeNKDe>KDe@;Ve=H0
2^KDeNKDe^KDe>KDe^KDeNKDe>KDe^KDeNK@e>KDeRSoool002Koool01MgMfmgLfmgNfmgMf]gLf`05
gMkL00CMg=_Mg]_Mg]cMg]P9gMkL00?Mg]_Mg]cMg]`01MgNg00X`<7Mg=gKg=SCf82ZgL6/gL6^g<2P
g<6`fl2]g<2`gL6ag<6af<:`f/:bfL:dfl2`g<2`fKn]fkFXe[BRe[2Nd:2DcjRFdZFEdJ2Dd:JDcZ2?
aYV2aYZ8`iJ3`9:1a9b5`9^6`YR3`YZ4`iV3P962`IZ5bZZKf/3@1MgNg004gMcHgMkLgMkLgMcH0]gM
f`03gMcHgMkLgMkL00?Mg]`00mgNf=gNg=gNf`03gMkL00?Mg=SMg]coool07Oooo`05i]?Ei]3Ei]CE
i]?Di]3E00GVe=H01>K@eNKDeNKDe^KDe0WVe=H00nKDeNKDe^KDeP05i]CF02SPd=7UdmGUcLgQ]:;V
]jCU]jKT]Z3U]jWT]ZGT/:SV]jWU]j[T^:SS^:[R^:cT]ZWU]ZWR]JGTX:3OZY[OYIGKX8CHWHgKVhgH
VX[IW8cGUHK0P@3?T7o<S7_:P7S=TWc9TGg8Sg[;Sg_<Sg[1SGS:T7cDX9?S`/P5i]CF00SVe=CVe=KV
e=GVd=CVdmGVe=GVd=CVe=D2i]CF00[Ve=GVe=KVe=CVe=KVe=GVe=CVe=KVe=GVd=CVe=HXoooo000V
oooo00GMg]cMg=[Mg]cMg]WMg=P01MgNg003gMcHgMkLgMkL00oMg]`0:mgLf=cLf]k0g>3Ph>;Qh=[@
c=R1X=c0Z=R0Z=20X=Z0Z]^oZMc0/=g0/=g0/Mc1/=c2]Mc4]Mc2/=g0/M_4]=b4P=V0X/20Y/20P=2`
R=:PP]BXT=>TU=2PT/2HR<RIQ/:HP<2BP<FLPL22P<2HP<6JQ<2E0X2B0<:LQ]20Z]c0`005gMkL00OM
g=SMg]cMg]cMg=SMgM_Mg]cMf=P01MgNg003gMcHgMkLgMgK00GMg]`Noooo00kVe=CVd]3Ve=CVe=GV
d=CVe=KVe=CVe=KVe=CVe=KVd=CVe=CVe=KVe=@8i]CF0^KDe0CVe=H0:nKDe>C@e>ODe^30`N38c>C2
`>:aP>FfXNBdX>2`P>2dX^BeX>B`Z>J`ZNBhZNBkX>F0YN2hX>BhX>JjXNB2Y>B0X>2aX>2UR<2PPL2P
P<BPT/20P<2HS=Z0R]2@P=2>O=20O<20N<2B0<Z@PLRA0<b@O<V9L<20L<b@OL2RX^C@d005i]CF00SV
d=3Ve=KVe=GVd=CVdmCVe=CVd=3Ve=@2i]CF00OVe=CVe=KVd=CVe=KVdmCVe=CVe=H00^KDe003i]CF
oooooooo02Koool002Koool01MgNg=gLf]gNg=gNg=gLf005gMkL00?Mg=SMg]cMg]`03mgNg00[g=kL
gmoMgMgLeMGAcL_8fL[1f82Tg<6[g<2[f82Zfl2]g<6]gL2`gL:agLBeg<Jhg/Rjg/FegLBdgLRig/Vj
g<2bg<:`g[n]f82PfKRUfZnPeZZBeZJFeJVF`9j<c9Z7bY^7aY>4aY^7`Yj:`Yb6`i^6`YV3PiR2aIn9
fLS3g<3L00GMg]`01mgLf=gNg=gMfmgLf=gMfmgNg=gLf005gMkL00?Mg=SMg]cMgM/01MgNg1koool0
1NKDe^KBe>KDeNKDe^K@e@02i]CE00CVe=CVe=GVe=KVd=@;i]CF00?Ve=CVe=KVe=H01>KDeP0ZimKG
iMCEhLS:fL30hl2jhK24iKNSi;JSh;BRi;JVi;NUi;2Zi[RYi[Z]i[b`ikjbik^^i[R^i[jaiknbi82S
iKRYi[FUh;20hJjMhjFGgj22gYb=gYn>dIB4eI1ndi1n`85lci5obiB1bi9lc95mbhijb89hcYF0h[jl
i]CA1NKDeP07i]3Di]CFi]?Ei]3Di]?Ei]CFi]3B00GVe=H00nK@e>KDe^KCe@05i]CF:?ooo`009_oo
o`08gMkLgMcJgMkKgMkLgMcHgMkKgMkLgMcH0]gNg003gMcHgMkLgMkL00oMg]`0:mcNg>3Qgm[JfH24
P;6ZY]S4^=R2Z=c1[Mc1[]S0/=c1/=c2/=g2/mg2/]g4]Mg4]]g6]mk4]=g2/mg6^=k6]]c0/=^o[]bn
ZmVjX=VfX]V_W]BZT]FXUMFXU/j0R/fLQl^KQl2JQ/JJQ/:JQL2HQ<:KQL>LQL:IP<FPR][?bmcNg005
gMkL00OMg=SMg]cMgM_Mg=SMgM_Mg]cMg=P01MgNg003gMcHgMkLgMgK00GMg]`Noooo00SVe=KVd]7V
e=GVe=GVd=CVe=GVe=KVd=@2i]CF00?Vd=CVe=KVe=H04>KDeP0Yj=OIhm3B`j2P`IjJh[Z`i;2PiKNV
iKNWi;2XiKNYiKRXi[R[i[RZi[Z]i[RPi[b`i[Z/i[R/i[b`i[b_i;JXi;FViKBSh;20hJbJhZFEgZ21
gIf=gIj>d9B2eI9ne95n`I1lci1mbi1mb91ibi5lc95mb95mcYF2hlG400KVe=H01nK@e>KDe^KCeNK@
e>KCeNKDe^K@e005i]CF00?Vd=CVe=KVdmD01NKDeRSoool002Koool02=gNg=gHf=gMfmgMfmgLf=gM
fmgNg=gLf0;Mg]`00mgLf=gNg=gNg00>gMkL013Lg=S0`<3Pj^S6bLX000P<0TCE/8SH`:3L`J;M`[7L
`;3L`;?L`K?M`;3M`[;Ma;H2gL2`01_M`[3M`:3Ma[SNa;GL`J3H`:7L`:cHP:7H^:3J/9cDX9SDZIKF
Z9S>X830WHS<W8O2P836V870T`60T830W8K4Q8S2P8[5XHc1c<[L`<3Mg]P01=gNg005gMcHgMkLgMcJ
gMkLgMgK00OMg]`00mgLf=gNg=gMf`05gMkL7_ooo`08i]CFi]3@i]?Di]3Ei]CDi]3Ei]CFi]3D0^KD
eP03i]3Di]CFi]CF00gVe=H0;nKDeNC@e>30`>SPi>71b0800@A4;<2PP>B`X>FgZ>BhZ>B`XNJhX>Ji
X>JhZNJhZnJh[^J`Z>JbZ^JhZ>J`X>Jl/>Nj[>BeXNB`XNB`Y>6`PN6PV>:PU<2PP=f1S<20T=2@P=2A
0=B@O/2@0<j?N<Z9L<20N<ZAOLf@P<2@P<jAQ>G0`>K@d>KDeNKDe003i]CF00OVd=CVe=KVd]CVe=CV
dmGVe=KVe=@01NKDeP03i]3Di]CFi]?E00GVe=HXoooo000Voooo00SMg]cMf]SMgM_MgM_Mg=SMgM_M
g]cMg=P2gMkL00?Mg=SMg]cMg]`03]gNg00/g]oMf=SDe]KDb<K4P1PBQgEZekRSg<:`gL6bgL:dg<:`
g/BegLBegL2agL:bgLBegL2bgLBegLBcgL:agLBegL6afH:XfKZXfKZWdKNQfK>Mf:fJe:b@djVDe:RF
c:28cIn8c9b6`Yb2aYR3`YEnP9R0`IZ4a9n9`828aJ:>g=gJgMcH1mgNg003gMgKgMkLgMgK00OMg]`0
0mgLf=gNg=gMf`05gMkL7_ooo`08i]CFi]3Ai]?Ei]?Di]3Ei]?Di]CFi]3D0^KDeP03i]3Di]CFi]CF
00kVe=H0;>OEen;4a^3<c=Fj^i0<099ZGn2^VnBhZ>FgZ^Jh[>JhXNNj[NJj[NJhZNJhZnJj[^Jh[>Jj
[NJjZnJhX>Jj[^JgZNB`X>>_X>:`Wn2]VN:XUN2STMbRS]^ORmbNSMF@1MJDOmFBOLB@0Ln>N/^:M<6=
N<Z@NlfEP<2DP/jHQNGCe>K@dPGVe=H01NKDe>KDe^KCe>KDe^KCe@07i]CF00?Vd=CVe=KVdmD01NKD
eRSoool002Koool00mgNg=gLf=gMf`03gMcJ00GMg]cMg=SMg]cMg]cMg=P03mgNg00^g=kLa>34P824
V9B@SH0RX820R927f82Yg<2`gL:bgL:cgL2`g/>cgLBcgL2cgL2`gL:`gLBdgL2`gL6ag<2dg<>`fkjY
fK2PeJ2IeJ2Jd::@d:>BdJ2Dd:R@`JN0`:J0b820bIj7bYZ4`9R0aYR2`9H0P9P0`901`9R0a9R0a:6<
dlJ9f/;0g<3L1]gNg003gMcHgMkLgMcK00OMg]`00mgLf=gNg=gNf005gMkL7_ooo`04i]CFi]3Di]?E
i];D0^KBd005i]CFi]3Di]CFi]CFi]3D00kVe=H0<>KDe>KDe^?De/24P8V8PH0A0X2009:15>2bXNB`
Z>JhZnJh[>JhZ>JiZnJjZ>JhZ>J`Z>JhZNJj[>JlX^JkXNJh[>JiZN2dXN2PP<2QT<2PT]R0P=Z0R=bL
S=R0R=:LP=2LP=2D0M2DO]>@N<20N<n<NLb<M/2<L<R<L<V0Llf@0<fGQ<21P>30`>KEd>KDeP;Ve=@0
1^KDe^KDe>KDe^K@eNKDe^K@e@OVe=H00nK@e>KDe^KDe@05i]CF:?ooo`009_ooo`;Mg]`01]gMfmgL
f]gJf=gKfMgNg=gLf17Mg]`0<MgLfn3Qgnkakj:PYFaVHei>A8B18>oB_=o4/]c0/=g3]=g2]=g0]]k4
/mg4/mg0/Mg0[mfo/=g3]=g>_]k>_l78^=o5/M[0Z/6`X=>WTmBYU/:QQ<jSS]:XUM2ZU<f[SlZWRl:2
R<NOQlVIQ<2HP/JGPLJHPHBG0;nCNkjCN/FFP<FQSM2k/L;2`moThmgOgMgNf00>gMkL00?Mg=SMg]cM
g]`01MgNg1koool2i]CF00WVdmGVd]?VdM;VdM?Ve=GVd=;Ve=KVe=GVe=@03^KDeP0=i]CEj=OHlnW[
/H^@NE]EJ4@iT202m/Vej;Z[i[2Zi[V/i[R/i[R^00;V^Z/08NJhZNJfZ>JeZNJhX>G5]^K5]n63/>Nk
ZN:gX^2VP]^MR]^PSM:HPMJIQMVOS=2QR=BRQM>MPL>@0M2EOm:?Nl6>N<n=N<j>N<F=L/R9LLJ9LLb1
MljGQ=^aZ>30a>KJgNKEeP03i]CE1>KDeP03i]CEi]CFi]CD00GVe=H00nK@e>KDe^KDeP05i]CF:?oo
o`009_ooo`08gMkLgMcHgMgKgMcJgMSHgMcJgMkLgMcH4MgNg00Ug]kLg=gKemOEPHBASX=jRGM[T920
iLVdg/>`gL:bgL>dgL:cgL6`gL6^gL6_gL:Rg/>bg/:cg<2bgLJggLBeg8B`g;ZYek2Od8bAdIZ9dI^:
cY20cIJ4ciN6cYR1cIb6bYf6`9Z4aYb5aiR2`I2000;5Uh4028BG0<:EO/2EO<FHPL>NR/bbYM34T=gL
f@SMg]`00mgMfmgNg=gNg005gMkL00?Mg=SMg]cMg]`01MgNg1koool02>KDe^KDe>KCeNKBe>K@dnKB
dnKDe^K@e0;Ve=H00nKDe>KDe^KDeP0<i]CF02GVeMKUdmCQc<fPPH2KMfnGJek1QAS]_jgW^JSV^:_V
^JcV^:cV/JSV]jOU^:OV^:;V^J[V^:_V^:cV_:oV^JkT/:SU/:7QYIO4P83KSh7JT8;@S7gFS7cHS7kA
PP3GTWkCTgg1T7S>TWc@SWW:SG000/j=N009b8edbX]eb8Ycc85hc9B1ejRLaHR0i];Ci]CE00OVe=H0
0nKDeNKDe^KDe005i]CF00?Vd=CVe=KVe=H01NKDeRSoool002Koool01=gNg=gLf=gNf=gMf`;Mg=X0
0mgNg=gLf=gNg00@gMkL0370`<3Hf=:0P:R4T820RXR=U830XH3O`k3L`:cM`;3M`kCM`[?L`:3L_ZSL
_jWLP:S2`;30`;32`;7L^J3L/:C@X:3HX8;@PHC00030303:36o0003:26c806W82V30PgC9Q030P0;0
V8;1U`20T7c4T875UX30U`74V830UWk4T821V8?0RXS0Q83Jd<3MgMSL`=`00]cNg0CMg]`00mgMfmgN
g=gNg005gMkL00?Mg=SMg]cMg]`01MgNg1koool01>KDe^K@e>KDeNKCe0;Vd]@01NKDe^K@e>KDe^KD
e^KDe00<i]CF0^KDe00ah]3@hLC6T9BDQ880PH21V8PJa826j;VXi[2Ui[RXi[V/i[RXi[2PiKBPiKFQ
i[6Ph8:Ph82Ph;2XiZBPiZJ6`:20hHBBfX0<`000dP5Pd05P`01@d@1TdVUPe0=PdP1Td85``85`bHii
bXee`HQ`cHahcXagb8e`c8ihbXaec8Q`b81j`IB0`8R0i<;0i]7Dh=C@00;Ve=H01NKDe>KDe^KDe^KD
e^KCe007i]CF00?Vd=CVe=KVe=H01NKDeRSoool002Koool01mgNg=gLf=gNg=gMfmgLf]gMfmgOg@02
gMkL00?MgmcMg]cMg]`03=gNg00eg=gKi>OQjN[YU92?4`1@fl2YmMS5hlRhg/:agL6[gL2bgL>egLBe
g/6PgknXgl6Y`XVPj=K6i];2h<6hh;:Wg:NNd:2@eYVAc7Yb`4U0bF9Ia6EKSE18b6MNb5eDbV11eWI^
chAj`HH0`iR3`9Un_95i`iV3aIN0a9J0aiZ4`YEn`900_9Eo_I1g`H04flg8hNGU`N34gn7Ng^3MgMkH
00?Mg]`00mgLf]gNg=gNg005gMkL00?Mg=SMg]cMg]`01MgNg1koool01nKDe^K@e>KDe^KCeNKCe>KC
eNKEeP02i]CF00?VeMKVe=KVe=H01NKDeP03i]CEi]CFi]CF00;Ve=H0=^KDe>KDeNGCeN?6bNWSiZB3
PX1AA^BfXOW@`N[0/>NiZ^JgXnJhZnJi[NJj[NNhX>JfX>JhX>22Q^[A_Nc:^nR4/>RYWnJLU/62R=j@
R==`J<I2@LiJC<aLD<11@<iODleEA]90@N1[HmMjLLP<LLZ@N/V?M<F2L<b?N/f<Mlj9LM2@Nl^;M<b3
L<B;M/B7Kl:50>G3`NSLgn;Df>SGenOFe`?Ve=D00nKDe^KBe>KDeP04i]CF00?Ve=GVe=KVd=@01nKD
eRSoool002Koool01]gNg=gLf=gNg=gMfmgLf]gMfa7Mg]`0<mkNg=kOgM3Cd;fj]iR?RXN50=RnZ>[=
^l;2/=fn[=g2[]g0/Mg3]=g0[mViX]RbV]RdWMZaX=Vl[=Zo[mRaZ=^]XMVWWLBPP]BLT/j=QLP80<f0
M/UiJl00H<IgKL9^H/9PH<AbIl1lKkX0H;f<N<2ANKj@N/:GO/FEO/JAP/VMQlFIPLBA0[nGPL2EOL60
3=C0]M[Bc=SHd`02gMgL00GNg]cMg]cMg]cMg]cMgM/01mgNg003gMcHgMkLgMkL00GMg]`Noooo00cV
e=KVd=CVe=GVdmGVd]CVdmCVe=GVe=CVe=KVe=GVe=CVe=D7i]CF03WVe=CVe=GVe=GVe=CVe=KWeMK2
`<?;[ZjXPWfU2FSQ]:3`a;GR^:SV]:CV^:KV^:[V^JcV]ZSTY8?QZ9;QZYCT[9ST/:GT]:OT[:3UXi[T
ViKKVI3NTX[HPWgAL6SHM6oCKF?2IU3@KFG;HeS9I5[>Iek9LFK0JV77PVo9Qg36R73;SGC>RgG>SGSB
Tgk>SWS=RG37SGS8RgC2R0CO]JgTb<GP`]7VdmGVe=D01>KDeP03i]?Di]CFi]CF00GVe=H00nK@e>KD
e^KDeP05i]CF:?ooo`009_ooo`05gMkLgMcHgMcKgMgKgMcH00;Mg=X00mgLf=gNg=gLfP09gMkL03_M
g]SMg]cMg]cLg=S0`=c4h<60P80840RAP0B0X83HP:SPa;3IP:3H/j3M`k3M`;3M`;?L_:;BX831PX30
R87@RY2=QH30S8j0P83BX9CCXY?0P8G@WY;?RHC0P872T8[0P072P030Q@2e06FPL6:RHT2QI420@4B`
0V:1P720TWS0UG75TWc0TX39X8S1W8C0U031V8;2T830P838XH31P:30`<;Kf=SKfm[0`=cLg]`00]gN
g003gMcHgMkLgMkL00GMg]`00mgNf=gNg=gNg005gMkL7_ooo`05i]CFi]3Di]3Ei]?Ei]3D00;Vd]@0
1NK@e>KDe^KCe>KDe>KDe@07i]CF03[Ve=CVe=GVe=GTd=CPd=3Re=J0P80R0D^PLfS0P8;P/Z3X^:SP
X83TX9WV^JWV^:SV^:_V/X;0P83AS0GDT@S1P8;@50K@PHC0P03PU8GPTY3HP83LTX_KP8cHP8CLQ83H
27;200310730J6F2H42[@4R]B4bP@430HT;8NVS0R638Rf3>PG30P7WDT83@T7[0P7C8SWS:S7S0Q03@
RHSGYXK0P83S`=3TdMCPd=03i]CF00?Vd=GVe=KVe=H01NKDeP03i]CDi]CFi]CF00GVe=HXoooo000V
oooo0]gNg0;MgM/01]gLf=gLf]gKfMgLf=gNg=gLfPOMg]`0?MgOgMgNg=gLf=gNg=gNfl30fnKWi>ka
kXV>TBPK58Y`H^S0]=o3/=g2[mJ1R]VbVmg5]]g2/mk4/n2lXm2QR/>;L<RCO=21Q:maI[N8NHTA1LbD
R<nOTl4T4<fMTLnl]m76aMKCcMBYUL>ZX;fJSjZ?OXI/DXUBA99GB8H<<[9XE/N1L<2N2;nEKlJ@N/20
P/nWSl^QR<:01/JJQ<BJQ<FKQ<2DNlFMQL2@V=gKg=cLg>3Vh=oQg@08gMkL00?MgmgMg]cMg]`01mgN
g1koool03>KDeNKDe^KCe>KCeNK@d^KBe>KAd^K@e>KDe^KBdnKDe>KDe@GVe=H00nKEe^KDe^KDe002
i]CE03SPd=3/g]o`jNZ0QH0U5Q6GHeKR`JKX^JSV^:S7Yh;RZ9?V^joV^:SV^j_X/Y_0R83;PFO@RG?N
Q8FoHUc3OFo20VCKQh7NTHgD203LSh[I/ZoJa8gIc<COWHk<X93;SHNiPgBPHD2?BSjHCSj402RlG4[@
MfS0Tfk8RfK?QW71Q03HWHODUh34Q7C?T7_=Sg_0T7S7Rg;=Tgg2Ri3TdMOUd]K/g=[XemH8i]CF00?V
eMKVe=KVe=H01nKDeRSoool002Koool2gMkL0]gMf`08gMcHgMcJgMcJgMcHgMkLgMcJgMcHgMgK1mgN
g00kgMcHgMgKgMkKg=cHfMWGemOER2DXFd]3XhUih<:`g/:]gL6]f;64fK:LgLBdgL:cgL:`fk:K`HR2
a8ed`X]fQ802]7IX_XenR8X:dJ:EdZ>FbX24cj6DdkVbdL62e<2gdZ6?b:J0a9jC]I60X81`WV]KW6ED
TeQ:ZFaK]7ET^X=]_91_a91j`X22dJRAcZF=b822aYZ4a9V4aIR0`YR0aYj8`8>8d/k@e]?Df=SJg=gK
01;Mg]`Noooo00cVe=KVe=CVdmGVdmGVd=CVd]CVd]?Vd=CVe=KVd]?Vd=CVdmD5i]CF017Ve=GVe=KT
d=CVdmGVe=GUd];Scm3Rc<jD4R1T@3RaO6kXP:[W^:GU]jGPXICRZ9?V^Zd00^JhZ00Zi:RCe989cH=[
cGm]d01[`fMObX9eb@T1giF>giJ?fH0Ng9F<gJnZ`860g;N_g9F7dH2@dI:;`hAg]75PZF1DYE];R4`2
]EiB_VYKaGITaHEVcHEa`XP0fYj9ei^5d900cY1kcHmkcX1jbXigciAoc861fl?:g/W>i=3@iM?E2>KD
eP03i]CEi]CFi]CF00OVe=HXoooo000Voooo00KMg]cMg=SMgM_MgM_Mg=SMgM/2gMcH00CMg]cMg=[M
g=SMgM/5gMkL03gMg=[Mg]cLf=SMgM_MgMS0`<35a<>3P:l010204028U8g0`:3L`:[L_Z;H/8;H/9SM
`[?M`;3MP:cCX830PP30RWFd1620042`L674T870RHC@Z:3DX9W@Y83@XI3@^:k@P83@XX3=Th;0X830
X9N8TX64P82^P0FPL4J00421Kd20B4V1@42aR6o0PGS4P83@ZI7@Z930P8;4VXC4V8C4T834VX36VX34
P828PX7=`/S4`<3Hd]P02=gNg003gMcJgMkLgMkL00OMg]`Noooo00KVe=KVd=CVdmGVdmGVd=CVdm@2
i]3D00CVe=KVd]CVd=CVdm@5i]CF03kVd]CVe=KTd=3VdmCPdMCP`<?@P832XJ00@0B@0ES1P8;P^:3V
]Z;T]8;PZ9;QX93V^:_V^:ST]:C0UH30Q639P6c2ITR0@030HT31QGSHP8CQXH7PV9;0P83MVX3P[:O0
X83MPi3HR`?HPH3DP8O4PP70P@6806FUI5FP@42PFU68DT2P@03006C:QG34R03JPHSHQ8W@T03>P7_=
Sg[=P77<T7[0T036Q830XkC@P<7DP<7Q`=3Ve=@7i]CF00?Vd]CVe=KVe=H01nKDeRSoool002Koool0
3=gNg=gLf=gMfmgMfmgNg=gMfmgOgMgMf=gNg=gLf]gLf=gLfPGMg]`0?]gKfMgNg=WJf=gLf^;Rg^;P
dL?3aj:MX34U2=6eZNW>]]g0X=o0ZM^mY=BVP=N_VMk1/]c4]=fmZ/jDPKV0H[n6LZINCPD05;=UD/Z<
OM6HPmc6^=JYVM[8_]>/VMfk[]B3Vm2IQlZ@P]RTXMViZm>MT=21VM:fXZj7L80=08E^HWE:>Q`@0;J6
L/:FPL::Q=R]V=NdWm2XQ/JJQ<BJQ<2B1<BKQLFHPX:<PK:X/Lk4b/BlR=GDfMkOg@OMg]`00mgKfMgN
g=gNg007gMkL7_ooo`0<i]GFi]3Bi]?Ei]?Ei]CFi]?Ei]GFi]7Di]CFi];Ci]3Di];D1NKDeP0ni]7B
i]CFi=3@i];Cj]WHh/3:d;Rm]i2B<P@0gJZQklJ`i[RPikJQi;>Lh:B@h:FAi[N[i[R/iK>RehYh`GQ0
b7aX/e54420:^Ua8dX5e`I:1i;f`h9nAi8B`g::@ik2Wh9R@fheneHEji:2:hjjSh929f9bBg:bI^WYW
T180VeMKOD0aP@8F_gaXbHegbX01h:>@gjZGf826ci1kcI1kc81`cI1lcXiia80H_9jXd[c5cK21g/[C
imGG1nKDeP03i]7Bi]CFi]CF00OVe=HXoooo000Voooo00cMg]cMg=SMgM_MgM_Mg]cMgM_Mg]cMgM_M
g]cMgM[Mg=SMgM/5gMkL03kMg=[Mg]cLf]SMgM_JfMRAQY2YY:>BQhI04@3>/ZCRak3M`JcL_ZOK^jCH
/X7G/IcM`K3M`;3K^jO>V8BmP6c5T7bgOVf8C4joPW3?VhcDXHCK`[CG/:3Ha;SF[ikL^:_DZ93AWXc=
UXKFZH3C[Ig@V8[<TX;9XhncQ6nB4@2ELVB8ETF04`2_O6NiQW?2Q0[F[ISF/Ic2XhC6VXC4VH?2TP34
V8?6V8:6RXBbZ:bi[[30P8_Dd]KLgMX7gMkL00?Mg=[Mg]cMg]`01mgNg1koool03>KDeNK@e>KCeNKC
eNKDe^KCeNKEe^KCeNKDe^KCe>K@e>KCe0GVe=H0?^KBdnKDe^C@d^KCe>??d/R0P;fFUJQhMT@00=VV
W>ZnZNJgY>FdWnBaW>2XT>2WTnJgZ>J`Z^BaWmN>Nl1lH<n5L/Q^IJa9A<aeImV@Q>2@T>Bi[>6UV>Bh
/=nUU^J]Xn2BP]bCQ=N;O^60T=nQUMb<Pm23Q=FHQkigIZ@:F:MOG95;?8<89;Y`GL=kJLB80=nST=nW
TmR0Q<n@Nlf?N/^8L<f>N/j>NLR05;fMXl>TZ<:`P=g8cnGCe0OVe=H00nKBdnKDe^KDeP07i]CF:?oo
o`009_ooo`09gMgKgMcHgMkHgMkHgMkLgMkHgMkLgMSHgMkL00?Mg=P5gMkL03kMg=SMg]cLg=SN`=W4
`L<8000@0043D4P@0134/:3N`jcMP:SH^:;K/:3H]J3F]9kL`:SL^jSH/J3>VhK0R73:P8G4T8BAP032
TX7@X8SC/:;KP;3H]:KH`;3H/Z3L/Z3@X83@XH71VhW@P83<PH3>TH71P023P02fP6jT0F2RL6F0AD82
A02PHU:RJ4J0P0;E[9SD[YW2X836VXC4V8:0T034U076T8;0P82`XXJ4P832P8CA`<;Jf=07gMkL00?M
g=SMg]cMg]`01mgNg1koool03>KCe>K@e>KDeNKDeNKDe^KDeNKDe^K@d>KDe^K@eNK@e>K@e@GVe=H0
?nK@e>KDe^C@e>3DeMB7b0D4081@@A1470000MRRV>JhYNJ`X>2RV^B/V>:XV<2XU^FfX>B`X>6]V=2A
OLX0H=250/287<0Q4<24P<B9P>2QP^BdZ>2SQnB`Z>6XP>JXP<B0P=bCPMV4PMZ8P=>62=R0NM200<P9
J<1dI800@;1TGZ5@@H009:12@;59CL20H=bPPMjTT=B0P/n@N<f>N<R8L<b8L<n<NLb@1KRHUZ8:1<B0
Q=S0a>30`^KDe006i]CF00?Vd=CVe=KVe=H01nKDeRSoool002Koool00mgLf]gNg=gNg004gMkL00?M
f=CMg]cMg]`01mgNg00ngMoMgMkLg=kLh^GQa<3=8208?b`S?b@G@101fk^Yg/B/gK>Te;JOfk6Qf;2P
e;FOfkjUfKFRe[BMc9^4`8ETejjNj=c:h^3@i=;2hLJhg8V/g;f^g<Jgf86PgKZ^g:nPd:>@e:ZDe:FA
`X@@b8ehcXama81`^WQUaWi`b0QS_7aX[VYI004`U5A1VU52PXAaeK2MejfHbJN8aYb6aIR2_I1iaI5l
aiJ1`9V4[IjGPg9Z`I6AcLG7em?A1mgNg003gMoMgMkLgMkL00OMg]`Noooo00?Vd]?Ve=CVe=H00nKD
eP04i]CEi/C@i]CFi]GF1nKDeP0oi]GFi]CFi]CFj]_KcKK5<1`A@B@K>ahDA@PHi;6QikZTiZ2LgJbG
i:NIh:bHgJ^Gi;BMi:V0gZZEeI5kb@=SgjFEimW1j>;8jLZkjKbai82UiK>WiKb`i;:QiZnViZBH`9V8
g9n<gIZ9eH00dX9_f89dc7AP`ViKd7=Wd7APa7=N^eeAQR0VWDTgY4Hg``QTgZJDgj>@`XF2ci9mcXii
`8Y`cXMcd8ah`HAi^9>>SfMO`XV8e[_0h<W;i]CD00KVe=H00nKEe^KDe^KDeP07i]CF:?ooo`009_oo
o`03gMgJgMkLgMkL00CMg]`00mgJf=gNg=gNg00:gMkL03_Lg=[8_l<:0TadGE5bEDMP@07J_:SM`J[M
^J3G^JCL]jKJ^Z7G^JGL`J[L^Z?G]J3?X8_6T7SBYI;Ma;3S`H3Pbk_OaKKLR;3L_k3L`kCH`:7L_:kL
/j;BXI3BYY3BXXk0Q0g8TWc;T7g0PgBjP6c1PG31P66iP6^`Lf22ED2PIU2TI564P7;BZiCDZiG5X876
VH?3UX2mTWS4Tgc5UX74VXB]WYM_HefAQH3Cc/oJf=H04MgNg1koool00nKCe>KDe>KDeP03i]CF00?V
e=GVd=;Ve=H02>KDeP0ni]GFi]CFi]CDiM;CdKFl4dDbP554O4TkP0`[hk:Qi[NRiZ>0h:nLiJfNhj60
h:nMi;NRi:63h:^Hf9J2`8EPfi^:hkbWhLF`j<6dik^_i;BPiKBXiKV]i;BQiK:ViJVK`h60fib7fiR6
dhT5dXQde8Edb01X`gERbWMWb01R`WMQ_6IHP400ZeY7/5Q8a@]Pfj2<gJ6=eX20cXmjc8ag`8Q`c8Uc
cXahcY1j]i>>O5MAVH:0g<C8hlk?1nKDeP03i]GFi]CFi]CF00OVe=HXoooo000Voooo00?MgM_Mg]cM
g]`01=gNg003gMcHgMkLgMkL00WMg]`03=cLf=34`lbjZX2418V448@V180T0=ZmZ=ZjX=f0Z=VlZ=b0
Z`;HP:002]c0X=b0X=RgXM2QT/200<bFP<BPRM20P=k6]]k0/0;L`;008mb1/=c0X=b0X=bbYM6VT<23
R<21RL20P<R@P<BAO820L;Z0L;R0L;R0H;R0HK84IX00@:81AJ@0AXB4M<ZPQ=2PTL20P<FB086@O;j@
N<2DN<2GP<2HQ:bMUT1048R0P<30e=_0f=cNg00@gMkL7_ooo`03i]?Ei]CDi]CF00CVe=H00nK@e>KD
e^KDeP08i]CF03gVe=CTd=C1`/SD/:20002480V3406:00CS/J7P/83V/:3P/:3T/Z3T/:3P/Z3U^:;T
/:3R[IWJVhW@P03@Q07FQX30X83W_:3V^Z3V^:3T]ZST]:[T/:3T]:7U[9c0Q83HTH3HU83@P03@RW31
R730P630Nf?2NVO0063206B0L4BP@42eH5BhH5G0P6C@U03HW8S@T03>R738PW70P639R7;9S7O8T7Rd
TXi80020103P`lSPdM004NKDeRSoool002KooolBgMkL03kMg]_Lh<;;`l[>]Z;GX83nglGkf<?0T:[K
`JWH]jCMP:[M`JoNaKGN`[;Oa;GMa[GMa;7K]jKH[Ik6S837S7C5Rg7@ZH7Ob;[Mc;cM`KSN`[?N_[3L
Qj3M`k;K_JK@X93<VX;>WHW:PX37W8?0VG^1TG:jSgVfSG:gRG2jT7FlU7S0TgZmT7>kSg24PW35VGW=
Y8k9P8K4SgZlSWVnP7:nV7[0Ugn4U82]WiTR9bIA@E7^lNgUjNOM`=`@gMkL7_ooo`03i]CEi]CFi]CF
00CVe=H00nKEe^KDe^KDeP07i]CF0^KDe@0mi=KHe;S3ej^JhXb4omW2o=?0d82Ri;NQh:fLi[BRi[NW
i[^]ikR/ikZ^i[b]i[RZi:fNh:>FeX<?ch9[cH5X`8n8j;jci/:ei[fai[R[i[BYi;FPi[VZi;>NfHB2
eI1iei>0e903d99jbHmaR8=Q`hE__h9X`85X`XI[`h]]aXQ^a8MY`HMVaH1RcXi`eYZ6d99lcHEaaHA`
ahAQahiabHefaH1h]IFA;1`JDdA6lnWXkN3Qh=C@00KVe=H00nKDeNKDe^KDeP07i]CF:?ooo`009_oo
oa?Mg]`09]cHd]74`m>kZ<28YN[7[nO4[/B0ZMc1Z]ZhYMf1Z=g2/Mg5]Mk4]Mk6^=g7]mg5/MbkZMVa
X=2SR<bFOlVDNm2PR]c1/Mg7^=g0/Mg2/]fn/=c0XMg4/mbnZM>PP<nORLjOR/R0Q<JJP/2FNh22LKV<
MP:fRW005K^>L[b?M/24MkjAM[jAML6@0<VNPLbRS<RKQLFAO;j@Nkj@N;nGO<2GOl2HP:VFSC8`;B@V
8=WJem[KfMcLf00@gMkL7_ooo`03i]CEi]CDi]CF00CVe=H00nKDe>KDe^KDeP09i]CF02[T`/CJ^[gK
/J7@P8c`_jW]^jS8[Z3T]j;R[YgV]J3V^:WV_:kW^:kW_;7V_JoV^JcT/J;QYiSJPH7ES7KBRW;IPX7U
]j[V_K7V_;3V^:[V]:WT/Z7V^ZcT]:;0X8CHUH3GUH;@TP;?T7W9S7:9P632PVfoP6J00F33Q6S4QV`2
aXQ/0176R6_0R73BTgSEV8?@TGc=Qg?7QW;7QV;8SG?9SGK8P7ZbS8Dk9R9000;Scm3Sd=;Td=@01^KD
eP03i]CEi]CFi]CF00OVe=HXoooo000Voooo00?Mg]cMg=SMg]`01=gNg003gMcHgMkLgMkL00SMg]`0
?]g0`=c0P=C4]=B6X=20P=>QT]6PTm2`X=c1Z]VhY]g0X=g1/]g0/=c0/=g8P=g8^=g0/=b2XMZ`Xm2P
T=26R<bJP<20P=2dX]c0/=g4/=g1/=f0/=c0X=g0/=c0X=2PP=6SQ<jQS<20P<B@PKnAO;R0L;60L;B0
K[20H;^<H;b8MH20L<2CNL:@0L20PLVQQ<V0P/2IP<FDO/2@OKj@N;nDO<2FO86@PHF60`0`<00008J4
Q<32`M7@d13Mg]`Noooo00?Ve=GVd=CVe=H01>KDeP03i]3Di]CFi]CF00KVe=H0@>KDe>KDe^KEd>C0
P<Bi/<BdX<2PR<B<P/2PPl2RP>BgX^B^WnJfX>JiZ^JlXNJlX>J2/>J0/>JlX>B`X>2PVl24P]R@1mF@
NM2@0/:QP>BaZ>JhX>JgZNJeZ>B`X>JjX>F`X<2PP=RIPMNAPM200<b<N<R8L/00J<1lJ;ilI81lI<B2
H/@2J<24K<R9I<2;L<220=BC0]2B0<20N<j9M<R8M<20L<R8M<V<M<R1N:T4JTP/80080/6XZm:4P<;0
`Q3Ve=HXoooo000Voooo00?Mg]cMg=SMg]`01=gNg003gMcHgMkLgMkL00KMg]`0@=gNf=gOgMgViMc2
Q^C<]>GC_l:BP/VJPlNLQ=:`Y=k2ZmngYmg2X=g7^Mg9^]g:_=g@aMg;_]g:_=k7]]foZmRdX=N^V=2R
R<R1N=6]Umbk[Mg2/=k2/=k1/Mc0/]g<_=g8^<24X]N]W<nXTL20Q<BGPKjBO[R4LKJ3L;F4KK:4K;^;
J;f5Lh29LlFKPLbNR=2RQ=2YT/NHPl2@P/FGPL>FP;j@O;nDP;nGO82D1YIkJ3/b:Q802JBQY[^c/]7<
c13Mg]`Noooo00?Ve=KVd=;Ve=H01>KDeP03i]3Ai]CFi]CF00KVe=H0@>KDe>KEe^GLgnF@Qn[4Zn[<
]/23>=:@N/nBNl>XW>JhY>N]WnJhX>Jm/^Jo/nK0]>K6_^K1]nK0]>Jm[nFeY>6RV>2USmVHP=26HMZS
SnFaY^JhXNNhZNNgZ^FhZ>K2]>Jn/LVXR]nSTmRNRL680/f=N<N8M<40J;mhI[ijHkYhHLB1GlIkJ/44
J/nAN=FCOmR0P]VOR]2>N/:<N<j<N<b<MlN0L/R:MlR<Ll22M9maGd@W8B808kFEV/RWZ<;0a13Ve=HX
oooo000Voooo00?Mg]cMg=SMg]`01=gNg003gMcHgMkLgMkL00SMg]`0?]gJf=b@QmfkYM^kZ<RHP<^N
R<ZVSmRfY]g2ZmjkZMg2X=g7^=g9^]g:_=g>`]g;_Mg9^]k4]=g0[=RbX=R]V]6VS/fHQMB`Vmbm[]g4
]=c0[Mbn[]g2/Mg7]mc2/]B`R=:XUL^QRl6EPL6DO[fANkZ8L[R5LKB4K;64J[f=Kl2<NL6@NlRNQ/jQ
Rl2QP/nWTLNKQL:HPLFGPL>FP82@OL2DOl2FOH>GPJ:1KF1<?e12@:2IV;bg]M3>c13Mg]`Noooo00?V
e=KVd=CVe=H01>KDeP03i]3Di]CFi]CF00OVe=H0?nKDeNK@d^B2P>JaWNF`X<6A8MBDOm>LQ^2/W^Jh
XnNaXNJhX>Jm/NJo/nK0]NK4^nK1]^Jo/^Jj[NFfY>2PV>6STMZKQM2@O=fVTnFcY^Jj[NFfY^FdY^Bh
ZNJm[nFhZ/BTP=^NS=BGP/b30<V:MLJ7L/00J<5kIkejHX1hHLJ3ILV2Klb3L]6DOMNGP]RKPMRMR=2A
O<>0N<j=N<b;Ml68LlR9M/V<M<R50:]gI6Y0=@0F2Zn=S<V[ZlC4aP0@i]CF:?ooo`009_ooo`03gMkL
gMcHgMkL00CMg]`00mgLf=gNg=gNg006gMkL02OM`<3Mg=SM`L3@P83@S832P832P038X8c<Y9SH^:3M
`Z_LP:WM`:3MakSMbK[Mb[cMb83Lb[cL`;SL`;?M`:cH/Z3H[83AZ97@X83@/X3L_ZkMa;7J_:SJ^:?H
`:3LPj?J^:C@X83<X8_0TX20P02jPGRjP7400[R8L00G/H1YX81PPHm``982`H20bZ6:d:22`:20cjJ@
b821`YR0aI22`9F0PYAl`99l`9An`820Y89`PF10P610Rh09^;Vgd<3<013Mg]`Noooo00?Ve=KVd=CV
e=H01>KDeP03i]3Di]CFi]CF00KVe=H0@>KDd^K@e>N4P>20P<>0P=J02<:00=BFP=FPT>2PX>JhXnJd
Y>J`X>Jm/NJo/^K0]>K0^>K0]>Jl/NJ`ZnB`YN2PP>2PT=b4P=R0P<6XT>FdY^JjZ>2`X>2RX>B`X>Ba
Xn2RQ<2PP=2BP/20ML20L<>2H<24H<00J<9mJ;Qh@H1`@<R4JlV5L=200=BCP=RJP=6HP=RLQm6D0<20
N<j<N<b;L<28M<R0L<Z:MLR20;D0J8YA@X10@8T4K/:^[L34`13Ve=HXoooo000Voooo4=gNg010g<C4
g^?Tg[bedY>8d8ae`gQX_0QRbIn<c;bXgH2XgL:ZgLB^gL2SgLRigLZkgLV1gL^ngl^ng/Nig/2cg/Jb
f82ZgjjVekBPd;23f[>Qg<2]gL2`f;VSf;BRf8:Zg;ZZfK:Pd:Z@b9b5`Xmj^Xah]XYd^8ae^8Q`_8]a
[X1UZ018`XilaYf7`ZRBdjZEejjIa::AcjJ@b:>:b820aYZ4aYF1QY00`91k`i=oaJ20`hmed9]jPX1T
OG1S][Zhd<c<4=gNg1koool00nKDeNKDe>KDeP04i]CF00?Ve=CVe=KVe=H01NKDeP11i]CEi=3EiM[N
ik:^a820fX5]c6eOaG98dYF4eK:Qh;BPi[RRi[^Vi[2Xi[jai/2ci/6bi/6gil6gh;fbikJ/ikbZhK2R
j:BNh:ZH`:2ChjRIiKJUi[RXhJnKhJZJh[2RiK2ShZRH`:21dI9mbhEa`X9P_gm[`H9[`@APa81W]gEL
PG11bhAcci9nf82:fj2<h:B@eX28f9b8dIR2d900chmkcX]hb8YfbHIac8UfcYJ1c8E[f99`U0A8QVEI
a:n]`/36013Ve=HXoooo000Voooo4=gNg00?g=C8f<2:g;RP`924b8agP7e[P802`:6@d;RVg82XgL:/
gLB`gL2`gLJ`gL2a00;M`;00;mW4/=S0Y=bjZmR0ZMRaX=RPX=N`W=J`P=ZbY=g0X=g0/=ZmXmZiZ=R0
X=blZ=ZdX=2PR<2HQ<6@N;6:L[N8L;J8MK28L;b<M;20H821H<2@P<R1R=2RT=2YT=6XUL2PP<bQS/VP
R<2HP<B@P/2@082@OX2@O<2CO<20Q;Z8LL21LH28I800HX2h/]CBd00@gMkL7_ooo`03i]CFi]CDi]CF
00CVe=H00nKDe>KDe^KDeP06i]CF00_V`<;TR8?V/:30R13BPVk1L6;0063@VXWH/YoT]:3V^:@00^Jh
Z0;V_;00<NJ0X>JlX^BhX>BbY>B`Xn6bXN6QP>2TV>2PU<2TT>>PW>BfX>JhZ>2`X>2SX>B`X>F`X>:X
V=R0P=2@N<R6L/20H<1oJX20Jh40J<F0J800H802@<20N=6DP=R0R=RORmbPS=2HP=JHQ=2FP<20NLb<
N<b8M/R8M<R6L/R9M<V@3<<2J<V0J<04HHUWH<Z/Z<30`P0@i]CF:?ooo`009_oooa3Mg]`0@=c0`=Zg
Z>6lZ/bEP<R<N;Z1JXB41]>^V]NmY]c0[]g2/=g7^=g4/=k6]mk6]]k5/=k4/MW0[MRnZ=biYmVhYMR`
X]RbW]RaW=JcX=^oZmg2/]c0/Mg2[mg0/Mg0/]boZm^gYLFPP/NJPknANkF8L;J9L[F;M;29M[f@NKb?
Ml2@1/bQSLfTT=:XT/nZU=:[U/2SP<fRSLZPRLBBP<>GPL:BOX2@O[n@OKnCO<:5PkV9LL6:Ll2B0;F7
M/Rk]=cNg13Mg]`Noooo00?Ve=KVe=CVe=H01>KDeP03i]CDi]CFi]CF00CVe=H03nKDeNKDe^K0`>B]
XNRbXlB96=62Kl=fH8d@I=bTTN2cWnBfY^JhZNJm/NJhX002ikb_037V^jcV^ZWR]ZGR]:;U[ioR[IgP
ZY[PZ9KQYYC0ZIST]:?V]j[V^:SU^:OU]ZWV/:[U]JCS[IgHPX7?T7[8Qg:l166oOVRnP6^jP6c6QW35
QFg0P7GEUhCFVXOHPX[HX8cKXHgHVH3EUhCCUX3>SGS<SGO;R7G8P7C7QWC8RG?0R@[3OVS;P6[8P72n
OFgD/:cTe=004>KDeRSoool002Koool?gMkL047MgmgN`L7MZYGZ`Z_3V8C=Sg^kQFZ6PPcF/YkL_ZKL
`;3M`[?Nb[kL`KSPakOOaKK0`k3N`ZcG_:KB^Z?L]j;G/j7H/J7E]IcJ/IcA/:3Ma;7N`kGL`;3OaKCO
aKKL`KGL`:_L^ZO5R8K6VX:nTW^aR7>fR72dRWBRS7RnTgc2UGg8X8?AZYGAZIGEZY3?ZiKB[IO0XX_<
X8c<WhW5U@;3UWo1T7fnP7jnT7jmTg[0PX2jRG;4RgK0X83:SgcA`K[4c<`04=gNg1koool00nKEe^KD
e^KDeP0:i]CF04?Ve=CVe=GVeMKTb:;TXHg^^ZK:PbGEQW;4Nf2?60COZ9KU]9kT/:SV^:cV`;KV_K7X
_K3W^jkP^:WW^:CP/Yk3/9_T[9[PZIWQYYWNZiCSYiCP[IWV^ZWW^JgV^:SW^jcW^joV/JgU]Z?T/9oH
P0c?T7W7Qg:h166oOFNmP6^dPV37R7?:RW?ATX;JX8gJWhcLX83HXHgKXhoHUH;EUX?DUH3=RG3;S7K:
QWC0Q7C7QWG6RG71R1;3OVW>P6g;P`WDQG;K]k?Pa<004>KDeRSoool002Koool00mgLf=gNg=gNg00<
gMkL047Lg=S@R832U82@P1:00P2BKTZ4Hd68907H/:3LP:SI`:kM`[;Ma;3L`;;H`;3HPZ3HP:SHP:[F
^JC@/:C@/J3E/83@XX;AXISBZY7DX83BP:CIPJ7L`:3N`k3N`[3L`[3M`:[H]J30R8C0TW^lSGR`Q72d
R76dR7:`S72mTWc0UGg0P83:XH7:XX30X83<X93<X8?8X8S;WHS1WX30T830UH30T7jnT7blT7fnTWf0
PX2R06Bc0f20P0B4PW30X8;DU9004=gNg1koool00nK@eNKDe^KDeP0<i]CF01GVd=C0Q8C4P0;3Q020
10RSI46<HDN0003P[9SU]:3T/:3V^:[T^:3T^:SP/ZSQ/:;P/:3Q/Z;0XIc0X9cPZ9P00/2PT007fJ>@
fj20g:2@`[:4hKJQi;2Ri[VX00;V^:P08NBfXn6YV=203LV8L/B1L;`0H;inJ;anJ820H<J8L/V;M<22
0=BCP=:HPM20P=JLP]2IP]B@P=2AP=2@OlR<N<Z;L<R8M<26L<J6M<J8M<200;1`@8A`@<00H<T0J=64
P^20PP0@i]CF:?ooo`009_ooo`03gMgKgMkLgMkL00[Mg]`0@mgLf=kOgMkNgLR0QK>5L:MjI91QAX=P
DH5PDX0P5=^nZ=g1[mV2X=g2/]c2/=c1X=No[]RlZm2mZ]c0[MRjYmRjXMReXmZcX=BSP]N^Vm6YU=BR
P=NmYm_2[Mc2Y=g2[]g2/Mg1X]g0Z]NbX<28Q<2>N;Z;NK22H[J9LkB9L[6<L[fBNl2FPLBHQ<VORlRR
S<RRRlfTS/VNRlR0R<ZKQ/FLQ/2IPL2DPL2FP;nANKbAO;jAPKVMS:=eH:adFK42I;j5Kl6ANLf8W00@
gMkL7_ooo`03i]?Di]CFi]CF00WVe=H0A>KDeNK@e>KFenKDe/6@9;ejI[=_F8Q<B8aEAXYFB94P1>Bd
X>JgYnB`X>JhZ^FhZ>BaX]neY^:bXn2bX^FfYN:`Wn2QPN:ZV^>ZUlBRTmjUU=ZORmbQT=jeWn:iYNFh
Y>JhY^JhZ^JgXnJfX^2XV=:@3<V3Kl>0L840HKmoJKeoJHB2H<J8L/V<N<b0NM:EPm6HQ=:HP]JJQM:D
P]:DP=>AOLjBOLR?N<V:N<R;MlR1L<F7LlN7N<2BPZe[EKEYD81`A<UjI/^6L<:DUA3Ve=HXoooo000V
oooo00?Mg=[Mg]cMg]`02MgNg014gMgKg=cJh>;Pg^;R`H@8XG5KTf5:2456JDm2K5A9Q2THgL>/g/>d
f8:Pg/>cfkj[fH2Ydkb[ekZXdKfPi<Neg[n/hX:RgkZYi[bVcX2=hKFSdZVDeJb0f/>[gLN`g<>VgL6/
gL6`gL6RgL2YeJnM`8R4_HQd^HQj]H1P]h]f]h]d^Xed_95k`9R3`Y22b9j:aZ:;`j28cZ:<aiR6`9f1
bIR2`YZ5`9V5_iB2_iR2`95h_99l_i23/864VfaGY6]?ZGA1_XM__7mPb91L4=gNg1koool01>KBdnKD
e^KDeNKDe@SVe=H0A>KCeNC@dNOHfnKHg<0Z0:QWDYYJ?X5@0G95=gI:?hD33^JjY>Ni[>:`X^JiZn>d
Xn:dXMbbXn2`X<B`X>Zn[^NdY>R`Y>R`XNncW>2WPNF]W]^ORl6RSmflXn;0Z>FhZ>JgY>JgZ>JgX>Jf
XMjUU=2?2lInJl9nLHAkH/21K;n1J/:3H<F7LLV=N/R<N=2DPLnHPm2DP=JHPm2>OL6C0=:>NL^@O<R1
O<R9NLR>NLV3LLF8LlR6NXB73:=RCJeQAK9XDLQkI/5fE/24EA3Ve=HXoooo000Voooo00?MgM[Mg]cM
g]`02MgNg014g]oL`<30e=C@g<C0`HH0X`AP1550@400@D4jH411D20AgL:/g<2Pf82Xg<2Pg<2/f86Z
dkZPd;:2`::0P8B1RX^9P8@@QH20PHH<P000P804Q960R808RX0B`:B=dH2PgL:^gL:`gL:PgL6Xe;2N
`8R2_8Qb/81bX81XX85YX0AUY81a_I40`IV3P9@0`9>2`9R2`9R0`Ib0`9R4`9b5b9V0a9b0Q9R0_9B0
^IAm^91h^I5h_920^922VG1JVF9@X61@/711^P1Pa9:04=gNg1koool00nKCe>KDe^KDeP09i]CF01_V
eMKPd=3Q`/;V`8S@P02dLTJ0A31R021P>29P@C80007V^:CT/:3P]:3T]Z3U]ZCT]J;L/83JZ9;0P82D
P135P120P02@PPR840:000240F000/20000W`HH0e8R4h:20i[RPi[RZi[RXi[NPgZ2Fd8`8aX1X`7aX
^7Q0/W95/712P01P`8UdbXmjb8Q`c85db85h`800`Y40b8il`91ld95mc91nb81haXY`a8Qd`81``XIb
aX1h`800XV1@X5e6X410PVA@`gAI`81@013Ve=HXoooo000Voooo3=gNg014h^?Qj>SSfm[Fg/Fc`80:
^HajH48f0b8PBSXcETDk@Q4<g/:_fl2/f;bPg<2[glB`g8:Xd[NQcJbG/Y08U7ETYHIeQ0T0U7Y/NVQU
0TA1QV=@Z8MfY09B[GUT_I1hd:b8gL:agL:cgL2dg/:^e[>O`820_Ha`]XI^[81RZ7aSXgMQZ8H1`IN1
aYf6`9D6aYV2`IN1`IZ6aI^6a9^7`J20bZ:=b::<QYR0_IF0^I9k/Y9h^91k_9>1_9R3VWIRU6A?V5i8
[61;^7YP`Y1L4=gNg1koool00nKDeNKDe^KDeP08i]CF04GVe=GYf]cXhN;Ud/kV_:c@4P72PW1/=2Y0
305D;bMO>S1D2@CV^:OT]ZCR/83U]Z?W^ZSU/:;K[IWGXXj8P72PJEV_NfZ@052NL6:6GE/370VCEd>a
O6f`Id2kK5_:Q6o0X83V^:WV^:_V^:cV^:KOZIO:S0;6PVJnO6BdL46aLEV_JeR426S9SGS?Tgg0P7CA
SgK:SGO<TGk>TGc=TGk@U`3CV8GAV8C6Q035RgO2R7:2Qg;1QW;5RGS6P7ZSK5RMFTFVD`2eET31L5K4
Q5@04>KDeRSoool002Koool01=gOgMgNg=gOgMgOg@OMg]`0AMcMfnW[j__ooNWXhnBoY/0P4L:FQDH_
:0040C/_:d/n=E@@2=k4/]^oZ]RjX]g0ZN;8]=g0ZLncVlNSRi02H6];>hMYF@90:G1LD4Q2B1D44Ehn
;9EhJXQ@8YMG@jegG]2RPMg2/mg1/mg1/=k3/=JdX<644Kf=K;B6JJ20H:9fFia`FjJ80<BIP/nTRl24
4=:PQLRJP/Z0R<VNR<bRS<2WR]6ZU/jYThV2Q;bGPKN@NK:@N;N?Nk^EPL:IP9amJ91RCi1A0:9;=[Ed
Fl6>G00@gMkL7_ooo`04i]GGi]CFi]GFi]GF1nKDeP15iM?EkN;UlOckj^OLikVOa084bXalDB<L4@@0
A2@OE3@ZAP@EikZ[hkFRh;2JiKJQj[j]i;2Rf:VCdIR3X010Kd8cSf1@5BPPNE96E3Tk0@`<I3DRWfiQ
QD0@X4dh^6]D`921i[R/i[N[i[VPikVXgjZHbXP0aX=S_GaOXWEJZf]AZ6=BP11Yc8iif9^2cX@1giIf
d95id9B0dYEne9R5d9j2f:2>eZ2<`I05aHah_hI`P81a`8Ea`h]hbX5jYG=NVEQ4PTTbYd<X_VUA`8AB
00[Ve=H00nKDeNKDe^KDeP03i]CF:?ooo`009_ooo`04gMcJgMkLgMcHgMcH1mgNg015g/3Lb<S4P820
Pc0X`XV7P1@4]8QdD@4`80P0<2lZ@3TaAQ@0g86Zf[jYf;bPd[RPd[NSfKRPe;RRaJJ1P840P01MX840
4000R01R0TY100001D0>Q7a/P690X018P8E]d:R0gL:`gLBdgL2ag<2/e[B0`820_8eQ]8AYZ01TX71M
W6iAP100^iZ3X800801@P09<PP=>P01PT0aXQ0QPX81R[8X4PI00P900^91h]Y1i/91h]81k^i00X800
P61D0EE30UA1Y65<^05PP010013Mg]`Noooo00CVd=CVe=KVd=GVd=D7i]CF04GPe=K0RX^0P8:020C@
P@c0003016149BHP00029Ai28217003T]J?R]:7P/83PXIWPYH?P/830X9[IY920P0BK0E200V200422
IT0@@4`010PBAP:UL6>P@4B0HDk52F;0X8SV^:SV^:gV_;3T/:GOZYO:S036PV2lNV2`M5R/K56PH420
0530P0:026R304R2F4BEH420042S0F6H0Db02624PFb:PF[1PV32PW2oQ720P7:nQG;4R7J00628@D:2
@024Bc2eAT70L5S0E4004>KDeRSoool002Koool01=gKfMgNg=gLf]gLfPOMg]`0ANCVh/:o^a000Ua:
@[V=N<:30[Z8M69:@C@`;c0]9d0d;EDQ0m^mZ=VnZ=RmX]BbW=2^V]2hY=g1[mk2/=2hX<f]VLZXUH60
3:j?O9ioL81R@9E]FJR0Jj05JL6>M/^OQm6XP=g2[]g8^Mg8P=_0[MJdWl:9PKj<L[>3J:QlH:AhGiUY
Dh0:EKNMTXehK@P`8UQ;A7AFB@1@@8EXFgIPDX1T@9MkIZN2JJR4HKN?MkF?NK2AN;>?NkbBOYP@JGIJ
Bg5B@g1E@kb4Kkn:L:1PGP0@gMkL7_ooo`04i]7Ci]CFi];Di];D1nKDeP16k=cLdK>`R4Q0M3L`bgY^
d0QYaG]ZJclg?2DT>B8KBBTRH0L9i;>PhKBPhK62gJRDfZBBhJ2Li[NWi[RYa:B3f::@e9j<R8@4^8Ab
ZGAXQ4YAX65>/GIR]793cH9/e9An`::8i[RVi[jai/2ai;JUgjZGbh48ah5Y_7QN/71D[VeEY5e9T@10
`i:9VFaS4bXQHD0lOTXn44@JSeeAP5I8U619XG5L/GQOP@9P`8A]_XA`PX5b_8Eba8MeP01DP4m0NTPh
0DXhaWUVb81W`D=@i]CE3nKDeRSoool002Koool01=gIemgNg=gKfMgKf@OMg]`0A^c_jknk]S4502@9
0;>0J/60Q<B<MG1FC3Db<2PZ93T^:EPT1MZjYMNmYm>0Y<n[ULRSS]J`XNK;^^WB`nc@`?CD_^K1[MBP
V<JSSKfEOjF6H:IlIjn3Jh20JM6QQ]F/U=2YP=g2[=g;_=k2`=[0[MJeWl:8Q;j:Lk:1IJQjA:AhH9ES
C8H0@[6QW6eRGP000AhR94dd;D<H1FI?Ade2>6ED@7aVDIIaEZ40B[F;L[F=NK:@N;6?NkfAOY0DH6]>
@FM=@65@A<NKQ/JGOJ9P@=gMf`oMg]`Noooo00CVcm7Ve=KVdM;VdM87i]CF04KdinG=/:/040LK2@77
Jek3P@3BOf]fCD<69R0b7aQ291f140gS/9gP/ioP/XCHX8cBV8GOX9S^`K?_b[g`c;[hcKW]^:KMXX3@
VH?8RWFVO62aLEfhNF:815?IUggLXh_0XXSV^:CV`KGV`83R]ZGNZiO<P`_7OfVkMe^`I52^KEJOEd>8
D3:oUI9jEU80000W6AYB;2A40P9_ACeF>2if@P:5FdNNIdbZK42nPFRnPfn3PG6jQ776QgB42U1dA3Ia
@cA`B03>TWc=SW>[@47UdmD9i]CF00?VeMKVe=KVe=H00nKDeRSoool002Koool01=gJf=gNg=gLf]gL
fPOMg]`0A/[1b1`@2T0003430110AP12A11@@483030P8B`Y9P0a:E0P0=^jYMRnX=RlX]B`P<6PU=2R
P<V`X=20X<R0P<b^R<2QU820P::10J20I800H81b@Z9jI:04H<:HP<:XT]6XP=g2X=g1/Mc0/=RhXMJa
W<28P;j2N;>0JZQlH:EiGh1PDX00D;FDP800HP0004PG269:@01020A8D6A1A81P@8abB:42HJ20H;J=
L;F0N;2BO;2@Nk20N000@45205A0>4800820M;04C:1P@=kOg0OMg]`00mgNf=gNg=gLf005gMkL7_oo
o`05i]3Bi]CDi];Ai];Ai]CD00KVe=H0A/2<`I00FD00004D18122X10@813@T4`900T830P6T0P8808
2>B`WN:dP>2`P<2XT=B5Q=RPT<2QP<BPR<2PP<FTQ<b2P/200820I[9fH:1Q@:=XE:=SFX00@=20N=R0
R/2PP>JhXNJm/>B0X>2`PMnQTLZ00<20H[ahH;1`D:i^EJ9P@840@<201H1QH000050400E01010081B
@0182H10@HIPE:1`@802@X21K;j4L828L;b6LX24L@19@600=THj8T008<20HhIX@<10B>KEePOVe=H0
0nKDe>KDe^K@e@05i]CF:?ooo`009_ooo`03gMcIgMkLgMkL00SMg]`0A[Va]EQ7?d0h<3XZ8ddg;e@;
04dn>3@`;BXX8Rl]9d4c;U4T0=bjYMboZ=VnZ=ZmZ=FdX/fXT<:PTLNRSkRNS[bOSkFGR:28LYanK9if
Hi9aH9M/EimaFjYdH<:EO/fYT]>ZP=k2/mg6]mc0/=NgXMJ^V/2RP;nFP;:4LJQh@JIjGjMlH:P@I[fE
OkZCOXT9H8MZFXY]FhAPD8aaGX]]G8EkH:R7LKB9L;N?L;RAN[BAN[2CO;JDOK>AN`Q974a2?DXo=c0@
0KF8LZaTCjQX@>7Sh0OMg]`00mgLf=gNg=gMf`05gMkL7_ooo`05i];Ci]CDi]CFi]CFi]CD00KVe=H0
Al>V[VPi<E0P8D8O6ET[9F009ULb;CdV8S0P6cPR6dXY8X082>F`WNFeX>:dX>>cX=jZVM22S/bERM6G
QLBAQ<JEQ[n=O[41K:IcHZM[FJ1REZ5QC:QWDK1PE<^;MMJOR/2PT>JhZnJl[nFbZ>2]VMnTTLRHPLR<
Mk]jJ;9TDJm_E;5`EX44C<J<M/:8MI9RB95ODIERDHeIB9EVEIASDZI`F;5mIkeoIl24H<67LKf7L829
M;n:Lk^8LP0R45Dg<e@d;4P65KenJKIIAL9P@N[If^KDe@06i]CF00?Vd=CVe=KVdm@01NKDeRSoool0
02Koool01=gLf]gNg=gPgMgPg@OMg]`0AZ6DVb/C2`@P83`^:B8F528201hO7adS8b0Q82l]9d8b;EPP
0]jkYmo1Z]R0XMk4[mRiY/>QP;6:OKN;MZB1LZN:O:25MiQ`IXQZFXmTDH5QE8ePBYASC:5ZD;b?NLZW
T]BXP=k2]]k5]]b1Z]FdWMJ[UlBTS[jJQ:n2LjQe@:QjGK27IhB8M<RFN=fZSX6H0j^3K9f0JHATE9Ai
I9ehIJ61K;NBO<2BNX2@OkVCO;BCN[JA0;ZGOkNIP40S440m>chi<RX17;26L:EA?[AXANKYiPOMg]`0
0mgLf=gNg=gLfP05gMkL7_ooo`05i];Di]CDi]KGi]KGi]CD00KVe=H0AjZ:Tb@@2PT>04HS7BH@3R40
22HE52LH5R805CPR6d/X8X8:2>NaWnNgX^6bX>JjZ>:^W]2AQ;V0M<21KJ1kH;20LZ]jK:1]G8mPD9IK
B95JBYAF@9YI@ZQPB/B5L=>MRMbPTnNh[nNk[nBbX]jYUMjQS/BJQ<J@NkQhJ[1SB;5`DkUmGLJ0JLj>
KnBQQ/2BLkIiGjIeH819@Ye_FjI^G;EmH;n8LlR8LL28M/:9Lkf9LKj9M<:=M[f@N0880TTb<4P^9S00
4[QmIZ]8<L1A@NkOh>KDe@06i]CF00?Vd=CVe=KVd]<01NKDeRSoool002Koool00mgMf]gLf=gLf002
gMcH1]gNg016/:N/22@<020P=2`W820080028R@P82@R820P<24YA3Ta@200dK20f;RTfX2PgL:/f;VX
`:20`920a8j9P8V8Q8R9P8R:P800Th44X806X000XA<0Z1@0PH00a8V0`jBHd;6Pg<2Sf8:Rf[RQe[>N
eZfH`:2@`9f8]h@3X01PY7QQX7IPXP5PX01QXA9XR01PP7UTV7QVT710P05RX01XX8A/XXQcYX5T/81`
^I9h]I1h/900Y81`R01<0008>30`>C0c<P40ZGIPP510P0P0dL_81mgNg003gMcHgMkLgMgJ00GMg]`N
oooo00?VdmCVd=CVd=@00^K@e0KVe=H0AX><Y14;0T0R004P630H400402<H62PI5b80404U050T:4P0
0<:TTN6`Vn2dP>JhY>2`X<2PT<:4R<R3P<20P<:0P8V=P8R00:X@0h00H800I886EH80EX00I<RC3=RP
T<2PP>BfZ>B`X^2`P=jYUMjQT=20R<2@0l20LX@0@:m`Dj5SDZAP@:Y/@8H3CJ1]@:QPFJEQG81PD:Ac
@:Ub@k1hH;P2J;P1HX20H/:8L[j0L/28L;F0H81Q@D08844Y:D@/:0004;AR@:5<<9040<31``OVe=H0
0nK@e>KDe^KCe005i]CF:?ooo`009_ooo`05gMkLgMcHgMcJgMcJgMcH00KMg]`0AlS4bU4k<SPP82h[
9BhZ9C4Z82DU8QlQ82XX93dc;E96?c000]:^V=VhXMb1X]g2[=c0/=[0/=Vo[mNl[<jgXM2fYlbfZ/nd
X<F`Xlb]W/>/X<B[W<^ZV]2`W=JfX]JjYMb2XM_0[MZkZMVhYMJbWMJ`VlBPTLfRTLFMS86009mjIYE/
G81XD8UUDhQXEH1PEI]hHimkJ::5KZn9Kjf9LjZ0LJj4L:N0JjZ0I;VBNkR@OK^@0:f<M79JB`4Y830^
<3Le=0XP1j]bGI]JAH020<[6amkOg006gMkL00?Mg=SMg]cMgM/01MgNg1koool01NKDeNK@e>KBe>KB
e>K@e006i]CF00?B^L=I<BQ281T00SLP6P12>20I;QXF:AHD=00HARTRFc/d@Q98fjB?hZjIi;>2i[RT
iKJXh;FXh[FWhK:Tf:b1fZbOej^QfZV3d:FJf::Eb:2GdInCeijAfjBBgj^Jgk2MiK2Ri;JUhk6QhZ2M
gjREgjJBe:61eYR8ci>3R0QRZfmKX61AUEi=TeY8Tea9TTA2YfaHZG1M/7QT^7mV]GmZ/7UP]gYV/GIQ
]7YP`XQb`HIda89`]X9[OTi02B@4>R<U@2XX1003]VEDYDliR652dkc0i]GF1^KDeP03i]3Di]CFi]?E
00GVe=HXoooo000Voooo00GMg]cMg=SMfmWMfmWMg=P01]gNg017emGLFD<j<2@P9RPS;2dW;2XP7b8N
6adL:2PQ@SH_FDi69P1AdJbDf;JPgH6TgL:[g/>fh<bmim?2hljoflJ`gLFef/Nkh<R0f/VnhlNj`/Nl
fLJkglBghLRah<Faf/6/`<Bhf[nZf;JTd;2Pe[6Me[:Ld:B0djFFcJNFRX0@UgIVQEaBL514JDXmHdXj
0450VGQRXgeZ/I1j_iEg^IEnZHQd[81/WWUUX0AP^Y9k^hmnP984/8ifFT<h8R0Q9bH[<S<d030:/W1J
WUm7851BaKo1g^3M00KMg]`00mgLf=gNg=gNg005gMkL7_ooo`05i]GFi]3Di]7Bi]7Bi]3D00;Ve=H0
BnKDe>KDe^KDe^KDe]o;eV<h;cP04C0N63HR6c0P62TG4bDB438N64/[9654?3L0A=ZQS>6/V>FaQ>Jh
XnNi[^S0/>o:^n[5^>BlXNJk[^>m]>V3/n:o]n^n/lRm]>2m]NNj/>31Y>RkZ^>gY>6h/N>eX^6/W>2/
VMnWU=nXU=VPT=bKS]JMSI8E2:=ZFY1@A`14>G50<Fa0;`a00:I[EZmaGXB4LLR:KL6;MK=nJ;IfHZQ_
Fj5bAL>7L/B5ML68L;N5KF<h;B<L430L7c`X:@PP3[iRDJYB>ba2@<fe^nOFe`06i]CF00?Vd=CVe=KV
e=D01NKDeRSoool002Koool01MgNg=gLf=gLf]gLf]gLf006gMkL04O0a<9JA3P08B0`82PQ;RPP820R
820R808P:212=S1DBD0Q0428Q8CAX9?HP:3M`ZSL`[3N`;33b;S0`[SJa;3Ka;3I`;cLb83Hb;cLa[SB
`;SHa;[H`[3La;7L`;3K`:cL`:3J_ZWH^JCA/:3F/9cF/9_BX9SCZ9S1ZIJ0P82XP02@066404:5I460
Hd60I42IN6BJN6JP062P26JQ2F:P0F2/PVbR0FVPP62hTWZ`SgbPP720HTA50CDP:2@Q:2`c<300000@
B0X4@004C42TX93If=P01]gNg003gMcHgMkLgMkL00GMg]`Noooo00GVe=KVd=CVd]3Vd]3Vd=@01>KD
eP1:i]CEi]CFdH?0H3X`@2@00B<0>20L020J9AX@818D=00HB2`UGP0`9010`985fJ>2h:20i[RTi[RX
h;RPj8:ah82ahkRPi;RPh[bdi82`h;jfiKb``;beh;Rci;N/i;RPi;2Xh;2Ti;2Ph[BQhZ6M`:RHgj2D
gjNCf:2@g821f82>`800P@5PZFQ<PD10P518PT=0P410XFQHXFaHX714ZW14Y7AQX714]W5P[793/7AR
`8Q`PHE`P01PPTY;FC8X<B0H<R0P?20T000@7@h220DU4440P8F0hM3@i]CD1NKDeP03i]3Di]CFi]CE
00GVe=HXoooo000Voooo2mgNg018c<S;GTU0DT8h?SD_<S0Z<20T<2/V;BTT9R0YA3TbEDU02EY9^IN1
d:bEg86Rg/:]gL:^g/Bdg/Jgg/Nhg<Rig<Vlg<g2gLZ4g<k4gLg2fLc0fl_0g<JggLRhgL:bgL>afL2Z
fKjXf[fWd[22ek:Le[6Ke;2HeK2Me:nJ`JJBbJ2=a9n<P920/Y5lZXMcP@1XW7IVTW9QV7=0V71NUg=P
Pg9PZh=^Yh9_/89a]i9j]Y5lZHEXKUA6ASH`82`V=S0]<c0^;B`PEcP_F3hcDd07VIBBg]kLgMkH3MgN
g1koool01NKDe^KDe>KDeNKDeNKDe004i]CF04[Ve=GVe=KD_/EW?cE4=257:b<k9Ah18P4j8A/f7QT0
1P1>;RMN?cDTAD31SGSHXXgTYH;V^:GV^:KV^ZgW_:oV_K7UP;3U_kCU`k_V`;GUa;gV`k_T`;[U`KWU
_;3VP;3V^:[U^JWQ]Z;R]:3S/Yo3ZY;PZ9COYi?NY9?NYYCMYI;DQ83BUHC>U8?0R7RmQW:dO6VPID2W
JU^MIeJRH56RIU>QJ5JPH5FeNFB`N6F1OF;0R76nQg>00fAiBC]?:b@a8QXo9R4l9R81801Q;BMQ<bQ9
00BUR8SVe=KVe=@5i]CF00?Ve=CVe=KVe=D01NKDeRSoool002Koool2gMkL0]gOg@OMg]`0B=C?df9>
A611@4Di<S8`:P0P93L_:C<]9bdP84Ll=EM:@@AJA[FCOM>]Umj0X=k3[]g2Zmg0/=g4]Mg7^=k:P=k=
`=kBb=k4S=oDbmkCb/3Bb>3Bamk;_=k:PMk3]Mk6]=R0XmVnYmboZMB`P=RcWMJbW=JQVMJeXMVeWmR`
XMfaW]fjXm2QVLbZTl6KQi@?J9UaI8MZFX9P@XEND8IRDHQQ@jV3KJN4L;R5NKNDNkNDOZZ4IEHo=3/^
:Rh/93dd;C@`;0H013HP7Clb;10>28b8Q^KWi]cLf0gMg]`Noooo0^KDeP;VeMH5i]CF04[Ve=GVe=CH
alm[@cUP@S1>;RHk9Ah98@909Adl8a/1821@<BUP@3HFD42mRWCJXhoVZ83W^JOV^:?V^:cU^ZgV_K7W
`;3W`kWWb<7V`XGXb/CVbL?Pb<3Xb<3W`KCV`;CV^JgW_:gP]8?R]9oT]J74Z93QZIGOZ9?0YI3OZiWR
ZiKPZYWTZ9OR/ic0X9;BXH_8TGjV162SIUVBGdn3F4B>EDF?F4N4B4VbN6>aNVK006K0RG:oRWF4169O
=BY491hh81U6:R4m9R0@00Pl6AI9:20R0AjFOGc/g^;Td=@=i]CF:?ooo`009_ooo`OMg]`0:MgLf=gN
g=gMfmgNf9><REY80419@4P1<CP`8`4P834/:38/9RPP:08`8404<P121801H:f:1L6TP=b1ZMg0[=g2
/=g4]Mg7^=c9P=c=`=c0a=g0`=k@`Mg@`=c0`=k@a]c8^]c8P=g3/=c0XMR0Z=RlY=RhY=2`P=N`VP02
eZ2H027D/9[EX9W@X9SBZ97@X930Xh;0XHf0VXFPP02R26J9062:062806280V2006:RPg6QR72`R7Va
P72TQ6L00410>S0a;bXP;20V82TP:BX0000`824`;241001XH4^1R83Lg]`03MgNg1koool7i]CF04_V
d=CVe=KVdmGVe=BVPR=T031P@31B<RY0:R<080Dl8a`l8Q/08018:29A<B00002:J4:0P6S0P83T]J3V
/:CV^:SV^ZgV_K7VPk3V`kSVa;gV`83V`<3Va/3V`83Va[oVP;;VPK3V^JcT^:;P/:3Q/YcQ/9c0X930
YY7NY93OY93NX930Y930X93JX87HX83BP83>V8C8T7b006:`LVBTJTRTJ42SI46RHDBTH42c0FRb0FZ0
062lPVfW0VB0@41B<2509Aha81Pi8P0a81hT410h71P18A`@80@8@4;0X9`03^KDeRSoool002Koool7
gMkL04cMg=SMg]cMgM_Mg=QiKVMGASUHC4AAACe3?3L5<2@a;2Lb;2HV;20i<B]3=c11@P5mIENJNFC4
U8SL_ZSN`ZgL`[3M`kCMb;WMbH3Mc/;Mc/CMc/7MdLOMd<OM`8OMd<OMbKWMb;SMa;?L`JcLP:SG^jCG
]j7F/IWF[YWF[YSFX9SE[iWD[9OBZYK@ZYC>Z978X837YHk4WXR2W8JoUH6jU7nhT7RhSgZgSg^`SWVf
T7ZgT7fbP7^dS7JPOfX2B48o=Bhc;RPP;2XZ:RPX:2TP8B0Y9b8Y9R<X821HBd6HRh?M`=`=gMkL7_oo
o`OVe=H0:>K@e>KDe^KCe>K@e8ISFf0k;V=2>5Xk<Tdb:dHP83/Q6c`Q6P0P64<V7d`]9E03;8MJCJA^
F/f05>BdX>JhYNJhZ>Ji[NJn/NJ3/^K4^nK5_NK4_>K7`>K6`>K2P>K7`>Jo/^Jn/^Jj[>FgYNFbX>2a
W>2]VL2WT0?OY9008MjUT=fRS]RPS=VPS=JNRM:FP=2KQ/fDOlRBOLV;N<>9ML:6L<64LL65LH64L;n6
LL26M<24L;f2K:UeH@a424TZ8c`T734R7S@O738N7BPH5C8M5c8K5`0<06=0=:>1NN3DeP0=i]CF:?oo
o`009_ooo`OMg]`07=gJf=gNg=gLf]cMfEI8?E=2=55>@UI;@TU0>T0`9BhZ9C8[9B@X93</9cX_:D00
;6IBAh=UD9>@7=bnZ=o3[mc2/=g2/mg9^]g8P]g?a=g>`mg1`0;Md<L0;]g1R=gAbMg8^Mg8^=g5/m^o
ZMf1Z=JjY=JeW]JPVmJ]UmN]V=JPV=B^UmBZUM2QT<jZTl^US/R8RlVWTLVSS<RQP/nTSLjTS/RQR<^Q
R/ZQRhRJP;bFOknGQ;RAO;R=MYelITHJ0S<^:Rh]9R0/:B@W9b@U9`0R8QlW8A/O7A@S83h^879MDL70
g0gMg]`Noooo0^KDeP;Ve=D3i]CF01cVd=;Ve=KVd]CVdMAK?SEL>2U2@3aO@3QB=Rm9820g7aTk8AXg
81Pm8A]39Ae1;29^B3f<FTO8R1CT]J3W^ZOV^:SV^:cV_k;VQ;;VaKgVa;cV`h42i/K002kVQh3Val;V
_[;V_[3V^jcT]J7V/J3O/9_NZiK0Y9;OXhoPXho0Y97MY8kLX8cIWHSGX8_DVXGBU8;BWHSAVH?BPH;G
VhGEVhK@V8?BV8;AUh?0T035S7K8SGc0RG70PffULUe7400m8ahg8QXh824^71/^6a`X61HY6a@U514X
01A19QUdED[Re=0=i]CF:?ooo`009_ooo`OMg]`0:=gLf=gNg=gMf]gLfUa0@5A5>E19@U1;@4500T01
<C@R:C8]8C0/83PP:@0`;48806UDBHAWD8B00=2`P=RjX=c0X=g0]=g5/=g0/=g<`Mg>`]g0`=g@a]g@
amg0QMg0aMg8^Mg8^=g0/m^oZ=RlZ=N`X=JdW]B^V0;AZY@08]BXT=2YU=6XT<2PT<bUPL^RSL22R<2P
R<J0R<20P<6KPL:JP<2HP<6@PL2BP82@1;6AO;20N:20H8L2I@aPDD000S0^:2h]:20Y:2<T928T900P
820T8@8P820P8440:X626<30g0gMg]`Noooo0^KDeP;Ve=@3i]CF00KVd=3Ve=KVdmCTd=APA3YN>B82
H40h021B>S=0820580438A`h81Q091e1:21002A`BSn<G4R00030Y93Q/83T/:3V^:cV^J3VP;3V`;SV
a;SV`;[VaX3Va/3V`83Va83V_k;V_[7V^:cT]J3T/:30[9SOZ9KLX902g:2<02;LX83LX8cJWX_HV8SD
VH7DTHC@TH30T830U070T030T@3;T038PWS8P7S8P7C0R722PG22PVFX062PID24@T10020h91hg8a``
01`/6QP/61PX4A@Z61DX4Q@0011@<2FH4A3Pe=0=i]CF:?ooo`009_ooo`OMg]`0C=gLf=gNg=gMfmcI
fEa=A5M:@E58@5Y=AUI=Ad090D8f<Cd`:S8/8Cda;44e;d0906UBAh1TDZV1J]6[UMRgXMc0XMk5]Mg3
]=g0/=g=`Mg>`]g>`Mg@a]gAb=g=`=g?aMg9^]c8^Mg3]=_0[MRhXMReWmJcW]:]V=6XTm6XT]2YU=>Z
Tm2WT/fTSl^SSLZORl:0RLJNR<FMQl2HQ<:JQ<2HPl6AP<2COkjDOKZBOKNBOK>:MI44JXY^GVaCAD05
<2d/:2d]:R@T820S8R0R8adP0AlR8B<V92@Z9592><6m^=cNg0gMg]`Noooo1nKDeP0Xi]3Di]CFi]?E
i=3@ID8jH3lfAD0eHd8kGd<lDC@XBb/UARHO?B0IAbLPBR/T@2lTLTLmREY8P01PfZ6=hJfIi;2Qi[^^
i[V/i[bQi/>ji/Bki/Bli/Joi/O1i/6ii/Fni[nbi[jbi[V/i;JUi;21h:^GgjVFfj>00]ZNRP0QfH6=
g:2:fIf9d9Z6e9V4diF3a9B1ci=ocY9nbH1ibi1jbHijbXebbHUfahYd`hQd_hQd_81[XW1PU6=DMTTj
C2PP=b8L=R<O:00H:QPF:APG81HA:APE;A`H<04IF3T_c[:_00kVe=HXoooo000Voooo1mgNg00XgMcH
gMkLgMcHg=S@F4I0D4U4D400FDi0F599@480B3Pd@30P<B0P@30/@S0`@00`H414N612PP10`8F0d:FG
f86Pg<BcgL2`gLBegLV0gLc0gL30gL33gL;0gLg0gL25gLRhg<2bg<6`f82[f;RPf;:Le;2Kd:R@0/nV
T00Rd:2@dJR@cjFAb::<bJ2:bIb:`828aIZ4aIZ5`9B0`921_IB0P900_i1m^I5j/81hZ81fXh1RP010
L4A7D40a030P:2PW:2dX820P7R017B0P7000720P924T02@0@20@f=SCg=cH3MgNg1koool7i]CF02SV
d=CVe=KVd=GT`=5P0C52@3U0031T@3aT@D51031B8RU88P@281Q8:259:BE1825`A3^4D4F0IT39T0W0
XhKP/H3V^:3V]Z[V^ZcV`K7V`;WV`;SVa83V`8;V`KSV`[SVP;7V_:3V/J[P]:3PX83QZ9CNX9;JX8`2
f9b002;HW8SJWXSHVhS@V8CBUX;BT872T03>T7c<PGc8R7S8SGS6R730R730Q734QW20P721P6B`MV20
H404D4A2<Ra4820`81Pe8`0P01PQ5A4P5A@P510V51@/71P0001<403Q`]3Td=@=i]CF:?ooo`009_oo
o`OMg]`0BmgLf=gNg=gMf]WHdf9DBeA:@e=00UU=AeYABU50@T/o>4Hi=3Pa:d4f<4Dj=4@4=FEBAWYS
DhEZ@;bBO<fUSmRjX]c2[mk2/Mg1]=g:_=g;_mg8_]g<_mg<`=g8_]g9^]g6]]c4/=g0[mVlYmRaX=Ra
VmF]V=2XT=2WSm2VT<6PT=2VSlnUT<fPS<bPRlVNR/6MPlFIQ<BHPl6FP[nGPKfEO[b@OKn@O;V@NJ:8
M:F3KYahI0aQD6QDAdlm=04a82//:2`]:R4T8B4S8b4T8aP001`O82@V91060IB:Q=WHeP0>gMkL7_oo
o`OVe=H0C>K@e>KDe^KCe>C@d6]9@Eho>400<692?6=6?d<6>5De;E0^:44V7dX/94h_:4d`8Vi7>h=H
BHIPB<J8L]JKQn6TP^FhYnJhZNJi[>K0]NK1^>K0/>K2^>K2^NK0]nJo/nJl[nBj[>FfZ>6bWn6]V>2W
T]fST=R0R=RMQmRKR=RJP]VLQmNKR=JBQ=FFP]:DPL2A0/f?Nlf>N/V<N<R<N<J:MLF8M<N6Ll:5L;@2
JZihIJE]FXA0BW99?5Pc:D8T83DR73HR7RP06BXH5bXI5b8A42DE52dL61TS4:EmM^;>cnKDe0gVe=HX
oooo000Voooo1mgNg00]gMcHgMkLgMcJfMSBHUE<DDM1B40hF4a6FU5:E454CD<kBShi>34Y@cTbAcdf
@0@dI5=6NfEFP69A]8Uabj2:f;RPg<:]g/>ag/2dg/VkgL^ngLVjgLZlgLVlg<VlgLJeg/BefL2`g;n]
ekZTf;2Pf;2Je:^Fd::@d:N?d:FAcj20cjF>cZF@00;>X8`07<ZOR/20Q<BGPlBFPH2FP[nFPKfDOKZ@
O<2AO;R@NZ:5LYimJ9=aGV]2@5a:?dLh<3DT82`]:2`]:R0V:28T92<V9AD10APM7B8U8a0:0;Rb[McL
fPkMg]`Noooo1nKDeP1<i]3Bi]CFi];Ci<;AJd]2FSdf@CHTHD8kHdLoAT00EcP`E3<]@202C2hWD38[
DC0PKTPkQ5Y<Q4Q2_WiWdiJ1h:F0i;RUikVYikR/i[ndi/6giX2di/2ei[ndiX6ei[b^i[Z^i;:YiKFV
h;2Lh:bHhJJAgJ6>fH23f9f6fI^8f9Z1f9^6ei^7eiB4eYJ3dYF1`I82cHejcHahb8Qhb8ahaHYd`81a
bHIc`HIa/05XYg=OW6IE0E14ISldD2dT1R4P=R<M=R8N;0@L;1TH;A/I818A8Q8A;1XG:00Ib:FRiM;D
i]CD3NKDeRSoool002Koool7gMkL04GMf]SMg]cMf=SHf=1PA4U2@0A1031GC4IID4Q0D41@@3e<@3df
9211>C120350@3Q4D4A`BE80@D2>Mf29R@30P83HPZ3M`J7M`:7L`K7Mb;SL`;3La[3Ma;GM`;;L`:3L
`;7HP:3H^jSD/83@/83@[93BXI30X830XHc1XH;<X8;<X8c<XH30P830P8S8P8?4P834U8;0U020U82n
U@6hTWR0P7R0P7F`PGB00629J44;Be10@411030h8RPP82XZ;24/;2PP820Q8R@Q8B@00Q800004228P
1080a<3H`>3N3]gNg1koool00nKDe^KDe>KDeP04i]CF04_Vd=;Ve=KVd=;P`=1VB41C0390<21P@3]P
ACeP@41H?31@>31080A:8R5@<RY@<21X@ST2E400@0:WI5C2PVc0X83P/H3P/j3V/:SU^jCVP;;VP:3V
_:;V^:3VP:3T/:3U/:WP/:3T/J3N[930Z931X87HW8S@P83HVh;BVH3ET83FV87FVH3@T83AU83AU0;0
P03=R7W<RGK0R730Rg31R760P730P6B01f>P0421H4R4@41P13AA<2=19000808d81Xf8Q`0000Z6APP
6QP041081P@P5100203Rd=3Qe]403^KDeRSoool002Koool7gMkL04_Mf]SMg]cMgM[Lg=V6NGAPEDi6
@caFC4IGCTMHD4YBBD9<@S/4=30n=S14>cA613QICD9VEdeRD4R@KebYP6c1Rh3D]9gJ_JSK_J[J`:kM
aKGLa;;Ma;?Ma;;L`;7K_Z[K_jgK_:SI^:GG]9oBX9;DZI;AY8g0X8S>XXW<X8c9PXS>X8[<XHc9P8S9
VXC7Vh?4TH73UX72UH2mU7nlU7fiT7VdR72aQW6WPVb:J41mH4m[DdM8@CU1=Rha;2HX:R0X:RD/:bLQ
82DM8B8M8B4B7AhX:BHc;BP54@WIemGNgm`03]gNg1koool00nKDe^KDe>KDeP04i]CF04_Vd=;Ve=KV
dmCTd]2AKVUYBT=0>C1P@S]P@caQA@1L?cMF=c178R57;2E><2U@<25R@SM_CD=d@0:IIE:cMF75P83N
ZYGS/j3T/J3S]ZOV^jgV^:SV^Z_V^Z[T^:ST]:;S]JGT/Z3R[YgPZYKLXX7LWh[JVXG@TX3FV83EUX?D
T83GUX7EUX?BT@3BT7_?TG[=PGS<S7S:RgO6RWK5RWC1QVnm0V^jO6N`Mf>4H4R8E4AeB3a0<R1:;2<j
8A/c01Pb81Xe8A/Q6QTV5QHV5QD5418b7AXk8QhX00SScLkWeMH03^KDeRSoool002Koool7gMkL04_M
f]SMg]cMgM_Mg=RER8EVFE53A3]FC4IEC4EG@DEDC4E<@SX<134j<bi2>C961P1CB41ICdIP@4B1IUFK
Len8Q0cF/I[M_ZOMP:SL_j[PaK?Qa[3OaK;PaK7L`Z3K_JOJ_j[L^:7J]Z?J]9oCX9;DZ97BXhc0Q8S>
X8O;Wh[9P8S?WhW;X8_9VHK7V836VH74TH;4Uh;1Uh6nU7jmUWbiT7R`RG2[PfjQOFL@CDUaDdEJAce1
>30g<2TX:2<V:28W:B@];2LP82@J7b4G7Qh>000`;bXe:R=0@D3Lg=WNg]`03]gNg1koool00nKDe^KD
e>KDeP04i]CF04[Vd=;Ve=KVdmGVd=FPOG]^CTMH>c1O@S]N@CYP@01N@CYE=bm0:B14:B=;;RM8<2EM
?SESA3aYA3^:G4^UJ5C5RP3OYY7V]9oU]:3T]J?X^j_Y_:[W^j[X^jWU^:7T/ioS]J?T/83R[9_RZYO0
QX;MWXWKVH?BT83GUWoDUH7BTP7HUH3DUX;BT7g@SWO?SWO<RGW=SGW:SGS7RWC5S7?2QFni0fVdNVBY
Lef2@41jB3UT?3998B509Qda7AL`7A<`7aPf8A/P61PS5ADQ4a8810@j91li8A]F4@[Ud]<?i]CF:?oo
o`009_ooo`03gMkLgMcHgMkL00CMg]`0B]gHf=gNg=gNg=cNg:B0PFQA@41005A9AE98A4A0@5I>B4Y0
=000034`;00f<4000De4?TY00T10061HBPa5@H080L2@P<22P<20P<20R<B8X<28X<:2XL28X<B0X=Fd
QM2hXM6`P=>TP]>TPL:0Q<28PL21PL21P<RGP<:IP<2HP<:IP<RJP<2@0<2AN/6CN<200<2A182B1824
0;B9MJ^0L:40HXL0H8aY@`100451<4<a<00P82PQ8ahP7`0P020P820U8`0P81HM7a0H6@00000a9A00
0h080=k0g0oMg]`Noooo00?Ve=KVd=CVe=H01>KDeP1;i]3Bi]CFi]CDi]GF[Xb02410@00P@44hF@0i
A400H4<mD38PB00P0bDPB2`T@28PESTbD3Tb@04`L411QU92P019`X0@`J22`:20b:J0h:j8h828h;29
hK28`:R0a:2D`ZB1h:22`:2Ba:6:`800dI48d8/0d840d8Ee`h@0`800d8D0d8D1`81`bHU`bXU`bX1`
bHUa`H1c`81PR8ATP0IXXP10XFU2Q6190040H3<Z@2`U0200<1dG814C:1PA:aXD<00H810D7a8C6P00
2000@20Q91XBP011i]G@i]CE00kVe=HXoooo000Voooo00?Mg]cMg=SMg]`01=gNg019gMcHgMkLgMkL
gMkL`[bkTHN3@DA2E4Y3ED]4DDU5Edi8DDQ1@PT1?C<^@CH`30@bCD@mDdY4D4U2I5=9L5I9R6e:YhUf
[YB1^9R4`:6=bjbHb:REcJjIc:nKbjVHcJ^Dck2IdJ2@c:NBb:>>PI02^hmi^hig_Y1h`Y1j`I=l`9=h
a9=kaIAo`91h_i1h_Hmd_8Uf^Xei]hef/8QbZhE^Xh1[U711RFMFOEi=BD00D3`b?C@^92PP9BDR720N
7B417B8P7b8P51`M5QdN6AlP2b8RBd<lNg1ZXJ:P013Mg]`Noooo00?Ve=KVd=CVe=H01>KDeP19i]3D
i]CFi]CEi]CFcK6cWGahH400GClhGT0i@T0hH4@mFcdfBbhVARTRBR/U@2PSESTbG40i@T0hKTToN4`o
Q610/Gi/^8Ug`X1hbIN5eJ6?d8:<ejB@eJFBeJ20eZ2;f:JAf8J0eIf:dIR5`hI`a8E_a8A^b81RbhEa
bXUcb8U`cHUbcXYfbX1ab8I_aXE[a0E/`h=_`8=/^WeX]7]U[GEQQ6A@Tea;R5=2HP4XFC4WARTR=20H
;aXG9QDB9QHA9aLD:ALE018@7a8B8a@D81P@ESP_SV9K`9VH013Ve=HXoooo000Voooo00?Mg]cMg=SM
g]`02=gNg015eM?AY9bJ@DQ2DTLoET]4E4Y1F4m9EDa6@PP0?c@^@SD`2P8/Bd<lDd]4E4U4FT]4G4Y1
04YBSGASU7e/X81c/iB1`j:=Q868b:J?aZRDa:>@bZJ?cjfE`JB8bZ>>`Yf8ZHQ`/HE_/XI`^8Q``8]g
`I5hQ85``I1gaY1k`81c`91h_Hia^HQd]hYf]HYaXX9PY7iYVWYVP6AANeY;Ke51C@@bA3D/=2lY820R
828Q6QdM6QhN6AhO5a`M2a0H4a`M724R:206CT8jWiJ@c/38013Mg]`Noooo00?Ve=KVd=CVe=H01>KD
eP19i]CDi]CFi]CEi]CFglW;/96@HD80FcdeH44iGP0hHDDnGd8kB2dUB2TRBbXTA20RE3PaG40i@44h
I40iID0g2D10UfUIWW=RZGQX_HUhcIN4aY44dYb6cYj<`9R0dib6ejB=f827diV5c9=oP09T^gYU^g]U
`81Xb85^bXM_b8EPbXI^cXIbbH=RbHI_aXAWa0AX`81]_X1X]7QT[G=OXfmLTT98QDm0NDDf@30WCBXP
?R@N<1T@:ALE918A91<B8Q@C8A8A4@`<7A4A9AHF<1P@F3L^/hN2`/30013Ve=HXoooo000Voooo00?M
g]cMg=SMg]`02=gNg015i>OUPK6d0408A482D4Q0@400DT58DT99@000@3@Q@C4P000XB40hD4Y0D410
A405A04g@410HT10MV1DPF1LR0ATZ8P0P804Q806PX<@P800P8@8T8HCT804PX8:Yh80P01PP6Y4R718
Q01PP@1TQ15VP01PP81PP89YP@=PQ8=XP85TP0QPY@QPXPQQP01PSfE0P6120410H4D0@04d030P<b`T
:BPT004061`05QPH41PL41XL010H010@21PJ0B0T0000@2PPb/21`<30013Mg]`Noooo00?Ve=KVd=CV
e=H01nKDeP0>i]CDhLC8`Z2T00@0ESP`H40hF00`H4@0A4@2@2<RBBPPB2PT0200DC0R0T10>00fESHb
BC0PH000LU50OUQ9P61@XG9PPPaZR01PT81/P800P000TX04`X81`8D0U801P11XQF5@T61BXFABQ6a2
P6i9Q0A=P010R0A;TPEQR05PQ@URP0A1P018[W9<[710X610P61@RTU80400HP0aB3DY@B00024I<1hH
8A0@81<C0@l0000@710@40T<000000@391PH00450102e[2`h<304>KDeRSoool002Koool00mgNg=gL
f=gNg008gMkL04GPhMo:b<HO515LD4YFBT9@BTAECDIBC4I0@056>SA0=S49031@Ad1LDdaKDdaJD4]G
CDI8D41cHUEdHeN0J5^:Lf>DN6N8L62CN6N<MFJ4L66GMfFOP6fR1fBLOVbAMVJ2J5R1HU>6I5>5HEBC
JURFKUZFL5VNM5jRMF60M62JMF6KM5bDH5RDL5fAKEZ:HU20He=hG4ePB01F@CM=?3<09BH_:RHW9b<N
8@4G7AhD6AX@61/@6A/B6Q`B61TT8b4Y:BQ5612KThg>b/O0`<004=gNg1koool00nKDe^K@e>KDeP08
i]CF04GYemWD_Kn92@EVASmO?cQM03UN@SaL@C]D0S1?;bQ9:bE48R5I?3AVB45UB45TAT1Q@S]Q@41l
F4]mFDf4H56CJEZNKUbEHEBMK5fHJU^0JEbRJeZZM6:/M6:VM66KJeb3A4B:EdV@FDR@G4RMGdbPHdnP
HDBXJE>/JeJXJUBSJUJTJE60HDjNIU:JHTn@@4V:F4V2DD5P131P=RaF<RP88P0h81/`71LP5Q4Q4Q8M
3PhH3PlJ3`lK3a0L0P8/6ALa7QeA0@>`Q7kK_[kPd=004>KDeRSoool002Koool;gMkL04GOgmgHemF<
QXEMDDY@A3aAB49CBdE>BTA6@418?CLl=C0;0S9BB45QEe50ET1OEe5MDde4D45`HUI]Ge@0IEIhJ5Un
IeM`GE5iHUIaGE1dHUEmGe28JUV>ID67KUekI5M`A51]E4UeETMaDTQoG4V1GTf4H4BAJEBBJeJ2JEB8
J5J<JEB1@db6IU>1HU1kG4acFTa/D49=131:>352=c0P82<Y:2HS9B4L0P8E6adA5aT05QP<5aT@6Q`E
71`X8AhV8b80<bK5`;cHf=GM`=`04=gNg1koool00nKDe^KDe>KDeP08i]CF04GWe]OQcLn9;2QUAT1G
>S9J03=L@CYH?cQ013AA<R]5:RE0921K?SIZCDIXB4AXCDMWBD9UAd1iF4afE4Z0FDf2GDn8G4alD4:3
EdakDTF0D4Z8E4BCGTj@H52@I5:3FTihDTAfBCmoBc`2C029DCj;Dd68ED2KGTVLH4^C@4VBGT^FGTV=
D46@FdR:EdF0D45mCd5fACI1<2UC;RE;;BDd1@0b7A/]6aDP518N4A4K3@d@30`E30dJ3a0P4A4]6AD[
6QTA80[D];;ScLkVe=004>KDeRSoool002Koool;gMkL04GLg=_PhN20R81AB4I54@54A@1@BD=9@D1@
@41:0SP0<bI0031@BD1PFEARF51P@55QF550D41Y@U1UFD5P@41TF4YQDTA@@01KBD5A@C90B010@cAT
@49P@41PE4A0@4=0@41@@CY3@S90@358A35:A3UP@004D400@4<0@41TDD9[D41Q@01PD41PA41:@016
@@1D03@1<2Xd;BP`8RPP80H38R808000000@6Q`05A4241044A856Ad000006AD;1@800PWYj>GQh>3L
g=P04=gNg1koool00nKDe>KDe^KDeP04i]CF04WVe=CVe=KVe=KVe=KTd=CP`L2PP8@2@1a92010031H
?cQB?3E0@01A=B10829082111CAPD4QP@D1XD4]X@49P@41bDDQP@4EdD41^@D5/@C]1031S0C5H<B12
031U>R1T@SP0@01X@@9P@SU00050<bAP=Be0<21P0RaT02<4@308@cH8@000@01`@3P0A05X0202@3AY
@CAP0C1P1314<2Q080=08A`0800P010X4a8R4A<P410H010A2@T020P820P00P<Q0180100A2P@0007V
h^7Xf/7Td=@04>KDeRSoool002Koool<gMkL04?OhMjHTiBAQhAfJfMF@41BBT=@BTA@Bd1=A3i9@ce0
@0=OE4eRFE5PDE5PF55NETm0DTaUF4mXEdeTDT9SDdQPCdEDA0EIBdA>A3aA@d1IBCmIAd11@T1JBd9F
Acm0@017?CI;?3A0>31??S=@?cEB@31IACUMB3]LB3]GAcaHACUB@3ECA3MF@cU@03I8?3=8>34092Pa
:bL/:bL7820K7b0J7ahE6A`C6adA6A/B61`G7QdR8b80:2IQEE5fL6fFQXCQhMkOh=h04MgNg1koool0
0nKDeNKDe^KDeP08i]CF04GVe=GXemS1P92NNgV3GeY9@01L?cQI?cUI@3QG>C=C>35D031YBT9/CTMZ
C4IYCTMXBdAPB41^CTEaC49^B05/BCiYACY0031Q@CUG>C5003=Q?cER?CIP1cQS@3QO?3AB=C1A<R]C
<BY0<2UH=2UI=BY0<R]R>biW?C1T?31Q?39Q>Ri0<2QM>BaP>2eH=2QA<RMA;RH8800j81/f8A/P5Q0T
51@T5A<0410M4A4J3`lH410P518Z6AP43PUcAT:8HUn=:BSXemSWe]OVe=@04>KDeRSoool002Koool<
gMkL04?Ngmg@d=2/XZ::OWa0A11AAd1CBdE@BDE@Ad5BBdE@@45WG5ERF513DU1OETmMEDiLDTaPDd]Y
ED]L@0QPCTAHBT94@`ABBD97@3Y0@0A@B41:?c]0201;?cY=?cQ1>C0k=C0k<bhf<b`n=Bdo=Bd6<B11
=Ri7>C11>315>SA1=Rh5<2dn=Re7>300=Bhf<2Tl<RdX8R8Y:2@U9b<51b0D6Q`F71d@61/B6adA6Q/B
700J7adT81d8921jK6VRViO0T93OgmgNgmd04MgNg1koool00nKDeNKDe^KDeP08i]CF04GVe=GWeMO0
`/2gUiVFLg5820EJ?CEL@3YH@CQI?CIL@3Y0@3Y`DDY[CDEXC41XC4AVBT=PB41ZBD1cBT1W@SAYA3YQ
@3MD035K?cM@=Bm@=C=I?SEC=31@<31D=31F=2e;8RU5:bA4:B=0:217:R98:b90:R19;2=@;RE@<2E>
;bU;;298:R17;21A;BA2:R8o9Qe59b80800c7AP_71LV510N410O4Q4J3PhL410J3`l0410R5A8X5aD@
4PR=G5ZcSH[0Qh3We]OWeMKVe=@04>KDeRSoool002Koool00mgLf=gNg=gNg009gMkL04?Mg=S0`<39
`/B<P8141019@PADB4I3B4AABD5IDD]BD4QQAUM0EDi0D41LD4aID4U0@41HC4APA410@0ID@010@3a0
0018@P0n>S000010@04h<C@0830b<304<R4`82`/;BPY:BPR82@Z:2H[:2@P82@P820]:28P:20Q:2TP
9B0P82@U9R0b:RDP82@R8a`X8R0P8200820J8Al20201418@61T0410A61`66Q`0008@40T05Q000024
Ph7Bc<SSh>3Lg=SMg]P04MgNg1koool00nK@eNKDe^KDeP09i]CF00OTd=GP`/3A^H6PR8X000110C5O
@3/00UP1>00jHT=0H400L5=4HdU0H410ITU1HD50H400H48kHT8iD00PACT`DSPb@00PD3D`B30/@B@T
@CH`@RPX220P@20UABPT0R@P<28L<alH800H<1hJ=1lH<00@81P@<00H<20H<B0L<1PE<00H81`D>b0H
<00H:QPA<@0H800@:14D810C810@40X:6001400000<@6A0@010A7`<0510<0100XP05`<30h>3Qi=3E
i]CE4NKDeRSoool002Koool00mgMfmgNg=gNg00:gMkL043Ng]c@c<bl][DD00ATFE5HCdQ@BT5?B49F
CTQA@41OEe1JE4aJDTaLDdaGD4U@@45FBdEHAci1?CA:?cM:@C]203A5?CTn>CHi<SPn?3Xg<C4a<30a
;bdc;RdP;2`^;BTX:BPP9B@W9bHY:2HS82DZ:RD_:bP[:B@/:BLX9bDX:20W9b@^:RPP828P8R0Q8b<4
80<K81lH7alI020E6adG7Ql@6`0L8R8L8R4Q:29?B41]I60I40Bi/[3Ac/_1`/0CgMkL7_ooo`03i]?E
i]CFi]CF00WVe=H0>>KDeNKDd=W2aLN[[H4:0Fm>AV54?ET1>5Tn=em3?D10>VU<AFA9@V=8@FE8@F55
?T080611>V8m<d@b:E@d;5@f<40V84lb;TP^:d4[;4Pa;d4V9P8R9C/T8SdS8SPS83LR7C4N72`H634L
6S8N6c0L6S<O6SPQ73@N6SDO734M6C00634L63LO7C4L62TG52XI62@B42DE528D4b0A41l@4B0C4`@@
408V5aH01c4305`k<h1FDHD10<^SY]g3`n3@f002i]CE4NKDeRSoool002Koool00mgMfmgNg=gNg00:
gMkL043Lg]cJfMO@cLb0>S1YG5ACBD50@09<AT1DC4I4BTEHDD]FDT]HA4UJDD]DCDM8@0QBBD9>@3P0
=210>C97?cY2=312>CDn>3He<c4i=cLc;Rla;RhZ:bXY:2TY:b//;2PT9bLN824R8b@T9RDS920W:BDZ
:BHP80<R8b8Q8b8Q9B8R8b8V9RH38B0J7QhE7Ah@01/E7AdA6a`D61`F71lF7R00008O92@M8R0Y:2AU
ETbBR8B4PJ7Bd<kIfMKN`=`CgMkL7_ooo`03i]?Di]CFi]CF00WVe=H0@^KDeNKDe^;?dM[2aH0^87=B
BEXo=e0h<5Hl=Ee1>eI0>F97@617@6100VA7@5i2?40105/n=eLf;D8Y84X^9U4d;TPQ:4/^:TL]:clX
9T8/;3dS8cPT8S<P7S8N7S4P03DQ7BhL6bPF5B/I62dK6R`H4C0O6C<N6bPB52/I5bXI5b`H4R`H5RlL
6bPB42<C4QlB4P@@0ahB4A/@41`A420A4b0D50X@4RPI62HG5C@Q779:?jMhML2@T]o4a^?>cnKDd>KD
eA;Ve=HXoooo000Voooo00?Mg=[Mg]cMg]`02]gNg010gMkHh>?PhN3QP8202UY@AR0@2009@484DTU1
@4Q0D4Y4DTm8D410F458D4Q4@100@410@3Pa820P<C4/13Ha030P>30R=c8a820P8b0`;BTX828X82DT
7B0U820P8bPP82@T61`0600P7B4Q620P92TR828P0004100100H80B000@<P020P00404QP00Q@H010A
11DH1A@02000500P00@P00033b@P4Q<<0@00401@P;2U`<S0h>3Ph>73g=cH4mgNg1koool00nKBe>KD
e^KDeP0:i]CF043Ve=CYf=[Xf<:P5@0ADDQ:40500P1@>35H03Q@039H@3QHACm0@01PA05J0SQ0001@
>CA98200000m821592Q0821082A09B@`00@h8b0`7`0`000Z61PP41P/61P`01PX61PP410T51@Q414P
41@^7QPP6aP0000>410P510P410T410T4a<440000P@@0000000E0@0A0P00000P41084Q00410R0aT0
10800126ETW1X:;T`<CPh^?Xf=[Td=@Ci]CF:?ooo`009_ooo`03gMgKgMkLgMkL00_Mg]`0?]oPgMkN
g9RBTZJOVY28PfQDDEYAC5I=B419@E5<AEA?BE1ABeaCCUM?BD4<0E=:A4Hl=30R:S4_:c<a;S0P:C8_
;Bl];2<X9R/[;BXY:B0P81lR8b0S9B0T9R@U9AlS91X281XN81/P8AhR8RDX:2`];RX/8S0_;R`_<28X
;2DW:RPZ:b8V8B4T9A`S8P8P81lR8R4U9RDX82@W9b/[:RH/8Che;U15?P5FD:bSW<O2`<31d^7Rh=kO
gACMg]`Noooo00?VdmGVe=KVe=H02^KDeP10i]CDimKGi]CF`860]I>?Wgaf0454I4M1Gd<mDP4hFd4j
GDDn@TI0IDU3H4@nB@0ZG40iCc4Y120P>bDO?BHS>R8P>b@R>B<Q<@81=B0Q=1lM8Q`L:APG:QPI:aPJ
;A/I:APH81@D8a@D9ADE:1LF;ahL=R8R=20R>b<R=b@T<040<1`N<QlO81TI:aTI9QPG914@:1PG:QXK
81dL;Q`L=20O>24MAR/UG3Tb6490_YF@ekFfh<S9j=WJi]GGi]CE4nKDeRSoool002Koool>gMkL03kN
gmgNg]cAdLc6`/2c[JT90A1KDDaAB499@05>BT=DCTQAD4aNEU5ID4/<2PACBTA4>S8`82d/:bPX:2PX
92LZ:RTV9bHR828T9RLW:2HR9B@L7b0P8b@O8R0O8R8N8B800@8F71hH7AhL824U9bX`<38a<P8l>CHd
=SPP828X:Rl[;BhP:2PU:2XT:BHV82DV9RD[:bd`820X:bXb;bdh82=8=R]VDDF25PS:alCEe=;L`=SO
h=kNgm`DgMkL7_ooo`03i]CEi]CFi]CF00[Ve=H0@>KDe>OEe^KDe/K3`=>g]l2QWR8016=7@ELn>50h
<UPo>5e3?DA1@FM;Af=6@400:Ua0>D``:08S83DQ734N734063<P7RlL6b0J4RhK6c0N6b`J62DD52TH
62P@42PG5RLF5R4@4QlB4R4B4R0E52hM7SXU9`4V8DL]:T0Z;30Q8S8O8SHR8S0N7BlM7RhN6b0M62hK
6S@P8CXR838P7S/T8S`P6T`]8g56>I@03=Nk^n79b^G@d>OFf>KEe^KDe1?Ve=HXoooo000Voooo3]gN
g00mgMkHgMkLa/30i>7Qf=3B4000Dd14@B8E0P00@4H9DTa0D410@E1AG59<0000D4512`8Z820P92@P
00DP020P820U00@40R00020P8B0R020P4QTM7R8P600P6043700P000141P04aTJ00008b0[<30g0000
A40o?@11820`:R0d8C0b828P:R0P;B0X820X82PX<38d0C0a:RHQ0P0Z4000C1004EQ1P820iN3Ph^3P
`<30g=cK01GMg]`Noooo3^KDeP;Ve=D0?>C0`^30b^3;`00200A0840C04020580=410>T10069;@fA8
@T019D8804DT804P12@1620C4RD04BTJ6B0@4B0@42@@42XL4R0A424@4BP@42@D524B4RDD50P@4004
10020b0B424K0S`X:40P0TL`<4T`=P0P830P:3PT9S0P830R8C0T030P03@400<X:40P800T1d0T8`08
04P8789@8X200>WPh^S2`>3@d>C@e>KDeACVe=HXoooo000Voooo4=gNg00j`L;0g]kLe]CBR8B4ViFB
RXB1061CGUQBFU9<D4]0FU=?GUE?EU1<IE]FETa6@3D`=C8];b`Z8RTX:b`X;B`Y:2PP:BPX:2XX8B0P
71lQ7R4S7b8T8R@W7b4S8R0S7b@T6b4S920Q:bdb<C@g0048@3do@T52>38h<C<e=3<b=30`=3@b<S4^
>C@R>SHb@3Te@3PdC40hG4m7J4Q1RW]b[InGThR1gn3Ogn3Ng=kL5]gNg1koool>i]CF0^KDe@0kh=3B
i]CFgl[;TiRHZHR6V7Qe455:JDe7I4Q1FT0jHdU4J4Y4@D12KU5;H44jBB0X?RLR>28O=0@0=24M=R4N
=20H<QhL<QlL;1PH9Q@E:1LG:APH;1TJ:1LG81`K:ATH9AHG81XI=R8V?2P[2b8`BS8eCCDg@BX]?2PY
?RPW?b8Q?RTW?2HR@RPRA2/WBBl[@28ZECH^J4<k2Ta2W6iT`I:9cXB2i]OIimKGi]CFi]CE01GVe=HX
oooo000Voooo4=gNg00ig<3Hg=kL`L;0`L30Y::PP8J00000@514A400100P@T08G51:@4Q0K61PH4=0
@000>3@^<24Z920P:2<P<20Z82`X:R4P824T000041DH41DG600282@X6@01820Q924P620T82PP:2he
:30d0000<S10@4A40@00<c@d<3@`>30`>3<d<30P030P@3/`A3XT0B00E`0UHeQ:00<0R820`<C1`<30
g=gJg=kI01OMg]`Noooo00?Ve=CVe=KVe=H03NKDeP0ii=3@i]CDh=7B`820bXjSV8:;P084H4]0D0<`
1200B@8bIDQ104A00DQ4HdQ4D30P@2XS0BD0<0@08`0B>2@P>200<1hL81XH810@00820P0081@@;AXL
810B800181`H81HH<000=R<X<2@R2R0P02Xf@CPh02@P?2XQ?2TT@20P@20X?BHT@20PBS0XB30R0200
@30V0410P000T82=d:Zch<S0i];@i]CE00;Ve=@Ei]CF:?ooo`009_oooa3Mg]`0=mgNf=gNg=oPg^;P
h]kOg]3>cXV6PH9kMg=[I5aD@UiHDfIMEV9PA7E/IV]QGE10@4Y2?4Ln>0@f<3/g<D8m=chh=3Td<S<c
<RDU92X[:bLY:RPZ:Rh^<bLY:bPV<34c<RT]<S@e<CTi?SHi?0P313hn@de7AT090Clm>T4l=TD0>DLo
>44j=Da2>59:@UQ<@TU9@GmXG9>0M86@R<g:anOYin3Ph00IgMkL7_oooa3Ve=H0=nKDeNKDe^OFf>WL
`>KEfMW2b820>8m`Jh1OF6Q:@FQ=B71BC71FD7iQG7EGDd84=5@h<54c;4PP84@/94`b;4P/:4<Z9ShX
9`0R83DO7c8N7S000STS9S8N7`8P8C`X9S@R9@4X9D@^<d4]<40X<THb>EHl?4Pb<4Tc;TXa:d0b8U0e
;DX_:eH`8E`o=f=1=V4=08iKCZ=dIY22P=O0_n_PhnS0`002i]CE00?Ve=CVe=KVe=H05>KDeRSoool0
02KooolBgMkL03GNgmc0hMkJf]WAd<n1R82RWI^ET8X1L6UcKFQ`If9ZHF1aJ69[HUi0D4AFCdUDBTA3
B4A;ACm?BD=:@3a7@Ce0@3m10@50?C/k>c/e<38h=cdd=3P0=CXk?C`h>Ci00096@dA1@D922498ADEB
BDE0@PA;AD1?@ca0A01CACa?@SaDB41OEDe[G5@8JFBLSXF/XIV9Q8;?c/_PhMo0`/406MgNg1koool@
i]CF03OVe=CVe=GVeMKXemSSd=?KaLW0PX2`THnUQ7j0J61oHEakG5IcF5IkGEMeEe=RAT5QA3eO?cUJ
03QF>S=J?SQD<35B=S5;=3A0<C1<<Bm8;bm0:2Y4:c50:2a08RA7<C13;S9:<BI@=cY<=SM4=3QA>SaK
?S]E035D>SEH>C5A>39K>c9H>3570SI[BT5iDDN:D4J`OgNnU8_:Vj3J`l?XemWQdM<00^KDeAOVe=HX
oooo000Voooo4mgNg00dg<3Hg=gI`L30`<30aL30XJFRP8R8PPP5LVQVA410ATY3@U18@UQ0H41@H5A6
BTA0B511@51;DT10DD10B492@41:A4=:@T190010@0A420A00010A4I5@419@T10@4Q0@DQ5@4A0D456
DT50@410EDY4B4PlE40h@00XD`@`@000H5Y006M7Q820YJ2Pb/;0`<;0`L72gMgIg<3H6MgNg1koool@
i]CF03SVe=CVe=KVe=CTd=GUdMCRbm70`<;AX:S8R8R0PP20L6UmGUY0@01@@0UQ@T9P@41RBd1Q@45P
@41P@0QPAT10001423QC20Y8041D@Q1:@1=00@11<010<P508P560@1@00i00018@T1E1@5003Q0@3Q3
?3500315@3UP0SA2>31N<B1I>250121aCdB0@5600@39X:78Z;32`<3Rc<kVd]GTd=3Ve=@Hi]CF:?oo
o`009_oooaCMg]`0<mkNg>3Qgn7Ph>GUiMgMfhR8PJNRWI6;R01`J7]cK7adLGAbMWUbKWI/J7QaJWM[
IgE_JFaP@6iTGF=RHVaSHfmVGfQSH5AAD5IAEeM@Ee1;@EMEDe]EFT5DBFEKE5iFDD1BC65GC65?Af1D
B6QID71HCFaMD7]PE7YUF`QPAHZ0Min?RI61P=kOg>GXin;Ph^3Rh=gNg=gNf00IgMkL7_ooo`03i]CE
i]CDi]CE00oVe=H2i]CE03?VeMKYemSX`<3[g>7Ve=C0[H6eUY:OOgb4H6:7J668JVH8J6b3J6B0HEj3
IT61H5b1HeicD4IhFE5/F5UfF5QhG5AbF5IPB45PADiOATiI149QBdQUBe1T@T1^DDYWBdQPB49ZCD1Z
ACaTB@1bCTIjCD9hD426EDV6FTn8B52JLfVbPW_<P8CVe]KZgn;Y`<GXf=[Ve=GVe=@06NKDeRSoool0
02Koool00mgMfmgNf=gNg00BgMkL033Ngmg0`/3NgmkIfMO6`/6j]kB]ZJN1U92KUY2JU9:2Q8R6P7n1
NWZ10Wb5Ng^:Ph40M75oMG1gLG5hHFYdJVE_J6ETA49VGV5UG5eQF55SG5QUG5aPFU1[H5UXGEIXF51Z
GE9XF4iT@59bHeYgI5d4L62CPGNFQh20QHFWXI^e[:S2`8cJf]OOh=o1h<3NgmdKgMkL7_ooo`03i]?D
i]CDi]CE013Ve=H0<^KDeNKDe^OEe^3@dnOEf>??d=20P<R/Z[^NW:R0PZV:Q:R9Qi00PI9eMHa_L8U`
LI5`L9MhMXYXH8]ZIH1WIh1RH7mPFWUMFW1@D71BFFiAEFY=@faACVmBDV9@@7EECg5BCG53B7=CAg9=
@`1BA7eHChAHDH9P@:AdJZMjLj:00;VDS/NOW=B1QNC@d>OGfN3Bf>OEea_Ve=HXoooo000Voooo00?M
f=SMg=SMg]`04]gNg00`g=kLg<3Hg=kLg=cH`<30dM3@`<C0P860XJ2DV96DP820T8B?RH28P860TXR0
U8R@P860P8B0R@P8PW1`L6QUL61R061PLfIXLF10H41DH5a@H5eBJE10K5Y@HUe6H5Q1HEY1JE1504Q@
N6QNNVYVP800S822T8:0P:2P`<K4dLW8`/30g<70g^3Ng<3Lg/3L0]k0gAWMg]`Noooo00?Vd=;Vd=CV
e=D00nKDeP03i]CDi]CFi]CD00[Ve=H0<NKDe>KDe^KDe>K@d>KDeNGBdn30`=C8b=31`<20X<R9R<F1
PX20P8Z0Q9@0P808P8P>QZR4SHX048P:281cM81PHP52FGQMF091@014H050D01@@79@BWAD@610@79@
B7IDAG1@@7I@@6==1010@85LDh14@h002/2DRL::T<28Q=2Y/=33`N30`>GCd>KFf>K@d002i]C@00?V
e=7Ve=KVe=H02>KDeP03i]CDi]CFi]CD00;Ve=H00nKDe>KDe^KDeP04i]CF00?Ve=CVe=KVe=H0:?oo
o`009_ooo`03gM_IgMcHgMgK01?Mg]`01=gNf=gNg=kOgN3Q``;Xj^P0:<31`=_LfMSGeh60P:nZ/:JV
ZjRPX;2Z/Kji^k2XZZnVYJbOWZ2@PiB8QHn5PY>8Q9B9QY:5OH83M8UjLhYkLh1hHXYkLhamLX1hHH]j
KXIgJhP9M9J8OiJ<RjZQS<g8`]GAd=SHf>OWi^SZjL?P`]gMfmgMf]cLfP;MgMX00mcLf]gNg=gNg00G
gMkL7_ooo`06i]7Ci]3Di]?Ei]CEi]CFi]CE1nKDeP03i]CDi]CFi]CF00GVe=H3i]CE02cVeMKYf=W^
h>?^hN?Qd]KUd];QcM30Z;:kWZN_VZF0R:6jWj[7[[BjP::iW9fgU9B/RH6OOG^JNWR407RNOgjMNW:A
LF6DL6RFLFR@K6>EL6RHLVNDH6:GKf>CK628062UO7BUP828P83K_KWPa/WPd=3^gN7[h^GXe=SVdmGV
dmCVd]02i]?D00?Td]3Ve=KVe=H00nKDeP04i]CDi]CFi]CFi]CD2nKDeP03i]CDi]CFi]CF00;Ve=HX
oooo000Voooo00?Mg=[Mg=SMgM/00]gNg003gMkKgMkLgMkL017Mg]`0:=k0g>7Rh>7Rh=WHf=SIe]KF
eL30`;nm_k^k_HB0^/2k_LS3`X2h/Kjg];bc/KBZXZfTXJNPWJRQP:VQWjRNV:2DTZ6ET::FTJ6DP:>H
TJBITJ:GSZ:FSJ2DRZ20TjnTWJnWY82dZLo9`mC>c=3Dd=kLfN3Og=cIdP;KfMH01=SIe]_Ie]_Je][I
e0SMg]`00mgNf=gNg=gNg009gMkL00?Mg]SMg]cMg]`00]gNg1koool01^KBdnK@e>KCeNKDeNKDe^KD
e@OVe=H00nKDe>KDe^KDeP06i]CF02_Ve=CVe=GVe=KPeM3YfM_Yf=[Pa=;RclkPc<k4P<3;/KO4[kK1
Y[C:/;KA^K_8[K38[:c8Z:W0Q82iVINcUIB`T9BdUYJdThjPPHR]RHF_RhF_RX6aSHJbSXJaR8:`RX6_
R7jcR8RnV9:nVY[1X:3L_[_O`lCPb/SXd]?WeMOVd=401NG?c`03i<k>i]CFi]CF00?Ve=H01>KDe>KD
e^KDe^KDe0_Ve=H00nKDe>KDe^KDeP02i]CF:?ooo`009_ooo`03gMcJgMcHgMcJ00;Mg]`00mgMfmgN
g=gNg00AgMkL02_Lg=SL`=[L`=[Lg=SK`=[0`MS0`/C4d<3Bd<;0`<74`/70`L;1b<S0b/S0c<W8`<39
a<32YJG0P:C0Xj70X:2LT9BJT92LTI20PJ2RX:C0XZB0XJ2LX:2PXj30P830`<;1`LK0`<C0a<32a<30
`<3Mg=SLg]WLfMSHf]GIf]CLf]@00]cJe@03f=3@gMkLgMkL00KMg]`00mgLf=gNg=gNg009gMkL00?M
g=SMg]cMg]`00]gNg1koool01^KBe>K@e>KBe>KDeNKDe>KCe0OVe=H00nKDe>KDe^KDeP09i]CF02kV
d=CUd]3Ud]3Td=CUd]3PdM30`<3Db<CHb/G0`<;D`<3P`/30`<3;`L3@`<30P:3@XJW8T:70T871TIG5
T8c0P8S1R8G0P870P8S8S8c8T8_0R8S2R8?8RX;0X:3A[K?@[/30`<3RbL3Pb<cP`L3Ud=;Ve=CVdM7U
d=3Td=3T`=3Td=3Td=7T`<05i]CF00CVe=CVe=KVe=KVd=@;i]CF00?Vd=CVe=KVe=H00^KDeRSoool0
02Koool01]gMf]gLf=gMf]gMfmgNg=gMf`OMg]`00mgLf=gNg=gNg00:gMkL00?MgM_Mg]_Lg]`00]kO
g@0Oh^3Pi^STj>WVh/3EiMoFhmcDh]SDh]cGiMkIh]W@hmgHgMOCfMKBfMG@f]C=el39eL_7e/g8d/39
fM79f=39e/g4e<c5e/c3f=3:h=O@h=OA`M30fLo7f<k6elc500;Fbl<01mK:`]G:`]C:`MC8`=C:`]C:
`M38`005gMkL00CMg=SMg]cMg]cMg=P;gMkL00?Mg=SMg]cMg]`00]gNg1koool03^KCe>K@eNKCe>KC
eNKDe^KCeNKDeNKDe^KDeNKDe^KDe>KDeNKDe^K@e@SVe=H00nKDe>KDeNKDeP03i]CE02_Ve=KVeMKW
eMOXfM[^gmk`h=o/dLK_eLo/dlgXd<3[dm7/eM?ZdM3Zdm;UcLkTc<cRbl[Sb/OPa<CN`L3O`l7P`/?S
al;Ra/7P`83N`KgQ`KcQ`<CYc/[YcL_Xb<7Ta<3S`kkR`[gR`;cQ`;cPP;[P_k_P_kWP_[[P_k[P_kW0
P;P01NKDeP04i]3Di]CFi]CFi]3D0^KDe@05i]CFi]CEi]CFi]CFi]CE00CVe=H01NK@e>KDe^KDeNKD
e>KDeP0Xoooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool0
0?ooool]oooo0032oooo0`0006Ooool00<?oool00`000?ooooooo`1Voooo000hoooo0`0000;oool0
0`000?ooooooo`0200000_ooo`@00009oooo0`0000Coool200000oooo`@00003oooo100000;oool3
00000_ooo`@0000aoooo100000Coool300000oooo`<00003oooo0P0000;oool2000000Goool0003o
ool0003oool00`0000Coool200000oooo`<00004oooo0`0000?oool400001oooo`<00004oooo0P00
00Coool400000_ooo`<00002oooo100002Woool003Woool010000?ooooooo`0000;oool010000?oo
ooooo`0000;oool010000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`00
00?oool00`000?ooooooo`02oooo00@0003oooooool00002oooo00<0003oooooool01?ooo`030000
oooooooo03;oool010000?ooooooo`0000;oool00`000?ooooooo`03oooo00<0003oooooool00ooo
o`040000oooooooo00000_ooo`070000oooo0000oooo0000oooo000000;oool010000?ooooooo`00
00;oool00`000?ooooooo`03oooo00@0003oooooool00005oooo00@0003oooooool00008oooo00@0
003oooooool00002oooo00@0003oooooool00002oooo00@0003oooooool00002oooo00<0003ooooo
ool01?ooo`030000oooooooo02Woool003Woool300000oooo`030000oooo0000008000001Oooo`00
0?ooooooo`000008oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003ooooo
ool00_ooo`040000oooooooo00000_ooo`@00003oooo00<0003oooooool0<_ooo`040000oooooooo
00000_ooo`@00002oooo00<0003oooooool00oooo`040000oooooooo00000_ooo`070000oooo0000
oooo0000oooo000000;oool010000?ooooooo`0000;oool00`000?ooooooo`0300000oooo`@00002
oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00002oooo00@0
003oooooool00002oooo100000?oool00`000?ooooooo`0Yoooo000ioooo00@0003oooooool00002
oooo00<0003oooooool00oooo`<00009oooo0`0000Coool200000oooo`@00003oooo0`0000?oool2
00000oooo`@0000boooo00@0003oooooool00003oooo0P0000Coool300000oooo`800002oooo0`00
0003oooo0000oooo00@00004oooo0P0000?oool400000oooo`800004oooo0`0000Soool300001?oo
o`800004oooo0`0000?oool200000oooo`@0000Yoooo000ioooo00@0003oooooool00002oooo00<0
003oooooool00oooo`040000oooooooo00002Oooo`030000oooooooo017oool00`000?ooooooo`0l
oooo00@0003oooooool0000eoooo00<0003oooooool01oooo`030000oooooooo00_oool00`000?oo
ooooo`0coooo000hoooo100000Coool3000000?oool0000000000P0000[oool300004?ooo`80000m
oooo100003Goool200002Oooo`<0000:oooo0P0003Goool00?ooool]oooo003ooooo;Oooo`00oooo
obgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00oooo
obgoool00?ooool]oooo003ooooo;Oooo`00ooooobgoool00?ooool]oooo003ooooo;Oooo`00oooo
obgoool00?ooool]oooo003ooooo;Oooo`00>Oooo`<0000boooo0`00043oool300005Oooo`80001Q
oooo000loooo00<0003oooooool0<?ooo`030000oooooooo04;oool00`000?ooooooo`0Coooo00<0
003oooooool0Goooo`00;Oooo`<00004oooo0`0000?oool300000oooo`800003oooo1@000003oooo
0000000000800003oooo0P0000[oool300000oooo`800002oooo0P000005oooo0000oooo0000oooo
00<00003oooo100000?oool300000_ooo`<00003oooo0`0000Coool300000oooo`@00008oooo0`00
0008oooo00000000oooo0000oooo0000oooo1@0000;oool300000oooo`<00007oooo100000Goool0
0`000?ooooooo`08oooo0`0000?oool200001?ooo`<00002oooo10000008oooo00000000oooo0000
oooo0000oooo1`0000;oool20000;_ooo`00;_ooo`030000oooooooo00Coool01@000?oooooooooo
o`000002oooo00<0003oooooool02?ooo`050000oooooooooooo0000017oool00`000?ooooooo`03
oooo00@0003oooooool00002oooo00L0003oool0003oool0003oool000000_ooo`050000oooooooo
oooo000000Coool00`000?ooooooo`06oooo00<0003oooooool00oooo`040000oooooooo00001Ooo
o`040000oooooooo00002_ooo`0:0000oooooooooooo0000oooo0000oooo0000oooo100000;oool0
10000?ooooooo`0000;oool00`000?ooooooo`09oooo00@0003oooooool00003oooo00<0003oool0
00002?ooo`030000oooooooo00?oool010000?ooooooo`0000Coool00`000?ooooooo`02oooo00<0
003oooooool00_ooo`060000oooo0000oooo0000oooo100000;oool010000?ooooooo`0002ooool0
02koool00`000?ooooooo`04oooo00D0003oooooooooool000000_ooo`030000oooooooo00Soool0
0`000?ooooooo`02oooo00<0003oooooool03_ooo`030000oooooooo00?oool010000?ooooooo`00
00;oool01`000?ooo`000?ooo`000?ooo`000002oooo00D0003oooooooooool000001?ooo`@00002
oooo0`0000?oool300000oooo`@00002oooo00@0003oooooool0000:oooo00T0003oooooooooool0
003oool0003oool000001?ooo`040000oooooooo00000_ooo`030000oooooooo00@00008oooo00@0
003oooooool00002oooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo
00001?ooo`030000oooooooo00;oool00`000?ooooooo`02oooo00D0003oool0003oool000001?oo
o`040000oooooooo00000_ooo`030000oooooooo02goool002koool200001?ooo`800004oooo1000
00Woool00`000?ooooooo`03oooo00<0003oooooool03Oooo`030000oooooooo00Coool200000_oo
o`<000000oooo`000?ooo`0400000oooo`@00003oooo0P0000?oool400000_ooo`@00003oooo0P00
00Coool300002Oooo`800002oooo0`000003oooo0000oooo00;oool300000oooo`@00002oooo0P00
00Woool300000_ooo`<000000oooo`0000000007oooo00<0003oooooool01?ooo`800004oooo0P00
00?oool4000000Koool000000000003oool00003oooo0`000003oooo000000000080000`oooo000^
oooo00@0003oooooool0000Eoooo00D0003oooooooooool000000_ooo`030000oooooooo00coool0
10000?ooooooo`0003Goool00`000?ooooooo`0Zoooo00<0003oooooool03oooo`040000oooooooo
00003oooo`030000oooooooo047oool002goool500000oooo`030000oooooooo00koool200001?oo
o`80000@oooo0`0003Coool200002_ooo`030000oooooooo01koool200004_ooo`<0000:oooo00<0
003oooooool00oooo`800011oooo003ooooo;Oooo`00ooooobgoool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {399, 0}} -> {-0.248143, -0.0762067, \
0.00834879, 0.00834879}, {{29.6875, 143.75}, {389.813, 275.75}} -> {-52.2641, \
-15.5184, 1.3407, 1.3407}, {{155.188, 269.25}, {389.813, 275.75}} -> \
{-220.522, -15.5184, 1.3407, 1.3407}, {{29.6875, 143.75}, {264.375, 150.313}} -> \
{-52.2641, -183.693, 1.3407, 1.3407}, {{155.188, 269.25}, {264.375, 150.313}} -> \
{-220.522, -183.693, 1.3407, 1.3407}, {{29.6875, 143.75}, {138.875, 24.8125}} -> \
{-52.2641, -351.951, 1.3407, 1.3407}, {{155.188, 269.25}, {138.875, 24.8125}} -> \
{-220.522, -351.951, 1.3407, 1.3407}}],

Cell[BoxData[
    InterpretationBox[\(3233\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ 3233, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4.4 Dynamic image processing",
  FontFamily->"Times New Roman"]], "Section"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4.4.1 Three-dimensional image sample",
  FontFamily->"Times New Roman",
  FontSize->12]], "Subsection"],

Cell[TextData[{
  "\t",
  StyleBox[
  "Previous sections have carried out the two-dimensional wavelet image \
compressions. In this section, we carry out the three-dimensional wavelet \
image expansions.\n",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["\t",
    FormatType->InputForm],
  StyleBox[
  "At the beginning, we have to set up the sample images. A 64 by 64 \
resolution color image is employed as a sample image. This sample image data \
is read in the ",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " front-end by a following code. After reading in the sample image data, we \
compute its resolution.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
sample=rgbBMP[\"AF038-64.bmp\"];
dim=Dimensions[sample];\
\>", "Input"],

Cell[TextData[{
  "\t",
  StyleBox[
  "By means of the inner product in vector fields, we wok out the 8 shadowed \
lighting images. Figure 13 shows the shadowed lighting images. After removing \
the graphics image data, it is revealed that about 3.4 mega bytes are \
required to store the 8 shadowed lighting images.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
rotation=8;
color3D=colorImage3D[sample,rotation];\
\>", "Input"],

Cell["\<\
color3DG=Table[Show[convertRGB[color3D[[i]]],
\tPlotLabel->StringForm[\"``deg.\",360*(i-1)/rotation],
\tAspectRatio->dim[[2]]/dim[[3]],DisplayFunction->Identity],
\t{i,rotation}];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[
\tTable[Table[color3DG[[i+j]],{j,0,3}],{i,1,rotation,4}]],
\tImageSize->{400,200},PlotLabel->\"Fig.13. 3D color images\"];
Remove[\"color3DG\"];memoryUsed\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .48837 
%%ImageSize: 400 200 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0116279 0.238095 [
[.5 .50087 -71 0 ]
[.5 .50087 71 12.5625 ]
[ 0 0 0 0 ]
[ 1 .48837 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50087 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.813 moveto
(.13) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
117.000 12.813 moveto
(D) show
129.000 12.813 moveto
(color) show
165.000 12.813 moveto
(images) show
201.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .48837 L
0 .48837 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0116279 0.245293 0.233112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(180) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7D7E78
76695C7C6D607C6D657C71687C6D657C71697C71697C71697C71687C6D647D6D5F78695B
796455745C4F755B4E6F584B6F584B6F584B6F584B6F574A7054456B54446B54456B5444
654C3F7C7E7E7C7E7E7C7E7E7C7E7E7C7F7E7C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7A797C79797C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E81837E
7C6D657C6D607C6D607C71687C6D657C71697C6D60786555736555736154745C516A584C
6A584B6A55486B54476A55486F584B6F584B6F54476F544770544A6B54476B54456B655C
65605B7C7E7E7C7E7E7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C83827C7A797C79797C83827C7E7E7C7E7E7C7A797C79797C7A797C79797C7E7E
7C7E7E7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E787A75
7669587C6D657C69617C71697C6D657C69617869606B655C645C546F544C6F51486F594C
6F60526F6052745F516B54476651446651446654476654436B54446B54476B544A7C6A61
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7F7E7C79797C7E7E7C7E7E7C7E7E7C83827C7E7E7C83827C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E817E78
7C69617C6D657C6D657C69617C6D657C6D6081716892766D82766A81706784635B7A584B
7A554C7A554F754F4A7050476B54476B54476B54476B544A6F584B70574A6B5447654C3F
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C837E
7C6D5C7C6D5C7C6D607C6D657C6D657C6D697C71697C766D8176707876637D6C627D685E
7D6857795F527E685A7F594F744C47745854705B4F6F54476F51447054476F5C4F6B5548
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7F7A
7C6D607C6D657C6D607C6D607C6D657C71697C6D657C69617C7169817670817A6B7D7162
78645B7D685A745C4F7A6355755F516F5141745C546B5B4F6654476B5447736561766A65
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E6F5C546B5B55
7C6D657C6D607C6D607C6D607C71697C6D657C71697C766D7C71697C71687C6D69817167
816D5B7D64577D6457795F527A584E75574A6B4D3F6B54476F5447705447675A51767474
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7A79
7C75757C79797C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E463A3242473F76695C
7C6D607C6D697C6D697C6D657C6D657C71687C695C7C6D607C6D657C6D657C6D607C7164
78685E786057785C5479604E6F57476F584B74574A7054476A5C4F745F51705A4D7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C8382
7C83827C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E6B65693F231F161A227C6D64
7C71647C71687C71697C71687C69617C71697C76717C6D657C6D607C60587855516F5146
735C4D7860547464546F5B51745B4E75584B6B57456B5444664D42665144654C3F7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C83827C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E8082823D2B1E7E725F7669587C6D65
7C69617C6D657C69617C6D657C6D657C69617C6D657C7168786960736858786057796052
6F594C6F594C745948755B4B6A54476F514474544A7454477054476F584B674638766A65
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7A797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E2F20187C71698176707C6D647C6D60
7C6D657C6D657C6D607C6D607C6D657C71697C6D657C6D657D4E4D783C3C743637743335
74333574433F6F51476F51446F4F436B50406A54446F54477054436A4C3E613C2E654C3F
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7A79
7C79797C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E6B6565C4B3B27669657C6D657C6D647C6D60
7C6D657C695C7C65587C65557C695D7C69617C605C7C55557D5A5574433A6F362C6E3B35
6F3E366E3332713C3966463E6654436B4F436A50446F544774544A6F5345745448603828
6B51437C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C8382
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E352923151D1C7669587C6D5C7C6D607C6D60
7C6D6078695B735C517664597C6D607C6558784F446F362F6A493F5E3D2E615C4C6E6D5B
713E33612A216F322C703C376B4A446B533C66503B6A54446F54476F584A6F51446F5548
6B4B3C7C746F7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E5B4F4F95726260524A7C6D6578655B7668617C7168
7C655B795C4B6A4C3E6B4543743B393C0E092F2A24745A507E595198A09D844E4767362D
5A513A55574848382A4E282067332D664C3C6F4C3E6F544874604E755B4A6F584B6F5447
603C2E6B4B3C7C746F7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7A797C79797C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E433630363F3F7669617C6D607D685A765B517C6D65
7C6D627952416B4436390F0B353837B4D0C887979487ABAD81979E7C767682A08E929C94
9EA2A57A7471583E352420143120196240386A5343745549745C527A63517557476F5447
6F5548604E4D67636D7674747C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E6F6D75452A2510191F7669587C6D60817A6B7C6D607C6D65
745B4F684D38562E1F54190E3F120F6D393073493D76544A7C6D5C7C6451795B526D4E48
74584B926D5DA6877092766837291F2D1C195D3C33695143786554796458755F516F5245
6F4D426B4D35595146564E516B6A747C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E463A32160D08634B43604E4A7C6D607C65587C5D517C65557C6D5C
7E685789675E949883C5C5A7877F747D5C5A74584F6A3F376D3C3C6A36376A3932651E18
6628245B302A704D3F75423B82554B311209311C1C694A42735C4D7964517557476B584A
6A584B74514387756B7A717165606A7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E6F696D2318121B130F2234367C6D647C695C7C645F78645F76695C7C605C
7E6259674434654A427C716D7C7F70817F7487887D87877C81907A887B67837F6B7F8165
7F745C754C407948437A3830742C206E251938140F4725266D5147796051755B4A704F43
6A4D426F51453119103830207871717674747C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7F8388F2CDBDEFB191735C4E76695C7C6D5F7C766081645F7C605C7C7A64
7E6F5E7F5F5267483D7660557C71697C71687C69617C71697C64637D605A786054796055
745B4E715B48615C466B654D7A6C588E766083665D624638644D3D745C4E755B4A705845
6A54446F5548624B4122201D6B6A657C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E8D7F677C6D65817F797D7167736558766D607C6D657C7A6D7C716D7C716D
8275697F6A596A463B674B3F76685C7C766D7C71687C6D657C7F6B7D6C5D745447745545
6B5743634F435E4B3A634136634536634436674B366A554B6E594C74584E7152456B4C43
6650406651423D261E1F232A716F797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7876757676737865546F513F6659556B65637C69617C71697C766D7C71697C766D
816C6A8268617F6152734D44765B517C6D657C645F78585176695C796758745F516B443A
6B4A41704A3C67483A674E3E6B4F3C6C513A6747366A4A3D7455486F54477053456B4F43
6B50476F584B2B1A18000703605A577C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E8176677C6D657963586F584E7D5C4676605C7C605D7C6D657C71697C71697C7169
7C7F6B8171627E6B576F51417153497C6D657C7F7081716D7C6D698270697963587A6555
74544770504167443A67483C664C457452487E5F54745C4F6F574A6F544774584A705345
6B50406651423F22190B0A0A1713127C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7F7A7869586C503C6D584A7C605C7C6D607C6D607C6D657C76717C76707C7169
7C716D7C766B7E6B5E7463516D58467665597C6D607C71647C71687D7162745B4D6F5447
6B544770594B70563F6C4A3866493E6F584F7860577960527563556F5F516B574A6B584A
6B544A6F5C4FB9784F6632211207051714137C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C6D6574544A662F287046405C4C476572607C6D607C6D607C6D657C6C617C71697C7169
7C71687869607D71627D72677C6D607C6D5C786058765B517C605879584E7556456B4C40
67483C664C385F43365E44386A51456E5C4C735C5079605275584B6F5447745447705443
6F4F406F5146795F559C6F5ACAB0A47C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C70717E545075493F6B463F78584A7669617C716D7C71687C6D657C71697C71697C6D65
7C6D607D6D5F7C695B7D65587669617C716D817F747C6D697C715F7E645871594A674B3E
63473A5A423A6C4E416F5B4E745C4F746054736054796052755B4E6F574A6F4F47744C4A
6B4F456A514A6C503F66493B69483C8183827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7169
7C7A677E6C5771563F6A4D3F705B517C6D607C6D657C766D7C6D657C6961786558766958
7C605C7D5C58736054785C517665597C695C7C6D607C6D657C68677E574F7553456C4E41
6C4E416852456657466A55456E594C785C50745C4F74584B75584B6F52456F4F406B4F40
6B54436A5547795F5570544753392E6560617C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E746759
5E3E3143302442342C5A49407160557C6D607C69617C69617C6D607C69587D695C735C54
6F6051735C5478695F786D5F7669587C6D657C6D657C6D65787663796A597556486C4E41
674B3E704C406B50476F554C74594F6F594C746054746355755B4E6F5F516B5B4C6B5345
6B4C476A514A6742306A463A70412F653C307C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E796455
3E231436241E2C1F1D2A2A2D7160597C6D657C6D607C6D5C7C6D657C716D81716D817A70
826C6574584F6A4A426D554A73615576695D7C6D657C6D607D645B745B4F6C4A4567483D
63473862493E6F54486A54446A51456E554C6F4D446A51456B54476651446B54476B5345
6B4F44664A3F6859405A3C2B664A3E653C357C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7671847C77
955946462A1F3925202A2A2D7160517869587669617C6D646F5C4C604D3F553F32483328
4D3C33543E3B65464265463C694D447160557C6D657C6D697D6C627A5E5270543C674736
684B3C5E483C5A463B564C405D4D426559496B5B4C6A5548745B4E70574A6B54476B5345
6B4F446B50475A382C401F174B30226037267C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E786D62796355
2A0F0A180F0D1E18151524287361557C695C7C69587C6D608875656C5648574638352E2A
1D1C1B1B1C142E251E43241B3B17124728217665597C6D657D71627A615270524163523C
5F4634614D42795C4E7E5F5174574A6B4942634C436151456F584B70574A634F435A4F43
6254446B54476E48365A3325542E26602D217C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E80828287817A795948
6B3E332A1813291713151D237C6D60786D5F76695C7C6D6081766C8D71629874696C483A
301C16241813222221423D33745E4F6D584E766D607C7A757D7A717A655567493C5A3B30
3D140B311C1A563C2A4F382A3C2D2343392D634C405D4D3E6651426B54476C4F41634C40
624C4463483E54372C4B362B58443C693E368183827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C75757C79797C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E27100B0A10157A6052
7346352E1F221C141205141C7365587C6D6078695C73655876695D887E71746452A67660
B984689B6649814E34705B466F584873554A7664587C6C617D6D627A61527A533F684638
764E3A4738353230330B06071517172A25211F19141C1E1E382C214B3627684C3E634F43
624F405E4638412D212D231D3D3C3469493C8183827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7A797C79797C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E2D19142B1B1606030209080A
1F14181C141027191410191F78695C76696174524D65433D6B574D81767187837C8E7770
7F5E52846659846557795C4E7864547860547664587C71697D6C657A675B705A486C563C
75583F835742955E482F1B181B16112F1F1D3124203229215A4036615143704F3E684C40
625443462B2531211A2F1F172A1E1A5A281C7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E543129342119331F181F1816
160D0C2517142D191415181E7C65587865558788787F6F6252382B432A21423026352C24
2C221E281E1831251C37231C4737306D60557665597C695C7D6C5A7A605270574A6C4438
634F3A62503B755E4DCD8A6BA2735B7E4D387E4835714E4175563F634C3E665746755847
634F45482F202919142F1E182F231B541E137C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E5C392921100B18130F1C130F
2516111A14102824201924276B5C51816D607C6D608D7F789E938383665A664D4B755952
8C5E4C7F5A4A705141795E4F7861557C6D657C6D657C60607D655E7A645570534D4E2E25
3C1F1943322862503B6B5440795B4A8868537A63506657466353486B4F47634C45625040
5E4636281B15181410433E365B3929491E137C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E6848392F140E2414101C1410
0F08081C120F281F1C202627574C447665597C6D607C7169817A75929689AE9E8D929689
9D9E959D9A91A3A3998D8B7E7D6D5F766D60786D5F73725C78695B7F685A847761987D68
623E3829191816121021201E5343396B5445755843634F43674B3E5744366149416B4C45
462A202B18122B211D1F231E532D1F1D08041C19187C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E55453F2E221D241612221410
1D120D1E1410281F1C2D2D2B5D4C437665597C6D607C6D657C71697C76717C7B797C7B79
7C76707C76717C76707C767181766B7C69588171647D695B7860547D65587D695B887065
A78978AB796B80544831241D16120F191717272221322921382B215C433C6B4F43674B3E
3D221B241511211616120C0A21130E3E2621221E1C7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E684D45442F2A2419141F1410
2415112519192A211F272B28473E376B5B517C6D5C7C695D7C6D657C6C617C71687C7671
7C7B797C76717C76707C71697C76717C71687C6D607D6D5E78695B786054786054786458
7F64577A6B58926F5A99735D8C6651654936623D2D684A3C7A5C4D5E47405F4943574A3D
3F241C2415111B140F15110C1817142F2421221E1C7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E63443431201732201A241612
25100C2917122D1D1627221E36322E62504776695C7C6D607C6D657C76717C71697C7168
7C76717C76717C76707C71697C6D607C6D657C69607D645778605478695B786054786051
795C4F7A584B7A5B4E795B4C8463548D6C5A88685875594B754F47705645704B3E543427
381F182415112B19142116121C1410241913120A065A51527C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E553E2F3529252E201B2C1B16
19120D1B130F1B120F241B1625201947382F7665597C6D607C6D657C71687C7B797C7169
7C71687C71697C71697C71697C71687C6D5C78695B78695B786054785C51786054786054
7960526F5B4E6F584B7460526B574A6F54477054476353455A4F405A4F43534638332721
19120D21181717101117100C0F07071A12111E1A184437357C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E68473834241F3629242D201B
301C17241511291D192C26242D2A282E2D2B6B544A7C695D7C69617C685D7C71687C7B79
7C76717C76707C71697C71697C716D78696078695B7860547860547860547460546F5C4F
745C4F755B4E6F584B6F5548745B4E6B574A6B54476C53456B4F436C4B3E50362C341D17
301F1A150C0C1710101008081810101B13102123223832307C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E5C4D47382B27382B27382A25
2D1C171A110C211612311F184730244230255D44397665557C6D607C69617C685D7C7168
7C76717C7B797C76707C71697C71688171687D6D5E7464576F5C4F73595079594F74584B
74554C75584E6F584B6F54476B51446B5447674B3E704C4063473A4E38303E281F301C16
18100B191110140C0C19110C1810102518144F51527C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7A7978717155413A2F2420332824342722
2417122D1E1A291E19251E1C322B24483C335A453D7160557C6D607C71697C71697C7168
7C76717C76717C76707C7169786D5F7665587D64577D60547D645774604F745C4F745B4E
6F5C4C6F5B4E6B4F476650476B54476B5447705648634F435B483A5E3F2F3F281C2D1B15
2116121D15101F161119110C1C14102318140B05048183827C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C8382818887523E3537241B34241F352925
3D2D282D1F1A2D211D312119302F2A38332A47362E67504776695D7C69617C6D657C6C61
7C6C617C6C617C6D6578655878655873655878685A745C4B6F5949745C4B745C4C746052
75584B6F584B745B4A7054476B4F436B4C40634F435B473A533D2F3925212C1A161C1410
18100C171010130B0C0B0708100A0B2C211F1C0F0E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E6B4E4731231A352822352925
2F231E2B1A152F1E173125212F2823332620322A265D473F7669587C6D5C7C695D7C695C
7C69587C69587C6D608171687D6D5E785C5174584B74554B74554C745952745C4F745447
7555486F54476F54477054476B5345674B3E5F4438533A2D3925213121192416111E1410
2215111A1110150C0C160C0C2919146972728183827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E796A623D2E2A2F2420372824
38241A31241E271D192D221F271D1A292624292A253F2F266250437365587669587C6D60
7C6D6078695C73655576695C7D685A74584B745C4B6F57476A55456A55486E55486F574A
6F51446F4F476B50476B5443674F3E634B3E5F4638452D2436231921141018100C171010
1E14101A1110110808130B0B1F16130600007C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E6F605341322B382B272F2521
312724271A1A271C19291E1A352925312119241C1727252344362E644A406D554A735D51
73615578695C786558735D517464576F5B4D6A4D446F54476F4C406F4D426A51446F5447
6B4F43664F4067483C5F453C57473A4B382C4B322638251A2114101C141019110C140C0B
110B0B0B07070B0808251814311D141709047C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7EA49EAA593F3B382925342722
392E293D281C2D1A143326222D211D332927271E1A1E201E21221E2925214C3831614A3F
604A4465514D65554C69584D6B544757433649382E543C2E62493B664C4066443866463B
6B4F3A674B3963473A5F40345A4034493128341E182C191424151119100C140C0C140C0C
1008080C0808140C0C19120F626D717674747C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E98A29A72625333251F2F2420
2D221F29231F251B1A281C16342520372C283F302B2D22202F28262C2A262B231C322A27
2928242D281F3E302842362C40332C4332283C2C21382F23422F234D36285944325A3E30
4B342C4A312652372C4B38303F2A243921192D191422141018100C140C0C1008080B0707
0B08080C08081A1410271914110E0E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E8E8691483632352925
342B27362824201712221D1A372C28392E2940342F46383345392F3F382F35322B312621
311F19291E1C2A1C193324203426222C242436262136231A30231C352923382D243C2C21
4332263C2C20362A233C261F37241C291A15271D191A120D18100C150C0C1108080C0808
0C0808211410191010474240493C3A7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7EA3A3A3634842342521
3124203125213D2B26382B27372C283D322D35292531262231211F3C231D3C221A31241F
251D1A28221F211814211C1B2D242029201C1F17141D18171D16131A12101F1814241C16
221B152316132012101F15122116131C1410150F0B140C0C130B0C140C0C0C08080C0808
2114192114123627214955577C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E878D879D9898483631
3125213529253427223B302C2F231E2F26232F231E3026223F342B352D282F2724312521
31241F3728242C1D1C231D1A2518142717132114101A130F1C14102318142517141E1310
1B120F1C14102318142114101E141019100C18100C150C0C140C0C0C08080C0808140C0C
231A162C1B16706F6F7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E989397613E38
3A2925352925342722231D19372E293D322D3A302B2B211D2C1F192B1C17291E1A2B201B
21191D1E1C1A261B192717142114191A14111B141018100C1A141018141018141017100C
120B0B150F0B1B130F18100C120B0B17100C181010150C0C0C0808140C0C1F15112C1F1A
2919147C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E8D979180736C
3D2D283328243427223A2B272F28242E26222F211D291D19211A18211410271D19251919
2619181F13101F1417161011120B0B160F10171010140C0C160F10130B0C160F10140C0C
1810101C1411171010140C0C0C08080A07070A07070A070718101019110C130B0B190E0A
6D6D6C7674747C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7EBFCACB
87736C3728222F24202F2824312925372E29382A2A2D1B17291C181F16121B120E1B140F
1E140F140C0C110B0A171010191111140C0C171010150C0C171010150C0C2717140E0908
150F0F1B14101911100C08080C08081008081910101C12121810102919153D251A624433
49372A7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
BFCACB8A6E673F322C2D211D372A26392E293E312B3028222D231E27171B1810121F1410
1810101D15111F1611191110140C0C140C0C130B0B140C0C130B0B1C1410151010332D36
37333627191E160C0D1A11112016122017121911102D211D32211B291A153F2A246B6F74
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7EC6D6D78A6C644C39332D211D2A252138302C46353038251B302019211712171010
140C0C160F0B171010140C0C140C0C181010150C0C181010150C0C120B0B2B2828291D22
3B2C2C5140364833314937313B29232117122B1E19271B183529254B30267675757C7979
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E767979BFCFD079594A4E3A333C2D28382E2A40342F463A3632231D2E1F1A3A2A24
3629222718131F15101A1211191111140C0C140C0C1B14171A12121D1511140D0C211D17
261F1C150E0E14100D130F0C140E0E1F1410251A173121194B32247E76756B6A6F7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7EC5D9DF7665573527202C231F4036324D433F51423C32231D211717
2717143627223227211D1312140C0C21191D251C212B231E271D20382B2925191D352C2C
382A293F2D283D2B263727213D2B25493A303D2D26533D31827F7E8D928C7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7EC5CFD5C8BEC6624F4A3026222F24213B383C564B49604D45
5C534C3D2E2E312B2D4B434D66585546332F352A3134272B493D433A2F2E3F2D25322825
3E2D273E27223E251D3D2B2545342B573A2D4E2D205A656A7C83827C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E929C96D1D9DA7C6A71463836352E2E404247514B4D
49413F564D455E514D54463D493A3646373046362C382A28271C162D221F392E29352925
3F29214D2F2550362D5C3F344B2D2443383B9EA2AA7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C75757C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7EC5CFC7D1D9DACDC3C263586553484E
75677478666E624B4551413C4D413C624E4D664E4B6550486D564F604B3F54463F65514A
53493F464238392D28504D55AEBBC6B4C5C17C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E878D87C5CABDAEBBB8
9DA69A9EA3ADA9AFBCA69EAC6A61744A4A584641434A3E3A433C384D413F463A36392E26
3F322A767574D6DEDF98A6A07C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E878D827C8382929C91BAC0B3BAC0B3BFCACBBFC3C5BFC5C7BFCACBC5CFD0CAD9DF
CAD4DA7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0116279 0.488926 0.233112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(225) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D807D78
79685C7F6C607F6C647F70687F6C647F70687F70687F70687F70687F6C63806C5F7B685B
7C6355765B4F785B4D72574B72574B72574B72574B7256497353456E53446E53456E5344
664A3D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F78787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7B7B7F7A7A7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D82807C
7C6A607F6C5F7F6C627F70687F6C647F70687F6E637D6A5D7B6A5D7B665B7C6356755F52
755D4F72574B7356496F554972574B72574B7255487255487353486E53456E53456E5C50
66544C7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7F7F7F79797F7A7A7F7F7F7F7A7A7F7D7D7F7B7B7F7A7A7F7B7B7F7A7A7F7D7D
7F7D7D7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7D7B76
7C6A5B7F6C647F6A607F70687F6C647F6C647D6C6378685D706156765C5278594D755B4F
725D50725B4F755B4D6E53466E53466E53466E55486E53447053456E53466E534872594C
726E6B7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F78787F7D7D7F7D7D7F7D7D7F7F7F7F7A7A7F7F7F7F7A7A7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D827D78
7C685E7F6C627F6C647F6A627F6E667F6C61826E66886E64776C627C675D7F5D5576574B
76574D76574F75534B7353486E53466E53466E53466E53486F55487055486E5346664A3D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F807C
7F6A5B7F6C5F7F6C627F6C647F6C647F6C667F6E647F706882706A7B6E5F80655E7B6156
7B5F52795B507B60557A534B724F4672564E70564B6F53466F51457355486F584C694F42
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7E7A
7F6C5F7F6C627F6C5F7F6C627F6C647F6E667F6C647F6C647F706882706A7F71637D685C
7B61577D635776594F7C605375574C725044755B536E564B6E53467053466F5B54725E55
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7A6A63756C67
7F6C627F6C5F7F6C617F6C607F6E667F6C647F70687F70687F6E667F70687F6C66826E62
7F68597D61567D6155795C507A574D75564970504270564B6F5346705346685349796E6C
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7B7B
7F79797F7A7A7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D5E4D4360615B726158
7F6C607F6C667F6C647F6C627F6C647F70687F6A607F6E647F6E667F6E667F6C617F6E63
7D675C7D61567B5D537C5F4F75564975574B7555487053466C584C75594C6C51447C7878
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F
7F7D7D7F7A7A7F7D7D7F7D7D
7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7870724E2A241E272B7C6A60
7F6E617F6E667F6E667F6E667F6A627F70687F706A7F6C627F6E637F655D7D5F58795D50
7B63557B5F55796153785B51765B4C7555497056467053456B50446E5548694C3F7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7F7F7F79797F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D807E7E4F3527756A62413E3A7F6C64
7F6A607F6E667F6A627F6E667F6C647F6A627F6E667F70687D6A617B695B7D5F587C5F52
74594D765B4F795B4C785C4E6F55487553467555497253457053466F5549684B3F7C7270
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7B7B7F7D7D7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D482F248279744A49467C6A607F6C60
7F6C647F6C647F6C617F6C627F6C647F6E667F6C647F6E668058537B4E4879454279443F
76423E764E467555497555467252457051426F53457253467353446C4F416B493B6F5951
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7B7B
7F7A7A7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D787070A798974442407F6E667F6C637F6C60
7F6C647F6A5F7F685D7F68597F6A607F6A627F67617F5F5B805E5779453D783B32733E39
753F38733A3876463F6E4B416E5344704F426C51447253467553486F5244755246674537
75665F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F
7F7A7A7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D48342D3B403E796A5F7F6C5F7F6C617F6C60
7F6C617D6A5E7B61557C655A7F6A5E7F685C7D584F79453D7852496F3E316D5045705448
763C326B312775393270413A6E4C446E523D6B4F3E6F5345725346725548725044725549
6C4E427F78757F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D6F60609072643437367C6A607D685C7C69607F6E64
7F685E7F635275554672524B7C4C45571A0F56453C79524A7B4E4885747074433B6F4539
6B503C63483D5B35286030276C3D356B4F3E6F4D3D6F544673594B755648725549725346
69493C755F557F78757F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7B7B7F7A7A7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D533E37414647695A527F6C5F80695D795F547F6E66
7F6C62805745734C3C5218125B4B49988582594E4D7F7E7B7C6D6E7C6663838A7D856863
8473706F5D555E3C323823164F2A2166453C6C504073524773594F7A5F4D755546725548
725448695149746B6E7C78787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7A75794E2D270E1D2479685A7F6C618273657C655A7F6C64
7C615477543D6634245E1C0F3A1A186C4E467B5D537C645C7F73697F6C617F665C755A51
7C6458886C62896E6072554C39251B48282166473A6D5043786052795F53785C4D725245
725044705140675D5B6A61627572787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D5E4D43341E186D57523130327C6A5D7F685B7F64577F685A7F6C5F
826759825D537B6E5D917767594C457B5450795B50744C4478524F784D4677493E6F322A
733F386A433A7B5648744840754E45361209482B276A4C43755B4D7C6352785849705749
6F5448755245786A6173686569636E7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7A73742E1D152617120F23276C5A547F6A5D7F675F7D645B7C665A7F655D
8265597149396C51487C6C647F7568826E688270687F6E667C73658463587B675A796151
79574972453C764D45763C3372322665251A3917125936337156497C6152785A49735044
6C504472544849291D59534B71696E7C78787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D838082B69A947763563937347C6A607F6C5F7F6E5D82615D7C635C7F7361
82665B7D5A4D65473C7C665C7F70687F6E667F6A627F70687F676380655B7B5F537C5F53
765B4C7658476B55447355467655487855466948415938306A5042795D4F785A49735545
6C514472544865473D25221F75706E7C78787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D887E70756C6C82756C7D685D7866597C6C5F7F6A607F73667F67647F6E66
8370637C62536F4A3E71574B7C69607F726A7F6E667F6C647F776980655B79584B79594B
7358466F5245674E3C6A463A6A4B3A6A483A6C4C3A6A4E486D544576594D765546704F44
6B51416E51444729212227256C66697F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7D79797C79767D6859795D4E76645E72665F7C685E7F6E647F70687F6E667F726A
826B6680655B7C5C4D714E447961567F6E667F69627D61597C6C617F6859795E5073493D
735145714C3D674B3C6A4C3D6B4B3B6C4E3A6A4637684B3D7355497556497654466E4F42
6E4F456F55482F1B180A13116963677F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D8279707C716C7F6659785D507B5B496F615F7F635C7F6C647F70687F70687F7068
7F776982685E7F655374514476584E7F6C647F776C8267647C6A62836D63795F537B5D4F
724E42714F416A453A6A493B684B427250427355496E5245755649755548755548705044
6E4F416B51444222191613133836347F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7E7A7D6A5B79584572594D755C547C6A5D7F655E7F6C647F726C7F736C7F7068
7F706A7F7065826759765F4D7255477C685E7F6E637F6E647F6E66806E627A5C4F755649
7053467355486E4F3C6C4839684A3E6E544A74574E795B4F785F5272594C705548705548
6E51466F584A9963454A281D2116124745447F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F75707C645A7642387853496349406F6C5D7F655D7F6C607F6C647F6E647F736C7F7068
7F70687D6A61806E607B665B7963567C6A5B7D655C7C63587F675F7F61557B5A4A704F42
6F4C3F6B4F3C6846396748396A4D426D5649755A507C5F5278594C725649755548705344
6F50426F5247785C4F835C497F61584747477F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7574825B5379493E6E423B7152486F665E7F6E667F6E647F6C647F70687F70687F6E66
7F6E63806C617C685B7D645879685E7F6E6682756A7C65607F6E5E8261587658496F4C3F
6A493C63453B6F4E3E6750456E5247735C50755D517C5F52785B4D725649725046754F48
6E50446F50487152406B4B3E664438827F7F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7772
7F7B6F826456774F3D6C473D6C564D7C6A5E7F6C647F726A7F6C647F6C647D6A5F7C6C5F
7F655F80645B7863567D605479665A7F6A607F6E647F6C647F6964825C507955476F4E41
6C4C3F684D416650416A504370584C785C50765D50795B4E78594C725346725042704F42
7051446C5246775C516E4E416043397570707F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7C7064
7150426040305D3F345F483E6F5A507F6C607F6A627F6C647F6E637F6A5D806A5F786157
7965567B5D577B665B7B66597966587F6C647F6C627F6C647D70637F64587954466F4E41
6A4B3E6E4B40684F456E544973584D74594D795F53765F5278594C725B4D705548705044
6E4D456C52486F47356F4A3F704837664C477F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D80695A
522B1A4D2E253B25203C3432735F567F6C627F6C617F6C5F7F6C647F6E66826C647F7166
80655E765B5075544B745E527864587C6A5E7F6C647F6C6180675E7A5F52744E466C4B3D
68483A664A3E6F52466C534572544973574D75534872574B7356496E53467055486E5245
6E4F446B4C426F5640623D2D6E4F43663A307F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7977857974
884E3C42271C3F272125292C735F527D6A5D7C6A627F6C617A6353725B4F6D5143654B3E
684F456A4B456F4E466C4E4273584D7663587F6C647F6C66806B607D5D5274523E6A4639
6A4B3B62483B654A3E6550446850446C584A73584C6F544875594C7055486E53466E5245
6E4F446E4F46653D2F522A1C5A3B2C63382C7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7D746C7F695E
37120C281611281B17172429755F547F6A5D7C685A7F6C61877061725749654C3D48362F
3627223B291D4B342C5B3124562A1F5D433A7C685E7F6C64806E627D5F52745141684F3B
664535634C4172544772574B6C53466E4D446D524667524672574B7356496A5044655044
6851446E5146704635593124522F266030227F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D807E7E857E787D5C4C
6A3A312615112817130B1B227C685C7B6A5D7C685C7F6C5F82706688695B7D6157634134
331D172B1B153127234F3C3164493E5C413B79675B7F726C80736A7D62536F4B3D634133
4D1A0E472F29634533614435563A2C5B45386A4D42614E406E53457055486F4F42654D41
634D446A4C40603A2F52362A563C34633228827F7F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F79797F7A7A7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D3D19124544417F6153
7241322E1D201F141105151C7866597F6C5F7B685B7B685B7C6A5E87756A735D4F966959
7E5E4D6347375A3B2C53493D624B3F7153497965597F6E648070677D625379513E664437
6E4533442E2A47363216090935251F3B2D2637241A3E312C523A2A5D42326D4F41654D41
634F4168483B4E30233B2620463B33663F358582817F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F79797F78787F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D43251E3F261F16060338211B
311B1E24161227181502151C7B685B79685E7D5C52725449725F5482706A82756C846960
78584C7A5D507255486A5043715C4D785B507963577F7068806D657D65587455446D4F3A
6C4E3A6E493A7751422B18161C1611382420362620332A22553E3558473A6F4B3B684D41
6351425330283E261C35201831272163382C827F7F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D593129322018301B16231714
1B0E0D2617142918140B181E7C66597B665885796E7A5F5563443663463A61493C584137
4F332A4A30245036295434285F493D745F547963587F6C61806D5E7D5F537457496C4638
654F3A664C3A7358499E69545B493F5B3B2D5F3C2F4B3D3560483763483C6B5544705144
654F445030212E1A1632201831251C5923187F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D60382924110C1E1510211410
2616111A13102B221E162125725F54826A5D7C6A5E88756E89776A73554B684B45685048
6F4E4163473D5F4437644C41634A4275635A7C6A607F656180685E7D615374534B5C3427
522B2054403168513E6E5342755748785A496A50425E4A3D684F446E4F42654D44685141
68493A301E161E151131322D4C30234D1B117F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D6C47382E130D2313101D1410
1208081F1310271F1C222A2A6353497C665A7F6C607F6E6682726C887E728E756A6F6C66
85756E7F6E6682756C72655C775F5479695D7D6C617B6E5F7D645B7F65587C6958846256
5B362F39201B32211846352C604A3E705345735542654F426C4E3F5F483A684B44684D44
533023321B14281F1B1B231E5D31213419134A4A497F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D5D453E31211B241511221410
1C120C1C130F291F1C2A2E2C5D4D447963587F6C607F6C647F70687F726C7F75707F7570
7F736C7F726C7F736C7F726C8270657C685A8270657D685B7B63567D64577B645781675C
8E6E607B574F61413834241C301E163F2A2345332B4E372A4E372A63473E634B406C4C40
46231C2816112316161D0F0C3919114628231819187F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D6C4C453E2B27231712211410
2315112317172A201D2B2D2953453C725F547F6C5D7F6A607F6E667F6E647F726C7F7570
7F77747F726C7F75707F70687F726C7F6E637F6C5F806C5E7B66597B5F537B62567B6457
7F6156786355835F5077584A664B3D4E3A2D56372B544237654B40554139684B44644B3D
46241C2515111D141019110D2016133624201B1B1A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D69443535221933201B221511
25110C2817132C1D172E2622433B3468554B7C6A5D7F6C607F6C647F726C7F70687F726C
7F75707F75707F75707F70687F6E637F6E667F6A5F8067597B62567B66597B5F537B6153
7C5D527A5B4E785B4D76574975594C765A4C6E5346634B406E4B426B52446F493F5D3A2B
3E211A2515112918142015111D1310291B15201E1B6C66677F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D5D3E2F3828232F1F1A2C1A15
1B110C1F130F2013102C1F18332A2157453C79665A7F6C607F6C647F6F677F77747F7068
7F726C7F736C7F736C7F70687F70677F6C5D7D6A5E7D685B7B5F537B5F537B61557B5F53
7C5F52755B4D75574B755B4F6E55487255487053466A5245654F41654F4461483A412A23
21140E2518171911111B110C1108081F151227231F4D42427F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D6C463734241E3627232C1E1A
2E1A16211410281B172B2321342A263A352E725B517F6A5E7F6A627F6B627F726C7F7774
7F726C7F75707F70687F70687F706A7D6A5F7D6A5C7B61557B61557B5F53795F53765D50
795D50785B4D72574B725549755B4D6E55487053466F5245684F426A4C3F593B303B1F19
2F1E1A160C0C1A11111108081910101B120F2724233B33307F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D634C45392924372925362723
2C1A161C110C24161331201A402F263E342A654D437C66587F6C627F6A627F6B627F726C
7F75707F77747F736C7F70687F7068826E657D6A5C796456765D50785B517C5B50765B4E
76574D78594D72574B7255487053467055486C4E40704F4265493C5E3F354C2D22351D17
1B110C1C1211150C0C19110C18100F2317142226275956557F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7B7B7D77775D433C322521352824352722
2717132C1C18261B17281E1B362C244A3B325F463C7661567F6C607F6E667F6E667F6F67
7F75707F75707F75707F70687D6E627C685D8067597D61557B6155765D4F795B50765B4D
75594C75594D7052486E53487053466E5346705446684D4166493B63403143281D301B15
2216111D14101E151119100C1C1410221713000000827F7F7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F827F7F573D3536241C342420372925
3929242A1C182D201C302018312D2944352B533F366F574D7C6A5E7F6A627F6E667F6E64
7F70687F70687F716A7D6A5F7D6A5E7866597D6759795D4E765B4D795D4E765B4D765D50
78574B72594C7558497051466E50446E4F426A504466493C5D4133462A24361D18201611
1B110C191010150C0C0D0808130B0B29201D0C0707827F7F7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D6D4D4531221A382722352824
31231E2D1A162F1F173124203328233D2B2340342C654C4479685A7F6C5F7F6A607F6C61
7F6C5F7F6C5F7F6E64826E657D6A5C7B6053795E5079594E76574C765950765B4D765649
78574B7255487255487353466E52456C4C3F68483B5D4032462B253C251B281712201511
2115111A1110160C0C160C0C221613232F32504A497F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7B655E3B2A2631241F382824
37241B30221D291C1830231E2C201C322925352D26503B316F5B4F7B685B7C6A5B7F6C61
7F6C5F7D6A5D7B68597C6A6080695B795D4F795D4E75564872554872554B73574B75584B
7551457252487051467053446C4F406A4C3F6646394F31263F261B2616121C120C191010
1F14101B1110120808140B0B1F1513000000827F7F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D75605443312B372925312521
352723291A192A1C192A1F1B3528243121192E211B3C312A58443970584C755E527B6457
7B66597D6A5D7B66597862567C6759785B4E725146755648724F427251456F5346755548
7050446E50426F4A3F684B3F644B3C5A3D3058392B41281D2816122016111B110C150C0B
140B0C0D08080C08082116132A1A130904027F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D988C93503732382925352722
382B2739251B2B19153125212E211C3529262B1E192C2521392E264B382E61493F705548
6F564D725B53725D52735D51765A4C684C3D5F42366445366B4D406E4D416E493C6E4B40
70503D6C4C3D6A493C66443761443752352A41241A351C162616111B110C160C0C150C0C
1108080D0808140B0B19120F353B3D443D3B7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D8E8F8B6D574C35241F322521
3024202E241F281A192B1D16352621352A263C2C282D221F362B27382E27422E244F3A34
4837304E3A2E5842385A45395A4137583B2E4C33264C362856372A5F4031644837664134
5D3C315D3B2C5F3E32583C334E302745261C351B162716111B110C160C0C1108080C0808
0C08080C080819130F2317130004047C78787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D8A7C8344302B342723
342925352722211712261D1B362A25382B273F322D40332E3E332B3E352D3E322A3E2A23
3C261E3625213D261F463027432D273B2A27422A2240271C4029204830274C3528513426
52372A492F224830274A2C2240281F311B162D1D181D120D1A110C160C0C1108080D0808
0C08081D1310181010313231251E1D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D9690905C403C342521
342521322622392824302622352A263D312C382A263729253825224028213F271E362721
2C1E1A30231F2A19162F211E3627222F221D2919152A1C182A1914291713312018342219
312018311A152E18132C19152C191522161119100C170D0C150C0C150C0C0D08080C0808
1D13161D131030231E182629635C5A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D8584818F8183412E29
322521352824342622392E2A31231E35292633241F3427233D3129382A26362722352520
31231E3326222C1C1B271D1A2A19152B19152416111E1410211511271814291714231511
2114102215112818142415112114101C110C19110C160C0C150C0C0C08080C0808140B0B
1F18152A19153435354747477F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D91888A5C3A35
38282435282435272229201B3B2E2A392E2A3A2D292D211C32231C311F192E211C2E211C
251A1D251E1B2B1B1A2817142316191E14111E15111A110C1B14101B14101D14101B110C
150C0C18100C1E13101B110C150C0C19100C191010160C0C0C0808150C0C1B1310241B17
251713414242413F3F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D8889877A6561
3B29243528243527223829252F272334282433241F2C1E1A271C18261611291E1A271919
281918211411221518191111160C0C191011191010160C0C181010150C0C181010160C0C
1910101B1310181010160C0C0D08080C07080C08070C080818101017100C140B0B1C0F0B
3C3E3D3E3A3B7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7DA4A3A4
6D5953352520322521312724342925372C283728272D1A162A1C182016111E130F1F1511
211410170C0C150C0B191011191111150C0C181010160C0C180F10160C0C2416130E0808
160F0F1B13101A11100D08080C08081008081810101910101710102617143120183E3129
1F16107C78787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
A4A3A46F554F392C272F221D362A27382C283E2F2A3025202D201C26161A191111211410
1911101E15111D1410191010150C0C150C0C140B0B150C0C140B0B1C141016101030272D
2A272923161A170C0C1A11111C14101C1410181010281E1B2B1D192618143827213E3D3D
60544E7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7DA6A8A96F534D42322D2E211C3127233A302B42312C34231A2F1F19201611181010
160C0C18100C191010160C0C150C0C181010150C0C181010150C0C140B0B282423261B20
372C2D4337313A2929372A2730221E201611281C17251A173427233E2A223E3D3D564A47
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7C7A7AA7A8A965473C47352F382925372D2A40332E42353131201B2D1E19312420
2D221E2215111E14101A1111191010150C0C150C0C1B13161A11111C1410160E0E27201B
2A201F1C12121E15111B13101B1211231511251A163020183C2D23534E4C4A3F3F7F7A7A
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7DA7ABAE624D42372620312622413531483D394A3A342F1F1B251817
2B19153225212D221D1C1211150C0C20171B21181C261E1B241A1D2F252322171A2C2626
3427263A29243124212F221D322520372E2734262140332B4A4744665C537570737F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7DA7A6A9897C7D4D3C38342723392B27413A3B4D403D493B36
463D3A3627263129293F373B463D3C3527262F252B2F23263D34373328283B2A242C2523
3F2C273B26223B251D3929243D2F2746342B482B20343A3D6056507F7A7A7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D8B8C89A19B9F624F53413330382F2E403F444E4444
493E3B50453F4C403E443B364639384635303F312B3527282C1F1A342724392C28352824
3E2A22462D254831294E362E432B234437377366644D47447F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F79797F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7DA7A6A285828782777451475052474B
60565C61535656454050413D4E3F3B56454452413E55433D52423F4B3B33463A3552423E
483C354639313F2C27484141787275726D6960595A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D858481A19B9872757A
75726E827E877F7B827E70745E51594C454B4E4041503F3B483C3951403D483A3542332B
48372F53514E8884825C5E5A6F686B7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D85847F79777D8B8984958F8E7F7D7D8282897F7B7B7F7A7A7F7D7D827F7F828284
7F7A7A5354507F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0116279 0.732558 0.233112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(270) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E817E76
7B6B5D806F61806F65807368806F65807369807369807369807368806F64816F5F7C6A5B
7C6555785E4F785D4E735A4B735A4B735A4B735A4B7358497355456F55456F55456F5545
6C534380807E80807E80807E80807E80807E807C7980807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807F78
7B6B5D806F60806F65807368806F65807369807367817266817266816E61816D5D7C6858
7C6353785D4E785B4C735A4B735A4B735A4B7358497358497355476F55456F55456F5848
6C534380807E80807E80807E80807E80807E807C7980807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E807C7A80807E80807E807C7980807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E817E76
806F60806F65806F61807369806F65807368817266806E5F7C695A7C67587C6353786152
735E4F735B4C735A4B6F55477358497358497358497355457355476F55476F55476C533F
6C655E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E807C7980807E80807E80807E80807E807C7980807E807C7980807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807E76
7B6B5D806F61806F65806F65807368806F64806F657B6B5D6E675C776256785B4F735A4B
735D4F735D4F735A4C7358496F55476F55476F55476F55476F57466F55476F55476C5343
80807E80807E80807E80807E80807E80807E80807E807C7980807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807F78
806B5D806F64806F65806F65806F65806F65806F61806F65806F657C6B5C81625B775F50
775B4E785A4F775B507351476F54476F574B6F55476F55476F55477358496F574A6C5343
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807F78
806F60806F61806F60806F65806F65806F65806F65807368807369806F657B6B5D7C6358
7C62557C6254785B4F7C6052735348735247735E546F55477355477355476E574B715B4C
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E817972807F78
806F61806F60806F64806F61806F65806F65807369806F65806F65807368806F65806F5F
7B67587C62577C6254785D4F785A4E735849735547735B4F6F55476F55476E55477B6E67
80807E80807E80807E80807E80807E80807E80807E80807E807C7980807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E6D5E52817E76715F56
806F61806F65806F61806F61806F65807368806F64807369807368807368806F64806F64
81695B8166577C61547C615178584C785A4B7355476F55476F574A7357486C53437B7775
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
807C79807C7980807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E807D7B512F27403F397B6B5D
806F61806F65806F65806F65806F65807369806F65806F61807367806D63816D60816B5B
816D5D7C62577C62547C5D51785D4B7357487358487355476F5547735B4C71574880807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E807C7A80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E7F807D573D2E6E6766221F22806F65
806F61807368806F65807368806F65806F65807369807368816F63816D5E81625A7C6152
785E4F7C61527C61517860517358497858497358496F55456F55476F57486E574B80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E573D2E85847F2728237B6B5D806F61
806F65806F65806F64806F65806F65806F65806F658073688163597C60547C554C7C554A
785347785D4E785B4C785B497357487355457355477355477355456F54457358497B6E67
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E807D7A817F7B272823807368806F64806F61
806F65806F63806F63806F5F806F65806F65807066806D638163597C49417C413778443E
78423A78443E7853457354457355457351436F55457355477355476F54437353466F5748
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
807C7980807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E513D356E67637B6F67806F64806F64806F61
806F64816E6181695A806B5D806B5D806E6181635981554B815C547B4134784A41734038
783A3173382E78423A6F483E6F52456F543F6F5243735547735547735547735245735A4B
715A4D80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E7B716F7E71642228297B6B5D816E5E806F61806F61
806E61816B597C604F7B6256815D506925158163557C4D45774A42715149653B30735545
75503F6E3C3469332773382E6F4A3E6F54416F513E6F5746735748735547735748735547
735A4B80787180807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E57433C5A5452635348806F60816D607B675A807368
806E61815D4978554364201880635D7744403B151077584E774D437B5E5581766C774038
694B3F624A3C5F3A2F4927176E35296B4F406F513E735447735B4C785E4B735547735849
735748735B4B81787180807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E817F7E4B2F272B2E2E7B6B5D806F64806F607B6356806F65
8168597E5B42713A285F1E114529266E665D817269807871807B758077728170667C6B5D
8170637B6F6867584F4F3A333B22186737296F5443735446775F51785E4F785D4B735445
735547735C4F736D707C777580807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E6D5E524B2F277263601D1F227B6B5D806E5E806E5E806F60806F64
81685978574A644C3B5D332D3B231D7750487C60527C5D5281686081655681594A78473B
7C5549785B4C80604F6F504560493E3B1309673E336E5446775F4E7C6553785B4C735849
73534673574A6C665B6B635D716E7580807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E817E7C3121182E1C151D1F20634F48806F5F806D5F816759806759806D5F
816A5977503E775F527B6B5D806F6180635D7B5F56775B52775B527C514B72544B73463E
7340386F42397353476F42366A392B57261A411D156F4C42775F4E7C6553785B49735445
6F5547735A4B593829807C7A6E676D80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E807C7980807E80807E80807E80807E80807E
80807E80807E817F7E716B6A0D1F20171E21806F64806F5F806B5D80625C7B6B5D806F60
816158785748694D3F806F65807369806F65806F65807369806D63816D5D7C62547C6152
785D4B7858487351437849406F4239623A30522E2856312973574A7C6151785B49735545
6F52457357485D44393B2F29807C797B777580807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E807F78716F73806F617C63567C6B5C806F60806B5D806F6180635D806F61
816E5E785D4E7351437C6759806F65807369806F65806F6580736781625A7C5E4F7C6151
785B4A7757486F523F6F4E3F6F523F6F4E3F6F4F3F6B4D466E5441785D4E785A48735445
6F5543735547462C233B362B6C655E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E81807E807F78816E5E816B5B8071687B6B5C7B6B5D806F61806F65806F65807369
806D637C66577858497254487B6B5D807369807066816F63807367816B5B7C6051785041
785B496F503F674F3F6B4D3C6B4B3A6B4D3A6B48386A5040735A4B785B4C7857486F5143
6F52456F57462D1B182D2A2777727980807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E807F787B7773816B5B7C6353775F4F6C6663806B5D806F65807369807369807369
80736780635B7C61517855477B6356806F6580736880635D7B6B5D816D5E785E4F785849
6F4C3F6F50416B483A6B4D3C6B4E406F513E6A50406A4D3E7858497858497355476F5143
6F52436F55473B2119271F1C68615B80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E807F78816F5F7F604C775F52715B4F7B6B5D80635D806F65807369807369807369
807368806F60816555785E4B77584C806F65807367806F65806F65816E617C5E51785B4C
7355477354456B4B3A6B483A6B4E406E5347725448785B4C785E4F735748735547735547
6F52456F57476E503B2F211A332621807C7980807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
807F7A8174688055467C62516B4D3E7B6B5D80635D806F61806F65807369807870807369
807368816F63816E5E775F52775F4F7B6B5D816D61806F60807066816B5B7C604F735445
7352436F54416E4B3C6F4E3A6B4D406E5447775B507C6152785D4E735B4C7358496F5545
6F54456F574A735A4A674B393B201627201B80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
807B76816356784B3E6F433A6E54486C675D806F61806F61806F65807369807369807368
807367816F637B6A5B7C67597B6B5D806F61806F617B635A806E5E816158785A48734F41
6E4E3F6B4B3C6F4F3C614A3E6A4D41735B4E775F507C6152785D4E735849735447735447
6F54437354487355426F51436B4B3C80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807B
807E76815E54774B3C6F463E6C574C7B6B5D806F65807369806F65807368817266807367
806D63816E5E7C695A8167587B6B5D806F64807368806F65806D63816251785A4A6F4F41
6B4D3E674B3E674C3E6B5043735B4C775F507861527C6051785D4E735748735445735145
7352456F5448735A4D6B4C3D6F544885858280807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E81796B
7F6251734F3B744B3B6A4D3F715B4F806F61806F65807368807367806F63816F637C695B
816D5D81625B7C67597C63567B6759806F65806F61806F65816F638160567854456F4F41
6B4D3E6B4E406752456E5747735B4C785E4F7C6254785E4F785A4B735A4B735245735143
6F51456F5748734D387354476F50416C656380807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E816E5C
5C331E5F392C472C245C463C776356806F61806F64806F64806F65806F61806B5D7B6B5D
7C62587860527C60537C6A5B7C6B5C806F61806F65806F64816D617C65547753486F4F3F
6B4B3C6B4E406F53466F5547785A4E785D4F785B4C786051785B4C7358497358496F5445
6F51456F52477255416B42327355476C453680807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807D81776F
7044323B251B422922373130776356816F63806F65806F60816B5B816B5E7E63537E6353
7E63567B584F78584C7358497C66577B6B5D806F65806F65816D5E7C5E517352416B483C
6B4D3C674A3C6E5143725748735547735B4C78584C735748735A4B6F55476F55476F5445
6F51456F52476942306335226B49366C453A80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E817D74817066
3C140D341C15311F19342F2F776356806F5F7B6B5D806F64816E5E725A4A6E5342563E34
4B322A5A36266944396E3E2C6E3E2C776355806F65806F65816E617C5E517352416B4E3A
6A4736674F426B50436653466652456F5447725A4A6F5748735A4B7358496E54456E5445
6F52456F52476B453456302256332768402D80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E7F807D807D747C604F
5C372E22130F2918142126277B67597C6B5C806B5D806F60806F617C6353645448523A2E
321F19331F17422F275E3E2F593A3056352E7B675A806F65816F637C6251714E3E6A4936
5620116246386E503B7050406A47357252436E51456752437358497358496E5243675143
6751456E5243643E305A37295A392F66342580807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E4B211885776B816555
643C2F2A1C1E2215102522247C6B5C806F607C6B5C816F5F806F61816F63735B4C7C5E51
443D35312C25392E25403D375C433872584B7B6B5D80736981756B7C655473503E624436
603D2C452923563C321E0C0B5433274C372C4B2E216146396948326F503E6E5445674E40
6751436B4B3E533225492C225940356B423785858280807E80807E80807E80807E80807E
80807E80807E80807E80807E
807C7A807C7980807E807C7980807E80807E80807E80807E512F274B2F27280804643A2C
3C2224291913271916171E217C6B5C7B6B5D8165567C67567B6B5D806F657B6B5D775F51
6F55476F574861493A604A3B6E5848775C4E7B675A8073698170647C65557352416B4B38
6246365A403557463C221615231812402A243828213B2D23533F345643346B4A3A675143
67524357342B452C1F3B231946332971534385858280807E80807E80807E80807E80807E
80807E80807E80807E80807E
807C79807C7980807E80807E80807E80807E80807E80807E512F27311F182D1914291814
1E0F0E2718152718142124257B6B5C7C6B5C806F6573544A7150407E63537B6251735548
6A43356742306C47356E4534785E4C7C63567B675A8073678170637C61557358476B4B38
67513A6B4C3C6F5547674C3F1F26263B2C2441332A31312C51403262483C6F55436B4F42
6751434F3122311C17372219402A1F68372880807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E57362726120D231712261611
2416121B13102F221E2C28287B6759806B5D7B6B5D806F65725F5262483D644B405E4B3F
5241364B39314F3A2E544035563D34715F527B6B5D806D63816E5E7C615273554A643A2A
64392767513A6F55436F55456F5547674F405B42375A43376B4E406F513F6751436F5543
6B4E3E3120182317122F2C27412A1F5D291B80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E6043352B120D2214101D1510
13090822151029211C373430725F51806B5D806F61806F65806F657B6B5D6C524B544A47
6C524B634A3F634E435D473E72584C7B6B5D816F63816F6381635B7C6657735F506B4C45
502E2647291E4B2F206C4B396F55457355456F55436751436F5241654E3F6F5147675143
573526331D16251E1A292721633524492C2480807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E807C7980807E80807E80807E80807E57433C311F19231410221510
1A110C1D130F2B211C37342F6454487B6759806F61806F65807369807369807369807369
807369807369807369807369806F607B6B5D8073677C6A5B7C695A7C6758776355776255
6F574B4D3A3541312937251C472A1E623E305F45366745326143326B4E425E4B3E6F4F43
45251D2A18122518172A130E4F1F14492D252C241F80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E604942372924211612221510
2215102217162B211C3B332C6650447B6759806F60806F65807369807369807871807871
807871807369807870807369807369806F60806F60816E5E7C67587C62547C67587C6658
7C6257735E526F524752423941342B3B2F254B352A473E34524034523E346E51456C4E3F
43241C2416111E15101C120D2A17133E262131292480807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E60433537241B31201B201510
25110C2718142D1F193A2E265A493D725F52806F60806F61806F65807369807369807871
807871807871807870807369807367807368806F5F816D5D7C67587C67587C62547C6657
7C6155786051735D4E6F55476653465E4C3F564338564237674B3F6751436B4A415F402F
3E231B2416112718141D15101F14102F1F183F393580807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E573D2E3929232E1E192A1A15
1B110C23141024161137251C4837296E584B7B6B5D806F61806F65807369807871807369
807871807870807870807369807367806F60816E61816A5B7C62547C66577C66577C6254
7C6152785D4E785A4B735B4C6F55477358496F55476E54456E51436E51456B4B3C482E25
25160E2819181B11101D120D1309082718143B312A63575580807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E60433533251F3527222A1D19
2A19141F1410271B172D231F3F2E255443357B6759806F61806F65807369807871807871
807369807870807369807369807368816F5F816E5E7C66577C66577C62547C62547C6152
7C6152785D4E735A4B735A4B735D4E6F55477355476E5445675143674F415C40323C221A
2C1E19160C0C1C12121208081911101D130F352B274F403A80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E5C4942392923352924332621
2A1A151D120D27181432231C3E3128463C30725C4E806B5D806F65806F65807369807871
807871807871807369807369807368806F647C6A5B7C66577C61527C61547C6152786051
785D4F785D4E735A4B7358497358497358496F52436F5445674E3F674639533225361F18
1D120D1D1212150C0C19110C170F0F241714130D09453B3680807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E81807E57433C352722372A25352722
2718132A1C18241A162D1F1B412F25523E326A4D3F7B6759806F61806F65806F65807369
807871807871807870807369817266806F63816D5D7C6657776254785E4F7C5E52785D4E
785B4C785A4E7357497358497355476F55476F54456B4E406C4B3C63423241291E311C16
2116111C14101C141018100C1C1410241714190E0980807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E807C794F3A3337261E332621372A25
332621271B172D211C2F2119372F2952392C664C3F776356806F61806F65807369807369
80787080787080776F8172668171647C6B5C81695A7C61517C61527C6151785E4F785E4F
785A4B735D4E7358496F52476F54456F54456E54456C4E3F6346364E30273B2019231712
1D120D1A1110160D0C0E0908160C0C2B211C1D120D85858280807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E604942312219392923352924
32241F2E1C172F2119312520382C2347302657413472584C7B6B5D806F64806F65807367
807367807367807368806F647C6A5B7C66577C67567C6051785D4C785E4F785E4C785B4C
785D4E7358497358497355476F54456F4F416C4E3F6346364E312843291D2A1813211611
201510191110160C0C150C0C1F151200000031201B80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E6D5E5737272233251F392A25
35241B2E221D2A1C1833251F30231E3B2D27483329674C3E7C6B5C816F5F806F60806F64
806F60816F5F816F5F806F64816D5D7C63537C6151785849785A4B785A4E785D4E785B4C
7855477357497355477355456F52436E4F4168493A54352843291D2A18131F130D1B1110
2015101B1110120808150C0C2216131D120D85858280807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E6D5E5240302B352924332621
3727222B1B192C1E192D211C35292431221939271F563F326F55457C68587C6A5B816E5E
816F5F816F5F7C6A5B7C6A5B816D5D7C5E4F785849785B49735445735849735849785849
735445735445734F436E52436C503F664434614131452C1F2D19132317121B110C160C0C
160C0C0E09080D08082015122519131D120D80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E807B7A423029372A25352722
372B2633231A2919153126212E221D372A252E1E193D2E25523A2E6C4B3B785D4E7C6251
7C65577C685A7C68587C66577C6251745544714E3E73503E735445735143735041735445
7354416F4F416E4E3F6A493A64493A56392C49291D391F182717121B110C160D0C160C0C
1108080D0808130C0B1B130F21191427160D80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E5C4B4334241F352722
3326213125202B1B192F1F18352722342A25372A252F231F3E30294633295A3B2C674A40
62483B6C4D3C7055477055456D4F41674534593A2B5F402E6942316E4B396F4E3C6E4738
6B46366C463269473761423659372B4C2C1F391E172A17121D120D170D0C1208080D0808
0D08080D080819130F221613130D097B777580807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E7971723B2C25332723
3329243326212117122B1F1C372A23372B263D312C3B2F2A3A2F293F332C453329472F27
452D23422D264F3025563C2F4E352C4730294C2F24492D1F4F30245A392B5D3D2C623C2B
5D3D2E54332556372B543226472D22361E17311E191E120D1B110C160C0C1108080D0808
0C08081B130F160F0F2929261D120D80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E81807E4C3834332621
3527223327223326212A231F342A253D312C392C273B2D283E2A25442F25402C21392A24
31201B372620311C173B27213D2A2434241F311D1734201A341D16381D1741281C41281C
3F271B3D1F18391E17361F18341D172518121D120D190E0D160C0C160C0C0D08080D0808
1B13151B130F2B211C09090954453F80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E746B6C372722
332621352924332621382E2932241F3B2E29362721372A253C2F283929243B2721372620
30231E3226212B1C1A2A1F1B2E1C172E1C172617122116112416122A19142C1914271712
2717122717122C19142616112416111D120D1A110C160C0C150C0C0D08080D0808130C0B
1F1815271815130D0927201B80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E817E7C4E3530
3529243529243527222E231E3E302B362C27372C272E221D39271F34231C32241F30231E
271C1E2C221D2D1D1B2919152417192116112116111B110C1D15101E15102116111D120D
170D0C1B110C2215101D120D170D0C1B110C191110160C0C0D0808150C0C19130F1F1815
2216131D16121D120D80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E675753
372621372A253527223529242F2723392C273627212E201B2C1E192A18122D211C291B19
291B192216122417191C1212190D0D1B11121A1110160D0C191110160D0C1A1110160D0C
1911101B1310191110170D0C0D08080D08080D08080D0808181010160F0B150C0C20110C
211D191D120D80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
4D403A30231E352722332924352A25372D283527252C1B162A1D19211612221510221712
231612180D0D170D0C1B1112191110150C0C191110160C0C181010160C0C2216130D0808
1810101C14101A11100D08080D0808100808160F0F160F0F160F0F241714271D16242420
1309047B777580807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E4D3E3831272330231E372D28372D283B2E292E231F2D1F1B2416191A1110221510
1A11101E15101B1310181010160C0C160C0C150C0C160C0C150C0C1C14101810102D2425
201E1D1F1417160D0C19111019130F19130F170F0F251D1A241A17241714352620271B12
4F372880807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807D4D3B36372D282E221D372C273D312C3B2E292F22192C1E191E1512191110
170D0C19110C1A1110160D0C160C0C181010150C0C181010150C0C150C0C272321241A1F
362F2F362F2C2B212127211F251D1A1D1510251B17241A1733272334261F1D161140291F
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E8585824B372E3D312C332723382F2A40332D3D312C2E1E192A1D1929211C
241D1A1E13101C1410191110181010150C0C160C0C1B13161911101B13101810102C2420
2F2322221615261A15231813211514261712251B172F2119352B2335312B3B241B807C79
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E49372E362721372A2543373243393440332D2A1D19281A19
2E1C172F2520271E1A1A1110160C0C1F171A1E1618221C1820181C28211F1D1517292422
2F2523332621271F1C271E1A29211C2924212B211C342C25271F154A322471696C80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E494238362C27372A2542332E453E3C433732352C28
322B292F2220302926332D2C292725251E1D2922272B2223332D2C2D24233527222B2423
3E2D2837262237261E352924372C253B31293E2A2027201B4F3728807C7980807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E6C65674337353B2F2A3931304441424A3F3C
493D3849403A3B333238343243393A42352F382E2A31262830231F392C2A392D28352924
3F2C24402D25402E264131293C2A22483A344F372831201680807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E40373A3B362D3D393D534A48
4F4A484C45414B423C4D423F4D403A4B3F3C4138334439343B3331372F293B322E413833
3D332D46332B422C254A3C334A372D3B241B4F403F80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
807C79807C7980807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E777275403B43
544948655F64594F4E5649424E43414E434153423F53423C4D403A53423C493B3449382F
4F3D3440393040372D31241F685B5E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E777279807C796C656C4A454C4A454C453E38453B36453B36453B36403731
3B2E243B3228807C7980807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0116279 0.97619 0.233112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(315) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
928278928278928278928278928278928278928278928278928278928278928278928278
9282789282789282789282789282789282789282789282789282789282789282788D6C58
92705C92706092756492706092756492756492756492756492706092705C8D6C588D6854
895F4C895F4C835B48835B48835B48835B48835B488357447F57407F57447F57407F5744
928278928278928278928278928278927E75928278928278928278928278928278928278
928278928278928278928278
92827892817792857B92827892817792857B928278928278928278928278928278928278
92827892827892827892817792857B9282789282789282789282789282789282788F6E5A
8F6E5B92705C92756792706092756492756492736191746494746494705D8F6D588C6954
8D624E8A5F4C845B47865D4A835B48835B488359468359467F57427F57427F57407F5D4E
927566928278928278928278928278927F75927F75928278928278928278928278928278
928278928278928278928278
928278927F75927E7592857B927F75927F7592827892817792857B92817792857B928278
928278928278928278927F75927F75928278928278928278928278928278928278916F5A
95736192706092736092756492706092766591715D8A6D5A956B548F6654896650876450
835D4A835A488156447F5744845B47845B478459468457428157467F57447F5742856E60
856E6392827892827892827892827892827892817792857B928278928278928278928278
928278928278928278928278
928278928278927E75928278928278928278928278927F75927F75927F75927F75928278
9282789282789282789282789282789282789282789282789282789282789282788F6C58
8F705E92705E92706092736392736392705F8F6E5E8268567E614F89594D7F5844825B48
825F4E825F4C8058467F5B467F57447F57447F57447F57428159447C54427F5744928278
928278928278928278928278928278928278927F75927F75928278928278928278928278
928278928278928278928278
928278928278927F75927F75928278928278928278928278928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278926E5A
926E5C92706192706392706092706092705E92725F926F5F8F6B598D64538D5C50875C48
875A4A86564A87594A7A4C3F7E56447E5D4A7C523F8157448159467F5946815A488F7B72
928278928278928278928278928278928278928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
92827892827892827892827892827892827892827892827892827892827892827892705C
92705C92705E92705C9270639270609272629270609276659275648F6B598C65538A5D4E
8D60508A5E4C895D4C88584A805143835648815F507F523F8457448157448765558C7566
92827892827892827892827892827892827892827892817792857B928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
9282789282789282789282789282789282789282789282789282789282788C72659C8774
92705E92705C92705F927060927262927060927564926F5F92726292706092705E8F6A53
8C63528A60508A614E86594A855B48805744815B49815B498157447C57448D7368927B6F
928278928278928278928278928278928278928278927F75927F75928278928278928177
92847A92857B928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
9282789282789282789282789282789282789282789282789282786B5546B0907C8C6857
92706092705E92705B92705E92756492706092736192776A92736392736392705F926E5C
9164529166508D6150895F4A875747875B488154427C5744835A488154438C786F8F7B72
928278928278928278928278928278928278928278928278928278928278928278927F75
927B72927F75928278928278
92827892827892817792857B928278928278928278928278928278928278928278928278
9282789282789282789282789282789282789282789282788A787141221AA3846D8F6E57
927262926E5E927262926E5E927363927564926F5D92705E927361926B5F91725B927059
946D5B8D63528C6150895B48895B46805946815742815746815B47845D4995857B928278
928278928278928278928278928278928278928278928278928278928278928278928278
928278928278928278928278
928278928278927F75927E7592857B928278928278928278928278928278928278928278
9282789282789282789282789282789282789282789483794B2F2380645D573B36927060
927360927363927363927363927060927363927767927060916F5A946658916352895F4C
8C614E8F64508C644E835D4C875946875B478159447E57427C57448159468D796F958F88
928278928278928278928278928278928278928278928278928278928278928278928278
928278928278928278928278
928278928278928177928278927F75928278928278928278928278928278928278928278
92827892827892827892827892827892827892827853362795807455382C8F6E57927060
92706092706092705F9270639270609272629270609273638D5B4D8D65548C5A4A8C5C4A
895A48896B51875D47875D478356438159438657468357447F57428356458768569C9591
928278928278928278928278928278928278928278928278928278928278928278928177
92857B928278928278928278
928278928278927F75927F75928278928278928278928278928278928278928278928278
9282789282789282789282789282789282788A786F654E435B403492736392705C927060
927060926F5D92715F92715F927366927363926D5F9272628D54488C493C893F348C4A42
8742378C5043815844845A4584574281524083594483574481574281523F815946896D5C
9C9F9E928278928278928278928278928278928278928278928278928278928278927F75
927F75928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
928278928278928278928278928278928278473028BD9A8692736692706192705F927060
92705F916B59946B5695735E926E5E926D5B915B52925A4B8F5E52853B2C8F5144893B34
813127873D30874A3D7C51407F5B447F5239815745865746835744835442835644835D4A
927F75928882928278928278928278928278928278928278928278928278928278928278
928278928278928278928278
92827892827892827892827892817792857B928278928278928278928278928278928278
9282789282789282789282789282787E6962685243644F448F6E5B916D56957764926E5B
926D588C69518C5E4C9975638F5C4B6A2513B67F6B8C443A8753467842357333257F5E48
7F4534823A33753022923E317D5B4781563B815440815B46855844805242835946835744
8C6D5A9C958E928882928278928278928278928278928278928278928278928278928278
928278928278928278928278
92827892827892817792857B927F75927F75928278928278928278928278928278928278
9282789282789282789282789282784730299D7763825F4F92705C8D6655927665927363
92685487553E8454416C2018A982746B1B135E1E138644368945348F67568A51447F392F
6B3521653D2D5B2D20592716974532815F4583503D855D4A855D48855A44805444835946
835B488C766D9A867395887E928278928278928278928278928278928278928278928278
928278928278928278928278
928278928278927F75927F75928278928278928278928278928278928278928278928278
9282789282789282789282788C7C76361E1694745F92705F92705F8F68558F6859927060
8F5F4B8253377F372655180D85594D8A7F6D947A6D958F8592796D927C728C695A948271
8F6B5982706857382F452921451D1395493287604A8C5F4A8A6352865A46835944835240
835B47817068877574988A889C8F7E928278928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
9282789282789282786B55465131297D5D54614C408F6E5A926D5892725D927663927061
8957467D533E6E3829510D0C5E221D8755448C5F4E926D5E976B5D8F71598F56448D5342
8A5B4992796287564474534751382C4812089B5E4A89644A8D6854895F4A835947815644
8656448162507F7169735D5B95887F928278928278928278928278928278928278928278
928278928278928278928278
92827892827892827892827892827892817792857B928278928278928278928278928278
9282789282788C7A7326170F321B14855D4F7F5A49926F5A926858916D54956E5A926B5A
895F4882513B997C6A8F6F5A9265568F5D5189574A865245894C4284453E80453B7F362E
7F36307D4A3B824C3F7642346937274E1E1564281B986E56916B5489624A8357447F5442
835B47835F4C5C3B2CB9ADAE84706D95887E928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278927F75927F75928278928278928278928278928278
928278928278836E6B4430280000064E3E38957361926C5892685A8F61568F765C92685A
8955487E4C3A8A685495796A927564926E5E9273639275649268588D6B528D6350895F4A
895B46815440874A3E84433876352C62292159231D73422E8F64548C614A8357447F5440
835444835B48473027876D619C8C858F7B72928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
92827892827888706888706A8F69558A614D916F5A95705C926E5B92685992695A926E59
8A634D825141865845977D6895776A927262926E5E92756492685A8D5C4E8C5D498C664F
84594580564382523B7F513E7F553E7F4F3E7D4F3E815444865A44895D48815642815642
81594284594737221B927B718C7866928278928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
928278917F76957661916D5B92705B8D786D996F538F705E92725F926F5F927262927262
8F645487614A82503F8A6652927968927767926B5D917A649576638C614E8C5B4884513C
846149774D3977513B7A4C3A7C4E36774A387A4935855D4A855D4A875B478254427F5240
7F57428159441F12108D746D9C8F8E928278928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
9282788F76688F766A8C644E89624C876C5D88665D927660927564927564927564927564
92685A8F5D508658448C594895796892756492685B8F65568F6E598A614D865A46814E3D
7E503F7749387A4B387A4F3C7F523D7E50397A4F3B7F53408757448759468154427C503F
7F574281594726151049332BBDADA192857B928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
92827892705C916F5D85543F916F5D885E4F8F6E5A92685E92756492766792715F927564
92705E926B55895A46895A44916A5B957668927361927265926E5E8D6554875847875B47
8157447F4E3D794A357748397F5442855646875946865A48835A48835443815442815442
7F5441815A464930242B1B164D3A32CDC3B9928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
927C6F8F6C598D564484654C8465519C6B5A92685A927060927564927869927869927564
927060916F5A8D6552875E4A8C65508F6E5C916B5B957C66926D628C6B51865847815643
7F544081563E774A38824F398156448658488D6150895F4C835D4A835B478159467C5742
81544381624E794E3A5D392A371D18583D34928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
926B5D8958457F42347F5241846756886E5E92725C926E5B927564927564927564927363
9273618D6C5B8F68548A6C5892705E92725C8F65548F6856926554895C4C81523F7F4F3D
7A4D3B7D4F397A4E39784D3D7F5342855E4C8D614E895F4C835B48835744835444815642
7F543F865F4E7D4D378156459483798F7F75928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278927E71
926F63894E427D42338354468C6B578F6E5E927564927262927060927665917461957666
926B5D8D7258916854916D58927363927361927366927060926656895D467F56437A4E3C
774C3A734C3B7C4E3B815646895F4C8A635089614E8C5F4C835D4A835442835443815243
815442835C507E4E3B79503D8D776FA2988E928278928278928278928278928278928278
928278928278928278928278
9282789282789282789282789282789282789282789282789282789282789282788F6B55
8D614E794D37884F3A8F644E8F6B57927060927363927665927361926F5F8D6F5D916B58
926B589466588D6A548D6452926E5C92706092705E9270609167588C54467F503F7A4E3C
7A4E3C795240795742855B48855F4A8C614E8C6350895A4883594683564481503F81503F
7F544283624E7F442E8666547C5344929998928278928278928278928278928278928278
928278928278928278928278
92827892827892827892827892827892827892827892827892827892827892827887553E
562E1A6B3C2D532E24A1725992705E92705E92705F927061927060926E598F6B568C6554
875C4C895F4E8C685394755F91715D95736392706092705F8D6859875D477F4F427D5139
784B3B8154428159468457468A5F4D8C5F4E875F498A644F845B47845B478159467F5240
7F5244815B497A4731824F3C845142928275928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278927F75855848
552F1F3C231948282289635092705F916F5F9573639270598C69569572608D6552946D58
926757905A4D8C614B89614D92725D95766592706092705E8D63528357447A4C3B7A4938
754E3C7D4E3C7F58458458458A5B47895F4E845444865B488159467C54427F57447F5240
7F52447F57446A3A277539238A553C958581928278928278928278928278928278928278
928278928278928278928278
9282789282789282789282789282789282789282789282789282789282789172618C6458
331009381D153B221B976B578D6C58926F5A8F705F92705F876350775442744E3A5C3E32
56352A723C288C54417F402B844831A78C759576689270608D65548354447A4E38784E36
7545357F56447851417251417852417F58477D5A45895D4A835B487F57447A54427F5442
8454447F5444643727622D1E773E2C92897C928278928278928278928278928278928278
928278928278928278928278
9282789282789282789282789282789282789282789282789282789483798C6552845645
3C231D22120D341A148A6C588F6B578D6A5695705C92705C8F6B5978523F6B4D3F3E2B20
311B164222165A3C2F7A3C2A6F3C2F7B5142926F5F9270618D644F835442754935784E34
571D0F8F634B82563B7E55437749348F5D4A7A5444815943845B49815946754F3D755442
7F54447A543F6134276D38277C403390796C8F7F75928278928278928278928278928278
928278928278928278928278
92847A92857B92817792857B928278928278928278928278928278471D14CF9A7C8B614E
4B292024171929150F976F5A916F5A92705C8D6C5894715D95736387614F85584865473B
3526232D1D18412E265D4136794B3D8A68549277679278698D6D5B8359467448346B4333
582D1F5D392F5E3C2C1F0C0A723D2B6143325430208356417E4F338D5A4378564575503E
7F52426D49384E2A1E5E30238F5744947C76928278928278928278928278928278928278
928278928278928278928278
927E75928278927F75927F759282789282789282789282784C292045281F3E0B05844B36
391F202919122F1915876A568D6C5892705E895E4B8F7259997C6A8F6F5D89604C7E5240
78503D754F3D6C433176513B845A488A63509275649275648D6654835D487A4834724A35
6C3D2F63453B4E3930150E0E3D1E144D312839251C5E3929694333744B36754A39735442
7F54404E2C2446291B4A25198548359C998E95857B928278928278928278928278928278
928278928278928278928278
927B72927F75928278928278928278928278928278928278351914382117301511351D16
1D0E0D301A153019138A6B568F6F5A8D6F5D8C5F547A4C3C81554197735C8C6B55815748
7844347C4B34844F38864F379E775E946C589270609276638D6657835F4E7A4E3A774D34
755238815240795040412D282119183B251E3F2D254E382E65422F724E3F81543E765040
75523F3F2419351B15472418753322998C81928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278391D1429120C2718112C1711
2615102115103D251E865D4A99725D8F6E5A8F6E5E886554714938683D316448396D4838
50352953362B5935286941327451418865548F6E5B926B5A8D6D54835C4A7A4B3E693723
7340298865438459457F57437B5242684534603B2F734736784E3B7F523F75543F845942
6D4A39271812271711633B2E542419998278928278928278928278928278928278928278
928278928278928278928278
92827892827892817792857B92827892827892827892827841251A29100B251510211510
1509082917113927207D58459A725D95735E9270609272628F6C5A825748684039684039
7240336B3D2E683A2B714132845C4B927262916C5B94695D91635485614E7C524662362D
4C241C55301F5A3522965C418D624B8157407954407552407D523D724F3E84564879543F
4E2E202C19122C20196639296A301F584238CAC3B9928278928278928278928278928278
928278928278928278928278
928278928278927F75927F759282789282789282789282783D271F311B1526140E261510
1B100B25140F3A2720754F3D8D6B5792705C927060927564927564927667927361927361
92715F92766792715F92725F8F6B558F705F8F705F8A68548D68548A6854876250815949
603E3343272135241C45271B5732217D48356F4F397B4A33734733845847734E3D7D4F3F
361C152A17102C1B183D160E6322144A332A8F7F75928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278412A233B26201F130E281510
25150F28181639261E6D493792695499766192705F927366927767927869927D7292796C
92766792766792756492756492725F926E5792705C8D68548D65528D63508D6B568D6354
8561507D55486843384831293B261F452A205236295D40325A3D2F6F42387D5642774B39
331A1427151023161021110C3A19134B2F27928278928278928278928278928278928278
928278928278928278928278
92827892827892827892827892827892827892827892827844271D3D251B2F1E1824140F
2B110C2E1A15392319573A2D8F644D94745F95735E927060927564927667927564927D72
92796C92796C927564927564927361927363926F588D68548D6B568D65528D63508D6654
896150855F4C7D5B487652416F4F3F6041325D3C2F684133744E3F764E3F754C3D5D3C29
351D162715102D19131E140F2815103F261B8A7670A69F94928278928278928278928278
928278928278928278928278
9282789282789282789282789282789282789282789282783D2318402A222F1C162E1913
1D100B2B16102C17114D2C1F734A32A07A6692735E92706092756492796C927667927564
927D7292786992786992756492705C92705F916B599168548D63508D69548D66528D6350
895F4C875B48875B48815A487F54428359467C57447A52407F52427F524274493742281E
24140C2E1A181F110F20120C150908371D156F51479F928B928278928278928278928278
928278928278928278928278
92827892827892827892827892827892827892827892827841261B39272039251F2E1B16
2C171223140F2E1C163E282057352695664E997761927363927363927B6C927D72927667
92766792756492756492756492705E916F58916B568D66528D66528D63508C63508F614E
8C614E835B48835B48835D4A815B487F5442815744755240795240704F3D5A3A2C361D16
2D1D17180C0B1F12111408081D110F27150F5F443B99857B928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278402A223F29213C292236241D
2E18131E110C321B1542281E54382A774F3B977561957361927063927363927B6C927D72
92796C92766792715F9275649270608F6E5A8A65528C63508F614E91645389644E895F4C
895F4E835D48835B48835946815B478159467D523F7C5644754D3B6B4536502D20331B15
1F120C1F1210180C0B1C100B1B100F2E1913654E446B5147928278928278928278928278
928278928278928278928278
9282789282789282789282789282789282789281779182793D29223D2821402C253A2720
2816102E1C162C1B1539221B6239287849368F665095735E92706092726292726292796C
92796C92796C927564927564916F5D95715F8D68548A665287614E895D4C8C5F4E895B48
875D4C875948815646845B468157447F57447C503E78503E754735643E2E3B2319321A14
21150F20140F1F130F1B100B2115102F19149483798F7F75928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278927F758F786F35211B43271D3927223F2B24
34221C2C1B1534211B382117543B2F6E3F2D92644F947761957363927363927767927869
927B6E927B6E92766891746191705D916F5A9163508C614C8F64528C614C895F4E895D4A
835B48835D4A8154447C54447F54427F56437A5442754D3B6A4230502D24391E16251710
1F120C1E1210190D0C0F09081B0D0C41261E887B7295857B928278928278928278928278
928278928278928278928278
9282789282789282789282789282789282789282789282783F2922392117402B243E2A23
36231C311B1539231939261F4C352858312487564097745F92705F927061927366927663
9276669276669273668F6E5A8A65528D68548C644F8C614C895F4C89614A895F4A895B47
835F4C8359468359467F57447F52407D4F3D724F3C6A4431502E2545281B2A1611231610
25150F1B100F180C0B170C0B2917124D322C5B3A31928278928278928278928278928278
928278928278928278928278
9282789282789282789282789282789282789282789282784D362F36221B3C271F442C25
38221833211B311D163D28203A261E492F2671412E92684F9A7C6894715D95736192705F
92705C916F5A94715F9573618D66528C624E8C614C8757468A5D4C8A5D4C8C5F4C875946
8759468356468159448157427D4F3F7A4F3D6B473557302342271B2C171121130C1F1210
2816101D1110140808180C0C30191495857B95857B928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278533C313E2A243C29223C2720
3D271F2D1A17321F1836231C3E2A233922184E2D207F553D956A5295725C94755F94725D
94745F916F5A8D6B5691705B8F68548959468A5D47875B46835643835D49875B47875946
8154428454437F52407D5641774F3B71443169422F42271B2E18112517101D110B180D0C
1A0D0C1009080F08082C1713311B138C7F78928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278644D433621193E2B243A2720
412D26341F162D19143C2A2335221B412B23331E16593C2C6A43329159419B725A8D6650
92705D8F6E588F6B54926B57875F4B7C513D86533F8A563F87584784544284513E845A47
81543C7D4F417A4D3B754A386B4A385A342650291B381E162916101D110C190D0C180D0B
1408080E0808170C0B2715105E3C315B3D31928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278826B66422A2335211C3D2822
3D282135241C2E19163D24193A2721412D263926203A271F4B342A60392A774732775244
74523F86553F87614C855E48774E3E714530673D2A77472F80483581533B854F3B7A4A39
7948327E4A34774A376942346138284E291C3C1D162B17101F120C190D0C1408080F0808
0F08080E080720140F2C171389786F8F7B72928278928278928278928278928278928278
928278928278928278928278
9282789282789282789282789282789282789282789282789282785B463D3220173C2922
39292238251E21151039231C432D25412D26453129412D264531274C3429513427503027
4E2F2252302663382767433253342A5332275A302158311E5F332571422D71422D6D3E2A
6B3F2D603423653C2D5C32254D2C20381C15361E171F110B1E110C180C0B1308070E0807
0E080722130F1A100F4F372E6E5E56928278928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278735D5936211B392720
3C28213A272134231D35241E412D2647322A402C25452F274A2C24523225452C203E2A23
372019422921391C15492D24432A223B251E3A1D163D231A3D1E164621184E2D1D4B2A1C
4B2A1C4420174321183D20183B1E1627171121130C1B0D0C190D0B180D0B0E08070E0807
22131522130E32221D61474175574D928278928278928278928278928278928278928278
928278928278928278928278
9282789282789282789282789282789282789282789282789282788C7872533A35301D17
3A27203E2A2339261F45312936231C4A342C39251E422D264A302640272141271E3D271F
34211B3F29222B191633231C351C16331D162917112517112B1711331A14331B142C1811
2E18112D1711341A142916102A16101E120C1D110C180C0B180C0B0E08080E0808170C0B
2C1B172C1713513A31583D34928278928278928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278755F5839221B
3B2A233E2A233A272036261E473029422E2738272136221B4A2B1F36221B3A261E38241D
2A1B1C38261D2F1B19301B152817182516102416101E110C23161024161026161020120C
1B0D0C20120C2A16111F120C1B0D0C1F120C1D110F180C0B0E0808180C0B1D130E261814
2B171351372E51332B928278928278928278928278928278928278928278928278928278
928278928278928278928278
92827892827892827892827892827892827892827892827892827892827888726C4A2F29
36221C402C253A27203B2922392A23452E2639261E3220193620192C171137241D2D1B18
2C1B192817112917192012101C0D0C1F12111E1210190D0B1E1210190D0C1E1210190D0B
1D110F20140F1D110F190D0B0F08080F09081009080F09081C100F1A100B180C0C2A130C
583F37543A31928278928278928278928278928278928278928278928278928278928278
928278928278928278928278
9282789282789282789282789282789282789282789282789282789282789282786B5147
341E18301F193D28223C2B243C2B24422E273825212F1913301E182215102A1711251712
2916111A0D0C1B0D0C1F12111C100F180C0B1D1110180C0B1D1110180C0B2C18130D0807
1E11102115101D11100E08080E08081308071A100F190F0E1B100F2C18132C1C1438251F
685B5A8F7B72928278928278928278928278928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
6B5147321C1631231D36231C433029412E27412D272E1F193420192515161D110F281610
1D111021150F1E130F1B100F180D0C180D0C180D0C180D0C180D0C2115101E1110302425
261C17211213180D0B1B100F1C120E1C120E1B100F2F1F192618152C1713492C21624434
724E3D928278928278928278928278928278928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
9282786B4D43321C1636272035221B412F274A342C3C2A243420162D1C181F14101D1110
190D0C1E120C1E1210190D0C180D0C1C100F170C0B1C100F170C0B190D0C3127232C1B21
44352E372825281A1A2D201B271A151E130E2C1B162D1C173C29223E231B54382F68473A
928278928278928278928278928278928278928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
92827895857B6E5147371D163D2D2738262047342C47322A422D252D1B142D1C162E201B
241A1621120E1F140F1B100F1B100F180C0B180D0C2115161B100E1F130F1F1312362721
3E28242416142C1C152A1B142415132A17112F1E173821174C3227523B366F4E3E927F75
928278928278928278928278928278928278928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
92827892827892827868473A371E1635221C452F27523C344B39303D29232B1A142E1B19
331D1635251E291C161B100E180D0C2518192115162A1D1822161934231C1C12133F2D25
34231F32221C2C1E192A1C162D1F1A33241D2F1E194C302454382D643D3188726C928278
928278928278928278928278928278928278928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
928278928278928278928278684E412F14072D1C15422D264E39304D3F3C462F25372521
372521311E1B3429243829262C1E182518182D212534231E3A2D2C35231C34231E3E2C27
422B253E26203E271C392923432D244E352839251C6B4E41724A3A927F75928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
928278928278928278928278928278856E6954342E2F1B15402D244035355C4740523C35
513D3349373140302E4433304D3B37412E283F2D2A3524243A2721412C27422E273E2A23
4C2C21492D24472D244A312844291F62453B5E37215E3D31928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
928278928278928278928278
92847A92857B928278928278928278928278928278928278928278928278928278928278
928278928278928278928278928278928278928278684E4A37130F2D140E3A2B2A644E44
5B4A434E3B2E523E36534039563F36523B3549352C42302B412D2839282146322C49342C
442D24513127482A2272514451261344130972544D928278928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
928278928278928278928278
927B72927F75928278928278928278928278928278928278928278928278928278928278
9282789282789282789282789282789282789282789282789282788C787262474A4B292B
6240416446455E3B2C4C2E224A352B5C443C5E41355B42395B42395A4136533C33573A2E
573F326B5145340F034E2622826863928278928278928278928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
9282788C78758C7572856B6961444A4A2D34472625442217442318442015411C123A1306
37100065473A927F75928278928278928278928278928278928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278
928278928278928278928278
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.25526 0.245293 0.476744 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
69.000 12.813 moveto
(deg) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B797972503C
816D607B69657B71697B655D7B71697B6D657B6D657B6D657B655D7B6959726155775D52
6E514673594D6951466F55496F55496F55496F55496F4D4266513E6B51476B513E6B5147
92ABB87B79797B79797B79797B79797B70717B7E7E7B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B75757B7E7E7B79797B75757B7E7E7B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B75757B7E7E7B79797B79797B79797B79797B79797B797976533F
7B69617B695D7B716E7B655D7B71697B6D657B695D7769607C69607C6558736054745D4F
74554974584B6B514574584B6F55496F55496F51456F51456651426B51456B513E6B6160
92979C7B79797B79797B79797B79797B74757B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B74757B75757B7E7E7B74757B79797B79797B75757B7E7E7B75757B7E7E7B7979
7B79797B79797B79797B74757B79797B79797B79797B79797B79797B79797B7979775440
816D647B69617B6D657B6D657B69617B6D657765556B615983605178584F6F5B4C6F5C4F
6F554A6F554A6A4E436B51456F54476F54476F51456F51416B51476B51456B51427B8D96
7B79797B79797B79797B79797B79797B79797B75757B7E7E7B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B70717B7E7E7B79797B79797B79797B74757B79797B74757B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B797976503C
7B6D657B69617B69617B6D657B69617B695D76655D6560596D584B764D4E6351406D5549
6D584F6D584D694C426654456B51456B51456B51456B51426F5549664D426B514592ABB8
7B79797B79797B79797B79797B79797B79797B74757B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B74757B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B533F
7B69617B69617B69657B69617B69617B695D7B6D657B686176605577585272514B725547
72554D6E4E4971554B5F433C6A50456A5D51664A3C6F51456F54476651456F594D8CA2AF
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B5743
7B695D7B69617B695D7B69657B69617B6D657B69617B6D657B6D65766055765B5272554B
77585272554A73594D6D4A47694D436F544A6A59516B4A3C6F51456B51457C716D818D92
7B79797B79797B79797B79797B79797B79797B79797B75757B7E7E7B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79796F59518C7A68
7B69617B695D7B695D7B69657B6D657B69617B6D657B68617B6D657B655D7B695D765D4E
76595272584E72594D6E4E496D5546694D426B574D6B51456F5145665145888D96818383
7B79797B79797B79797B79797B79797B79797B79797B74757B79797B79797B79797B7575
7B7A7A7B7E7E7B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B7979463830AD8775816D60
7B69657B695D7B695D7B69617B71697B655D7B6D607B716E7B69617B69617B695D7B6559
77554E775C4E7759516E55456F4D456F55496A4D4266514574594D6A4E43879DAA7B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7475
7B74757B79797B79797B7979
7B79797B79797B75757B7E7E7B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79796B61651A0E09E1BCA37B6959
7B6D6A7B655D7B6D657B655D7B6D657B6D657B685D7B69617B695D7B5C5D776854786455
7C6058775C517359516F51437351466955496B4D3E6B51476F574A6F544792ABB87B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B74757B75757B7E7E7B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797F7D7D261712715C55816D647B6961
7B6D657B69617B6D657B69617B69617B6D657B71697B655D7765557C5555775C4E6E5549
785C50785C50735C4C6951497451456F54476A51426A51456651456F5549889096818D92
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B75757B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79793321197B6D657660557B69597B6965
7B69617B69617B695D7B69657B69617B6D657B69617B696172453F775750734E44735146
735146736A546F54456F54476F4C416B54437451476F5145665141744F4675685D92ABB8
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7575
7B7E7E7B79797B79797B7979
7B79797B79797B74757B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79796B61612B231C816D617B69617B69597B6965
7B69617B65597B695C7B69607B6D697B6D657B5C597B68607239377340386F342E794946
6F3C347951486550416F56466F51416B4C417454476F51456A51426F493E6A584B7E746B
8CA6B47B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7475
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B7979241815DAB199816D647B69617B695D7B6965
7B695D775D527C60548172647B69657B6155774547784E4474524D682E237D594F794040
65241E7538306F493F6650446B5B486B49366F54497451476F51456F4D426F54476F584B
8C9CA17B83887B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B75757B7E7E7B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79795A4C4D3129219783737B696177615181766D7B655D
7B61516E5949744F468C7871734941471A0EB78378733934715C545F4741632D23675646
623329703C3B5D2A20883A3267614D6F4F366F50466F584B735546694A426F55496F5145
7E71658C9CA17B83887B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B75757B7E7E7B74757B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79791F1312B98F75816D657B695D72554B817A757B6961
7B594B6542316B473D521915A08E8543171670504A7044427650497B71686D2E27654B4A
5134294C38343C1B144E2115944A3874654B74494173605273594A6D5143694D456F5145
6F584B7E889A88847A8183837B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B74757B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79796F69720D0704DFB595816D647B695D765B527B69657B6961
734A3C5E3E2A662C23300F09A882758283747C6B678192947B69617B726C6E514A828886
735549656969301E1B2A26243C1811994E38795F507E64517761586E5143694E436F493E
6F584A6B7980756C6E8888968C8D837B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79794638303B24216348419788737B695D7B61557B695B7B71687B6961
693D345E4D3D5B3632321116703D4072594B73554D7D6E65825750746655744138794C41
704B3E838571663F34584A492B251F410E06A56F5E7E6B517C695F6E5143694D456B4D42
7455496A6459707A845C556592978D7B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B75757B7E7E7B79797B79797B79797B79797B7979
7B79797B79796F65690D0805271511D5A2907B69597B65597B5955776955816D607B5C59
694A3A674736928C847B6D617B5755765752705651704F4A76464367413E6C3D3A68342E
683837694F436E3B375C3A32492E212E130F6D2E21978066826C5E6E5543694A42664C41
74584A6F5B4E413028BFBFCF7776768183837B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B74757B79797B79797B79797B79797B79797B7979
7B79797B79795F535F050900000B147C7267816D607B61557B605D7659557B76607B5B59
69463D5F3C31887D708176717B6D657B655D7B6D657B6D657B5952725C4B775C516E5546
735146654A3C753F3E6B40365C2F2C4826244B252774563A83675F735946694A42664D3E
7451476F584B191818B4A6A08C8D927B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79796A57567B6961765F55725D4E7C695C81695D7B69617B5B597B6D617B6559
6D514468433A7456498883758176717B68617B655D7B71697B575272514873514573604E
6B4D41634C417048386B4A3D6B4E3D6B473D67483D745849795C4F73554665493E6B5041
6F54436F544A141212C7BBC586887E7B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B797977717281604A7761597863546F6D718C69527B6D657B6D657B68617B6D657B6861
76514B6D554468433A7C7061817A757B71697B5955777664816D606E4D44734E436B4738
6B5B4A5E4136674B3867453C6B4C366242386744347D635773584B6F514566493E6B4C41
6B54456F5549050608CEB5B2979DA07B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797660567B69616E51436F554672726E815C597B76697B71697B6D657B6D657B6D65
7B575276554B694A3D78544A86837D7B71697B57557665597B695D6D4D446E5143644037
6A51455E3C31674738674B3F6F4F3E6A493B694E4073594D6F4D426F51456A4D4266493E
6B54436F544A020607573F37E0DCDD7B7E7E7B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B574377655D623C2E82766B7B5C597B695D7B69657B71697B716D7B685D7B6D65
7B65597B6052694A3D73514382766E81716D7B695D7B6D6A7B655D72554B6A4A3F6F5145
6B514566433966463462423A6F524678554D775C4E6E55496951476F4E436B4D426B4D42
6B51426F594D0D14131D181751423DE0E3E47B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B69617351426F443A665643797A6E92645D7B695D7B69657B71697B726D7B6D657B6D65
7B655D77655572554B725C4E7B695D7B6961775C55817A6C7B5C5D6E5D4669463E6B5043
674C3F6F4F3B5E403470473A745B4F79594F7C60546E55496955496F51456A5145665141
6F4C436F64555C3C2F3A2C292D47537B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B4D44693F3461322C6B5E4D77766B816D657B6D617B655D7B71697B6D657B6D657B6961
7B695D7261557B5D5272695C816D657B6D617657527B695D7B554E69514365433967483C
6344386B4A3861453A6F514673594D735C517C5C516E55496951466F4D426F4C456A5042
6B4C3E74645A623C2C6F524996B7C37674757B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B6D65
7B544E6939345D362C745F54877A6C7B69657B71697B68617B69617B6D6577695C816D64
7B5C597269557C5C5177695B81716D7B6D607B69657B69617B554E694D3C61493E62453A
62453A5E493E6F4D3E74584E795C4F77605473594D7355496955496F493E6F4C436B4C43
6B514174605E653C2E665145838D989297967B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979734D3A
704D41583B2D7346368D74648676687B69657B6D657B6D657B695D7B655D7265597C6058
785C547C6158776555776155816D647B69617B69617B69617758526E433A61463C62453A
67483C664F436B544578584F735C4D785C50735C517351466951466F4D436B4A3F6B493E
6B504574645B673122746F62664A4492BBC77B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B797965301D
341F1455352B462A24BD937886766D7B69617B695D7B69617B69617B6559766559765B55
6D514773554D7463518271637C6D60816D697B69617B695D7259526A4A3C62413E674B36
63443A7452466F584B745147745B4E79584F6F5748745B4E6B51456F54476B51456B493E
6B4C476F5B4D5E33237457486F423C92BBC27B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B716D633125
201A132C1F19392421BD937886766C77655D816D657B69596F59507E675C7054497D6152
795750794D48785E4A795E507E70618676717B69617B695D72514B64473A5E3F36674434
5E483F704B3F6B564970504379584A795C526B4A3F74584B6A5146664D426B51456B493E
6B4C476B54454B2A1D65322183534097C0D17B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B797977594B6E4A46
17080529191334201CDAA2857C6D607B65597B6D647B695D67514759463B563E3246342F
462D276935258755446A3527724230A89E8B81716D7B696172554B64433A5E4231634936
5E3E3675574A655146604D436A4D426B524A6350417D5C4E6F5549664D42634C416B4C41
7451476B51453F231B52261C79443397CAD67B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797F7D7D70453365433B
070C0E18100D311A15DAB1927B695D776155816D607B695D76605A513C31574944171A18
2115123F20155940387336276A463D82766781716E7B6D69725444644037563B2E634832
3D140C947058705038664B415F3D2E825A4D634F437958466F544A6B51455A453A634F43
745047634C3C3F231D6234267E473F96C1C97674757B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B7A7A7B7E7E7B75757B7E7E7B79797B79797B79797B79797B79792A100CDD94766D554A
19141413121625140FE9B9997C695C7B695D7765597C695C816D6967504373514A302F2C
1D2124221D193C362E664A3E78554B7C7163817A757B726D72594B64433A54392C553E32
371C185E4B464832271509086E3A2A5A463843281D7F54446D46308356435E4F46634C41
744C434E3E32311C17572F24A1685896B6C37674757B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B75757B7E7E7B74757B79797B79797B79797B79797B79792D1814271612430C057B4937
2214191C14102B1814DFB595776559816D656A493F796A578C7F7976685D70534A61453D
5F473A5A463A5A40346E5946775951776558817A757B6D65725147644E405E392B594636
58332C524D4A312D2B02060848221744322D291D186A41306343347554415E453C5E4F43
7451412C1E1C31201744231AA4543F9DCFDB7B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B74757B79797B79797B79797B79797B79797B79797B79790500002F201826121032201B
120A0B2C1A152D1814DAAE8F7B695C776960704E4E5F463A6B4B3F826959735B4D67463E
5F372B6B4531744635764835977D6B826E6081716D7B6D6072514B6455495E3C30624732
634C3874544961463F091B2124211F2E25212E2A255D453A6146346350466F4D3E614D45
634C3E1A13102918144423198E3727A3D9E47B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B797906000021100C201511251511
1C120F1F14103A2521C590748C726476695D7B69656A574D513B32523631463F3961433A
3A2D264739304D332A65463C776D607B69617B69617B5C5572614E6451465E39364E2C1C
603B2882694A7454496B5143654A424E3C314C39336F4D3E63493B6B4C4563503E745443
4E3D34100D0B201410824D3D522118AED9E47B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B75757B7E7E7B79797B79797B79797B79790A01001B0C091D14101C1410
1107072516113A2A25A6765D987A698171647B69657B6D65766459654845493F41654845
5A3F385A443C543B356A4A3F72615581716E7761557C5C59775D5268554A6345443E2824
321B1A4930204C2F20945A448362526B513E614D41634C4167483C5E473D75524A6B503E
2C1F1816100E27201C8E48335224194D4946DBDEDF7B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B74757B79797B79797B79797B79797B79790D04022316131E120F1F1410
140E0A2414103A2A25996650927A6A8171647B69657B71697B6D657B716D7B6C657B6C65
7B685D7B716D7B685D7B685D7660527B6D64766559725D52775C51726155725C52674D47
372C2D2B23211C1E1B41251C4C2F217242335D48386A4130633F307959506B4C4167483C
140F0D1E130F281B1A3F140D591E12343330D5D9DB7B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79790A05042F2320140F0D221410
1D130F2518183829238559439776658C7A6C7B69617B6D697B71697B726D7B76767B716D
7B6C657B716D7B685D7B6D657B685D7B65557B695D72594E775C52775C51776558775855
68594E644A434436322C29272925223F2A2343362C5E42364C3F367044436752415E4236
120D0D1E130F1D14111B0F0B391A15443530D5D9DB7B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79790F060431211A1F18161E120F
25100B291A1636241B5D4033A0725D8D7E6E816D607B69657B71697B716D7B6D657B7676
7B716D7B716D7B685D7B6D657B695D7B69617B655572594E776558775C52775C51775C54
6E594D6D55496451465C4A3F5A4A404939314E3C34614339614C4566463E5E483C3F2E23
1A12111E130F27181417120E2514103E281DB4A2A79DA6A57B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79790D0401352824231815251612
170E0A2715112716114E2F227F5238A88E7E8171647B69657B71697B76767B6C657B6D65
7B76767B6D657B6D657B6D657B65557B6961775D52775C52775C51776154775C51775C51
6E55496F51466F55496A554A6B4D426F514566514563493E6B4C436B4C415A3E32261B17
170E0A28191919100F19100B120808381E17876963B3C0C27B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79790A03012F25232C211D251815
2115111E130F291C183F2B2557382AB07F698C7A6B7B6D697B6D657B76717B76767B6C65
7B716D7B685D7B6D657B6D657B6559776555775D52775C51775C51775C51735C5178594D
73594D6951466F55496F584B6A51466B4D426B51455A493E6B4C415A483C3C2C251D1411
211916130B0B191010100707181010271510725851BFC5C77B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79790E05023326233326232A1F1C
251511160F0B301B16412A20553B2D8C5B459281738171687B69657B6D657B76717B7676
7B716D7B6C657B685D7B6D657B655D76655572594E73584E78594D7C5C546E5C4D735549
73584F6955466F55496F51456B54476B514567483C664F436344384E3A32342119211512
18100C170F10140B0B170F0B1810102C1914A8A6A57B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B75757776760D09073325213729252F221F
1D110E251A17291A1735231D6A3F2D7E503F8D78688676687B69657B6D657B6D657B7676
7B716D7B716D7B685D7B6D6577615581695C72594E725C5172594D73554D73594D735146
6F594F6F51466B4C456F54456B51456B514566463B634C415A3B3047332A231914251613
17120E1B13101A120F170F0B1C14102E1915F4FAFB7674757B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B7475766F700804033C251D2F2523352824
261C1A2519162D201C3120185C44386D3F2F976F5E887E6E816D697B6D657B71697B726D
7B726D7B726D7B696177695C7761557C695C77554B735949785C5373594973594F73554A
6955496F55496A4A426651456B4C416B5043634C415A443852362A3924202517121C1410
18100B191010150C0B0C0807180D0C462923DBE8E97B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B7979070302311F16352927352824
2B1F1B27171333231A3124204B3A2E512B2194614D928775816D647B69617B6D697B6D60
7B6D647B6D647B696576655572594E77605473554973584973584F735C4A73594D735145
69584B6F51456F51456651456B493E67483C56473B52382C3924203120181D120F1B1410
1F130F160F10130B0B120B0B291814968D8D7674757B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B7979120908261B173325213C2925
2A1D16281D1B2B1C1736272333241E412B267C493596765D8D7E717C695C816D647B695D
7B695D7765597C6960816D6072554B7355497359496F4D4574584E74584B79584B6F4D42
6F54476F4C456B54456B514167453C63483C4E3E323F241D2C1F1821141018100B191010
241410160F100F0707150C0C321B15F1F7F77B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79791C120F291F1E332623332420
31221D2317172A1D1831231E3528243120184E2D21855E47926F5D836B5C8271637C695B
7C6D607765597761557C695B73584E6F4A3F7457476F51456F4F436F584A7454476F5145
6B4C416F4C43674C3F674F3F5E44385A3A2E51392B2A1C162114101C1410170F0B140B0C
170C0C0C08080C07072C1915311C14E0EEF37B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79792A1E1B1A120E3328242F221F
392C28261914251714372B272D201C3828232A1A165C43336340338C5542927563755B4D
7E6B6179645779604F7E64586B51455E4034744B3D79503D7452496F50436F483A6F5649
6B4C386748416344385E43365243364228213E23192518141E130F17100B140B0B140B0B
1007070B0707140B0B2816118D7A768183837B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79795F555D110807261C19342521
352723291F192516163A251B2F24213C2E2A2B211E35272144312B5F382B714835614943
624B3E784B3A775B4A7355465C3F3658392A5736286D442E7344376F4E3A75473862463B
623F2E6B4233634436513B324C30253920182D18141F141018100B140B0B1007070C0808
0C07070C07071F14102B1814E6E9E97B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79791F16131A130F352824
2F26232C211D18110E37241E3C2E2A392C283A2E2A352A273F322A44322A453026412B28
412A1F492B255A3528593E323E2B27462D254E2B204E2F1E532F2566412E633D2D573628
58382B4F2E2155382E472B233C251D2917132A1C18160E0A18100B130B0B0F07070B0707
0C0707211410171010664A43AEBBBD7B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B7979443B440F0A072F2420
312521312420261E1B3226223C2E2A3D302C3528243A2B27412923482F2436271E312523
2C1C173A2723301914412D2735252131211D321A1534201A341B153F1F1843291C3E251B
41271C371B15391E18321C16301B151C14101B110C140B0B150C0B140B0B0B07070C0707
21141821140F2C2220AEA2A07B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B7979706A70180D0D1B1310
3124203528242F221F40322E2B1E1B44332E2B1F1B3A2B27442E2635242133221D312420
281D193C29261E14142E241E2C19152A1A152114101F15112514102E19152C1A15241510
2716112514102E191521141023141017100B18100B130B0B140B0B0C07070C0707140B0B
2E1E1B2516128788887B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979463B3F120C09
3028243528242F221F2E241F3C2C283D302C28211E2F201C462A1F271D1A31231E2F211D
21181C34251E2316172A1A152114181F140F1D141018100B1F141020141020141019100B
160C0C1B110C27151118100B160C0C19100B181010130B0B0C0707140B0B19130F251917
2918147B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79796A6066140707
261C1A3729252F221F3026223329253C2B272B201C291C18301E1921141033241F251818
23181922151022141A1A100F160C0C1A1110191010140B0B1A1110150C0B1A1110140B0B
1810101C140F191010140B0B0C07070D08080D08080D0808181010170F0B150C0C28120D
827A7B8183837B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979382D2C
0D07072219163425213329253128243C2C282A1F20251611291D191A120F2716121D1411
241411140B0B170C0D191010170F0F140B0B191010130B0B191010130B0B2A1915090607
1B11111D1410170F100B07070C0707100707171010150E0E181010291813261C16432F27
AEC0CC7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
382D2C090404241F1D2D201C3C2F2B392C283428262119162D1E1B1B111518100F221410
1810101B130F1A120F170F10140B0B140B0B150C0C140B0B150C0C1C14101B101026242C
221E1B1B0F12120B0A160F0F18120E18110E170F102D201C1F17152917134C30258C8883
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79793929280A070627211E2D201C382D2843322E2C24222A1C1521181817110F191010
140B0B1A110C191010140B0B140B0B181010130B0B181010130B0B160C0C2F2A2A291C27
40362E2A22231B16182923201E181517110E271A182A1D1935282438211B817A7A7B7E7E
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B7979817E7E382827120A082C28272E242143342F3A2E2A3528231F1613231916281F1E
1B18161B100D191310160E0F170F0F140B0B140B0B1D1519160E0E1B130F1D1314302421
3C2A251B12122418132519141D12122214102C1E1A31201851382D6058618C8D887B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B7979321E18160E0B241B183F2F2A4C3D383F373429201E1F1613281A1A
2A1A152D221F1F1B17140D0E140B0B21181C1C1517271F1B1B1418322620130F1346362E
2A1F20231C1A261E1B221B17261E1C322822261C1B5236287570716A656B7B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79793228220E08081914103A2B27443530403B3F3628212C2526
2F2826261B1B2826252F272E26231D1D161A241F282F221E322D3730231B231C1C41312D
34252334221F34241C2E26243F2E264E382C241C189D928D7B74757B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B7979655B61261E1D0F0909352A2335343D5C4A45433836
423934362D2D3533363F34364238342C2322352C2E2A1F21332522362723392C28352824
4428203F2A243C2C253F332E39251D614B4859554D7B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B7A7A7B7E7E7B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B7979322830261E1D1A1B242923265A4C46
514D523D362E433935433936463A364336363F36302F2A2B382E2B2C28233F34343F3330
392A2346312A3925217E6768493C314332367B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B74757B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B7979706A70322D3A493C3F
5A515D493B424E403330282A312A285142444D3A2F4A3C38513F3A463A344638344B342B
443830817A7B2119185F51577B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B7979706A757B7475655B663D37443D3744382D2C382B2A383230382D2C3228272D1E18
2D231D7B74757B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B7979
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.25526 0.488926 0.476744 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A6F513D
7E6E61786A6678726A78665E78726A786E66786E66786E6678665E786A596F6256745E52
6B524770594D6652466C55496C55496C55496C55496C4E4263513F68514868513F685148
91ADBA787A7A787A7A787A7A787A7A787172787F7F787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787474787D7D787A7A787474787D7D787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A787A7A787A7A755641
7B6C66786A5D78726C78665E78726A786E6678685A7164587464587460526B594E69564A
6950456C5549634E426F574B6C55496C55496C50446C504463514468514668513F686A6C
91A3AB787A7A787A7A787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787878787676787D7D787878787D7D787A7A787474787D7D787474787D7D787A7A
787A7A787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A71533E
7B6C61786A62786C66786E66786A62786A627162525D5E58765B4E70504A66544669594D
6C584C6C594D695246685145685145685145685044685140665146685145685144859EAB
85898C787A7A787A7A787A7A787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787172787F7F787A7A787A7A787A7A787878787D7D787878787D7D787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A75513D
7B6E68786A64786A62786C64786860786A5B7568606F68627861527B5658685847705549
70554F70554D6948416352446851456851456851456851446F574C66504468514591ADBA
787A7A787A7A787A7A787A7A787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A785641
786C61786A5D786A64786A62786A62786A6078706A786E6675665C745F566F574F745C4E
745D536E524B745D506448416C4D456C5F57664E416F51456F53466350446F5D508EA8B5
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A785843
786A5D786A64786A5D786A64786A62787068786A62786A62786E6675665C78655A715E50
745B56715A4E705B4D6A4D486955486C5548695952684E41685145665145807B7A8599A2
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787474787D7D787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A644A41826A56
786A64786A5D786A5B786A66787068786A62786E66786E6678706878665E786A60756052
785E54715B4E715C506E504B6D5546694E42665549664E416F514566514587949E7E898B
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787878787D7D787A7A787A7A787474
787676787D7D787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A2D261F8F6C59857565
786A66786A60786A62786A6478726A78665E786C5D78706A786860786860786A5B78685A
715650715B4E7458526B5644694E42695549695044665145715D506954488BA6B37B7F7F
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787878
787A7A787D7D787A7A787A7A
787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A5D565C0C0704D9AF9B7B6C5D
78706C786860787068786860786C64786E66786E64786A6478685A785758715D4D6E584B
745950745D506E5C5266524370524869574B664E3D6651466B55486850448EABB8787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787878787676787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A7F8181130D097A6452B69883786A62
786C66786860786C64786860786A62786C6478706878665E716454745352715D4D6B564A
735B4F70594D6E59486650466F50446951456950426C51466651456F574B878B8F7B8487
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787474787A7A787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A1B120D75655AAD8D807B6C5D786A66
786A62786A62786A5B786A64786A62787068786A627868606F3B387446446E3E396E403B
70413D705E4E6950426950456C4A3F6653416F51466C5145635140714D426B5C50889EA6
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787474
787D7D787A7A787A7A787A7A
787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A5D5656483E37B39486786860786A59786A66
786A6278645678665878665B786C66786C64785654785D596F35346E3E35662F28744542
693B3374494360453B685043685140664D417153486C51456951446F4940695B4D77675C
829198787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787878
787D7D787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A110D0BB48E767E6C5D786A5D786A5B786A66
786A5B715C4F745B507B7163786C68785E50713B3D6E3E35664A42572C20716556775953
60261F6B322A694238664B406859486849356B55456F51466C51456C50446C55486C574B
8B999C787F82787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A463B3C362A1FC39F877B6C66715E507B756E786862
785E4E68524269463D856B696B38352C0E089067606E413974665D72736E73372F5F473A
523426634C464A2E2176332B6257456B4D346F4F476F594D745B49694E446C574B6C5145
756458828888787F82787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787474787D7D787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A100C0BAE886D8E7C74786A5D6F54487E7772786860
785A4B5E3D2D633F363A100F7B7B745F615C9E99917871747B7A797B817B6C4337727E7B
6B635E575050351D173B1E13774130705F48714B44746355745B4D6D56466950456C5044
6C594C75849E7B7C797B7F7F787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A64616E040302E1B1917E6E63786A5B7563587B716C786A62
6B44374F382557261E260C08AD7A6B836F5F7458527B8382786354786A5B68473F7A7C7D
6B493C6F6A644D362C4B4740391C157E42307055497A655077665B6E56486650466C4A3F
6C5548667475675F5974758582847F787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A2D261F1D1210593D31C6A68A7B6C5F785E52786256786E63786A5D
653D33655748745F58665F569E716F7461556E524B73605877413D664F4567312C6F3830
63342B7472615B352B5A4344382C263C0E068E60547C68507A6A606B5242664D42664E42
6F594C6963567F858E635E708E9489787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A787A7A
787A7A787A7A645B610303021C110EE8B39F8B7C68786458785656716A597B7063785758
65473A5C42318B847E7B726A78615E75685E756E667868607B63586B594D74564B6E5443
6E554B6C57487136356036304B271C36130E6B2A1F856E597D675B6B5442664B42634B40
7155486C594C29201B9E9BA47D7E797B7F7F787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A
787A7A787A7A5B5665413B2978594FB697817B6C5D78625678675F755C587B736178635C
654E41614237897F717B706A786E66786860786C64786E667856526F574A745D526B5648
705248604C3C6B474063503D60463C5D473D6544427D64437C65596E5845664B4263503F
7153486C594C151B1CB1A39E8287897B7F7F787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A6F584D826A5A75696271665877685B7B6A5D786C6678636078776A786860
6C56496A4B406F52457D776A7B756E786C6478686078726A785F546F574A6E4D416E5B49
634D3D564A3F674636644539644939644439624839745E4C7A615670544660473D664D40
6B53426853480B0F0FC5B7CA8B918E787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A716E6E7B5C47715E546E57466062688568567B6E6878706A786E66787068786C64
75524F6F57496A493E7D6F607E7570787068785452716C5B7B6A5B684C426E4F43634235
6353475D3F3567493664483E6B50386246396445347F625674574B694E4260483D684D41
6855466F574C010608C4AAA38E9490787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A755D4D7B655A684E4266504374736C885B5678736A78726A786E66786E66786E66
785F54755E4F685040735348817E7878726A785F5A756E627B6C646C50496E564863473D
6C57495D3C32644639644B3F6D50416C4B4174574B796356694E42695044695044664B40
6855426B53480006074D362FBFB9BB787D7D787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A78584371645A5534267D75688261617B6C5F78716878726A787572786B62786E66
78665C786658654E427056467D796D7B6E6878685A78706A7868606F584B64493D694E42
66514563463C684D3662443A6D52457959527B65576E594D66564A6C5448665044665044
6853456F5D522C281D39211B41342FB0B2B3787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
7861566B413260302B5D483B737D74886A5F78715F786A6678726A78706A786B62786E66
78665E7164546F584D7468597E73677B6C617157507B736578565668543F634239664D41
5F483B6B4D36553D3167443A7460527A5F537A63556B564A6654486C4E42695044665140
6F4B416F63555E403453403A78969FB0B0B0787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
7848406538305D312C6863507D7B6D88706878706878686278726A786E66786E66786860
78685A6F62547B5E52716A5D7E6E6878706875615C7B716678584F65544460433B5F483B
5B42366346385F463D775D4F7963557461557A5F536B564A6652466C4E426C4B45694D44
684B406F655D5D392A6B504599BBC8757878787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A78675C
785346654136573C2D7166568B80707B6C6878726A786C64786A62786A627164567B6A5D
7857566F625277594E7166597E706C786C5D786862786A6278545065493B5D463C5F463A
62483B5E4F43705542745D50775D5077615570584B6E52466654486C483D6C4B41664D41
66534071635F67403368574B76838D828787787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A6B4530
5C3B313C2B21583B2F887567887C6C786A66786C64786A6278685A7864586F6456775B56
6E574E74605674685974685B7E7065786A62786A64786A62715D5268493C5D483D5F463A
64493D6850446D5546795953745D4F735B4F6E5D5270564A6654486C5246665044664B40
684F4671635D5F2C1D6F6A5C66443B91ABB0787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A5E2A19
21160F3F2B24382421AB8872847770786A64786A5B786A5D786A62786860756A62786560
6F574F70524B6959497B685B776A5D7B6C68786A62786A5B6F564F64463A5A3E3D624935
5E44397052456F5B4D7251466C594B74554F6951446C5549634E4268514566504468493F
684D486B59495735226C5745683C3891BDC7787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A786E67623328
2D241D31231C332320C2947984776A7164587B6C64786A5B6452496C594D59433860493D
5E443F64413E6E574572574974655881736E786A62786A606F524D61483A5A4134644531
5B493F6C4C3F605245604B406D5548725D52634D406F594C69544866504468514568493F
684D4868554540251B52271C74483794BFCB787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A71524168433D
0A050319130F2A1D19D8A2847A6E607864587B6E63786A5B68564B54453B47382D322D2A
2C221F48281B6A473752281E562F229283737B6E68786A626F584B61463A5A43325E4D38
573E3673584B6C594C6C5549715245684E48594A3D775B4D6C5549634E425B4B40604B40
6D53486853453C241C54281E7B433397C7D5787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A7F8181724835614038
080F101B130F311915E4B3937B6E617464587B6E61786A5D756660564339715C5620211E
1E1311371D13493B366636297A5C4E938C7A7E77727875726F5B4B6142394E392D5A4230
2E0E097E5C4A6346305340364630256B4F435B4F41755744685146665044574439604F43
734F485B483A331F1B5B3527804F469CCDD7757878787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787676787D7D787474787D7D787A7A787A7A787A7A787A7A787A7A140705A2614B685448
1A191713131822140FEAB99877685B786A5D7466597466597B6C6868594B74574D403C33
58473E5A3D2C634837835C468562557D72637E797478706A6F5646614239553B2C574034
3E251E615650342D270A06064F2C22483E332B1E165D4137523927714938594D42604F43
734D42453C2F251A15482B22986A5999C0CA727576787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787676787F7F787878787D7D787A7A787A7A787A7A787A7A160C0A120B093409044C3126
100D1214120F2B1813EDB9987466597E6E6861403A6C594B857772756E6475615A6B544D
664D406450436C50447C65507D6158776A5C7E7B76786E666F50486150445A3E2E594D39
623E30685C524F3B3106080A4622173B2D29241C186941306845367E5E495F493F5E4F43
7353411F1A19251B143E21189D4C3994BFCB757878787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787D7D787A7A787A7A787A7A787A7A787A7A787A7A0000003022182915122E211C
0D090A2C1914301814E4AE8E7B685B74685D725C586456475A4035634E4053423644312C
3D271F4A33255435285937297F6C5E7B6F617E726E786A5B6F50466156485A3D32624533
604D39705949634C42383B376B4A3B52372C4E362A83574576533B6353486B5040665348
604D4012110F2316134022188B34259ED4DF787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A0200001D100B1A1310201410
1C120F1E1511372723C89477856E61756C5F7B6C686F615865574B63464145413F6D4B44
573E32634C3E5E40347A584B8C847382736C7B6C667857546F5E4F6154485A383840261A
4A2E21725C426D5345685141694E445D4B3B5B4B41785A465E4D40684D49604F406D5342
453A30090B0A1A131095594561291EAADCE6787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A0703011B0D0A1E15111B1410
0E07072215113B2A26A3725A8C73637B7063786A66787068756C626F605C696964887268
726960787068756962857161786E617E7570716254745F5671625268574D6B544D524236
39242339291D3020186F4537765A4D66513F635041604D4162463B5644396E50486D4F40
1F1A150F0D0C2A221D914733482117363836ADADAE787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A0604032018151D13101F1410
140F0B2516113A2A269C664F9279697E7265786A6678726A786E6678757278726E78726E
786B62787572786B62786C627566587B6E63756658715E5274594E7162567462566E5650
5047445B453D3A322B3F261C32231A4D2F263E372E4E33274E342773554E73504462483A
0C0D0C19120F261A1A34110B42170F2C312FDFDEDF787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A07050535262315110E211410
1E1310271919392A248257418A7060857769786A60786C6678706878706A78757278726E
78706A78757278695E786E66786C6278685A786A5D6F5A4F746054745D52746457745956
685C4E66524753463B4F43394F413556392C4E3B2E72493B605044794B4A5E5040514135
0C0C0C1D130F1B1411170F0A311A153C3531DCDCDD787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A0905032D20171E18151F130F
25100B2A1916362419563C3093695787796A7B6C5F786A6678726A787572786E66787572
78726E78726E78695E786E6678685A7868607864566F564B746457746054745D52745B52
6B584A6D5246665246604E42695447604B406851457350446850496B4A405F4B3B37291E
130F0F1D130F28181419130F2415113A261BA68F928B9190787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A060301332926221916261613
160F0B221511211510462A207148309881717E7063786A6678726A78787678706A786E66
787572786B62786B62786E66786656786A60715C4F715E52745D52745D52745B50745D52
6B564A69524669554969594D6850446C50446651455B493F604D42604D404B3C30181715
0F0C0A25181917101016100B0F0707321B167E615BAAB5B5787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A0703012F26232C221E251A16
2316132014102A1D19402E294F382CA47865857364786C68786C6478736C78757278706A
78757278695E786E66786E6678665C716456715C50745B50745B50745D526E5D5270584B
6E584B6652466C55496C574B69524668504466514557493F6D4D415B483B32282216110F
221A16130B0B1610100F07071710102616116D564FBCC4C7787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A0705043128253428242C221E
251612140F0B2E1A1642291F5B3B2C90584089796A7B7065786A64786C6478736C787572
78726E78706A786B62786E6678665E756858715C506E594E70584B7759536B594B705246
70554F6654466C55496C504466514566504462463A664D416042363E342E261C161C1311
15100B140F0F140B0B17100B1911112E1914D5D1D09EA1A2787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A7874747170700606053024203529252D231F
1B110E251C182C1D1931231D653F2D7C5141887769817567786A66787068787068787876
78726E78726E78695E786E667160527B66586F564B715B50745C5070584D6E594B705246
695B50695446664A4468524466514568514566483D5E4F434F3A2F423329201913211513
16130F1B14101B131017100B1C14112F1915FFFFFF757878787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A7878787578780304033C251C2F2522342824
2A201D271C182D211C3221185B463A613D2F8A66568077687B6C68786C6478706878706A
786E66786E6678655C716456715C4F77685B71554B6E584670594F6E584670594F70584C
6655496C5448694C42665345684B40684D415B4B404F42364832272C1F1D1B131118130F
150F0B171010130B0B0A0707150C0C492A24EBF0F0757878787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A050504312016332A27352925
281E1A241612342219312521483A2F47261E8558468982717E6E63786A5D786C66786A5B
786A5D786A5D786862756858715C50745D526E4E436E5446705550705B4C70594F704E42
6655496C50446C504463514568493F62483B4D44384833282C1E1C261C1519110E181310
201310161010130B0B120B0B2F1A15DCD0CDA7ADAE787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A110E0C271F1B3126223B2925
2B1E15291F1B291C183227232E221C3828246F4633856A528073667466597B6C61786A5B
786A5D71645874665B7B6C5D6F544A6E50456E5846694E446C574C6C5749745549694D41
6953466C4A4466534566514062443A5B483B473D3235211B231C151B120F140F0B171010
221410150F100E0707140C0C321B16F7F7F7757878787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A16130E28211E342824312420
2D231E201617281C172F221E35292531201745281D7053417E6153765D507A685B746256
74685B7164587460547764576B554B66493E6C5345694E446C4D416C53466F5145695044
664B40684B415F493B5E493B5141364A352A44312621191319120F18130F160F0B130B0C
150C0B0A07070B0707301A16391E15EEF3F5787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A363033221A173328242D231F
3B2E2A2A1C15261713392D282C201C352824261B174E3D304A352C6A43357D6455665044
6F5F586C59526C584A745F53604B404C382D5E41356A46356B4E44684F42684236685044
664B3562483E5B42365740344B40343A251F321E161C14121B120F16100B130B0B130B0B
0F07070A0707150C0C281611BAACAAB3BABC787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A69686C17140E251D1A302420
322622231E1921161737241A2D24203E302C2E25213527223C2E2A54352A593C2D443937
443B3356392B5C493B5A463A42322C442F23483024593C295F3B305E44326A4434574237
50362958372D563D314436303D29222E1B142515121A130F150F0B120B0B0F07070B0707
0B07070B07072016112E1915F7F3F37B7F7F787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A2220221E1916372A26
2F28242D231F17110E33241D3C302C3B2E2A3C312C3A302B45382E45362C3D3127352726
36241A3C2420472C2246332A2F242238272342271F432A1C432822533A2B503629422F24
4A3327422A1F44332B39261F322119201512241B18130F0A16100B130B0B0F07070B0707
0B07072415111911117B5952D2D9DA787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A514E5716110D2F2420
2F24203024202A211E3B2C273E302C3D322D3327243428243B242043292033231B2C2320
251A163226222817133428242C23202A201B291713281C182817143019153122182F2017
3121182816132C181526171325171316120F17100B110A0B140B0B130B0B0A07070B0707
24151A241510322723DFD1CE949B9D787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A727276262422211B18
3024203529252F2420423530281E1A3E302C261D19372A264732283327242C231F2D2421
281E1A3F2C271D14152B241E2817132617131D130F1B14102113102B18142919141E1310
2014101F13102A18141D1310201410140F0B17100B130B0B140B0B0B07070B0707150C0C
32201B281713C3C2C2B0B0B0787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A4D464C17100D
3329253529252D231F28221D382B274235302924212D201C40271C2019172C201C2C201C
1C161B2D231D1E15162A19141E13171B140F1A131016100B1D14101D14101B1410160F0B
130B0B18100B231511150F0B130B0B17100B171010130B0B0B0707140B0B1D15102D1E19
2D1915B6B5B5B6B8B8787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A6F6E70191512
27201D3529252D231F322824342B27362925261E1A251A162B1C181B120F30231E221717
21171821140F1F131817100F120B0B171010171010130B0B191111130B0B181010130B0B
1710101D1510181010120B0B0A07070C08070B07080B070718101019100B140C0C25110C
B3A9AAB9BDBC787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A535453
272220251C18302420312A262F28243C2D292B2122241612281C1818120F231511191310
211410110B0B140B0C171010171010140B0B181010130B0B191111130B0B2E1A15090707
1A11111D1510160F100A07070B07071007071911111710101911112C1914312118674131
D8E1E77B7F7F787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
535453241D1B2A26222A201B3C2F2B3B2D29352A27211C182D211C1B121617100F211410
1710101A13101B1410171010130B0B130B0B140C0C130B0B140C0C1C14101A1111292A36
2F2A281E1216110B0B1610101C14101C141018101131231D271B172C1814543328B9BABA
97A3A9787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A59575625201D3028242C201C312A2640332E3128252F1E1622191718130F181010
120B0B19110B171010130B0B130B0B181010130B0B181010130B0B150C0C312D2E2C1E29
43362C372C292920213C2F2A291F1A19130F2A1C192D1E19372A2645271FB9B2B2A1ADB0
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A7B7D7D504F4E261B15342E2A3328244335303A302B392E29201815241B17312522
241F1B1F130F1B1410160F10171010140B0B130B0B1D151A160F0F1C14101B12122B211D
392922140E0F1A130F1D1510150F0F1E130F2D1E1A3221185F3E2E8B7F8AADB8B8787D7D
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A504C492A2620221B18392C274B3D39443E3A312825221915251819
26171330242024201B140E0F130B0B21191D20181C2C231E1D161B3C2C261611164E3C33
2F232428201D3125202A201B30242143352A2F232065402FADA8AB919BA4828784787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A50514E4D4A512E2621372A26392E2A3A393F3F332D423735
463E392C22232828283C343F463E362D22242A242E3426233D374438292127201E46352E
34252238241F38241B31282547342A5F3F2F2B1E18C3BDBA97A1A7787D7D787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A6C6B6E565C582A23283A302A33343C5B4C48464040
423C373B35334844454F3F3C463A332C24223B322F2E22212E221E2F231D392D29352925
45271F462C244432284E3C3540271E614C4D849193AAB0B3787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787676787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A5051557275706567733B343B5B4C49
655F6A5348454E3F3A443A35463B384E3E4052433C3F373552413B41372F4D403D52413D
44362D463A3233262386747C7F8482858A8E979E9D787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A727276565C5F85827D
82848965606878746D5855613E3B42504750463A32443B384C3E3A423A35443936423027
3B332BA49EA16F72759B999D888F8C787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A7272787E807A6C6E73626869787A7A75756E787474787D7D787A7A757878757573
787D7DA4A3A7787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.25526 0.732558 0.476744 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
777779777779777779777779777779777779777779777779777779777779777779777779
7777797777797777797777797777797777797777797777797777797777797777796E503E
7B6B60776765776F6977635E776F69776B65776B65776B6577635E7767596E5F56735C52
6A50476F574C6650466B53486B53486B53486B53486B4C42634F3E674F47674F3E674F47
8BA4B4777779777779777779777779776F71777B7E777779777779777779777779777779
777779777779777779777779
777779776F71777779777779776F71777779777779777779777779777779777779777779
777779777779777779776F71777779777779777779777779777779777779777779775744
7B6B6977675D776F6977635E776F69776B657763566E5C4F6E5C4F6E584B665048614D44
6149406650465E49406B53486B53486B53486B4C426B4C42634F45674F47674F3E676E75
8BA4B4777779777779777779777779777779777B7E777779777779777779777779777779
777779777779777779777779
777779777779777375777779777779777B7E777779776F71777779776F71777779777779
777779777779777779777779777B7E7777797777797777797777797777797777796E503E
77675D776761776765776B6577676177635E6E5C4F5658566A534B6A4644614940665449
6B574C6B5A4F6B5348674F45634C42634C42634C42634F3E634F45674F45674F458BA4B8
8B9299777779777779777779777779777779776F71777779777779777779777779777779
777779777779777779777779
777779777779776F71777B7E777779777779777779777779777B7E777779777B7E777779
77777977777977777977777977777977777977777977777977777977777977777977503E
7B6B6977676577676177676177635E7767597767617B6B69816759805B5F6F5A4C745348
74504C74504C6B4240634C42674F45674F45674F45674F456F564E674F45674F458BA4B4
777779777779777779777779777779777779777779777B7E777779777779777779777779
777779777779777779777779
777779777779777779777B7E777779777779777779777779777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779775744
776B60776759776761776761776761776761776F6D776F697767617363596E5B52775E54
7762576F534C7762546B4B456F48456F5D5A674F456F4F456F4F45634C426F5D528BA4B4
777779777779777779777779777779777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779775744
77675D77676577675D776761776761776F6977676177635E776B657767617B6B60736355
735B58735B516F5A4C6A4D496B5A4B6B53456B5751674F45634F45634F45817E83869CAB
777779777779777779777779777779777779777779776F71777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
7777797777797777797777797777797777797777797777797777797777795D3C33775744
77676577675D776759776765776F69776761776B65776F69776F6977635E776761775F56
7B5F55735B4E735B516F504C6F53466B4C42634F4563493D6F4F45674F458191A07B8990
777779777779777779777779777779777779777779777779777B7E777779777779776F71
776F71777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
7777797777797777797777797777797777797777797777797777791F15106E503E867767
776765776761776765776765776F6977635E776759776B6577635E77635E776759776759
6E53526E574E7354516A5443664C406653486B4F45674F456F5D526B564B8BA4B47B8082
777779777779777779777779777779777779777779777779777779777779777779777779
777B7E777B7E777779777779
777779777779776F71777779777779777779777779777779777779777779777779777779
777779777779777779777779777779777779777779777779564952080101B7978C7B6B60
776F6D776761776F69776761776761776B65776F697767657763567750526E5045664941
6E5048735B4E6A5B516150436F50486B564B634C3C634F45674F4563494086A0AF777779
777779777779777779777779777779777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777375777779777779777779777779777779777779777779777779
777779777779777779777779777779777779777779807F820C040281674FD5B69B776761
77676577635E77676177635E776761776761776B6577635E6E5F526E504F6E5B4B6A5449
6F574C6A54496A5443664D436B4C42664C426B4C426F4F47674F456F564B817E83777779
777779777779777779777779777779777779777779777779777779777779777779777779
777779777779777779777779
777779777779776F71777779777B7E777779777779777779777779777779777779777779
7777797777797777797777797777797777797777790C0402725A4FD0AEA27B6B60776765
776761776761776759776761776761776F6977676177635E6E31337334386A2E2F6A2E31
6F31336F50466649406649426B453C634F3E6B4F456B4F45634F3E6F483E634C427B8990
777779777779777779777779777779777779777779777779777779777779777779776F71
777779777779777779777779
777779777779777779777B7E777779777779777779777779777779777779777779777779
77777977777977777977777977777977777956494C6E5752D0AEA277635E776759776765
776761775F52775F52775F56776761776761774D4F7750526E31336A3A326129226F3F3C
6638306F3F3C5E393563483E634F3E634B416F4F476B4F456B4F456F48416B5A4E6F564B
777779777779777779777779777779777779777779777779777779777779777779777779
777B7E777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
7777797777797777797777797777797777790804048167527B6756776759776759776765
7767596E584B6E534B776B60776B6977584B6E3133662E275D3F384B291D666B5B746D63
5E2821632A2366383067433C6753476748346753416B4F456B4F456B4F456B53476B5348
868D91777779777779777779777779777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779776F71777779777779777779777779777779777779777779
7777797777797777797777797777793A2B2D472B1FD5AE947B6B696E584F776F6D776765
77584B66493B613C357B5B5F66272A1A03026649476A473E776B63869695823F3A5B362E
47332457574F3B2F23632A235F4A3C6748326F4B466F564E745D4B6B4F456B564B6B4F45
6B5348776F6D777779777779777779777779777779777779777779777779777779777779
777779777779777779777779
777779777779776F71777779777779777B7E777779777779777779777779777779777779
7777797777797777797777797777790C0606957A6394837E77675D6E50457B6F6C77635E
77584B5D36295E363027090956636080A39EBCD2CE8096A1809AA47B89896E574880A7A5
868B8F636369351F1A291A115735286B55436F4B46746155745A4F6F57486B4F456B4C42
6B564B6B7B9C6E6F76777779777779777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777B7E777779777779777779777779777779777779777779777779
7777797777797777797777795D5769060101C4A0877B6B6077675977675D7B7370776761
663D334731204B1F19250A07A26B5D8157486E423C776F6D775B48775F4B663C36736B70
663C307B675E6F4C3D6E6259371F195F332867484174614E77675B6F574C6650486B483E
6B4F45636A665B5045615F71777779777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
7777797777797777791F1510060101533124DAB69B7B6B6077584F77584F77675D776759
663D336F5D528B827A9AA390BC9A9877645D6A4D496A50496E2B2B5D36355D222166231F
5A1D19665A4F562C235F3B3E4C322C370D066F4E4779614E77675E6A5040664940634C42
6B5A4E6B5D528B89946B6379868982777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779776F71777779777779777779777779777779777779
7777797777795D5059000000130C0BDAB6A6948775775F567750566E675C776F63775056
66433B563B2C8077747B73707767657773697B7F78807B74807B6A736C5A7D695A746F56
746D5B6F594A74313367312D53211644130E63241B6F584A775E576A504066494263483E
6F4F456B534819110F77737581807A777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777B7E777779777779777779777779777779
7777797777795D5769866B52E19D84D8B094776759775F56776B60775B597B6B6077675D
66544466453C86796E776761776B65776761776761776B657750526E5048735B516A5449
6F50485E4C3C634B415E5B4367594A7462547C5D5B806A49745D526A5443664942634F3E
6F53476B564B1D1F209A9694777B7E7B8082777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
777779777779775744866753776F6D736B5F73635977675D776B69776765777B70776765
6E584F6F50466B4B4173675C776F69776B65776761776F697763566E5B4B6A463D6A5443
5E493A4F453C5F41345F3E345F41345F3E345F443473604E79615B6F50465E423C63483E
674F41634F450B0C0DACA8C48B9299777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
7777796E67697757446E584F66493856545E7B63597B6B69776F6D776F69776F69776B65
77505273574E6F4C427D695D7B6B69776B65774D4F6E5F527763566649416A4D435E3B32
5E49425F3B3467443463473E6B50386347386343327D5D537453486649405E453C674B41
6753476F564E030608A1938E80857E777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
7777797757447B5F53664941614940776F668B5752776B69776F69776B65776B65776B65
7763567763526A54436F4F457B7370776F6977635E7773697B6B696E504F6F574C664C42
6F584C5F3B3263433863473E6B4E436F4B467D5D537D685D664C42664C426B4F45674B41
675341674F450607073B2A258F8E94777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
7777797757446E5F564E2C1F776F638662667B6B60777369776F69777475776B65776B65
77635E77675D6650476F5748777669776761776356776F697767616E584B61463A664940
634F4563483E6B50386343386B4E43795A557D695D6F5A4F66574C6B564B634F45634F45
6753476F5D55573B2754291F2F2320777B7E777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
77574C663123561D1D5A39326B79767B6B60777360776765776F69776B6577665E776B65
77635E6E5F526E584F776F6380776E7B6B606E504B77675D774D4F664938613C3563483E
5B41386748324F382E5F3E387360537961557762546A54496650466B49406B4C42674F3E
6F483E6F5D5263423A6F504ABCD7E1D0D7DC777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
77423E66312D5E2F2C676251817A6C8B6F69776F6D776765776F69776B65776B6577635E
7763566E5F527B5C5273675C7B6B69776F6D7767657B736C77584F6654445E423C5B443A
573E345B41365F443E7C63567D685B746257775E546A54496650466B4C426B48456B4845
6748416B615D5B3629674B4194B4C3777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779775E52
77503E66463856412E6F67568B7E717B6B69776F69776B6577676177635E6E5C4F776356
7750526E584F73534B6E5F557B6B6977675977635E77676177505266433A5E423A5F443A
63473C5F50466F5846735D51745A4F775E546F54496A4D436650466B453C6B483E634B3E
63533E6F615D6B42376B584F67727E727275777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779663C28
4E2921281B16412F277D7066867B6E77676577676177635E776356775F526E5F52735352
6650486E5B5273675C736B5F7B6F637767617767657767616E5F52664D3E5E483E5F443A
63473C6B4E436F5347795655745A4F6F574C6A5B516F574C6653486B5348635347634B41
674B476F5D5D5B26196B6155673B328B9294777779777779777779777779777779777779
777779777779777779777779
7777797777797777797777797777797777797777797777797777797777797777795D2617
160E0A2D211D2B1E1E8B7769807370776765776759776759776761776765776B697B6B69
735B556F4D49614D40735C527363597767657767617767596E504B61403856393C5F4434
5B41366B4E436F5A4E6F4F456653466F504C664940664D435E4940634C42634C4267483E
674B476753455336226352416336338BB2C1777779777779777779777779777779777779
777779777779777779777779
77777977777977777977777977777977777977777977777977777977777977676166362D
452E2737251E30211FB08C758073676E5F5277676177675D5D49415D493E473128473128
47312D523435664C406B4C426A574E7B6B697767617767616E504F61463A5B413263432E
5B473E674A3E574B4153453C634F456B5A4F5E4C406B564B6B5348674F45674F4567483E
674B476753453B2119421C16633A2D8BB2BD777779777779777779777779777779777779
777779777779777779777779
7777797777797777797777797777797777797777797777797777797777796E4939663C36
0503020D0C0C201917BB967E776B5F775F567B6B607767596E584F53423A3E3129242425
1717182A1B124C36293E1C153E1C157763587767617767616E584B61463A5B41325B4E38
533D346F554A735D51785A4E78534767484553423A6F564B6B5348634C4257483E57483E
67534767534542251D56291F7740328FB7CA777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779807F82774939613C35
1613131F1511301814CEA88E7B6F63736359776B6077675D7767656149408B6964322823
1F120F2F191138333257352A856B5B9999877B77747778796E5F5261433A4B352C533A2D
24090763463A573B2745332B32231C534138574B3E6F5341634C42634C425741385F4B41
6F4B475741382F1C195333287C534C99CBDA777779777779777779777779777779777779
777779777779777779777779
776F71777779776F71777779777779777779777779777779777779060000612E21665047
271E1A17141A1F1310CAAC9173635977675D7363596E5F567767656E5F52745A4F5A463A
9268568C583D84563D96684D8B6A5B7D6E617B7370776B656E50426140385B3B2C5B3F34
4C2D25605A572426270203042F1E1A37332D1713103B2C293B2A1F5F3B2C57483E5F4E43
6F4B4142382C2017133A261F85655694BDC8727275777779777779777779777779777779
777779777779777779777779
777375777B7E777779777B7E7777797777797777797777790801010601012207031F1815
05060C0F0F0D2A1712D8B0947363597B6B695D363561463E7B6B69776F697B6B69775E5B
6F4F456F564B7C5B51876B5981655D776A5E7B7774776B656E4D486150475B41325B503A
6B46347C65566F46360E0B0C3F2016322725221917603D2E6A443680624F634A415F4B41
6F53411B16161D1611371E1788403186A4B4727275777779777779777779777779777779
777779777779777779777779
777B7E777B7E7777797777797777797777797777797777790801013122192D171429201C
0A08092A1813321814CEA2877B63597363597767616B61524B332B4731283A2921281D1B
2117142C211938231C3E251D66574F736B5F7B6F6C7763566E4D426154475B3C33634132
5F4B386B5848674F456F584CA76D557246366B402F9D624E855C41635348674F416B554A
5F4B4114110F2014113B1F187D30238FC0CF777779777779777779777779777779777779
777779777779777779777779
7777797777797777797777797777797777797777797777790C03011B0E0A15110F1B130F
1D120F1D1510332724B28D747B675C776B607B6B697767617D6F6374534F48414378504C
734B3C7B5A496E493C8965569991808677747B6B697750526E584F6154495B363A381F18
38211A5F4B38674F41674F3E6F4F456F55436B594D7C624D5B4E43674B4C5F4B41674F41
42352C07090915110F97604B6B30239ACEDC777779777779777779777779777779777779
777779777779777779777779
777779777779776F717777797777797777797777797777791206041F0E0A1F14101B1310
0D06071F13103929258F68547D675B776B60776765776F69776F697B73708B8C83A39487
8B8C8394948F94908B9A8E7F7D76697B73706E5F526E5F526E63526A574E745E546B5847
442B2B2B211A171211482F29674F47634F3E674F415F4B415F413A4F3E34674B456F4B41
1B14120E0B0A2C231F844331421C14222625777779777779777779777779777779777779
777779777779777779777779
777779777779777779777B7E7777797777797777797777790C06062019171E14101F1310
160F0B2516113729258F604C8B72647B6F63776765776F69776B65777475777475777475
776B65777475776B65776B6577675D7B6B60776356735C5273534B735F55776358775B58
6F5D5A8962565A423A3B251D1B17122A1C1925252435251F3B271F6B4E4A7850465F4438
0D0B0B17100E251819270D0A2C110C292D2CCBD3D8777779777779777779777779777779
777779777779777779777779
7777797777797777797777797777797777797777797777791209083B292518120F1F1310
1F131028191A37292572503E7864587B6F6377675D776761776B65776B65776F6D776F6D
776F6D77747577665E776B65776B6577675D77675D6E584F735F55735B51735F55735755
6A5B4E6B574967534573594A7458476A4434593E2F7F4E3F735C4F7C4E4F574B3E483E34
0E0C0C1D130F1A1310140E0A271915353331C6CED3777779777779777779777779777779
777779777779777779777779
7777797777797777797777797777797777797777797777791206042B1D15201815211310
250F0B2A18143522184A352B7C5B4F7D6F6377675D776765776F69777475776B65776F6D
776F6D776F6D77665E776B6577635677635E775F566E5048735F55735F55735B5173574E
6A54476F4D436B5046674F45785A4E78584C80625480594D6F504C6F4B41634A3A35231A
130D0D1D130F2A18141B1310221410332219877378777779777779777779777779777779
777779777779777779777779
7777797777797777797777797777797777797777797777790C0402312927241A18271613
150F0B1E14101D130F3B251D5C3B28816E617B6B60776765776F69777475776F6D776B65
776F6D77665E77665E776B6577635677675D6E584B6E5C52735B5173574E73574E735B51
6A54496650466653486B5A4F674F456B4C42674F4557483E574B41574B3E42382E111313
0B0B09221719150F10130E0A0D06072A18146A535094A0A2777779777779777779777779
777779777779777779777779
7777797777797777797777797777797777797777797777791206042F25232D221F271B18
2717142214102A1D193E2F2B45352C896A5E7B675C776765776761776B65776F6D776F6D
77747577665E776B65776B6577635E6E5F566E584F73574E73574E735B516A5B516A5449
6A54496650466B53486B53486B5046674F45634F4557483E6F4B415F443A2F231F150E0E
251A17120B0B140E0F0E0707170F102516115F4F4BA8B7BD777779777779777779777779
777779777779777779777779
7777797777797777797777797777797777797777797777790F09083129273529252F2320
271613130E0A2A181440261D5D392988503A7D6A5E776B60776761776761776B65776F6D
776F6D776F6D776B65776B6577635E776759735C526A574E6A54497354516A54496F4D43
6F504C6650466B53486B4C42634C42634C425F413867483E5F3E34352C292017131B1210
130E0A130E0F130B0B170F0B1911112E1914E4EAEEB2BCC1777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779776F716E67690C06062D221F3327242D221F
1A100D271C192E1E1A2D221E5A3B2C734E417D70667B6F63776765776F69776F69777475
776F6D776F6D77665E776B656E5C4F775F526E504873574E775B516F574C6A57496F5046
665A4F665346634542634C42634F45674F4567483E5B4E4348382E423127221812201412
18130F1C14101C141018100B1C14102E1914E6F1F6777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777B7E0A07063B231A2F2320332724
2F23202A1D192D211D33211854443A53392D78584C776B5F776765776761776B65776B65
77665E77665E775F576E5C4F6E54487363596E534B6A54436A54496A54436F574C6F574C
6653486B50466B4C4267534567483E67483E57483E483E34422C24241A1A16100F15110F
130E0A160F10120A0B090607120B0B472925DAE5EA727275777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779120908311F17312927352925
271D1924141133211831252142372E3D211B6F4B3F7D76697B6B60776759776761776356
77635677635677635E776759735C5273574E6A463E6A4D436F504F6F574C6F574F6F4940
6650466B4C426B4C42634F4567483E5F443A483E34422C242418191F181317100D18130F
211310170F10120B0B130B0B331B16FFFFFFC6D7DC777779777779777779777779777779
777779777779777779777779
7777797777797777797777797777797777797777797777791F15132B221F2F2523392724
2D1D152B1F1C271C192F2523291E1A2F24235C40316F58467363596E5F5677675D776759
77675D6E5F566E5F567767596E50486A49406A5443664C426653486653466F5046664940
664F456B4542634F45634F3E5F413857443A453A302F1C191F181317100D110D0A150F10
211310150F100E0707130B0B2F1A15DAE5EA727275777779777779777779777779777779
777779777779777779777779
7777797777797777797777797777797777797777797777791F15102B211F3529252F2320
2B221F1F1518251A172D211D352925311F17392219564438674F476A4D44735C526E584F
6E5F566E5F56735C52735C5266504861463D664C426649426B483E6B4C426B4C42664C42
63483E63483E5B4438574138483B343F2E253B29211D161115100D15110F150F0B120B0B
120B0B0906070A0707311B163D1F15DAE5EA777779777779777779777779777779777779
777779777779777779777779
7777797777797777797777797777797777797777797777794E424C3021203327242D221F
3B2E2B2F1E162917133A2C282B1F1C332724241A183D352C322823482F276650465A433A
61504E614D4B614D446A574E5A433A412E274B352C5B3B2C63483E634B41633B3263483E
6348325F443A573E34533A30483A3035211D2918131811101A110F150F0B120A0B120B0B
0F07070A0707150C0C261611CECED2D0E1EA777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779271F16251D192D221F
2F2320201C181F15183322192D221F3E302C332724332623352928462F28412F252C282B
2A2A2738261D45362B45362E2E242235251D3B281F4533234C31284F38295F3E2E4F3D32
422C24482C274C342B3B312D32221F27161120131117110F130E0A110A0B0E07070A0707
0A07070B07072016112F1A15E4EAEE7B8082777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779342B33271E1D382A27
2F29252F232018110E2E221D3B302E3B2E2B3D312D40332F4A3B3145372D362F282B2223
2E1C15301C1B35211D352622241C1D2B212037221E3A241935211E4131263E2D2532261F
3E2D2338261D352C262F201B2B1C161B1311201A18120E0A150F0B120B0B0F07070B0707
0B07072616111A111184625DDAE5EA777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779665E692719152F2320
2D221F2F221F2F2320402F2B3E302C3D312D3126232F2421351F1D3F221D321E17291F1E
2018152B2321201411272220251F1E251D192014111D18161D1412221411221914221914
231A151C11102013111B12101D141113100E130E0A0F090A120B0B120B0B0A07070B0707
26161B261611372925EEEEEEA3B2B8777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779413A392B221F
2F23203529252F2320423531271D19372B28241A173327244733293129252722202B2321
291E1A402C281F141627221E2414112414111B110E18130F1D120F2717142517141A110F
1A110F1A110F2517141B130F1D130F130E0A160F0B120B0B130B0B0A07070A0707150C0C
33201B2A1813E4EAEED0D7DC777779777779777779777779777779777779777779777779
777779777779777779777779
7777797777797777797777797777797777797777797777797777797777795D5059241412
3529253529252D221F241E1A3529264537322B26232B1F1C3922191D1614271D19291E1A
1A141A251F1C1C14152917131D111718130F18130F150F0B1B13101A131018130F130E0A
110A0B150F0B1F1310130E0A110A0B150F0B170F10120B0B0A0707130B0B20161133201B
2F1A15DAE1E5DAE5EA777779777779777779777779777779777779777779777779777779
777779777779777779777779
7777797777797777797777797777797777797777797777797777797777797777792C241F
2B23203327242D221F352925332A27312623241A17241815251A1717100E2D211D201517
2015171F130E1D1117140E0F0F0A0A150F0F160F10120A0B170F10120A0B160F10120A0B
170F101D1510170F10110A0B0A07070A07070A07070A07071810101A110C130B0B210F0B
CECACEDAE5EA777779777779777779777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
473B38291E1A2D221F2F29252D27243B2D292D2224251512271B1818120F1F131016110E
1E130F100A0A110A0B150F0F170F10130B0B170F10120B0B181010120B0B2F1A150A0707
1810101C1410160F100A07070A07071007071A11111A11111A11112E19143B241A814F39
E4EEF37B8082777779777779777779777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
777779473532312A27291E1A3B2D293B2D29372B28241E192D221E1D1218160F101F1310
160F101A13101D1510181010120B0B120B0B130B0B120B0B130B0B1C14101810102D2D3D
393334221419120A0B170F1020161120161119111134241F2E1E192E1914573329D0DCE5
A8C0CF777779777779777779777779777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
777779807F824737343B2D292B1F1C2B26233D312D372B28331F17251A171A130F170F10
110A0B170F0B160F10120A0B120B0B181010130B0B181010130B0B130B0B322F312E1E2B
45332A45332D3729284C383234241F1B13102C1D192E1E19382A274F2C23DAD9DEB7CED8
777779777779777779777779777779777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
777779777779727275402C233D312D382A2742332F3B2F2C3D312D241A18271B18392925
2E241F2315101C1410170F10181010130B0B120B0B1D151A170F101D1510181010251D18
33261F0E0B0C120E0C15100D0F0B0C1B110E2C1D19332118673F2EA99DABBCD3DC777B7E
777779777779777779777779777779777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
777779777779777779777779433B34241A17332724493B3849423F3B2F2C271B18221618
2414113325212A231F160F10120B0B22191F231A202F262021181D42302B1B1319513E37
3325272F23203B2A2532231F392925513E31372925704634D0D0DAADC5D3868E8B777779
777779777779777779777779777779777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
7777797777797777797777797777798D849645373233272430262336353E493B38574642
5A4F4933272929292B473D4E62544D3D2C2C302732372727473D4E3E2D272D221F47352E
3524213B231F3B231A3529254D372C6A4231351F18D0D7DCA8C0CF777B7E777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
7777797777797777797777797777797777798B9290493B4540332F31313A574B4A4A4448
433D3A433B385950525C464149393030242242352F312321291E19291E18392D29352925
45261E4C2D244C352B5A423A47271F5C494FA8C0CFC6D7E1777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
777779777779777779777779
776F71777779777779777779777779777779777779777779777779777779777779777779
777779777779777779777779777779777779777779777779B7C0BDACA8B94E424F5A4A4B
776B7E69565B59423E473834473B38594448634C4750423F6A504954443A594845634C47
4E4036464038302624847889ADC0CABCD3DCA8B7B8777779777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
777779777779777779777779
777B7E777B7E777779777779777779777779777779777779777779777779777779777779
777779777779777779777779777779777779777779777779777779777779808582B7BCB4
A3AEAF827F8B9EA0A1807D944E485B4E485B413834413836473B384138364337363A2A22
352D25B7B6BFB7C0CAC6D3D88F9C99777779777779777779777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
77777977777980857E777B7E8B928BADB2ABADB2ABB2B1B7B2BCC1B2BCC1B2BCC1B7C0C6
BCC9D3BCC5CF777B7E777779777779777779777779777779777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779
777779777779777779777779
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.25526 0.97619 0.476744 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(135) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E61625D
65656165656565696965656565696965696965696965696965656565656161625D615E58
5E56505E56505A524C5A524C5A524C5A524C5A524C5A4E47574E43574E47574E43574E47
65757E65757E65757E65757E65757E65717A65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E656E7765727B65757E656E7765727B65757E65757E65757E65757E65757E65757E
65757E65757E65757E656E7765727B65757E65757E65757E65757E65757E65757E686863
68686A65656165696765656565696965696965635C5E5A515B5A515B565058504C524C48
514B46544D48514A4458504A5A524C5A524C5A4C465A4C46574E49574E49574E4357686F
65829165757E65757E65757E65757E65788165788165757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65788165717A65727B65788165788165757E656E7765727B656E7765727B65757E
65757E65757E65757E65788165788165757E65757E65757E65757E65757E65757E5E5F5A
62635C6565656563666569696565656560605E5C584C595A52525058464854474457514C
5A58525A5A545D564F574E47524A44524A44524C46524E42544E46574E47574E49728997
72899465757E65757E65757E65757E65757E656E7765727B65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65717A65757E65757E65757E65757E65788165788165788165788165757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E68625D
68656865656865656565636365636365655E686868756E70716D666E6468675D5865524C
654D4E654D505E4446574A46574E47574E47574E47574E495D544F5A5049574E4765757E
65757E65757E65757E65757E65757E65757E65788165788165757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65788165788165757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E656863
65686065655B656563656565656565656568656C6F656F6E686B6D616A6161615D68615D
68635B61565268645B63504D60454760585B5A524D5D4E475D4C46574C465D5A54687B85
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E656561
656561656568656561656563656565656C6C656565656060656969686B6D6B716A65695F
615C5D655E595E58505F54515E5B515A4E445D565457524D524E47544E476871796B8291
65757E65757E65757E65757E65757E65757E65757E656E7765727B65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E5243405B4F49
65656865656165655E656565656C6C656565656969656F6E656C6C656565656568686461
6B635B655C54655C5761545262524C5E4E47544A42544A425D4E475A4E4761747F657C88
65757E65757E65757E65757E65757E65757E65757E65788165788165757E65757E656E77
656B7565727B65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E211E1C3F3E386B6E65
65656565656865656B65656865696965656565635C65666465636365636365655E656860
5E595B5E57546153545E564A574E4457524C5D50495A4E475A5A545D59516B7F88687B85
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E657881
657B8565788165757E65757E
65757E65757E656E7765727B65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E4C4E5D180E0E545259686866
656C6C656868656C6C656868656363656969656F7165656865635C6552555E4A4A554542
5B504A615A525B5C5454524C5E524D5E544D544E42544E46544A4452484262727B65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65788165717A65727B65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E6B7C8617120E6E6A58A09B86656565
6563666563636563636563636565656563636566676565655E5F5A5B57545E5A525E5650
5B534E58514B5B51465A5048574C46574A445D4C47604E495A4E475D544D615D5F62686F
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E656E7765757E65788165757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E0F0B09625D5AA29E9A686866656565
65656565656565655E656563656565656C6C65656565636361383F612E385B2A315B2831
5E2A325E42425748445748445A4640544C40584E465A4E47574E425A463F4F3D365B6266
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E656E77
65727B65757E65757E65757E
65757E65757E65788165788165757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E4C4E578A878B9C9592656363656561656565
656565655F58655C56655C56656360656363655056654A536140445B3B36542B265B3939
5738345B343754333752413E524E42544A435A4C475A4E475D4E495D4A455D544D544037
5B585965757E65757E65757E65757E65757E65757E65757E65757E65757E65757E657881
65788165757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E13111132332F65635765655B65655E656565
65655E5E5B545B524E62625E6568686559525E3839552A284F3E394130264F64585E7267
54312B4F262157302D5A3B3A574A47574A39544E3E584E465A4E475A50495A4E475A504A
656869656F7565757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E656E7765727B65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E37333A5E4A4093877968686A5E595762666A65686A
6559545B4C42523D385E485158282F1A0304312D305B504A68625F7FA5A97447454F2E2B
3E3E2F4459513033274424205138345446385D48435D524D625D4F5E52495A544D5A4E47
5240395B5250656F7565757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E656E7765727B65788165788165757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E1B1918525751757777656561615750656060656363
655E58573E355137321F08082D44498CCCCB99C9CB71AAB96EA2B3688088657D7178AEAF
84A1AC617077382D29191A122F261F54463F5A4C47625852625854625A4F5E50475A4C46
5A524C526079556174626F7865757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65788165788165757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E525A711C12125B595665655E65655E686E68686E6D656565
58454044392B3E221B2F100A623A36653E385B3B38625859655D50655A4B5B44425B545D
58423B75655E7F6D5D77736B2D241E31211F4F3B395B564A65635B615B565A544F5A4A43
5A4A4454564D464841464C5F5B687865757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E211E1C01000049362F968A7D68686365595465545065605965655B
5E4E466A625D81958CA6C9B1999A97685F615B4D4E55403E58292F4F2B334E2527511817
4C181A4C3B3A4F352F5A393D5B423F2A0E083B2E315E514A615E585E564A5A4C44544E47
58574F5D534C787E8663697B626F7865757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E656E7765727B65757E65757E65757E65757E65757E
65757E65757E5254630A09080F0D0C727977787C74655F5A65545D5E616162686365525A
5E4D4C4C3B305E5A5C686F746571706879746E86837184816E8A7B6B78676E7869687E66
68776461524864373C60302F54221A4E1A14411A154636365E52505E534A5A4E47574842
5A4A445A4D48160E0C3E42416B7779626F7865757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65788165788165757E65757E65757E65757E65757E
65757E65757E5A687CB3A695EFBD9FA1907C62635C65625D656E63685C5F686061656E63
5E5F5460504A655E58625D5B65696965686865636365696965545D615252615A545E5652
5E524D5450434F524551624C606757747363756966635A455851485B534A5A4E47575043
5A50475A524C3333324F595C5B6B72687B8565757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E6F65556F655B687579656D685E5F5A62656165686A656E6D65757465686D
65635F645B5358443E58514D626664656C6C656868656969656E636161565B48425B4F44
514C3F4646404C42384F3B354F3E354F3D355144355D594F615B585E504C544642544542
544C42524C441B161555637E6B7F9165757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E5E687162605C5E5952554539494E595E5F61686568656C6F656F6E656C6C656C6C
685961685C5B64554D655752655D5E6566676552585E54516260595B534E5B524B513B36
514342573F395742385448405A4E3C574A3B54423562504A62504A574A44544842574A43
574E495D544F120E104148485B686965757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E68605568605B5B514E544B486862586F5758656065656969656969656969656969
656E6368695D615D4F5B4C44625D5E656969656E6A68717068686D655C5F615A565D574F
60554D57423B54403B54443F574A47604C4A6D5D5967625B574E47574C465D50495A4C45
574E42544C441C13101A16163A424E65727B65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E6565615E5F5849372C5E5F586F5E66686863656E68656969657177656C6E656969
656568656B685E5A555E5A4F5E645A62605E65635C656C69656868616158574C44574A44
544E47574E475D523E57443957484262575568645F615A545A5A545A5951545049545049
57504B5D5A557D5C3F582E22160F0F2A343D65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
655A57583833491C1F5137385160635B6B63656E63656565656969656664656664656969
6565655E5F5A61615B686F6A6B716C6868605E5252625A576550535B4A4258433D544540
4F403A5446354539324C3D395D574F615D54615C545E56505A504A5A4A445D4C465A4E42
5D48405D534E5D4E4A796259C0DADF9FBAC265757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
6552585E3C3E57383757534B6B675F6F6868656C7265686A656969656969656969656363
65635C61625A685E5865625D656568656C72687172686E706561595E5850544A454F443D
4C3F38493D39544642665F57676259625E59615C575E56505A524C5A4E475A48475D4549
574845585657513F3454463E6B7C8668788165757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65605D
655F515E5749514A385A594D6B6B65686868656969656C6C6565656560605E5A53626057
6552586153545E54505E585465636365635C65636065656565575F5E474657464054463F
5748405350485A57495D574E5E5650655A545E534E5B4D485A504A5A48425A4840544A40
5450425A5854604E485D554F494F57555F6965757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E584A3F
412A25221D1A2D2B28585957686B6665656565636365606065635C655F55615F585E5254
55524C5B5754616461616A636568606565656565686565655E675D5B594D574C4554463F
54463F5D4A435D4E496252546256525B534E5B5A545E5A545A544D5A574F54554D544C45
5748495A53564F2F23584E485A392F655E5F65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E573E35
1C140E211D1C201B1D464B4C65656865656865655E65655B65656565686D686B706B7172
6861615E4D4E5244405B514E5E5C5862636365656565655E6154545747444E3D42514239
4E40385448425D544D5A4E46544D465B4D4E574642544944514A44524A44544C46574A43
574A47544A424C44314C4436523B3965758165757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E656869625454
5F443A3627202A21205E5A5465655E5E5F55626363656563524C4649433C392E29322723
342D2C3E323652434154433F554A48626060656565656568615A5B5A4E47544838544232
51463F51463F47443E41433F4C4A4454564E51504758524C5D544D5A5049574E47574A43
574A47574E473A2823301816442F2662727565757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E5E534C5B4944
0E0706090B0C161616585B5661625D655F5A68655E65655E68635D4E48423936301E2427
0C14171115112826212D191629111048393862605E6565656161585A504754463B4E4E3C
483E35574E48665B536C5B5366534B57444449413F554F4A5A524C574E474C4842474842
52504757504749342B4B2D2357352E656E7B65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E6B7C866B605B5A463F
36272420161326161465625D686B6561645F626561656561686B6D665B5584706E453831
20151320161220272A3B36306F695C747D73656F6E65777C616A655A5049483B3545362F
230B08372828443527372F2825211D3736314C4840544C40524A42544C4651443D514842
5748474C403C3225233F322B5A4C486F869368788165757E65757E65757E65757E65757E
65757E65757E65757E65757E
656B7565727B656E7765727B65757E65757E65757E65757E65757E0A0303180B0F5C534E
4130291D1920181311585F5A5E5F5A65656161625D5B5C58626363686D66625D54715D50
A17E6990674A7C553C79644E6E6257655E586566676566646158525A4C465A4437524038
543E32484B4B1D272E0103051114172327270E1110181C2127241E4131284E463F514C45
574A423F3B33241F1A26211E4F4E486B838965757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65717A65757E65788165788165757E65757E65757E65757E0E07080C09090B040200060B
0809100F0F0E22171468645F61625D656568543D414E3B3B5E5A5B686F716E7679716B6C
66544F695D5772625B7164586B635D65635D6569696569696157585A5854544C3F54523D
624F3C7360507853421B1213251A14252021211C1C3D312954403862594D594A42534842
575043241D1D1C1815291C17492A255B5E6962727B65757E65757E65757E65757E65757E
65757E65757E65757E65757E
657B8565788165757E65757E65757E65757E65757E65757E2417152B2119291B171D1B1A
0B090A211614291715655B56685F5A615F586B777263695F3B2F292F211E28211E1A1B1B
141516171716211C19271C1A403E3E5B625C65656565605961574E5A564E544640573F37
514A3B5452435D554B957864A47B62724D3B6D4534805B4D715A43544E455450455F554B
514A45231D171D15132C1D1848271F5E6B7565757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E2A1B15180E0B11100F15110F
1C13101714112625235858525E5C586868636868686F71727E857C6E5E5B49444A685454
755749735D50634E437464597B7D736F717268686A65525A6159585A585254404533221E
281A183E372F524C3E574E406353496D604F666154635D4E4E4E49574A4D514845524C42
3F393111100E11110F6351455935285E757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E656E7765727B65757E65757E65757E65757E32251E21100C1C1310171310
0B06071811102A232149443F55535062635E656565656C6C6872747586868F9E958F9E95
859E9B8CA1A08FA4A286958B6B726A656C6C5E625A5B65585E6358625C576B6B5F746F5E
4835351E1919090C0E1F1E21494340544E435D5043514A4351423D423D355146445D4845
241B18150F0E26221F4631293A21191210112D343D65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65788165788165757E65757E65757E65757E262322201D1B1B15121C1310
16100C1C141128232151443D615B5665656165656565696965696965717765747C65747C
656C6E657177656C6E656C6F686B6868655E68655E655E58615450655E5868645D6E6463
7E777192756B664E462D231D0B0F0F0F1115151C2020201E28231E514444634E4751443C
1C14131711101D1618140A09180E0C28272868788165757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E322826382B291915121A1310
1C141121181B2924233F3B344C4C485E605C65655E656360656667656664656A6C656E72
657177657177656969656969656C6F656866656561615E5861615B615A54615B56615A58
625C54615F546E62547D6B5B7A65535F4939523C30684B406B5E545F4A4C4946423E4039
1E16141B1310151310100F0B171715272A2B65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E2F221B261C16221B181D1411
1F0F0C231614291E172D282446413F5B5A5662635E656565656969657177656969656A6C
656E72656E7265696965696965635C656363655F5D615450615B5661615B615A54615750
5E534C624D4861524C5F534B6F5E5576645979695D6D5A51624E4D5F4E4559483D362720
1D14121B13102417151A14111A1311231C163C373C51586365757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E261E182A2827221C1B231715
13100C16131015110F251D1932281F4F4B4765635E656565656969656E72657177656969
656A6C65666465666465696965656165655E5E5B545E5E58615A54615450615752615A54
5E565057524C57524C5D5A545750495A4C465A4E474C4A43474A42474A42393B34171A1A
0C0D0B1B1619120F11100E0B0B06071B141336323458656C65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E32241D2923212A2422231D1B
2519161E1411231C1A2D2A292D2D2C4947465E5753656363656363656362656A6C657177
6571776569696569696569696565685E5F5D5E5B56615752615752615A545B5A5458534E
5B534E5A524C5A524C5A504A5D524C575049544E47514A435D4A4356443D3128251C1312
241B19100B0C110E0F0C0708140F111B14113437385E727B65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E2A28272B29282E29272C2624
231816120F0C1F161430211B473228573D3058514C62635C656563656363656362656A6C
656E72657177656C6E65696965656568686365605B5B5A5458534E5E51525E514E5E4D48
5E4D4E5A504C5A524C5A4C46544A44544C4651423C5A4640513F38312D2C221C191E1513
110E0B120E10100B0C14100C15101123171592A9B38CA6B065757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E656E775E656E26201F2621202A2625282321
191310231C1A251E1B211F1D39312A4E423C58575462625E656565656C6C656C6C656E72
656E72656E726569696569695E5F58625C56615450655752685C575E58505B564E5E524C
57585057544C544646524A46544E47574E475A4C454E4C45403D3541352B271E171F1614
18141118141119151115100C1814102217156B7C8668788165757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E657881687F8824201D30221B2922202B2726
2F2826251E1B26201D2B201937383436332D4C413D5B5753626363656363656667656664
65635F65635F65605E5E5A535E56505E5F5A5E5A545B534858514A5B53485E564E5E5852
5A524C5A504A5D50475A50475748425745404C4842403F383A3029221C1D181213131110
110E0B120E100F0A0C0806070E0A0B3224236F7C8562727B65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E3329272A20192A27262D2826
231E1C2016142A1E172A24222F2D2A2B201D3F353258595665655E65655B656360656059
65605765605765636068686365605B6154505B49445B4B485E4D505E53525E56525E4A44
5A4D485A4C465A4C46574E47574A4351443D423D363A2F28221B1D1E1A1617120F151310
1C1411151011100B0C110B0C291916B2CDD39CBDC565757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E3E3C3C2C28262723222F2625
2B1F1827211D201B1A252221201B1B21222434322B433D3555514D5B5C5862635C65655E
6565615E5F5A5B5C5662635C6157525B4B465B5348574E465450485450485B4D48574C46
574C465A4646544C47544E4251443C4C443D423D352D211E201B1615110F100D0B120E10
1A1310140F100D0708100B0C21171562727B62727B65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E3936312D28262E2927272321
2623221C16191F1918231E1C2D28262A1F18241C182D2F2D413B395243405B514E5B5450
5B5A565E5F5A615B565E5652585550544C46544844574A465A46405A4742574A44574C46
5448425248404F423A493E3A3E3D38342F28332922201B1614100F131110130F0C100B0C
0E0A0B070607080707251916311E166B787E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E6A70833C30312D2726282321
322D2C2F221A2418142E2827241F1D2A27261E1B1A2227261A1F1F232221433B39493F3B
4C45484E474C4E4A4855524E4F454039322D37302C44352C4F443D524842523B3552413D
54483651443A4C3F38483933423933312623221815191212191210130F0C0F0A0C100B0C
0D0708090708110B0C1B131091ABB69CBAC665757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E758C9142413724201D252120
2621201D1D1C1B171A261D17282220322D2C312B292823222725282C292825231F1D2126
1821231E1E1A2D2A262F2E2B2424252B26212D251F2D2C22342A253B3127493D30433931
342A273729263E302B33302F2A22212418141D1413161110110E0B0F0A0C0C0708080707
0807080907081814112519166E7F88687B8565757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E525667302A2A2E2927
2929272B2523171310211E1C302D2D322D2C3531303A35333E3A323837302A2F2B222122
241A1621191B211A1A251F1F201D1F201F222A21202B201A241E1D2B29252B292427241F
312B252C261E272725281F1C261D181914131C1A19120F0C120F0C100B0C0D0708090708
0907081F15111610115D55568999A165757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E74818D3C302E292321
2721202822212F2725352D2B322D2C33302F2A2625262222291D1D321F1D2D1D19241F1E
1B18172021211814131A1C1D1F1F1F1E1C1B171312141516141213141010151413171714
17171415101116101014101016121212110F0F0E0B0E0A0B0F0A0C100B0C090708090708
1F151B1F151230282596B0B682A0AA65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E6B7F85616B6F332D2B
2823212D2826292422353130231E1C292626211C1B28242439332C2A2A28222323262322
26201D3329271F171A1E1E1D1D14121E141218110F13110F16110F1E16141E161415100F
14100F15110F1D1614181310171210120E0B130F0C100B0C100B0C090708090708110B0C
251D19251915A6BDC59FBAC265757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E696F7D392826
2F28262D28262823211C1B1A2C29293834322B2A28231F1D281E191C16151F1B1A221D1B
17151C1A1B1B1A1617211614191118131210141310120F0C151310141310121210100E0B
0E0A0B100E0B171210110E0B0E0A0B120E0C140F11100B0C090708100B0C1B15122B201C
261916A6C0C9A6C4CC65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E6F858B4A4C49
2C28262A26252823213029272A2827262323211B1A1F18171C181715110F221D1B1C1618
1D16171A110F181117100E100C0A0B110E0F120E100F0A0C120E100F0A0C120E100F0A0C
140F11181411130F110F0A0C08070808060707060708060714101116110C100B0C170D0B
97A8B0A3BDC665757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E8CA6B0
5F5C5A292220252120272726272726302C2B2B2528221715211A1816131017110F13110E
18120F0E0A0B0D0A0B120E0F141011100B0C130F10100B0C140F10100B0C2518150A0708
120F10171310140F100907080907080E070816101118111216101125181637251C6D4D3A
8F9C9D687B8565757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
8CA6B0615654312E2C231E1C302929322C2B322D2B23221F26221F1C141A130F111A1310
130F101714111A1511151011100B0C100B0C100B0C100B0C100B0C181410120F11292D3E
34363A20161E100B0C1510111C16121C16121511112A221F2B201C251916422E2895B3C3
85A9B965757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E94B2BC6156543C3331241F1D222222302F2E362F2E2F211A241C18191510130F10
0F0A0C120E0B120E100F0A0C100B0C141011110B0C141011110B0C0F0A0C282B2F251D28
372D2B443B343A3030453A363328231A1512251D1A241C192E2927452E26A3B7BF8FB0BC
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E62727B89A6B055453B3D3532322B29332F2E33302F383534241E1C241C1A342A26
2D2823211613191411151011151011100B0C100B0C18141A151012191511120E0E1C1B17
24211D0C0A0C0C0D0C0E0E0C0C0B0D17110F221B192B201950382B8C93A088A9B9657881
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E8FB0BC55554D241F1C2622223936374142423D3937261E1C1B1517
1E14132D2523292522161112100B0C1C181F201B232824201F1A20372E2D1C161D3C3534
2F272A302826372C282F2522352B27473E34342C28594236A3B7C293BAC66F858B65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E8FA9B6A6B2C64D46442824242421212D333F464445554D49
555652312C2F26292E424254605C5A3D31322D29352F272B403E4E352E2D2F2723352E2B
30262535242135231C31292640352E573E3139251D8CA9B685ADBC65788165757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E72898EA3C3C95C58653A35362A2E353F444B42474F
3B3D3F4244425453565047423E3834322C2A3C352F2D2626201B17221D1A302C2B2D2826
382620422D2644352E52413A402922433E4999C0D699BAC665757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
656B7565727B65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E8FA9ADC0E4E8BACAD9514F6249464F
6B6B8366616D524545403A393E3C3C52494F5B4E4E524A48645753534A414E49465B504E
48463F3B413B2A28275C6478A6D1E4B3E4EE85A3AA65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
657B8565788165757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E6B7F8595B0ADACCDCC
95B7B68398AA99B4C38A98B45257713F485F363A3D3838393838393A3A3C3936382D2824
2D2B278C9EAAC3E8F4A9D1D5758F9465757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E6B7F816B8285728C8E96B3ADADCAC3B0D1D2B3CDD7B3D4DFB3D7E2B6DBE5BDE4F1
C0E7F792B0BC65788165757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 200},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000b1P00`40o`000?l0003ooooooi7oool0
0?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool0
01kooolHO7in00ImOWQfJEalKF1lKFElLFQlKFD3O75Y00MlLFQlKFAmKEmhJE]iI5EdG4meFdh016mH
B`04KeM:L5A5JeA4JeA50V]DA003ID`oO7inO7in009lOWh00gaoOWaiNGanOP08O7in6OoooaQoOGd0
1X1mN7UXG7m/H7m/I7m`J7m/I0AoL6P01Wm/Hh1/Gg]XFgaSEGIKCgQKC@AbEd/0179FBG=CAFiCA6iC
A@9^Dd@00fI:?GmmOGmmO@03Ogem00=oN7QoOGeoOGd01gmmOASooolHP81n00J1OWIkJef0Kf60KfF0
LfR0KfD3P7=Y00N0LfR0KfB1KemlJU]lIEEhGTmhGDh017=JB`03LeQ9LeE5KeE500=_EDD00faC@h20
OX20OP03P81n00>0O7V0P7j0P7h01h20OQWooolHTX9h00F=K5RBL5bBL62BMFBBL600199eI004TW1P
TW1LSFaHSFQD0XUOC0F3FdP018=GA7mG@7mGA7mG@09oEd@5TX9h00>BOWFBPWRBPWP029:2N23oool0
01koool01WanOWajNGaiNGanOWajNGaiN@UlOWh2O7Yi00=lNGUlOWilOWh017anOP0APH=nO6eUO6eP
O6ePO75XO6eUO75YO6ePN6EELfEELf5DM5aAJUQ<JUQ;JUE8JeA7JUE8009_F4/2KeA700=`E4Y[E4M[
E4D00V]UG003IF1KO7inO7in009lOWh00gb3PWanOWanOP08O7in6Oooo`06OgemOg]kOgYjOgemOg]k
OgYj2GmmO@9oNg/00gmjNWmmOGmmO@04Ogem0162P7alJV1oK5moK69oL6QoK6AoL6QoKV=mJUekJUek
IU]lHeIeGe9eGDmbEd]cETU_EDT00W9GB`9bEDP00g=CB6iCAFiCA@02KUa@00=VE4aoOGeoOGd00Wmm
O@03OgmoOgYjOgem00QoOGdHoooo6820OP08P7mhNf]MP6mPP6mUP7=XP6mUP7=YP7=W0X5bIP06PFiQ
PFeMO6QHO6=CN5e>N5]<0g=JB`9cF4T00g=EAfmEAFmEA@02KeQ800=/Dd>0P7j0P7h00h20OP03P7ai
P81nP81n00N0P7hIoooo00JBPWRBPGNBQG^BPWRBPGNBQG/9TX9h0Y:1M`03TXEkTX9hTX9h00BBPWP0
1Hm^FXm^Fi9`G99eIi9`H002TWET00ZBLf6AM6BDM6BDL5f?KER<JEB=HTj:Gdb4FdN6GDX2Pe]80X=I
AP9oEd8017mG@7mMCWmMCY9eIPBBPWP2TWme2I:2N23oool001koool01GanOWb3PWajNGaiNGb3PP02
O7in00AlNWUlNGUlNWUlNGT4O7in0Wb3PPMlOWh03GQjMGIYF7a]IGaYHGaaJGa]IGaYHGQYH6]UG6AL
E6mDC6mAB6mIC002Kf1B00UdGe5[E4MVDDAVDDAVE4MVE4=[E4A[E4M[E4X00WaZH@IlOWh00gajNGai
NGanOP07O7in6Oooo`0;OgemOgmoOgUiOgYjOgmoOgYjOgemOg]kOgYjOg]kOgYj00AoOGd2Ogmo00=o
NWYoOGeoOGd017mmO@05OG]fO6YKOfaTOfYPOg1X009oK6@02Ge/HgQXGG1QEWILDWQICGEKCg9MD79K
CgEKC@03KU=600E^EDQ^DdA`DdE^DdI^DdP00W9IC003LVi[OgemOgem00=oOGd00gmkNgmjNWmmO@07
Ogem6?ooo`:0P7h0181lNX20OX20OX1lN@^0P7h00h1lNH20OX20OP04P81n0161OWJ0Kf20KfF0Kf60
LfV0KfF0LfR1LVJ0KUmlJEYlIeQlHe=hHE9cGTmcFdacFT]_EDL00g=HB@04LeE5LeE7KeE7KeE70VaC
?`03K6ENP81nP81n00f0P7hIoooo00BBPWRBOgFBOWFBQG/2TWme00FBPWRBPGNBQG^BPGNBQG/019:2
N0>BOgD6TX9h016AKeZELf6BL62BLf2BMFBBL62BMVFALEf:KEZEJeB?IUB9IU27I523GDZ3FTR1ETAo
Ed@00XAKA`05Q5U6Q5M2PEM6OeM4OeM200:5KV000hE^Hi:2N9:2N003TX9h00>BPGNBQG^BPWP01i:2
N23oool001koool2O7in00=lOgilNGUlOWh00WanOP03O8>2O7inO8>200ilOWh04H5nN7aYHGa]IGa]
IGaYHGa]IGa]H85aJ99fKH9fJX5`IhASFgYHBgYEC7YECgE?BW1@A`03JeA700A[E4Y_F4]`EdY[E4L2
ID`o1WanOP03O8>2O7inO7in00MlOWhIoooo0gmmO@08OgQhOgemOgemOgemOgmoOgYjOgmoOgYj3Gmm
O@0APWehO6QNOfaROfaTOfYROfiVOfaQPViVR6iTMfaRO6MMOeeEMUM;MUM=MUM?ME=;Le=800=^DdH0
16iCB6mEB71EB6iCAP9VBSd6Ogem00=oOgmoNWYoOGd01gmmOASoool3P81n00>0O7V0P7j0P7h00X20
OP03P7aiP81nP7ai00f0P7h00h1nMW][GH1_H@02P6mU00R0LfR0KfB0KfEkJee^IeagHUIhFdmcFT/2
Lee?00=cFTacF4U_EDL00fmEA`03KeM6KeE7KeE7009/Dd<7P81n00>0O7V0P7j0P7h01X20OQWoool2
TX9h00>BOWFBPWRBPWP00Y:2N0BBOgD=TX9h00B?K5R?L5jBL5jBL602TW=S00^BL5n?KUj2J5InHDn9
FDeoF4B2FdR2Gdj2Gdb0F4IoFdH00gmGA004OeM2PEU4O5A2OeM429:2N0:BOgD8TX9h8?ooo`007_oo
o`9lOWh00gb3PWanOWanOP0CO7in00AlPgilKEalKEalKF02O6eU019lKFUlLFUlMVf1MW1hMV=mK69m
J5imJ5MiGe9nJ5YoFDmdC4MdF5A`Fdm_E4M_DDA`E4M_G4l2JeE847anOQWoool2Ogem00=oOgmoNWYo
OGd04gmmO@04Oh1lOfYKOfaOOfaR0Wm/I00BOfaVOfiTOg1XPW1ZNfiOP6ENNf5FNemBNE]@Nf1ENU=;
LTm6LUI>L5I;Ke=6Ke55LeE8KeQ<0VU?@Q1oOGdHoooo0h20OP03P7aiP81nP81n01:0P7h00h1oN81[
GH1_I004P6mU00b0Kf60KfF0KfElJeb1HU]gGe1gFdihFTmgFe1cDDM_E4M_Ed/3KeE700AcF4U_EdY/
Dd=/Dd<@P81n6Oooo`:BPWP2TWme59:2N004TViJTViLTW1QTW1S0Y9`H00BTW1NTW9OTVmOSf]ISFAC
SEa@Qea8QeY:QUI:QeU:NT`oOUI4OUe:O58oPEM4PEU6OeU6PEY80XmkLQ2BPWPPoooo000Noooo67an
OP03O7mjO6ePO6eU009lKF004ga]IGaaJGa]IGaYHGaaJH5fL85jJgeaHWQTFgeXFWALCgYSEGEODFmA
@GALE6]KCfIDAf]DAg=UH@02MVYU1ganOP03O7YiO7UiO7in00IlOWhIoooo67mmO@07OgijOfaOOfaR
OfaOOfaROfaTOfiV009oK6@03gm`J89`JWmaHgeXG7]QEgeSEgIICgaPDgEGC79@A7EKDfiFBfiCAW1C
AVmKE002LUiE1gmmO@03Og]kOgYjOgem00IoOGdHoooo6820OP04P7mhP6mPP6mQP6mP181_I@0=P7=X
P7=YP6mUNf]MO6=HO69EO69DN5]?O61BLe=8Le97LeiDKeE7009cEDL00fiGBg5KC75KC00@P81n6Ooo
oaRBPWP2TW1L01JBL5jBL5bBL6>BL62BLV:BL62BMVFBMFB?JeV<IE>:GDj=H52:GTb9GDb8F4Z0DD>3
ETR1Ge1oDSn4EdB1EdB7IED2S7EV1i:2N003TX5gTXEkTX9h00JBPWPPoooo000Noooo5ganOP03KeaD
Je]EO6eU00=lKF002GaaJGa]IGaaJGafKGaaJGaaJ7a]JH5aIh5]F`02OFAG00QiGe9jF4ieEdY[CCm[
E4M_E4M`E4MWFU42MWAd1ganOP07O8>2O7inO7inO7inO7YiO7EeO7Ui009lOWhIoooo5gmmO@08NVYS
MFaWOfaROfaOOfaQOfaPOfiVOfaT0Wm`J00?OfiVOg1XOfaVPViROfQIOF5FOF5ENEa@NUM=MEI9L512
L5I;Ke=6L5=6J5=9009iKV`7Ogem00MoOgmoNWYoOGeoOGeoNg]oNGUoNWX00WmmOASooolGP81n00J1
NG:0OgR0Kf60Kf20KfB0Kf42P6mU00j0LfV0KfF0KfF0LfR0KfF0KemkIeQlHUMlHUAhGDmhFTicF4Uc
EDMcFdl2KeE700=^EDMkKVMkKVL02820OP03P7aiP81nP81n00F0P7hIoooo5i:2N00DS79UW8MdTW1N
TW1LTW1OTW1PTW9RTW1PTWETTVmOTW9RTW1PTW1NSfYCS6=BRV1@RV5>QUU:QE]8P5M40X5KB@03PEM4
O5M4SG=X00:BNfl7TX9h0Y9oM@:BPWP00i:1Mi:4NY:5N`02TX9h8?ooo`007_oooaIlOWh014Hj<T97
?gIYG7a]H09lKFT2O6eU00=lLFQlJEalKF000Wa]I@0=O6ePO75TN6QNN61GN5aDNF1>KeM7KeQ;M5M:
L5A7JUa?M5mAL5Y=00elOWh2O8>20ganOQWooolFOgem00]NCD=PHE]bHEQoK61oK6IoK6AoK69oK6Ao
L6QoJV1oKV@00Wm^IP0=OfaQOfiSOFMLOF5FNeeCO5m?MEI9MEM;MEE8L5=6K5Q<MEU<K554009lN7P;
Ogem00=oOgmoOGeoNWX00WmmOASooolFP81n00E]GU:1OWIaGeJ0Kf60KfD00X1_H@04P6mUP7=XP6mT
P7=Y0X1cJ0:0Kf@02h5YFh5VEgaQE7aQDGQHC7QJBg=EAfmEAfmGBW=GB6aC@`02NgMe3820OP:0O7T2
P81n6OoooaJBPWP02f]EA[2@O8aXEi9`H99`GY9`Fi9`GY9eI99`H99cHI9gJP02TW=S00fBL5nBKUbA
I5:AIU2=HE29GdZ7EdN7FdR1E49lEdB3FTR1E4><N6l00XmkLP^BPWP00i9oMI9kLY9oM@02TX9h8?oo
o`007_ooo`9lOWh00gajNGaiNGanOP0@O7in01][IFTo8alF6R9lKFAlLFAlLFQlLFUlLFQlJF5lLFUl
MW5lKFElKF1lH5QhEE5_DDIcG4ehH5AdI5A_Fe5dFdieF4][EdE[E4AVCD9VDDAUC3l04WanOQWoool2
Ogem00=oNg]oNWYoOGd047mmO@05N71bCRXT7RL[O6YPOfiQ00=oKVH04gmZHWm`J7m`JWm/HWm^HgmU
GGeOF7UMD7]SEG]OEGUQDgQKDGIKC7EEBG1FAW1CAF]@A6iEB6U<?`0BOgem6?oooaF0P7h01H1mNe4_
9d0o>G][GH1_H@04P6mU01:0LfV0KfF0Kf60LfN0KF>1KF21Je^1KEelHUMlHUAlGE5hGD]cEdQcF4Qc
EDM_EDMcFdaaEdPBP81n6Oooo`:BPWP00i:1Mi:5Ni:2N00@TX9h01^:N7518QZSQ6f?KUNBLV:BKUjB
LV:BKUjBLf>BMFBBKefBL5jBLf6BJenALU^BL5VDKE^=He:<HE29FdR9FdJ0FDJ1Ed:1EdJ1FdN4GDVE
QG/04Y:2N23oool001koool2O7in00=lPh9lNWUlNGT03ganOP08P8:2?B/NOW9OMVUHO6eUO6UQO6eU
O6UQ0Wa]I@07O6UQO6eUO75XN6UPLfQHN61GNF1B009_FD`02GAIB7EKBfYDAfmAA7ADBWADAg1DAfmH
BfM6>002MVYU47anOQWoool2Ogem00=oOgmoNGUoNWX03gmmO@0LP7inCcDWMFYR@ChjOfaTOfYPOfiV
OfYROfiVOfaTOfYROfiVOg1XOFYQNfUKOEmHO5mBM5U=MU]?NE]<N5a>KeE8ME=6MEE9LU=5L5=6KeE9
J4/o0WabL11oOGdHoooo0h20OP03P7ajP81nP81n00j0P7h02Gn0OELm;ViWIR8O8X1_IH1_HH1cJ81_
IH1cJ002P6mU0160LfV0LfR1Kf>1KEj1HUYlHE9hGTmlHE9lHE5hH55cF4UhF4UcF4U_EDE_EDM_EdQ^
Ed/04X20OQWoool2TX9h00>BOgFBOWFBQG/03i:2N006U8=iBblSP6AMEc/fTW1PTW=P0i9cH`0CTW1P
TW=STWMWTW1PTFmJU6IHTF=BREm<S65>SfA@S6A>Pee<QeU6Qe]7PEU4OUM2O5M4PEU6SGU_00:EShP@
TX9h8?ooo`007_ooo`9lOWh00gajNGanOWanOP0?O7in00D_81QlLFV1MW1lKFAlKF000Wa]I@9lKF00
1ga]IGaaJGa]IGa]IGe>CGPl?7@f=`02M3<e00Yd@cm_DDM_DDA_Cd=[D41ZE4A_E4M`E4=ZC3iQ?2h2
ID`o2ganOP03O7YiO7UiO7in009lOWhIoooo0WmmO@03Og]kOgemOgYj00moOGd01DP_989iM4Y9AWaZ
H7m/H002OfaT01EoK65oK69oK6AoKVIoK6AoKVJ0F5=kCTQiAD9iA3mf@SifCTIeEDUeEDIbDTE`DD9_
DdEbDdIcDdA/Cd5[BC/00VmID@]oOGd00gmkNgmjNWmmO@02Ogem6?ooo`B0P7h00h1lNH20OX20OP0=
P81n00EG?Bj5Q7lW:2=kJef0Kf400X1_I@03P6mTP6mUP6mU00:0KfD02h1cJ85SFGaPE7aEC7aEBWQC
AgQMCWQKC7QKBG=GB7=EA@02LeE700=cEDE_E4EcF4T00W]^Ia20P7hIoooo0Y:2N003TX5gTX9hTWme
00nBPWP015<f9iF0M5Dh;8m^E`>BL600399`Gi9`Hi9`H99bHY9`H99cHheKCHeUE8aJBXaLBXUJB8U[
D@:7GDL01h=F@h5I@hIGAX=GA7mG@X=FAHMXEP02W9FA2i:2N003TX5gTXEkTX9h00:BPWPPoooo000N
oooo0WanOP03O8>2O7inO7in00ilOWh07F]UILBc/WIYIGa]IGa]I7a]H7a]IGaYG7aUF7aUEGaYGGaY
HGaPG7aEEGeJEGA3>Vlf;6hk=Fln=Vhc<W4l>FI6?VID@f]?@fY@A6mDAgADBVmCAGADB002H3PX00=[
DD=lOWilOWh027anOP03O8>2O7inO7in009lOWhIoooo0WmmO@03OgmoOgYjOgem00ioOGd07GQ`L:NH
UdA2@7m^IWm/Hgm/H7m/I7mZGgmXGGmXFGmZH7mZHWmWHGmOFh1NEgU5?GPk<W<n>GDo>7<j>7I6?fi;
@FiCA71?@VaAA79CAWECB6mBA7EBAP02IdDg00=eIUmoOGeoOGd027mmO@03OgmoOgYjOgem009oOGdH
oooo0h20OP03P7aiP81nP81n00f0P7h01h1mNX5oNbLX8h1cJ81_I81_HH1_I@02P6mS0120Ken0KfF0
KfF0L6J0KF>1HeUlBD5l@CMhA3ih@SYhA3ihDdEcE4EcEDEcDD=_EDD2LeE700A_E4=cDdI_EdQ_EdP<
P81n00B0O7V0P7j0P7j0P7hIoooo0Y:2N0:BOgD?TX9h00F:N6mUCT=K@3BBLf>BL5`00Y9`H00FTVmM
TW5OTW5OTW=VTW=STVeOTW9RSEA8S4TlRCldS4Y2Qd8gS513PEQ4Q5Y5Q5M2PE90PeU4PeM4PEM2PE8o
PEU60XU]G003W9nNTX9hTX9h00RBPWP2TWme0i:2N23oool001kooolCO7in00@e:B<E7AafJEQlKE`3
O6eP01IhJE]cG55fI5UlKF1lIEQhCdA_=RmZBCmN?BiQG4a^KE]a?S=Q:R5_<Ra`?3M[BTA[DcaVD3]Z
E4A_E4M_F4Y_DD@2KeE800=[BcalM6mlOWh03GanOQWooolCOgem01e8=2dk@3iiJUmoK5moK65oK61o
K65mJUikHEElIEYoJUioJ5amF4miACehDTU_?S5]D4E`E4Qf?39[<BMe>C9`@CY^C4A^DSe[Cci_DdEb
DdIbEDQbD4@00W9EB@03K4i2OgQeOgem00eoOGdHoooo4h20OP03DCdeKVMSNfmW00:0Kf@0181_HH1_
I85^HH5YFP:0Jed03X1^HH5SFH5EBh5LE7]1=7Q:@G=0>7Pj<G<h;WQ2>Vm8?VmBAFmD?fmB@`=cEDL0
17=BAG=JBg=JBg5JC@n0P7hIoooo4i:2N00MAc0X_IZ6TW=VTW1QTW1OTW1PTW1OTF]IU6]FUG=NTViN
TVeKTE]BTUY;SeiBQC//Se54RC/dPC4WQcd`QdXmO550Oe]4Oe8iPEM5QUM6PeM4PeA2PeI400:3GDX0
0i9oMI:8PY:2N00=TX9h8?ooo`007_ooo`AlOWh00gajNGaiNGanOP0;O7in01iKCdnELV9PDTYlKFEh
IE]fJ65lLFQlIE]iG4]ZC3i[AD=d>cTl3PT_:RAdFU1nFE6HX9f4CTMW=ReJDCYEEdQ8>2Y>:21W<beV
C3a_C3i_E4QdH4ieFdY_F4/2KeA700=P?2i[BcalM6l03GanOQWoool4Ogem00=oNg]oNWYoOGd02gmm
O@0NKf1PT79T=3LfO6YPOFQLO6UPOfiTOfQNOf=BMEE6LU9;O4a5EaX?ETDlNE9:Ndi8QGA`M4<kKdDi
Je0lHdPmFcDXH30WK3deJdlnKddmKeA6LeU;MEI8LUE90W9CAP03JDTlMEmEOgQe00eoOGdHoooo4X20
OP05Ng5_OW5T8RPYNf]MPFiN00:0Kf405h1^HH5[FGaPCg]REX5MD6TU5H5SEGa=AGM:@W5ABFDk<7=E
AGE@?fhl=6Tc9g<h;Vm:?VmD@FmA?VmGAW=GB7=EAg=GB002LeE700=cFT^0N760P7h03H20OQWoool4
TX9h00>BPGNBQG^BPWP02i:2N00NOVURJ593I4m4SfiKTFeFUGMTTViKTVeHS6UAS5i<VGESSea;JRDC
]Wm[S4@jQe=6N48eLc<UOei8OdDdPSXcMC0RTShaOE]7PEHkPEA0PE]6QEQ4P592PeU60X=GA003S6eJ
W9F>TXR200fBPWPPoooo000Noooo0WanOP03O7YiO7UiO8>200elOWh07T<f<3Ho?gIYHGa]H7eXFWIK
DGa]IGa]HWUB@F]4=ST?2cDh=kC@b8NGU8N[[H6GWWafMX:PSY:LU9jRYGYdLEPn=B@P534P6F90>6YC
@gAEBGALDWYSDGEGA`9_E4L016mEB61>CFMSKGIdM0alOWhIoooo0WmmO@04Og]kOgYjOgmoOgYj37mm
O@0NDchg@DI7JEYBOfaOP6UMNEmDOfiVOfaRP5M5Ld`lDQPBFd]9V8F2FDi=OgikO6e^O6ISPhYmQFQS
Q7=`KeeEGS`b>2<FCbXQITDlK510Le97LeU?NUm=MEE60W9EB004LUA8JE59M6]^O7Qh37mmOASoool5
P81n00>0O7V0P7j0P7h02X20OP0NEd<lFUABHe=8P6mPPFePNfMJP7=XP6iQPEe9N5E3I20HP6=MMdA0
>aD@MeQ>Mde3NeiEPGI/Md0hJD/oHTXlGcX_BBLGKSDYJdm0Ke4nLeA7Le]<N5i;LeE70W=HB@03LeM8
Le];PGQa00f0P7hIoooo0Y:2N004TX5gTXEkTWmeTWme39:2N00NAc0YWGMSPUm?TW1LSFIETWIUTW=S
TVQDQeDnQ5A1K20HZH9dJa/CGQhCQT@fRDDdSfMFRU54OcT_JcDQICd]FbdPFBLFUdDbPEm5Pe0mQEe:
QEe8QEY4P5A40X=IAP04Pe]8S7I]VXIcUHQn39:2N23oool001koool2O7in00=lPh9lOWilOWh037an
OP0OKfeeABXU41TOMVUHO6ePPGY[O6ePO6eUM5]?J4dhERhOE1T>?a8?KCT`LdTmMUA:O6eLO6AANE]B
KDi8M5Q;TVeMYXM`TWIX=bTO;A`IGC`cJE53N6EDNFAHMEmA009_DTD01Fm=@V]==EUAAUI>DF]ZM00;
O7in6Oooo`9oOGd00gmoOgmjNWmmO@0<Ogem01mjMGU>;BL>7BAiJ5YoK662LfElIEYoK6AlHEAgE3eV
=2AN70lj6QQ/CTIkGE=lI5aoLfUoK65oIUaeFU5lI5R8K6:9KV1bED`i9A]8:25VAcY]D4=hH59iGe=h
G4d00W9BA@05LU14L550IeeKJV5RMG9h00]oOGdHoooo0h20OP03P7aiP81nP81n00^0P7h07h5oOT/_
9b/^;W][GH1_I81_H7]SEX1_IH5XFGiK@W4j:5lN4DDY9ViVGH5bJH1hLH1kMH1gLX5`IWa[GH5`Hg]_
J6MHCdlj<c/R66Lg:FmD@g=DAWMODGQNCgQMB`02LeA500AcEDMcG4mcKG1lMgD<P81n6Oooo`:BPWP2
TWme3I:2N003S7af=QhFU7AO00:BL5l06XmXEHmXFI9`H8mOBh9C=glg9UDH3HEICHYoKIAjKIF?QI9i
KI9lLXaYFYB2LHm[FH9`J5Lh;dDY8DDM4iE9<XMPBXaOBXYSDXIJAX=IA0:3DT001H=KAh5`J8MeM9R:
R9b?OP0;TX9h8?ooo`007_ooo`9lOWh00gb3PWanOWanOP0<O7in01m_KGE5:RD@6AmfJEQlKF21NV]l
KF1lKFEdFdmXCCQF;QmD6@ho4Pm]>C1cBCefE4YlKEalI55iFe9]CTQdF4^BKEfVQg2BMVPg:Al]71UM
?3=YDD=hIEAiI5QeGe400VmBA@05Kde2JddeFE56ETiAJfYd00]lOWhIoooo0WmmO@03OgmoOgYjOgem
00aoOGd07gYeNDh]9`hM97UXFWm/HH9cIGaUFWm/I7aQE7MD?FHd95hL3cXJ66a>AW]MDgaTG7mcJGm/
HGmVG7EJDGaTF8Q/HXU^H79EC3TU6dPX8FI7>Ve@@gQPDWUODgQLC@02LU9500EbD4A`DD1WGE]ZHF9e
LWP02gmmOASoool3P81n00>0O7V0P7j0P7h02h20OP0OPGmnBblW:bh^Nf]MP6mTP6mPNf=FP6mUPFQI
OU]2LCXXGahAABTVKVIMPG9YP7QaP7]eP7MbPG1VO6]MPG1SNfmXIeQ?CcXc>b8HIcLYKeA3LeA6MemA
N5i?N5e;009cE4D017=EAg=LCg=]L7agM@b0P7hIoooo0Y:2N0:BOgD=TX9h00><O7Hf7QJDM5l00Y9`
G`0JSfQESfQITW1PSem;PU<gOcLVEAP=QEU=RWm]U7Y]UHn5TWU]TWabS6UJU89aSf]IPW1XEcP_ABTQ
AAdCUDTbQf1:S5m:RV=BQUY6PeU40X=B@005Pe]7PG1XQgEdV8Z8W8mn00^BPWPPoooo000Noooo3gan
OP96>S807aH=26=;@f1>BWa]H7aUF7aMDGaUEGa]G7iXEhUWGYBHPlG5YhMoM7eLFWAHCfXo=fdl?6Xf
=fXi<VDN66HX95/`:W1=?gE2>h9EBc4B2C4L76U:@W=LCGUTDGEGA`02JeQ:00EZF4]dDD>7MF]jLG5U
H6X02ganOQWoool?Ogem0Ui=@`0O=1hHKEMB<C0bO6YMOfQKOfAGOfQJOfaOPVMIPUeCNfiMTGMWFDa5
NeA@NE]@M4a4N59?N4e6MdTnKc8ZLclhJT<jNeI8M4Q0MDi5=Q89B2/WJTa3ME]=O6=BN5Q9009`EdT0
1FmDB7EBAGQZHG=XIFUSKP0;Ogem6?ooo`n0P7h2KEiB00A;;bMbHf0M7b9kJed2P6iN01V0Kf20KfB1
J5UhEdYTC3]M<bdk8aegD4QlH59lGE:1J621IEJ1FDYhAc]lEDUhFdb0H4m_D4EPBChk4`UW?S=^E4Ig
GdilIE=hFd`00W=HB@05Le=6LeM:K6IKJf=MLFie00^0P7hIoooo3i:2N09[EDH07e4a:GeME65<@8m^
FY9]F99bGI9fHi9`HHUGAWeC?Vhh:E4=35hR7HMEA8aOCY9]GYM[GHmaFHmFA8eC@XYKBI9iHXMFA7AC
Ae4h;4PB29]NBXUTBXeXE8UOBX=IA`02PEI400F6ETB1HU1oLFUcGE^ER7l02i:2N23oool001koool5
O7in00=lNWUlNGUlOWh01WanOP0RKfU]8aPB8aPB6a<?8S@fO6eTO6ULO6AON6AOMVULO61LOV9IId@d
IDY2O75]O7m`PGmdQhQmQhMlPI1jR7]WPgm[Oh5UOgALMDa0NDQ3NSP`M2`PKRDI>1@?AbDVKE57NF1A
ME]:0W1?@`06JTe2Ke55<AT@>30PN75aMWAd2WanOQWoool5Ogem00=oNg]oNWYoOGd01WmmO@0RNW=d
;QdE;QdE9QLB3b<WK5YDOfYMOfMOOFAKO6IJOfEMPVEILDTiK558O6aTOgEXPViXPW1XOfiVO7=UQ6=H
NfMJNF5ANEM9LTDlMTe5MS`cLS8VIBDJ>ALBFCHcLEI9O65BN5Y90W=@A006K514LUA8BBTMFE=;LFU^
O7Qh2WmmOASoool>P81n01:1OW`a8APa8AP^71DM7b1SCdR0Ken0KEn1IeV0IeV0KEn1JUUgD3igGe9k
Jef0Kf60HeekGeH2Me]B00ilDD]bE4]cASic@3Q_@SUcDdM_@SIZ>B]G9QY17AE_C49gGdilIE=hFdT2
LeA500E_EDMcFT]I>2V0O7Y^Ifd02h20OQWoool5TX9h00>BPGNBQG^BPWP01Y:2N00RS7Yc9QL?9QL?
<Q/DQEe?OeY9TVmJTVQHTFeDUFiJTV]JREm8PU4kVGaZSfmJTVEFSeeAREM:QU95RDa2Q4DnP4DkOcH^
OcH`ODXkPT`oMT8dJCLWCQhEI2PKV6iFTF]DRF9:PeM40WmD@P06Pe]7Pem<G3//^Jf^Q71]UHQn2Y:2
N23oool001koool5O7in00=lPh9lOWilOWh01WanOP0ROh>8l/fml/fmkk6ALea>MVULO6eOO7IPPFAO
O61LO7YTOVmNOemBIdPmMV1EO75YO75XO6UQO75YO6ASOF1JN61DNF1EM5]>LE]8HEa6JfE=NVaHSWIP
PfIMHTHhI4dmM5a>ME]:0W1HA@05JUA4KeE8HT]18R0MJfYU00]lOWhIoooo1GmmO@03OgmoOgYjOgem
00IoOGd08X>0P[JJU;JJU7MSESTg=7aZH7m/Ggm^GH9QGGaSG7mcHH9VFgeJCFE7?7aVG7m`J7m^IWmZ
HWm`J7mWHh1UFg]ODgaODgIKC7IHAf]EA7=EAWIEB7QEAVU8@ETh<6Y@@WUMCgQJB@9cEDD01VaAA79D
B6E7?BDR7gE`KWahN0YoOGdHoooo1X20OP03P7aiP81nP81n00F0P7h0485oOW5[JW5[JPdO81LN8H1_
I81_Gh1[GH1RG7][GH1_H85QF7QGB6U=?h1_IH1cJ@:0KfD0481cJH1]Hh5]GGaRE7aQDWQMBgQHB7=A
@gQ9@6m2>F8j<58^:5Ha:G=GBWaQDGQKB@9cEDD01VmBAG=GB5e4>C/_:H1lNG]gM@Z0P7hIoooo1I:2
N0:BOgD7TX9h02:3KV]4<2Q4<2P000I>?SRELf6BK5RBJ5Z?HEJ?MUbBJ5Z9EDQnC3Z:J5BENFZBMFBB
KUjBLf>BMFBBJ5R=Je:=He29GdZ9FdJ1E427BSj4@cQf=BaR:B5I8aec@Rj?I5B<HDZ3Ed@2OeA000J3
E4B3FdQ7<2N7KF6LS8F?Ng8:TX9h8?ooo`007_ooo`ilOWh02HeoIga]IGa]IH5oNGeaIg=UF7I]H7a]
IGajK@02O75]01N2MFUoJUUZAS]WBcmfJ5alMVelLFQlKFElOf]mK5edE4MdEDE[Ed=SCd=NBcYS@CIS
ACISA3IWBcIZED]^FDadF4iaDTD00V]<@`05IU10IU52?BHN7b<ZLFmi00]lOWhIoooo3WmmO@0RR7i`
MFa/MFa/PWE/OFQMN6IIO6aOOfYPOg=VOfMTOfiVPg1SO69CKdXnLEM;O6UPOg9ZOfiVOfaTOgMYP6EK
NEQ;NEU;LeQ6Ke95IdhlJTHjJT/jJTPjK4`jJTi8KEA5MUU=MUE60W1?A005Je51KU54AbTQ8RLUK6IY
00]oOGdHoooo3X20OP0AP7mhLFmcLFmcP6mQO6=FO6]LP6mPP6]MP6mQP6=MP6mQPFiNN5e>Le53O6MI
P6mUP7=Y00:0KfD03h1cIh5RFWaNCgaQDGQKBWMGB6mB?fm>?fmB?fm>?fm??f]=AViD@GQMCWQJB002
LeA500E_ED=cEDM6;2<k=R]/IEh02h20OQWoool>TX9h0268L6R8L6Z8L6Z?JEF:HDfAKeZEL5bBKU^B
J5VBJEZBKUV:Hdf2DD66F4FGOFREMfZBLV:BKUjBMFBBJ5Z=G4j<GDV<ITn4FDF0ET>2DS]oDCioECio
CcimCcj1E4B6FTB9GDP00h5F@P05PEU2Q5U7=b8KTW]aS7QV00^BPWPPoooo000Noooo3GanOP0SN7Ie
MWIcN6EDN6EDKe4oIUUEJfESO6UQO75YO7I]O75YO7I]PFaZPVQQOf5BLde4MU]AO6eUO6AON5QAMVUL
NFMHM5mAJd@jJdY1L4XlIdPjIdhnJdllK54jIdLfJTXmM5E8KeA7L5=5009[Cd<01F]@AfmHBb/J6007
0f1JE`0;O7in6Oooo`eoOGd08geiNGaiMWeXFGeXFGUMCWITGW9VGgaXGWm^I7m`J7m^IWmbJX9[IX1U
FgaLCG5>A7UQEWm^IWmYHWeQFGa/HGmXFGUND7=9?G=AAG5<?FM;?6Y<?F];>fa>>VY6=fQ;?G=EBGEF
BGIDAP02KTm200E^CdE_EDP_6aP:4a5YHfL02gmmOASoool=P81n00V1P7j0OgR1KUj1KUj1Je^0LFQk
JeakJef0Kf400X1_I@0HP7=YP6eSO6IGN5Q9LUA8Nf]MP7=YP71VPFmSP7=WPF]KO61AN511N5]9Ke0o
IdloJddlJd/jJddjJdPhJU10LeY;N5]<N5M80VmA@`05Ke95KeM6;A/H;BXWMg9i00^0P7hIoooo3I:2
N00:TGmfUGIQTFeKTFeKTW1KSGQ]VFmCSg1NTW9OTVmO0Y9bHP0CSfADQf5:PU0oRVIBTWUXTWMWTV]M
TGYTUGISS65>S5]8Q54lQ659MddiMe4kNT`jO4hfMdXhNTTe00:5GDX02HMKAh9D@WmB@7mB@7mG@X5I
A1lB48edKIb?SP0;TX9h8?ooo`007_ooo`elOWh02H5fIga]IGUSF7USF6mHCWeLAWIPG7aPGGa]I@03
O75Y01MlOf^1LF9nJeM_DD5aDdUlKFElOg21LFelKFV2L6UiHeQjIEEdE4M`D45WA3YWB3aVC4EdDTQn
GeAdG4m_EdY_E4MdF4X00W1CA@06Je10IU52?b8I2`X:5a<BO7Ui2WanOQWoool=Ogem00V2NG1lLFao
IUUoIUUhGE1kFdU_HEmoHeaoK6@00gm`J00EOgMYPVQNOfECM554MUQ>OfaTOgM/PVMTO6YRPfeSNEmC
Nee?LTi2LDm1JTDjJTTkJ4]2LU12LeE9KU95MEI9009eEDP2L51400I^Cd5[DDA28QTF4a<h=SAoNWX:
Ogem6?ooo`f0P7h02H1oN7]gLh5[Fh5[FgaSDgMOCfaVHh1[GH1_I@03P7=Y01B0LfN0He]lHE5hEDMk
HeJ0KfF0LfR0HeekJef1KEihGTmhF4U_C3m_D45[B3Y[CCa[CT1_DCiZD41ZCCh2N5Q900QcEDM_DD=_
DD=_DT=_EDLk8ATW7aaXHE/;P81n6Oooo`fBPWP028mfJ8mfJXaTCXaTCXURC8M/GHQVGI9fH0BBMF@0
5i9XFXmMD8IHA8aIB9EiJ99eI99XFhmUEXm^FHYQCHIJAX5>?Gi@?gM9>7Y;>7Y??7mB?Gi@>GY?>gmC
@8MGA8MIAX5D@P02O50o00IoEd:1FDLV5A19<b^m[J6BQG/:TX9h8?ooo`007_ooo`elOWh01WaoNWQY
F6a@?6a@?6eHBWaPG09lKF006ga]IGafLGafL7aaJGaaKGafJgi[GWASDFeHAWIUFGa]H7aaI7aaJ7ea
HWAKCFmDAf]DAg1IBg1F?fa:>6I9?VmHCgQPEgUPDWESEFmODF]GBP02JeQ:00I[E4Y_G4niN4mV<R4B
1`DG51<:O7in6Oooo`eoOGd08WmnNWeZFgUHAGUHAG9ICGELE7aZGGmUGWm/I7mbK7mcK7m`J7m`JWm`
IH9WFGIOCG9EAgaXGWm^Hgm^I7m^IX1^HWYLCgEFBG1CAW=EB6i??6a8>FQ:?ViDBWAGCWUKCgQODW9I
C0=`EDP01ViAAVmHBYUSADXX7B4F4TM5A0YoOGdHoooo3H20OP09P7mhPFmOOf1<Of1<MemBLE]?Nf]M
P6=MP6mU00>0LfT01h1cJ81_H85UEGQNBgMHC81_IH1cI`02P6mU00f1KV5lGU5hFdacEDMcE4E[BcY[
B3Y[CT1^DdMbE4QhFdahGTmcEdP00g=EA`06Ke95KeM7KU0k;b4J<bHQP7ai2X20OQWoool=TX9h02:B
L5bAKef5E3n5E3nAKef8GTn?KUZBJ5jBMFBBMVNBLEnBMFBBL5jBJeF9FTJ9FTBAJU^EMVRBLf6BLVFB
KUj=IEB7F4N7FdN1EdAoCSeiBSEgB3UoE4:5ETJ7FDJ6FTR3FTR3E4<3PEA200IoE461FTI9<2@[6aI=
>S;=`kT:TX9h8?ooo`007_ooo`alOWh00ga]IGADBVH_:002L4I000ILC4MULV1lKF1lKF1lKFElK642
O75Y01MlLFQhJF1mLF9mLVMlKF1lKEahH5QfFe5lH5QiF4ieETE[C41WB3aVC3QO@cINA3QZDDE^G4ac
G51iH59eF4]_E4MdE4L00W1D@`05Kdm0Ke56NEmEW6mJb[2T00]lOWhIoooo37mmO@03OgE`O6AJMT8h
009hDdT01f=9@6m/GGmUGGm/H7m/I7m^I7mcK002Og1X01ImJV60KV1kIU]iHeIlJU]mIEalHeQoIemo
HEEkFTY`Cd9_C3m[CcaXASUWB3UZCD9]ETUeFU1lGe9hFDabETUeEDP2L5=400I_D49_DTMhG4n3G4Uo
HEQ7AdL:Ogem6?ooo`b0P7h00h1oNX5dJ81EAP02O69A01m[CCikJef0Hef0Kf60KfF0LfV0N720LfV0
LfR1Kf>1KUigGe9gGdmkJef1KF60Kf20L6J1Je]lH4mcE4EcDT=_E45^Bca_CSY[CD1^E4MgFe1lHE9h
GDicFdacF4T00VmEA@06KeA5KeM:LeY:Id/i>b0F9b0K2X20OQWoool<TX9h00>BO6n?K5V=ET@00XAU
C005Q6EAW6]JTVQJTW1PTWET00:BN6T0699eI99`H95_FXeUDXMNBXaUD8m^G95[FiElIY9]HXa[DHIH
Ah5F@gmD@85F?WM:>89?>H5FA8IHB8eQD8UOC8=MBX=KAh5IAP9lEd801X5D@h5RCWU>>Udi:SLM65Pm
=0ZBPWPPoooo000Noooo37anOP03O71aOUA@MDTo009[ASl01GQHBWIYHGaaKGaaJ7a]I@02O75Y01Ql
KFElKF1mKEmlJE]mIEQfJF5lLFf1OgAlKFUlLEmnI5QaFDYWBciSAcYJ@SY/CT5_FdidG4mdH5AcH5Ai
H59eFdi_EdY_CdL2M4a:00I[CdEZDDY/D3mVBC]YB3b1Ph8:O7in6Oooo`aoOGd00gmeM89KDgU9?P02
KT8k00EaDTQ_IUioKVIoKVAoK6@00Wm`J00HOfiVOfiSP6aQO6QKOFAHNFQNOfiVPWEZO6EPOfiNPV5H
MUQ9Kd`oJTTlHdDkKdhnIe15KU97Lea@MEeAO5mBN5]=LUI9LU160WE?B006KU14Ke18LE90Jd/nIT@h
PWmo2WmmOASoool<P81n00>0NgJ1HeIhBch00Vm3>P05KUA8K6MMP6mQP6mQP6mU00:0LfT01X1cJ81c
Ih5_Hg]ZFgaWFG][G@:0Kf403g]SFX1^GX5QF7QJB7=?@Fi>?f];?6m??65:?VY=@G=KCWMOD7aQDWQM
CW=HB@03LeA700E_E4=cE4QcED9_DD=[Bc`02h20OQWoool<TX9h00>BJef9F4Eo@S@00WmB@@04Q6MF
R6iNTW9LTViK0i9eI00HTW=STW=QSFaKSfQDRVaHTW1NTW9LSfEDSfQFTVEDREa<PE8oOdlmNTdkODli
NThiN4dmOe=2QEi<SF5>REm<Pe]8PeM4PeA40X5F@P06Oe@oQUm>ODdgPEI5U8=iSgme2Y:2N23oool0
01koool;O7in00AlLFUlNVMnK5MaESl2JTdo01=`Fe5lKF1lKFElMVelKFElJF5hIEQfJEQlH5amG5Qc
H5AhG55fIEUlJEalKF1lKFElJ6MnEdmeDdD00Va>@@0:J595IUM6JUE5KUU<N5a@M5a?M5Q;MEQ;Ke95
Kdm00V]?@006JeA3JUE7NEmEL5A7DcT^IF1Q2WanOQWoool;Ogem00AoMg9oNfn2I5IgCcd2K4Lm00A/
ETelJUioK6AoLVX2OfaT01UmJUmlK5moIEn0I5]hHeImH5AiIUYoJV1oKVAoK6AoJFB2G51iEDM_CT5/
C3mXCD5VD45ZD4=`F4ahG51fGE1iFdihFDabDdIbD4800W1?@P06L554K596MeaAKTi1H4<iMG1`2Wmm
OASoool;P81n00B0P7^0OWJ1GUAgBc`2KdHn01m/EdakJef0KfF0LfV0KfF0LfR1LVJ0LfN0KF>1KUil
JEZ1IeQkJef0KfB0LfR0KfF0KF>1HU5hFTY_Cd5[CCiWBciWC3i[D4=cFdagGe1hHE9lH55hGDicEdQc
E4D00W=AA@06Le95KeA8LeY=Jd`mKeA8QHF22X20OQWoool;TX9h00BBOW6BKf>9CT9m@S<2PeA601n<
JeN?KUjBMFBBLV:BL62BMVFAM66EMVJBJef=LURAJ5BAKERBLf>BLf6BLfJBL62BIUJ9GDIoET=jCSag
C3YcC3]lCS^1ETJ9Gdb:He29HDj<Gdb3GDZ3E4:3E4<00X5B@`06PEA2Pea@OThkNE0mSGM_XYR>2Y:2
N23oool001koool;O7in00AdIeUN?S53<2A2=2`2FTU000eaH5ElKF1lJF5lJF5lKF1lJEQmJEacG5A_
H55cG5AhJEmhKEmfJEP00ga]I@0?N7ISNFYIMEI8K4i1Id/nL4a0Je17KeE<M5U?KeU<M61DM6=EME]>
KemAJe]<009[DdD01V]<AfYABVM2<6Y6>W11;fDl<0YlOWhIoooo2gmmO@04O71TLE12H40`GCld0Um8
?P0OKeY@OfaPOfYROfaTOfiSOfYMP6YON65GNFEFNeeGNfIKNfIINFIHOfaTOfaROfaTOG1SOfAHNEA6
Kdi1JT/nKT]0J4m5KUA9LeQ=M5U=NEmCMUmBN5U<LU]=L5E8009`D4@01Vi=AFaBB6m7=Fm:?g18=fI<
A`YoOGdHoooo2h20OP04PGU[Of9ALdlkM4/k0VY=?`0OLE]?P6mQP6mUP7=XP7=WP6mSPFmSO6UKPFeM
PF9KO6MIO6=FNfMIP6mUP6mQP6mUPFmSPF1FN5A5Kdm1JddnJdi0Ie95KUM7Le]<N5i?O69DN5i?N5Y;
LeY;Le95009cDD<01VmAAFmGB7==>7=DAfm@@FaUH`Z0P7hIoooo2i:2N004Sf]ESF5>NDdgR4lj0XmT
CP0CSf]GTW1PTW=STWIUTW=QTVmOSFmMTF]HTV]HU6IHSFYDSFABTViLTW1PTW1NTW1PTFMHS5A6Oe0o
009jCS`02GUB@7UG@XEKB8EOBXaQCXaSD8UJB8=IAX=FA003PE0o00IoE4:3HTioA2j6IUAlDdBBVIP:
TX9h8?ooo`007_ooo`]lOWh017UTEChS53HT7R`O7@8Z:Rd07g5PFGa]IGa]H7a]G7a]IGaaKH5aKH5j
L89/IGAHCfY:@VeEBW=QEGIYGGa]IGa]H7eTFgAKCfa:AFM8?F=7>699?VmDB6YDA6YAAFiEC6m=A6YA
AF]DAfIAA6]DA`02Je=500I[CdAVBSmXFD1J?2]VBSiU?3D:O7in6Oooo`]oOGd0181YFU8[6Td^9C/U
808l=3807g=OEWm/HWm/HGm/Ggm/I7m^IX9/I7maIX1UGWIKD7EDBgANDWQTF7aZGWm/I7m/HH1WGWYO
DWA>AVa;?FQ8>VI:?VmBAVaCAG9DBG=GCGECB79GBg=FBFiCAW1EB002KU9500I^CdA[C49_ET1R?Be^
Cd=V>S0:Ogem6?ooo`^0P7h0185^G5`c7Uli;4L/909LAS`07GMSEX1_HH1_I81_I81_IH1_HH1[GG][
GGaRF7QPDWaPDgaZFga[G81_HH1_IH1_I85]HGaUE7MCB6m??f];?6]>@6mCAVmEAgQJCWQMCgQKC7QP
DGQKC002LeQ90VmDA@06Ke55Ke97LUE1Jd8bLeE7K4Df2X20OQWoool;TX9h00B7ECiF;QY[?2eC;R@2
XG9I0Y9`GP0JTW1OTW1QTW1PTViISf]FS6EDQea<REm>S6QCU7EOTG5MUG=STW1PTW1OSFQIQee7Odm2
OE4iN4/kPEA2PEU6Q5M6RUm=S5m>Qem9RVA?0XAKA`09PEU6Oe90Oe90Oe94PE]9NTLaPTllQ552TX9e
00ZBPWPPoooo000Noooo2WanOP05O7IaQ7agUEU6ARXO>BDP008Z:Rd07g5PDGQYF7IYHGa]I6mLC61=
?eDo<TPc:4dl<e@n>fE6@VE6?6U=A75PEGa]IGa]JGe/HWYNDW1D?6M7=VQ;?5i8?5Y6>eI<@5e=@VEI
BF]KC6YEB7AKCW1GBV]DA`02Je=500I[CdA[D4MJ>2a07aM;<29P=bH:O7in6Oooo`YoOGd01GmiMhEi
M8Q>?48W73lW8@029BT/01mcGe9mJUelJV9oK65jHe=bFdm]DD=UBciXCdEZBdE_CTI/CT9cF4efHeQo
K6AoK6J0Jf1mGE9dDSiZASUZBc]RB3]UBSiUD4AXD4A/F4YcF4a_E4QeFDa`EDQ^DdH00ViBA@06KTm4
KTm6ICd_DRXLFS//HcP/2WmmOASoool:P81n00F0P7f1Mfm`A38k9A]2:B800SLa<006Mf=FPFmSP6mU
P6mPPF]KPF]N0WiSD`06OV=FNeQ?N5Q<LeQ9O6IGNf]M0X1_I@0=PFeNO5iALe91JdPlJddlIdXlKU53
LUM8LeE7Le]<N5Q<LeM8LeY;009_EDL2KeA500I_DDE_DTMY@S1S=B9[BCI/ACX:P81n6Oooo`ZBPWP0
1I9oMHEHB5D_7c`S6DPX8P02RF=@01nBL5nAKenELf>BL5V<JEJELV2=IE:DKERBIeN@FTf<HD^9HDfB
LUfEMVFBL62BL5j=He:3EdAjC3]jBCQeCSamCSaoF4F4F4F:FdN9Gdj4E4B6FdR1FDIlE49oEd@00WmB
@006Oe94OeM4JSXWMCTSRUDlUHF12Y:2N23oool001koool:O7in00EhKF9iHeDZ3`XH3`dN61D00QDT
:00OLf5EO6ULO6UHO6ePR7EUK5I8EdHh=BhZ7A`K6a`D;RDN@b@K>aLBAbPQMVEIO6eUOG5RNV5BL591
He8lGdHdHDe2NEa>OUmAM5M:JdU2Hda3HE55KeQ;L5M:Hdm3009JCd<01V9DA6]DAfi8=UXc9E@^9V0]
8@YlOWhIoooo2WmmO@05OGA/OfUN=a8<:1HA:1/G008G92T07gEOE7mZGGaXFWm/HHM`HG9GBFE<?DPf
;cHW8S/Y7D/d;5/a95HZ7ee3>WaXGWm/I81^HWeODWAA@FQ?>fI5=F=<@G9DAg9GBfaCAVi=A6eBAVMB
AW9GBg=FBFY@A002IE1400IXDDA^DDI`ASEI<BAB;bIP<28:Ogem6?ooo`Z0P7h01H5mM85`IS`D3C@L
5C4O6@02=2l_00]gHeJ0KemkJef0KfB1KUibFTY^Dd9F?SA;<RYJ=RIYA3T00Vhn;00AMf=EP6mUP6mU
PFiQO5iALe91JdhjJTLfIdm2Je13IU=6IU95KeA7LUY:KeM8LeY;LeQ900=^E4D01VmBAFmBAf]5=5H`
8UHc9fQ0;@Z0P7hIoooo2Y:2N005TG9QS6AH<a09>1dE>b8K00:GJeL07he/F99_FXm`Gi9`GhMSD7MD
@WA>>U`n<UHe:W8l:8aD@Gm0:hA8<JN<MIEfJ99`H8eUE8=DA7Y>>7Q>=WE5=GmFA7QA@G9A@GQB@GmH
AgeJAHUMBX=KB7mGA7YD@P02OeA200J4E4AoE4AT=bMR;Aig?RbBRG`:TX9h8?ooo`007_ooo`UlOWh0
1X22PXN1NWUIB6/n<bXH4bTG4`8E7B<07ga]H7Q]GgIYG7a]H85fK8eaHYQdJFa8>S0L5R@H4b8R8D8m
<gANCfeHCWI]H7ajMGejLGYUEFM9?5Xk<3dD2c4L6UHl:Tlh:S`]8d<i;F=<@5e=?VIA@V]DAfa?@@02
Hda000MRC4ASB3iD=ba;=R]HA3aY?SJ1Ph802GanOQWoool9Ogem00J0OWj5OWQmG4aZ>S4V5A4X5a<2
2a/R01mlJ5akJUelJ5aoK5n2L6J8JE]mHEMS@C@c7AL[6aDa9b=??35TBCiL@C]iIe]oLVb0LfYmHU=_
BceS@C==6Pi7;bUSAC=QA3EF>RaKACQZCD9QCT1^DdE`EDQ_Cd800VE=@@07Hde4JTa0H3X_DSHZES`d
Hc8XPWmo00UoOGdHoooo2H20OP06Oh1mP7edO61?G3L^8Q<?:APD0R4V9`0LNfMIO6]LP6]MP6mPP6mQ
O6=CI5A8DSX^<QlI<alG@RlWGSh_FCX`ESD^NfMJP6mUPFmSO69ALDhnJTTfER0AHTHhKU0kL510JTLe
LU93KU55Ie930W=HB@09KU93Ie53Ie53Ie55KU93I3h`FSLYFST_IS@U00Z0P7hIoooo2I:2N006U8=i
S6EBQ5I5?2<M8Q8==1XD0XY/F00OSf]GSFYFUG1LTW1LSf]IN58oJddo?R/P<A/F@R8FFS`_NS`ZKc`_
Ne52TVmOTW1QSFA?PeA2MDTeN4hdEad?Sf=;PUHkOUE3MdTdSee:NUA4PEU3Q5]9PEU6MDlm009eE480
1gmDA7YD?f4d9fdh9ga0<i1iK8moM@09TX9h8?ooo`007_ooo`04O7EeO7UiO7YiO7Ui1GanOP069a0;
2Q0ENV1BLdHe;QlR71@B0PDD700OLfEHO6ePN6ULLfEHMVUMR7iaM6ABYWIP^HAXVfI9PDhdL5]6KeQ8
LeE:MVAHO6aQOFeRNV5BNU<oJ4HhMThjAcPe<S0c2`H75ALG:RDQ7aTD71hN>2`QBcHWJ4`n009SCd<0
1f9?@5i6>44]8BdS7Cdl=6U9?863PP09O7in6Oooo`04OgUiOgYjOg]kOgYj1GmmO@06?ATBADA1Of5C
LT4b;QdP7a@A0PDE700ON6IIOfaONfQKNfQKO6YNQgEZLee?UVUIOUi=HdLgFS//DdTmHT/oLE=9NFEI
OfiTP71WOF9CNE4nIT@gKTDcA2hZAcHb5PT9=BDO>bdV=b@J?S4/DSXZGD8bKDm1009UCD401f=?@FQ8
>dh`8c/V84Hk<fHo=HF2P@09Ogem6?ooo`V0P7h01T/Q68EgJh5UEF@l;bXL7R8E408U8R@07ga[G81_
H7a[G85_Gh1_HH5_Hg=KC7aNDD@m=C4/9CT^9D0m=ea3>79HBg][GH1cJH5eJgaUE7=@?V94=V0m;4DY
8eHl<Qh<2e@c9d`g;4/^8F56>FU8<Vm@?ViDA@02Idi000MWDD=[BciC<RE9;29I@3E[@SN5QH802H20
OQWoool019:4NY:5Ni:1Mi:5N`FBPWP01TLM5<nJO8]QCT/Y82@G6BTE3`:GKeX07i5_FY9`G8e/F9Aa
GIEcHhMQChEHB6E7>cDV8bdM644^9Ue1=WU;?HYXE99gIi9hJHe]Fh=IAWA8=6]3<eP]7edi;ehl;1l<
2W8m:f53<U@`88=F@Gi?<heJ@gQFA@02ME0n00IoDT9]BCQ>:QiN<2>?EdBDO7H:TX9h8?ooo`007_oo
o`03O7YiO7UiO8>200ElOWh01bdI52/K5PH30PT82QlD61`D42LI500241TO01mhJEafJF5dDTeU@ce[
Edf1MW67Pgb>Mg1oGU:4IUV4IEMiG4ihI5AhH5AfI5QlLFUmK6EjIe]`FTQ/ESaeF3n3Ed:EGTP_6aPK
5Q4_7ada920b:B5J@3IQDD=`Cch00VQ<@006HUA3AR/U<B4J;alG:QhJFRPL2WanOQWoool017miNGmh
N7moOgmjNPAoOGd01d<U7SlV7aH60cPQ6c4K7R@F4RLH5@020QDL01mkJ5]iJ5imG59bE4UbGeB2L6Z2
MFb4JF1hF4ajGE1bEDQZD4=aG4ehFe1iHeMoL6R0KFEmIEQdEDA]CcY/CSY^BCYgDD8[61HL5Q4h920f
9R0c:R9E?SEHAcY_Bc/00VQ=@@07He52Dc0X?RHL=B0H<BLQHcP/PWmo00UoOGdHoooo00B0O7Z0O7V0
P7j0O7T4P81n00MA;bM;;bLX20AT>R`l8R@Y6A<W6AH00QLN8@0OO6]LNf]MPFEFO6MFNf]MP6mUNf]M
MemAKeE7KeM8HDTjH4XkKUQ8Mea>NfMJP7=YPG1TO6EELe91Jd/hHTHfFT0eEdHl8QHE8aPB@2XT>2PQ
>bdSDcldET<dJdXj009WDD<01fMB@eLd:dD/7c/S6DHc:G5C@hF5PP09P81n6Oooo`04TWieTX9hTWme
TWme19:2N007C2TPABPO?P/5Q4/f>AlP:ATB;aTE00:7JUH03Xe/F99`GXUNBhmbFIUlJXm_GHUPC7iB
@7Q@?GE??Fa3<GIA>hAJB8YSD0:BMF@03heVE8=MB7Y8=79:=F`m;f=5>dhi<1D>3SdN54da:3TU75hi
:FU3<gA;=WE:>@02LeA200MoE41>;2A6:A]:9AV5B3FLVHjEQG/02I:2N23oool001koool00gb3PWan
OWanOP05O7in00MD<BTd8ATc7aPO61HF3@`U5a@]6A@00QDH7P0OO6EHN6EEQhQhOfmRDSP[@bXQ@S0V
=B`T;28N:1hH<BDL=b<LAcL`KF1EMVEIO6ULOFaJNV1BL5M:K4@hHdljHU0kMEi=cHY[XW=KOTdhOTPe
LDi1MEHoHd`nIUM6009eF4L01V=?ADP_82TI52lN62lS6e@N4`YlOWhIoooo00=oOGeoNWYoOGd01Gmm
O@07FC4Y<R0H<1/F8aLD6`h=9QLD:APD008;61h07gaVFG]VF8EiKWYOEF=4=V=6>V59?5Q1=dlc:TX`
950f:E@d:5m9?GAOE7USF7m/HH1]GWeODgAGBFa6>6E?>VI<>W=HBIiYE5]9?e/k;Ell;d/m=F18=f=8
?6]EA002L55400IUCdA@<24^6QHb81Pa9AaI8aP:Ogem6?ooo`:0O7T6P81n00MA;bLa7aP]6A@Y61@N
3`hW61DW61@00R4T9@0ONf]LO6]LP6mULeA:LE10OV=CNf9ALeE8JT<eId8`K4LeKTDdN5i<O6=FNfMJ
P7=WPG1SO65ELeQ7Jd/hIe4jJd`lKeE7Id`o7bHV>b`T@C<Z<C4/DD0bHTPlKeE3009[Cd801VMA@dla
8S4L5cLR6D0Z7fPg:0Z0P7hIoooo00>BNg:BOgFBPWP01I:2N007=ATD>24G<1DA=AdF7@h=<1XE<1TC
00::JeH07hm_FXe_GHaOE7Y<?85E@IMcG8a[EH5GB7Q4=7a;=8A?>8I?=iigGYA/F99`H99fHheVEh=O
CWY>>WM==7EB>85B@7U@@44]:24I63/U7Sl]9Dhh;VE2;g9>?h5D?P02MU1000IeDSlo91Te6aE791Qe
<b:IS84:TX9h8?ooo`007_ooo`QlOWh01e`i:B4@2aPC3a`C3bDF4AXD42PT80026B@W00e[G561KF1l
KF2=OgRNTh>3IUYVCD]eFE:<GTaoFTY`DD5iGTmhHED00Wa]I@0@O61POFENNVAEL5==CRhU?1lI@c8X
HU0kJeA0NE]:R6QCNV=@IUM6He=8Jdm7Hda50V9@@006GTHf:1/E61@@@chfFcTYBAhC2WanOQWoool8
Ogem00MP>2TT4@`N5A0Q510V5Q4J4a0[8Qh00QHQ9@0OLUmDPVYMO6YNR7E^RGMZLeE;J4]5J518Kdi1
HdLmGd@gI4a1HdY2MF=JO6YPOfEQP6QNOF5CM5=;G3@WDR/PE40aJ54nKU=2MEM8N5Y9JU12GTXmJ4m4
KTm2IDe4009XDD401VQ9>S0N5QhE4C4b;D``8ddK4@YoOGdHoooo2820OP07EcHW9Q8=8aLB9QHA91HB
6a<@;b8N008/:2P07g]WFH1[GG][GH1_IG9ODV98?FA;@5i;?e91=T/i<Dlj;UA0=EHm=75ODW][GH1]
Hh5^GWaQDW=EBV@j:V@i9fMA>VmE@fmEAFmEAfM?@5]2=eY3=f]>@6mA?fMA@`02KeE300I[CSha81PS
5a8_;2M1:QmM:A/:P81n6Oooo`RBPWP01cTM52TB32LH4B`G4BHE424E43dU7P02QUe:01nILUf?KUZ?
KUj8IEAaBCQX?C5TB3U]B3Q@=BUC=R]I=BQY@C9dDD68IEB?KU^BJeZ=KEB3G4YjBciY=b=c@2V8ID>4
FDEoEd=kDT9XACAP>bmcAcIhCS]oDSmeE3l00XAI@P06KDXi9aPB9aLAHc/^E2@IVH9h2Y:2N23oool0
01koool2O7in00=lNWUlNGUlOWh00ganOP07J4Pi;a@>91@@71@@3`P8718?:1lL008P9RL07eM<A7IU
FGa]H7aaJH5jMI:FRJjNSI:FRIfNUIfJTJ>SVHf;OWe]GgI]H7Q]Gg=bG7QYFgmXFXAgHIQmJ68n>2TI
61HB424P7U=3>F]DAGEH@f=?@fM;?UM4=V59@@02Jda500M6:R0[618[8AdO8aiC;AlM20@L6AP02Gan
OQWoool2Ogem00=oNg]oNWYoOGd00gmmO@07K4Lh;Q<=8a<@7A@@4PP87a<@9alL008R:RX07f=CBGaV
FWm/H7m^IX9bK8QnLXieJVm/IXEeKWm^IX9eK79UG7MOE7UYGGe/HG]^GgeTFgmUF7aYF8AREU/f;cTP
6c8Q64He;61:?W1CAG=E@VE?@Va>?em8>VQ;A002J4e400MC<2<b6a@X7a/K8aiM<B4d6A=:BTT02Gmm
OASoool8P81n00MP@cD[4PdR510M5A0C2@PR5A0Y8A`00SLd<003LUmAP6]MP6mQ00:0KfD02G][GFaB
BeA:AfaBBf=:?f=>@ee7?W9HC7][G@02PFmS00n1He]lIUMcGe1[C4E@;RI7:Ai;;b1/BcU_EDEcEDE_
ED=WDD=_DT5UCSm_DDL00VMA@`06EcDV<adF9AhJ:BLQHcDTBB`T2X20OQWoool2TX9h00>BPGNBQG^B
PWP00i:2N007@BDJ:A0;9AD@8AD@5@T8:ALA>BLP009mF4D01YYbGIEcGY9`H99bHXm/FX9GB09X@3T0
5g90<f/m;VPj:g51<XALBi9bHY5/FiAYGI5SE8EQCWaBAV8f;D`T75D`7eXe8YIL@HeRBh5G@7UD@7EB
@7eB?G9??XAFB002NE@o00M>;R0/6A8/81UV>BUZ<1mH@SS:`kT02I:2N23oool001koool2O7in00=l
Ph9lOWilOWh00ganOP07EDDo;R8M91HB8Q@@7A8=7Q@@:1lL008];B/01Ue<@gIUFGa]H7a]IGaaJGaf
L@9lNgT05gafL7afLGafL7afLH5fJgaYF85aI7eYFgQPE7eUF7eYFhQ`IJN9N:]iJh1DB34T7AHB3aTG
5bLR8C8Y8CP[8Ea3?6]?@`02Id/n00Lm8Q/T5A4Q5QHB30XQ4`hn9R4R7Q`02GanOQWoool2Ogem00=o
OgmoNWYoOGd00gmmO@07GDDn<B4K91DA8Q@@718<71<?:AlL008Z;R`01Ue=A7USF7m/H7m/I7m`J7mb
K09oMG004gmcK7mbK7mcK7mbK89`IGaXFX9`IGeXFg]SEWeTEg]TEh5WG8i^H7]GCf51>3@T730N5SlZ
8dDc:`02CSLZ00]SAciSBd1/C41/C4168a`X5Q4S5QHM3``i6A56:2<H6AP02GmmOASoool3P81n00>0
O7V0P7j0P7h00X20OP07Ed<l<AlI8a@@8QD@6Q4<7A<?:b4L008g=2l016ADB7]WFH1_HH1_I@R0LfT0
4h1_H7][GH1cIgaZFgaYFWaWF7MSEGMREFmGBddj=D4a:CLU74LZ7V8n<5m5=VM5<V53<V]>@Ui;?P02
Kdm300M59AdZ618U61LZ4`i?7aA9;BD/91l02H20OQWoool2TX9h0Y9oM@BBPWP01cdW7c4K5BHD3RHE
41/@2bDD3cXW8002MDlm00>=JeNBL5bBL6000Y9eI008TWIWTW=QTW=QTW5OTWIWTW5OTW9OSf]E0Xm`
G`0@RVQDSFQDRVQDQf9@PEU9H3hc@bLQ=B@LABLKEc8QODPeKdliNdXcLdLcQ5Q7Ldhm0We??`07=Q`E
:QL@;1/H?AH>Hb8DBS<ZSgme00VBPWPPoooo000Noooo27anOP07J4e5A2lZ91TD7a@@91DA9ATI:R4O
008W:bP04DLn=f]KDGa]G7aYGGa]IGa/HGaaJ7afLGakNGafLGafL7aaJGafLGaaJ7a]H7e]GWQYF`02
N61D00ahI5QoI5MjJeRBKeZILef<IU5UBCIR?BeXBSajG4eNAd1OBD<2EdXm00Lo91`T5A4K50lE4@`H
5a@_924R7Q`02GanOQWoool8Ogem00M/C4Dn:bLS5a8Q510S5A4S5aLZ81d00R/]:@0ODdDlLUmDOfaM
OfYPOfiVOfiTOg9/OgE`OgMdOg9/OgE`Og1XOg9/OfiSOfaOP6aNNfIINemCNf9FNfAGOf5FN6=EPem@
MeQ:IT/mCSX]ESL[E48gID]0ED4iJ4]4009TBcd01dHT72DE4AdD41TA3B0F4cHT81/K6P09Ogem6?oo
o`R0P7h00f19@SLY924F4P028QD@00PR5aH[8A`k<b`k<baVD4AkIeV0Kf20KfD2P7=Y0h1hL@04P7=Y
P7Q`P7=YP7=Y0X1_H00@PFiNO6MHO69DO6MHO6IHO69GLeiBKe97DT8i@C@[>blUBcDZAchdDT0dDShd
KU550Va>?`07@b@L91HA7QD@718=:QLC?RHQ<BTT00V0P7hIoooo29:2N007@BXS>bHP7a<>:1D@9AD?
:1PF>BHN009]BCL0299YE9UfHI9`Gi9cIY9gIi9hJI9mLY9iK0:BMVL2TWET01>BLUnBKUNBL5b=J5B=
IE:=He2=JeJ=HeB5HE1mEDQX@cQ8<BTk9Qm5:R1B=RUM@39J?Bm_@SQmET800WM;>@06<aXD9aD@8aH@
8A4<>QTCBblW2Y:2N23oool001koool8O7in00MSA3@a81Lb81XT5Q8U40`Y5a8]7AH00RLR7P08=S8^
HU17MVULO6ePO6eUO7IaO75YO75X0WafL@0EO7I`O75YO6ePO6eUO6UPOFAGN61DN6UKN61DN61ANEa?
NUQ;NU]>NE]<Q6=DSFaJR6QHMEU;MDm7L5I5L4/n009D=2L023PO62@E4B/I524F4Q`D42@I4a8:1UYA
DPQlOWhIoooo27mmO@07JD@e=B8I<b0K8QDA9A4<:1LC;1dG008^9R8024<k=6QEBgaZGGm/H7m/I7mb
K7m`J7mbK0=oMG0057m`J7m^Hgm^IWmZGh1WFG]REW]VFG]ODg]QDgaMDWYKCWQKCGIGBGEIC7IJC6iC
AV=;@6i;@V]BA6m9?`9M>R/023hQ6RDE4BTH520E4AdC42TK5B0N6faVI`QoOGdHoooo2820OP07H4<e
=b@K<B0K81D@9A4<9aPD;AlI008j;RH01EY9?G9ODX1_H81_HH1_I@02P7=Y0h1hL@06P7Q`P7=YP7=W
P7=XP6mOPFeM0WaWF00=O69DO6IGO65EN61ALee>KeE7IU=6GT`oET<hET8gId/oIe53JdY1009O@2l0
1chS6b@F4BLH51dE41lD42lO63li=@09P81n6Oooo`RBPWP01d@W7CdU6blN62@D3b/A32hJ5CTS6@02
EcX]00R?I4fDM5nELejBL62BMFBBMVNBMFBBOG82TWU/0Y9eI00CTW=QTW=STVmHSFQDSF]FSFEBSF=@
SFIDRF5@QEm<OE]8MU91KdloH44bGC`_J44cM4hoMThoMD`m009M?2T023DM5RLE42dI4ahD3bPE43lV
6hYfL:JOU0RBPWPPoooo000Noooo27anOP07ECh_=BTU;R0K;1/F6A8=6a<?6a8?008T6aH02BDP6DLh
;gIUFGa]H7a]IGaaJ7akNGaaJGaaJ003O75Y00IlLFQlKEahJE]hJE]hH5AhG542N61D00]iH59_Fdi_
F4]dH59[EdY_E4M`E4MSDdEJCd1JCd=CASP00S<W8@086A8=8APG5a0A5a0<3`L76Q8A7QXHA3Le27an
OQWoool8Ogem00MM?Rlh:2<_7aX/6QDK4@`O4`lP4a000R`O6009<bXQEdDlNFIJOfaPOfaTOfmWOgMd
Og1XOg9/009oLf`01Gm`J7m`Igm/GGeZGWeXF`02NemC00ekHEEkGe=lGe9eFdeeEd]eFdm^EDQbEDQ`
DdIZDTEUCd5UCdAQB3X00T4Z8`088A@>9APG6A4A6a4<4@P87aDB9b<OCD9227mmOASoool8P81n00MG
?Bhi:B<^7QTZ6QDK4@`S510T5Q400SLU7009B3LYKUQ;Nf]MP6mQP6mUP7=YP7QaP7=YP7Qa00:0N700
1X1cJH1cIh1_H85^HH5ZFgaRE09lIUL037aRE7aQDWQMCWQJBg=KC6mEAg=HBFmEAfiDAFiA@fiAAF];
?098;RD022DF3RPI61/A41dB3A<922LH53/a:V=GE@R0P7hIoooo29:2N007?B<H@2XR;a`F;QTC7A0;
:aH@;1LA009=;1l02G=:<Z1jIY9cGY9`H99eI99iK99fIi9eI99mLP02TWQY00ZBMFBBL5bBL5nAJeVA
J5B=He2=JEB=IU:=He29Gd`2Qe]800F1FTQoE4:3FDIlEdAjDT000WmB@P0;M4Tg@RPN@RPN91@<;QXH
7a4?818<5@T8=adEKe57Wi:;00RBPWPPoooo000Noooo27anOP07J4Lh=2@O=RTT;B0K<1`G91DA:AdI
008/9R@02RdZ:2h]:f]DBWaYGGaYHGaXGGaaJ7akNGafLGafL09lLFT00gaaKGQYH7QYF`03N61D00ed
H5A_G4mdG4meFdi_F4]_EDQdFdi[EdY[E4M/DdE[Cd=/Bci@=R`00S@M5`08<1lJ5@`<5a0@40P8610@
6a<@8B<R>38`27anOQWoool8Ogem00M/ASLd91hf9b</7QX^6QHQ510X6aL00R/S8@0:=2XV>SD^LU]A
OfYNOfYROf]ROg9/OgMdOg9/OgE`0Wm`J003Og1ZOFYOOFYL009kHED03W]ODgUODgIMD7UMD7QKCG9G
Bg9EBGEKCFiEB71CAVmBAFQ?@VY<?eTk<08k7aT022lN6QH<31XA4A4821T@41/B3bLT8c/c<0QoOGdH
oooo2820OP07H4<e<bDO=BLR:QdI:QTD7a@@9a/G008]8al01Sl^9EA3=G]WFH1_HH1_IH1cJ@:0N740
1h1cJH1hL81cJH1cJH1cJ85_Gh5^GP02O6IG0WaRE09lHE802WQMCW=JBg=JBg=MCVmEAg=EAfiDAFMA
@fM?@Ea0<P8l8QX022`N6AH<31`B4Q8821TA41dC3cD[9dm0>PR0P7hIoooo29:2N007@BHK>BLP>BDO
;Q/F;1LB8a@?;Q`F008n:2000eLe9YEVCYUgH@02TW=S00BBNfbBOG:BMVNBMVL3TWET00>BL5jAKeRA
JeH00XeVDP04SF=@S6=@Sf5>S65>0X=KB008Pee:PE]8OeA2PEM4ME90NE90L4lmFSX/0SHM5P08;AdG
60`;7a8A50P87A4?9aD?Gd@kVHEk29:2N23oool001koool8O7in00MLCDLh:bLh:bLh:RD]71LJ4@`Q
5Q800S4O600OAc0T@S0UGD@iMVEEO6ePO6UQO6QMO75XO7IaO7]iO7I`O75YO75XPG5XOFeNM6AGKea?
LeU@NEU?M5Q;M5E<MEQ>KeQ;KeA7Je54JeA7Id/nL4a0HdLjCSP`?RPO008`71H01aP@2aTA41@<31TA
31P@42DH54mADP09O7in6Oooo`QoOGd01f=<ACTY93LY9CHW8b`J5Q`A32@F4`02<B0J00]0;bHn=2YU
CD=lIUQoK69oJV9oJf9oLVaoMG1oMgAoLf`00Wm`J00BPViUOFYLNFAFMUe@N5]AO5]@MU]>MUM=N5U=
LUM;LUE8L5=6L5E8K4i0L4m2IDTlGSleC2dR0SDM5`086a4<718A5@`<6A4<610?8aLD8RHWFEIE27mm
OASoool8P81n00MLBD8i:B<e:B@c9R4Z6QDM4PdW61@00S8S7004?S4XAS``LUa>P6]M0X1_I@04P7=Y
P7QaP7QaP7Qa0X1cJ@0;P7=XP6mTO6YKO6IGO65BO65DO65BN61AN5e?N5e>LeY;00=cF4T01FmB@fmD
AFM>?fM6>E<b9@02=QlH00PM4PdM4Q8E30`I4@`G3`lT5a@C3@U5>cH8P81n6Oooo`RBPWP01d0Z8SlY
8C`Y8SHT7BhH4ahA338K5@02@RPN01mD>2YgCc^GMF6ELf6BL6>BLf>BNfbBOG:BNFbBMVNBLEnBMFBB
L62?KUZ:IE:<He2?HDjAI5>9I4j9Gdb9Gdj3GDR3FdR3FDJ1FdN1FDImDSmlETAeCC][ACI@;B000S<K
5@087a8<7a8@60`;710;6a0?;QTCIDi4Je5729:2N23oool001koool6O7in00UlNWUhLG5E@CX_920c
:2@d9b8T5a8]7QXY7QT00RDN7005<R/TB3`cFTDmLF1EO6eP009lLFT04GaaJ7afLGafLGafL7aaJGQ]
GgIUF7eTEgePE7eTEgAPCgALCgAKCVmLC6mKCV]?AfI@A`02JeA700E`ETQSCd=KB3YN?blo:1`00RdK
5@088AHB7AD@7aHA6A4<71@@8aPD2`D4PH>227anOQWoool6Ogem00UoNg]mMgMM@c`b9B4e:2@e9b8W
5a</71PV6aL00RPN6`05=R`TBS/bGdHlMV5FOfaP009oKVH067m_IgmeL7meL7meL7m`J7e^HWaXGH1W
FGeQEG]QEGIMCgUKD7IKCGEIC7EICG1BB6iCB71CAViCAW1DAVQ=@FI9>f=0<D<X7@8`6aD0228F4AdD
41hE4AT@31`D428G4`00089oO`QoOGdHoooo1h20OP08PH1nEd<l=BLR=bXU=BLR9aPC:Q`H91XF0RdO
6`05@BlUDShbJTdoNfMIP6mQ00:0KfD0681cJH1hLH1hLH1hL81cJH5bIX1_Hh5]GGaVEgMRE7QNCgaN
DWQMCWQKC7QJCW=GBG=HBG=EAfmEAfmDAF]>@6a;?6=2<T4Y7P8a71H01b4F4A`D41`D41P@31`D42@G
51T>2@09P81n6Oooo`JBPWP02I:1Mi62NCdY8SdX8D0/9CXW82PF42hL5R`K5@02>B8K00ER>BQhBCJ?
IU2ELejBL6000Y9bHP>BNF`2TWET01>AKefELEn=J5B:IU:7HDj9GDb<Gdj9FdR7GDb7FDR1ETJ4FdJ1
EdAoEdAlD3ihD3ieAcET?Rhk8aT00S8J50088AD?81@?7a<?6a0;8AD@;aTDU8=iSgme29:2N23oool0
01koool6O7in00UlPh:1R8MB?SDg91/d91le:BDm;BP]7aX]8Ad00S4Q6@07<2lZ>3<ZAcH^Ie17MVUM
O6UQO6eU00=lK6405Ga]IGQUF7QUF7=UF7QXFWALBfmIBGALBgALC7APDWEHBfmHBgAKBW1DAf]?@f]<
@6=?@e]7>U<m;cTU8B`J5P0271@@00LH40`G410C2``;1`P@2P//8AlL3`h02GanOQWoool6Ogem00Uo
Ogn2OgmG?CDf91`d920g:BDi:B@Z71P]81`00S0P6008<BdYA3D[DclfKeM=O6YNOfYROfiVOfiT0Wm`
J00EOg5ZOFYOOFYNN6IIOFMINEe>MU]=NEe>MU]=MUe@N5M;LUU<MEQ9L556KU14KTm2JU14ITTlGD4c
ARXT=QdH008P5Q4021/A31T@41D<30d821<;2bTP7@`71h9oO`QoOGdHoooo1h20OP08P7aiCcXc=bHN
<bHQ=bXU<bHQ9a/G;B4L0RlQ6@06=blYDST/IT`oMf=FP6mQP6mU0X1cJ@:0N700281gKh5bIX5aI7a[
G85YFWaQDGaQDWaQD@9hGTl017QJBg=MCW=HBFmBA`9_E4D01FiDAFa>?f=6=Th`9c/P6@028aLB00PM
4PdJ4A0F3@`>2@PF30`[8A`M4Pf5QH88P81n6Oooo`JBPWP02I9oMHmhKcDQ6d<W7CTW8Sl[93@R72`K
5C@Q6`02>24G00QD>bm^?bfBI4nDMf6ELf>BLf>BMfNBN6T2TW]^01FBMVRAM66AL5fAKeZAHe2<HDb?
I5:<HDb9Gdj9GDZ3FdR3GDZ1E4AlE4AoE49oET=jE49eCC]Z@S1@;B@i7QH00RDG40087a8<7Q8@6@d<
3`T86`d<@BHNR7]bUHEk29:2N23oool001koool8O7in00M[CTLa8aXe:28e:BD_8ah[6QD_7QL00S4U
8@08;bPS<bHP<RXVGDLoMVUHO6eLO6UMO6UL0WaYF00;O6ePPG5XOFeNN5aAM5Q;M5E;M5E<M5UBM5a?
M5A7MEE8009_E4L0271DAf]CAFM;?Um4>5<j;CTU8C4Q6B@F4@8N51001b8E4AXA41D<31H<32TI56Ub
LX63PP09O7in6Oooo`QoOGd01fe=AC4R6SPW8SDX934S7RdJ5RlO5`02<B@P00Pc:2<m:b=0=2aUC4Ai
J5YoK5moJV1oK642OfaO00]oKVB2KVEmJUakH5=iGU1iFDifEdafFE1fFdefETUhEd/00W9EB008Le=6
KU95K4`oJ4PkGD0bAR/U?2DK:1LB0R0E4@078ADA6Q4@5P`<5P`<8QHC8blbD4Y900UoOGdHoooo2820
OP07H4U2<B8I>BTS=BTT<R@O;Q`G;b4I008a9B001cP/8dL`9UM1=79HC7][GH1_I81_I@03P7=W00^0
LfR0KfAlJU]lIUMlIeIlH55hGDahGTmhGTahFdahGDh00W=HB@08LeE7KeA5Kdm1K4hoHdHfCS4X@bTM
:QPC0R4F4@0781D@6A4@5P`<5@`<7aDB0000<B0K00V0P7hIoooo29:2N007?bTR>B4G@2/T?RXS=R<L
<A/E>B<I008i9Ql024`e:5Pa98MF@9MdGi9`Gi9`HI9cIY9fH`:BMVH02i9cIXm^FXYUDXeXE8aTChaQ
C8UOC8UQBXUOBXUKAh=OC002PeU600QoEdAoDT1mCcebCcaZA35@;RE5:1/Z5Q428aH@00LU5@lK40lH
30/G30/Y5a9=<RaK>S402I:2N23oool001koool8O7in00MiJV8m;RX_920g:2@h91Xa91hW7AT00RdR
7`079adJ:BHT:BXU?blVHU13LfEHMVUH009lKF005WQYG7=UEGIYG7eXFWAHBgALBfmGAfYEAFYEB6iE
B6mGBVmAA6m?Af]@Af]D@fM??V=;?Um6>4D]93HS6B4D41P@308G41001QhD41XA414821<;2alF4`H0
00YlOWhIoooo27mmO@07NfEN>bXV<B@O>2PT=b@K<28M:A`H008`8ah07b`P738Y9CD]9U0k<FmKCg]X
FgaZFgm/HGm/GgeZGG]XFGaZH81YFgUMCgUMCWEFB79EB79EBg=GBgEHBgEAAG9BB71AAW1CA6a?@6Y<
?fI6>Dla9SlV6bHF4Q`B30026A0@00LO510K4A0B20PD2`/O5A<00022Ogl02GmmOASoool8P81n00M]
GULg9b8c9Ali:RDe91/^8QdZ71P00S<U7`09<2<N>bdWB3<YId`nO6]LPFmOP6mPP6mTP6mP00:1Kel0
581_I85]GGaSDgaQDGQHBGQJBgQJCWQMCWQKC7QEAg=GBG=EAg=EAFmB@fi?@FQ9>U@e:4<Y7BXH4alC
3@8K4A001b0E41/A418821D<328F4adB3HF5PP09P81n6Oooo`RBPWP01ddf;cHR6c`W7d@/9CPR63<Q
6c4M5P02?BPP010j9Qi9;bIa@BjBJ4nJO6RDLEfELf6BL5nBL5bAKeZDLEnELf6=IU:<HTj<HDb7EdH2
RUe<00f<Gdb7FDJ7FDJ3ETJ1FDB1Ed9mCcmjCce[AcEG<2=29a//5a4Q4``00QlB4005:1H@7A4@50P8
60`<<1TD00:EQG/9TX9h8?ooo`007_ooo`QlOWh01fmPDd4b:cP[9blU8C4W92LJ6RLL6@02:AhJ01le
:BDa8ATT71LW9B=4=RiTBT1]EDYcGE5cHEEhJEahIEQcGE5dI5M_FdeZCDA_E4M_C41_CD9ZDDA_E4M[
Cd=VCd1WB3aOACaGAcY;>2a;<RHh9AXQ510L510I4@`00Q@<2`064@/;2`L72`P89APD<AdD5`T42Wan
OQWoool8Ogem00MeH5A3<B/g:BDa9B4e9b<Y6QTZ71T00RXO6`0O=BPT<B4I;R4K?34ZF4@iL5Q<MEiB
NfAGNfIIOFYMNfIIN69FO6MIN5]>LU56MEI8LTm2LU55Ke=6MEE8L514KU12KdXoJ4/oI4/lFSd`F3T[
@BPM:1HB81HA6a4<008E30/01Q@;30d820`8224F4bXJ4`T40PYoOGdHoooo2820OP07KEiB@30[=BTT
<bHQ=bLR:a/I;1hI008]8A`023DY934R6CTW7eHo<VmEAGaXF7aZFh5^GP:1Kel2O6YK00F1KEelGTmh
F4UhFdUcE4D00W=HB@0<N5Q9LeA5LeA5Ldm3KU93K50oIT@dHD4aAB`O;ATC8aLB6a4<0aH<30053PT8
3@P881DB9ATC7A8=00Z0P7hIoooo29:2N007Dc`a?RXT?2TR?2LP?BLO;AXG<QlH008f8a`07chZ8cTR
64h]87mE?IEZDYEbG9AeGiAbGIAdGi5_FXe[EY5`FhmXE8UIAXYMAhMKAX=F@h=MBHMKAhMIAX5D@XAD
@gmB@7eF@GM?>g54<FU2;d8W6bhH4BDG41dA2`0260d<00HJ3@`@2@P?20P/5a<a6a><OgP:TX9h8?oo
o`007_ooo`QlOWh01jBNZUTo>cPY9C@W8ST^:CdX72dJ5002<bHR01h]8Adc:BLW7QXN81hQ8QhY9B5<
>35QBSmPBTAUDDeUEDaYF4e[E4MG@cI9>2iD?2iRBC]VC41VA3QVAS][CcYWBcUSAcYO@3AJ@3A9<BPd
7QP/6A@T5A4I40`350`<00H@20P<20PD30`I4PmRKG5fM7@:O7in6Oooo`QoOGd01iR<Te0g<SPY9CDW
8SP[9cTU6b/I5@02<BDQ01l^8A`e:BH[7QT/9B4i;RI;>2iQBCm`EDQ_ETebFe=bGE9cGE5fFTaXC3eO
@SITACI[CD1^CD5^BCa^Bd1`D3e/C3eZBCaVA3MQA3MB=BY191Xe71HV5Q4K4@`F30`00QD<30064@P8
3@P850/;6A8?=C/mA3dk2WmmOASoool8P81n00N0NgY2<2Tg:RDe9b8g:bHc8aXY6AD00S4V8@0O;R8M
=bXU;QhI?BhUDSX^K4/kN5e>O69AO6EGO6QJO6QHO6IGO69AM5E4LDhnLe0nLeA5Le53Le11LeA5LeA1
Kdm1KThoJTTjI4TjEST/BBTM>AlH9aLB6a4<5Pd<008F30`01Q4820d821<<2a/C3b4I52LF3@Z0P7hI
oooo29:2N007I4e3=R4I?R/T>RLP@BdV=1lF;ATD008l:R<07cDR6d4[8c<N5UTl;6Y3<Y5I@I]bFXeV
D99`GHm^F8m[E99[EhMOBgaA?HIC?hYF?hMHAhAD@XAA?XAJAh5D?7e?@GY=>gE:>6]:>5Xd9U0Y6cPN
5RTF41dA31T=300260d;00HD20P>20PG30/W5A1N?35K?C4:TX9h8?ooo`007_ooo`QlOWh01jBNZUTo
>cPY9C@W8ST^:CdX72dJ5002<bHR01h]8Adc:BLW7QXN81hQ8QhY9B5<>35QBSmPBTAUDDeUEDaYF4e[
E4MG@cI9>2iD?2iRBC]VC41VA3QVAS][CcYWBcUSAcYO@3AJ@3A9<BPd7QP/6A@T5A4I40`350`<00H@
20P<20PD30`I4PmRKG5fM7@:O7in6Oooo`QoOGd01iR<Te0g<SPY9CDW8SP[9cTU6b/I5@02<BDQ01l^
8A`e:BH[7QT/9B4i;RI;>2iQBCm`EDQ_ETebFe=bGE9cGE5fFTaXC3eO@SITACI[CD1^CD5^BCa^Bd1`
D3e/C3eZBCaVA3MQA3MB=BY191Xe71HV5Q4K4@`F30`00QD<30064@P83@P850/;6A8?=C/mA3dk2Wmm
OASoool8P81n00N0NgY2<2Tg:RDe9b8g:bHc8aXY6AD00S4V8@0O;R8M=bXU;QhI?BhUDSX^K4/kN5e>
O69AO6EGO6QJO6QHO6IGO69AM5E4LDhnLe0nLeA5Le53Le11LeA5LeA1Kdm1KThoJTTjI4TjEST/BBTM
>AlH9aLB6a4<5Pd<008F30`01Q4820d821<<2a/C3b4I52LF3@Z0P7hIoooo29:2N007I4e3=R4I?R/T
>RLP@BdV=1lF;ATD008l:R<07cDR6d4[8c<N5UTl;6Y3<Y5I@I]bFXeVD99`GHm^F8m[E99[EhMOBgaA
?HIC?hYF?hMHAhAD@XAA?XAJAh5D?7e?@GY=>gE:>6]:>5Xd9U0Y6cPN5RTF41dA31T=300260d;00HD
20P>20PG30/W5A1N?35K?C4:TX9h8?ooo`007_ooo`QlOWh01iRRVW9RDc<U7blT82dR7bTS7bDK6P02
:1`F01ld9B0g;2Po<2/]8R0_:2H/:RH[8a`b:RLY:2@]:1ln<2Q2=Ra0<ba3<RPl;24h;b=2;b===RQI
A39J?S1;=2a:<BIB=ba;>30o:R@i8AT]6A@R510H40`D30`@20P00P/71`052`P830P86Q@@9aTD4@h>
00]lOWhIoooo27mmO@07SXn;KEM<=B@O<RDQ<2@P;R@O:1XI008[7AH07cDV8CDZ9S`/:2dR7cH[9cP^
9d8^94lj=4Pg<4hj;UQ2>5Y5>EY1=ePk;T`c9T`f:5Hg:Um0<FA8=fI1=5dl<Edk;5ln<UPl<dh`9dDV
73DK5RLF4A/A31H<3148200430P800@I4`lS5a<010AlN7P:Ogem6?ooo`V0P7h01Ua;@c@T7cDW8S<V
8C4U82/K6@8_7aP07cDW8S@Z9CLZ9BlS7ch`:DHc:EXk;6M:@698>fa=?71EAg1EAFe?@FM5=5Tj:em0
;VU2<Fi;>Fm>?6i7>6]6=Va6<VU7=f52=UTg:d`/7cTN5bXG4QdB3AL=318820043@P800@I4`lR5Q<C
3@UkMgD:P81n6Oooo`RBPWP01h9[IT8Z8cDQ73dX8SdX8CDT72hI5P02?B@I01lj9b51;BHi9R0j9am;
=2YP>BYgAc9gDTAdDSn6ECn7HDb5GTQgCSiaAC1W?BYgAbn0B3F1Dc^5Cc]jBSUiB39nBSAgBSMY@SAQ
>2Q>:A`l7AH[5a0O4P`I3@`D20P00`l820053PP781@?;1LCRGQ_Sg]b00ZBPWPPoooo000Noooo2Gan
OP06SXJAB3Hb=BTU=2/W=RPT81LB0R8M6P0O=b`X>BhY@3@_ASPcACT_?cP_=C8[<BHQ<AlI:AhL:Q`I
<b@P=2HR;2@T=RHQ=R<J<2<L=BTS>2dT?2`Q@c8V?2`P=RXS?2HO=b@L:AXE9adI6Q8=610<5@`<4@P8
00<<20P0124D41T@44M2@4Tl>P]lOWhIoooo2GmmO@06RWb3A30[=2LS=2TU=BLR8ALB0RHM6`0O=RXU
>2/W?c8]@3<^?S<[?SD]?S8Z?RXS?2HN=RDQ?BHOAS0W@bdW>bXW@RXR@2LL@2TPB30WC3DXDC@VDSLZ
BBlRB30WBR`R@2PO<A/F;AdH7A8=6Q4<5P`<4@P8008=20P01@`821dC41P@434b<BDN7@0;Ogem6?oo
o`V0P7h01WUaLS//9C<W8c<Y93<V8B4G4P8[7a`07cLZ8cL[9Sda;3/_:SX_:Clc;4Dc:DL_9dD]8d8]
9Tl`9EHl;dhe;4L`:D`_94T]7dl`95Xi:edm;68l:edm;U@c9EHg:e@b9TL]8SHN5c4N6AhB3A/A31H<
314820023@P800D<20PK4`lF3`lY:BHM4Pd02h20OQWoool9TX9h00IKASdb81Ll:B8i:B8h9AhQ5A02
>B<L0153;BE1;BI5<BU1;BI5<BM<=2UA=2M@<2M>;b9B<2IS>2MW@c9C=2YC<RMJ<25H<AiO<bD00W52
;@0<KChZJcl]H3@SIC`]G38UCB`P>1`E=QhG7a4;7Q4<60`;4`P70`h81`048Q<?6Q0?CcL^KUiF2i:2
N23oool001koool9O7in00JSXj=SB48d9B4a920a9B4m:bH2>2/W01hg;2Pm<Rde:BDa9R8a8All8adl
8QXa91lU7AXX8QlQ61@Q71/]920Y81`O5a@M61LM5Q<J4Q0O61@T71HR6aDS5Q<P4Q0O5A8Q5Q<L510E
3`/D30`C2``D30`330P800@Q51TQ518f9b59EEL<O7in6Oooo`UoOGd01YJ@T5a0?3@U8C@U8C8V8STX
908`9R805cDZ9Sda;3PZ9SLY9CPU8T0X8ClW7SHW8B`N6S0S7bXI5RlQ7SHW8RlR7BTI5BXL62XI52TG
4c4P63@R6C4P634J5BhH4`02;1TE00<R5Q4I40`G3@`00QD<30083@P830P830P87A<F7A<@<2<N62HY
HeaJ2gmmOASoool9P81n00J1P7i<>3@c9R4e9b8c9b8c9R42:R<O018d:RDm<B`i;2Lk;BPn:RE4;bE0
;24i:R@a81/g9R0a71Lk9b4m:R@d91la7ALd81Xd7AHh7AL2@BPL00Po9a/m7aPi7QLf7aPd7ALU618M
4PdI3Pd25P`<0`d820056a<E6a<?:b4L2@T9E4Do00^0P7hIoooo2I:2N006LeeI=R4K>BLP?2PQ>RLQ
=2<M0SDT7P0C@BdVAc8Z@2`UABlWBR`TDS8UAB`P?RXS=b0I@RTQ>A`EBBdT@bXR>bDN>QdF?B<J?AhF
AR4HCRdM009;:Q`02D@P5d<Q63dP63/N5RLG4B4C31/=31T=2aP=2`033PP700DR4aDR4`hb8QeQAd5e
Edd02i:2N23oool001koool9O7in00J7SHNMV9Q8=S4a9B4e:BDd9b82>c0/01d_8ah_9R<_8ah`9R8o
=2/e;BP_9b@a9B4a91lg:2@/7A`S7AXU61@W5a<Q510J4`lL510S61@U5a@N4a0K4PlL510S61@Q510N
510I40`H40`E30`D30`00P`8208D30`00b<J5R`K5W1_K`0=O7in6Oooo`UoOGd01XF4PHn1Pd4^:C8U
8CDX93@V8P8i;RX07C4S7SDY9S<T7c@W8cda:CPZ9SHW8SDU834S7S<V8R`L6bLM6RXI5B/I5B@F4AhD
424E4BLH52TG52<E4B4D428E4BPH52@E4B4D41`A31TA31H<31D<300230P80Q@;2`047aPE:QTE=3De
AdM737mmOASoool:P81n00EdJf`g9b8c9R4e:B@c9R400SP^:@0<<R@O>bhY=RLQ=bXU?2lX>BTT>bLQ
=bHP<2<N<RHQ:a`J:QlK0RhL5`059QLB8AHA91HB:QTD;1TD00<W5a801b`I52HF4B@F4AdB3AXA31H<
31D<30023@P80Q<<2`047aPE9aPE4`d99b0K3820OQWoool9TX9h00J<N79C>SD`7ALj9b0n:R<i9Ql2
AC4Y01/f8aa:=2`i9Ai2;BI:<2I09b519ahm9ald8A/o:B8[6AHc8a`e71Hc7AHY5a4U5a4[5a4c6Q@c
6a@/614^614]5a4d6Q@Y5Q0Z5Q0N4P`M4@`00QP<2`8>20P25``;00@/6aL/5a=A>S5H?C@<TX9h8?oo
o`007_ooo`YlOWh01IRCUf4n>3XY9CDY9C@W8P028adI014g;RTm<Rdj<2/[8Ad/7aT[71LY7QX[81/Q
6AdN71XV6aTW5a@Q51TJ514K510H40`J51000QPD400<5a0<4P/;5@l;6a<?610<4P/;5a0<610@5@`<
30P850`<7aDA0R`O6P03:ATDO7inO7in00elOWhIoooo2WmmO@05THR:G3Xe>2PT=BPT=BLR008Y81/0
1S/^:ST^:SX]:BdQ738S734O6@8^8A`022DJ7BDN6b/K6RPG52<F6AhD4AhE4AXA308K51003AdD41/A
31D<31P@31hC41/A31D<31T@31T@41H<30`821D<31/C400291/G00<U5a=1@T91?cl03GmmOASoool:
P81n00F1OWa>=C0e:B@e:B@e9b800RhS7P0=?S0[=R`W=b`W;R8M>BLO=2<L<R@O<2<N9a`N;28M;AdK
:ATE91LI008Q5Q4041/A31dE41hE424F4AdB3AL=31/A328E41dB3AL=31/A31TA41H<30d821D<31TC
3`8O61D00b8F4adF4QdB3@0=P81n6Oooo`ZBPWP01GEOF3TR6c/Z8chZ8cXW8002=RHN01m7<2U2;RLh
9b4f8Q]::alf8Q/j9Qhh91dZ6a`h9Qd_6aT`6aDX5aPU5Q0T5Q0N4@`S5Q0T5Q0V5Q0P4P`K3@`P4P`Z
5Q4O4P`K3@`O4P`M4@lH30/>20PH30/M4`h00RHH5003:aLCDCL^DC<[00fBPWPPoooo000Noooo2Wan
OP05SINAP7=/?BdX<bPT=2LR008j:bL06BlX92hV8RlQ7BTM6B4J624D42LM6BDI6BHI61lC41lD5aH@
4A8;2aH?41L@41@<31H?41<;31H?41@<31P@41`D4AL@41@<30`820032PL700<H410I4@`C2`/00QT>
2P03KFe/MWAdO7in00elOWhIoooo2WmmO@05R8V7NVEQ>bTT=BPT=BLR008h:BD07blW8c@X93<T7b`N
6RLL62HF4BTN6RLI6BPI624D4B8E61TA4AH<31T@4AT@41H<31P@41D<31P@41H<31T@41/C41P@41H<
30d820`720`81``821P@41L@31@;2`0270l;00<l?Sdn>S]oOGd03GmmOASoool;P81n00AWEe<g9R4g
:RDe9b82=BTT00L_9b<i;2Lf9b4^81//7QTZ618]8A`00RTK6@0?8QHB91LI718B6@d=6a4B6Q4@5Pd<
6A4@5Pd<6Q4@5Pd<6A4@6a<@6A4@5`d<00@=20P00aP@41H?2aD<3002814<00<Q7ATM4Pf0P7h03H20
OQWoool:TX9h00F8LVa:;bTf8Qa0;2Dj9b000S/Y8P0O>BXSABhV>BHN<R0I=R0I;1LA=b@M;A/H;1/I
:1LA:ALI818@70d<7a8A7Q8@6@d;7Q8@6@d<7Q8@6@d;7A4?81@?7A4?6@d;3`P83`T840T83`T8710?
6Q0;60`<008Z4``00ePo=e@j<I:2N00=TX9h8?ooo`007_ooo`]lOWh01;o:bhMcK3LX8RlT808_:2@0
5c4Y9CL^:CPZ:RdK5bTL61lF4Q/B3Q/D3ahD3a@<314;2QL@41TA4A@<31L@41D<31L@41D<32LG50h9
21D?3a/D41TA400230P800H@20PI410L4Q8H410Y6ADm9AX2HT@c00=9=bYlOWilOWh03GanOQWoool;
Ogem00BTXjA]FE<e9B0b9B42<BLT01ld:BDg;2Pg:2L]6QHZ71PP5Q4N4`lO5A4Q510G30`E30/I414I
4A4E30`H410F30`H3a0F30`T5Q<>20PF3`lK4a0J4A0=20P<20P@20PH410I410G410V5a@a81P00Sha
:@037aH@O7QhOgem00eoOGdHoooo3820OP03CD0j<2<N=BLR008c:B@05cDZ9CL]:3DW9B`K5RXM6B4F
4R8E428G4R<F4QP=3AL=31/A4QTA41D<31TA41H<31P@41H<328F4`d821P@41`D41XA40023@P800H@
20PF3`lF3`lF3`lT5a@W7AH292@P00<C2@AkMgF0P7h03H20OQWoool;TX9h00A[DDLd7QP`7aTm:283
?2/T01I2;RLh9B4_6A<`7QPR5A0Z5a4U5a8Y5Q4J3@`K3@`O4Q4L40lH30/M4A0H30/M4A0H30//61<=
20LN4A0Q5A0M4A023PP800HC20LJ40lI3`hK40l/61</71@2>2DO00=XFeZ?Ng:BPWP03I:2N23oool0
01koool<O7in00>ob/^:KVLo<R`00RdQ7@0<=bXV>BhY?S4[<2PR;B<N9aLK610B7a@@610@7ADA7aHA
6A4@0Q@<300A4`/;50`<4`/;71@@5A0@<bdf=c<f9aTN5P`=6Q4A81HB81LB6A4@;B4M<R4K:AXE?bXT
009[Kg@@O7in6Oooo`aoOGd00jBSY6mECcT/9`02;b8M00`f:RLh;2Pn;bX`9B0]81`V5QXI4A4Q510I
4A0N5A4M510I41025@`<00XD2`/E30`D2`/L510F410`9bdZ9bTS5QXG30`J4A4271@@00DH410X7Q/[
7ATV61@h9b400Shm?@03H5A>OgemOgem00eoOGdHoooo3H20OP04CChh<BLS<2<N<2<N0SL]:00:>bhY
;R<O;AlK91HI6Q4@8QD@6Q4@7QD@6a<@610@0QH<300:5@`<5P`<5@`<71@@610@;B@U81hM7a@G5Pd<
6A4@0QTC3`055`l?9AdJ91XG91LD=BHP008W6a800dlg:820OX20OP0=P81n6Oooo`bBPWP00f]AAc8L
5S4S7@02=R<L00a3<2U1;RM1;BL^7aTd81TU5AHM4@lX5Q0M4A0Q5@lN4`lK40l560d<00LQ5A0N4A0`
92DV71LQ4Q<H3@/K40l00Q`B3P056a0?;alI9QPE;1LCBB`Q009RA3@00g9>?I:2N9:2N00=TX9h8?oo
o`007_ooo`elOWh03lKFehY/I4`i<d`i<bdQ7BXU8CP`;4He<3PU6c0P6B4G4QL@41@<31H?2aL@4002
50`<018H410E30`H410E30`B2`/[:2PY7B8k;2aA@3I8<c59=c4k:B<Q5a8[7QTW6aPe:BE;<2IfMGD2
O7Ui47anOQWoool=Ogem02>VZ:U_Dde2<Re2<Rd^8A`a9b<j<2]2<B`d8aX_7aTP5Q4H410F30`H40`I
410F30`E30`H410E30`H410E30`D2`/X92<V6b0g;2e3=c4j:BTg:RL`8QhP5Q4X71LU6QLd9b<n:R8n
?Cd00UI:Aa1oOGdHoooo3H20OP0DP81mCC/f=bdX=bdX;R8M=b`W?C4/>bhY;b8I;1hI7QDB6A4@5`d<
6A4<6Q4@5Pd<5P`<610@5@`<610@0QD<300=9b<Q91XO=Rl_=Rl/:b4Q9b4O9AdJ7AD@9A/G91XG<bLS
=2HO7AHA0090:Al@P81n6Oooo`fBPWP08f]=@c8L5SHW83HW83DR6d4_9dXd;3`Z93@P5RdL61lD41dA
41T=31hB31hB41T=31P=31`@3aL<2a`@3aL<2aT=334W8b`K8D@e;SLX9BPJ6RdP6bLJ5AhC3R`K5RdL
5c`Y8ShS6e@h;`02J4Lj49:2N23oool001koool=O7in015fNGVocm1iFDYiFDY>>S<l;BPh;RY0=2m6
>SHb8ad^7aXj:R@f:B8W61<O5A0J4Q4I4A400Q@<300@6a@G6Q8B7ADA50d<8AdG9QlL5@h>510=4`l<
50h>7a@@9AXG<B4IBc8TOWIeJfY_4WanOQWoool=Ogem015lNWZWZ:UUAcaUAca7=Blh:BDg;BY0<bi2
=C4a81/]7QTa920]8QhR5A4N510J4A4I41000QD<300@6a<F6Q4A71@@5Ph>9b0K:R0O718B7QDA6a<@
6a8A8aDA9AXF<20H?2dSDdi<BSlo0WmjNQ1oOGdHoooo3X20OP0RQHF2BcL^BcL^?C4/<bLS>2lZ@3<]
?C4/;QhI:QdI:B4L91dJ7Q<@71@@6A4@610@5@`<5P`<6a<F6A4@6a<@610@;2@P;b<R8QHE9QXE8aPC
8ADD9QLB9A/G;b4I=B/S=C4[>b@K0X1lNA20P7hIoooo3I:2N00?UHEkKU57=adF=adF?BdW>2HPAc@/
Ac8Z@RdU;A/D;A`F;R0K91XF8A8>7a@?008K40l04QP<2aP=324E5Q/@3QlC3alC4SHW8ChX92@F52`L
5BXK52@E4bXG4BlN5cPQ5d`b9e8k=Vm>?P:BOgD@TX9h8?ooo`007_ooo`mlOWh2aMWO01ifIELe9b0/
8am0=S9=@cmA@S`b8adQ5aLW5a@f9b8b9b4M4a8D30`Q6AdU724[8ahW7B0h:bTU6Ade;2`h:RTo;BPm
:bHg9b4m:bE9>S0m;BIC?C62Ogj=TX`CO7in6Oooo`moOGd2Yj^^01mRCD8g9R0a9R91=C58?CU:>S@_
7a/U61L[6ADb9B4]8QdL4Q4E30`P5a/Q61`V7Q/T6Qd_9B<R5aX/9RHd9bHj:B@a924_8Qdb9B0g;RLd
9R50<b]:AdAVG5=eL7<04WmmOASooolAP81n01m9=bhf9b4g:RE3=c93>CA0<bdZ7ATX6QT^71L_9B0W
7QXJ4A0F30`O5aXN5QPR71PP61`X8AlM5ALY928_9B<c9R4W7a`W7QXY8A`Y924[8A`d;2DW7aE:<RAa
JF`04X20OQWoool?TX9h0VQ7>P0O=ahF=B8LABlWDS`dBcT`?BTS:aXD;Q/I<adF=BDN:A`F6a0>60d<
9API8ADF:QdH8QHI=2<L718C?bdU=2<O<R8L;1hI:Q`F;AlJ<b@M;ahIC30TE3P]I3daR79/01:BPWPP
oooo000Noooo4GanOP0MaLoEb;k6HTm:<2HR;b@Q>cPlET]9H4e5G5=<?Bh^<B/]Bd==IUQEAS<_=BXa
=2L[BCe3>Rl^?bdU<RPU?RdW?RLR?RDM?B/UAC@[EcX]CRdPFVEZO8>201AlOWhIoooo4GmmO@0NYjJY
RGamCC`h=2LS>B/W@CXkCD0mBC/fASdj=RLV<BTY?cLkASdl=BLV;bD[;b<V?C@g<bPX>bXT;2DS?b`W
>bHR>bDM>BTT?BlWAS@[B2/P=3XmH5I@OgYj4gmmOASooolBP81n01e9@SPf;2Lg:RE2<bi5?Sa3=c8e
;2Pb:bT_8R0`:BHc;B`Y9bDU7QdY8RL[8R<c;B`]92<e9b8[92<n;BPg9R8g9Qhe:B@g;2Dk<BTn:R0W
81]?=bR0O7T04h20OQWooolATX9h00MXCT4_50L]71E2;BI>>C1=?ca6;bD00SLU8@0E<AhK=2TT>2TV
;1hH9APH;B4U=2<N>Rd/=B<L=2<N?R`W@R/U?RHP?RLL>BTS@bdTCSDX>BDLJdi1LTXjTWme01>BPWPP
oooo000Noooo4WanOP0JTYbFdMWJO6YaASPf=Bh^@497DD]=BD4oETe5GU5=E4HmBCXfASL`ASH/>2XX
9a`F;B8O>BhY=BTU?bTQCBlUD3H]G3ldBbdT@cPkWZ:Z5WanOQWooolBOgem01^;S8VQVimRCe=1<c0h
;bi0?dA>A4A9?S]@ACm<@3i4>cI6>CQ6=C0o<B/e9bP/7aXd9b@i;2Pe:2@n:R96;BE8<BU>=Ri3:b=4
=cMcIVA=Ad@05GmmOASooolCP81n01Y/IFM3=cDk;bXi<C14@D9:?ca9?CQ9@3Xk<c8h=393>CY2=Blh
;RXa9RP`8ali;2Xi;BPe:B@o;2A0;BE0;RI1<BTl:R98>SA?=bPa81HEP81n6Ooooa:BPWP06hE^JE@d
;RlK5D0]940e=Ea7@58l=E4m<dTg<D0`;T@c<4dk=d4^:3l]:SDT93XW8D4/9d8^9chZ8d`/8DT]94L]
94Xa:4@Y7f95>ehg8Ehm<@0ETX9h8?ooo`007_ooo`03O7EeO7UiO7in015lOWh05lG?am7If/g3`V=H
IE=8CWEWM7QVKV9;AE51?4e1?69>CFI>BfE@B6eFCf1;?eA6?fEABU=9?dI2>3T]:51=EJjka[C5`@0G
O7in6Oooo`03OgUiOgYjOgem015oOGd06:NVXXF2Qh9gM557D597Bf1FG65CEUI5@511?Dho>eI5A591
?UE3?E92?d/k<dHj=E92?TPl=DHi<Cl/9dQ1@GQbMG9]JF1IFQIoOGdHoooo5H20OP0G@3Lj>cH]?CTm
DdY8CdY8C4E1Bd8lCD8oCD0jBcll@CPcA3Td>c<a=blY>c8^@CPc?C<]AS<[@R`UBS`cBSL]>b@KCd0o
01J0P7hIoooo00>BQ7ZBQG^BPWP04I:2N00HJ4i:=a<?;A@>>R/ZI4i4FdY3CS/^DShfDd0iESlfDS/e
BCD/@S0[@BdX>BPQAS8/BC@/A2dTDC4WB2XRLU54DBHCA1<9LUA=5Y:2N23oool001koool00gb3PWan
OWanOP0CO7in01>7SHO5b[f^^kRMYYZNXjfY[kbVWZaZHGA:BUQ6@D=:?SY3?3Q=@Cm6>SHi;RHo<RYf
MGCFg]nHYZ006GanOQWoool00gmmOGmjNWmmO@0COgem01B5Q86QViQbMGYeLVj2OXMoNh9nL7ANDEU<
AD]>@45@?c]8?3UA@3e8>SE2<b]8=bmCDDj8Q89LGUY_J6/HOgem6?ooo`:0O7TEP81n00IgLWE0>d=D
BDQUGfAICdiFBD82CT=100]C@SmC@Sa=@3YC@Sa9>cA9>2m??CA0>C10=bda91mXFeh06820OQWoool0
0i9kLY9oMI:2N00CTX9h00Z<N79RAdY;:B]R@45TATEN>ba<;R9:=B]LA3aN@CD2Fd8i00QJ@CIC?3=G
>RiG?c9[DDDd3`=>9R:2J6<HTX9h8?ooo`007_oooaYlOWh00hN=PWb3PY:LT@02^/2c00Rob/^o`lFo
aLNob/_5cm3:fMo:e=YlPh8KO7in6OoooaYoOGd03XF4OgUgOH^9Q9F?SWmmOH:2RGmkNgmjNWmmOH9o
Oh:2Q7mjNU=DD7mjNQYoOGdHoooo6h20OP03Mg9iP7aiK6E/009:AD`024Dn>4Dk=TDk=TDk=T0g<C/^
93/b:81lNAZ0P7hIoooo6Y:2N00>S7QeS7EbQF]YHDA:BRddAbHUA28GA2<HA20E@A`B>Q<6=a00IDLj
TWme6Y:2N23oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo0019oooo0`00
05Soool30000Eoooo`<0001Hoooo0`0003Coool004coool00`000?ooooooo`1Hoooo00<0003ooooo
ool0Eoooo`030000oooooooo05Soool00`000?ooooooo`0aoooo000[oooo1@0000;oool200001?oo
o`800004oooo100000;oool300000oooo`<00003oooo0P0003Coool400000_ooo`@00003oooo0P00
00Coool400000_ooo`<00003oooo0`0000?oool20000<oooo`@00004oooo00<0003oooooool00_oo
o`800004oooo100000;oool300000oooo`<00003oooo0P0003Goool200000oooo`D00002oooo0P00
00Coool400000_ooo`<00003oooo0`0000?oool20000;_ooo`00;Oooo`050000oooooooooooo0000
00;oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`0000Goool0
10000?ooooooo`0003Woool00`000?ooooooo`03oooo00<0003oooooool00oooo`040000oooooooo
00000_ooo`040000oooooooo00000_ooo`030000oooooooo00?oool010000?ooooooo`0003Soool0
0`000?ooooooo`05oooo00D0003oooooooooool000000_ooo`040000oooooooo00000_ooo`040000
oooooooo00001Oooo`040000oooooooo0000>Oooo`040000oooooooo00001?ooo`050000oooooooo
oooo000000;oool010000?ooooooo`0000;oool010000?ooooooo`0000Goool010000?ooooooo`00
03?oool002goool01@000?ooooooooooo`000002oooo00@0003oooooool00002oooo00@0003ooooo
ool00002oooo00<0003oooooool0100000;oool010000?ooooooo`0003[oool00`000?ooooooo`03
oooo00<0003oooooool01Oooo`040000oooooooo00000_ooo`030000oooooooo00@00002oooo00@0
003oooooool0000ioooo00<0003oooooool01?ooo`050000oooooooooooo000000;oool010000?oo
ooooo`0000;oool00`000?ooooooo`0400000_ooo`040000oooooooo0000>oooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00@0003oooooool00002oooo00<0003oooooool0100000;oool0
10000?ooooooo`0003?oool002goool00`000?ooooooo`02oooo0P0000?oool010000?ooooooo`00
00?oool300000oooo`800004oooo100003[oool00`000?ooooooo`03oooo00<0003oooooool00_oo
o`800004oooo0`0000?oool200001?ooo`@0000ioooo00<0003oooooool01?ooo`040000oooooooo
00000_ooo`040000oooooooooooo0`0000?oool200001?ooo`@0000koooo00<0003oooooool00_oo
o`030000oooooooo00;oool200001?ooo`<00003oooo0P0000Coool40000<_ooo`00;Oooo`050000
oooooooooooo000000;oool010000?ooooooo`0000;oool00`000?ooooooo`03oooo00<0003ooooo
ool0@oooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo00Goool0
0`000?ooooooo`12oooo00@0003oooooool00002oooo00@0003oooooool00002oooo00@0003ooooo
ool00005oooo00<0003oooooool0@oooo`040000oooooooo00001?ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00<0003oooooool0?Oooo`00;?ooo`800004oooo0P0000Coool200001Ooo
o`800016oooo0P0000Coool200001?ooo`<00004oooo0P0004Goool200000oooo`@00003oooo0P00
00Goool20000A_ooo`800004oooo0P0000Coool300001?ooo`80000ooooo003oooooTOooo`00oooo
oi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooo
oi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`007_oo
oaQkNGT01W9@?85]H7]YIG]aJG]UGG]aJ@=kKFD01g]UGG]YFG9QEGMMDViAAW=ICFUAAP04KeE900A_
CD9VDCi[DDM[DCh2Je5700>BZkQkNGUkNGT00W]iN@03Ng1aNginNgUi00QkNGTIoooo67QjNP06Ke4m
OViQN6YVN79ZN6INN79Z0gQ^IP07N6INN6YIKf9FM5iBJe97L5U=IU9600A/EDT016a>@V=A?fQAB6QA
?`9XDDP00i6]^WQjNWQjNP02N7Yj00=hLG9hOgmhNWX027QjNQSooolHMgMi00I^D3ikJf1gIfEgKfUg
HeigKfT3Mf]U00MgHeigIeU^GeIcG59ZD4M_EdaVD4H016]CB004Jda2HdlnIdm7Idln0VM?A`03RjBd
MgMiMgMi009gMgT00gM_LGMkOWMgN@08MgMi6OoooaQUMGh01F5RGFEUHFEUIFEYJFEUI@04IFUY00AU
IFEUIF5QHUeQGUP2GUI@1EYBC004FTi7Edi3Edi7Edi30UM>A`EUMGh00fEaNVEeOVEeOP08IGEn8?oo
o`007_ooo`06NgUiNgEeNginNgUiNgEeNgin2G]iN@9kMGD00g]nOW]iNG]iN@04NgUi015fDcmkJF5k
JEekLFikIEekLFUkKFEkJEegJF1lJF1lIEQcH5AdGDmdEDUdF4][DDEdF4/00VmEB@9_DDD00fIA@V]A
AF]A?P02Jf5P00>BUiakNGUkNGT00W]iN@03NgAeNgUiNgUi00QkNGTIoooo00IhNWYhM7AhOGehNWYh
M7AhOGd9N7Yj0WQdM003N7emN7YjN7Yj00AhNWX04GEF@G]/IWQZGGQbK7QVGWQbJWQ^IWQXFW5TF7AT
F7APDV]ICVUFBVU@AFaEBF=>@VmGB`02K5E90Va@A003He54J556J54o009XJV`00i6SZgQjNWQjNP02
N7Yj00=hN7QhOGehNWX027QjNQSoool01GMgNGM_LGMgNGMgNGM_L@0:MgMi0WM_L@MgMgT027MGA7][
JGMWGGM_JGMSGWM_JGM[IGMSEP9^G4l01ViHBfI@B65=A659@6I@AUi9@0=[DdP2Jda200=SCdEWCdMW
Cch00VM^M@03RjBdMgMiMgMi00=gMgT00gMkOWMgNGMgN@07MgMi6Oooo`06IGEnIFigIG9kIGEnIFig
IG9k2FEeOP9UKWL00fEbNfEeOVEeOP04IGEn00EXJ6=XJ6YUIF5UJFMUIFD00VEYJ@0:IF=LGUYAFeYA
FeI@F51<DTa8DD]6E4e8DDY4F51:0UYBC09JC4H2Edi900AGCT=GJ6mGJ6mUPY44IGEn0VEhP@UUMGhP
oooo000Noooo00EkNGUkM7EkMGEkOWikM7D00W]iN@04NgEeNginNgEeNgin17]iN@9kM7D7NgUi00=g
E421KFAkJF400W]]I@08NfUQNfeUMfEEJf5IPf1AN5Q?Ke]<Kea?0VmEBP09JTi3Je55KeA7KeA7Ke55
Ke51Je57Je55Je52009kSIH6NgUi00=kMGEkOWikNGT01g]iNAWoool02gQjNWQhN7QfMWQmOGQhN7Qm
OGQjNWQdM7QmOGQdM7QmO@04N7Yj0WQhN003N7emN7YjN7Yj00AhNWX01G5C?W]/HGQZHWQ/IWQ^IP02
N6YR00UaHU9MGUQfFdi`D4YVE4IYFDe/F4a/FDeYDTH00fQAA@05J514J550IU56J555J55400:5WZ/0
0hF9S7QjNWQjNP03N7Yj00=hM7AhOGehNWX01gQjNQSoool2MgMi00QgLgEgMgUgMgUgNgigMgUgKg5g
MgUgKg47MgMi00=gNgigMgUgMgT017MgN@0AKU0nMfMMMfMQMfMUMf]UMfMQMf=NKUa?EUQFJU=;JTI4
HDU0IUA9JeM<JeY?Je=8Idm500=SC48016=??V=?AFM?AFM?A@:;Y;P00h^BVGMgNGMgN@03MgMi00=g
Kg5gMgUgMgT01gMgNAWoool016EeOVEhPFEaNVEbN`9UN8401FEeOVE^MfEbNfE^MfEbN`04IGEn0fEh
P@IUMGh04EiOFV9SG6EUIFESIVEYJFEUIFEPH5iLF4aIFU9BD5Q6B5A7A5MAC5YHDUYJE5eFCeM>A`02
DTY400EBC4IBCT9DCTIGCTMGCTT00W:9U`03LXVDIGEnIGEn00=UMGh00fE^MfEbNfEeOP07IGEn8?oo
o`007_ooo`9kNGT00g]`LG]nOW]iN@02NgUi00=kM7EkNGUkM7D03W]iN@0AMU0lNfeUNfUQNfUQNfeU
NfUQNfUMMVEMIF1IKEQ;MTe>He50KEE9KEQ?KEQ=JDa2IUA500=[DDD016]A@VmEBFI=@V]AA@:BZkP6
NgUi00=kM7EkNGUkNGT01g]iNAWoool2N7Yj00=hLG9hOgmhNWX00WQjNP04N7QhN7emN7QhN7em3GQj
NP0AME4mNfiXN6YTN6YRN6aTN6QPN6YKMFQPKfQRN65BNeIHJ5Q7L5E9L5E?L5E=JDQ1He9400=XDDD0
16QAA6mGC6I@A6QAA@:A[KX6N7Yj00=hN7QhOGehNWX01gQjNQSoool2MgMi00=gKg5gNgigMgT00gMg
N@03Mg]nMgMiMg]n00egMgT00gM@?W][JGMWI@02MfMQ00QgHeigIeUgIf5kJfV1IeV0Fem_FTadDdP2
M51<00=[@T1SC49WCdD00fM?A@03KeI>Idm5Idm500:;Y;@7MgMi00=gNgigMgUgMgT01WMgNAWoool2
IGEn00=ULGYUMGiUMGh00VEeOPAUN84=IGEn00AXHUeXIFQUIFQUIFD2IF=S00]UIEiXJ6QeKW1aKFI^
I6QWGEQUDTaUCDiUCE1NA4IGBTH00eM>A`04Edi9GEA?FU19Edi726EeOP9UN848IGEn8?ooo`007_oo
o`9kNGT00g]dMG]iNG]iN@0CNgUi00AkDcmkJF5kJF5kJFD2NfUQ019kJEekKFEkJ65fH5EgF59bDD]b
EDMbEDe^CTUaED]O@caZD4EZGE5VBSa_DDE_E4MVDDE_FDd2S::_47]iNAWoool2N7Yj00=hN7QhOGeh
NWX04gQjNP04N5I1N6aQN6YMN6YT0WQZHP0BN6YPN71ZN6iVMFILM5mFKeM?M5a>M5eCKU9;M5e@I4Q1
K4e5K5mGITi1Ke55Ke=6He14Kee@0XjX]A1hNWXHoooo0gMgN@03Mg]nMgMiMgMi019gMgT00gMGA7M[
H7MWF@04MfMQ00egKfegKfUgIf5cHeU^Fe9gGUAgHUM_DdagHUA[BdE_B4E_GEYWCdD00Vm?A@04Hda2
KeeBRjBdRjBd47MgNAWoool2IGEn0VEhPAAUMGh016EXHfEXH6EUFfEUH`9UIFD04VEUJ6E/KfE_KVQ[
KF5ZHF5QGFQQGFQSFf5FDVQTFf=@CF15Af1HFeYBCEe>Aee<AUM<AUeJE09XNhD@IGEn8?ooo`007_oo
oaQkNGT027]G@g]YGG]YHG]YGG]YIG]YHG]]IG]YH@9kKFD03WIPEGIKDW9EBgMHDW9EBW=ICFe:AfU=
@fmDBVYIDF]:?6mAAF]AAGaaK@:1SI87NgUi00=kMGEkOWikNGT01W]iNAWooolHN7Yj00MhF4=hJUeh
JVAhJUehJVAhJV9hL6P00WQZHP0?N6iVMFILN6EJLEi@M5]FLEY>L5]=JTe8JEE8K5E8JEUBJ4i1J555
IU55P7]j00:5VJ87N7Yj00=hM7AhOGehNWX01WQjNQSooolHMgMi00AgEdAgIeegIfEgIed2MfMQ00mg
KfUgIf5gHeigJfEgIf5kJf1cHeEcFeQcFe5_FTaZCDU[FT][DdE[Ee5WCdD00V=?A@03PGj3QYb[QYb[
00MgMgT00gM_LGMgNGMgN@06MgMi6OoooaQUMGh2IFEQ01IUIFQUIF5UIF=UIFEUK6aUIFEUH61UJFUX
Jfe[LFYUJEmQG5eUGUUNF51OE55NFe5JCTAMEUAGDTeBCTMDCTMXLGT2Jh:A1fEeOP03IFigIG9kIGEn
00IUMGhPoooo000Noooo5g]iN@03KeUAS7YXNfUQ009kJEd057]YIG]]IG]YHG]]IG]XHG]]IG]UGG]Y
GGIMCWIIDW9HCW9ICFi>BFeEAVU=@V]GCF]AAFmAAFIAAHR=UP:1Ph<7NgUi00MkM7EkNGUkNGUkNGUk
MGEkNWYkOWh00W]iNAWooolGN7Yj00QTBT62JUIhJVAhJUehJU]hJVIhL6QhJV82N6iV00mhL6QhIUih
JV1eH59hGUAaFdiaG51^D4]]EDIYCT9VEDUVCT5_DDEVDDF7U9h00Wj9R`MhNWX01gQhN7QmOGQjNWQj
NWQdM7QfMWQmO@02N7Yj6?oooaMgMgT02Edl<gMGA7MWIGMWGGMWFGMWIGM_JGMWHGM[I@02MfmY00ig
HeigIf5gGeIkGeEcFdicFe5_D4a_DdI[C49SCdESBCe_CdEWCdF1TJ02NhV@27MgN@03Mg]nMgMiMgMi
009gKg43MgMi6OoooaMUMGh05593@5]?BFEUJ6EUHFEUGVEUIFE/K6EUIFEYJFE_KVE/K6EUIFEUJ6QT
HF]SFfELE6ELEf5DDV9BC5i>A`9DBT800ee>AeY>Af5dO`02IGb81fEeOP9UN842IGEn00=UKWMUJgEU
LW/00VEeOR3oool001kooolFNgUi00A6>32]QgF1KF1kJFD2NfUM00EkJF5kLFUkIEekKF1kLFh00W]Y
H@0=NfUMNfEIMeE>Mea>MeUAKUE5Kde5KeE9JTe2IU55M5U=JTi3QifZ00ekNGT2NgAe0g]iNAWooolF
N7Yj00/]9Qn?K5V5MFEhJVIhJV1hJV9hJVAhLVYhIUihK5ehL6X00WQXH00=N6YKN6QJLEI@LE]>M5QB
JeI4JDi2JEE9JE14IU55LEe@JEA8RjJc009kOgl;N7Yj00=hN7QhNWYhOGd00WQjNQSooolFMgMi00DO
5A1^D3j6MfMgIfEgIf400WMWI@04MfmYMf=NMfMIMf]U0WMSGP9gIeT02fiCDViGCW=DDFYD@fI<@6IC
B6]?AFM?AFmMDV]FBh^T]002Nh2237MgN@9gNgh2MgMi6OoooaIUMGh02b4N73ln>6]^IFEUIFEUJ6EU
JfEUJ6EYJFEUIFESG6EVI002IF=S00eUIEiUJ61NFE]NEeAQDeANETYGCTAGDTaMD4UJCTMJFUAMFE5[
OhP00VQkQ@]UMGh00fEhPFEkQFEhP@02IGEn8?ooo`007_ooo`9kNGT00g]eMG]nOW]iN@0@NgUi00Q[
HFDJ3PWQ_:=kJEUkKFYkIEekKFEkIEd2NfeU015kJ5ekJF5kJEekG5egJ5AhI5ElH5QgG55cFE5_DD=c
DDIYEDU[CCi[DDM_EdY_E4NBZkP04W]iNAWoool2N7Yj00=hM7AhOGehNWX047QjNP0KGEIL30L4fJnK
NfaMN71/N6QPN71XN6QPN6aTN6iVN6iTN6YTN6QJN5MHLEe=KUQ;M5U@M5e@KUaBIU93L598JEM;IThm
IU56JeE8J514SZ^h019hNWXHoooo0WMgN@03MfmaMgMiMgMi011gMgT01eI9DPP10KNGS7][H7M_KGMW
HGM_J@02MfMQ019gJfEgKfUgIfEgHeIgD59^D4EVBD5^D4QcFdiZFe5QD4=_D4Q[ET]SC3aSCdEWCdES
BD26X:lBMgMi6Oooo`9UMGh00fE^MfEbNfEeOP0@IGEn01]<CUdH3PiDDUUXJ6IUK6aUJ6QUK6aUJ6QU
Hf=UJFUUKg5UIFQUHeaUDUENBTYEAD9KD4YQFU9KG5ADDTaNDTeNE4eDCT9DCTIDBTABB49RLW/04VEe
OR3oool001koool2NgUi00=kM7EkMGEkOWh03g]iN@08Ogem9QLBLEaEPFeTNfUQNfeUNfUQNfeU0W]Y
H@07NfeUNg5YNfEMMfEEO5EEMea>KUE9009hG5002G=LC6UABGAAAFmDAfYA@VYAAFIAAFmEBHR@UP02
PHfB47]iNAWoool2N7Yj00=hN7QhMWIhOGd03gQjNP0LOh614`d9NVAB]YR3N6YRN6aVN6QPN6aTN6QP
N6YRN6aTN71XN6INLFADM5=BLEe=JeI:Le]?L5U=KUU8IU16Ke14JE55JE12K556IU55KeM;Qh^?0W^4
Qa1hNWXHoooo0gMgN@03Mg=eMgMiMgMi00igMgT02H1oPP`40X5WCmFfVgMWHGMWIGMSGWMWHGMSGP02
MfMQ015gJfEgHei^Ge9^D4m^Fd]ZE4U_EdaZE4UZE4=VCD=[C49VC49[C49_CdMWCdE_ET^1OX<04WMg
NAWoool2IGEn00=UN85ULGYULW/03fEeOP06Jgb65a8>KVYHX9^6IFEUIF=V0fESH`0CIFEUIF=SIFIW
IFEUGUmJFeMDGUYBGUI@Fe=>F55;Fe56FU18Eda6EdY4GDa7H4i9FTi7GEA=HEeO009RJ6l@IGEn8?oo
o`007_ooo`9kNGT00g]eMG]iNG]iN@0?NgUi00Dc8AUkKFEfH5EkJEUkJFD00W]YH@04NfUMNfUUNfUQ
NfeU0W]YH@03LTDoMeM@Ldi4009cDDH02W=ZE6mDAFmDAfm<@F]D@gAAAfmAAFIA@GA?AWEXG@:BZkP;
NgUi00=kMGEkOWikNGT00W]iNAWoool2N7Yj00=hM7AhNWYhOGd03gQjNP056a8=MFEJ[Hf0NfaMN6YV
009hJV805GQZFgQZI7QZHWQ`J7QZHWQXH6lk>7A6A6hn>Fi0>g11?G1NCVU@@VU@AFa:?fIC@FmAAVaA
AF=A@75=@V]LD002R9jV2gQjNP03N7AdN7emN7Yj009hNWXHoooo0WMgN@03MfmaMgMiMg]n00mgMgT0
1@`40W9JCm2^XW][H7MWI@02MfMQ011gIeUgIf5gIf5gKfUgIf5gHei^<C=c=3QZ;RmZ;S5_<C=_D4IV
BD1VBD9[ACaSCch2Jdm500=SCci_B3iSC4800W^9T0]gMgT00gM_LGMgNGMgN@02MgMi6Oooo`9UMGh0
0fE^MfEeOVEhP@0?IGEn00@?2`URGEZRWYYXJ6H3IFEU00aUIEiUIF=UIFEUK6aUIFEUHf=Q>3mQ;SQK
:S5K:35N:S9N@T82EdQ400MJAT1DC41HCTIJCTMGCT9JASm??CH00U]RIP]UMGh00fE^MfEbNfEeOP02
IGEn8?ooo`007_ooo`9kNGT00g]dMG]iNG]iN@0>NgUi01e[HF4[8ab1KF5kJF5kJEUkJFEkJF5kIEUk
JEakJF1kKFUkKFEkG5UkJ61b>CMc@3Q_=2iiBDI_?3AiDDQUD45_ETI_DD5[C45dE4M_DDEZDD9_BCiZ
F4/00WidJ`03S:JdNgUiNgUi00QkNGT00g]dMG]iNG]iN@02NgUi6Oooo`9hNWX00gQhN7QmOGQjNP0>
N7Yj01eMEUI8?SNcU8IhJ61hJUUhJVIhJV9hI5IhIUQhIU]hK6IhK6AhEUAhGEU_=CA^?SEV;bQdAD9Y
>c=dBD=PAC]XD4=XDD1VCD5aDdQ/DDEYDDA_BD1YFdd00WMWG003PY6HN7YjN7Yj00QhNWX00gQhN7Qm
OGQjNP02N7Yj6?ooo`=gMgT00gMkOWMgNGMgN@0=MgMi00MFBDa^Ee;@[Z9gHeigIeUgIfEgIf400WMO
DP0@MemFMfMQMfMQMde?Me1BKS4cJSXbHBTRKcllISP`KcllGSTeHdPnHdlnHd]1Kdm70V]?A@04KdQ1
JeY>KeI;KeI;37MgN@04Mg]nMgMiMgMiMgMi6Oooo`9UMGh2IGR13fEeOP05C4iGRXN;W9FBIF=SIFEQ
009UIFD05VEOF6ELEVELEVESH6ESHfE@EVE:Df50A5/k=U@[9U/i>ELh=5/d=e@c=e91?U9>@UA:@eY<
AeY>Aee>BEe:AEeDC@9D@3L00e]HFFEeOVEeOP08IGEn0VEhP@=UMGhPoooo000Noooo4g]iN@0M91PE
f[6IPFeTNfUQNfUMNfUUNfUMMeeBO61DPG9TNfUUNf5EMdE7N4i4M59=J2hSOEU?ND10IB@NMCP`KdTo
IU14Je]8JdTfKeA9M557Ke55Kde2KeA7009_F4/00hbLXG^3R7]iN@0=NgUi6Ooooa=hNWX07A4=2kB>
MWi/GGQZGGQZFgQZIWQZFg5LCgAKD7]aHgQ/J7QND74k?Fhn=FI:@UL/875UEWMIDf0V7f/b:VU2>6I;
@6QIB6Q9=F]EAFmAAVaAAFa@A6aEB002K5M;00>;VIahOh9hNWX03GQjNQSooolCMgMi00<810B1Ie9k
IeH00WMWF@0DMfMUMfMIKUQ;KU=;Mf]PMf]YMeQ;KS4cIRhWGClhBbTMIV]KM6eSGRPQHbXSISP`Id<l
Ie=7IdPdIe=10f]?A@04Je=7Je=8Je=8QXfA3gMgNAWooolCIGEn01dC4A4b<bmUHeMUIE]UIEiUIFEU
IEiNFeAKDTiRHUiUJ6QUFE9N>3UE:RQ??SU1<2I?I5QNLVMD<B]?9R5G<2eJ>cYGBTMGBSUDCSiHCTIJ
CTMJD4UJCTL00UY@BP03IFQYIFmeIGEn00eUMGhPoooo000Noooo17]iN@03NgEeNginNgUi00]kNGT0
7UY<CC4Y8IN3Lg]YHGMQDH5fKG]UGG]QDFiIBGA?AXahLG=9@DLJ3[N3N7<i=75LE5m7@F<]8fMFAV8c
:G0l>edZ88Pj<VMQCFm?=Vm@AVmHBg=EAVU:@VmEB@9_DDD00giaIHbLXG^3R00=NgUi6Oooo`AhNWX0
0gQdM7QmOGQjNP0;N7Yj01i6>c`f:Qo3WhMkK6IaGU1kMFihJ69hGTiXDT9YASf5JfU[>3D/3PR@If1^
@CUdIUebLfic=bmOAcYB=2ISC4I:;R5f<b]REdE[CCA_CdM_FDedFdUYCTA/Ed/2K55500=eI5R2R8Qh
Oh803GQjNQSoool4MgMi00=gKg5gMgUgMgT02gMgN@0N>R/]Ab/OeJjDNf]YKUQ?Mfm]MfMUMeQ;ITTk
HC`eNe]OIRLZ6P<2ITU7JTLnMf]SQYJEPSljFcH^Ac<TEeM?>blSHbXSGdXlIdPbKd]6KeI>M5e;Jdm5
JeI;0V]?A@03Je=8Mfm]MgMi00egMgTIoooo16EeOP03IFigIG9kIGEn00]UMGh07SLc>Ui:@9>7NFQX
JUiIEf9VJVEXJVEIE5]<@U8m>5i8DEPX;aX3134]<5]@BVQRGgnUZGA7ADl^:chn;dAIDC0c9d@T854h
=5A6>5e8@eeBCF9MCeiBBEYDC@9JCTL00e90>E]BD6E_M@0=IGEn8?ooo`007_ooo`9kNGT00g]eMG]n
OW]dM@0=NgUi01hO4a:iSgF1KFEkJEebED^1NWEkJF5kFD]U@S5[AceB6AFPSXE35aI`D4Y`A49fD4Uk
LFQ];RMUBdYA=2U<>3@l6aA>8AFDBSQdID]dBD5cH59cFDY]DD=YCDD2Ke5500A_F4]nR9Z8Q7Z1Ph<<
NgUi6Oooo`9hNWX017QdM7QmOGQhN7QmO@ahNWX07Q0<2jj8KHilM7QZGFmDB7igLWQXH7QJBehm;F<o
=SX@3g]kM5mQG9jITGQaM7]jNG^1Nfa3=g9nNf]SGUM@D3DM5c/N4gM1<71OB75;A7ASEGAKCFeFAVU@
A@9/D4@016aIC7F4WW]lNG]oO`ahNWXHoooo0WMgN@04MfmaMgMiMgMiMg]n37MgN@0N30H6UGYSU8=n
MfMMKU15Nfm/Mf=NMeQ;GCHYGSH`9`T9EV=PP:>N_=;>P9JQP9ZTNhV9KUM8P:NUQX^?Hf=Y=AlJ:AXA
EcDXJeE3Kd]6M65EM5Y?KeM8Jdm50V]<@P03JeI;Jg^LKVmf00egMgTIoooo0VEeOP04IFigIG9kIGR1
IGR136EeOP0N6aTHDUMAMGMgIFEQHEM@IF1PIF=SIEiHEcheDCLb7`P8;DA9S<c;VLW;LJZiKZ:cJ828
IGeaN:j_Q:6/HG1g>2dY6AXB;bHOE4HoFTa7HUQBHUQDHUY?GU170UY<AP04FU9<DV1iEF5dHVmh36Ee
OR3oool001koool2NgUi00=kM7EkNGUkNGT037]iN@0OKfUb3@L4gkFEPFeTNfUMMU]BNfUUNfUQLdXl
GShZIR`S<0l9Z89ePX=dO6]WPI:DNfUQNg9/KU5:PXR6LeE9IFUY<1hK:RHT?1PAVDhhNEm@OVAAMf5H
KU53JDi3009_BCh01FmHBV]iP7E/KXR8UXb=P`0;NgUi6Oooo`9hNWX00gQhN7QmOGQjNP0<N7Yj01mT
HFh40`;Q/I5nKV=hJU]eHeQkLFahJV9[A3M?>2EG9QhV30R]NV^3KemdF59kPh9hHeAhJU]XAcmjO7e[
BCa_JVA==Ra;Ad0i71En@S1`EDUjIE1gIU]^ETQVD4H00Va:?`05K5E8IWAeIemIM7F5PXAo00]hNWXH
oooo0gMgN@03Mg]nMgMiMgMi00]gMgT07eeGJ@H10LBPQg][H7MWFGMWGG]cL7MWHFHm<dLa84/O6BD:
1j9[GH5GB6i2?7M_KGMKB7MOBfHl=W=[L6Hl<7]WGVm<?FiRFCLO6Elc:6M8@GAQCWMWFfmGC6I@B002
JdPn00A[CdESJVIKD4EQGg4<MgMi6Oooo`9UMGh2IGR13FEeOP03DUYa718BFeUF009UIEh06VQ^J6Q^
KFEUIEQ5@4@i:chR6bl@2V8j=VDn>5/k>69HFFEMD6EJBe]4@U]DGEQ2>gEUGWm]GGMcJbdT7S4Q7dlk
>E]FBVESFf5KEUYDC`9JBT<01EY:A5AFCDI8@DI<Ge]XN00;IGEn8?ooo`007_ooo`9kNGT00g]dMG]i
NG]iN@0<NgUi01m_JG8=1`CO]IF1KFAkJEefFe9kJFEkJF5cBSaN?RYV;2<`3`VXPWF2PgAlJfN1TYAk
JF5kLVa^DDZ2R8IcEDUUJFT`7Q/Z9R@l616ICSQiGe1nI55gHEQ^DD=YCT<00Vm9?P05KeQ:JgV0MFa^
R8RFS8f300]kNGTIoooo0WQjNP03N7QhN7emN7Yj00ahNWX07fAQKP@30^6aTGi^HgQZFgESF7]aK7QZ
HV]4=dlh9ELV7RH<2:ejJh=_GgAHDW^3PWQSE7QZFfQ7?gYlOF]9?6mZI4df;4]7@3TL5Gi2<71EBGYU
D7MVFfiFB6I@AP02K4Xo00E/EDQVM7EWGeUdMHF2Q7l02gQjNQSoool3MgMi00=gNgigMgUgMgT02gMg
N@0OGEMY1P41a:27Nf]PMfMIMfMMNg=`MfMQISdcAc4PBalI9@X7XV]MPEM8KT8lMfm]Me]8Mem;IS`f
Lf]`IS``NfMNKd`mKV9I=alIGc<XIdQ1M65>MfMKKeM<IU18009[B3h016]?AF=ZIU]@AF5OL@agMgTI
oooo0VEeOP9UN84=IGEn00=BFW4L4Q9KFEH00VEUGP0JJ6iXJ6i]IFEUF4E0A3T[?R8K;a0:HSXfIChh
Fc/hHUQIIEe@IEY;FdA2FeAMF48kMFENOfeMMg=[;B@N<B4OCc/iFeI:IF=KHE]FFUA?0UY:@`05FTY4
E5I=ATQ1ATaOFfQh00]UMGhPoooo000Noooo3g]iN@96>3007c/T8F=8@IN8Lg]YGG]QEG]YFg]aJ7]Y
HFTm=5i=?E/f<S8A5W0m@79IBg=ECGe^IH9GD7AVEGA1>7U<@G1;?X>5LFHo=5Q:BB/U7d4>1ZE_GWi[
DGaYGfiA@fU=A@02Jde200EdEDUZI5U`NXALEFFBUhd02g]iNAWoool?N7Yj0RdV7`0O7A8@FCdaaZJ:
NfaON5iBN69FN6iSN6YMICdcIEM8M5mHIUmFWW5_M65EKU9;Lf1HMd4mITm5Ic4/KcP`Hc@[M79QFcD[
FT=4>2`V?0h6SV1DO6Q@NVYPJe92ITe2009VCT801FmIC6USEWn5SV=NL8jDR@0;N7Yj6?ooo`mgMgT2
7aD@00@60@5C<BCJ]Y]kJf02MeQ?01UgIeegIeUV?C=_GE:;PWZJXi2lVYQgI5eZCDUZD4U^:b]M=SEM
8R5V8amJ7AUVFTmF;2=O>ci<<R`g3@I_CTMiHDigIeiZD41VBD000V=<@P05JeY>JeeBRhVDJf=iQXV2
00]gMgTIoooo3fEeOP8Q7Q`07`4004Tf;iJ:OFQXHfEIE6EDD6EPFFEUFei>AVYRGH6ES:K9/IVJUfQO
HE]=CUE0?UPY;dl[<dhU9e4H5d`H6T`k>Tle;eXi?E]2?bX>23/^<EiABV5NF5iFBUY<A002E4i700EH
EdmMDdahOXISJG]RKgP02fEeOR3oool001koool5NgUi00=kMGEkOWikNGT01W]iN@0RKfEY3@P53@P5
9aDAeJ:@NfUINfEINeUEMfUEPFePNeaIJDXjIdLfTXb4NfeQNeMEMUMBL5IAL4m:MTI3Id4nK3djJ3@^
J3PgJDm3KS/gG3XbBBhQ;Q<?KBhQUh1VPVaNKUE3JDY20VI<@@06M5Q:Ke]>@C0X_ko?MgIfPH>32W]i
NAWoool5N7Yj00=hM7AhOGehNWX01WQjNP0RI5]Q0`<20`<2714>j;>ORgaXN6AHN5IFLFYINg1SN5MH
IDLjG48aRhAnNg9ZN65NMFQNMFiVN6QPNf=HJeU=M5I;KUA3KUE;K5M8LCHeH3H`BbLL=Q<>JbXOQFiI
OFMKJeA2IT]20V=;@006LEE8K5U<:B0KWY^TOGiiNgmo2WQjNQSoool5MgMi00=gKg5gMgUgMgT01WMg
N@0RGE1I000000004``;f[JVU8MeMemFMe1FKVMLMfmSMe1FIT<kES//P7MdNg=`MfMUMg=YNgmhP7]d
P7]ZLfaJOFUJM6mFM6eKKeU:M34cIc4]Db4FA1<>Hb@KKeQ:MeiGJU10ITU20V=8?P05Kdm5Je=86A4?
Mg=ePH1j00]gMgTIoooo1FEeOP03IFigIG9kIGEn00IUMGh08U9DH`X920X920l=379iMgQlM6EOFVED
GEiQHF9XHfEBFUi=C4`k<5iJG6Q_M6EaL6QiM6j6Pg64PFj:Nf]hIfihJFQnIVQgI65BB6@g?60`;e@R
6ThJ544J5DHf=UiBD5iCBUY>A`9GB4801UY:A5Y=B1H>33i2@F]gNF9_N0YUMGhPoooo000Noooo1G]i
N@03NgAeNgUiNgUi00IkNGT04EmCG`D900D9000;57abIh5]H7]QEG]PGGIIEG]fH7]KFFU6?Ell<HQm
L85fLG]]IG]UG@02NfeU00mkFE9bG4]gG55^EDIcDDIUBSae?ci[@3IL;ba89RA;9BMdESZ3IemcFDIY
BT800VI=?P05M557KeQ;6APH]:JPS8fB00]kNGTIoooo1GQjNP03N7QhN7emN7Yj00IhNWX08U]FID4k
:D4k:GQICkJGPG]/GGQREWQWGgELF7]cHGQSG6E>@F52=hUoLG]`JWQ^IWQXH7Q/I7Q^IWQFDVmGBWAM
DV]FB71BB61<?6]7@6=@?F16?5e7?FE4@WeT@gaUFFiHAFI;@P9SD3l01W5CB6aIC1DK7;6SWX:7RG]o
O`YhNWXHoooo1WMgN@03Mg]nMgMiMgMi00EgMgT045eGJHI[DXI[D^6MQ=R`U7MWFGMOEWM[H7MKFG][
H7MWGFIDA6I5?8IiKWMWHGM[I@9gIf4047M[IGM@DVi@B7=KDFYDBFm@B5i<?6=;@EiK@fMIBWARE7aM
Fh1ZBGAMDVYD@fI9@P9SCch01VmCAf]FBadO89ZFU7MkOW^0PPYgMgTIoooo1FEeOP9UN847IGEn029J
J7bcYYFcYYG__InQT7aRHeaUHUeUKV=XG5mXH65UKV=NGeAPD4YUGUQRGE]UJFUUJ6QUHf=UJFUUE5eQ
DU9QFUANEU9NDTeDD4=?DTEAHTaPIeMdLf=eJFISFTEHDDQKDdYJCTL2Ee1300IJD4MJDT`c<c9?FEaK
Jg9XNhD:IGEn8?ooo`007_ooo`ikNGT08VYGEW]YHG]YHGIOEG9MCWaYG85YGG]YHG]KFG]]HG]UFFeA
A6Q3>WAFBHR3MH5fLG]XHG]UGG]aJG]GDW9AB7=AAG=PCV]=@F=<@G18>6]:?F]>?F]7?FM8?GAHBGUL
Cg=EAVE9?P9[D4401FmD@fmDBQ@B4/NkaHJ8OP0;NgUi6Oooo`ihNWX08VmHCH9ZFX9ZFWEYHW5VF7MX
Fg]ZGGQ/IWQSH7QgJWQXH6aFBFY;@6mBAGegJW]eKWQ/I7QXH7QbJWQOE6mGBVi=@FiKBF==?EI:?fM6
=VA5>FA9>FA4>F98>GANC7YQEW1DAV17?@9VCD001F]C@VQCB0/?3lFgbX^ASP0;N7Yj6?ooo`igMgT0
8WMGA8IWDhIWDgM_KG=[Gg=SFGMWGGM[JGMWIGMkL7MWIFiHCfm@AV];@G=WG7M_JGM[IGMWHGM_JGMS
EViKBfY6?FYD@ei9>Tm5?5m1=5ln=5m1=5ln=5m4=7=PCWUQFfm@AUi2?09SB3h01FM?@F=?A@/<3JbX
a8^BV@0;MgMi6Oooo`iUMGh08VmUEFmUFfmUFfQeNFE]J5iOFV9UHFEXJVE^KFEeM6EXKFESGfAKDeQ4
?UQACF9VI6E/K6EXJ6EYJFE^Hf5QEU]8@U]?A55<?dI6@4a2>4lk=Dln=Dlm=E54=EeICf5KF5i@C5A6
@P9DAD801EA<@U9<A1/F5EESOV]oT@0;IGEn8?ooo`007_ooo`ekNGT01gMaLX5PBWMQFGMQFGQSE6m]
LHaYDP02NfeU01YkJ65kKFEkJ65fDD]]EDAX@cYlL661NWEkLFUkFEEgMVB1KF1^CDAcCT=[AcQ[FdYN
@CIWBcQWACa[C3IR@SQWA3AmHeMcF4]_DDEVBCh2Jda100E[E4E_EDT51PS>]K:GWJ002g]iNAWoool=
N7Yj02=aKVikG4MaGUAaGUA^EdIPHVR5J5IkKVQhL6YhKVIhL6QhK6AeDTm_EdUZBCimKf1nMG1hL6Qh
E59aK5]kJU]XC49^Cd=S@SESDdMM?cEWBCITB3i[D3QRASUTACAoHUIdEd]YCT9PB3d00VQ=@@05J5E6
KeM<0@H8a:ZSSYB@00]hNWXHoooo3GMgN@09KVMYMeM4KUQ?KUQ?ITThEUANNf=INf]YMfm]009gKfT0
67M[IGM@DW=GCVm<@WeYGG][JGM[IGM=CfiODWMSEVI9@FY=@ehk<Ui9@Ulk=6M4=6=7?V]@>6=7>6=3
<WeMDgACB6I9@5i5?09WBd401FMCAfmFCP<62:6CSX25OP0;MgMi6Oooo`eUMGh02UiXLF9PG5iIDUiI
DUE5>DU>FEiOHFQUJ6E/KfE_KP9UK6`04fQIHFQLFfAECFEGDVEMGVEVIfEBF5iDDF9PFE]CCU]BBe4k
=U53@ULo>EM2>5A8@5Y>?5M:>eA2=@02HU1:00UGBTADB49GBT=GBT=GCTUME4lB3Q11B4QKJ6T02fEe
OR3oool001koool=NgUi00UfH5IkJF5^DD=^DD=_EDIbLVj1G5UkMVUkLFT00g]]I@0GNeMBMUE;JDXm
N5A:QX=mNg5YNeMEMVEINfUMKDe4KU53I40gJU55GS`aIdLhId/oKdlnJTTkJDi0LeU=Kde2Ke55JTe2
009VBCh01V]D@fmDBP861eLo=n3LgG]nOPYkNGTIoooo3GQjNP09MEe=NfEJJ4i2J4i2IU13M7=/R5]F
N7=ZN79Z00=hKVH05GQOE7ENCfQ@@7=CB85nN7QbJWQOFWE^HW]/I6a@BFiFB6=7?FaGBEdl<VA6>FA;
?fe@@Fa;@GAGBgUSEVU>@P02JE140VI;@006J5E2Je=800H7CCH__kVkN7em2WQjNQSoool=MgMi00Ug
EdAkGe=VBD5VBD5QBD1gKfJ;Ee9gJfUgKfT00gM[I@0DMf=FMf=BJUA3Kdm5Ng=`MfmYMf=NMg=YNf]Y
KU1?KeM<ITa2KeQ<Gc/bHd<hHdLnJdi3Kd]6OEeCOFQM0VI<@P08Jdm5Id]1Id]1Ie=1Idm51PL7>bXU
ShjD2gMgNAWoool=IGEn00QXH5EXH5]KDDiKDDiDBdQXHUQ_EeQUH6D4IFUY01MUKV=XJEeQGDmKC4AR
GEiUJFUUKVYXLG1XJ6eUG5mQFUIMEdmPEDeG@S]D@3]DA3mGBTMPC4Y]GEUWHU]GCTMGC4IMD4T00UY<
A@06Edi2E4a471<@6QHF>T9>IG9k2VEeOR3oool001koool=NgUi029kEd=gIEeR?2iR?2j2MV]kG5Uk
JEekJFEkLFUkLFekJ5ekKFEkIEUkH59YBSecDD>2MVj1LFekJEekKFYkIEebED]ZBSm_DDE[DDEV@cUV
ASAR@SY_DTIhEDegG4i^EDUYDDM_CT<3Jde200I[DD9_FDd=51<M61MA@SgPhn@:NgUi6Oooo`ehNWX0
8WQH@g5TFUDd9UDd9WeeJ89QHG]/GgQaJ7QbJWQeLWQ[HWQ^IWQVG7QVF6E>@W1FAWeiKG]^J7QXFWQ`
JWQXH6mHBfA9?FU>@VIAAF=6?6Q==V94>VeBAGUIDW]UEfiICFIFBVaDB0=VD4@01VQCAFmMDR`X7CTQ
6d4d;k2b/`YhNWXHoooo3GMgN@0:MeM4KUmFCR`OCR`OMfmSQV9VNf]PMg=YMfmYMgAe0WM[I@0FMf=N
MfMMIU17KeM8MgIYMfMQMf=FMfmYMfMQKUQ;HDHjITU0Hdm5HdPnJe0hHd<hJdi3NEYEOFUMKeY?IUM<
JeI;0f=?A@06Ie=7KeeEEc/WE2TO;b<PMg]n2WMgNAWoool=IGEn029UIF5NGeQ9=ba9=baNGeQ_GVIX
J6=UKVQUJFUULGMUK6iUJFUUIFQUJfQNFUENFTmNI5YRH5iUHeaUK6UUJ6QQHEQGC4AGBTADCTMGCTMM
DSiGA3UGB49REeEXI5mQFUAJFUAJFE43E51900IGD4]MFUEmG3mH;R8F3`lZ=3d:IGEn8?ooo`007_oo
o`akNGT00g]YHG=A@Vm4>P02IUI300IiNVjBI5ekJEekJFEkLFUkLVd2NfeU01MkIEegIEEbED]bG4ik
JEekJF5gG5F1NVakG5e^GDIYASi[D4=WC3m_Cc]N@3A`AcYdFdmiFDmlH5A^EDUYEDU_DDEZDDD00VIA
@@05Kda3KfAEG3`_>R`Y;DMC00]kNGTIoooo37QjNP03N65FJd4bH30[009MB3/07g=mM8QZGgQaGgQZ
IWQbJWQ`JWQ[HWQ^IWQVGW5TE6mHCGAXFGicIg]/HG5GD7]cIGQFEVQD?f=2>FI=@Em8>f]==UDm<FM4
>WAPDWYODgYSEF]FBVIDB6a>@VU@A002IU5000I_Bd5_HeEN@3AC@3YhUYn`/;0:N7Yj6?ooo`agMgT0
0gMGC6Ha8eHM7@02FSTb01m[NGIkJf1gLf1gIfEgKfUgJfEgIUigJfEgHei^Ge9^F4mgKf>0MfikJf1^
D4]gIeegCDmVBCQQ?3ESB3iK@CQWB39?>2iO?SQcH5=iHEEgHUAZE4UVD4I[BD1[C4800VM??P06KdPn
KeeBHd8jKe1:_=OQd=OL2WMgNAWoool<IGEn00=UFUMH>3=971l00U4g>005DF1SFf]SIFiSIFEUIFUY
009UIV@066EYJFEUIEiOFV5QFfQ_JV]aK6QXH5iBDV9JEfE@De]:@UQ3?EA5@4m0>UA6=DDi<T`m>EeG
Cf5ME65LE5iFD5Y@BUY:A5e<AP9JCT801Ue8@5eCCUe>BWURFL3Jginj`PYUMGhPoooo000Noooo37]i
N@03Nde4JCldHC8/009[GTd01GMfJh5]IG]]HG]UGG]aJ@02NfeU01QkJF5kJEebHEEkGE9bJEb1KFEk
KF5fEe9kJEekEDiYDD=U@cUWB3aSA3Q[BSQQACY_DDIcFDecG55lG55^EDUYDDI_CD9_C4D2JU1200I[
C3idI5YR?2a_DTVF]l=fM7D:NgUi6Oooo`ahNWX00gQ8@6Dh<5da;002J6=@00EmNff8L6QhL6QhJ69h
LVX00WQ^IP0HN6QPN6QJKf9DNeiBLFYMOViXN71XMF5LNg5VN5Q?IEA4H4<kGdPkFd8fHdHhGdHmMee?
NF=EM65ENUmCJeI:IU96K4i2K4]50VU=A006J4]0KfEMGCTZJe15VK_8MGQh2WQjNQSoool<MgMi00=g
@SiV<BeN;b`00VMRD@05PGY/RfmYMfm]MfMUMfmY009gJfD05gMSGWMSEViODW]LDW=WG7][JGM_KGMW
IG]cK7MHCfIDA5i2?5]4>ULn=5]1=Um4?WaSEWeXFgAREgMNE6YDBFI@AV]<@P03JdQ500EWB45[HEeK
=RUWBd6D]<<02gMgNAWoool<IGEn00=UDUQN?3iG>3L00UMCB`04JfMOKfQXIFabIFQZ0fEYJ@0HIF=S
IF=LHF9JJ5iHIF9MIFEXIFabJ75bJ6i`IF5IGUQ@E4Y5Cd@mC3lhBCdiE4I2IUmGIf9IHUiIHEaGGUI@
FU9<FTi7FTQ70Ue5B@06EdQ5F5IGDCldE4HnJgb6J7R12VEeOR3oool001koool;NgUi00AkKFEkE4iY
>CAM=R`2M5mD01>7NVakJFEkLFUkJ65kJF5kKFEgJEb1KFAkG5UbJEElG55gJE^1LFekKF1kJFEkJF5k
EDiYCCaQBCh00V95>P0:GTTnKddnM5Q>NEa?Mf1DLeU=LeE9JEE9KdTnKda30V]<@`06Je51M61NIC`^
IU55PhfHTYNF2W]iNAWoool;N7Yj00AhIeahDdIU@CIG?2d2LFIF00B;P71kK6QhLVYhK6@2N6YR01Ua
I5IkJUehEeI_HU9gFDiaIUUnL6ahK5ehJ69hJV9hE51UBC]MASaOASYRB3]NCd=`ED9dGE1gGE1gHEE`
F4]^DTIVE4Q/B3e/Bd400VI=@@06IU=0LF=OId0cJ5M;MX>=PXN72WQjNQSoool;MgMi00AgGU9gD3iV
ASQF@Bh2KfMF01n;OW5kJfUgKfUgJfEgIf5gHei^G4mgHeIgD59^F4mcDd]^GeEkJfUgIeUgHeigIf5g
D59V@cYN@SYOA3YSAcaOD4I_F4IcGE5dFTmgGUA_E4UZCD=VD4I[ACa[B3h00V=;?P06He<nKf5MJd8g
JeQ?Ig9nLW9e2WMgNAWoool;IGEn00AUH5eUGe5NEdUABSP2FUU=01m[JfEXJ6QUJFUUK6aUIFEUH61N
FU=RH5MUDUQQDeANE51NF5AUHf=UHeaUHf1UIFEUEemNAdIGAT1DASmGB41CD4QJEdUMEdiNEU1UFUAN
DdiKCDQJD4YJB49JB4000UA:@006E512FUQDH4i8GEE?BDmGEEmY2VEeOR3oool001koool;NgUi00Ac
CCY`CD5H>becASH2SGAT00f6MVQkJFEkKFEkKFEkJEekIEebIEUlH5QhG5AlHEQgIEEgHEF1KF@00g]Y
H@0?MeQBKT<jHDHlHTDjIdPlITm3JeA5N5Q?Lea=N5a@LeaALe56JE56Kde3JdXo009[BCh01V]@AGAT
FfLa8WA_HVI:A9:ka`YkNGTIoooo2gQjNP04JdD`G3/a?2/QF3/_0XQeI`0OR7a/N6YVN6aTN6YRN6QJ
N6AHKfAFMe]FKUM>M61FM6QIM6QKOW1UN6YRN6YTN6YRLEeBJ4TlGDPmGdHjI4TmJ514KEE6NEUCM5e?
Le]?KUeBL5I:IUA8K596IU14009VBd001VQ?AW5SGEl/7FmZG6I4>i6[/0YhNWXHoooo2gMgN@04IS`X
CRTQ:1/F@BlW0We`IP0OQW]^MfMUMfMQMf=NMf=FMemBKUmBLe=BIU18KU]BLfMLLf]ONfmSMfMQMfMU
MfMQKUmBITdnGTPnGd@jHdLlJdi3Ke=7NEIEM5Y?KeM<JU]AKeM<IU=8Je=8He=7009SBd401VM;AfmM
GE/V6F]QEFLk<X^BU0YgMgTIoooo2fEeOP04F4Xo@BXU8QdJ;B/X0UQIE`0CJ6]VIFEUIF=SIF1PIF=L
IEmEHEmHGU9DEE9<FeMDHFAQHFYSIFQPIFEUIFEXIFEUGVMMFeU=Eda5009DASl02Ue:@ee>BF9BE69F
DU]CCU]JE5iJE5YDCEYGCeAEC@9DC4D01UM8BEYCETl_8eQ>B5Xi;fENG`YUMGhPoooo000Noooo2g]i
N@04IC0M=1lDECD[ARXT0[fCN003QWI]NfUQNfUM009kJF406W]UFGIUFGIKEFeAAg=ECGASDH9aHga]
H85]JG]YHG]YGG9IDVY:?691?VM;=V=4>WABAVmHBgAAAgAKCWUHCfmGB7AKCV]AAFmDAf]AA@9[BCh0
1V]<AfmKCEhc8gAGB6m2?9:k`PYkNGTIoooo2gQjNP04GRXI8AH??b/T>2@Q0Z^8LP0OQ7M`N6YTN6YK
N6YMN6YRN6QPMFYRN6EPKeM?L59;JEU9NfQKMfYMNfaXN6YRN6YKKeI?I4HjFShmHTTeGT@iL595Ke]=
LU56K5U;M5E?JE54K5E9Hdi2J555IU14009XBCl01VQ=B6]IBELe8VaGAFPl>96ma`YhNWXHoooo2gMg
N@04GBHG5Ph:;B4M:ahN0X]gJ@0MP7=`MfMUMfMIMfMIMfMQMfMUMf]YNf]YLe]EKde9HDe0LeaBLf=I
MfMUMfMQMfMIKU1;HD0hESTlGd@dFd4fJdi3KeY>Kdm5IU=6Ke1<ITU0ITe3GTU0009SC482IdPn00IW
BdMWDdEC=R9SDT5S=S>;//4:MgMi6Oooo`]UMGh015Ln=A`D3R4M720K7@96Bd`2IFEX01eUIEiUIE]U
IFEUJ6eXJg1[LG9XHF5NCDiBA41KDDiNG5QRHf=UIFEUIEiQE5AGAdA>?D9A@SU>@3QDB49ME4eJCTID
CDIKCDiGAT9DBDAABTABBTADC4H00UM:@`06EdY7E4Y2C4@aC4@fDS/iIGF12VEeOR3oool001koool:
NgUi00EkLFeS<BDP6Q</7aTi92400[fCN00OQWI/MfEMPFeUNfUIKeU@OVMLL5A9OF5BNEM@NDe8N5i:
NEi@OW1QQWIaNfUQNfUMLU5;I4LjGSlfId@dGTPoL4/oJeI9L513NEQ:NEaBJdXoM5Q;JU56ITe2Je55
009[BCh01V]<Af]DAD/Z7FDb8H=C@9O0d@YkNGTIoooo2WQjNP05N6iWHS<X;B@M<B<L<b<P00;2U7T0
7hAgJW5TF7]/I7QZFfABBFaICEU3>619?Ei4?fA1?ViGAG9GBGAUF85cKWQZHWQZH6mBCF58>UY1=6A5
<E]9?fa<?f1BAF1;@6eEB79MDV==@6mIC6UDB6I@A6QAA@02J4To00IXCDQXEDE09A]B9aadB3ND_l/:
N7Yj6?ooo`YgMgT01GMWHFHf;DD^9cLU7S0Q7`02/8ae00J0LfM^Ge9gIf5gIeeMBD5MBCh2Ac4X00I7
<BeB=3EVC41[C49ZEdikJfT2MfMQ00e^D4mQASYK@C9S@biKAciWBSiGBd5CACaSCdE[FTmNC41[ET][
DdP00VM?A@9WB3h01VM;AfMCAC/Q6D8L5V<j;H^b_@YgMgTIoooo2VEeOP05IFQYHUADGd@j=RLP:R4P
009NFU@056EUGUiOEF9SHfEUHe9<ATU3?3T^:C8W8c@];3hb=U93@EA3?eE:B69PH6EUIFEUJ65JFeY>
AeA8>5A2<P9AASl02DM4?T53?da:A5AFCU5@AeQBC5eDCEY@BEM>A`02EdY300IGBTMGCTLj:2<`61I4
;bIRLWD:IGEn8?ooo`007_ooo`YkNGT01GMIBfi:AQL81BTI4c@P7002fZ:501mlKF1kIEUkKFAkJEeW
DDMIAS]F?S96=2m6;BMY=BF7EDAZ=BMb@S2XWX^1LFekJF5bED]T@cYN@S5SBCIN?SIeEdYUDDIPCD=Z
CD9[DTYSD45mG4i_EDUVCD9SC4400V]<@@06M557Je55?b<KDRHLND@cUl[F2W]iNAWoool:N7Yj00Ea
DT5X@cd:1@<I4`lZ7AT00]RRQ00ONViPN6AHNfiSN6YKJ5I;E4DkAcP]<RdZ;28OB2PKJTLgDRPNERlR
TX=cNfiXN6YRKeQ;HDHjFT<bGTdhEchfLeQ;K5U<K5E9LE95J4i8FDXmMe]=K5E9Hdi2Fd]0009PBd00
1VeCB6QCAC`T75@X7W]3<iO7e@YhNWXHoooo2WMgN@05KTTiIS`f1@<23@`<81TG00:kUWh02gM[GgMO
EW][H7MWFFiHCe=2>Sha:B@T9ALG62XK4T`f:@02?Q`E015gHeQgIf5gIf5^F4]QASYK@C9KCSQC?CA_
EDYcGE5hFTihDdMWB4EC@SY_ET][DdQSC4800eM8?P06Ie=7Ie=5@RDMERTOMd0bSkO:2WMgNAWoool:
IGEn00ENDdaKBD@>1`H92``F5QH00UQKEP0OHF9MIEmJJ6ENIFENJ6=MCTQ2>CH`7R@W31@G4ADA:2HQ
;ATF:A4@B3ThHV1NIFEUHF5HFU17E4HkCThlB3heEdi8IU]CK5]CIU=;EdA4BD4oEDm:FU9<Edi7C4Q2
0097B4801U9@AeM@AdTd:d/]8eLe;VE^N`YUMGhPoooo000Noooo2G]iN@06OgemL4DcID<k1``>610=
<AXE0]ZaTP0ONfUMMf5EPFePNfUMMV1JDC`aEdU45aXH8ADB?b0EFD0hLcHWJTHmPWIWPG5^NfeYLUA4
I40gES/^HdPb?A@<U71HL50hIT]1Gcd^PUY=Hdm3NEQ6KeA:Je55FTDj009SCd<01gA@Af=<?3lS7F8d
9Wi7?iK1bGIdM@09NgUi6Oooo`UhNWX01Wn1PG98=F50>0P?41/C3c4I5@;T/i<07g]^HGATF7]^HGQZ
GGEVH5I3>G5LER0Q7QhC4CLM4dTk=VHf:GYLCY><NWigLWQeLVmKBf52>Dhi;EY2<2h>2GiLBV=6<5=0
=TH`9F]?@e]?@GEGA6QAAVI@A5M4>@02H4m300McCdQKB3Xc7a]K=BN0CdJLcMMeN7P02GQjNQSoool9
MgMi00J0Oh9gBCUQ?3DF4a<O5A4`61@2cZR>01akKf=cHeUgJf1gIeegIfEQBD2;JF@b:2<O4Pl_6A4h
<c9G=BZ5Je^IVHMkMgAgN7U^Ge9Q@cY;=BaC>RdT2@MSASYG>bM5<b/b8aaC@CQGBci_Dd42Hda200UG
@CQOBd5OBd5_BdMG@CP_71UC<bQlDdbIbmX02WMgNAWoool9IGEn00I[O8I[H5]JASlf9b@P5Q<V5Q@2
IF9M01mXJfEQI5mRIF5UIF5XJfeVFeF4L6i5>34P5A<P5Q8P9bXk=S1_JEadOG=UKfiUMgaQJVEJD4U8
>cE5=RlS2`Pg:2Q4=BLg;bPU8Adg=S5<B41DC41BBT9DC4IAA3d00U58@P07EdQ7C40l<RDS?c8[FTa8
KhJCJ7R100UUMGhPoooo000Noooo00AkNWYkOWikMGEkOWh5NgUi00HZ40cMU7I]EDXI51@C4QHU50l2
jKVI01mlJEakJEegIEUlJEb1KFUWD4=cDDX`;b`M8B@R7ATl=RiVBSihED]lLF>1NWEkLVebFD]T@cYD
>BaE?S8g71QNBdI8<RLE2@Q^>RYJASQ3:1eoE4A]AS23ET=NCdH00V=<@@07M4a3CShb<A`GEblTXFQH
U[K3MWAe00UkNGTIoooo00AhMWIhOGehM7AhOGd5N7Yj00HD1`FRHD]XE4PJ6ALC4aPR50l2j[VH01mg
J5]hJUedIUUdIUUkK6QXFD]dEde0?3=HAciJ?BaSB3N3G4J5HUEmLV=nNGAhL6Y_ETIQ@SUE>baG@3@n
9AiQEU0d;BL:1PI?;298?S<[7QIM@CMB>BMaBCQICD800V1?@`07Lde2AC`_9AXEB2/RV6YIVL3:LWEf
00UhNWXHoooo00=gKg5gMgUgKg401WMgN@061P00HBhQIU179ahJ5a@J7a<@0/Z/T@0OLf=IMfMMLf=I
KUmFMfMUKUmBM5Y?FTHjTVQFS5PmQ5HmUVQ=RfYKOFiQNg=`Mf]UKU12HD0hFc//FcldC2dUH5YG92HW
0P<4;ahJ=c<]5a<@>b`Y>bXOGc//EdPn009OCT<01fm;@D8h;20G4cXV7hEUEYBmb79bM@09MgMi6Ooo
o`04IF]eIG9kIFigIG9k1FEeOP062P<360/?G5=>@C0Y7ATP61<A0UQOFP0OGUmJIFEQHF9MFeaHHV=S
J6eVHUeDLEe@XGiYT6M:O5DlNFA>KV9GIEiHIFIWIFITHEQBFTa6FT@gDT0hE3hbB4];7BL^0@<54A@G
8bLW3Q4@61`Q9b@N@C4XCTHo009AC4D01UM:@Slk<b@O6RHQ7Tm>B6^3R@YUMGhPoooo000Noooo00=k
MGEkOWikM7D01G]iN@07;APD9aHB@``5NdTg8Q@I71@@:aPD00;O]ID07gMUFH5]IFY9?gUZEhaoNGIX
GG1CBV55?Em7>UY6>UY0=6iIAWMIDGMUF85jMG]]IG9AAfA>@5hi:eU6=UPc;59=BS4]:`8624PR5d@b
;BTM66Y1<6=3=7ED@Ei5?002GTm300IdDD4/7Q`a81M48aZTE3nMcm/:NgUi6Oooo`04N7IfN7moN7Qh
N7em17QjNP075P`:4P/9=0T4C34V40dB518?:aPC00;]^IP07gAVFGi^J650>VaIBhEgLWE^I7EQFV]D
CFI=@6A@@fa@A7aUD7eQF7MZG7ikMWQ^IVm@B65@A5Xn;UU=>F8n<6QLDTlk<@H82THR5c/]:B@L66U1
<6Q5=WiNBEm9?`02GTm300McDd4O6QTU6a@n8ARMC3VD_l]eN7P02GQjNQSoool017McMGMkOWMgNGMk
OPAgMgT01`P10@H10B870alH5@D630l?3BXG4P02f;2D01mcHeUkJfUM=SEQASikJfUgKfUkJfUgGU]_
CdE_ET]lFe67JeV1IEegJUikMgAgJfE^CDQQD4MK@C9KD3Y[ASAlIEI_ASH>2``o81Hb9bDR6AMP?BiZ
A3J0HTmSBT400Um;@@07Ke=16aHF7AHA=ahGR40aQZBdLW9e00UgMgTIoooo00AULGYUMGiUN85UN844
IGEn00L>1`P<2@T;10801P/82A0?3`hR5a@00VQTG`0>HF9MIFEXE3e1CS/kGUYKJ6maKWIiLF]/IUA?
JEeGLV9KLFAHJf=MIF=M0VEYJ@0?HEMHFUQDE4`oE58mHTllLf1@N5=26a8C9AXD9B0Q8A`L?C4YE40h
HUU=FDY2009CB4801eM@@b@M7A`H5BTL5dTZ9E]NJF9bN`09IGEn8?ooo`007_ooo`03NgAeNgUiNgUi
00EkNGT01`D002lP62HB438P6a8:2b`J5BdH5002fZj?01mkJEagJF1`CTiOASY[Bcn2JEUcFdeWASiO
=b][AC5dASEfB3FGOF^2KV21LFekKF1bDD]TEDUN?31RAc9SC3QdE4UQASl96b4T8Al^9B4^:REMACYQ
ASASD4I_CCh00V5=A@06Hd`n6Q<@:APDA2<ISSLWXmWT2W]iNAWoool00gQjNWQmOGQjNP05N7Yj00L0
000`8QPY5A8^8A`=2@X/6A@`61@00^B^SP0ONfQKM6QMLUaHI5I7FT0eHdi0Dd8fA34/?BLOBS<UE3DX
FCLYOfaNNfmQOW9^N6YKKe16HEI8FSdbHTDcH4diL5U9Hda2>3/gJdXkDSL/CSHZPeM5MU<kHe=8Je10
009VDdP01V1=@18A3b<F4d0R68/d9IkDg`YhNWXHoooo0WMkOPIgMgT01`P10C4R6BdG52TP70X82BXH
4c8H5002cZ:701mkHeUcHeUgIf5[HE9;<b]7<BPj:B4X7A/Q5a@/8ATh8a`n9AeVEdmcJemkKfagHeI^
CD9QE4MK?3=S@C9OBcQ[F4QWCdE_F4bWKEEbASI[@2nMHTj5G45SDdQWCd400V]EBP06Gd]1514?81@A
>alHOC0SSl3?2WMgNAWoool00fEkQFEhPFEeOP05IGEn00LT5aD[8ATY6aLM6aX;2@XQ5Q@Y5aD00VEK
EP0OJ5mJHEmHJgMbHfUO>blY;b4N:24N6Q/K51DF5aLF8A`I9a`J@3hnFf9LIFEUIF1IHEM>FUI>E4I0
EclgDDXkE593GEE;UGQTY7]RLTdkKDDdP5]=LEY3E4i5E515009OED/01U5:AB<M5adE4b`M64PW7ei[
M@YUMGhPoooo000Noooo27]iN@071P008A0<81DA9ADA718?7a@@>RDQ00;5T7@03HabI7IYGG]YIFYG
CE4k<U8f<DHo>F53>SX]9TLi<4dc:VE6?7M]H002NfUQ011kG5EbHDiTDDIN>CI>;1aP>bR2JDYdE4U[
DD=UBT9>?35<>C=_CCiSBC][C4ESD3h2M5A300I>?C@@3@/P5122CCeB8AR^fN@:NgUi6Oooo`QhNWX0
1`8001d@2aXC420D41`B3ahE4CLW8`02b9Ag01n5KV5eK5mkK6Q_HEQUEd]SAT55@Cm]BdAG?S9SC3iN
@3AjF4^<Q7>2LfakK6IhEeA_GTmQE4QJ>3Q09QY:;R5bG49]DdEXDD5YCTAMBc]KBd5hFTINCD1XCDUP
Cd000VeC@P06ACX`2@/:6Q<@UEU5HBTNZ]cV2WQjNQSoool8MgMi00L<0`4K3PXE4@lK4`lM4PlM5A0c
9b@00[:=M00ONfMLMf]PNf]YMfMQOFmSM5=?B453N51<Ld/lNeY9KTTlRFEFVI60QWMdNf]YMe1BKUQ?
HEA9FcHj>1lH>24JGd/hIdm1IdlnKdm5KeE3JeU=O69=Fdi3Id]<Gd]1009WCd401T8e;0L92ADA3iMP
Bf/`8i[>g0YgMgTIoooo26EeOP07:Q/E60h;4A0?5A4?71<@5a@A9RDS009HF5807eiLF6QXHfQXJ6ma
LWj5O6iNFdU4BVQDE7EGBG=MD6=>@gATFG]mLfmaLVQXJVEBFV5IF5YHDUA0AC<R7RPJ63hg;e9<?UM>
@6=CBFePCfIQE6=MCTi>BEM:CE58A@02DTa200Ho>C4A40hA4@mSDDEI=BQNMGh:IGEn8?ooo`007_oo
o`9kNGT00g]eMG]nOW]iN@03NgUi00L:0@0K30TM510L510A1`LU5Q4j:RD00ZIfG@0OV7YYPG5TNfUU
NfeUMVAIIDQ5BCm1IDQ5FSlhFT@lE3/eJTXoLV5EPG5^Mf5EO5aIMeeBJ5E:HdE4?RPT<Q/JBC0PC2lP
U5Y4Pf9BJe4nHDe1Hda1IdPlGTLmME9:009[D3h01b`O61H@3RLP78i8<e8T6De9A]_Ng`09NgUi6Ooo
o`9hNWX00gQdM7QmOGQjNP03N7Yj00L70`4K3@XN5A4K510>1`LR5A4k:RH00Z=bFP0OS7=SNg1SN6YV
N71XMFaRKf1LJFUTR79XLVUPN71XMFURQG5QN6iQOWE`LF9DM5mFLF9BJ5M=JeA=DT8f>B@S>BTM<20H
KdDgMUY=IU4oHe11H4e1HTHkET@iKU18009]Cd001alJ5@l=32XR7I57<dPQ5cHh=Zf][P09N7Yj6?oo
o`9gMgT00gM_LGMgNGMgN@03MgMi00LB1P@O3PXO510K4a0=1PLO4a0i:BD00XmXE003OFMKMf]PMfMU
009gKfT02G]cL8^<Pj>DQh^<PiBDSiB@RiZ>OgefJG]cL002KUmB00m^He9ZEdidGUA[F4M4:b/[8AXG
4Q58;bUWCdMSCciWCd5OBd5O@CY??SAWBdD00Vm;@@066a@B3P/:;2<OQ4<a@Q`D8RHU2WMgNAWoool2
IGEn00=UKWMULW]UMGh00fEeOP07<RDN8A0<71<@5a<@2`H7614@:R<Q0099A3l01UECD69SGVEUIFE/
K6QbM7F6QP:?WYD05hFNVhbQX8nTXXJERf]bJVE/K5iRFU]UF5iSF69LEf][GgA_GTPe=AhI6@T<3QlN
8DU3@5A>@ee@@e5:@e52?D8m=E56A002GDQ500LT6aPE3`hV8Qm6<BTj8ATB414]=3d02FEeOR3oool0
01koool2NgUi00=kM7EkNGUkNGT00g]iN@073@@28aHC7Q8?7a@@50h:91@@>RXU00:IIU001Y9jJX5a
I7]YIG]aJG]]IG]aK@9kK6D05g]XGG]aKG]XGG]XGGIPDW]]I7IUFG9MDWMLDG9QEG9LDVM=AcL/;B/S
8A`N6d4U74`_8G92<ee8>6Y1<6<o<7UID6]<@@02IdPl00LD3`dN4`lX6aXo50eI7Q8d<c3EfM/02G]i
NAWoool2N7Yj00=hN7QhOGehNWX00gQjNP071P@381PE7A<@7a@@50l;9AHA>RXV00:LITl01Y9iJGib
IGQZIWQbJWQ^IWQeLP9hLVh05gQ[HWQeLWQ[HWQ/HWEVF7]^HgEVF75NDWAICW5REWAREViFD517A5]5
?CXb:clV738S6Td_9Shg;Thc9dhd9g=ECW=@A002HTPj00L<3@`I4PlV6QXd4@]25`l/<BoOg]l02GQj
NQSoool3MgMi00=gNgigMgUgMgT00WMgN@0730H681TG7Q@@7a<@5Pl;9AHA=bTU00:?H4`01H]bI7]_
HgMWIGM_JGM[I@03MgAe01MgJfEgM7EgJfEgJfEgIeekJf1gHeIcG59cDd]cGeEgHeQgFeQ_GEZ9HUIJ
@SXk9AdK5a8Z71TU9B@e9Alk9am[CTYhD4H00Um4>0073@/;5a0>9API9`d:;14<:Bd/bm?H00UgMgTI
oooo0VEeOP9UN844IGEn00LV8b8P7A/K5A8L4a0F40`L514X8b400U54?@03HE]FIFEQIFEU009UJFT0
26EaMfEdO6EdO6E/KVEaMfE/KVE/KfQ[J09XIEh046ENF65DD6ENF6QTGFiTHgigLI9eJfI>ARdS7@/?
3`lA5ADL820P7RPS7U54A6=>A`9AA3`01a`D4aLA41dF61@:2AP>32PW:6QhP@09IGEn8?ooo`007_oo
o`QkNGT01`X512lS81@?3B8D41dC3bDH63PY8`02QEU301nGMVF<NVakJF5kKFUkLFUkLVekMWIkLFek
K6EkLFekJ5ekKFEkJ5ekIEEkJEebFDigG59gG55gIEQgF5EXFDiTBT=4=S8/:BLY9B8o:R=3=RaN@SI<
?cI`A4=WDT400Ui2=P074Pd=7Q<?7A@A6`l;>AXEA3D`eMWK00UkNGTIoooo27QjNP071`D5=BHS5A4>
8A@@7Q<@9aTI>BXT00:2Ed407hY`H8EgJGQZH7Q/IWQ`J7Q`JWQeLWQbKWQ`JWQeLWQYGWQ^IWQ/HWQX
FWQZGFmJCgAPE7AMDWATEgAIEVQLCVIBAe=6>dm3>Dm1=EHi;4hk;W99>f1@A7U;BUi@@002DD4e00L<
30`M4`lK514G3`Xa6QDl=C7Lg=d02GQjNQSoool8MgMi00<B2@Pk:BDH4Pl00QlC4008:1TJ=bTULU0n
LU0nN6AHNfmSMfMMMfMQ0WM[I@=gKfd017MdMGMVGWM[IGM[I@9gIed046iHCg=OEG=KDG=OEG=GEFYK
CV]GBFMCAG=IBWAHAfY4=5Tn;gm>?g=LCga>CeM;?P98?S@01`h<31dC3aXC41@>2RLI5CDc<LK>d`09
MgMi6Oooo`QUMGh01c8X9SP[:ATE4QXC41`D4B4H6bTT8`02?c/d00Q<C4QNH5aUIEiUHf1UIVMUIVAU
JVaUKW82IG5g0VEYJ@0CIFa_IFQVIFEQHEiHHF5KHEYDHE]FHEYHHUaDHEmDKV9DOF]KNVECGdTiDS``
J4]0JeiDGdY<BDI2008n@3T01QhF51/C41DC410?2aLG5BLZ:`YUMGhPoooo000Noooo27]iN@073`H4
<B4J7aPF7Q8?9A0;:AXF=R@K009M@3<02:1bGHenKX5]H7]YIG]aJG]aKG]]IG]fMP9kLFd05G]XGG]]
IG]YGG]YHG]UEG9ICWMUF7MLDWMLDGMLE6iICFeEBFAAAUa:?eY:@4Ti<Dhl=653>F5<AFI6?Ui8?002
?bhS00PJ4Q4N4`lW61@G4PhU510n:1fdXZNMYZD8NgUi6Oooo`QhNWX01`T50bdP5ahH5AlC3bD@2bXI
5SHT6@02ES``00RCJEN7NFYkK5mhJVIhLVYhMG9hKVIhMG82N79^01EhJEihKVIhJ5YhJ61hI5I_ET]d
I5MdH5AdGE9dFe9[F4Y]DTIVDTIPCT9YE4MPBd1XDDEcD4AXD4U[BT1OBc/00SLY7P084`l?7A<?:1PD
6A<?91DA>RHKYXnBRi6@27QjNQSoool8MgMi00LB1P@[7ADP61DQ4a0U3`/Z61@e8QP00TXe:`07O5]?
OFmSMfMMMfMUMfmYMgAeMf]U00=gKfd01WMVGWM[IGMSEWMSGWMOEVi@B09cGeD03G=KDG=GCVYDAfm=
@f]@AVM?AGQJCWQHC81RE81ICFm@C6m;@F=:>P02=B<J00LC3@dM4`lZ61@K4a0R510c8QV7LgP02GMg
NAWoool8IGEn00L_8Q/V71HR6aPM514O3``S5Q@Y7QL00RdX9008AT4oFeYFHV=NIFEUIFUYIG5gIFUY
IFY/0VE^LP9UJFT04fESG6ESHfEOGF5DD65KEV5QFf5JE65GD5iCC69=B65BC5mCBfmNEGITFGUYGFeJ
DF9>CEm>AEU8?@02=RLP00PM518K4a0T5aDJ514J4a4S71Hl=caAF6<8IGEn8?ooo`007_ooo`QkNGT0
1`d40CDX92<H5BDF4QL>2RLE4BLF4@02CRlR00UoDSRXSWj1LFAkJFEkLFUkMWIkK6EkKFEkMWH00g]]
I@06NfEENfUQMeeBMeaBMeaAMf5D0WMLD@0;KUE9Ke56KeE9JUE:Jde2Ke55IU55HdTnJda3Jda1FShb
008V6aL021L>2RPI6AT@3aT@2a8823PN5hMYHk?0`PQkNGTIoooo27QjNP071P<1<bTV8QTF9QHC5Pl;
8QDA8AD@0096:R002G58<9R1LGi`HgQZIWQbJWQhMWQ`JWQ^IWQeLP02N6]R00EhKVIhIUIhJV1aG4ma
GU800WAMDP0=M5]@M5eBJeI:JE96JEE9JEU=J514K514IU55FdToH4e2H4e0Bc``008H5aD020l<2RDH
6AL@41H@2`l71c8K5WiQFjZe]@QhNWXHoooo27MgN@0730@2<BTW91XH9aHC5@l;7Q@@7A<?008k9Ad0
2E`k:85^HG][H7MWIGM_JGMdMGM_KGM[IGM_K@02MfIN00IgJfEgHeIgIee^F4]^G59cFe42LeM>00ac
Fe5ZE4UVD4IVDdQ[FTmWCdE[C49WCdEGB3iGBd5GBci2>2h24A<C00P;2`TR5aTE3a0C3PX=1PLZ61AZ
De2DX:88MgMi6Oooo`QUMGh01bHN62XX9b8L6b<G5A<@31HC41DA3`029AdI00Tb:1m?BdMUHeiUIFEU
JFUUKW9ULGMUJFUUJV`00VEVI00:IFUYIFEQIFENGU]DGUiHHEYDHEA@HEMBHEYDGUI@0UMBC005GEYD
Ee19FTa6FTi7C4Y30097BT802cTk=1LJ6QLJ6P`=2a/F6A8?4A0>2`/61a/D4cHb=5QUK008IGEn8?oo
o`007_ooo`QkNGT01`X30BlU8b`Q7BDH5B4E4AhC3bTL6002?b/U00YG>2Z`OfV<NV]kKFUkKFEkMW5k
MWIkK6EkLFekJ5d2NfeU00=kIEUgIEEgGE800gMLD@0=LeaAN5U=LeU=JE56KeE9KeQ;JU56Jde2Je55
FTTnJda1FTPl?2`U008M5140224I5Q<;2aT@41071aP@42LE479HDKo5a`QkNGTIoooo27QjNP071`<1
;bHS;28N9AXF8aHC81@@:QdI0090;RT02Tlh;:AhIHEcI7Q/J7Q/I7QcK7QeLWQ`JWQeLWQYGP9hKVH0
0gQVG75TEW5LD002M5]@00idGE9^GE9`F4]^F4]VDTI/EDU/Ed]YDTIXD4AVDDEGBCm]CD5KB3/b:282
5Q4?00PR6QHC2`/F410?1`LG410V5Q5]ETnla<L8N7Yj6?ooo`QgMgT01a8612lU8bdR7bLK62LG528D
42XM6@02?Rl[00I5=Bb9JUikIeagIfEgIf5gJfD2Mfm]00MgM7EgIUigJfEgJfEgHei^GeI^F4l00W=G
CP05Le]AJU]AJUA9JUA9IU16009[DdP01f]@AVM?AF=?AEM8?Vm;@Em4>RlS7`025@h>00PU6QLB2`/D
3Pl>1`LG3a0U5Q5OCd^X]kd8MgMi6Oooo`QUMGh01c8T7BTS8BXT8R<M6bDI5QhD4B<L6P02;BXY00<]
;Ba9AdINEe<00VESH`04IF=RIFY/IG5gIG5g0fEYJ@03IFEXGUmMGU]F009QEe80165JE5]JE5QCCU]C
CP9JDT`025Y@BUeBC5M@BEA>Ae5:@ee:@eI4?C4X9@8L4a8022@K6A0;314>3``721@?4A/D4C@g>5ib
N`QUMGhPoooo000Noooo27]iN@073PD2<bHS<bHS:QlL9ADA5Pl;<1/F0091:R007eDk;HaKAI:1Lh5a
J7]YIG]]IG]fLG]fMW]aKG]/IG]XGG]]IG]UGGIUEG9ICW=HCWQICGaLE6iLCG=EBG=HCfUEAVmEBFmA
AF]DAf]AAFM8?6I?@f=4>4hj<S@Q6@028ADB00LH40`G3a0D2`/G3`/H410/6ABXYZD02G]iNAWoool8
N7Yj00L71@@a:2Dd:2@/8QhU5Q8D3`/^6QH00T8Y7`0OFc//T5Q0RGUZNg1UN6YTN6aTN7=/N7EbN79^
N71ZN6]RN6iVN6INMFQHLEa@KUU>L5Q;MeUCJeU;L596L5E?IUA6K5E9K514IU55IU14HTHjITe1H48f
?S@^9Q`F008L4a4021D@2a@?3a@;2aL@2aTA4BhI5=GAd9jQXPQhNWXHoooo27MgN@073`T8<BTW=BTU
;b<P9aHC4`h::QPD00909Qd015di:HQ@>WeZGWM[H09gIf4017M[IGM_KGM_KGM_K@9gJfD037MSGWMW
FG=LDVYGCVYDBG=DDFYDBFm=@fm@C6I@AV]CB6]<@P9SC4801Em1>6M8?Uln=3D/:B0G4`026a8@00PC
3PXC3PlC2`/G3`/I4A4^6ACTj^jb_<48MgMi6Oooo`QUMGh01bXX9b/Y:2hY9b`V92<H5Q8?31lF5002
<24K01m7<RQG?C1HDDaRHeaUIF=UHf=UHf9UJVaUKW9ULGMUK6iUJFUUIFEXJ6=UH5]KFUAHDdiNDE9N
DDiNCDQNCDiJD4aJDTaJC4IDBTADC4IA@SaJAT1A?cPa;B`R71T00QhE4`084@h;4Ph@40/<510<5A0A
8aLETZVcS:J`26EeOR3oool001koool6NgUi00UkMGEgMWH=2@Lc9B4g:BD_8QlM4@hU6QLY6QL00SDS
7@05JSl]OU0oSGQXQWIXNfUU009kKFD04G]fMW]aKG]aKG]XGG]]IGMQEH5YG79ICW9LDG9ICG=ECG=I
CG=AAVmICfmAAV]<AFmDA@02Je5500EVAS]SC45J>c17<bXS6A@00RDF4`085a8>6a<@6Q8?5`l;71@@
;QTEm?[kMWAe27]iNAWoool6N7Yj00UhM7AaL7061PD`920e:BD]8alK4@hU71P/7AT00S4S7@05ICl]
O551R7MYPGEWN6YV009hL6P067QhMWQbKWQbKWQYGWQ^IW5PDW]VF6mFBg5KD7ALD71HCFiIBg1BAVUK
D6UDAVI:A6QBA6IAAFQAAFI8?Ei?@dlj;d8c:B0I4`8Q5A<021HC3a/D41/C41L@2a`D4BlI5OooogEh
N0QhNWXHoooo1WMgN@09MfmaKVMY30H6;B8O<bLT;B8O6Q0=9a`I;QhJ008]8Qh01EXk;7=>@Ge`IW]_
HgMWI@02MfmY01QgM7EgKfegKfegIUigJfE^G4mgGe9^D4QcEdigFe5_EdaZEdU_D4IVFTmVDdISAD9S
C49SCdEWCdEWB3iKCT=8>2i2<BLR618281@B00LH4`lL510L510H40/L510^6ACVlOH02GMgNAWoool6
IGEn00UUKWMNIFhV81lV8B0Z9RDX8b4I4a0S71XU7Q/00R4O7@05>C4ZCT8lF5MDHV9NIFEU009UK6`3
IFib0VEYJ@0CGUmHHUaFHEA@IEMBJ5aGGUQ@FeI>GU9<EeQ@EeA<E4I6DTY6E4i7Edi7FTa5CTa5@3de
@CD[9ahG008O5Q@261@A00HI5A4E40`H510R5aE[O8IXN848IGEn8?ooo`007_ooo`IkNGT02G]dMGI_
L0P40c`U7BlU8cDX92HL6RDI5RdP7002<B0H00MLA3Q]?bnGKej8OVj1KFUkKFEkLFT00g]bK@0ENfUQ
MfULMf5EO6ULMeE;LeU9N5aCLeU9LeU?LeE:JEE9KeE9JTY2IU55Jda1Je13Hda1FT@hDSHZ>B@P9ALB
008L51001aP@2aT@41D<2``81aP=34HY8m_Xj@09NgUi6Oooo`IhNWX02GQhN7EhN0<40c`U72lU8S@X
92XP7BLL62dQ7002<R4H00QKASYQ?Bn:IUJ0MfQkK6QhK6AhL6QhL6X2N6iV01EhIEaaI5IaG4mgJ5]a
ED]^F4I`FDm^F4I`FDm`F4aVEDU/E4QYC49VDdEXBd1XCD5KBd1?@SI8<RL/7adK4a400QPC3`085@l;
5a0@4`/;2PL75@`<BBXTjo3`MGQh27QjNQSoool7MgMi00QgNgh:1`Hk8aX_8b0c9b@_8b0Z7AT]8Ad2
<b4H00IDA3YC>BehF4agJemgIfEgIf42Mf]U0WMVGP08MemGKUa?KUA8Lf=IKU=;JUA3JUA9JUA30VmG
C004IU=8Je16Jda2Ie=50VM8?P05EdPnB3hd@R`T91XJ5Q0?008E4@l021<>2QH?418:2`T61a8;2dLY
9M[UjW9bM@QgMgTIoooo1VEeOP09IGR1J7n8920M<28K:B8P:bLV;bPV9AhK9R0M008[81T023Lh=3Hc
;Da1?E]GDf9SHfESHfEVIfEVI09UHel05FEPGUiJDeiFD5iOFUiJE5]CB5QABU]CB5iFCUiHDUYBC5Y@
BUe@AeY@AeM8@UM5@4a8@T0o>3X`:B8L7APB4`024a4@00PA3P/B3Q0?2P`81PL>2P/b92=_O8ERLW/8
IGEn8?ooo`007_ooo`QkNGT01`L30S4O5SDY9cDX92/O6bLG4c<S6P02<B@P00Q;>RiA:b6DHDfBQgF1
KFAkJF5kKFUkKF02NfeT00]kJFEfIEEbFDigH5AcEDUcF4UcF4mcG4YcFDecDDEYF4/00VmAA@08IU55
JdTnIdPlETLkDSP/>B@P<B0H7A8?0Q/D40077a<?5Pl@4`/;4P/;:APDUXf=MWAe00UkNGTIoooo27Qj
NP071@D4<B0F<bXW=BTU:1hJ91HB=28I008a9B4024Pj;dLV7XEHAXV2LGi^HgQZGGQ/IWQZF`9hJUd0
2gQXHWEXF75LD7AMDVi>@fiDAW1ED71KC71ICg1>@VIEB@02K51400QSDDEXBCmRB3]=A3Q8<bP/7Q`V
71DI4@h261<@00LP4a0F410C2`/B2`/_6QGLd<fW[Jh02GQjNQSoool8MgMi00LB2@Pa7aLa:BLe:BDW
7ATT514c8AP00S4U8@07@SL^?B4KKd/oOGIYNf]PMfMIMfMQ00=gHeH02gMSGWMWFG=LDW=GCVY6?VY=
@fm@CfmGC6mGCfm9@6I@AP02Jda200QSCdEWB3iOA3Y8?SA2;2@T61TO61<G40d261<?00LQ4a0G3a0B
2`/C2`/c6aKoooo6em`02GMgNAWoool8IGEn00Lc:BLZ81TZ9bH]:2HS7Q`P5Q@Z7QL00RXT8P08;bdZ
:b0M?cDbF5UFIFENIFEKIF=PIF1I0VEPE`0;IF=PJ6QSIF1KHEA@FdU4Fd]8GTe@GU=BGUIBGTY4FTe8
009JC4H025M>AeM:@e54?D8m=SX_:28K7AhJ5QLB3`8E4a001a`D4AD@4A0;314;32TI5[;=dibma@09
IGEn8?ooo`007_ooo`QkNGT01a8922HK5c<U8C`Y9BXM5RPM6b/L5`02=RLS00Lc91i1:bIlBCFFMUf=
OW5lJEb1KF@00W]YG@0FMfEIO6UPPFePLUE;LeE9LeU9Kde5M5Q>M5Q;NEQ;Kde2KeA7Kda5JeA5Je51
IdDlHdPlCShb?b@M;1lH8A@@610;0QT@400691@@5Pl@3`L75@`<<Q/ElOOg2W]iNAWoool8N7Yj00LA
3P`W7a/a9R8k:BD[7QDY7a/Y71P00S8W8`0O;R8L>2PTKdHcQFYBP7=VM6IINfaQN6YKN6YMLFAHM6IK
NfaMKeA:KU15KUQ6JDi4K5M<K5M9M5E9JDe1JE=6K4Y4IU=5IU50HT@jFdPkAcdb=B4K8a`E6a8?50l;
008G41001b8D41D?40h71a@<338K5_OgmgEhN009N7Yj6?ooo`QgMgT01alE4b/R7blU8cTW92dM5B/O
72LL6@02;bDS00TY7QX_92=L@35_F4IcHeU^GeIgIeegIeUgIed00ViOEP0DMfMIKU18JTU0JUA3ITa2
IU=8IU=6Ke16ITU0ITm5JdE2Hdm5HdlnGd4hEd@jACX`;a`I7aPC5a0=4@d:0QD?40078A<@5@l@3PL7
4`/;;aXEf^GZLW9e00UgMgTIoooo26EeOP07?S`l;2PV9b<R;bHU:alH9b4M81/J008U8R40420K6b4R
93@b:d<m=EEACE]LF69SG6EUGVEUHEiOFU]LEV9SG65GDU];AU]CB5M>AP9DD4P03E]=B5M<AUM<AUY6
AUA<AeA>@U54?4a4?D8m=BdQ7R0K5QDA3a0=2`024Ph@00DJ4a0D3a0=1`P@2``Q5aD00V9bN`UUMGhP
oooo000Noooo27]iN@07718?:AlN<bHS<b@P<B8M8aLG:QdH008a8ah07cDX934P64h]8HENAi9_GH=[
G89aHgaYFga]H7MUFGMQEGaYFg=HCVm:?gAGAfmAAFm?@fmHBWADAfmAAF]<@Fm<@fM<?fM??ei4>5Xj
;U4i:bXL5R4D41`D41L?2`0250/<00HG30`<20P<1`L/6ADa71CPk_<:NgUi6Oooo`QhNWX01aHC3RPQ
7S@X934T82dS7R0F5bPL5`02;b8N01le:BDa81M5:1e`Dd5nHE=fGE1jJ5]dHUIdJ5]aI5QdH5AgI5M[
ED]VBCi/DdEYCTA/CD5/DdI_DDEYD4AVBd1XBd5OBC]NBC]A@CI:=BY4<BHQ6A<I4PlH4`lF3`/00Q<;
30065@`;2PL72`L7<1XF>AhEk_?e2WQjNQSoool8MgMi00LO5A0[8Ale:BD_8b0[8QlO5APU6QL00RdQ
7@08=BTU<AlG>B8IET@hIdm7JTe4LeaBKUQ?0ViOEP9cG5801FI@B656?FI<@VI9@V]8?P02Jda200aV
C49SB3iSB3iKA3QG@CQ8>c@o;RDk:B4M5Q4E40dE4@lE3`/34P/;00D91PL:1`La6aHm7aGJiNX02WMg
NAWoool8IGEn00Li=S4]:2H^:BLW8b4V8b8L5QTO6AP00R<N700O;BPV:QlH91`H;Bl]@C/iDT=0Fe5>
FeA@FeYFGUmJHE]FGUIBF5E@E4a6E4Q4EdY6FTI0FTM2EdY4Eda6E4Q2DTQ0Cd8jBChj?Sdh=2lX<bTR
81/F510?4a4@4`l<008@2``01Ph:2`L61`P71bDI5S4N5V]hOPYUMGhPoooo000Noooo27]iN@07:QhK
6Q8><bPT;b8O>B`X9QTD9ALD008g:bL07RdP73PX8bXJ5Ua3<f=0<haE@Y9eHgEKCGi[HGUTEgUPCgiT
F6]AAEi0=7A;?GU@?GABBFm@@fm8>VmFBF]<>6M8@F=4>5i3=U93=T8X8ChS6BDH51hC3aL@2`<D2`/0
1Q071`/71a@;2bPF4HejMX63P`YkNGTIoooo27QjNP07=S0c8QXG<bPT;B<O>bhZ:Q`E9QLC008i;BP0
7R`P73DX92HK5dhm<4Xe;6Y3=GeTEFI@A6mOF6aIDVaHBWAODf1;@4`h;Ei1=FY6=F]>A6Q?@VQ2=VQ@
A6I;=F98?U]2=UM0=4]0=3XU7c8N5Q`D4Q/B3aH@2`<C2`/01Pl71`X71aD<32PF4KZ/Z[>j_0YhNWXH
oooo27MgN@07CT9<<24P<bLT;B8O>bh[;ahF:ALC008j;2P07b/O73<W92@J63de;38X8dP_9fI@AUY3
>V5@CV5=Bf5=A6YGCUY3>T4^9d/e;5/k;6=8?V=;@F<k<V=8?V=8<Um4>ULn=5<j<4Pj<3DQ7BTH4aPA
41XA3aD?2a8:2`024P/;00H?1`L:1`LE30`V5Q7>c];@hNX:MgMi6Oooo`QUMGh01fY`Pc``<BdW9RPS
8C8];2lR6R@H5002;RPW01lT7adZ9bHN6aXR9bHJ7alS8R53>cU9?c]<ADQ>Ada>BTQEDTi?AD0i<Rdg
<2a4=Ba?A3eBB49B>cEB@CeDB3IAA3Y<?cQ8>C=2>C<a9R<R61DI4Q8I4Q0C3``?2P`00Q0;30063@L8
2@L84@/<6a<@TJ^fW;[62VEeOR3oool001koool8NgUi00LZ7Q/J4Phc:2@_8Qli;2PV6A@U5a@00SL[
9`0N;B0L>2PS:QXFG4<cHd0cS5E2TWESME]=OV]QNFAGNF1?OVAHJe55GT0dM4/mNE0mM599Ke13KdPj
KeI9Jd`hIdQ1Hd@hGT<fDT<f@RPQ?R<I9APD7Q<?5a0;0a@;2`0640L72`L750/;:1HASGYfPH>32W]i
NAWoool8N7Yj00Lf<3<R6QLc:2@]8alk;RXZ71DV5a<00ST]:00N;20L=BPT9Q/GCSd`BSD/JT<eOFAE
IU14KemHK5UBK5Q:M5mCH4]0C3P]GT4eJTHeJdi4J4m2J48fJ514IT/eHTPnFd8fEd0dBd0d>RDO<QhF
71@B6a8?5Q0;0a<;2`063`L72PL75@`<:1HA^ZbZ/kZl2WQjNQSoool8MgMi00M>@T``8B0c9b@]8Qlk
;R/_7QHY5a<00SX/:00O:alL<bLT91XH?CD/<RPSB2lWIU16FT<jHE1>HDe;HDe4JUM>FT<j@BhWBcD/
Fc//HdPnHd]1Hc/bHdPnHdPbGd@jEchdDcX`B3X`=B4M:APC614@6Q4?5@l;4PX;008B2`/01Pl71`X7
1aD<32HF4Lk>d]3QjPYgMgTIoooo26EeOP07JW23?30a;BLV:2<Q<Rd/;b8J91PD008^:2L07b@O7BXW
9QhK6R8W9QXO7b<R8D<k>DTo>da5B4i7C4i:B5EBCTm5@3Tb;CL`;4@e;4m4?E98@U8k=E91?EA8=U54
>T`o>4Pi<d8i<c4V8b8H5ATB4QTB41<?30l:300240/<00H=1`P91`PA2``K4a2AZkJL^/H:IGEn8?oo
o`007_ooo`QkNGT01emEGA481bHL6C@U8CDW8bTO6BDF5P02>RDK01l_924l;RX[8Ahe9b54<B]O>2]a
B3EQBD=RBcihBcYgFdYcEDIL?cIH>BYG=RQ]A2icA3M_CSYeAcQRAS]R?bi[@S=SA3IA>c9<<2Di81P]
61@O510H40/D2`/@1`L00P`8208<1`L00alD42/H5>KYj@0;NgUi6Oooo`QhNWX01fUXK1LD3RDM6S0T
838V8R<N6B4F5`02=b@J01l]920n<2`^9B4e9b8l;RYD=BYI?2e4>CM4>c=F>B]LBC]JASY2<Ra4;b=8
<2AI?2UO>c1NA39ZA3AG@SM@=RUH=beF?C54=S0m:B8^6a@U5A8J4`lE3`/B2`/?1`L010/71`0481HA
;QTEmo?cNgmo2WQjNQSoool9MgMi00HW7aHU7AT]8Ql_8b0P71PO5AP2<b8I01l]8Qln<2`c9b@c9R<e
:BQ6;bQ1;bD/:2/Z:RLh9Qe5=R]5=Rh^928e9Adk:1m5<b=<<BQ?>2UO?Ri??C92;2A8;2M<=2/k<Bdb
8QlW5Q4P4a4G4@lC3PXA2P/>1`L00`X71`052`L781HA;aXEi>[^Nh2200YgMgTIoooo26EeOP07MHbA
@T4g920M9B4P9R4P7AdL6aLJ008V7AL07bPR838];34[:BPS8RLU:2`Y:2DS7adQ9QPQ8ahN6RdZ9Rl^
:b@T9B/V8BdU7bd/8S@Z9C/a9dTm<4<i<C@Z9cLY9Sh`:c<`;bXR8B@H51dD4aHA414>2`l:30`72002
20L700H81`P91`PH514U6AI^OhQXNhD:IGEn8?ooo`007_ooo`UkNGT01QlF4aXC3cDX92lV8b`Q7APA
3P8g91h07c`^:ST/:3X^:SDZ9clb:T@b:TD`9T4[:44Z7dT[9EXe:5Tn<Sh[9dH]9Dh[84h_7U<_9FI1
;V<m;ELf:5Ph:dl^8EDh;TL[8c`U7BTG4bXL61H>2QP@2a<;2`l71`022`L700D<1`LQ510G411VBT>^
^kd02g]iNAWoool9N7Yj00HR828N6AHg:RH_:2@]8alG4@h2<b@M01ll<2`k;RXl<B`j<2]5>2i5=R`m
<BLe9bHf91Xl9217;296<bX_928h9b=29am3:Qa3:29C>R]@=RU2;bA:<bM2:Qm4<b/i9Qlb8ATP5A8T
6aPC3`XF40/C2`/?1`L00`/71`0491DA6A4ANeUBd]WJ2gQjNQSoool9MgMi00Hd:c<W7Qdh:RL_:BD_
8b0H4@h2;R8M01lk<2hk;R/m<Be0<bm:>c55=bdf;bP[8R<^71D`71/e8Ade9R8T71d[8B0g8Qhj91Te
8Ai1<BHn;BDb9Qln;B<h9Qde;2H_81/[71HK4a4P6QPB3PXE3`/B2`/?1`L00`/71`049QHA6Q4AQ69M
f^GZ2gMgNAWoool9IGEn00IBEVL`:RX^:BLY:BL[9B<G4a028AhL01/`;Bdb;B`e<C0j=C<n>S8h=c0Z
;b/R8B8T6QHQ6A/Q6QXU7alP7AlP7b8Z8B0[81XT7Qd[:BD[:B@W91la:bD/9QhW9bDX7a`V7API51<L
6QT00Q8?300340/<3@L82@L800891`P011lE4AH@4EeEEXVIX@]UMGhPoooo000Noooo2G]iN@06A3]4
3`X7;b@P<BDQ<B@P9QhK0S8V8P0O?2hZ?C0/=BPT>R/W@BTSB2lT=RLN<BDS;1`G>RLS<1TD@BdW=BDQ
<B4M<QXE=20J=1/E?alH@bTL?RDK@BLL=a/E>AhH<Q`F<1/E71@@6a4<50/;5@`;50/;2`L7008<1`L0
124D624D3b`R8:jRX0akNGTIoooo2GQjNP06DDiG5Q4=;b@P;b@P<2@P:R4N0S//9`0O?S0/?C8]<bLT
=2PT>b@P@bTP<b<K;2<P9AXF<RHR:1LC=2PT;2<P:R0K:ALC:1`H:1LD<1TE<B8H;b0G<B4H:1HC;1PE
9QLC9ALC5Q8?5a0;4@X;50/;4`/;2PL7008;1`L01B@E6R@E438W8moAcYBKW@0;N7Yj6?ooo`UgMgT0
1VINJBLI5BlS82dR7blR7blS8090;b/04Sh`;3da;C4V8blT8CDO7ClR7C8N5bTO7R0H5B/S8B0D4BLR
82DO7RDM6B0D4AdH5QdD4R8D4@8R6A@022<J5A`A420C4A/B41dD4A<@3Q<>2Pl92P8B2`/020X71`/7
1`/71bHF6bHF4CLY9Nk^kZ>b^0]gMgTIoooo2FEeOP06M86=?30^:B<Q9b4P:28Q;bLU0SD]:`0C<Rd/
<c0_:RHU9R8R:AdM<QlM;AdI91lN6aPG824Q61@C6Q`M7alO7Q`K5a<B51DF518C510@5A@C008G5a@0
2AD@4AH@41@@41HB4Q8A3`l>2`h:2`l:310;30032@L800DO5A/O5A8`:2FF/;J2X:X02fEeOR3oool0
01koool9NgUi00I`JW0H3@dK4a0a920e:2@_8Ql2@38^01d[7Q]4<bh[7a/j:bM4;RHe924c8Qda920X
7ATl:BHN51@^91h/6ADZ6QDQ510O5A4U510^6AD/6QDT5A0W5Q4U510^6ADQ510S510G40/H40/C2`/D
2`/00P`71`8D2`/00bhN6bDF4XN8R00=NgUi6Oooo`UhNWX01W9bMRHT8R4K630T83DY9BlT8092=C00
7BPN6Sh`;2HM6CLZ9TLb:3<W92`S7bdT8BPN6Sl/9adD5B/T7RPG4bHG4adC3a/D424C42/H52TI51hC
420D41lC42XH51dC420D41@?2aL@2a<;2a@;2`022`L70QD<3004<R0K:1LC`l;2/;2`37QjNQSoool:
MgMi00E1>ST[8Ql_8b0e:BD_8b000T8e<@0<9adI=b/X91XG<bLTAc<Y<BTU9b8P:b<Q:AhJ@2`X7a@F
9b8N0R@D4@056a4>61<?7A8?9aLD9ALD00<J4@l01bDG51/C3adC3a<>2QH?2a8;2a<;2`022PL70QD<
3004<b0K:QPCi>[^d=OL37MgNAWoool9IGEn00I[OhEQJflc;B/X8b4]:2HY9282=C4`014S7Q`Y9RHQ
71/X92@i<b`Z:RPR8b<V8b8V81dc:BLO5aXN7QdM518N518H4@lC4@lF4@l00QhF50085A0?510?5A4?
7AHD61<@5a8@4Ph;4`l<0Q0;30891`P24@/<00@U7ATU6AFV_LFO^/8<IGEn8?ooo`007_ooo`YkNGT0
1DHk?a8<2C0X93DX92lR7`02;R@O014l;2Pm<2`X8Ah_81a6:QlW7AXa8ah_8AdQ61`d9AhS5QLZ6QDQ
51PO50lM510H40/O51000R0D400<6A0;5P`<6a4<9aDA610;5P`<6A0;610@4`/;30L750/;6A<?0RDI
5`03:APDNgUiNgUi00ekNGTIoooo2WQjNP05CDI<5a0=<bTU=BTU;B<O008X8Qd01SP[9d8e<2TT8BdP
740W720I5`8/81`021`F6bdS7AhE5RXI51hC5a/D3aXC41H@2`8M51003A/D41H?2a<;2aP@2b<E4AD?
2a<;2aL@2aL@41<;2`/71a@;2adE4002;AhI00<]6AFf]KFf^;P03GQjNQSoool:MgMi00EMD5TT518e
:BDe:BD]8Ql00R@N6P0==BTVACLb:bHS:alL>B8I7AHD9adI:AhJ6Q@J9AlL71@E:ALC7A4G008H4`l0
41D?2a/C41XC41PC3a<>2Q4:2aD?2alC41<>2Q4:2aD?2aL?418;2`X71a<;2b0F4@8c81/00blJ5M[Q
iM[UjP0=MgMi6Oooo`YUMGh01FU_OCTX9RlX9RdX9RPS8@0271/J01l/:BTh=38[:RPS7adX7QTL5QDO
6aXR7A/G5A`J6a/J5QLQ5Q@I4APC4Q0D4a0B3``E4a0D4a0B4Q0@3P/>2P/@3P/G4Q0A3P/>2P/B3P`D
3a4@2``91`P@2``K5A800R/P70039QTFY/39Y/C<00eUMGhPoooo000Noooo2W]iN@05JV1V50L79Q`J
=bTU;b8O008`9R806C<Y9C`[9b/P72TL630N6B4D43<T7bDH62<H6B8E428D6QX@3aH<31XA41T@41@;
2aXA41D<2aXA41@;2aP@41`D3aT@41@;2``71`033@P800<H410G3`/E30`00RPB3@03PWYkPH>3NgUi
00ekNGTIoooo2WQjNP05Kfi`6ADB9b0M=BTU;B<O008b:2@03C@[9cHY9BHN6RDJ5R/L61/B3c0S7R8G
5b4G624D3alC61L@3a8;2`025a0@010C2`/I4A4C2`/H410C2`/G410M5A0H410B2`/:1`L<20L;1`P;
1`LH410I40/D30`29A4<00>cZJZi_KahNWX03GQjNQSoool;MgMi00@/91l[8b0c9b@]8Ql2=BTU00Lc
:RLa9R<T6QLT61DU6QLG40h]8Ad00R0E5`0?7a<>7A4G50h?3`X:5@l?5Pl@4PX;5`l@4PX;5Pl@4PX;
5`l@7AD@5`l@4@X;00@:1`L00aP@41XA31<;2`028@l;00?>b/kJiNYgMgT03GMgNAWoool:IGEn00E_
QH]:C4T/:2HZ9RDX8b400S0Y9`0O:RPW9R<S8A/J7aPG71PG5A4?8QdK71HH7AHG6Q4?614G40h@30X;
4@h?4Ph@3`X<4Ph@3`X<4Ph@3`X<50lA61@A4`lA3`X<20L820H71`H720H7510A5Q4<40/<008G3@/0
0iNX/:>maVEeOP0=IGEn8?ooo`007_ooo`]kNGT013P];0d71b8I5S@U8@8c:BD07c4X93`/:2XO82DF
4BTM6AXB3bLF4QdD4B@D4A@;2aL<3AT@41L?3a@;2aT@41<;2aT@41<;2bXI5@T61a/A4AdD41L?40/7
1``71a071aL@41D>3QP@42TH4bHL5P02@blW00>^`<akNGUkNGT03G]iNAWoool;N7Yj00ACE5<W8R0U
71P`9202<BXV00/_:2@l;BT[8B8T5Q8X71PH4PlS5A4I4a0Q510A2`/D2``00QL@400B50/;610@4`/;
6A4A4`/;;QXE2@L76Q4A7AD@5Pl@2PL72`L740L76A4A5a0@6A4A;1TD<B4H0VM1<@03f>7WNgmoN7Yj
00ehNWXHoooo37MgN@03Ac/h:AhJ;B8O008_:BD05bdW93/]:BdR92DE4RLK61PB3alC41HA3QhC3a0:
2Q4:2aD?3aL?41<;2aL?418;2aP@418;2blJ5@X71aP@41`D41H?40022PL700H@1`LJ4A4J4A4J4A4^
6A@k91X2PDli00?Tk_=kP89gMgT03GMgNAWoool;IGEn00B<Y[1OG5XY8R0U8B039bLV01H`;2/[9BPR
5aDQ6QPF4a0G4@lC4@hH4Pl>2P/=2P/B3PlD414@2``C3a0@2``D3a0@2``U61D:1`PB3a0G4a0D3a02
2@L800H>1`PF414H4A8F414U61Hg9A`2KDdj00>?W9eXNhEUMGh03FEeOR3oool001koool<NgUi00<h
;B`910@T7ad00RdP700<?2l[>B`X=2PV8ATF;AhK6a4E610?8Q@@610@6a<?6Q8?5`l@0Q@;2`0A5@`<
50/;5@`<71@@6a0@9R@/8QhK6`lB4P/:5Pl?618>614>5`l@;B0L7aLE:ALCC30U00:<R8<@NgUi6Ooo
o`ahNWX00e=DDb@M6bXV8P02:R0K00`l;b/k;BTe:RLQ71P]8A`K4QHG40lQ510G410J4a0K510G4102
4`/;00XD30`C2`/D30`L510J4A4Y:SH_:RPN4QHA2`/F410271@@00DH414a8adW6aL/61AD<bP00[Vj
^P03Uj>YN7YjN7Yj00ehNWXHoooo3GMgN@04AcDb<BXW:AhJ:AhJ0S/]:@0:=b/X91hI;B8N7A8H5Pl@
7a<@5Pl@6Q<@7AD@610@0Q8;2`0:4`/;4P/;4`/;71@@610@;Bdm>C<d8Q@I4PX;5`l@0R0F4@056A4A
=2@O;QhI;QTDEc<Y00;@g>D00jS0cgMgNGMgN@0=MgMi6Oooo`aUMGh00hbV/65FE34^;0028ahL00``
:BTb;2/b;B/S8QlV8QlL51XC3a4J4a0C3a0G514J5A4E414540/<00LH510B3a4Y;Chd=SXP5Qh@2``E
41400Q`F4P055A4A:R8O:b0L9ATF@RhX00:E/l<00hFY^FEeOVEeOP0=IGEn8?ooo`007_ooo`ekNGT0
3cTY:0X71RLQ7RLQ7RdP73P]:4<b;R`T8RXL5B4H61LA3aT@41@;2aXA31T@400250/;018H410C2`/H
410C2`/F30`_:RXY72M0=RhZ8R<K5QPY8b0N61DG4@hW6QPZ7ATe:2@h8A^1NWX2Ngin47]iNAWoool=
N7Yj00mIEeHU81d`:2@`:2@/81`a:RI0<bha:2D_7QHR6ALH4`lH410B2`/I4@/G41000Q<;2`0B610@
4`/;610@4`/;5@`<<Bd^;1hY@cH/=b`Y:B0Q?2lZ:AlJ6A<?:Q`I;AhI=bXVABLO^K:b0Z6]/11hNWXH
oooo3GMgN@0DP7n2AcLd>bdY>bdY:alL:bHS?C4]=b/X<alG9AXG6Q<?5`l@4@X;5`l;5Pl@4PX;4P/;
610@4`/;610@0Q<;2`0=<Rla;Qh[AC<ZAC<]=bTXC3Pb=2@O6a<@;1dI;QhI>2XWCb`Sf]WN00:gc]P@
MgMi6Oooo`eUMGh08iBb_65FE3`c<C`c<B@O7B8R8S0_;SH_;RlQ6R@L61TE41<?40l:318>2a8>40l:
310;31@@4A4;31@@4A4;30l:32P[;bDM:3L]:d@k=3X`<4Dj=S<X8aXE4RDM6R@L6BhY9dD^9Z>g_`02
Sk2l46EeOR3oool001koool=NgUi0161OWhh:2LB2PPB2PP/:2L^9253=2lj;RXe:2<O5Q<S6AHX7ahK
61HK40dI4a0F3PlG3`l00Q@;2`0@7ADI5Ph>6a<?7A<D<2@Q?2XU6a8B91PC9ATD7A8B8Q@@;1hJ<B0H
DCP]H5QQS8f84W]iNAWoool=N7Yj02=kOGe@CdhV6aDV6aDd;RXc:2A3=C0j<2/i;RTP61DT6aLa9B8T
7a/O4`lK510F3a0G410D2`/C2`/M5AXF3`lL510K4Q8[8Adi:B8D3PlJ4`lM5A0E3`lN4`l]7QXb8AQO
?Rj;OhZ]^;P00WQmOA1hNWXHoooo3WMgN@0RLW9e@2`S@2`S?C4]>2XW@S<_>bl/?C4]91XH9a/H>BTU
;R@O8aD@71@@5`l@610@4`/;4P/;7ADJ5`l@7AD@610@9AdH<bHO3P/<4Ph<5A0=3`/<6a4>;1dI<b4H
Icl^ZIf[_=?L0WMkOQ1gMgTIoooo3FEeOP0?HW9kRJJ`EDDkEDDk?CDb<R/Y<bl^<c0_>3Dd91hL91`J
=2XV;BPS8AHC6A@A008E414240/<010H51XE418I5A4B3PhL6aLT8Ad<2P`<3@`>3P`<2`dG4@lR6aT[
81U@>2^<Tj28ZKT2IGR146EeOR3oool001koool?NgUi0S8N600N5Ph;91/H?blZC3dh?cLd:B0N7aHC
:1XJ:QXE;B8O7a/G50d>50/;8APL71DG9alK6a@H<RHP4`lCASH^:QlP8a`J9QhK8Q/G9QhL<RPR9Q`K
DSHXMG1aJVE[4g]iNAWoool?N7Yj0U1<B@0O:RHP8Q/H>B`WBcdiA3hj<BPU8QTE9API9QLC<2@P920K
50h?4`/;8ATM81PL;2<N7AHK?2`V5Q4FCS`c;b<T:20M<BDP:R0K<2@Q@cDZ;b<PID0_[JR[TI^TPXN4
019hNWXHoooo4GMgN@0O@c/d91XG<bLTBC/hBD8o>bl/9a/H8QHH91@A<bDQ:R<O5Pl@4P/;8QTO8aXP
;bHP8APM@S0[6a<IDChg<bDW;b<P>bXU<R<O>BTUDCha=bTUL4Hdd=3J[LGCQXj;019gMgTIoooo3fEe
OP:?/;`07eEECB@O72HR8STf=d52@Sdi=bHN71/E5ahD4bdU8bTU8QHA4Q0;31`H7b0K8bPT81lJ83L^
;A`F7C`e=2lW:S0X9SL/:2lU8SD[9dLn=3@/:5U2=Z>g`Y>jaVn5R`0BIGEn8?ooo`007_oooa5kNGT0
7C8X8Ph821TD43X[9d@e<40k?cHX8B`U9RlX9RHK6bPV9BlW;RHS7AdF6R@O:2lR7S8]=c0S6b<L744a
;C@U8c@R7c@T72hV93l^9Thh;2@L69fBSG]dM@0DNgUi6Ooooa5hNWX07U1ACTe:DBhV8CLZ9ST^:SXi
?clc;D8g=DHn>B`R8bPX:3`d?dHn=RdR92XT;S@V8cdgA3PY8BLP7THe;S@U8SPT7cPT6c4X9DLd:Ulo
;b/N6<>m^YNQYgQmOA=hNWXHoooo4WMgN@0MSHBFACLb<bLT<2HS=SDnBC/hEdI2FTm9<bLY:BT[Ace>
HUA=?B`/<2Lb=bLWAce>?RdW;B8OAcD^=B@Q>b<O>b<J=BTUCCL/JT8a=AlHd=OLZ<3?Mg]n01=gMgTI
oooo4FEeOP0NSjVfY[;6CDI4:2@T924Q;C<oATA5EDe9EEIB<B`_9RT^@T9DH5aJ?C4b;BTe;bL[@3i>
=Bh];bLS=Bh[<2HU=B@Q=B<L<BTV@3D^Echa>BDMS:VfQJflIGR14fEeOR3oool001kooolBNgUi01YU
Ff4V7Qd?2@Te:R<e=3eLBTE3>3I2>C@f;Bde<cHo=3I2>3@/8b8e;2hZ7b4c9B8f9b<i;2Pe:2A4:20o
:R@l;2Do<bhi9AeQBdQIEDdFNgUi6Ooooa9hNWX06fa[KUILF2XS:3X`:S<d?5]<B4I0@48l=c/e<dQ4
ADlo?4Hj<b`T8S/b;bhR8BhR7RlS7CT]:CDY9DDW7dH/94@b:4hl=D0W7V5<CHBATjZ`/`0EN7Yj6?oo
oa=gMgT06X^BT4TkAD0c;c4a>UM;BTY4B4<m>T<k>5U@DUa6@DTi<30T8T8e;c4S8BTN6BTN63T]:CDY
9DDV7T`]94`e:eY2>TLW7ea9CjS0clKGhAEgMgTIoooo4VEeOP0KLXV>Xl?9G5QU>SDf:Rhe?dA;@TM?
>cdo@TA2E5=FD4M2?SPd<R`Z?3D_;BHV81/G8QdJ<2`[;BPV>2HP@RdVA3D^DT4j@2TR@ci9VL3FVK[6
01EUMGhPoooo000Noooo00=kNWYkOWikNGT04G]iN@0G<RP`9QhM6Q/T:B<VFTa6DDeB?CH^@cTe@cTf
ASXf@cHf?cH`;bX[>2h[;2PS?c@d?c<`>BXSAS4Z>BDQOVMXBC`a@c8f01MkNGTIoooo00=hMWIhOGeh
NWX04GQjNP0HD55ELWE`IFMc>c@kFda9IEmZDdQ5CSljA3XeAS/hCSi0DT<l?cLeDT4k@CL_CD0mDT4m
A3H]ASXb<bHSQWAlOhB2QHZ>UijM5WQjNQSoool00gM_LGMgNGMgN@0BMgMi01Ng`;f/Z;U>@TmJBT]g
JgiYEU]I@Si7>3A7>cQIA4QSC4M@@SmZD4UDA3YIB4ESC4M>@3I6@3P`9RB4N8V]`<ZldmbX]kP05WMg
NAWoool00fE[MFEbNfEeOP0AIGEn01R?ZJg0i>Rjb]UACf99ATm[Jh=VHFeBADE0>STn?3aBBDmKCTiB
BTQTEe=CBT5>BDIKD4i8ASlk@C/Z:2MLI7RVdNBci>j5XjXFIGEn8?ooo`007_ooo`03NgAeNgUiNgUi
01=kNGT04g1ZL38]>TTl?eYAGDTk@Ti0<c0X:S4Z:552A4dj;dXl>54o>THj=4Hh=4/d:d@h<85jNb4I
65mAE`0INgUi6Oooo`03N7YjN7emN7Yj01=hNWX0579bMUILGhF2OH:4RFEPJ7QdKEQEHChk@U17D4Hj
<T@k>4`n>T8j=D@i=T8`9c/c:jBNXFmbMI^IWHR?S1QhNWXHoooo0WMkOQEgMgT01X25P[Nl]:>^[h9o
RijPXH1mU09>B5/02d4h=44h=TLk>44h=T<g=SXZ8SD]9KNf_kO0b/KCf8nLV@0HMgMi6Oooo`03IG^5
IGR1IGEn01=UMGh02V]oQIF`[Jc=c9Fg]X>HZYVd`hZH]59GLCm8GcHj?@8h>3T023Xj?3Tf>2dX92d[
9hbNZ/?Xm:WAeGF?U1QUMGhPoooo000Noooo6W]iN@03L6YeNgAeIE]V008m=d@023P];3P[:SPb<3P]
;38X9bdN62dS7G]dMA]kNGTIoooo6WQjNP0>LW9hOX1jK6icHVQYN7YjMGE^N7AdN7emN7YjMGQhMGEc
N7emY:>WN7em6WQjNQSooolKMgMi00>0QGigNgj;TX/00ZfbZ`08/[6g/[c1/[c1/[c1]l36_<WC_<G?
Mg]n6WMgNAWooolJIGEn00i[Oh5[PXEbS8jF/jf]b/>`dM:ccMNce=ncen:ffnFmi?70ioNB/;aUN84J
IGEn8?ooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool004?oool30000Fooo
o`<0001Goooo0`0005_oool30000=?ooo`00A_ooo`030000oooooooo05_oool00`000?ooooooo`1G
oooo00<0003oooooool0Foooo`030000oooooooo037oool003;oool200001?ooo`@00002oooo0`00
00?oool300000oooo`80000ooooo0`0000;oool200001?ooo`@00002oooo0`0000?oool300000ooo
o`80000ioooo0`0000Coool200001?ooo`@00002oooo0`0000?oool300000oooo`80000goooo1@00
00;oool200001?ooo`800004oooo100000;oool300000oooo`<00003oooo0P0002koool0037oool0
10000?ooooooo`0000;oool010000?ooooooo`0000;oool00`000?ooooooo`03oooo00@0003ooooo
ool00015oooo00@0003oooooool00002oooo00@0003oooooool00002oooo00@0003oooooool00005
oooo00@0003oooooool00010oooo00D0003oooooooooool000000_ooo`040000oooooooo00000_oo
o`040000oooooooo00001Oooo`040000oooooooo0000?_ooo`050000oooooooooooo000000;oool0
10000?ooooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`0000Goool010000?oo
ooooo`0003?oool0037oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool400000_oo
o`040000oooooooo0000@_ooo`D00004oooo00@0003oooooool00002oooo00<0003oooooool01000
00;oool010000?ooooooo`0003ooool300000_ooo`040000oooooooo00000_ooo`040000oooooooo
00000_ooo`@00002oooo00@0003oooooool0000noooo00<0003oooooool00oooo`030000oooooooo
00Coool010000?ooooooo`0000;oool00`000?ooooooo`0400000_ooo`040000oooooooo0000<ooo
o`00<Oooo`040000oooooooo00000oooo`<00003oooo0P0000Coool40000@Oooo`040000oooooooo
00000oooo`800004oooo0`0000?oool200001?ooo`@0000moooo00@0003oooooool00002oooo00@0
003oooooool00003oooo0`0000?oool200001?ooo`@0000moooo00<0003oooooool01?ooo`040000
oooooooooooo0P0000Coool300000oooo`800004oooo100003;oool0037oool010000?ooooooo`00
00Goool00`000?ooooooo`1=oooo00<0003oool000000oooo`030000oooooooo00Goool00`000?oo
ooooo`18oooo00@0003oooooool00002oooo00@0003oooooool00005oooo00<0003oooooool0B?oo
o`050000oooooooooooo000000;oool01@000?ooooooooooo`000007oooo00<0003oooooool0?Ooo
o`00<_ooo`800005oooo0P00053oool200000oooo`<00004oooo0P0004_oool300000oooo`800005
oooo0P0004Woool200001?ooo`800004oooo0`0000Coool20000?oooo`00oooooi7oool00?oooonA
oooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonA
oooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonA
oooo002?oooo0`0006Woool30000T_ooo`00T_ooo`030000oooooooo06Woool00`000?ooooooo`2?
oooo0023oooo0`0000Coool300000oooo`<00003oooo0P0000?oool500000_ooo`800004oooo0P00
00[oool200000_ooo`@0000:oooo0`0000?oool200000oooo`<00004oooo0P0000?oool400002Ooo
o`<000002?ooo`0000000?ooo`000?ooo`000?ooo`D00002oooo0`0000?oool300000_ooo`<00026
oooo0024oooo00<0003oooooool01?ooo`050000oooooooooooo000000;oool00`000?ooooooo`08
oooo00D0003oooooooooool000000_ooo`030000oooooooo00coool010000?ooooooo`0000;oool0
10000?ooooooo`0000Soool00`000?ooooooo`03oooo00@0003oooooool00003oooo00<0003ooooo
ool00_ooo`040000oooooooo00000oooo`030000oooooooo00[oool02P000?ooooooooooo`000?oo
o`000?ooo`000?ooo`@00002oooo00@0003oooooool00002oooo00<0003oooooool01_ooo`030000
oooooooo08?oool008Coool00`000?ooooooo`04oooo00D0003oooooooooool000000_ooo`030000
oooooooo00Soool00`000?ooooooo`03oooo00<0003oooooool03oooo`050000oooooooooooo0000
00;oool00`000?ooooooo`06oooo00<0003oooooool00oooo`040000oooooooo00000oooo`030000
oooooooo00;oool010000?ooooooo`0000?oool00`000?ooooooo`0:oooo00T0003oooooooooool0
003oool0003oool000001?ooo`040000oooooooo00000_ooo`030000oooooooo00@00002oooo0`00
08Koool008Coool200001?ooo`800004oooo100000Woool00`000?ooooooo`04oooo00<0003ooooo
ool03oooo`040000oooooooo00000_ooo`030000oooooooo00Ooool300000oooo`800004oooo00<0
003oooooool00oooo`800003oooo100000Woool200000_ooo`<000000oooo`000?ooo`02oooo0`00
00?oool400000_ooo`800003oooo100008Goool008Coool010000?ooooooo`0001Goool01@000?oo
ooooooooo`000002oooo00<0003oooooool03?ooo`040000oooooooo00000_ooo`040000oooooooo
00005Oooo`030000oooooooo0;_oool008?oool500000oooo`030000oooooooo00koool200001?oo
o`80000@oooo0P0000;oool400005Oooo`80000Hoooo00<0003oooooool0X_ooo`00oooooi7oool0
0?oooonAoooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {199, 0}} -> {-0.251066, -0.0488477, \
0.0112836, 0.0112836}, {{22.25, 104.688}, {194.625, 112.188}} -> {-29.8025, \
-5.86047, 0.973745, 0.973745}, {{112.938, 195.375}, {194.625, 112.188}} -> \
{-118.109, -5.86047, 0.973745, 0.973745}, {{203.563, 286.063}, {194.625, \
112.188}} -> {-206.385, -5.86047, 0.973745, 0.973745}, {{294.25, 376.75}, \
{194.625, 112.188}} -> {-294.692, -5.86047, 0.973745, 0.973745}, {{22.25, \
104.688}, {103.938, 21.5}} -> {-29.8025, -94.167, 0.973745, 0.973745}, \
{{112.938, 195.375}, {103.938, 21.5}} -> {-118.109, -94.167, 0.973745, \
0.973745}, {{203.563, 286.063}, {103.938, 21.5}} -> {-206.385, -94.167, \
0.973745, 0.973745}, {{294.25, 376.75}, {103.938, 21.5}} -> {-294.692, \
-94.167, 0.973745, 0.973745}}],

Cell[BoxData[
    InterpretationBox[\(3865\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ 3865, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4.4.2 Three-dimensional wavelet transform",
  FontFamily->"Times New Roman",
  FontSize->12]], "Subsection"],

Cell[TextData[{
  "\t",
  StyleBox[
  "The sample image shown in Fig. 13 consists of the shadowed images having 8 \
different lighting directions. Each of the samples can be represented by the \
three two-dimensional image data, so that each of the red, green and blue \
color component data is represented in a three-dimensional image data. \
Thereby, we apply a three-dimensional wavelet transform to each of the color \
component data. The Daubechies 4",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[", 16",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["th",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" order base functions are employed.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
zcolor3D=Table[color3D[[j,i,k,l]],
\t{i,dim[[1]]},{j,rotation},{k,dim[[2]]},{l,dim[[3]]}];
dimZ=Dimensions[zcolor3D];
base={daub4,daub16,daub16};
wMat=Table[waveletMatrix[dimZ[[i+1]],base[[i]]],{i,Length[base]}];
zSpect=Table[waveletND[zcolor3D[[i]],wMat,3],{i,dim[[1]]}];\
\>", "Input"],

Cell[TextData[{
  "\t",
  StyleBox[
  "After computing the three-dimensional wavelet spectrum, we work out an \
approximate wavelet spectrum of the 16 shadowed lighting image data. An \
inverse wavelet transform generates the expanded 16 shadowed lighting image \
data from the 8 ones. These processes are applied to each of the red, green \
and blue components. ",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
angle=16;
aSpect=Table[0.,{dim[[1]]},{angle},{dim[[2]]},{dim[[3]]}];
Do[aSpect[[i,j]]=zSpect[[i,j]],{i,dim[[1]]},{j,rotation}];
wMat[[1]]=waveletMatrix[angle,base[[1]]];
wMatTrans=Table[Transpose[wMat[[i]]],{i,Length[base]}];
angleInc=Table[waveletND[aSpect[[i]],wMatTrans,3],{i,dim[[1]]}];
incColor3D=Table[imageNormalize[angleInc[[i,j]]],
\t{j,angle},{i,dim[[1]]}];\
\>", "Input"],

Cell[TextData[{
  "\t",
  StyleBox[
  "The expanded color image data are converted into the color graphics image \
ones. Figure 14 shows the expanded images. Depending on the lighting angles, \
the 8 shadowed lighting color images in Fig. 13 are successfully expanded to \
the 16 ones by the three-dimensional wavelet transform.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
incColor3DG=Table[Show[convertRGB[incColor3D[[i]]],
\tPlotLabel->StringForm[\"``deg.\",Round[360*(i-1.)/angle]],
\tAspectRatio->dim[[2]]/dim[[3]],
\tDisplayFunction->Identity],{i,angle}];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[
\tTable[Table[incColor3DG[[i+j]],{j,0,3}],{i,1,angle,4}]],
\tImageSize->{400,400},PlotLabel->\"Fig.14. Increased 3D color images\"];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0238095 0.238095 [
[.5 1.0125 -101 0 ]
[.5 1.0125 101 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.813 moveto
(.14) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Increased) show
171.000 12.813 moveto
(3) show
177.000 12.813 moveto
(D) show
189.000 12.813 moveto
(color) show
225.000 12.813 moveto
(images) show
261.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.245293 0.245293 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(270) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E2DDD4
D7B8A3E1C0ABE1C0B3E1C7B9E1C0B3E1C8BAE1C8BAE1C8BAE1C7B9E1C0B1E2BFA8D9B7A0
DAAD96D1A08BD29E88C89883C89883C89883C89883C89680C89079C09077C09079C09077
B78771E1E0E0E1E0E0E1E0E0E1E0E0E1E1E1E1D7D8E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1DFDFE1DEDFE1E0E0E1DFDFE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1DFDFE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E2E0D9
D8BAA6E1C0AAE1C0B1E1C7B9E1C0B3E1C8BAE1C6B5E1C3B0DFC3B0DFBBA9E0B8A0D6AF97
D5A890CE9C86CF9A83C69782C89883C89883C89580C89580C8907CC09078C09079C09983
B78D7AE1E0E0E1E0E0E1E0E0E1E0E0E1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E1E2E1D8D9E1DEDFE1E1E2E1D9D9E1E0E0E1DFDFE1DEDFE1DFDFE1DEDFE1E0E0
E1E0E0E1E0E0E1E0E0E1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1DCD3
DFBFA7E1C0B2E1BFABE1C8BAE1C0B2E1C5B7E1C4B3DDBCA7D3B29CD7AC97D7A68FD0A48F
C8A18CC89C87C99A85C0907CC5947FC5947FC59580C59078C7907BC0907CC0907CBF9075
BFB4AEE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1DFDFE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E1E1E1D7D8E1E0E0E1E0E0E1E0E0E1E1E2E1D9D9E1E1E2E1D9D9E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E2DDD4
D8B8A5E1C0ACE1C0B2E1BFB1E1C6B8E1C0B0E2C1B3E0BCA9C4B6A6D2AC9BD69D8ECA9883
CA9C8ACA9C8BCA9684C89480C0907CC0907CC0907CC0907CC0937BC1917CC0907CB78771
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0D9
E1BAA3E1C0AEE1C0B1E1C0B2E1C0B2E1C0B3E1C1ADE1C3B5E2C3B6D9BCA4E2ABA3D3A491
D39F8AD29A8CD39F90CD8A7EC28C7CC29485C1927EC0907CC08F7BC89580C09582B98A74
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1DFD8
E1C0AAE1C0ACE1C0AAE1C0B1E1C0B2E1C1B4E1C0B2E1C5B7E1C8BAE2C3B6DABEA8DAAE9E
D9A997DAAA95D19B8BDAA591CA9081C88A7AC9A093C0927EC5907CC7907CBE9788C59F8B
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1DFDFE1DEDFE1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0DFCBC2DBD4CD
E1C0ACE1C0AAE1C0B0E1C0ABE1C1B4E1C0B2E1C8BAE1C3B5E1C1B4E1C7B9E1C0B3E2C1AA
DAB39CDAA999DAA994D29F8CD39888CA9680C78E79C79A88C0907CC1907CBA907DD7BFBA
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E2E1D9D9E1E0E0E1E0E0E1DFDF
E1DEDEE1DEDFE1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0B49788CECDC3C5A599
E1C0ABE1C0B3E1C0ADE1C0ACE1C0B3E1C7B9E1BFAFE1C6B7E1C6B8E1C6B8E1C0B0E1C1B1
E1B6A1E1AE99D9A593DAA68DD09683D09883C9917CC1907CBF9582C99581BB8C75D8D2D2
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E2
E1DADBE1D9D9E1E0E0E1E0E0
E1E0E0E1E0E0E1DFDFE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0DDD4D784463F515A5AD8BAA6
E1C1ACE1C1B3E1C1B4E1C1B3E1BFB1E1C8BAE1C3B6E1C0ACE1C6B5E1B9ACE1B5A5DEB29A
DFB89FD9A898D8A993D79E8ED19E84CA937FC7967CC7907BBE8E7AC59983C08E78E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E1E2E1D8D9E1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E0E0E18D5F4AC2B5B33F3E46E1C0B2
E1BFABE1C6B8E1BFB1E1C6B8E1C0B2E1BFB1E1C6B9E1C7B9E1BEAEDFBBA4E1A89DDAA691
CF9F8AD7A48FD8A48BD2A38CC69580D0947FC99580C29078C1907CC0937FBA8E7CDFDAD9
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1DFDFE1E0E0E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0895B48E9E2DD4C4F4FD8BAA6E1C0AB
E1C0B2E1C0B2E1C0B0E1C0B1E1C0B2E1C1B4E1C0B2E1C6B8E2A49AD99B8CD8887FD8877B
D18377D19784D09983D0997FC8917CC78F77C6907BC8907CC89078BF8C76C38E78D1B3AA
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1DFDF
E1DEDFE1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0DDD4D4FAEFED484B4BE1C6B8E1C0B1E1C0AB
E1C0B2E1BEADE1BDACE1BDA5E1BFB0E1BFB1E1BEB2E1B5ABE2A89CD8786ED7685CCF6E69
D06C63CF6B68D08675C58A76C59078C78874BF8F77C8907CC9907CC08E75C98C7ABB8A75
DBD2CFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E2
E1D9D9E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0815E559F9B9AD7BFB3E1C0AEE1C0B0E1C0AB
E1C0B0E1BDABDFB29BDFB7A2E1BAA5E1BCAAE1A497DE887BDD998DD06A57CB8073C6756A
D06054C3574AD06860C1756AC08877C08E6CBE8A72C6907BC8907CC8927CC88A77C89782
C19380E1DDDCE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1DFDFE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0D0BBBCE8C6B237454CD8BAA6E1BCA5DFBFABE1C1AD
E1BCABE2B698D69F85D3A091E09587AA301CC99A87D8847CD37F75D19E96B76558C58871
C6886BB8695FAC5241BD5649BE7467BE8C6FC0876BC0927AC89680CA927CC8937FC8907C
C3907BDBC4B9E1DDDCE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1DFDFE1DEDFE1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E08F6C6489868AAD9183E1C0AAE2BBA8D7AE9BE1C6B8
E1BEADE29D7DCF8C70A12821CB9C98E398966F3B3AD4AEA3D2958DD8A69EE4DCCBD8817A
C5968AB08776A160516D3823AC4E40B5806DBF896CC88D7CC89B87D3A285CA917CC89580
C8927EC39782DBCBC7DFDDDDE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0DFDADE7D48412C3D48D7B8A2E1C0B0E2C4ADD8AC9AE1C0B2
E0B09AD99870BE5B41A02817683537BCA296DFBBADDFC6BDE1D3C9E1CAC1E2BEB0D5B09E
E0BDA9E0C0B5C5A594986E655C33279D5040BB876FC48C78D1A48FD2A28DD29F85C88E79
C88E7AC79782C1B4BBCFC4C6DBDADDE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0B497886D4038C3A3A22F3642D8BAA4E1BCA4E1BAA2E1BDA6E1C0AE
E3B49DD89986BA957ABE7A6D6F4B46D38A82D8A290D59688DDA8A0DDA18FDD8F7ACC6B5B
D48476C98D7BDEA087C38375B17D6F5A15099E5A50BD8A78CFA289DAAD92D29B83C79680
C68D7BC9927EC3B3A4BEAEAAC0B9CDE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1DFDFE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0DFD7DA472C233E231E1A2E38AF8D85E1BEA7E1BAA8E1B19EDFB29EE1B9A7
E3B59DCD8468C99C8BD8BBA9E1C5AFE2B2ABDCADA2D4A89CD2AB9CDE948ACC9A8CCC8576
CC776AC26F64CA8A7BC56A5ABB58459B382A64241EB3736ACD9E86DAAC92D29C80C88D78
BF8E7AC896828D513ECAC2BEC0B3C2DFDDDDE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E4E0E3EFD7D64555542C3940DFBFAFE1BFA8E1BCA4E2A9A3D8B6A3E1C4AB
E3AB9DD59680B37E6BDFBCAEE1C8BAE1C1B3E1BFB1E1C8BAE1BAAFE2B9A3D9A893DAA691
D19E84D0977DC38C75CF8273C5796BB56E5E975752915249C3917CD8A58DD29C80C89279
BF8B77C8927EA3726550423FDBD3D2D8D2D2E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E6DFD2C7C0C9E2C5B2DAAE9BD7B7A1DFC0AAE1BAA6E1C4AEE1ADA9E1C1AE
E4C1A9D4A38CC68572D3A995DFBFB0E1C9BBE1C1B3E1C0B3E1CBB8E2AB9FD89F88D8A38A
CF9B7FCB917CBB896BBD7F6ABD876ABD7F6ABE846AB7827BBF8E73D19D88D0977CC78C78
BE8F73C58F7A7243394D4D45BBAFADE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1DEDEDFDCD6E1BCA3DEB29ADBBEB3D3B7A4D8B8A5E1C1ADE1C3B5E1C1B4E1C9BB
E2BCB1DCB09CD49983C68B7BD7B4A1E1C6B9E1C0B3E1B9AADFC5B4E2B99FD8A48ECF846E
CF977EC2866CB1836BB88168B97F65B98264B87860B5846EC89782D09A83D0927CC08874
C08A78C0937B4323262B3234C7BFCEE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E2DCD2D8CDC9E2B89FD7A891D3A287BDAEADE1B6A4E1C0B3E1C8BAE1C8BAE1C8BA
E1CBB8E2AEA2DCAA8FCF8F7AD5A593E1C0B3E1CBBBE2AEA9D8BAA8E4BEA9D2A28DD39A84
C2816FC28870B87764B87F68B78271C2896EBC8B75B98570D09680D09580C9927CC18975
C08A73BE8F7A6030272C2528958E8AE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1DFD8E1BEA6DCA081CDA08DC79D8DD8BAA4E1ACA5E1C0B3E1C9BCE1C9BCE1C8BA
E1C7BAE1C3ADE3B098D1A285CD9482DFBDAFE1C6B5E1C1B3E1C1B3E2C0ADD9A18DD09A83
C7907CC8907ABA8066B97964B7816EBF8D7EC89181D29C87D2A28CC89581C7917CC7927C
C08B79C0957ED9946C56332A422F2EBFB9BAE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1DAD4E0C2B1DB8671D7A18AB47F6DD1BBA4E1ACA4E1C0ABE1C0B3E1C6B7E1CFC5E1C8BA
E1C7B9E1BEAEE2C0A7D3A896D0A68FD8BAA3E1B9AADFBBA5E1BEB1E2B49ED9A188C78C77
C58872BE8C6DBA7C66BB7F64B78170BF8F7DCF9C8DDAA691D29D87C89A83C99580C19078
C08D77C0927FCC9B85C2886C8654484A4444E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1D4D2E3A696D27E6BC06E65C08E7EBDB2A5E1C1AFE1C1ADE1C0B3E1C8BAE1C8BAE1C6B8
E1C6B5E2BFAED8B7A0DAB19CD7B8A5E1C1AFE2C5B1D8ACA2E1C0A6E3A89BD0997EC58470
BD806BB37B67C08569A97F6FB98574C89D89CFA28EDAA691D29E88C89680C88D7CC98C7C
C08D75C68C7DC79071BE8672B67B66E2E1E2E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1DCD7
E1DCCFE3A695D08168BF756BBB9585D8BAA5E1C0B3E1C9BBE1C0B2E1C5B7E1C3B1DFC5B3
E1B9ADE2B9A4D7B39CE1AE99D7B7A3E1BFAFE1C6B6E1C0B2E1BBB0E3A58ED29780C08570
B9816CB1806DB0826DB78775C69A85D1A18DD1A590D8A28CD29D87C8927CC88D77C78877
C78B78BF8D7CCB9B89BA816CB88574E1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E0CFBB
D79F86BD7D60BC7762B07F6CC39C8BE1C0ABE1BFB1E1C5B7E1C6B5E1BEACE2BEADD7B29F
DEB9A0DFA69FD9B29ED9AD99D7B29DE1C0B2E1C0ACE1C0B2E1C2AFE2A899D28F79C08570
B8806CBA826FB28A78BF927DC89A86CF9F8AD8A893D1A28DD29984C89A85C78D79C78975
C08778BF927DC57E5FC68977C1836BB7A09FE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E2BDA1
964C2E9755466C3F39886A62CDA898E1C0ACE1C0B0E1C0AEE1C0B2E1C1AEE2BBA9DABEAA
DCAB9FD1A290D69E8DD5B19BD7B6A0DFBFAAE1C0B2E1C0B0E2BAABD9AB92CE8A7CBE836C
B67C67B5816EC08C7ABE907BCE9686CF9C8AD09883CEA08ACF9A83C5947FC79580C08E79
C08877BE8879C59270B36A52C58E7AB76C59E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1DEDCE5D2C8
D1775C61372B693C3849484FCDA895E1BEACDFBFB1E1C0ABDFB69CD9B19DD3A088CF9C85
D09F8ECD8F85CD9182C4917CD5A893D5B6A2E1C0B2E1C0B3E2BCA7DBA28FC88C6FB87866
B88068AE7B67BA8572BF907BC28E7AC49A85CF9785C6927EC99984C1917CC0907CC08E79
C08877C08A7CB36A519F4E34AE7256B66B5CE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1D6CAE2C0B1
5C161048221D432A263D444CCFA996E1BEA7D8B8A2E1C0B0E6C1A8C69881BA8970886156
6E494185503AA2685BB35D45B05A43C09886DFBDAFE1C0B2E2C0ADDBA38FC88B70B68465
B4755CAE8472BC8A77B7907DB38C79C08B7AC3957FBB917DC89883C89680BD8D78BA8D78
BC8B77C08B7CBC745A924C398F4F40AD6045E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E0E0E1E4DCD1DBA289
A55A502F17163A1E1D1D323ED8B39FD9B9A3DFB8A3E1C0AAE2C3AEE1AF97BB9787926351
4C2A26482A2260453F9664519C665A945C55D7B39FE1C4B7E2C3B3DBA990C3826BB2765A
8B2916986758B88161B98168AA6F56B9846EBD8777AD8973C5947EC79580C08A74B08773
AE8777BD8873AA6351935846955E53AD513FE2E1E2E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1DEDEE1DEDFE1DFDFE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0732A21C4B2A5E2AC95
B464513E26312A18171F2937D7B7A1E1C0AAD9B8A2DFBDA6DFBFAAE6C4B3C89D87E9A993
9177696753486C5042716B629F7464C69483D7B7A3E1C6B7E2CBBBDBAD93CC886BAA715D
AD694F6E413E875F5620070C79493C7353476F423190695BA77151B58065BE8C76B08370
AE8873B77D6A874E3C6F40378A665AB66C5EEBE9E9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1D8D9E1D7D8E1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E07E433C74443D2C0000904F40
582D38361F1C3620210B2433D9B8A2D7B8A5E0AA95D4A790D3B39FE2C3B6DCC0ADD8A997
C5937FC79783B0826CAA806BC09880D19D8BD7B09DE1C8BAE2C2B3DBAE98C88E72B98062
AE795FA46F5EA57B6B311B202A1D1A613D39553B355744398B675A91715DBB7D65B18773
AE8B749050466B4030593227644A3FBC7C67E9E7E7E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1DADBE1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E08B4A424A2C25432220361E1E
230D12351E20381E1D1D2E3AD8B7A1D9B7A0E5C8B8CD9587BC8169CD9A83C89B83B88573
A66555A0624BAA6D54AF6952C2957DD5A996D7B19DE1C5B4E2C2ADDBA695C8957DB97B60
B08864B58066C3947DD2927A4B4E4E6F4D407B564A585550906E58A87967BE9175BC8773
B08875834C374724225230265D3D30AA4C39E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E09858423212102B1B19311918
321B191E1516433130323840D3AE9AE2BAA4D8BAA5E6C5B8D5B29EB28171AE7E72A68273
9B726389655A8D6553977162986C62C7A695D8BAA6E1B9AEE2BCA6DBA891C89182A65B44
A0543DA57F5FBC8F72C09077C4937DBB8C75A376659A7362B68472C0886FB08775BC8F73
B78169482B242B1C194647456F4334953625E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1DFDFE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0AB715C3F14112D1716231817
0F01082A1717392D2D484D4DBD9D8ADFB7A2E1C0ABE1C1B4E2C4B8E0C6B1D0A0959D908E
CAA097BA9284BC9B8CAB897CCA9B89D7B9A5E1BFAEDFC1ADE1ABA0DCB09ACDA992C88E82
8B4D456B392E6C422FA4715BB88B74C79079C39274B08874BE8970AA7F6ABC867AB28775
90523E4D2720342A29313934A5523A6A3832C1C2C2E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0957069492D292F17162C1817
1E12102214153C2D2D4D4F4DA78B7CD7B19DE1C0ABE1C0B3E1C8BAE1C9BCE1CABFE1CABF
E1C9BCE1C9BCE1C9BCE1C9BCE2C3ADD8B8A2E2C7B6DAB7A0D9B39CDAB09BD3AB97D6AC9A
D3A38F9B6F6A7C564D53362C653A2C925A4A916956A26B519A6851B47F70A37F6CBE8473
6F362E3A1D1A301E2334131175281C76433C342F2EE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0AB7C74593F3D2B1C1A2B1817
2D18172C1D223D2E2E524D49A48171D3AE9BE1C0A9E1BFB0E1C6B9E1C6B7E1CFC6E1D0C9
E1D2CBE1C9BCE1D0C8E1C8BAE1C9BCE1C1ACE1C0AAE2BEA6D9B29CD9A893D9AF9AD9AF9B
DCA999CBA492CD9381A07B6D7E60546850428356487B685B9570608A675CBB8678B6816C
6D352C311A182518171F1311361C1C5D37353C3635E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0AA705A53342A4A2E2B2A1917
31110F361E1D412B2553433D8A7264C19E8CDFBFA9E1C0ABE1C0B3E1C9BCE1C8BAE1CFC6
E1D0C9E1D0C9E1D0C8E1C8BAE1C6B5E1C6B8E1BEA8E2BAA2D9AF9AD9B29CD9A893D9AE97
DAA594D3A28CCB9E88C4937DB8917EAE89759E7968987363B57F6FB38A75BB7C70A0664D
62322A311A18371E1D251918261716412A23514D4CD5D2D3E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E095644F583E39442B273D2220
1F12102C16162E19184E332A695140B08B7BD7B7A2E1C0ABE1C0B3E1C7BAE1D2CBE1C8BA
E1CFC6E1CFC5E1CFC5E1C8BAE1C7B7E1C0A9E1BDABE1B8A0D9A893D9AD97D9AE98D9A893
DAA691D09E88D09883C99C87C0917CC89580C1907CBD8E79BA8873BA8878B37D6771463C
2F19133520241E11172112100E0108311D1D5044409C888BE1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0AB715B4E3631523B393D2927
3E211F2817163624233F33335D453E7D6758D3AC98E1BFAAE1BFB1E1C5B6E1CFC6E1D2CB
E1C9BCE1D0C8E1C8BAE1C8BAE1C7BAE1BEA8E1BDA5D9AE98D9AE98D9A893D8A893D7A590
D8A590D29E88C89883C89782C99E88C0917CC7907CC08E79B28874B384709B66545E3029
412A2815090F2012190D01081B1016211415483E3F76625EE1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0A07C74593E3A523E3C4F3A37
3D2220221310341E1D4A322B644C416C5C4EBF9583DFB7A1E1C0B1E1BFB1E1C5B6E1CFC6
E1D0C9E1D2CBE1C9BCE1C8BAE1C7B9E2C1B2DAB9A1D8AF99D7A590D7A492DAA490D1A28C
D19C8AD29D88C89883C89580C7947FC79580BE8973C18C77B0806BAB7060864D3B522A25
22121022131913080F1B1110180E152F1D1D19191B7C706EE1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1DFDFE1DDDD956F674F3A38543F3D513B38
361E1B3D26253123223E2B2A62483D846455B07E6BD5AF9CE1C0ABE1C1B4E1C1B4E1C7BA
E1D0C9E1D0C9E1D0C8E1C8BAE1C5B3DFBDACE2BAA2DAAE98D3A994D1A18BD8A090D19E88
D09B85D09988C79180C59480C7907CC0907CC18F79B68370B77E67A96C55693E30482521
2B1A182117162217171A100F2117162F1D1D0B0304E2E1E2E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E2E2DCDC88615854382F4E383555403E
513A38382524412E2C462E26514844805A49A47868CBA492DFBFAAE1BFB1E1C6B9E1C6B7
E1CDC3E1CDC3E1CDC3E1C3B1E1C2AFD7B7A1E1B69ED8A58CD7A48ED8A58CD1A08AD1A18C
D29883C89D87C99780C18B7CC08D78C08C77BD8D78B7806BA5725A7C4840592C262D1C19
2212101C111715090F05010813080E3D2E2E180D0EE9E7E7E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0AC7C74493128583D38513E3C
4B3531422522452D2649363454413A6D493D846354BF8F80D7B8A2E1C0AEE1BFB0E1C5B4
E1C5B3E1C5B3E1C6B6E2C1B2DAB9A1D9AD97D8AD94D8A18CD19C85D19F8CD1A086D19A83
D29C86C89580C89580C8907CC08E79BE8470B97F6AA5715A7C4A41683C2D3A1E1B291918
2A18171C111615091014080F281A1B000D165C4646E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0C5A59E573D3B4C3632583F3D
52352B45312E3B26254B353145312F58443F6A4D43A37664D1B19BDFBDA6DFBFA7E1C0B0
E1C0AAE1BEA7DFBDA5DFBFAFE2BBA3D8A890D8A58CD09680CE9782CE9786CF9C86D09B84
D08F7BC89180C78F7CC79078BE8A73BD8470B17963895242693D2D391D1B2514111E1117
2818171F12170D010813080F2B1B1C110809E9E7E7E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0C2A392674C48523E3C4C3836
533B393C23263E29283F2D2B513E3C49302852382F815F51B38770D3AB94D5B19BDFBAA2
DFBCA5E1BEA7D9B69FD7B49EE0BAA2D7A18ACE937FD09A80C88C77C8937EC6947FD09580
C78D78C58D77C58372BB8772B6856BA86D57A067506D41313E1E1B2D1C191F121014080E
13080F0601080401082A1A1B35211C160B0BE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0EFE2E973504B56403E513B38
55424151342A3A202049373644302E54403E412A2756423B795749A7735EC49480D2A189
D2A693D4AD9BD4AE97D5AB96D6A48CC38C72B97D66BF8166C48B75C58773C5846EC58A75
C78D6EBE846EBD806BB47762AA77628F5949733B2D562A24361C191F110F16090F14080F
0C000804000810070E1E141536353748322CE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0EAEBE9A6857A4F35324F3A38
4B37354737333B2427432B24513A38503F3E58423F4433325D4944694E448A5846A37368
976F5FA97660B48673B58871B17D6AA76D558D5A4596644AA9674FB4785EBA7F65B9735E
B06F59B26E52AF715CA06A5A9054467840305627233A1C1922121017090F0D0108030007
0300080300071A14152D1B1C040507D8D2D2E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0DECCD56246414D3B39
4E3E3C4E39372A1D1A3A2B2B543F3B554241624E4B5F4C495D4C4664524B6B50466E463E
6A413763413C784639875B4C7A50476C484477463A7243307A48388E5746945F499D5D45
97614B864F3B885446874B3D6F43364F2824462A262413101E110F15090F0C0008030007
020007201415160E153F4446271A1BE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0F0EBEB865F5E4E3836
503A384D3A38513A38403434503F3E614D4A5842405A44415E3E3B6C453B664034573E39
462D2B5037334524225538345C3E394C3431442523492B284925204D24215E372A60392B
5C36295929245225214C28244A2522311D1A2012101A0B1114080F14080F040008030007
20142020141641302F06131C95807DE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E4E5E3DAC7CD5B3F3D
4D3836513E3C4E39365847454B3531594543513935533F3D5F4B43583F3C5A3B37533834
4933304C38373E262A3A2B2A402422412422321C1A2819182F1A193A201E3D1F1E341B19
331B19331C193D201E3219182F19182212101D110F15090F13080F04000804000810070E
261E20381F202422234A4444E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0ECE4E6895854
533E3C513E3C513B3840312E604B4754454256444143302E5538304D302B49333046322F
35242F3B2F2D41262B391F20301C282819182819181E110F221817241817271918211210
16090F1D110F2A181722121016090F1E110F1B101615090F04000813080F1C1515292021
2E1B1C383535382E2FE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E6E8E6BD9D9B
573A38543F3D513B38533E3C453B3956413F513834422D2A3C2927391D1A3F2D2B392328
3923272B191A301C271F1219190A101E11191C11171609101A101615090F1C1117160910
1B10161F16161A1016170910040108030007040107040108190F16160F0E13080E27110F
3A3B3C372B2CE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0F7F7F7
9278734B34314F3A384C3D3B50403E544543523C3F4024223C27262A1B192A17172A1C19
2D1919180A1116090F1E11191B111713080F1B1017150910190F161509102D1B1C050108
180F162117171D12170501080400080A0007160E15170F16160E15311D1E3C2A223F3D3A
170A07D8D2D2E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
F7F7F793736E4E3E3B47322F5444425545435F4946443433412D2B321B271D11172B1817
1D11172518172016161A101614080F14080F13070E14080F13070E211717180F16433742
2F2F362918251609101C11171C15161C1516180F15352829342424311D1E523935443933
8D6959E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0F8F9FA936F6A5B484644302E51413E5F4D4A614A47483228412B282719191A1017
17090F1A100F1C111716090F14080F190F1613080F190F1613080F12070E373337312332
53484F5B4F4D47333B3F3537392B2B2519183425233022234D3B39563A3437313274514A
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0DFDEDFFFFFFF8C625666504C503C3A57494766514D63504D452B283E28273F312F
352B2B2717172217161C11171A101613080F14080F1F15221C1118201616180E153C3331
42323629181D30201D2A1C1B27171C321C1A322423462E2655433A635F5B664640E1D9D9
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0F9FBFD86665A533A35523E3C6A58556E5E5C6B55513F2928352126
4124224736343A2C2A1E121814080F271D29271C282F27272B202D3C3234261A253C373A
48373A513A383C2F303B2C2A3F3130433B394332305648414C433C8A6856C7BBC4E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0F9F8FA9D8F88604D4B533F3D654D4A6D6268715E5C5D4D4B
574D4F4A3438493E42554C544C474B3C2F343E334340323B544A5144383C553D393F363A
62464257393857382F543E3C58453E634F456841343E3D3E8D6B5AE1D9D9E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E8E9E7DBCFD87E676D604C4A584C516C6A737B6B6C
7765627B6C6767595C5E58586D5D636D55515B49474B3A4345312F554042594543513E3C
64423A6A463E6B4942705047634139735D5B9874665A443CE1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1DEDEE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0F9F8F6908591887D766C6475897B80
8D83898A7C7D836E6A806D6C7F6865836B6C735F5E78625E6B5A5C61504B63545273605E
67565071544B69433F786560957C767E61588D797DE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1DADBE1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E4E5E3E9E0E5848395
A09393BFB6C6ACA0A7A892908A777F7F7077876C6E886C677B6764896C6976605A73584E
7F6156726B6292867D635855B7A5AEE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E4E5E2D0CBDBE8E2DFD4C8D49994A29B97A99289879286849287859489878E8584
86756D6B645AE1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0238095 0.488926 0.245293 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(292) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE4EAE1
DCCBB5E3D1BCE3D2C3E3D8C9E3D2C3E3D9CAE3D9CAE3D9CAE3D8C9E3D1C1E4D0B9DCC9B1
DDBFA7D5B39DD5B19ACDAC95CDAC95CDAC95CDAC95CDAA93CDA58BC6A58AC6A58BC6A58A
C4A289E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3E8E7E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3F0F0E3F0F0E3EFEFE3F0F0E3F0F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3F0F0E3F0F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE2ECE4
DBCAB4E3D1BAE3D2C4E3D8C9E3D2C3E3D9CAE3D8C8E5D9C8E6D9C8E6D1BFE6CFB6DFC7AE
DFBEA5D7B29BD6B098CEAC96CDAC95CDAC95CDAA93CDAA93CDA58EC6A589C6A58BC6A78E
C49E85E3EFEFE3EFEFE3EFEFE3EFEFE3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EEEEE3E8E8E3F0F0E3EEEEE3E7E6E3EFEFE3F0F0E3F0F0E3F0F0E3F0F0E3EFEF
E3EFEFE3EFEFE3EFEFE3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE5EBE2
E4D2BCE3D1C3E3D2BCE3D9CAE3D1C3E3D9CAE5D8C6E5D0B9E0C9B0DEC5AEDEBFA6D6BAA3
CDB39CCDAC97CDAB95C6A58ECFAB93CFAB93CFAA93CFA58BCEA58FC6A58EC6A58EC09D7B
C0BCB2E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3F0F0E3F0F0E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3E8E7E3EFEFE3EFEFE3EFEFE3EEEEE3E7E6E3EEEEE3E7E6E3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE2EAE1
DBCBB5E3D1BBE3D1C3E3D2C3E3D8C9E3D1C2E2D1C2D7C9B3C0C1B1D1B8A5D3AC9BCBAC95
CBB29DCBB29DCDAD97CDAB93C6A58EC6A58EC6A58EC6A58EC6A68BC6A48EC6A58EC4A289
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3ECE4
E3CAB5E3D1C2E3D1C3E3D1C3E3D1C3E3D1C2E3D1BBE3D0C2E2D0C1DCC8B2E4B9B0D3B39D
D3AC98D4AB9CD3AC9DCB9B8DC5A38EC5A893C6A48DC6A58EC6A58FCDAA93C6A792C3A088
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3ECE5
E3D1BAE3D1BBE3D1BAE3D1C3E3D1C3E3D1C3E3D1C3E3D9CAE3D9CAE2D0C1DAC8B2DBB9AA
DCBAA6DBB9A4D5AD9DDCB6A2CD9E90CD9F8FCDB3A5C6A48DCFA58ECEA58EC3A692C9AD94
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3F0F0E3F0F0E3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE6E6DEE6F2EB
E3D1BBE3D1BAE3D1C2E3D1BCE3D1C3E3D1C3E3D9CAE3D0C2E3D1C3E3D8C9E3D1C2E2D0B8
DAC1ABDBBAAADBBAA4D4B19CD4AC9ACDAA93CEA690CEB09DC6A58EC6A58EC5A58DDCCEC6
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EEEEE3E7E6E3EFEFE3EFEFE3F0F0
E3F1F0E3F0F0E3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFC7B7A7EEF3EAC9B4A8
E3D1BCE3D1C2E3D1BAE3D1BBE3D2C3E3D8C9E3D2C2E3D9CBE3D8C9E3D8C9E3D1C2E3D1C1
E5C7B1E5C2AADCB9A5DDB9A0D6AA98D6AC95CDA48EC6A58EC7A792CDA590C29F87DBDEDE
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EEEE
E3E6E6E3E7E6E3EFEFE3EFEF
E3EFEFE3EFEFE3F0F0E3F0F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE5ECEE94635781857BDBCAB3
E3D1BCE3D1C2E3D1C3E3D1C2E3D2C3E3D9CAE3D0C1E3D1BBE3D8C8E3CFC1E5D0BCE6CEB4
E6CFB7DCBAAADDBAA5DEB19FD5B195CDA690CEAA90CEA58FC7A68FCFB098CCAA92E3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EEEEE3E8E8E3F0F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE2EEEDA07C64C1C2C63B3C45E3D1C3
E3D2BCE3D8C9E3D2C3E3D8C9E3D1C3E3D2C3E3D9CAE3D8C9E5D1C0E6CDB8E5BAAFDDB9A2
D6B49DDEBAA3DDBAA1D5B7A0CEAA93D6AB93CDAA93C5A589C6A58EC6A690C5AB98E4F2F3
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3F0F0E3EFEFE3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFA27D65ECF8F4424A44DBCAB3E3D1BC
E3D1C3E3D1C3E3D1C2E3D1C3E3D1C3E3D1C3E3D1C3E3D8C9E4BEB0DCBCA8DDA99ADDA996
D5A592D5B59CD6B098D6B093CDA890CEA58CCEA58FCDA58ECDA58BC7A38CD0AE97DFD5CE
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3F0F0
E3F0F0E3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE5ECECD8E4E2444C46E3D8C9E3D1C1E3D1BC
E3D1C3E3D1C0E3D2C1E3D2BBE3D2C4E3D2C3E3D5C6E3D0C1E4BCAEDD9084DE8274D68880
D68378D68981D5A38DCFA48CCFA58BCE9C87C7A58ACDA58ECDA58EC6A287CDA08CC8AB96
E6F7F8E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EEEE
E3E7E6E3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF967C70D3CFCBDCD2C9E3D1C2E3D1C2E3D1BC
E3D1C2E5CFBEE6C9B0E4CBB5E3CAB5E3D0BEE5BEB1E6A99AE7B3A8DD816DD98E82CD786F
D57466D07464D68579C69080C6A08AC6A280C79F88CEA58FCDA58ECDA48ECD9F8ACDAC96
CBAF9BE3F1F1E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3F0F0E3F0F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFDED9D9DAD3C23E4F55DBCAB4E5D0B7E4D2BCE3D1BA
E3D0BEE5CDAFDFB99FDEBFABE6B6A2C25338F1C6AFDD9389D38E82C49084B17462CEA98E
D49B80C9756AC16854D37464C79482C7A383C69D7EC6A78CCCA690CDA48ECDA690CDA58E
D0B09AE6E8E1E3F1F1E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3F0F0E3F0F0E3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF9E857CABA5A5AF9D8CE3D1BAE4CDBBDCC6B1E3D8C9
E3CFBDE4B493D6A788BA493CEEC2BBC9716D652119D09D8BD18A79DBB0A2E3D7CBCE7167
B38671AD8972AB74628C543BCF705CC19C84C79C7ECCA18ECCAD97D4B295CDA48ECDAA93
CDA791D0B196E8E4D9E4F1F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE6EFF08961565C6465DCCBB5E3D1C2E2CFB9DBBBA8E3D1C3
E6C6AFE2AF87CD7759AB442E825B58C4C8BBE6DDD0E4E6DFE3E8E3E3E2DEE5D6C8DECFB9
E6D6C4D7D1CBAEA296866B62704939C2745DC9A58ACEA28DD4B4A0D4B29BD5B195CDA28B
CDA68FCEB2A0D0D1DDE2E6E6E6F2F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFC7B7A791665BCDBFBE364148DBCAB4E3D0B8E3D1B9E3D3BCE3D1C2
E4C4AED2A590AD896E98534D653F37D39A8DDDB8A3DFB6A7E7CCC1E7C7AEE7AF96D8927E
DFAA98DAB49DE5B99FC49E8DA78C7C713120C1816FC6A38DD5B69BDDBFA4D5AF98CEAA93
CE9F8BCDA994BEBFAFBCB9B3CCD2E1E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3F0F0E3F0F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE6EEEF5E493B5B4137404547AE958CE3D1B9E3CEB9E5C4ADE4C3AEE3CFB9
E4C8ADD69D80D6B9A5DBC9B3E3CEB9E2B8B2D9AEA3D0A89CD1A69CDA9590C99B90CA8177
CA776EC58275CBA18FC48470BB745E9A513F7C4437CD9B8AD6B79BDDC0A4D5AF93CDA28B
C7A68FCDAD96A7755DEFF4F6C2C1D1E4F1F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3ECEDB4BBBF013138283C44E4D2C2E3D0B9E3C9B4E2BAB3DBCCB5E3CFBA
E4B6ABD4A58DBD9780E4D3C5E3D9CAE3D1C2E3D2C3E3D9CAE3CEBFE4CFB5DCBAA5DDB9A2
D5B195D5A98FD09A87D68B80C47D71A96B5D8E58509A6358CFA995DDB9A0D5AF93CDA48B
C79E8ACDA791A6847476665CE6EAEBDBDEDEE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE1ECE8C8D1DEE2CFB8DBBAA5DDCBB4E4D1BAE3CAB4E3CFBAE3B9B3E3D1BA
E3CDB5D4AF98CE9E88DFC8B2E4D2C5E3D8C9E3D1C2E3D2C3E3D6C6E4B9AEDDB59DDDBAA1
D6AF94D5A890C8A080C79881C7A181C79881C79A81BF948BC5A182D5B29AD5AC90CEA38B
C7A587CFA58F815D5076715EC2BEB3E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE5F0F0E4EEE6E5D0B8E6CEB7E6D9CCDECBB2DBCBB5E3D1BBE3D0C2E3D1C3E3D8C9
E2CDBEDBC0A8D4A891CCA390DCCDB8E3D9CAE3D4C6E5D4C2E4D9C9E5CBB1DDB79FD69D84
D6B194C59C80B89B80BF957BBF9277BF9478BF8E74BE9C83CCAC96D6B098D6A790C69C87
C69F89C6A68B563E3B615F5DD7DBEDE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE2EEE8DBE1DEE5CBB1DEBEA5D3B69EC1C2C0E3CCB6E3D2C3E3D9CAE3D9CAE3D9CA
E3D6C6E2B9B0DCB79ED6A58FDDBFABE3D2C3E3D6C7E2BAB3DBCAB4E3CCB5D4B29BD4A891
C5937FC59B83BF8E78BF967BC09882C59C7DBA987FBC947CD6AA93D6AA93CDA48EC69C87
C69F87C7A58F6C493C524946C8C6BEE3F0F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3ECE5E5D1BAE4B899D6B7A3C8AE9ADBCAB4E3BBB5E3D2C3E3D8C9E3D8C9E3D9CA
E3D8C8E3D0B9E4BEA5D5B295D6A997E4D3C5E3D8C8E3D1C4E3D1C2E4CEBDDDB4A1D6B098
CEA58ECDA18ABE9177BF8D78C09883C59F8DCBA08DD4AC97D5B29CCDA590CEA48ECEA48E
C69E89C6A78DB8957652463D675750F5F8F8E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFECE6DECDE6A990DDBFA3C1967EDFC9B4E3BBB4E3D1BCE3D2C3E3D9CBE3E1D8E3D9CA
E3D8C9E5D1C0E4CEB6D3B39ED2B39ADBCAB5E5CFBEE4D4BDE3D5C7E5CDB4DDB79DCEA38C
CEA088C7A384C5947CC89878BF9582C5A08DD5AE9FDDB9A2D5B29ACDB098CDAA93C6A58B
C6A28CC6A994CCAA91AF8D715A3222433A32E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3E6E2E4BDAAD5937EC68477C2A191C1C3B5E3D1BAE3D1BAE3D2C3E3D9CAE3D9CAE3D8C9
E3D8C8E4D0C0DBC9B1DBC4AEDCCBB5E3D1BAE2CEB9DBBBADE3CEB7E4B8ACD5AB8FCE9A84
C69780C1947CC69A7AAD8D7BBC9482CCAE99D5B49FDDB9A2D5B19ACDAA93CDA28ECDA38E
C6A287CEA28FCDA585C79D88C1957DE2EEEEE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3F0EE
E3EBE4E4B2A4D4907AC7897EC2A896DBCAB5E3D2C3E3D8C9E3D1C3E3D9CAE5D9C7E4D9C9
E3CFC0E4D1B8DDC8B0E5C4ADDCCBB6E3D2C2E3D8CAE3D1C3E3CDBEE4BBA0D5AC94C69A83
BF957EB8917DB8937DBF9A87CDAE98D4B59FD5B9A3DDB8A0D5B29ACDA790CDA28CCE9C8C
CE9E8BC7A190CCAA96BE937BCBA794F0FCFCE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE6E4D1
E6C0A5D39E7DD5967BC1977FCAAE9BE3D1BCE3D2C3E3D9CAE3D8C8E3D1C1E4D1C0DDC9B2
E6CFB6E6BBB2DCC3ADDCBAA6DCC3AFE3D1C3E3D1BBE3D1C3E5CFBFE5B5A8D5A18BC69A83
BF957FBE9882B79F89C5A78DCCAE97D6B49DDDBAA5D5B29CD5AB95CDAB95CE9D89CE9C87
C69D89C7A98FCE9676CEA490C69E86C4C7C8E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE4CFB3
A96B47B17561865D51AF8E7DD4BDA9E3D1BBE3D1C2E3D1C2E3D1C3E3D1BAE2C9B3DAC8B2
DBB9AAD5B8A3DFBAA7DECCB4DDCBB4E4D2BCE3D1C3E3D1C2E4CEBEDDC0A5D5A190C79B80
BF937CC19883C6A08CC7A58FD7AD9BD6B29DD6B198D7B9A1D6B098CFAB93CEAA93C6A28B
C69C8AC7A090CCA383C2836ACFA690C48A71E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3F0F0E3DCD2
C082676D4F3F7C574E6D6766D4BDAAE5D1C1E4D2C3E3D1BAE6CDB3E8CFBBE5C1A8E7C2A9
E7C1AEE0AC9FD8AC99CFAC95DFC5ADDDCCB7E3D1C3E3D1C2E4CDB6DCB4A0CC9E83BF8E7C
BF957BBA917BC89E88CFA890D0A68FCFAE98D6A997CEA791CDAB95C6A48EC6A58EC6A28B
C69C8AC69F8EBE8366B66F4EC49372C48B7CE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE5EBE0E5D5C7
73332767423660473E6B6566D5BCA8E3D1B9DBCBB5E3D1C2E2CDB5CCAC94C8A286A07E6E
906B5CAB7257C58B7ACB7F61CC8163DCC5AFE4D3C5E3D1C3E4CEBDDCB3A0CC9F83BF9777
BF8B71B99A85BC9985B49E8BB59E89C6A38FCDAE94C8A791CDAC95CDAA93C6A28BC8A28B
C89E8AC69E8EBD876C9C634D9E6956BC8463E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE2EEEDE2E7DDDCB79D
A16D6243302B513A34495458DBC3AEDCC9B3E4CBB5E3D1BAE2D0BAD9BAA1AC9D8B8F7360
60453D644739806457AE7B649D6F6199675EDCC3AEE3CFC1E4CEBDDCB9A0CA987EBF9170
9F482FB99079C89F7CCC9F85C48F72D3A38AC69D8CBA9F88CFAB94CEAA93C59F87B89D87
B99D8AC6A088B57C66A4705AA37162B86A50E2EEEEE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3F1F0E3F0F0E3F0F0E3F0F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF8E4B3CFFEEDAE5C0A7
B07662503F4545342D544E53DDCBB4E3D1BADCCAB3E6D2BAE4D2BCE2CEBDCCAC97D4B09E
6C6F664E534D605B5170756FA48172CCAA96DCCCB7E3D9CBE4DDCEDCBFA5CB9B7EAF8670
A9775D7F554DA17A6A402624A26D599073608F634CB9907AC3926CCBA082C5A38CB89782
B99C87C0947F9868528B5D4EA6806FC18373EBF7F6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3E8E8E3E8E7E3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEF9764598D6458531F18C17B64
744C52513C334D3B3839474CDCCAB3DCCBB5E5C2AAE0C8ACDECDB8E2D0C1D9C6B1D0B09C
C3A38CC2A48EAA8B73AA8E76C2A78ED4AE9ADCC4B0E3D9CAE4D3C2DCBFA6CC9D82BE9173
AE866F9C7C6D938579423434493A317A5B5269564B715F50967E6D9A826BBE9077B89D87
B99E879F6B5D815D48714D3E876C5BCEA78FECF8F7E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3E6E6E3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF9160555D463A553A34513934
3E2A2A4D3A364C3933495255DBCBB4DCCBB4E1CDBFCB9D8FCE9F85E8C4ABE2C2A7D6AA95
C68873C28869CA9173CD8D70DDB99CDEBDA8DCC4B0E3D9C9E4D3C0DCB9A7CCA88EBF9374
B89C78C1947AC5A38DA78A7A2D474B64584D70655A55615C8E7B67B18D7AC7A487BD9884
B89C878F644C5E4039694B3C7B5948BE755CE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF9A6C554B2F274838304C362F
48363039312C5C4A455C5757DEC5AFE2CAB4DBCAB5E1CEBFC4AD9AAB8978B39281A6907E
8D7B6D816E638C7260947A6B977569C8B39FDBCAB4E3CFC0E4D0B7DCB8A2CCA493B6775B
B97658BEA17BC8A588C6A58CC4A48EB3957F9F7E6DA1816FBF9781C69C7FB89D87C8A587
C0997F5E473B483830595954765545AD5A43E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3F0F0E3F0F0E3EFEFE3EFEFE3EFEFE3EFEFAA826C522F2744332C3C342E
2C1F1F45342E5148436E6D67D0B8A3E4CBB5E3D1BCE3D1C3E2D0C1D7C4AFB7938A908684
BA9389A98574A88B7AA28274CAA693DCCAB5E5D0C0E6D0C0E5BAB1DCC0A9CAB09CB78D84
8E5E5287594691664BCD997ACBA78CCEA58BC5A487B89C87C7A084B89881C89D8FB79D87
9F6E5561433849443D54554BB36D518B6156F4FFFFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEF9B83795D463D46322C44342E
362D263B302B5548436C6C64B6A391DCC4AFE3D1BCE3D2C3E3D9CAE3D8C9E3D7C8E3D7C8
E3D8C9E3D8C9E3D8C9E3D8C8E2D0B9DBCBB5E2D8C7DBC9B1DCC8B0DBC3ACD3BAA6D1B8A4
BCA08E7E6A666F5F546950418A5D48BA816AB28D73C08C6DB4886CC19986A8927EC79A88
7E5044523931493A39563229964835885F525B524AE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFAA8D8466564F41362F45342E
44342D433837544843726A60BD9F8BDEC6B0E3D1BBE3D2C4E3D9CAE3D9CBE3E2DAE3E1D8
E3E0D7E3D8C9E3E0D6E3D9CAE3D8C8E3D1B9E3D1BAE4CFB7DCC2ABDCBAA5DCC3ADDCC1AC
DCBAAACCB1A1C09A8B8B7C706D6258695D50876B5B7E7A6B907A69947A6CC79D8BC49780
7B4E4249352F3F342E3B2F2855383275524A645A52E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFAB836D684F425D484141342D
492E264D3A3457463D706156A9937FCEB8A4E4D2BBE3D1BCE3D2C3E3D8C9E3D9CAE3E2DA
E3E1D8E3E1D8E3E0D6E3D9CAE3D8C8E3D8C9E3D1B9E4CEB5DCC3ADDCC2ABDCBAA5DCC2AB
DDB9A8D4B8A0CCB19AC4A48DB39E8AA28F7C947E6E97806EB6927FB79B87BE9084AB8065
734D4149352F4C39333C342D40332C5C473B7E7C77E9F7F6E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF9B79616C564D58443C523C36
392D2648332D4A362F6B51428B745DCBAE9BDCCBB5E3D1BCE3D2C3E3D9CBE3E0D7E3D9CA
E3E2DAE3E1D8E3E1D8E3D9CAE3D8C7E3D1BBE5CFBEE5C9B1DCBAA5DCC2ABDCC2AADCBAA5
DDB9A2D6B19AD6AC95CDAC97C6A48ECDAA93C6A58EC6A28BC89C87C89C8BC2947B866152
4A362A4F3B3B392E2D3D2F272B1F1F4F3A3475685FB8ADAEE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFAA836D61504764544D52423C
513B343F322C4D3F39574B46785F51A18871DEC6B0E3D2BCE3D2C3E3DACCE3E2DAE3E0D7
E3D8C9E3E0D6E3D9CAE3D9CAE3D8C8E5D1B9E5CFB7DCC2AADCC2AADCBAA5DDBAA5DEB9A3
DDB9A3D5B19ACDAC95CDAC96CDB19AC6A48ECEA58EC5A28BB79C87B79A84A7806B714C40
54443D3025253B2F302A1E1F352D2C3C302B695C5896837AE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFA38D836C564D64565060514B
523C363C2F274E3A34604E42736658837968CFB39FE4CBB6E3D1C3E3D2C3E3DACCE3E2DA
E3E1D8E3E0D7E3D8C9E3D9CAE3D8C9E2D1C0DBC8B1DDC1AADEB9A3DDBAA5DDBAA3D5B8A0
D5B29DD5B29ACDAC95CDAA93CEAB93CEAA93C7A088C6A38CB89780BB8C7798695366453C
3D2F273C30302E2425352C26322A2B473833271F16786D65E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3F0F0E5F1F19B847A65554E69595364544D
4D393252403A473C375846407C6352997C69C19880DDC5AFE3D1BCE3D1C3E3D1C3E3D9CB
E3E1D8E3E1D8E3E0D6E3D9CAE5D7C6E4D2C1E4CEB5DBC2AAD3BAA4D5B39DDDB3A3D5B19A
D6AD98D6AB9ACEA893CFAB93CEA58EC6A58EC6A18BBF9782C4937BB1836A7857465E4037
42352E3A322C3A322D342B253A322C4838343D2C24E2EEEEE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EEEEE2E5E58E746968524661524C685953
5F514A4C3E385648415A483C6A615999745FBD9884D7BFAAE4D2BCE3D2C3E3D9CAE3D9CB
E3E2D9E3E2D9E3E1D7E5D9C7E5D7C4DDCBB4E5C7AFDDB9A0DEBAA4DDB9A0D5B39DD5B39C
D5AC95CDB29ACDA993C69E8EC6A28BC6A38CC6A28BC49780B38B7191645770493D473830
3D2F27372E2E312626231F1F30262654484341322AECF8F7E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFA98D835D4A3D6C574E655650
604F475840395A493C5D4F496C5C4F866555A4846FCFAC99DCCBB5E3D1C2E3D2C4E3D9C9
E3D9C9E3D9C9E3D8CAE2D1C0DBC8B1DCC2ABDDC4AADDB8A0D5B298D5B49CD5B397D5B098
D5B29BCDAA93CDAA93CDA58EC6A28BC79A84C39880B38B719167597E584552393242352F
42342D352C2C3025262E24253E3430000000543931E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFBEB0A966534C6250476C5953
644F41594A4353403A6250475E4D467260558B6A59BF9982E0CEB7E6D2BAE4D2BCE3D1C2
E3D1BAE5D1B9E6D2BBE4D2C2E4CDB5DDBEA5DDB9A0D6AA93D7AC96D7AC9BD6B29BD6AF97
D6A58FCDA893CEA58ECEA58BC79F88C69A84BA8F779A6D597D5845533A32403128392E2E
42342E392E2E2A1E1F2F242645363245342CECF8F7E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFC0B1A276635C64565062524B
68544D533F3C56453E5749426556505D4B3E6F5648A4826CCDAA8EE0C9B0DECCB4E6D1B9
E6D2BAE5D1B9DCC9B2DDCBB3E6CEB5DEB49CD7AB93D6B093CDA38CCDAB94CEAB93D6AA93
CEA28BCFA28CCE9B88C7A188C49D80BA886EB18369805C48573B32473830392E26302526
302526241F1F221E1F413431483A3242332CE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFDADFE077615768595364544D
675A545F4C3F4F3B365D514B594B4369595259443C7761539C7964CC987DDCB79FE0BDA3
E1C3ADE0C8B1E0C8AEDFC3ABDEBCA2D2A78BCF9B81D19F81D0A38DCF9D87CF9D84CFA48D
CEA284C79A84C69780BF9078B590789E735F8959456C473C4D3830392E26312626302525
291E1F211E1F2B24253A302B3C3028442A19E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFDFEAEAA18E84624E4765554E
62524C5E5149543E3C5C473B64544E6358516758525B4D4775655A856A5AAB7A62C09685
B8937DCB9A80CFAA93CEA98EC99C86BD8B6EA4775EB18164C18569C89679C9987CC68C75
C38C71C68D6CBF8D74B18470A5715D8D5D486D443B5238303D2F273326262A1E1F211E1F
211E1F201D1E35302B443632322A22DBDEDEE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFD1D0D46C5A4F60544D
61565061514B42383155464268584F675A5472655E6C605A6B615875685E81695A856256
8160507F6055966753A27C67926E6086655B8E62508A6048946651A9765EAE7D61B47B5E
AC7C639B6A52A1715E9C6855855F4E67433A5F453C3E2F27392E26302525281E1F201D1E
1F1D1E38302B302A2B4D54503A2B23E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFDEE8E9866E6A61524B
65554E61544E5F514B514B4663585172655E6C5C55716058755A537F6353785D4C6C5A50
5F48416A524960403972564C745A50644F4860423B6649406642386D433A7D58447C5743
79554275483C6F453A69463C6642394B3A313D2F27362828302525302525211E1F201D1E
38303538302B524742161616937F77E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE2EDEDC6C2C865524B
61524B65565061524B6A5E58604F4771625B66544B695A537061576C565070544B685249
5C4C455F514B52403F5346405940395941394B383143362F4A3730533B35563B354E3830
4F39304F3830563B354B352F49352F3C2F27372E263025252E2425211E1F211E1F2B2425
3F39364C3936221A12433A32E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFDFE7E88A6B63
64565065565064544D594D4674645D655B55675B545A4B436E5548644D436150485D4D46
4E4045574B44584241503B3649383E43352F43352F392E263D342E3F342E43352F3D2F27
3326263A2E2645342E3D2F27332626392E26352D2C302525211E1F2E2425342F2B3D3835
443632312820312018E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE1EBECB3A1A0
66514A69595364544D6456505A544E6D5C5666544B59484157453E533A31574942513F3E
503F3E45363149383E3B2F30362727392E30372E2E312626362D2C312626382E2E312626
352D2C38312C362D2C332626221E1F221E1F221E1F221E1F342B2C302A252F2426432E27
3A3830322219E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFD8E3E2
8276705B4C4565554E625750655953685D57645452553E3752433C42363045342E453831
473530342728332627392E30352C2D2E2425362D2E302526342B2C302526443632221E1F
342C2D3B332E372E2E221E1F211E1F261D1E302A2B2F2A2B302A2B4738334A41373F4947
281B14DBDEDEE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
D8E3E282736C5B524C5D4D45685E58675D576F605A574C4656463F48363C372E2D45342E
372E2E3E342D38312C342B2C3025263025262F24263025262F24263A322E342B2C554D50
3E41413E3238312626352C2D342F2B342F2B322A2B49413D453C38473833635149463422
8B654BE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFD6E0E0826F69645C55594B43695D5673655E6D5F59594A3D54443E3E3330362D2E
332626362D26372E2E312626302526342B2C2E2425342B2C2E24252F25264D4B49473D46
656265615F5D4F454947464447403C3C332D493E39473D3960544D604F46322820704C3B
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE4F0F0E1EBEA82695D6F645D5F534D6A625C76686171645D57443B51423C4E4742
44403D3C302C3A322C352C2D342B2C2E2425302526393137352C2D38312C342C2D57504A
5C4E4E4636364E3F36483A344435354C38314A3F395A483C625A4F5B5C516A4634E3E7E6
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFD7E1DF7D695C65534B6A5A547C70697A716B73665F51413B4F3D3C
594139594F494B433D362D2D3025263F383D3C353B433F3B4139414D48453B3338504E4C
594F4D5F514A4A44414B433D4D47424D4C485146415F5B514238277E5940C8C4CCE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFD7E2E1716F5D5F5650695A537E6B64807B7B786D665E5854
5955555849475C56545E5B5A484B4B4540414F4954534A4C5E5C5C544D4C63534D544F4F
735F5767524D675245635650665A516B6358705849493E358B644AE3E7E6E3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE0EAEBB1ADB57268656C605A6C65667F8084867C77
857A73837C766964656568677A73787A6C64685D5B5C51575E4E486D5D5C6B5D57655650
755C50755D53745D547562576E594D86766C855F44553A28E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3F1F0E3F0F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFD7E2E361575E59584A6C6E76969190
8A8C8984837D87807A8B83808C7E77877B77746D68786F69676363625D556B645F746D68
6F655D80665A7C5B52887767785B485E37278B7777E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3E6E6E3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE2EDEDC6C9D4676476
8E8183ADAAB6948B898F827489807C8F838098837E97837C8E7F7897837B85776D897366
927C6E716B5B605644503C35B7AAB2E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE2EDEED2D4E6E0E2E3B5B1C47675877673836D675E6D62596D61586C605862574D
5A4733675C4AE3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0238095 0.732558 0.245293 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(315) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9BEA393
C09E8AC2A091C2A497C2A295C2A497C2A699C2A699C2A699C2A295C2A08EBE9B87BC9581
B78975B58572B0806DAE7F6CAE7F6CAE7F6CAE7F6CAE7A67A97860A77864A77860A77864
B9A49CC2BBB9C2BBB9C2BBB9C2BBB9C2B6B5C2B8B7C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BAB8C2BEBDC2BBB9C2BAB8C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BAB8C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9BFA596
BD9B8AC2A08CC2A49AC2A295C2A497C2A699C2A595C1A597C4A597C49E8DBF9B86BB957F
BB8B76B68571B1806CB1816EAE7F6CAE7F6CAE7C68AE7C68A97864A77862A77860A78171
B99788C2BBB9C2BBB9C2BBB9C2BBB9C2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2B7B6C2B4B3C2BEBDC2B7B6C2B5B4C2BBB9C2BAB8C2BEBDC2BAB8C2BEBDC2BBB9
C2BBB9C2BBB9C2BBB9C2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C1A695
C5A391C2A093C2A391C2A699C2A093C2A89AC1A38FBA9C8AC39780BD917FB88F78B38C78
AE8370AE7F6CAB7A68A77865AF7E6AAF7E6AAF7C68AF7862AC7867A77865A77864AD907F
AD9992C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BAB8C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2B6B5C2B8B7C2BBB9C2BBB9C2BBB9C2B7B6C2B5B4C2B7B6C2B5B4C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9BFA393
BD9E8CC2A08EC2A093C2A396C2A597C2A091BF9D90B09584A68C7CB58176AC7C6AAD7F6C
AD8574AD8572AB7C6AA97E68A77865A77865A77865A77864A97B65A57664A77865B9A49C
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2A596
C29B8AC2A093C2A096C2A093C2A093C2A090C2A190C29E92BF9A8BBC9181BE847CB4826E
B47E6FB27A70B37E71A56B60A67765A6806EA57460A97865A97A67A97C68A97D6BB69E96
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2A898
C2A08CC2A08EC2A08CC2A096C2A093C2A195C2A093C2A89AC2A699BF9A8BBA9280B98678
BC8979B98774B58172B77F72AB7265AE7669AB8579A77460AF7865AC7865AF8879B59B8C
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BAB8C2BEBDC2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9BDA79ECCC0B1
C2A08EC2A08CC2A091C2A091C2A195C2A093C2A699C29E92C2A195C2A295C2A090BF9882
BA8D7DB9897AB98977B27E70B27F6DAB7A67AC7D6BAC806FA97865A57865B5968CC0ABA4
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2B7B6C2B5B4C2BBB9C2BBB9C2BAB8
C2BDBBC2BEBDC2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9937A6EDFC8BAB58F82
C2A091C2A090C2A08BC2A08EC2A497C2A295C2A393C2A99FC2A597C2A597C2A091C29D8E
C1907FC1907ABC8979B78770B37A6CB37F6CAB7664A57865AC7D6BAB7665B39A92BDB0AE
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2B7B6
C2B2B1C2B5B4C2BBB9C2BBB9
C2BBB9C2BBB9C2BAB8C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9BAAEB05E2E28B59E8BBD9B85
C2A193C29D90C2A195C29D90C2A396C2A699C29E8FC2A08EC2A595C29991C1A18AC29E86
C49B89BC8C7DBA8979B8806EB5806AAB7B68AC7A63AC7867AA7D69AF826DBFAAA2C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2B7B6C2B4B3C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C3BBBA6A4335A98F905E4044C2A093
C2A391C2A597C2A396C2A597C2A093C2A396C2A99CC2A295C19E8BC49387C18C7EB78774
B88874BD8C78BA8C75B08473B17C68B37E6AAB7C67A67862A57865A97B68B59D95C5C8CA
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BAB8C2BBB9C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9724A39C8BBB55E423ABD9B85C2A091
C2A093C2A093C2A091C2A096C2A093C2A195C2A093C2A597BE8478BC8D7DBA7C6EBA7D6D
B57A6AB59177B3826CB3826AAE7865AC7B64B17867AE7865A97862AC7765B28C79CAC6C9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BAB8
C2BEBDC2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9BAAEAE96847E644A42C2A597C2A08EC2A091
C2A093C29E8EC2A190C2A18FC2A398C2A396C29D92C2A193BE7B72BA635AB8554CB9635F
B35950B96960AE7964AF7B66AF7862AC715FAC7B64AE7865AB7864A9725DAB7967B29080
CCDAE1C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2B7B6
C2B5B4C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB963443DE3C8BAC0A39AC2A093C2A091C2A091
C2A091C19989C49782C5A18DC29B8DC29C8BC1837EC27C6EC0847BB35142BC6C62B3514D
AE443BB24F43B36257A56C5DA77B64A77256AA7765B17867AE7865AE7664AE7664AE816E
BCA59DC2C1C3C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BAB8C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9AC99999881736B5A56BD9B8AC19C84C5A795C29D8B
C29C89BC967CBB8572C79E8FBF8172902C18E6AA97BA6059B36F65A26055984639AA8068
AB634FAB4E499B3F30BC5044A57864AA7758A9735DA97D67B07B66AB7464AE7B68AE7865
B79280CCCBCAC2C1C3C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BAB8C2BEBDC2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9674742BC998DA58072C2A08CBE9484C0A293C2A597
C29684B77B5FB1765F91241ED9ACA498312D711D15B26759B56252BD8D80BB8278AB4E47
91503C8958477E3F32722F1CBF5643A87E63AC6F59B07E6CB0816CB28068AB7665AE7C68
AE7D6AB79C94CABBADC5C1C0C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9BDB4B7502A249D8476C09E8DC2A091BF9784BD9184C2A093
BF8A76B17755A84A36771C0F9B655FB2AB9CC4ABA2C5C4C1C2AFA9C2B0ACBC988CC2B0A1
BF9B8AB0A09D7D5953613A35582318B95B43AF826AB6806BB78A79B2806CB07E68AE7360
AE7D69AC9690B2A3ADC6BFC6CCC8C0C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9937A6E6A3E38A7868366524EBD9B88C29C87C2A18BC2A694C2A093
B98170A97561925442731A1B712927B47566BA8676C09487C7978DC09C84C07966B96D5D
B97C6CBF9F88B87D699D72677552475B0F05BF7462B1856BBA8F7BB78972B07D6CAC7967
B17765AB8574A69C979B8689BFB8BCC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BAB8C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9BDB1B3351C153F1D1889645EA2796BC29E8AC29687C1987FC59986C2998A
B98C72AF7057C5A494BD9D88C29486BF857FB77E74B2766CB57069B26460AB655EAA4F49
AA4C48A66155AD6C609F594B9049386D261C792B20C08D76BD927AB78B72B07B67A97562
AC7D69AE83707C4D3CE8E6F1AC9CA5C5C1C0C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9B4A5AA6F5A5900020F514346C5A393C29B87C29588BF8983BDA48AC29789
B97D72AB6E5AB08673C5A99EC2A699C29D90C2A396C2A699C29689BE9980BC8C79B78771
B5806AAE7761B2685DB15E559F4B45863A33762E2C91503EB98778BA8971B07B67A97660
AC7464AE7D6A69473F987D75CCC3C5BDB0AEC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9B9A8A5B2A0A5BF9884B98A76BF9C88C5A08CC29B8AC29788C29288C29D88
BB917BAF7665B17865C5A995C5A79DC2A396C29D90C2A497C2998DBE847ABA836FBA8E76
B17D68AC7865AA7157A86E5AA8755AA86C5AA56E5AA77165AE7B62B5836DAE7A63AC7762
AA7B61AF7A694F2D27A28F88B3A395C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C1B8B7C5AE9DC19C89C29D88BDA9A2C79C81BD9E8CC2A190C29E92C2A195C2A396
BF9184B68B74AF7361B48775C0A797C2A99CC29B90C1AA95C5A897BC8E7ABA826FB1705A
B1876CA06C569D7057A16855A36A509E6652A1644EAC7C68B0816EB3806CAE7663A7715F
A77762A97B652C1316978281C8C2CFC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9BFAEA5BDAAA5BC917AB88B74B49484B0908EC2A48FC2A497C2A699C2A699C2A699
C2998DBF867CB47F6BB87A69C3A394C2A497C2998FBF8E84BD9B87BB8E7BB2806CAD705F
A66D5CA06855A16652A16C57A6705AA66F55A06E58A6705DB37A67B37C68AB7664A56F5D
A77761AA7A69391A16523935E0D9D4C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2A898C19E8CB57B62BD9785B28375BD9B88C2918DC2A497C2A89CC2A394C2A699
C2A292C29A84B9846FB58068BD8D80C5A69BC2A595C2A198C29D90BE9384B57F6EB3806C
AC7865A96E5DA0664F9E6253A67260AE7768B17A68B27F6CB0806EAE7665AC7664AC7664
A77460A97D68734D3C391F1D5C433FFBFDFDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2B4AEBF9E8DBD7764B38D73AB846FCA9888C29188C2A091C2A497C2AA9FC2ACA2C2A699
C2A295C19E8BBE9380B48572B88C77BD9B8AC1998BC5AC96C29D95BC997EB57F6CAC7764
AA745FAA775BA06653AB6C53A77362AE796ABA8677B78774B0836FAE806CAB7C68A57862
A97564A98571A4715B8354434A211E61433EC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2A098B9806EAB5E4FA76A5BAC8879B0998CC2A18DC29D8BC2A497C2A699C2A699C2A597
C2A595BE9B8CBD9581B99884C09E8CC2A18DBF9483BD9182C29382B98476AE7560AA6E5B
A36A57A46B54A26C549A6959A67060B08371BA8775B78774B0806DAE7A67AE7565AB7764
A7755DB18071A76E54AA7565BAA29ABFB7B6C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2B6B0
C2A69FB9736AA95D4DAC6E63B38F7DBD9B8DC2A497C2A396C2A093C2A89AC1A594C5A89A
C2998EBEA187BF9580C19984C0A192C2A393C2A59AC2A093C29487B9856CAB7966A36C59
9E6856986857A16A57A77565B38471B78A77B58976BA8673B0836FAE7663AE7564AC7164
AC7462AC7D73A8715FA06D59B59A94D4D5D3C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9BF9F8A
BD8A75A46B52B36B54B5826CB8907EC2A091C2A396C2A89AC2A595C29E91BE9E8EBF9785
C29986C48F85BC957FBC8D7BC09989C2A093C2A08EC2A093C19589BC7A6FAB705FA36C59
A16A58A0705E9E7762AE7D6AB0846FB88874BA8C79B5806EB07C6AAE7A68AC6F5FAC6F5D
A77362AC8571AA6046B18877A57262B9C6CEC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9B78369
773C248D4E3F6B3931C08E76BE9A89C2A08EC2A091C2A093C2A093C29D88BF9884BA9282
B68476B58676BB907CC2A28CBF9F8AC5A394C2A093C2A091BE9689B5876FAC6F63A57055
9F6756A87260A97967AC7867B68373B98574B3846EB68B76B1806CAF7E6AAC7C68A77260
A77164AA7B6BA5684EA96752AF7263B99E92C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2B8B5B68A7E
8046334F2A205E322E987467BE9A8AC19E91C5A396C2A089BD9682C5A08FBC8E7AC39681
C19082BE7D73B9856FB48570C09E88C3A494C2A093C2A090BE9180B27D6BA56B58A16453
9C6A57A26957A87865AE7B67B47D69B48473B17768B17D6AAB7C6AA57664A77865A77260
A77164A7776591513A99492FB17054BCA1A1C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C1A99BBC938A
470E09482019492722A47B6DBA9582C29E8ABD9E8DC2A091B8917EA277649D6E587B5349
6F443A924D36B26D5CA8553DAC5D44D2B7A1C5A69BC2A093BE9384B27A6BA56D559F6B50
9C5F4DA475639F70609772619D7260A77969A77E68B2806CAE7F6CA97A67A37562A87562
AD7464A774658C4F3C803A2A954D3BB7A295C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C3BBBABC9B8BB27D6A
5E322F2A100E3F1A188F786BBD9684BC9783C59E8AC2A08CBF9A89A77A668F6D605B3D32
411F1C52271C70493F9B513D8E4F43986256C09B8CC2A094BE937FB27C699F66519E694B
762111B27E65AA7656A774609E634BB97E6AA37364A67963AF7E6CAC7C689E6F5C9A7361
A47364A3745E86483A8D49379B5246B58C80BFB7B6C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BDBBC2BEBDC2BAB8C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9612119FFD0B4BC8B77
703C32301A223114119E796CBF9C88C2A08CBC9986C4A18CC5A394B8907FB07C6C956C61
4D3A383B2725523B3471554E996356B48C79C0A696C2AA9FBEA08FB2826E9F664F8E5C4A
7C403174433D7C4F412606088F4D3A7B55456E3D2BA6705CA46949B57A5FA077659A6D5C
A471619565546C392C763B30AD6E5CBA9693C5BDBCC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2B4B3C2B8B7C2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB968352F5F342E480300A85F49
4D242D341A163A1A1A887166BC9986C09E8CBA8874BE9D83C7AA9ABF9E8FB78C79AA7867
A1725E9E715E8F5E4A996C56AC7C6AB78876C0A192C2A699BE9586B28671A5675099664E
905546825B536D514B1E0C11451F17623C364A2E2771463685594991634D9C6553987361
A4745F6E3B355D34255D2B209B5846C5BDB4C8C0BFC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2B2B1C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB952252146251D3D1615401D1B
23090D3B1B193B19178F7568BD9C88BC9C8BBC8E86A56C5EAB745FC69C85BA947DAC796A
9E5C4BA26348AC6950AE684ECA9E84C29683C09C8DC2A897BE9587B28777A5705B9E694C
9A7152A86F5BA271616748432820264E302B553C355C474081574496695AAA765D9E6E5F
9A715D5B3124431E1B582A1F893D2DBEA198C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9592C21330F0C301814361613
2F14122712114A2A2890685CC79E89BF9B88BD9B8DB994859B6F5E8C574B8963568F6354
6D4B406C483F75483B875749926659B28C7CBD9B8AC2998BBE9C82B28471A56C618D4A33
975238AC855EAD7B65A77864A473638E6251815247935F4E9F6B58A7715C9A735DAD7B61
956855361C173017136F463D692E23B99088C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BAB8C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9653A2F350D0A2D1311281411
170105311512442C298C695BC39A85C5A18DC2A091C2A195BF9B8CB08475905F5B855B59
9A5F558F584A8C5749935A4DAE7F6FC0A091C19B8CC4988EC18B81B48B78A7786C8A514C
67302A6C3A2973432DBD795CB5846CAC7860A2765F9A715FA5715B976C5AAD75699E735D
6E3E2E3C1C173523217043358E402C714E47F8FFFFC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB95C3D38401F1C2F12102E1411
200D0A2B1110462C29856052B18C7AC09C88C2A091C2A497C2A699C2A89CC2A496C2A496
C2A394C2A89CC2A394C2A393BF9A84BD9E8DBFA292B99581BC9580B9937FB48B79AD8172
8A5F555E38364B312B562E236F3D2BA05D49916851A06349965F49AB7666956A59A56E5E
4D231E361713361B1E49140E7E2618633E38998A87C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB965433F4C302D271311301411
2D131131181B452B277F5949B78975C7A28EC2A08FC2A398C2A99CC2AA9FC2B1ACC2AEA6
C2AAA0C2A89CC2A99DC2A699C2A393C29D87C2A08CBE9682BC907DBC8C79BC9682BC8E7F
B4897AA87B6F91625866474151353058362E6C463A7555487753468B574FA575629F6855
4A201C3014122A1412260E0C4519165F37329E908CC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9683E324E2C233E22202C1311
340E0B381A1946282068473CAE806ABD9C88C5A38EC2A091C2A497C2A89CC2A699C2B1AC
C2AEA6C2AEA6C2A99DC2A699C2A595C2A597C29E87BE9682BC9682BC907DBC8C79BC907F
B78979B28673A8806D9F7362946F5F825D4E7B534786594A996A5C9C6D5D9C675B80513C
49231E3014123719172513112F13114D2A219C8C8CD5DAD7C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB95C362953332E3C201C3A1A18
230D0A3414123516135E34288B5C43C79F8CC0A18DC2A091C2A497C2ABA2C2AAA0C2A699
C2B1ACC2ACA2C2ACA2C2A699C2A28FC2A08FC19989C19481BC8C79BC937FBC907DBC8C79
B78774B3806DB37F6CAB7F6CA77664AE7C68A57865A37260A87161A871629B65515B332C
2D120D391B1E240E11260F0C170105411D1980615AC2B8B9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9653C30492E2A492E2B3A1E1C
3818162A1210381E1C4A2E2A6B4133B18067C7A38EC2A394C2A396C2ADA1C2B1ACC2AAA0
C2A89CC2A99DC2A699C2A699C2A292C19E87C19985BC907DBC907DBC8C79BA8C79BD8976
BA8976B0806DAE7F6CAE816EAB806DA77664AC78659E72609E715F956E5B7B504149231D
39211E1B060A250F13150005210D112D12106F504BB39F9BC2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB962433E51322D4D322F462B29
3A1917240E0B3D1B19512F266846398E6450C09B88C5A18FC2A096C2A396C2ADA1C2B1AC
C2AEA6C2AAA0C2A394C2A699C2A295BF9D8BB9927FBA8E7ABD8976BF8C7BB78C76B58673
B58574B0836DAE7F6CAE7C68AC7E6AAC7C68A5715EA577649A6A57905E506D3C2D441F1B
250F0C250F131B060A200D0B1F0C10371917654C46816560C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BAB8C1BBBA5C403B4D312E5236334B2F2C
3316133A1F1C351C1A452723774736945F4CB5846EC39F8BC2A091C2A195C2A195C2ABA2
C2AEA6C2AEA6C2A99DC2A699C1A090C5A190BE9682B9907DB48977B58372BA8576B5806D
B38171B37C6DAC7868AF7E68AC7865A77865A5705E9F6D5C9C6350885443512C22411C19
2814112612112512111F0C0A261311381917958480BFB7B6C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2B7B6BFAEAD51332F542F27492F2D503532
432927361D1A41262345261E65483F8B523FB7816DC0A18CC5A394C2A396C2A99CC2AA9F
C2AFA8C2AFA8C2AAA0C1A594C1A08FBF9C88C18F7CBA8973BD8C7ABA8973B58574B58370
B07F6CAE836FAB7767A57465A77562A77764A375629C6A578E5B476B3A334C231C2E1713
250F0C230E121D070B0F01051E080B4C2B278C7E7AC8C0BFC2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB963423E47271E5334304E3330
452A263F1D1A47281F472D2A5D4035703F32A56E58C09985C09E8DC2A093C2A398C2A897
C2A89AC2A89AC2A59ABF9D8BB9927FBC937FBA8F79BA8973B58571B58870B5856FB5806C
B08571AE7C68AE7C68A97865A77260A56E5B9A6C598E5D496B3C345B31243616142B1512
2D1311200D111B060B19060A2F161545282868403BC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9765A56482A274B2E29563633
4829204026243D1F1C4C2F2A482C275C3B3488503EB7866DC8AA97C4A18CC5A391C2A091
C2A08CC19E8AC4A18FC5A393BE9480BA8B76BA8973B37A68B68170B68171B98571B37D6A
B37A67AE7868AC7B65AC7862A56F5EA36E5B91624F74403259302438181428100C240E12
2F1411220E111500051B060B381917998884C8C0BFC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB97C60575337344D322F4B2E2B
4E2F2B391C1D3F231F4328254E333047281F60362B9D6C54BD8D73C39E87C2A28CC4A18B
C4A48EC19E8ABC9783BF9D88BF9682B87F6BB6806AB38068AE7764AE816CB17E6AB37C68
AC7562AF7564AA705FA576609F6E57965C488C59435A31253B18142E1713230E0B1B070B
1D070B1001050F00053316153B1B168F8181C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB995807D4D2E284F35324B2F2C
52373443251E3819194B322E42282452353141211D6C483A865745B8765CC79881BB8E78
C19A88BE9985BE977FC09681B68772A7725DB0715BB4765BB17967AF7361AF705BAF7B67
AC755AA56E5FA36A579C65528F65527945386933244A221C331612230E0B1C070B1B070A
1500040D000419050A2C1311643F37643E34C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9B3A2A563443F4528254D312E
4C302D432C273A1B1D4A291F4B302E5137334B302E482D295F423A77483A975B459C6E62
976D5AAE725AB0846EAE80689F6C5B965E4686503B995D42A6604AA96F55AD6C56A26452
A0624AA663499D64508C594B8149396934264E201B371713250F0C1D070B1500040E0005
0E00040D0004241110341716887975BDB0AEC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9897474462A244B312E
49322F472C2A291513452825543732523734593F3B543A37573E3760433B684337683D36
653B2E673C357E46358558466E443C6B4038743D2E713D287A413290553E92573F90523B
8C54407D4331834D3E79413365382C491F1B44221E250E0B230E0B1B060A1400040D0004
0D00042811101D0C105A413D725F5CC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9A49498513130492E2B
4C312E4A302D432A28412A285137335B403C533733583B375E3731683F325A372B503530
45252153312C471E1B5B363057352F4B2C2849201C4D28224D211B57241D633626603324
60332458241E55241D4E241E4B211C30181427100C1F080C1C070A1B070A0E00040D0004
28111A28110F3E27255D434392716BC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9BCB0B37F6568412522
4A2E2B4E3330492D2A573D39452A265D403C492D295337345E3D3553312E542F2A4E2E2A
4228244E302E371B1E3F2823421E1B411F1C3317142D16133416133F1B18401C18361813
381814371713411B18331512331513250F0C220E0B1B060A1B060A0E00040E000419050A
321C1C36181852373261433EC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9A6959655312D
4B33304E33304B2F2C432C285B3E3A533A3649322F4428245C3429462824492D29462A27
351E26442C263D1D213B1C1932171F2D15122C1512230E0B2914122B14122E1513260F0C
1E070B250F0B321512250F0C1E070B240F0B210D111B060A0E00041B060A21100F2D1919
33171656383356322DC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9B9AAAC704F4F
4829275236334B2F2C4B322F47322F573935492E29402521422420381814442925391D1F
381D20301614331720260F1220080C250F13230E111C070B220E111D070B230F121C070B
210D11251210220D111D070B0E00040F00050F01050F0005200C111D0B0A1B060B32100C
5E4440593934C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB99C8784
5032303F25224D312E4B34314C3532533936482D2F3C1B183C211F2A14123215132D1715
3215141E080C1F080C240F13200D111B060A220E121B060B210D111B060B3418160D0004
220D12271311220E110E00050E00041300041D0C101C0B0F1E0C10351816361F19412C2A
68585BBDB0AEC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
9C87844D2F2C402C29452926543C385239365439373B25234124212E141C220E11301411
220E112813112411101F0C111B070B1B070B1B060B1B070B1B060B261311220D113D2B33
2D1F202910181B070A200D1120100F200F0F1E0B10392221301A1A35171659342C6B4839
8C604FC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB99C837F4E2E2C48322F422824523A365E423D4F363341251D39201F261212220D11
1D070B220E0B230E121C070B1B070B200C111A060A200C111A060A1C070B3C2D2E351D2B
544242483436341E25372525311C1C251210351D1C361E1D4B312E4E2B255939347C5247
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C5BEBDA18986512D27513B39472F2C59413D5C413D563B363A1E1B391F1D3A2524
2D1C1D27100F251211200C111F0C101B060A1B070B26121B200C10241110230F13422E2C
4C2F302D1518361D19331B182C141734171439201D45261E5B3D34624947805749C2B5B4
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9997D76502E27462A27563A36684E49614B47523834371D1B391D1F
411F1B432C2933201D200C101B070B2C182128151C321F1E2A16213E29262210194A3531
422A2B42292736222235201D3824233F2B283B22225B3C325E3E337D4C3FB29EA3C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB999847D49291C3E26235337346448436454575C3F3A473030
462F303F23254232324834383726252F1B2038263440282A4A383E422A28442B2A493334
5637344F2D2C4F2E264A32305438316043384D2F2674554C8C5C4BC2B5B4C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9B6A6A97D5B5E462B2A533A3453434A735E5F6B524F
69524C624C4A533F43554346634D50573E3B51393B442B33482D2C5337385439364E3330
60372E5E38325C39325F3F3957332B7A59527947306C4338C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BDBBC2BEBDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB99984874C222540231E4F3D44806966
76656468534B6C55516E57567055506C504F5F4742594241543B3C4A353159403F5F4542
583B356840385E35308A665C6A36235719108C6B6BC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2B2B1C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9BCB0B38F76835F3C49
7F5B62896B747E584F6B483E654C47775B5A7A58517859547658537758516B50496F4C41
7254497F655B491E125C2D2CA78D92C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9BCB0B6B8A6B1B6A1A78A6C7E634457603D465B352E5B352D5B312A582E27502217
4A1A0A77574BC2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0238095 0.97619 0.245293 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(338) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EA88470
B08E7CAF8D81AF9386AF8D80AF9386AF9385AF9385AF9385AF8D80AF8D7AA88875A98370
A27765A379679C73619D74629D74629D74629D74629D6E5C976F58986F5E986F58986F5E
B3ACACAFA29EAFA29EAFA29EAFA29EAF9C98AFA39FAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA19DAFA7A3AFA29EAFA19DAFA7A3AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA19DAFA7A3AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAA8672
AB8A7AAF8D7BAF938AAF8D80AF9386AF9385AF9180AC9285B09285B08D7CAA8976A78470
A87B68A579679E7361A177659D74629D74629D715F9D715F976F5A986F5B986F5898786B
B39A90AFA29EAFA29EAFA29EAFA29EAF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAF9E9AAF9D99AFA7A3AF9E9AAF9F9BAFA29EAFA19DAFA7A3AFA19DAFA7A3AFA29E
AFA29EAFA29EAFA29EAF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAC8873
B39182AF8D80AF9181AF9385AF8D80AF9487AC8E7AA38979B38771AB8170A3826BA07E6C
9D75649D7362996D5D986F5D9E74619E74619E715F9E6F5A9A6F60986F5D986F5AA19188
A18D85AFA29EAFA29EAFA29EAFA29EAFA29EAFA19DAFA7A3AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAF9C98AFA39FAFA29EAFA29EAFA29EAF9E9AAF9F9BAF9E9AAF9F9BAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAA8470
AB8E7EAF8D7DAF8D80AF9184AF9183AF8D7EAA8A7D9A8373977A69A4706797705B9B7462
9B796A9B796799705E97745F986F5D986F5D986F5D986F5A9A715E946C5A986F5DB3ACAC
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAF8672
AF8A7CAF8D82AF8D84AF8D80AF8D80AF8D7CAF8F7FAF8B7FAA8675A97D6FA8736AA27460
A272649F6D64A17164916055966F5D9677659469559A6F5D9A726097715F9A7462AEA3A3
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAF8A75
AF8D7BAF8D7DAF8D7BAF8D84AF8D80AF8F82AF8D80AF9487AF9385AA8675A77E6EA57568
A97A6CA57766A37667A26F6499685A9D6F6299796C9869559E6F5D9A6F5DA38375A9988E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA19DAFA7A3AFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EA68E84BCAA98
AF8D7DAF8D7BAF8D7EAF8D81AF8F82AF8D80AF9385AF8B7FAF8F82AF8D80AF8D7CAA846E
A77C6EA57A6CA57A699F70649F7461996E5C9A75659A73639A6F5D946F5DAC9792B09D95
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAF9E9AAF9F9BAFA29EAFA29EAFA19D
AFA5A1AFA7A3AFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E7D6A5ED7B6A6A98576
AF8D81AF8D7CAF8D79AF8D7DAF9386AF8D80AF9181AF978DAF9183AF9183AF8D7EAF8A7A
AC7D6DAC816CA97B6CA27863A06E61A07462996C5A946F5D9E7462996B5AAA9F9EAB9B97
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAF9E9A
AF9A96AF9F9BAFA29EAFA29E
AFA29EAFA29EAFA19DAFA7A3AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EA395944A2D26D3B49DAB8A74
AF8F83AF8A7DAF8F82AF8A7DAF9184AF9385AF8B7AAF8D7DAF9180AF867FAC9179AE8D78
B08979A97E6FA77A6CA37361A3735F9971609A6E599A6F609B75629E7663B6B0AFAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAF9E9AAF9D99AFA7A3AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EB1A49F573D319A7E7B725351AF8D80
AF9181AF9183AF9184AF9183AF8D80AF9184AF9789AF8D80AC8B78B07F76AC7E6EA27866
A77C6AAB7E6CA77E699C7566A2715FA0746199715C966F5B946F5D9A7160AC9F9BB3B5B5
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA19DAFA29EAF9F9BAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E624637B29F976E4E42AB8A74AF8D81
AF8D80AF8D80AF8D7EAF8D84AF8D80AF8F82AF8D80AF9183A87266A98171A77364A77665
A37463A3896FA07661A076619D6E5C9A725CA16F609D6F5D976F5A9E6E5FA28776BDC2C8
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA19D
AFA7A3AFA29EAFA29EAFA29E
AFA29EAFA29EAF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EA39591705A4F76594DAF9183AF8D7AAF8D81
AF8D80AF8B7BAF8F7FAF8F7FAF9188AF9184AF897EAF9182A8675EA75D53A35248A8615C
A0564CA8695E99715D9E745F9E6F5A9A69589E725E9D6F5D996F5A9A6856997260A68E81
BCCCD5AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAF9E9A
AF9F9BAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E523E37ECCBB8B09188AF8D82AF8D7EAF8D81
AF8D7EAC8576B08774B3937FAF8A7EAF8979AC726EAE7366AA786F9E4C3DAC695EA44C49
994037A25145A0615694695A98755E98684F9B6F60A16F609D6F5D9D6B5A9D6F5E9D7765
B2A7A4AFABACAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA19DAFA7A3AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29E948280756255846E64AB8A7AAC8972B39787AF8A7A
AF8975A6836CA77767B99788AA74667C3320DFA594A7564EA16C618E53468A4334977963
9757479C4C488B3F32B152469578639B6E519A6C599A7560A0705D99695A9D71609D6F5D
A98D7DBCBFC0AFABACAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA19DAFA7A3AF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29E523D37C59C899F7B6DAF8D7BA87F70B0978AAF9183
AF826F9F6B539E6B59812D26CEA99F7C1E16772C219F5446A45846AB8474A45F54964A41
7E412B784D3E6B392D6D3524B95C499C7C609E6654A07866A076629F725D996C5D9D715F
9D7462A99A99B9A999B3ABA7AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EA69A9B3C2720C3A18BB08E7FAF8D7EAA8171AB8479AF8D80
AA776399684B974838622318AA7C72A7A495B09A92B3B7B4AF978FAF9C97A68276B1A79B
AA85759A8D8B64433C51342E55291FB76249A37D67A97B66A67D6F9F725E9C705D9D6958
9D75629A9191A3949AB7B0B7BCB5A7AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29E7D6A5E61423C94756F816B5FAB8A78AF8976AF907CAF9585AF8D82
A26B5C9369548346375D0F0F77302DA26E5DA77969AF8D80B4877BAA9078AB6D5CA96D5D
A57464B09F87A06C5A8A6A615D473B591C12C07E6AA58166AA8573A277639C70619A6E5C
A16E5E997E6E98908F89757AB6AFAAAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA19DAFA7A3AFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EA697962C211A3D2721B283769A7464AF8B79AF8375AC8A70B38B79AF8679
A2775F9B6851BAA193AB8C78AF7D72AA746CA36E639F665BA45E579C575399564F97443E
9746439660539C60558C56497B49395A2A217D392CBA9278AF8974A27B639C6D5C976B5A
9E75629D7A676D4E40E4E0EE9F8F92B3ABA7AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29E9A868A47332B00000A685855B39181AF8875AF8278AA7A73AB977CAF8177
A26A5F945F4DA98977B3998FAF9385AF8A7DAF9184AF9385AF8374A8866DA97E6CA27863
A3735F996B57A25D559E564C8C433D74342E6B2E2A8E5943AD8174A77B649C6D5C976B58
9E6C5E9D7462503C35AE978FBCB1B2AB9B97AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EA18A87A48D8CAA8370A57B67AD8C79B38D7BAF8A7AAF8176AF8678AF8A76
A47A669B6656A17260B6A18EB3978EAF8F81AF8A7DAF9386AF8176A87368A77663A7826C
9E705E976E5C9C6851986856986E569865569566569B6D5EA1745EA37661996D599A6F5A
9B725B9E72623E2E29BCA9A6AA9B8AAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAC9F9BB3927CAC8979AE8D7AA79792B98C6FAB8E7EAF8F7FAF8B7FAF8F82AF8F81
AA7C6EA17A629B6555A68472B09A8DAF9789AF857BAC9B86B39484A67967A772619E6853
9E7D648E624F8F695192615195644C8E5E4E925F4AA27967A07765A073619A6A59986958
986F5B9A715E231A1BB9A2A0BEB8BFAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAA9287AB948CA67D67A37B66A28B80A5817BAF9782AF9386AF9385AF9385AF9385
AF8176AA756A9E6E5BA77262B49C8FAF9386AF8178AA8073AB8A76A478669F725E986252
9667578E5D4C92614E926753986A5496664F9266519A6C59A06E5CA0715F996B5A946656
986F5B9B72622A1E1B5D4942EDE6E3AFA7A3AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAF8A75AC8B7C9C6954AE8F7FA4786CAB8A78AF847EAF9386AF9589AF8E7EAF9385
AF8D7BAF8670A2715DA3725DAE897DB3958BAF9180AF8F86AF8A7DA87E6FA06F60A07361
9A6F5D976353915F498E5C50986C5BA16E60A273609F73619C72619D6B5A9A6C5A9A6B5A
986C599A74604F393034262460514BFEFFFFAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AF9A91AA8774A76E5D9D8066A08573BD8678AF8478AF8D81AF9386AF978DAF968BAF9385
AF8D80AC8B78A87E6CA27764A8816DAB8A7CAC8679B39D89AF8982A6876C9F6F5F9A6F5C
976B599B6E558E5F4E9C65509B705FA17163AA7C6DA278669C76649D736199715F946F5A
9A6B5C9A7E6B8F614D6C483A422927725750AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AF8377A26D5B965447986C5B9F8677A58B7EAF8F7BAF8A7AAF9386AF9385AF9385AF9183
AF9180A88878AB8370A58977B08E7EAF8F7BAA7D6EAB8474AF7E6FA27465996755976655
92635196664F91634F9164559A6C5CA07867AA7B6AA278669C73619D6E5C9D6B5D996F5A
986B56A17B6C94614A9B6F60B5AFAEAA9E9AAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAF9C94
AF8881A260589353469E6E62AA8B79AB8A7EAF9386AF8F81AF8D80AF9487AC9281B39488
AF867BA89176AD8371AC8B77B09286AF9181AF9187AF8D80AF7F71A2755D966D5B916352
8E61508962529664529B6F61A47967A67E6DA37B69A779669C76649D6B599D6B5C9A695C
9A6C5A9E776F95614E916755AB9D9DC4C1BDAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAA846E
A77B698F634DA36651AE836EAD8A78AF8D81AF9184AF9487AF9180AF8B7FA88B7BAD8777
AE8676B08277A98670A97E6EB08B7DAF8D80AF8D7DAF8D80AC8074A6685D966555916352
926453916A59926F5BA17463A07965A77C6AA77E6CA372619C705F9D6D5D9A66569A6656
986C5B9E7E6C97563FA18575946A5EB3C9D3AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E9F684F
653C28805041653F36CA997EB19080AF8D7DAF8D7EAF8D82AF8D80AF8A76AA8773A77E6F
A17364A37969A78571B29580AD907CB39185AF8D80AF8D7EA88376A0755F97645995694F
8F61519C6C5B9A72609F6F60A57A69A8796AA07964A57F6C9E73619E74619A715F986858
98695E9B75659159439D69569E665AB3AFAAAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAF9F999D6A5A
5F3A2B483027573732B18875B19081AC8B7FB39184AF8D77A68373B29181A7806EB28B78
AE8376AC7369A87D66A57D69AF927EB49789AF8D80AF8D7CA87B6C9B6D5B906051925F4E
8C64539664539972609F715EA67562A5796A9E6B5CA1746299705F946C5A986F5D986858
98695E986F5D7D4B378D4C34A86F56B7B4BBAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAC8D7EA67C73
3B1913442A2249302AC5937EAA8A77AF8B79AB8E7FAF8D7E9F7A698D6A598963506E5147
68473D8C503AAC6F5C99543F9F5F47CCB8A2B3958BAF8D80A87E6F9B695B90634C8F644C
8B594B9A705E90685989685890695998716294735EA678659D7462976E5C926B5A996B5A
9F6C5E986C5D744536763C2D935340B4BAB6AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EB1A49FA67B679C6C5D
422C29291C18412622B89882AB8776A98573B38E7CAF8D7BAA86768C65527F615546372E
3B2723523024705145944E3B874F43986E5FB08D81AF8D82A87C679B69588A5C498F6549
67291BB1846A9C6F53966D5C8E5E49AD7966926C5D9D725D9E74649A715F8B65548C6C5B
996C5E926B56724337844A38985549B2A6A1AA9E9AAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA5A1AFA7A3AFA19DAFA7A3AFA29EAFA29EAFA29EAFA29EAFA29E532820FFC6A8A57A69
54342D2B222634201BC89C86AD8C79AF8D7BA98876B08F7CB391859F7867A06F6272574E
3D30303526244F3E3873554C946256A68774B0988CAF978DA888769B6E5D895B477F5747
67392D734E47704E3E2715148C523F775A49664131A1715C986648AB755D8E6E5F8C6756
99695B815D4D5C382D734135B37361B5A7AAAEA19DAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AF9D99AFA39FAF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29E59372F51352E4F150FA1654F
442B3032251F3B2522B69580A98876B08E7EA37664AC9178B99E91AA8B7AA37764956655
8E66538A64528156448F69539F7263A67F6DB09589AF9385A87E6E9B7460905B46885F4A
814D41765B545A48421916184E2D225E433C44332B774E3D7F58478E634D8B5F4F896C5B
996C585B3A3454382A5B3328A9624DBFCDCCB2A6A2AFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AF9A96AF9F9BAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E3A211C442E253B201D422B25
2417183C27223C2520B89580AB8C79A98C7DA5756E9160519B6D5BB6937EA888749A7062
8F594896634AA0664FA2674EC09A82B28A78B08F83AF9484A87E729B786890614E8E6348
8C694E9C6B5A9065584536352A222447322D4B3C35634C427B56438965579B6C558D6659
8C6956482F25402823583326944534BDC0BFAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E3E241C331D1831241E37221E
2F201C2B201C4C332EB0816DB9917EAA8A78AB8A7EA17D6E8459497C4E43765C4F845C4C
5F443964473D6C46398054478F6C5DA48172AB8A7AAF8678A889709B7463905F547C4833
8A553CA5835F9F7260986F5C92685A7B5747734C428D5D4C8F64519869578C6C569F725B
815F4F2E231D31231D7F5043673127BFB5B5AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA19DAFA7A3AFA29EAFA29EAFA29EAFA29E472C23311A152E211C2A201C
1C111234231D483631A17864BC947FB3927FAF8D81AF8F82AA87779A6B5E794F4B7E514C
874F43804D3E7B48398953449E7666B09084AC8878B0837BAC7D709E796893665D72423C
59302A6742306D4834B8795CAB7E689A6F58906B588C69589568558965569F6F62926C56
5B3D2F34241E372D28854F3D7E3F2E6C5A53FAFFFEAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29E432F293C27222F1E1A2F201C
221A162F1F1C493631966C59AE8B78B08F7CAF8D81AF9386AF9385AF9589AF9081AF9081
AF8E7EAF9589AF8E7EAF8F7DAA8670AB8E7FAA8D7DA58370A98371A58371A27C6C997062
6E4B434E312D3E2F2856352A6A4433985F4B8667519561498B5D48A072638C6454956656
3D262134221D3827274D221A79302158453EBCB2AFAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E47322D473430261E1A32201C
2E201B33242347352F8B624FB48975B99784AF8D7FAF9188AF9789AF978DAF9D97AF988F
AF9387AF9589AF9284AF9385AF8F7DAF8A74AF8D7BA88270A97F6EA97E6CA98774A97D71
9E7A6C956B6079534B543D3846322D55383063483C7354476D504388574F956F5A8E604F
3B242030201C2C211D291C174926205C413ABFB5B3AFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E4B30274A332A392A262D1F1B
351C173926224732286C4F42B3846CB39682B3917EAF8D81AF9386AF9589AF9385AF9D97
AF988FAF988FAF9284AF9385AF9180AF9183AF8B75A88370A98774A97F6EA97E6CA98172
A27B6B9F79669573618C68588465557152456F4D417F55478A64578E63568B62556E4D3B
3D282330201C382520261F1B32211C4F352AB1A1A3C9CCC7AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E432B224E3933392823392420
251B1636211D37231E603E30906349C6A18EB0927FAF8D81AF9386AF9991AF9387AF9385
AF9D97AF968BAF968BAF9385AF8D79AF8D7FAC8576AC8270A97E6CA98572A9816FA97E6C
A27866A07361A07462997362986C5A9D715F946F5D92685899695B99695A8A5D4B4E352D
2C1E183A2626271C1B281D171C1212452A238D6F67C6C2C3AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E472E2446353145332E392723
36231E2C1F1B3929244D37316B4838BC896FB99984AF9185AF9184AF9B90AF9D97AF9387
AF9589AF9284AF9385AF9385AF8D7BAC8B75AC8573A9816FA9816FA97E6CA77E6CAB7B69
A77B699C73619D74629D7765997361986C5A9A6F5D8B68589269588666556A4B3E3F2923
3729241F1616271D1D1A1112251B1B32201B795D56C2B5B2AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E47322B4D38314A383242312C
39231F261C173F272253382E684B3D966A54B89886B39283AF8D84AF9184AF9B90AF9D97
AF988FAF9387AF8E7EAF9385AF8D80AA8A77A57F6DA77D6CAB7B69AD7E70A27E69A37966
A3796A9C76619D74629D715F9A74619A715F956856946E5D8C63517E594C5E3C2F3E2722
271D18261C1D1F1616241B16231A1C3A252088726B866C65AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA19DACA39F43332D4A38324F3C36473530
32201C39292437272346312A7B4E3B94614EAE8671B49480AF8D81AF8F82AF8F82AF9991
AF988FAF988FAF9284AF9385AC8B7BB38F7FA88370A5816FA27A69A37567A77969A37361
A07667A070619A6E5F9E745F9A6F5D986F5D9465558F67568B5B497650414630263D2621
281F1B281F1B271E1B231A1629201C3C2521C6BDBAAA9E9AAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAF9E9AAA96923A2A2552372D4637324D3A35
3F2E2A362722402F2A452F266A5044885441B4836FB39985B39185AF9184AF9789AF978D
AF9B92AF9B92AF9489AC9281AC8C7BAD8C79AC7C6BA77B66AB7E6FA77B66A3796AA37564
9C74629D7664996B5C946C5D986B5A986F5C926B5A8B63517E55445F3D35442A232E221D
271C17261C1D21171715121222171752352FB6B1AEB2A6A2AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E45312B462F244E3B354C3934
42312B3C272246322746342F5E483B6C4235A8735CB89884B08E7FAF8D82AF9188AF9484
AF9488AF9488AF9187AA8A77A57F6DA98472A77E6AA77C66A37967A37C64A37965A37361
9C79679D715F9D715F976F5D9868589566558765547E57455F3E3652362933211D2B211C
2E201B231B1B1F16161D151634231F6C4D4A74524CAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E553F39412E2849352F533C36
4330263E2E293D2A244B373147352D5A40378D5743B4896FBA9F8DB08F7CB39182AF8D7E
AF8D7BAC8B79B08F7FB39181A87F6DA77B68A77B66A06E5FA57767A57767A87967A0705E
A072609D6E5F9A725D9A6F5A9565569266557E5B4A673F334F352936231E291D17271C1D
32211C241B1C1A11122016173D2621C8BFBCB2A6A2AFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E5C483E4937344A3832493530
4A352E3826253E2C2643322C4C3934463026623E319E7158B68A72B3917CB19580B0907C
B0937FAC8B79A98674AD8D7AAA8270A3705EA57761A0735F9D6E5C9D7764A27461A0715F
9A6B5A9E6B5C976959956E598E65518758457D56434E342938231E2E221D251B16201617
2217171512121511123823203E2720BAB6B8AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E70594F3F2B234B3A35473530
503D373F2B233724214A3A3441302A4F3A333F2A246F5141825A48B1745CBC937DA8826D
AF8F7EAC8B77AC8870AF8875A07865936754A16B57A66F57A271619E6C5B9E68559E7461
9A6B539566599263518B604E7F604E6B443760382A432A2432211C251C17201617201616
1A11121311121E151632211C7C564C76584EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E99828349322C402E2A4B3832
4B383240322B3925244C3328473632503D3845342F48362F5C463D764C3D915F488E6A5F
8C6A58A26E58A37E69A178638E65558759437C503D915D439B5F4B9C6C53A06551916050
905E479760498F604E7D564975493A5E382B49292335221D271C172116171A1112141112
141112141112291F1B382320B9AEACAB9B97AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E6551493B2A234A3833
46383244322D29201C47322C523D37503D3754423C4E3C375542395D453C62453861413A
5F4033644139794B3A7C594763463D6544396D41326B432E74453789584189574182523D
8053407345347A4F416E43365C3C30432822422B26261B16261C171F1616191111131112
1311122C1F1B221A1B664B44938885AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E846F703D2925463530
4938324736313E302B42332E503D3857433D4E3B3654403A5A3D35634436543C304B3A34
432D27513831462823593F36523A3348332D482A244B31294B2B23562F265F3E2D5B3A2B
5C3A2B532D25522E264B2D26482B2430231D2A1D18221717201616201616131111141112
2C1F232C1F1A3E2F2C856A6790736DAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EA694955C423F382722
4735304C393446342F55423C42312B5B464045332D513D385B40374E36314F352D4A352F
3F2F294F383334242340322B4128233F292433221D2F221E36221D40262140272136241D
39241E37231D41262133211C34221D261C17251C171F16161F16161411121411121E1516
3828263723206D5650725750AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E87716F402B25
4839344C393447353042352E56413B513F3943353043302A5C3C2F41302A47352E44322D
34282B45352D3A26273C27223222262F221C2E211C261C172C211D2E211C30221D281C17
221717291D1735221D271C17221717271C17251B1B1F16161411121F1616251E1A312422
3623206B4F496B4C45AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EA18B8C513633
412E2A4F3C36473530483832463934543F3945342E3E2D28432E2736231D45332D382726
37272732231E332328281D1C231718281D1D261C1C201616261D1C211717271D1D201616
251B1B291F1B261B1B211616141112151112151212151112241B1B221A16201617351E18
7359546F554EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E795D55
3A241F3A2B264B3832493B35493A35523E394332313A25203C2B262B201C35231E2E231E
34221E211717231718271C1D241B1B1F1616251C1D1F1616251B1C1F1616372420121011
271C1D2A211C241B1C141112141112191112221A1B20191A231A1B37241F36292248342F
8C868CAB9B97AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
795D5537221D3B302C43312B52413C503E394F3C38382B27402D282D1F23251C1B32211C
251C1C2A201B271E1B231A1B20161720161720161720161720161729201C271B1C3B3236
2F28242A1C1F1F1616231B1B241D1A241C1A221A1B3B2C2830242237231F5C3C327F6152
8D695AAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29E7A584F37221D41342F41302A4F403A5B453F4839343F2D24372826271E1C261B1C
211617261D17261C1D201617201617241B1B1E1516241B1B1E15162017173E3634372832
544842423535302427382C2A302522261E1A3728243929254A38334C30296F514B836258
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EB3A7A37D5C543E251F493C3844353058463F56433D503C35372621372824392D2A
2D2523291C19271F1B231A1B231A1B1F16162016172A2024231A1A281E1B271E1F433632
4D38362D21213728223527222D202034231D3B2B26452F265F443A67504E8D6D5EAF9F9B
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29E7550423E251E402F2B55403A65504A5B4A444936313425213A2827
3F292341332E32282422191A2016172F24282A2023342A262B212741322C231C20503F37
3F302F3D2E2A362A27342824382B2940322D392A275F41356D50467C5349A49090AFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E75594C34150635251F513D38604C455E5353543D34423230
43322F3C2A283F38344536373629242E2225372E3640312D473C4042312A3E2F2D4D3D39
503A364C34304C352B463834533D3560473B44322A8D6E628D6456AF9F9BAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29E9D87875E3A3535211C4E3C344E474C725E59624E49
6250485846434D40415344455E4D4C4D3C384D3D3E4131344736324F3C39513E394C3934
5D3B32593C35573D3459423B52372E785C5472483178574CAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA5A1AFA7A3AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E75595940161134181346383879655D
6E5F5B5D4B3E63504A64544F67524C634C4959463E4E3F3C4F3B3844363055424059443E
523B336242395738328E6C6261311A531A108D706DAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AF9A96AF9F9BAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EA694956F525C5B3539
76525876555770493858382C5743397058537154496E564F6F57506B544B644F47694D41
685347876D643C11026235339E8585AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EA6949AA893969D838870515D583844542E2D51291E512B2051271C4C2217451606
4213007F6156AF9F9BAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.267442 0.245293 0.488926 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(180) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B79837B
75736779776B797870797A72797870797B73797B73797B73797A7279776D797568757163
746A5B7164577062546C5F526C5F526C5F526C5F526C5D4F6B5A4B685A4B685A4B685A4B
68625B798A8B798A8B798A8B798A8B79898A798687798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798485798586798A8B798485798586798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798485798586798A8B798A8B798A8B798A8B798A8B798A8B7E8981
7A787179776A79786C797A72797870797B73797668746C5B6F6C5B6F685B6E6256655D52
655C50665B4F66594C675C4F6C5F526C5F526C5A4D6C5A4D6B5A50685A4E685A4B68716C
687777798A8B798A8B798A8B798A8B798F90798B8C798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798F90798586798586798F90798B8C798A8B798485798586798485798586798A8B
798A8B798A8B798A8B798F90798B8C798A8B798A8B798A8B798A8B798A8B798A8B747E77
74726279776F79726C797B7379776F79716A747066646C6460635A6B58526A554D6B5F53
6C675A6C685A716658685A4D62564A62564A625A4D625A48675A4B685A4D685A507D817E
7D9193798A8B798A8B798A8B798A8B798A8B798485798586798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B79898A798687798A8B798A8B798A8B798F90798B8C798F90798B8C798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B7E837B
7A736D79777079776F79726B79766E7977697E7B738F8079828073807871806C63775F52
775B54775B5771534F6B564D685A4D685A4D685A4D685A506D60536C5E50685A4D68625B
798A8B798A8B798A8B798A8B798A8B798A8B798F90798B8C798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798F90798B8C798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798981
79786679776579776B79776F79776F797773797C757981787E7F7A757F6C79746A7B7166
7B726175665A7B72637A5F5672514D72615E6C61566D5A4D6D574B6B5A4D6D65586D6C64
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B79857E
79776A79777079776A79776B79776F797C7479776F79716A797B737E7F7A7F85767A7B6A
756D647A706271645775685C7168586C584871645C686156625A4D675A4D737473777F7F
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798485798586798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B695D54696159
79777079776A79776979776B797C7479776F797B73798178797C74797A727977737E796F
7F76647A6D5E7A6C5F75655A765F54715D4F67544567594B6D5A4D6C5A4D686D69758487
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798F90798B8C798A8B798A8B798485
797F81798586798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B39352E404B42777668
79776B797773797774797770797870797A7279726579776B79766E79766E797769797B6C
746E6674675E75635C7466546B5D4C6B5F52715E506C5A4D6865587167587271697A8C8D
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798F90
799091798B8C798A8B798A8B
798A8B798A8B798485798586798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B64686F311C1A272E387A786E
797C71797B73797C74797B7379726B797B7379817D79777079766879655F7459566A554B
6F625375685B706C5C6A6257716255716053675D4A675A4B63544862554A676159798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798F90798586798586798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B7E90912F24197E7C6689877179776F
79726C79766E79726B79766E79776F79726B79776F797A727471676F6E5F74685D746659
6C60536B5F52705F4D706151675A4D6B564A715A4F725A4E6C5A4D6D605368554A747573
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798485798A8B798B8C798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B22191378776E92928A7A786E79776B
79776F79776F79776979776B79776F797C7479776F79766E794E4F753C3F703539703237
7133387149466B554C6B554A6C5448675746675A4B6C5A4D6B5A486851435D4134655B52
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798485
798586798A8B798A8B798A8B
798A8B798A8B798F90798B8C798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B646869BCBAB888857F79766E79776D79776B
79776F797163796D60796D5D79726779726B79656379595C795A5770463D6A362C6B3F3A
6B42396B37386B3E3D624A43625A4867554968574B6C5A4D715A506D584B715D505E3F30
695B51798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798F90
798B8C798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B27221E1B252375726079776579776979776B
7977697470616F6357746E6379786C796C5E744E466A3530644C42563D2E5D69576C7B68
6B3F345D2B236B352F6C403C68514B685840635741675A4B6C5A4D6C5E506C584B6C5C4F
6C5D5179807C798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798485798586798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B504D4F897160746E617A7871746C6374736D797B73
796C6273604F654E416A4C4E6E393A2F08062E2D2A7060557B655D97B6B284534D62372F
52523A5161523F3B2B4B29216338336351406D52456D5C507269557161506C60536C5A4D
5D423569554879807C798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798485798586798F90798B8C798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B352F2B3E4D4B7A7A7279776A796D5F75675E79766E
7974687253426646382F0B09314142B0EADF93BCB785C1C480AEB77A87887EA89290B6AD
9DB6BA76807F4E3D351D1E132E231C60473F68594A725E5372645A766B58715E4D6C5A4D
6C5C505D5C64646D7A748082798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798F90798B8C798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B6973803623202530347573637977697E84747A7A6E79776F
6E5C515F4D384F2C1F48160B4B1F1C6E3F366F4B40745E56797460796B56735D546B5856
6E594C8F7766A18E759083733229202C1E1C5A4139675B4B766F5F756B607065586C584B
6C534867584154564B52555E697582798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B39352E0A05035D4B42756C637A786A796C5F796458796E5E797765
786A5985716794AA94C6E0BD93988D7B6765705D5666453D6A3A3C643639643632611C18
602422583733684C3E7044407A574E2D0F0732232468534A716758746A56705C4C675D4F
676153715A4C888680777B8067707A798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798485798586798A8B798A8B798A8B798A8B798A8B
798A8B798A8B696D7417120E120F0D3A5151807F73797164796968746E69747468796564
78655D6147366657507A7D7B79897B7E8C8084988C85978B80A087848971828C757C9070
7C8368725649774946763A336D2B1F6622183A1510462D2E6B595074665670604F6B5448
6853486C584C26150E393A2D78807F748082798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798F90798B8C798A8B798A8B798A8B798A8B798A8B
798A8B798A8B778992ECDAC4FFCDA587796574726579756879816A7E6C687A6A6779846D
78766479645769574B746A5F797B73797B7379726B797B7379696B79656075685C74665C
7162556B614D5D624C666F547677608B836A84736965544163564570635370604F6B5E4B
685B4B6C5C505449412E35346976737A8C8D798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B89856B7C776B7E8A857A7D71706E6274776A79787179847879807B797B78
7E7C707B7160674B41655549747368798077797B7379787079887379746470584B705B4B
665C475C54485A4F3E5E45395E49395E4839635039695F536D6357715E546B564A675148
63574662574830221C2E3C4A73818E798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B747E80747C76746C5B6A55425F5E5E6A6E6C7A736D797C75798178797C74798077
7E71717F6F687B675872584F75665D79776F796866746059747164736C5D70645666473D
664E476B4D40644D3E64544469574168573F644C3A6A5346725C4F6B594C6A574A685549
68574E6D60532015160F1C19606965798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B7E7B6B7A756B73685D6A5C537B6853786763796A69797870797B73797B73797B73
7988737E7B6979725C6C5748705F5779787079887A7E7E797A78757E7570756B60756B5A
725D4F6B534464493F644E4264534C72584F7D695D74685B6B5D4F6B5A4D715E506C594B
685746635748321D160A0C0D1F2327798586798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B79857E747160634F3B6C64567C6A687A786A797A6C79787079827E79807B797B73
797A76797F75787164716B586C6654746E63797668797C70797B737978686E5F516B594C
675A4D6B5E506D5D44684F3D6450446E6159776C6275685B706B5D6C6758675E50675E50
685B516D6559AF7C516434230E0706191E22798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
7973696E52485F2B276947435B5B57657D6A797A6A79776B79787079766C797A72797B73
797A727471677978697B7E727B7B6E7A786674655E74655B79655F735C516F5848675146
624C4063513B58453959483D695B4F6D6656716659746659705E516C594C715A4D6C5A48
6D54466D5A4F746359987763D3D6CB8DA3A3798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
7972747854516F494168514878675878746D797C7A797B73797870797B73797B7379766E
7976687975677A71637A6F6275736D797C7A7E897F7A7A76797866786B5E6B5D4F625043
5E4B3E56463F68534670675874685A726A5D71695D7466597062546C5D4F6C544D715150
68544B675B55665240634F416D625B7E8F90798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B79786F
797E6978705B6A5A4168594A726B607A786C79787079807779776F79716A746C5F747160
79656379635F70665A74655A756F6579726579766A79776F796D6E785B536F564A675346
685446645A4D65604D695E4E6C6154766559716356705D51705E516C574A6C5446675546
675B48685F527563596D5D50514540626A6D798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B6E6858
563C30372C233A352E5B564E726E6379776B79726B79716A79766879715F79716370635C
6A65566F645C75736975786A75746479776F79777079776F747E6B736F5E6F5B4D675346
6451446D53476A574E6E5C567261576C605370685C716B5D7063556C675867625367594B
68524E685A5562402F674F436C4432684E44798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B726152
321E122D231F251E1E31383B716C6779777079776979776579776F797B787E7C797F857C
7F746E715D56654F476A5C52706A5E74726879776F7977697969616E5D53654C4A634D40
5F4B3C6050446D5D50685A4B66584C6B5B546B524966564B66594C62564A675A4D68584B
68554B635145615A40574431624B41685654798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B797E7A7E7C77
8A5B48412B20332521393E3E716C5D74715F74726B79776E6960505A51434D3E32413229
453B344E3F3E614C47624C4265544B706A6179776F7977737972697462566A5940644C39
6351425C4E42554B41505045595348626151666051675C507163556C5E50685A4D68584B
68554B68574D51372C3A1D17493325635145798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B747064736457
1E0A070E0C0C17171528393B716C607971647A7363797769837C6C665A4C4E463A2B2D2C
13191A131A122927213B221A33141147302B746E6379776F7978687466566A56445F5941
5949386055497766577D6859735F51684E485D4F475F584D6C5F526B5D4F5E5448555448
5F5B4B685B4D65473657342656332B644743798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B7E909183847B735B4B
5C3A322317132516132C36397A796B75766874736779776A7E7F7786766799807562493B
2819151F17121D25263F4035776C5B736F62757A6F7988847982787468595F4B3F543E33
331009312020513E2C47392C332C233F3D325E52455C5444625647675A4D6653455F5246
61524B5E4C424A352C47392E5A4D456E5E5B7E8F90798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
797F81798586798485798586798A8B798A8B798A8B798A8B798A8B1A0907090C13746658
664435261D231713111C2F33706E6279776A7572656F6D61747268838779726C5A9C7A63
BC91739F725085583B77684F72655472615675706679766C797266746455745641634A3C
6F503B4743412930350202050F1517252725151612171E21312C2248382A6251435F5649
61554656483B372B2028231F42483F6D655C7D8E8F798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798586798687798F90798B8C798A8B798A8B798A8B798A8B2012101D1412020000000409
130F1514110E22171429343775726575736D6D534F6046416A61597E817D848E888A817A
7B6458806E61836F617B6959786F5F766C5F757167797B7379706B746D616A5F4B675D42
735E4384634C92644C2517171A161229201F292220342E255A463B645C4C6C5545645246
615B493A2924281F192A1E1732231E5D3E3978898A798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
799091798B8C798A8B798A8B798A8B798A8B798A8B798A8B452A242F22192E1E181B1917
0E090A2116132918152C30337A6E62756E5E8492827A796A4B392D3C2922392E252A2923
211E1C201C1829231C30211D443E396A6B5F75706679716479715E7466586A5A4D68483C
5F553F605943716553C69473AC83677F553D7E4E387A5B4A786045605445635E4C72604F
5F554B3B2B1F2217142B1E1835251D593A36798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B4D32241A0D0A11110E16110E
1F141014120F2425222B39396A665B7E786A7A786C8989829BA08F826E635F515175615A
8B66528065536F58477C6B5A7D76687C7B737A7871796567796C65746B5C6A5451452C25
341D1A41372D5F5741685A46766250857159776D5968634F5F5A4F68554F5F524B5F5746
5648381D171311110F4E4B3F5C3C2B513E39798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798485798586798A8B798A8B798A8B798A8B59423428110C1E120F161310
08040617100E26211F2A323158564E746F6379776B797C747E85808FA396ADB29F98AB9C
9DB2A79FB0A6A5B8AD91A0907C7B6C75796E7475676F7A637473637A6F6281816993866F
5B403B2319190D0E0F1D2021514940675A4B715E495F5549634F435148395E4F486A524B
3A261F21141026221E2929234B2B1E1508061E2225798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798F90798B8C798A8B798A8B798A8B798A8B463F3A27211E1D15111C1310
16100C19130F25211F37383460595075706479776B797870797B7379827E798787798787
79807B79827E79807B79807C7E7F757A73637E7A6B7A716375665A7A6D607B736485786F
A29382AC86767C5B4D2E251E0E100E1114161E21222A2822322B225B49446C574A635042
311E191C13101C15170E09081A100C362825363F41798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B5947403F302C1D1713191310
1E141120181A2723212D332E4849416A675C79776679726779776F79766C797B7479817D
79868579827E797F79797B7379807C797B7179776A79746575726475685C75695D756C60
7A6C5E76735F8D7760977D658C7159664F3B5F42316B52437A6757614F4A594F484F4E40
33201A1D131015120F0E0F0B1316142A2826353E40798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B543D2F2B1F162B1F1A1E1411
1F0E0B241612291E162625213A3B37625B5274726679776B79787079827E797B73797B74
79817D79817D797F79797B7379766879766E79716879695D75695D75726475685C756758
746355765D51766254756253826C5C8C756389746277635473574F6E5C4B6C51434B3326
2D1B161D13102618151B141117120F201A141C1818595B60798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B46372A302B28281F1C271916
130F0C15110F15100E211B1726241C4A433B756F6379776B797870797C76798685797B73
797B74797A72797A72797B73797A6F79776674706174716375685C75635875675B75685C
7466596B62546B5F5271685A685E506C5A4D6C5A4D5E584B5555465555484B483B272420
100E0B1B1618110E10100D0A0804061611112223224A4C4C798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B5940332E252130292527201C
2A1A171E1411241D192929282A2D2C3539376A5E5479726879726B797268797B74798685
79827E797F79797B73797B73797A7674716874706275675B75675B75685C70685C6B6356
7063567062546C5F526C5C4F716254685E50675A4D66584B6A554968504346352D2A1915
2A1E1B0F090B100D0F0A0406120E10161210242B2B444C4E798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B4D4742322D2A332D29332B27
271A17130F0B1D15122F201947342848382B5D4F44746F5F79776B79726B797268797B74
79817D79868579807B797B73797A727E7B707A7566706C5E6B6356705F58745F56715D51
715B54705E546C5F526C5A4D67564A675A4D634F426C51455F4B3E45383234261E281915
110D0A120E100E090B130F0B130F0F21171567797C869C9D798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798485747A7B463A352A24212E29262E2724
1D1511271D1A251E1B201F1D3230284A433A5B524A706B6079776B797C74797C74797C76
79817D79817D797F79797B73747466746D6079695D7A675B7B6C5F716757706456716254
6B64546B635467544D62564D675A4D685A4D6C5B4E5F5649534B3D56413136261C251915
1A1411181410191511130F0B17130F1F1714272D307E8F90798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798F907E959543383133241C2E2420302A27
372E29281F1B28221E2D221930353036372E483E36665A5174726879726B79776F79766C
79756A79756A79756C746C5F746B5D706E62746F617063516B5F5070635171645471675A
705F526C5E5171614F6C5B4D6854486851465E5448534B3E4B3D30302321231715151210
110E0A110D0F0D080B0404060A070A2C232135353878898A798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B5B48422D231B302925312B28
28221E2418152B1F172D26232D2C272E262034302C5D544D757363797765797267797164
79716079716079766A7E7B707A7566756358705C4F705A51715B5471605A71645771594C
705B4F6C5A4D6C5A4D6B5A4D68584B63504357483B4B3B2F302321281F181C1410171310
1D1411140F100F090B10090B26181585A1A090A8A8798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B6A655E362F2C2A2522322926
32231A2B241F211C1A282321211D1B2326262A2F2940372D60584C6F6D61747262797769
79776A7471646F6D5D747265796D60705C507063516B5D4D665C4C665C4F6B5B4F6B5C4F
6B574B6C544D67574D675A486353425E504357493C3C2B242D211819120F110E0A110D0F
181210140F100A05060D090A1C15131F252978898A798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B605B4F3A312C332D292A2623
2B272520181A211B19241F1C312B282D2119211C18262A28433B35604E456B5C526F6458
6F695D747164756D607064596E6A5D6A5F5166534A6B594D6C51466C524767564A6B5A4D
675448625446624D405949404F4A3E43392D4332272E231918120F151210130F0B0E090A
0B080A0404060404062217142F1D15302F2E798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B99A1AF513F3C322A272E2724
35302D37281C2719142F282627211E2E2A29211D1B1C23221B2220242522493D375B4D43
5B4F4B605554605952655F5465574B4E4337433A30503E305E4E4062524662473B624A40
67543D63503E5E4B3E5943375443374130292C1C172316141C1310130E0B0E090B0E090B
0A04060504060E090B15110F759095889B9D798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B93AEA86561502C251F292421
28232022221F1E191B241C162E2621342F2C39312D2923222A29292A2C2926241E292929
20272626261F37312A3B372F36312C3A3128362C223330243D302548382A554835544134
43342D4431284C392F433933372925311F172516141B1210110E0A0D090B0A0406040406
0404060504061513102318152C35387A8C8D798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B808492403533312B28
2E2D293029251915111E1E1C332F2C35302D3C3733413C37423D333C3C3330342E2A2623
2B1E19241C1C241B1A2C23212B242325242530262231231B2A221D302B25322E26342C22
3D3328362C212F2B2534251F2F231B211714201C19130F0B120E0B0F090B0A0506060406
0504061C1310140F104F4E4D606363798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B9BABAD5846412E2623
2C24212C2623372C28362E2B342F2C393531302A272B26242C201F37221E36211A2B2320
1E1B192323201B16141B1C1C262321221F1C191413161617161312140F101816131C1A15
1B19151A13121910101812111A131214120F0E0D0A0D090A0D080B0E090B050506050406
1C131A1C1311322924647F8183999A798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B839994909A9A403732
2C2623312B282E272438343028221E2A282628211E2B27243C372E302E2B2827252B2623
2B2420342A27241B1C1E1E1C1F16132115121A120F13110E16120F1E16141F151417100F
14100E16110F1E16141A131018120F120E0A120E0B0F090B0E090B0504060504060E090B
201B17271A168798998DA3A3798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B8F989E553B36
352B28312B282E27241D1D1A312F2C3B363234312D25211E281F1A231916231E1B25201C
1A171D181C1B1F19192215131A1219131210141310120E0B14120F12120F12120F100E0A
0C080A0E0D0A15110E110E0A0C080A110D0B120E100F090B0504060E090B1A141129201B
25181590A5A590A6A7798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B89A49E73726A
362E292E29262E2724352D292B2A2729272428201D221B181C191819120F221D1B1E1719
2017181A110F1911170F0D100B080A100D0F110D100E090B100D0F0D080B100D0F0E090B
120E10171311110E100D090B050406030406030405040406120E10140F0B0D090A140B09
808F8F8A9C9D798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8BB9D8D8
7F78703128232924212A29262C2A2733302C322A2C271917231B1818141115100E14110E
18120E0D090A0B0809110D0F130F110E090B110D0F0F090B110E0F0F090B231714070507
0F0D0F151210130F100505060504060A0406140F10161011130F1025181539271C684D39
6260567A8C8D798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
B9D8D882726A39342F27211D332C2935302C39332E2A282328231F20151C120E111A1210
120E10171411191511130F100E090B0E090B0D080A0E090B0D080A1713100F0E0F2E303D
34383C21171F0F090B140F101B15111B1611140F1029231E2E221C251915402D277D949C
849DA0798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8BC0E5E5827068473B3627211E25252334332F41373233251C2A1F191B1511110E10
0D090B100D0A110D0F0E090B0E090B120E100F0A0B120E100F0A0B0C080A272B2C251D26
382F2E4D443A433534483C37372B251B1512261E19231C19312B284A33298A9B9B889B9D
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B748586B8DCDC715B4B493D36382F2B35312E3B3732413D3A2B221E291E1B372C27
312B24221713191410141011130F110E090B0E090B1612191410121814110E0B0C1C1D17
22201D0D0B0D0D0D0C0C0D0B0C0B0D19110F211A182D22194D3829888E90788D95798B8C
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8BBEE7EC6F6A5C2E26202724223D3A374949454B453F2C221E1B1517
2115133128242D28231611120E090B1C181E201B23272420211C21362F2D1F181E353232
332B2C392E293A2E29332823392E28484035392F2956443693A2A396B3B07C908F798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8BBEDDE2C9D2DC5D534E2B2724292423353A4252504E5E554C
5C5C553830312B2D3049495667635F423634302C3630282E46424D373131392D26312C29
392D283A27243A261D382D2843382F584032482C206D899084A2A5798B8C798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B8EA9A3CEEEEC766F78423C3A3031333F484F4C5155
44464450514A5D5A57544D44463E393F3731423A30332B2A211B1626211E35302C312B28
3C2A224A31274C3A305B453A472E25433F45A5C1CC8BA3A4798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
797F81798586798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8BBEDDD4D8FAF8D3DFE05F5E6E504E55
767485766F795F504B4C44404945415F545565565361564E6D5F585D5245534E47655852
504E4542473D332D2A555D69B5DBE7BEEAE7849A9A798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
799091798B8C798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B839994C0DBCCB8DAD3
A3C2B59DB4BFADC7D3A5B0C265687F47506341444744423F3F3F3D474443413E3B332F27
38332B829293DDFFFFA6CBC47E9393798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B8399907B92918EAA9FB8D4C5C0DCCCC6E7E5C7E1E1C7E5E5C7EAEACCEFEFD2FAFE
D3F7FD89A3A5798B8C798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.267442 0.488926 0.488926 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(202) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96899E96
81847487897887887C878E8187887C878D81878D81878D81878E8187897D898A78838574
85816F7F77678177667A73637A73637A73637A73637A72627C6E5E766E5C766E5E766E5C
6D5D4B879B96879B96879B96879B96879C98879591879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879793879591879B96879793879591879B96879B96879B96879B96879B96879B96
879B96879B96879B96879793879591879B96879B96879B96879B96879B96879B968CA39C
86887C878978878878878E8187887C878D8187897983816E7E816E7E7D6E80796A767465
767464756F60776F60756F607A73637A73637A6F5F7A6F5F7C6E62766E5F766E5E767E71
6D736A879B96879B96879B96879B9687A09B879A96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B9687A09B87969287959187A09B879A96879B96879793879591879793879591879B96
879B96879B96879B9687A09B879A96879B96879B96879B96879B96879B96879B96839A93
81847087897D878478878D8187897D87857983867A7881756F786D7A70657B6C617B7464
7A7B6A7A7B6A7F7A69766E5F726B5C726B5C726F5F726E5B776E5C766E5F766E62847E6F
849792879B96879B96879B96879B96879B96879793879591879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879C98879591879B96879B96879B9687A09B879A9687A09B879A96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B968C9E96
86847887897C87897D87847987897D8789798C8E819E92858C92848B8D7F8F7F75847363
846F64846F67806B627C6B5F766E5F766E5F766E5F766E627A72627B7262766E5F6D5D4B
879B96879B96879B96879B96879B96879B9687A09B879A96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B9687A09B879A96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B9687A39C
87887387897487897887897D87897D878982878D808792858C928A83937C89887C888376
88836F847A6B8883728A74687F665F7F726B7B76687A6E5F7A6B5C7C6F5F7A7667736855
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879F98
87897887897C87897887897887897D878D8187897D878579878D818C928A8C9784888D7B
8380738884737F776785806E807A697A6A597F776C767668726E5F776E5F7C7C757F7F76
879B96879B96879B96879B96879B96879B96879B96879793879591879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B967C7B70757870
87897C878978878979878978878D8187897D878D81879285878D81878E818789828C8E80
8C8A74888070888070847B6B857366807262776756776F607A6E5F7B6E5F706E61818D89
879B96879B96879B96879B96879B96879B96879B9687A09B879A96879B96879B96879793
87928E879591879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B9655584E4B62597F8273
87897887898287898187897C87887C878E8187847587887887897D87897D878979878E7D
838578837C7083786C857C677B72607B73637F72627B6E5F7576677F7A69786D5A869A95
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B9687A09B
87A09B879A96879B96879B96
879B96879B96879793879591879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B967883834F3E3916263086887C
878D7B878E81878D81878E81878479878D8187928A87897C878979877D7183706A7A6C5F
7E7966837B6C7F806C7B776A7F776680726377725E776E5C716759726C5D6E5D4B879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B9687A09B879692879591879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B968A9E9A4C4739878E7976796887897D
87847887897D87847987897D87897D87847987887D878E818385797E8671837B70857C6B
7973647A74647F7460817764746F5F7B6B5C7F6F627F6E5F7B6E5F7A7263705A4981847C
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879793879B96879A96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B963E3B32878F8482898186887C878978
87897D87897D87897987897887897D878D8187897D87897D896C678357557F50507F4D4D
7F4D4D7F5C577B6C607B6C5C7A6A5B776A58756E5C7A6E5F7C6E5B7567566C54456F604F
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879793
879591879B96879B96879B96
879B96879B9687A09B879A96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96788380D2D9D3777A7587897D87897D878978
87897D87857587817187816D878474878479877D7587706D8979707F5D537B504579544C
7B584E794A497D5652725F55726E5B776A5B756A5C7A6E5F7F6E627A6E5E7F6E5F6A4F3D
756857879B96879B96879B96879B96879B96879B96879B96879B96879B96879B9687A09B
879A96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B9645463E1B302F818471878974878979878978
8789798386757E7869817E70878877878171836C5E7A50487764586B58486B7462788772
7D594C6C43397B4A437B544E76635B766E55716A52756E5C7A6E5F7A73627A6A5C7A6F60
735F4C879086879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879793879591879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96696E6BA595815F625986887C838175818378878E81
878175857965766857745D598057534B26213941397F7669887066A2BCB48D685F734F45
686D5461715F555242594037734A447167557A66547A6E5F7E7A668076627A72637A6E5F
6A5344756351879086879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B9687979387959187A09B879A96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B9653544C3B53547E807587897889857481746787897D
878A7C866E5B77604E472723404E4CC0EFE28AAAA391C8C48BB1B4868F8B8EC3AC9DB4A8
A8BEBD859088655A4F30382B3B37306C574F756D5A7E6D607E776A857F6980725F7A6F5F
7A6F606A645C727D8481908C879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B9687A09B879A96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B967C8B8F5546400E232D8184708789798C988486877787897D
80786A766A5263483763322642201F7651477E6556816D5F878B7787806A857A6D78665D
8076669E8975B2A78D9D918042423736322F67554A736959827F6C848071817B697A6D5E
7A6759776448646C5F61686775848C879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B9655584E25252070685F5E5C5886887887817187786A877F6C878974
8A87739583779DB49ACEE2BE8A95878875717F746875584D78585677504F76554C703630
72423E66453F7D6A59815C539072663C29203830307261597D766485816B817360777362
7572627F6A59908E7F858D886E7780879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879793879591879B96879B96879B96879B96879B96
879B96879B967C878732322C272B271E3F4283857A878575878178837F77818374877D75
8A8074745F4D6E6055868C84879C898C9B8D92A49591A3948BAD939497808D9C83899D7E
898F737F645783645D8652488145397B3E3240292550393B776A5D857C6B8177627C6A5B
7567597A6B5D403228414531818B8881908C879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B9687A09B879A96879B96879B96879B96879B96879B96
879B96879B968CA3A3FFF3DFF2CDA8726C5D818475878A788792788C8078867A7487987C
8A8C798B7C6C6F5D4F817B6C878D81878E81878479878D8187817D897D74837B6C857C6E
7F77667D77616C785E777F668688709891778C8074695B4E6E66527F78678177627C735E
756E5C7A6F6072685C242C2975847B869A95879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96989F8385897F8C9C92888D7F7D807081897887887C879885878B84878E85
8E93848A8773755F52726355818373879285878E8187887C879D858988777F70607F705E
77735C706A5B6966536E5B4E6E5F4E6E5F4E73664E746D627872627F73667D6E5E77665B
716A58726B594D4138202F3279868D879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B9683938F81959083816D7A6D5973746D74807C868478878D80879285878D81879285
8C89848E847A8A7E6B7C645981756787887D8781798372698185758585727F7B6A775F53
7764597C6555726253726956766954776C5272614E7262527E6F607B6F607C6E5E766A5B
766A5F7A726239333100110D69716C879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B968C9483868A7F8581737B746788755B7F7C75877A7387887C878D81878D81878D81
879D858C8D7B8A8870796B597B6A5D87887C879D8A8C8C858688818E8E84847F7186816E
7F6D5E7C6C5A725E5272625371665D7F6D6088796B7D75657B72627B6F5F7F73627B6D5E
766A58716B594E3C32131E1F1B211F879591879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879F98838570796E58777060857A7286887887877787887C87918887938A878D81
878E868792858A88787F7F69776F5B817F70878979878D7C878E81898F7C8077667B6F60
776E5F7C75647B705777645071625578726682796E847B6B817F6E7A7A69777262777362
766E627A7666C8986A704A381C1C1A1E2422879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
878B80807366734A427D615A6661596F8E7887877887897887887C878879878E82878D81
878E81838579898F7C888D7F868776868873837D71817568877D7185746881725F776658
7362547167506B5E4F695F5074695B7876637D7668857C6B8173637A6F607F6F5F7B6E5B
7A6A587A6A5D857C6FA88C73D0C5B37C8E8A879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
87908E8A726B826558765D54816F5F7F8378878D85878E8187887C878D81878D8187897D
878979898A79868574888070818478878D858C9C8D868780878F788A80727D7664736656
6F6253665B527869587874647D75657E7A6B7D7B6B857C6B8177667A72627A6A5F7F6662
766A5E756960786C587163527057468CA09B879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96878F83
879A838A8A727E715875645578726686887787887C87928587897D878579838172818571
877D758978717D7C6D837769817F6F87847587897987897D8785818A7469826F5E776959
776959736C5D70715D746E5C7873648277687F78687F74648173637A6E5E7A6A58776A58
776E5B756E5C847C707B6D5E5D4D3E707A78879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96808777
6B5B4B524B3E4E4E45625F547A776A8789788784798785798789798785718985757D786D
7A7D6A7E776D83847783887781836F87897D87897C87897D83937D858774827161776959
7265567B6657756A5F786F637E73677973647F7B6C7F7F6E8177667A7B69777664776D5E
76665F756A60735E4A755D4F7B5B466D4E3F879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96868574
4E3D2D433D363837352F3C3F7A796F87897C87897987897487897D878E858C8D858C9789
8E887F7F746876645B776F627D7B6D81847487897D87897989817580786A78665E736255
6F61506C62557A6E5F746E5C756B5D796F647B685C756C5E776F60726B5C776F5F766E5E
766A5C71635674765A6453407266576D4A3E879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B9687938B909E96
A47760524236453E372A393D7A796783857181847987897D7C79656C6858635B4B554D41
5A584C61595471605A6F605374675B7B7A6B87897D878982898A7C867B6C7D705572614F
736553686253665F526267596867596F7360777665756F607F77667B7262766E5F766E5E
766A5C766A5F6854464C382F55483967442F879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96838C7F858271
392722252725292F2C1431377D7A6C878575868470878979949380797262646252424842
2A353327342C383C35503E33472F294F3C35817F7087897D898F7C867F6C7D6D5A6F6D54
6B604C6B6659837665887A697E726276635970675C6A6A5D7A73637C72626F6A5B666A5B
6C6E5C766E5F7C6450654C3D5C453D673828879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B968A9E9A92A298857662
7C5A4E352F2A332E2A1227308688778389788184748789788C92859A907DA28F807B6453
3D342E2E2F2A2C38374C574B7C7665736B5F81877687968C89988C86836F746456665548
4B2D233A312F6155425B52424A483B4F52446F6658676655726B59776F5F786A596E6658
6B665C6F6257635246554F435F5C526F493D8CA09B879B96879B96879B96879B96879B96
879B96879B96879B96879B96
87928E879591879793879591879B96879B96879B96879B96879B9636292413282E867D6B
83624F3B373A282B29021D287D80708789788385747E8171818474949C8C7E7F6AB4957B
C2A080A2816189664A76735C76705E7C6C60817D6E878879898B7E86806D876F58736050
836B53504D48404A4B181D1E202E2E353C382D322C283535444539564F3F7467566E695A
6B6A586C605150483A383A354351487057458DA19C879B96879B96879B96879B96879B96
879B96879B96879B96879B96
87969287959187A09B879A96879B96879B96879B96879B963C332E3A3530111919151E21
2E2C30292B2732302C0B212B838574818478817067705D557470628C928A92A196999489
8A796B8F82728D7F6F817464817E6A827A6B817D6E878D81898A808684757D7761787054
8074578D6F57A07A613C3331232C283A36333D3D38393F3763594E6968597C6956736658
6B6E5B55463E3F3A323A362E2F332F623526879B97879B96879B96879B96879B96879B96
879B96879B96879B96879B96
87A09B879A96879B96879B96879B96879B96879B96879B96654E443F39303E37302A2E2C
222423302D2B37302C12222B86807083806C93A6928A8A7B5E5244504439504B3F43473E
3B3C373536303D3E35433B34514E45777A6B817E6F878575898A75867C6C7D7464775E50
6E6A526C6951807A65DAA985A78C7287664F88624C7565567D6E566E655471725E80725E
6E6A5E574A3935302C39362F3439315B2618879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B966D57442D2623242A26282A26
312E29252A27333B371932377476688C8878868877989C92A9B29D8E81737367637F746A
967965877361796A588177667E756885877B86887C877D7989817886806E7D6F675B483E
4937314D493E6C6A52766E5884766293846C847D686F705C6F6D60766A5E6E665E6C6A58
6C614F36342D242B2747534B6352414E2416879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879793879591879B96879B96879B96879B967A68553B2B252F2A27282B28
1B1E1F28292632363223383A606459817F70878978878D818C968E9EB5A3B9BBA599B0A0
A7BBAEA6B5A8ACBFB194A594878776818777838A797E8F758384748A85748F947AA49A82
6E595035302F232A272C38355D5B50776E5E80735B6E6A5B736656625F4E6C635975665E
55443939302A3638342237345F4737291D18242A28879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B9687A09B879A96879B96879B96879B96879B9666645C3B3B352F2D292E2B28
282A24282A2732363230403F646258817E7087897887887C878D81879188879792879792
87938A87918887938A87928A8C92858684708C8E7D888574837C6D888070888573938D7E
B4A891B494848B6F603C3B34232A26262F2E343B393E4339454539665B5274695A736657
4D3B34302D292D2C2D1D22212D2A254C3E38202321879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B967A6D634F474130302B2A2B28
2F2C283030303537352D3F3D4F544B74746787897487847487887D878879878C80879289
87989387918887938B878D8187928A878E81878978898A78838574837B6C837B6C838170
8A80708588729F8C74A48F769681696E624E6C55457063548475646660566B635B636555
4E3E352F2C28262B26202824232D2B3A3B37202422879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B967463513D382E3F38322F2D29
302723342E2937342D3038343D47436B675C81847487897887887C879188878D81878C80
87928987928987938B878D8187897987897D878579898170837B6C838574837B6C837C69
8578688574648577668576658E7E6C97887391836F7D72627F695E7A705E7C6556624F40
4638302F2C2836302C2D2D29272A272E302A161813646867879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96665C4B41413C3A383338322E
252924262A262629262E312D2D362F4E4D42817F7087897887887C878C7F879893878D81
878C80878E82878E82878D81878E82878974838675838674837B6C837769837C6C837B6C
857C6B7B77667B73637F7B6A7672627A6F5F7B6E5F6F6E5E666A58666A5B60605141413A
2629242D2F2F2327282327231A1E1F242928242D2A494742879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B967A66543F3B3542413C383833
3C332E2F2C28343430353D3A37413F33403E746D61878474878479878374878C80879893
87918887938B878D81878D81878E86838579838674837C6C837C6C837B6C7F7B6C7A7868
7F78688177667A73637A6F607F7766767262776E5F786E5E756A5B7766565D514542352F
3C37322123232326271C1E1F2427282529272836353B3E3A879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B966D6D6543433E43433E44423D
38332E2628242C2C293B362F4F473B47463B655B4E817F6C878978878479878374878C80
87928987989387938A878D81878E818C8E818889787F81707A78687D74688574687F7464
7F6F648173667A73637A6F5F776B5C776F5F7366577B67586E62535C52494D42383D342E
2427232528282022232528242327272F2E2C4B595880918D879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879793838E8A6660573B3C373E403B3F3F3A
302F2A3835313335312F36333A423B4F534A625A507B796C878978878D81878D81878C7F
87928987928987938B878D81838A79818171898170887C6C8880707F7B677F77687F7766
7B77647B7766776A5F726B5F776E5F766E5F7B71616F695A6763536B5A484C413539322D
2D2D29292C282A2D28252824272B272D2E2B0604038CA09B879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B9687A09B8CA5A0625C51413C333F3C3641423D
4846403837323839343C3930384540424B414F4C4371685C81847487847987887D878879
87887A87887A878A7E8381728382727D80708385737F78647A74617F78647F77647F7B6A
8173637A73637F77627B6E5F766A5B7666586F6A5B6762535F5748473F393A322E282C28
2427232327271F2223171E1F1C212235373518110F879B97879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B967D6F653C3A3241403940413D
3B3B3536312D3A362E3C3D39393F393E3F3839403B655D53818470878974878474878575
8785718785718789798C8E818889788378697F75647F70647F6F647F736A7F77677F6F60
816F607A6F5F7A6F5F7C6E5F766E5E7366566C5F505F5546473F3A3E3A30302E29292C28
2D2C28262828212324222323332F2B637B7983938F879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B968A8C824947433A3B3742403B
443C323C3C35323431383A35323532343E3B31403B48443B6C695A7E8171818470878979
8789788385757E816D8184758985747F74647F78647B725F756F5D756F60796F607B7362
7B6B5C7A6A5F776A5F776E5B736A576F66566C605152473C433B302D2C28242723232727
292B282628281C1E1F1F2222292C2A010000879B97879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B968082724E4C4443433E3A3D39
3D3F3C33313132333033363140413D3C39302F332E303B394E4D446F6458786F627E786A
7E7C6D8385758381707D78698082707B776675685C7B6F5F7A67587A6759746B5C7B6F5F
776A5B726A587362546B5F54636253585244574B3E453F332D2C28282C28252824202222
1D2122171E1F171E1F2F2E2B3B342C120A05879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96B4C4CB665B5543423D3F3F3A
44454148413438312C3D3D393839343E423E3336322836342C3A35343E38564F476D6557
6B645B706C66707065747365787060645F505552466055466D6353726658725F50725F53
776A537366516F62536B5A4C675A4C564C4141372F3A312C302D28252723202223202223
1C1E1F181E1F1F2223242826627B7D77817E879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96A4C2B68282703F3E373A3C37
383A36353B3731323233332D3F3D3741433F4B49433839373A403E36423D363A3340433F
36403C3A41384A49404E50454E4E45514C4149453943473B4E473A594F40645F4A675747
574D44564A3E5E50445751484C433C463A3139302C2E2C282427232022231C1E1F171E1F
171E1F171E1F242A27312F2C0B0F0E869A95879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B969EAAB355504C40413C
3F433E41413C2C2F292D343241433E4445414B4D4751514A4F5146495147414B433E3F38
3D37313536343534313F3C37413F3A383D3C423E39413B323C3B3341413A44463C4A4539
4F4B3E48453842423A493F36433D3435312D3334302629242427232123231C1E1F181E1F
171E1F2B2B272427274C575447433F879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96B1C7C072655E3F3D39
3D3C373D3D3949443E42423E41433F484B4541423D3C3E3A3D3936473B35483B323D3C36
313531343A362D2F2C2D3332393C383538332B2E2B292F2E292D2A2628282B2F2B30342D
2E322C2F2D2A2C2A282C2C2A2D2D2A282C282026222023231F2223202223181E1F171E1F
2B2B2F2B2B29403E38455E5D82938E879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B9692ACA1ADBCB954504A
3D3D3940413D3F3F3A4548433B3B353A3E3A3B3B363B3E3A494C424145403B3F3C3D3D39
3D3C37413F3B3835342E3431302F2B332E2A2D2C28252A26282B272E2F2B302D2B292A27
262926282B272F2F2B2D2C28292B27252723242723212323202223171E1F171E1F1F2223
2D312C37322E6E7A777C8E8A879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96A6B6B56F5A54
45413D40413D3F3F3A2F3531424641474A4446494336393437373137342E343632363833
2D3034293332333331322D2B2C2C30252B28262C28242723252B27242B27242B27232723
1E2222202622262A262427231E2222232623242728212324171E1F2022232A2C28363631
332F2C7B8C887B8C88879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B9698B7AB90968B
4946403E403B3F3F3A46433E3A3F3B393E3A3B3A353435302D322F2D2C28323430303030
32302F2B2A272B2B2E2227281E22222226272327282022242126271F2223212627202224
242728272B28222728202224171E1F151D1F151D1E161E1F2327282428231F2222242421
6D7C7876817E879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96CDEFEA
94928843413A3A3C373A403B3D423D41464144424238322F34332F2B2D29262926272B26
292B262022231D2121232627252828202223222627212324222627212324312E2B1A1F20
202626262A28252828181E1F171E1F1B1E1F24272727292923272733302D473D32675B49
463C2D869A95879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
CDEFEA988D834A4A4438393441423D4446414A4A433C413A383A35332E332427292B2B28
242728292C282A2D282528282022232022231F22222022231F2222272B282026273E454C
414B4D3230362223242628282B2D292B2E292428273738343D393333312C48413B6B7C7E
81918B879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96D3FBF6978A8057524B383934363C38434843524E48433D333C38302D2E29222728
2022232126222327272022232022232327282023242327282023241E2122353F3E333439
4543435C5A4E534C49534E4846413B2D2E2A35353031322F40413C55483E7683807F8985
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96819591CDF5F08676645A544B4745404246414B4D4751544E3E3B353A373245413B
41413A322F2A2A2C28262928252828202223202223262A2E26292A292C281F23232D352E
3036332126262028251F26242025262B2B2830312E3C393052493B828B866D787A879A96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96D3FFFF838271414038363A374A4D49575C565D5D543E3B352D2E2E
332E2B413F3A3E3E38282A2A2022232C3034303338353A353234374242413131353D4242
4342414B464047433E423E3847433C52524747453E5A5448838F8A92A79B859894879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96D3F5F5D2DEE06D69633B3E3A3B3C3946515361656269665C
666B634847453D4344565C636E716D504B474042483E3E435355594446464B463D3B3E3B
4A463F493F3A493D3448433D4F4C425F52445B4638597275819690879A96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B969EBCB0DCFCF889878C51514E414644495A5E5C6565
545B5762685E6869645D5F5454534E535149514E4343424032332D383B3744464140413D
49423957483D5A4E4466574B55453C4D4F51A4B8BB7E8E89879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
87928E879591879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96D3F5E5D7F6F2D4DFD86E737F5D6166
7E818A8281876C655E5C5B55595A546C68656F6762706B60766F676A64575E5E556F6A62
5D6258515A4F454540566266B5D4DAB9DDD381928E879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
87A09B879A96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B9692ACA1D1EDD9B4D5CE
A4C0AFA8C2C8B1CCD4B0BCC4767D8D55636F525B5C5658524E5550595B5751534E44473E
4B4B427A8883DDFCF59BBBAF849692879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B9692AC9B869E9B9EBBABC5E0CEC1DCCAC6E7E4C6E0DBC6E0DCC6E6E1CCEBE6D1F6F6
D0EFEF7F9690879A96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.267442 0.732558 0.488926 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(225) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9A1ADA2
97907C9F95819F95879F9B8C9F95879F9B8D9F9B8D9F9B8D9F9B8C9F9586A196809A907A
9B8973947E6A967E698E79658E79658E79658E79658E786390735D89735C89735D89735C
8067539FADA99FADA99FADA99FADA99FAEA99FA6A29FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FA9A59FA8A49FADA99FA9A59FA8A49FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FA9A59FA8A49FADA99FADA99FADA99FADA99FADA99FADA9A4B2A8
9C93839F95819F95839F9B8C9F95879F9B8D9F98859C907A97907A978A789986728F806C
8F7E698C77648E76628A76628E79658E79658E75618E756190736289735E89735D898372
80796D9FADA99FADA99FADA99FADA99FB1AD9FAAA69FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FB1AD9FA7A39FA8A49FB1AD9FAAA69FADA99FA9A59FA8A49FA9A59FA8A49FADA9
9FADA99FADA99FADA99FB1AD9FAAA69FADA99FADA99FADA99FADA99FADA99FADA99CA99F
9A927A9F95879F92829F9B8D9F95879F94859C9484938E7D898473927C6C937866917D69
8E826D8E806C937F6A89735F87725E87725E87756187735B8B735D89735F89736294826F
949E999FADA99FADA99FADA99FADA99FADA99FA9A59FA8A49FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FAEA99FA6A29FADA99FADA99FADA99FB1AD9FAAA69FB1AD9FAAA69FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9A4ADA2
9C90809F95859F95879F92849F98899F9583A4998AB09B8B9B9A889E9282A28375977965
97776897776A93716490716189735F89735F89735F8973628C77628D766289735F806753
9FADA99FADA99FADA99FADA99FADA99FADA99FB1AD9FAAA69FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FB1AD9FAAA69FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FB2A8
9F937C9F957F9F95839F95879F95879F958B9F99899F9D8EA49D929A9C82A18F819C8978
9C8771997F6D9C88749C7567906B5F90776C8D79678C735F8C705D9075618C7B6885705B
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FAEA4
9F95819F95859F95819F95839F95879F998B9F95879F94859F9B8DA49D92A1A0899E937F
9A88779E8B76947D6A9C8671937C698E6E5A937E7189796787735F8B735F8D817692877A
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FA9A59FA8A49FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9968C80908E83
9F95859F95819F95839F95819F998B9F95879F9B8D9F9D8E9F998B9F9B8C9F958BA49987
A192799E88759E877499816D9979699378638B6D588B76638C735F8D735F837666979A95
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FB1AD9FAAA69FADA99FADA99FA9A5
9FA5A19FA8A49FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA96D62546C7B6F928979
9F95819F958B9F95899F95859F95879F9B8C9F92809F97859F98899F98899F95839F9986
9C8F7D9C86759A80719B836A9178629179659376628D735F887B68937D698A74609CA8A4
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FB1AD
9FAFAB9FAAA69FADA99FADA9
9FADA99FADA99FA9A59FA8A49FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99396965B372E2130369C9383
9F99859F998A9F998B9F998A9F92849F9B8D9F9D929F95859F98859F8A7B9C7F74957B68
97866F9A8472978771937E6D947E679377648B785F8B735D856D5B87735F8369559FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FB1AD9FA7A39FA8A49FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA9A1B0AC5B443197968466685B9F9587
9F92829F98899F92849F98899F95879F92849F97899F9B8C9C92829791799C84769B836F
907B67927D69977D65967F6889756191725E93756390735E8D735F8C77648365529A9A93
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FA9A59FADA99FAAA69FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA94F3B2BA1A4987378719C93839F9581
9F95879F95879F95839F95839F95879F998B9F95879F9889A1756D9A645C975954975651
94555094675C91736291735E8E705C8B70598A735D8E735F90735B886C57835F4B887565
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FA9A5
9FA8A49FADA99FADA99FADA9
9FADA99FADA99FB1AD9FAAA69FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA9939692E0DED7696C669F98899F95869F9581
9F95879F927F9F8E7C9F8E779F92809F92849F8B809F7F78A18175975F519350418F554B
91574B8F4D49935D5387665687735B8B6D5A88705C8E735F9373628C725C9372607E5A44
9083759FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FB1AD
9FAAA69FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA95243393A494597927E9F957F9F95839F9581
9F95839C927E9784719A8B799F93809F8E7B9C766695594D916D5E8556418474618C7E6A
935444834033914C418D574D89685B897252856E538A735D8E735F8E77628E6E5C8E7662
876B569FA49C9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FA9A59FA8A49FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA9837E7AB89D875258519C93839C8E7C9A91829F9989
9F8E7E9E856C8F725B8D6B62996158631E125D54479775679C7165AFB4AB986155885947
806F51776A576A4B37723E31865045856C538C6A538C7460927E669379628E77648E735F
815F4B907B699FA49C9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FA9A59FA8A49FB1AD9FAAA69FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA96152474D5D5D8A83759F9581A1907C9781709F9889
9F95849F765C8E664E5D1D15635F5BCBD9CD838C86A3C1BB9EA9A99C948EA5C8B0AEA79A
B1B3AE908A7E7454453D2F1C5736297E5E4F887057927261927D6C99856A93765F8E7561
8E7461816F648D90949AA4A09FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FB1AD9FAAA69FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9969EA25E3D3311262E9790789F9583A4A28B9C8F7C9F9587
9983709071517A452E7226144A201D8862559778679A83759F9C889F927C9E887890776A
998571B09582B9A3889C84734635274F32297D5D4C886F5B97867099857396816A8E715D
8E6D5B8B6E527C7B727D7E7D909AA09FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA96D625434221985736850504E9C937F9F8E799F87739F8E779F957F
A28F77A78575A5AA8ECDC6A6837F729C7770977C6C8E6456936862916058915E4F883D31
8C4C437F544897735D936154996F6041190C51353085685A927F689B896E9679628B7863
8A756293715D9E978794938E8388939FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FA9A59FA8A49FADA99FADA99FADA99FADA99FADA9
9FADA99FADA9969A9A34261C291E1718383B8F85799F927D9F8D809C8A7D9A8E7A9F8A7D
A28B798B634B856D5F9C978B9FA690A49F91A6A596A3A3939EAB91A8947D9E99809B9476
9B856B91625396685D965143904230833323471F1768433F8D74629B856E967C63906F5B
886D5B8E72605232226364539294959AA4A09FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FB1AD9FAAA69FADA99FADA99FADA99FADA99FADA9
9FADA99FADA9A3B2B2FFEBDAC7AB8D5E5C519A92809F96809F9C7FA4877F9C877C9FA284
A2917C9F7E6A8063519A8A799F9B8D9F998A9F92849F9B8D9F8D85A18A7B9A84719B8372
947E67937B6183795C8E7C62968068A1846A8F7064735344836D5797806A967C6390775D
88715C8E74617E64542C2E299098909CA8A49FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA9AEAE9497958EA4A6979E9382958C789A95819F93839FA28C9F928B9F998C
A59D899E8B738A64538B73609A91809F9F909F998A9F95879FA88FA18F7C977863977A63
8E795D87705C7E6A50825F4C82654C82624C86694C856F628A7661947A6993745F8B6B5B
85705887705B54382C2834348A90959FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99CA6A29AA69E9C8E76957C638E857B8D8C829C90809F99899F9D8E9F998B9F9F90
A4948CA38D7E9E816A8F6B5C9783729F97899F8F849C82759A94819E907897826D8E6351
8E6D5C8E6952826650846A53876A50886D4E84624A84675392766291766292735F896D5A
896E5E8C77623924210616118185849FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA9A4A6949C9A8E9E8C78937E6B9C7E628F867F9F877C9F95879F9B8D9F9B8D9F9B8D
9FA88FA49380A08E7290705A9277679F95879FA893A4938B9C9387A598899985739A846D
906E5B8E6E58845F4E84655183695B90705C967A678D76629178639175619377628D705C
896E5885705B512F22151715373B389FA8A49FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FAEA49C927A9376598E7A679780759C937F9F8F809F95879F9F949FA0949F9B8D
9F9B909F9D8BA2907B94856A8E76609A8E7D9F98859F99879F998AA19984987E6A917662
8B735F9077628B705288644C8366548B7566947D6D99806C9685708E7D698B76628B7762
8971618C7B66CF9262683C292218134549479FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9F9E929983738E5345956D5F7A665A88987F9F8F7F9F95819F95879F97869F9D909F9B8D
9F9B8C9C9282A199829C92809A8D789C937C9C8A7B9A85749F8B7D9E8270987A628B6B59
886754856C4F7F604C7E624C856C5A8A7964927D6C9B836F967A668E76629375618D735B
8C6F598C716098806DB0876ABFA8976E7A779FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9F9F9CA27B6F976554895D529274628F8E809F998D9F99899F95879F9B8D9F9B8D9F9889
9F9885A196829C907A9E8A779790809F998DA4A6939C8F859F997FA28777937A63886955
836450795E4F8B6B558574618D766392806D92826F9B836F967E698E78638E6F5F936B62
896F5C8A6F628C705685675381604DA4B1AD9FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FA296
9FA992A28E749370538865548A79699C93809F95879F9F909F95879F94859C907D9A947E
9F8A7FA186799588739C8370978C799F92809F98859F95879F9089A27D6C9775608A6B57
886A56836D5A80715A85715C8C7966977F6C94806C977C68967A668E735F8E6F598B6D59
8B715B88725F97806F8B6E5A7458488D94919FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9999782
8767526D513C6953437564558D7F6F9F95819F92849F94859F98859F927BA1927F958475
958A729780759A8E7D9A8F7B978E779F95879F95859F95879C9E859E8C779775608A6B57
8467548B6956856E5E8B7464927969907B67978471948570967C678E7F6A8B78638B705C
896A5E8871628860458A65538D60478062569FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99F8F77
5F3820573C2F43312A4344429083769F95859F95839F957F9F95879F998CA4978BA1A08E
A38F82947C6C8F6F61907D6B9588759A927E9F95879F9583A18D7E98816D8F6A5F866653
81634D7E66548C726087735D8C72618F776891705F8C76638E766287725E8B756189725D
896D5C85685889785778543C876B588051439FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FA69EA7A89E
B170565437274C352C2F393C90836F9C927B9A92849F958596856D8878647F6853745D4A
7865567C625988685D8568578D74649287759F95879F958BA194829D816E90735384624C
8567517A63507B6453796D5A7F6D5B8579648E7B678A7461937C678D766289735F89725D
896D5C896E5F7A523E6035246B4D377B4D399FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99C9D8D9E8E7B
3F180F2A1B152C241E1B32379284729F927D9C90789F9583AB9D858D77627A665152473D
39322B3C3323524135683E2C6132246C51449A8E7D9F9587A199849D846E907058816E50
7D60477C6A58927763947C678C746189695B856E5D7F705F8E7965907863836F5B7B6F5B
81715C89715F8D624870453168413478412D9FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9A1B0ACA8AFA29C7D65
865244301E1832201A10262E9C917E9A947F9A907C9F9581A49D8CAE957EA98E7D805D48
3E281F32241B36342F5D5443846E5B7B645897917E9FA195A1A1929D8971896652795743
5A2212503931775B41735942614B38695A47836A59786B5587725C8B75618B6D587F6A57
7C6A5C836756744F3E644A396C574A7F4A3CA4B1AD9FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FA5A19FA8A49FA9A59FA8A49FADA99FADA99FADA99FADA99FADA9431E153E47459E8670
905B4539292C241C17051D26958C789F95819A907B978E7A9A927EABA59292846CC4977B
B79274936F52815A3F736D56806D598F7463978B789F9786A199899D8770997054815E4B
8E644856443E504844150C0B342D26423A313B2D21403C355C4A356D563F876C577F6B59
7C6D587F624F5C412F43342A535245815C4AA6B3AF9FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FA7A39FA6A29FB1AD9FAAA69FADA99FADA99FADA99FADA94B2D25462F2613070332221D
352226291E172F221C061E289A907B9790809A7A6C8A6C5D8D806EA49D92A6A798AA9788
9A7C699E8470977C688C745F92826A97806E9789779F9B8DA196889D8C7890785D89704F
8C7050936B52A2755C36221F211E1842302A41332C3E392D6C57487266538C6952836A57
7C715A6340354833253F2C20393229794634A1AFAB9FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FAFAB9FAAA69FADA99FADA99FADA99FADA99FADA99FADA96D43373F2C213D271F29201C
1E13112E1F1B34211B1021299C8C789A8C75A9AE989C8A787559446F55446E5A48605142
543F344F3A2C5843325E40316D5D4D908472978A779F9481A1967E9D837090786388604C
7F6D4E7E6B4F927D64DBA07B8F77618159428458426D5C4D82694E7C655185765C8F735D
7F6D5C61422C36231D3D2B203C32266E2E1E9FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9784E372A1710221C15261B15
2E1F171F1B1534302A1B2F338D8270A4937F9C9380AEA699B6B09A987D6C826860897365
98725C886B587E634E86715E857061978D7E9C93839F8A82A18E7F9D87729073676E4534
5D362962523E817053897359957A629E83678C7760796C56816F5D896D5B7F6A5C817058
7F644D37281E221D16444B416546325F27189FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FA9A59FA8A49FADA99FADA99FADA99FADA986624C391B122B1B15221C16
130B0B241A15302B262938377770619A8C799F95819F998BA4A196B0B8A4C1B39E9AA799
B2B3A5ACAB9CB2B5A59B9C8A998A7697937F9C9682979A7F9C8C7AA08D78A0977AAE937C
754E43402A2333271D4840357463528B735D92775A7F6D5A866A5574624C80675A856A5C
633F2E3B241B322C2522302970422C371B144A504E9FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FB1AD9FAAA69FADA99FADA99FADA99FADA97160553B2E262C1D172A1C16
221911231A15312B26343F3B746A5C978A779F95819F95879F9B8D9F9F949FA49B9FA49B
9FA0949F9F949FA0949F9F94A49D8B9C9078A49B889E907A9A88739E8A769C8C77A69281
BEA48CAF87778762523F312631251B3F322B4A40365646355947357A6053806A57866956
5330252F1F182A1F1E1F140F3D201655372E2125229FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA986695D4F3D352B211A271C16
2B1D172B2120332C28333D37635C4F8D81709F957D9F92809F97899F97869F9D909FA198
9FA69F9F9F949FA2979F9B8D9F9F949F99889F9581A1957F9A8E799A84719A86739A8A76
A08775988C74AC8A70A4856C90735B6B5641714F3C725F4D886F5C6E5C507F675B786753
5432262C1D17221B151C1811241F1A40322C2327259FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9825E48402E213F2C242A1E17
2D171031201936291E36332C4E4E448173649A927E9F95819F95879F9F949F9B8D9F9D90
9FA1989FA1989FA2979F9B8D9F98859F98899F9281A18D789A86739A8E799A84719A866F
9B806D997C68987E69967A64997F6A9E846D957C67846E5B8D6A5B89735C8C6655714D38
4B2D222C1D1733211B271E17231B1530251C21211C8183829FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA97156404438313A2B2436241D
1F1811241A15241A153329203A3629665A4B978C799F95819F95879F9A8C9FA69F9F9B8D
9F9D909F9D909F9D909F9B8D9F9B8B9F957D9C927E9C907A9A84719A826F9A86729A8471
9B836F917E6991796593806C8976628E75618D735F83725D7B6D587B6D5B74624E4B392F
251A122B21201D17171E1710120B0A241C182C2D275D57539FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA986614B403129433730362B24
39251E291D1631262035322E3E3B3443463D8D7B6A9F927E9F92849F93829F9D909FA69F
9F9F949FA2979F9B8D9F9B8D9F9B909C92819C927C9A86729A86729A847197847192806C
97806C967E698E79658E7662937E698976628B735F8B725D856D5A8669556C4F3F472A21
3A2A231911101E1716130B0B1D1716201A152D322F4846419FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA97A695E463A32443A33443830
36251E2118112A1F193C2C225241334E46377C67569A8C759F95839F92849F93829F9D90
9FA1989FA69F9FA0949F9B8D9F9B8CA4998A9E937D978A7592806C957D6D9B7D6C947C68
947768967A698E79658E75618B725E8B7561866A568D6C597F64506F54455A3D2D40281F
1F17102018171810101E17111C16152C201B3B47477E88849FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FA9A59CA29E715B503D332C41373141352E
2E20193628222F2721302A25413C315B52447560519285749F95819F998B9F998B9F9A8C
9FA1989FA1989FA2979F9B8D9C98849A8E7CA18D789E86729C877494826A977E6C947E69
917D66917C698B70618771618B735F89735F8D7560816B597C65507A58415238273A251D
291E18231D16241D171E1710221C152A201B020202A4B1AD9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FB1ADA4B3AF6B554843322640322A433932
483A32342922372D263C2D213C3F385049396353458875659A927E9F92849F97899F9786
9F99899F99899F9A8C9C907D9C907C958C789C8F79978068927D66978068947E6894826D
9679658E7A66937B638D715F896F5B896B59836F5B7C64507058435238303F271F261D17
1F17101D16151810100D0B0B150F0F342C28140D0DA1AFAB9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9896B5E3D2F2344372E423832
3C302936241D3A2B1F3D332C3D382F47392E4A43397C675A9790789F957F9F92809F9481
9F947E9F947E9F9885A4998A9E937D9A836F97806A977968947766947B6D947E69947662
9677648E75618E756190735F89725D8669557F624E7056415239304732232F1F18251D16
291D171F17161911111A11102C201A475E5F787F7B9FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99A8D814A3C353C312A453731
4531243C30283127213A3029342B253A38313D3D335E4C3E867965978E7A9A927A9F9583
9F95819C927D978E779A9280A1907B977E699780689178618C76608C76648F7764917964
91705D8E70618B705F8B735B866D568369557D614D5F42334B33232D1E172018111D1615
251B16201816140B0B171010261E19000000A1AFAB9FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA991847153443A443A333C332D
403530322422322721332B244238323D2E21342C23423E36665748897361907D6B978773
978A779C927D9A8C78958572998D78937E688C6F5E9176618E6C598E6E5C89725E917561
8B6F5B876F598866547F65547866506B533F694C384D37262E1E17261D171F181118110F
1610100E0B0A0D0B0B2A1F1A36251B0F08049FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9C5C9D068504845393241352E
463D3648352535231C3D332E382E2741393333292331312B3D3A30504538715D4F87705D
8671648A796E8A7D6C8D7F6C907A657C65506E5745785B45836954876A5887634F876654
8B6F518669518364507D5C49775C496347384B2F223E251D2E1E171F1710191110181110
130B0B0E0B0B1710101E1914546769696C689FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9B8CDC28B7D6940332A3D332C
3A312A36312A30252334271E41342C423A344C3F37382F2A403A35413D35493B2E574940
4D463C544838645344675947665445664E3C58433157483464493570533E7962487B5844
6D4F406D4D397252416951435C40345133243E241D2E1D171F1710191110130B0B0D0B0A
0D0B0B0D0B0A1D1A152C201B040B0A9CA8A49FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9B0AFB756453E413731
403A3342362F2820182D2924433A33463D364F463E52494050493C4E4A3E49453948382F
4631273E302A443028503D324E3C334338334D382E4C3426493629533F335746355D4431
604A3756402D523F33573A2D4C362839251E3528212218111E1710191110140B0B0E0B0A
0D0B0A251B151D1615464C493C37349FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9C3CFCA765C5440332D
3F332C3E342D4839313E3630423A344C443C443A3341373142312C4E352B4D332741342B
33292338312A30221D342C273F342D372E272E221C2E25202E211B2D1D1935281F392C20
362A1F37231C331F1931211B32211B271E171C16101A11111710101811100E0B0B0D0B0A
251B1F251B173E322A31494B868D899FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9A8BBB1BABCB954433B
3E332D42383240352E4740393C30293F38323E322A3F36304C4538443B3440352F40332C
3D312941352F3627252E292331221C33211B2A1D17221B15261C162E211B30201B281C16
261B16271D162F211B2A1D16271C162017101E17101911101810100D0B0B0D0B0B171010
27221D34231D5963616E7A779FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9BAC0BF755149
46383242383241352E302B2447403848413A484038362E273B2F253A2921362C26372D26
2B23272A292433262330201B2A1D21221C17231D161E1710201B15201B16211C161E1710
1810101B1610231B151F17101810101D16101D17161911100D0B0B181010221C16302720
2E201B6875726873709FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9AEC4BA9D9287
4A3A3241373141352E463A333A36303E37303E30293529222D26212D1E173229232F2321
312321271B16281D201D17171811101C16161D16161911111B15151810101C1615191111
1D1716211B161C17161911110E0B0B0C0A0A0C0A0A0D0B0A1D16161C171017100F21140F
5E6A67646A689FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9DBF2EE
94867B42352C3D332C3C37303F3932443E3745383637251E332620261E18231A14241D16
261C161A111117100F1D16161E17171810101C16151911111C16151911112D1F1A100C0B
1A1515211B161F18160E0B0B0D0B0B120B0A1D16151E17171B16152F211C412F215B4C3B
362D219CA8A49FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
DBF2EE978075493F37392E27433A34463E374D42393B352D372E262F1F241E1717271B16
1E1716241D17231D161E171618111018111017100F18111017100F221C161A16153D3941
393C3D2C20251A11111F1717231D17231D171D1715332B25372A232F221C48372E5F6A6A
84867E9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA9DFFCF8977D72564840382E273A352F47423B54453D4231243A2B21281E181C1716
1911101B15101D16151911101811101D16161911101D1616191110160F0F3233322F262C
463D3D5950444D3D3B4B403A40332B271F183227202D251F413731533D30646D6B7C7A75
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99AA8A4DDF9F5886A575B4B41473B33453F3850473F544B443D2D25382A2340352D
3B332A2B1E18241D161F18171E1716181010181110201B1F1F1818221C161913122D2B23
322C291F1717201B151D19141D1716291D172D241F3C2D21514030797D786A6A6A9FAAA6
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA9E0FFFF83756343352C3A332D5049435B574F5F544A3B2D252B201F
33211C3F342D3931292219181811102721252A2328302C252D25293D36332A21243A3836
4137354A3A3241352F3D312942362E4B453943382F574A3C747B7590968997A1A09FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9E0F7F7C7C8C7685B533F36304339334E4F51645D5865594F
605D564639373D3A3953515864605C483B373C353D3B3336514B4F413A394B3B31393430
4E3E354A352E4A3327493A324F43375E4B3B5C3C2B506366848B829FAAA69FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA9B3C8BEDFF1F086797D52494344403E50585D626160
5B5751676358665F5B5C574C584F4B584A4051463A4238363429223D342E473E37423832
4E3A2E5A3F325D4639674F40573C30544D4CA2A7A5737A759FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FA5A19FA8A49FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA9E0F7EAC7D9D9C2C5BE6C6975676366
827E87837B7F716259645A526158507163606F5F5971625772645C66594B5D564C6F6259
5E594D5752454C3D355D5F60AEBEC1ABBDB4848B899FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FAFAB9FAAA69FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9A8BBB1DAEBDDA8C0BF
A4B5A7B0BEC7B1C0C8AFAFB57B77845E616B5E595961574F58534C6459535950484E4438
574A3D778079CCDED78CA1989199999FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA9A8BBAD9AAAABB3C6B8CBDACFB8C9C0BDD3D5BAC9C5BAC9C6BACECABFD2CEC1D9D9
BFD0CE7988829FAAA69FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.267442 0.97619 0.488926 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(248) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1C1C5BA
B6A48FBFAA95BFAA9BBFB1A1BFAA9BBFB1A1BFB1A1BFB1A1BFB1A1BFAA9AC1AB93B9A48D
BB9C84B3907AB58F79AC8A74AC8A74AC8A74AC8A74AC8972AE846CA6846AA6846CA6846A
9A755FBFC5C1BFC5C1BFC5C1BFC5C1BFC6C2BFBDBABFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC3BFBFC1BEBFC5C1BFC3BFBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC3BFBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1C3C9BF
BAA694BFAA94BFAA98BFB1A1BFAA9BBFB1A1BFAE9BBEA993BAA993BAA38FBC9F88B29881
B2947CAD8B75AF8A73A98872AC8A74AC8A74AC8770AC8770AE8470A6846BA6846CA68F7A
9A8271BFC5C1BFC5C1BFC5C1BFC5C1BFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC8C4BFBEBBBFC1BEBFC8C4BFC0BDBFC5C1BFC3BFBFC1BEBFC3BFBFC1BEBFC5C1
BFC5C1BFC5C1BFC5C1BFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BEC3B8
BBA88FBFAA9BBFA895BFB1A1BFAA9BBFAC9CBEAC9AB8A591AD9C87B49581B6907AB1917C
AC937CAC8F7AAF8E78A6846EA7856FA7856FA78770A7846AAA846CA6846EA68470A98870
A9A8A2BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC3BFBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC6C2BFBDBABFC5C1BFC5C1BFC5C1BFC8C4BFC0BDBFC8C4BFC0BDBFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1C3C5BA
BAA491BFAA97BFAA9BBFA899BFAE9FBFAA98C3AD9EC9AC99B0A997B8A18EBE9282B18A74
B18B79B18B7AB08675AE8470A6846EA6846EA6846EA68470A7876FA98670A6846E9A755F
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC9BF
BFA68EBFAA95BFAA98BFAA9BBFAA9BBFAA9EBFAD9ABFB0A0C3B0A3B9AC93C19E91B79884
B7947EB68E7DB89582B68373AB7E6EAB8778A98873A7846EA7826CAE8770A78A759E7B65
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC6BD
BFAA94BFAA97BFAA94BFAA98BFAA9BBFAD9EBFAA9BBFAC9CBFB1A1C3B0A3BDAF98BCA28E
B99987BC9C86B38D7ABC9781B08875AC7E6AAF9081A68873A7846EAA846EA58D7EAB9280
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC3BFBFC1BEBFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BBAC9FB3AFA5
BFAA97BFAA94BFAA98BFAA95BFAD9EBFAA9BBFB1A1BFB0A0BFAD9EBFB1A1BFAA9EC3AD98
BDA38ABC9986BC9984B6927DB78A79B08972AA7F69AA8A76A7846EA9846E9E826FB6ABA5
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC8C4BFC0BDBFC5C1BFC5C1BFC3BF
BFC0BCBFC1BEBFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1957F6E99A296AB9788
BFAA95BFAA9EBFAA9ABFAA97BFAA9BBFB1A1BFA896BFAE9CBFAE9FBFAE9FBFAA98BFAD9A
BEA38FBE9B86B99481BB967CB18973B18A74AF8670A9846EA48A75AF8B75A17E68BABBB9
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC8C4
BFC3C0BFC0BDBFC5C1BFC5C1
BFC5C1BFC5C1BFC3BFBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1B8B4B47A453A334346BAA693
BFAD97BFAD9EBFAD9EBFAD9EBFA899BFB1A1BFB0A3BFAA97BFAE9BBFA292BE9A8BB99780
BA9F86B99784B89981B68F7EB38F76B08772AA896EAA846CA37F6BA788719F7963BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC8C4BFBEBBBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC6C37D5740ADA69A555652BFAA9B
BFA895BFAE9FBFA899BFAE9FBFAA9BBFA899BFAE9FBFB1A1BEA897BAA78EBE9789BB9680
AF8E78B4917BB89178B5937AA88770B1856FAF8772AB846BA9846EA787729E7964BBB7B2
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC3BFBFC5C1BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C174503CC4C2B8626662BAA693BFAA95
BFAA9BBFAA9BBFAA98BFAA98BFAA9BBFAD9EBFAA9BBFAE9FC18F83B98074B8726AB87166
B36E63B3806FB18873B1886FAC836CAA8168A9846CAC846EAE846AA47E67A37761AA9183
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC3BF
BFC1BEBFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1B8B4B0F2E8E35B5E5ABFAE9FBFAA9ABFAA95
BFAA9BBFA895BFA592BFA58CBFA896BFA899BFA598BF9A90C19789B86E61B66050AF645B
B16558AF5F59B37364A77967A7846AAA7D68A4816AAC846EAF8470A78269AF816D9D725B
B3A79CBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC8C4
BFC0BDBFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1735649666F6CB6A896BFAA95BFAA98BFAA95
BFAA98BEA893BA9C85BBA18CBFA691BFA591BE8F7EB97264B78475AC644EA77C6AA97D6C
B35F4EA35040B15D51A9685CA67A6AA68260A37E63A9846CAC846EAC8670AC7E6AAC8872
A37D68BFBEB8BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC3BFBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1AC9D9AD5B49D45504FBAA694BEA590BBA795BFAD9A
BFA594C09E82B28A70AE8578BC7D6F8C2E1B8E7665B88072B8796DC2ABA2AA6859A8725C
A57F5F996D5D8F533F964E3FA46456A37E62A77A5FA7846DAD8C73B08870AC8772AC846E
A17862B39C8CBFBEB8BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC3BFBFC1BEBFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C18264586771729B8B7CBFAA94C1A691B69784BFAE9F
BFAA98C18B6EAF7B6083291E947D77DBBDB57B6864BCBAB0B8A19DBA9D95C5D4BEC4978C
BEA89FA48C7C915F4E5C39238046379B705EA47F63AD816EAD8D7AB79578B0866EAC8770
AC8570A18271B2ACABBBBEBBBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BBBBBD79493E193139B6A48CBFAA98C3B39BBA9E8ABFAA9B
BC9B85B787629E543A912E1A572C2AA28173BA9988BBA295BFB7A6BFAD9CC0A493B29281
BCA18CC9AA99C5A890A27D6F593A2B7545369C735EA67F6AB4967FB69580B59278AC826C
AC7F6BAA83689F9894A59F9EB3B7BBBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1957F6E59362BA68D84404449BAA691BFA58EBFA08ABFA58DBFAA95
C3A38AC1917FB2A386CBA68E7B6A5FB78279B8907EB17D6EB78980B78173B77965AA5646
B06A5DA37060BC8C72AE7465AC7A6A561E0F754940A17A69B09178BB9C80B58C73AA8972
A9836FAF826DB1A494ABA29B9F9EACBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC3BFBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BBB8B74A30243F271F1634399F8A7FBFA891BFA493BE9D8DBBA08BBFA291
C3A18BAD765BA58373BAA999BFB69FC3A99EC1AA9CBCA798B8AD97C49685B69C87B59078
B5826CAB6C5DB17C6DB06150AA523D973C2A59271D8B5B54AC8973BB9A80B58E72AE806A
A47F6BAC8671764632908E82A9A3A9BBBEBBBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1C5C9C9FFE5DA938776484D4ABBA896BFAB93BFAC91C39990BA9E8FBFB396
C3A08DBC8D7699715DBBA291BFB1A1BFAD9EBFA899BFB1A1BFA499C1A28EB99781BB9682
B38F76B38B70A3856AAF826CB0816BAF7D6798695E845648A28069B8947CB58E72AE866C
A4806AAC85709A705F3C3832B3B3ADBABBB9BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1CAC6B1AFAAAAC3B6A4BCA18EB5A18CBBAA94BFA694BFB39CBFA099BFAD9C
C5B099BA9980A97663AD8D78BBA796BFB4A4BFAD9EBFAA9BBFBAA2C19E8DB88D76B88F76
AF8C6FAB836C9E7C5FA1715CA1785CA1735CA4795C9F7A6FA4836AB38D79B3886EAA7E6A
A38166A7826B6E4435373F3AA29F9FBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BEC0BDBBC1B8BEA58BB9977DB5A195AEA193BAA491BFAD9ABFB0A0BFAD9EBFB4A4
C3A99EC09F8DBA8F77AA7C6BB69B87BFAE9FBFA89ABE9D8EBBAC99C0A58BB8957DAF7661
AF836DAA7A609B775FA0785FA1775CA37A5AA070569C7760AD8872B18A73B3856EA67D68
A67E6BA7876F4B2B27152321A19FA4BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1C3C0B1BAB3AAC0A38CB6947EB79073A69B95BF9E8FBFAA9BBFB1A1BFB1A1BFB1A1
BFBAA2C3A291BF9D81AF826AB28D7BBFAA9BBFBAA6C3A199BAA696C5AC99B69580B89279
AB7A66AA7E65A06E5AA0745D9E7867AB7F66AA846FA37F6AB18972B18770AF8670A97F69
A67E66A3826B6637282823215F605BBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC6BDBEA88FB98E6EAC8D79AF9081BAA691BF9E91BFAA9BBFB3A6BFB4A6BFB1A1
BFB1A4BFB09BC3A18AB39578AC8670BBA594BFAE9BBFAD9BBFAD9EC1AD98B9917CB18A73
AA846EAE866FA57B5DA372599E7662A58372AE8877B68F7AB5957EAC8B75AA8670AA8670
A6806DA78A72DD986A6A3E2D3928227A7B79BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFBBB0BCA391B56F5BB78874977363AAAA91BF9E91BFAA95BFAA9BBFAE9CBFB5A9BFB1A1
BFB1A1BEA897C1AD94B79E8BB49A83BAA68EBEA291BB9F8BBFA595C09C86BA9075AA7E68
A87A64A37E5F9F715A9E73599F7866A48670B08D7CBB9680B58D77AC8A73AF8770A9846A
A78068A7826FB4907ABE8B6DAA82735E615FBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFBAB6C39383B67561A6685CA9816FA6A091BFAD9DBFAD9ABFAA9BBFB1A1BFB1A1BFAE9F
BFAE9BC1AB97BAA48DBC9E89B6A491BFAD9DC3B6A1BA9E93BFAD92C39989B38C71A87963
A2755F986F5CA87B60997C69A37F6CAD907BB0937EBB9680B58F79AC8972AC806EAF7E70
A68069A97F6FAC8365A37863996B56C3C8C4BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFBEB4
BFC3AFC39C85B47C60A46F5FA18776BAA691BFAA9BBFB4A4BFAA9BBFAC9CBEA996BBAC96
BFA295C1A08EB59E87BE9883B6A18CBFA896BFAE9CBFAA9BBFA69CC3927DB68870A77B65
A378629D79649A7C659F7E68A98B76B4917CB3947EB8907AB58D77AC856EAC8068AA7D68
AA806AA4816DB3907DA57A64956E5CB5B6B3BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BCB39E
B0856C986A4F946853927260A78D7CBFAA95BFA899BFAC9CBFAE9BBFA892C1A895B59C89
B9A288BA9489B9A08DB99F8AB6A089BFAA9BBFAA97BFAA9BBEB099C09C88B6846DA77B65
A07661A578639D7E6BA58570AD8B78AF8E78B89781B3957EB58C76AC8F78AA856FAA7F69
A67A6BA4826FA87254A97764A974599A7E75BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1C1A88D
82482A7B4D3D5E3D34615751AD9586BFAA97BFAA98BFAA95BFAA9BBFAD9CC3A999BDAF9B
C09E90B3907EB28777B19782B59F89BBA892BFAA9BBFAA98C1A493B99880B07D6EA47760
9E725B9B7662A7816DA3846CAD8673AF8B79B18671AD8C76AF8A73A7856FAA8770A6826C
A67D6AA37A69A98865966148A77F6A9A5D4BBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC0BAC7BFB3
C8795C643D2D633E35394145AD9581BEA892BBA899BFAA97BB9E84B0957FAA856DA17D67
A48371A57A6FAA7E6FA57E69B08E7AB29E8ABFAA9BBFAA9EC1A994BD937FAF8262A0705A
A1765D95725D9C76639D806BA17F6BA58B74AF8B76A98570AF8C76A98670A6846EA6826C
A67D6AA67E6E9B634A82462F8D6248965946BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BEB9AAC0A895
591F1444251D422D25273B40B09783BFA891BAA48CBFAA98C9B096AD8A729D7A6174584B
5B42386446317A574990523B8A4A35927262BBA594BFAA9BC1AD98BD967FAF80659E7C5C
9B6E53967965A9826EA88873A1826DA67C6BA6836F9D826EAC8A74AE8972A2806A9C806A
9F806AA6806EAA7053864E387D4B3C914E36BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC6C3C6C7B9BD9277
A05C4D3C221B40261F122B35BAA28DB9A790BBA48FBFAA94C3B09CCAA48BB59583936550
502F26462D225141397C604C936E5C876257B6A28DBFB2A5C1B3A2BD9B81A97760986950
792C18735144997152986F5689604991705AA27A68937C64A7856DAA8770A87E679A7A66
967A6AA27A65955E4A7F5642815E50944C3BC3C8C4BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC0BCBFC1BEBFC3BFBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1642B1F797A72C09A82
AB664E482E3233211B0D222DB5A18CBFAA94B9A48EBAA58FBBA892C9B6A2AD927ADCA388
AD89718767507E5A43766F5D917360AA8472B6A08CBFAE9CC1B2A1BD9C82B57F61996B56
A46C4E67474072584F2811105A3F34604A3E5C3D2C695549846045916D53A57E679A7A65
967D669F735D7A4D385F3F336D5E50996251C8CCC9BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFBEBBBFBDBABFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C16D3E33674034290B06633C30
522E323C261D3D282205212CB9A48EB6A491BE9481AF8976AE9885C3B0A3C1B5A3C3A291
B28A75B5907BA6826C9D7C66A98F75B48F7CB69C88BFB1A1C1AC9DBD9E88AF8669A47B5A
A0785A9F7059AB7C654227242E241C593B34553D344F43367F6352836E59A6765C9D7A66
968068824E40623F2E5435274E4136985E49C4C9C6BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC3C0BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1884E404E33264A2C233A2621
2E18163C2621402720122731BAA18CB9A189C7BCA8B692819A6F579E77629C7C648E6D5B
8156467A513D825B44885743957864B19683B69D89BFAC99C1AD94BD9682AF8971A37157
9A7D5A9B785BAC8A72E09D7D77685B805944885C48675C508C6F5595725DA3866AA88069
9A7D697C4D35492B234F33264E3C2E893A28BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C19359403A1C1433231B37211A
3C241C2B1F1A44363024353AAE9884C3A691BAA691CAB6A8C8B39DA882709D766A9A7D6D
A077628E6C5B8A68539174618F6F62AF9A89BAA694BFA297C1A592BD9982AF85758F543F
824935846A4F9F8163A68468AE8870B18A6F9C7A648B735D9E7C69A67D669A7A699F8166
9F765C4C312533231B474D456F4A37762C1BBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC3BFBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1A37057481F163820192F211B
1F0F0E33201A3E322C384442988674BBA18CBFAA95BFAD9EC3B2A6C9C0ABCCAC9B9E9E95
C0ACA0B6A192BAAB9BA59585B29380B6A691BEAB97BAAE95BE9C8DBFA089B8A286C09481
8753475D362C563929755B49957863AA846CAC86689A7D68A47C6392735C9F786A9D7A69
824E39502C213E312A2C39318F4F36572E247D8380BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C18E6E624D342B39221B37211B
2D1D152E1F1940322C4149458C7A6BB69D89BFAA95BFAA9BBFB1A1BFB3A6BFB6ABBFB6AB
BFB4A6BFB3A6BFB4A6BFB4A7C3B09BBAA48CC3B19DBCA48DB99E87BC9E88B79D87BFA18D
CDA68FAC7F738B625351392C5234266B4A3C7257477E5C457C5B45977162937763A47965
6D3A2D40251D382524331B145E2A1C6E4237262725BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1A3786B5D443C38261E35211B
38221B37262442332E454841826F5FAE9784BFAA92BFA896BFAE9FBFAE9CBFB5A8BFB8AE
BFBBB3BFB3A6BFB9AEBFB1A1BFB4A7BFAD99BFAA94C1AA92B9A18AB99781B99B86B99D88
BF9986B39A83C1927AA9856F8F6F5A7158458057447B67569473607E65589F786A9A7760
6C3A2D3B231C30211A2A1D1537251F563A332B2C2ABFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1A06D5453372850342B36221B
3A1C143F261F4530254A3F376A61549F8876BBA892BFAA95BFAA9BBFB3A6BFB1A1BFB5A8
BFB8AEBFB8AEBFB9AEBFB1A1BFAE9BBFAE9FBFA894C1A48CB99B86B9A18AB99781B99B82
BB9480B7907AB38F79B08871AC8A75AA89739E7E69917461A37766A08169A673638E5E45
62362A3B231C40272033221B30201A412D23373631A8A7A5BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C18E634B5740384A3229452A23
2C1D1533201935211A483328544736877261B6A18CBFAA95BFAA9BBFB0A1BFBBB3BFB1A1
BFB5A8BFB5A9BFB5A9BFB1A1BFB1A0BFAA92BEA893BEA48DB99781B99882B99B84B99781
BB9680B18F79B18A74AF8F7AA68670AC8770A9846EA2826C9C7D669C7D6A97735C684538
3721173B27262B1C1B2D1C141E0E0E34231E403B34796C6ABFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1A36F56503930543F37453029
472A2235211A3F2C2543383353443B5E574AAE937FBFA892BFA899BFAB9ABFB5A8BFBBB3
BFB3A6BFB9AEBFB1A1BFB1A1BFB1A4BEA894BEA890B99B84B99B84B99781B89781B4947E
B8947EB58F79AC8A74AC8872AF8F79A68670AA846EA8826C9D7D68A079638A5F4C5D3428
4931292515142C1C1B1E0E0E291B1A2C1E193E3B385B514CBFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C197786C59413954413A543F37
452B232F1D1539251F4C3529614B3C5E54449B7D6BBBA18ABFAA98BFA899BFAB9ABFB5A8
BFB8AEBFBBB3BFB4A6BFB1A1BFB1A1C3AD9DBCA78FB89D86B4947EB5917FBB917EB3907A
B38B79B58D79AC8A74AC8770AA856FAA8770A47C65A97E689A755F926654784A37542F26
2D1C142E1D1C2314142A1C14271A193825202A31317E7D7ABFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC3BFBEBEBA8E6B5E4F3C3553413A523E36
3E261E452E273B2C2541312B564639715E4E926F5EB29A87BFAA95BFAD9EBFAD9EBFB0A1
BFB8AEBFB8AEBFB9AEBFB1A1BEAE9ABBA592C1A48CBC9B84B79984B3937AB8907EB38F79
B18D76B18C79AA8370A78470AA846EA6846EA9846D9E7A659D745D97664D67412F4C2C23
36231C2F211A30221B291B142E2119372520010000C3C8C4BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC8C4C3C6C3856153543B2E503B3355423B
574038412E2746342C4A34274C47406B5543826656A88C7ABBA892BFA899BFAE9FBFAE9C
BFB2A4BFB2A4BFB3A6BEA996BEA994B5A18CBEA38BB8947AB49179B8947AB39079B3937C
B58A74AC8D77AF8B72A9806EA6806AA67E68A2806A9D755F8F68506F463A56302635241C
2D1C14291B1A241514180E0E21131340332E120B0AC4C9C6BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1A5796C4D3629573F36534039
4E3930472B244932264D3A335041376046386755479B7B6BB6A48CBFAA95BFA896BFAC99
BFAC96BFAC96BFAE9CC3AD9DBCA78FB99882B8977FB88E7AB38B76B38E7CB39078B38A73
B58B75AC8770AC8770AE846EA6826CA479639F735D8F674F6F473B603D2B41261D34221B
35221B2B1C1A25151424141436241F25383C6D6462BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1B89E915B433B4D393157413A
56392B4B372E412D274C383046342D51433B56483D7F6250AA947EBAA58FBBA88FBFAA98
BFAA94BEA891BAA58CBBA896C1A68EB8947CB8947AB18970AD8871AD8875AF8B75B18C75
B1826CAC8370AA816EAA846AA47E65A279639B70597B4F3D633E2B3E251D301E152B1B1A
32211B2D1C1B1F0E0E22141333231E020101C4C9C6BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1B29883674E4454413A4D3C34
533E37422A28432F2843322B5340394D35284A372C6351448B705CAD8F79B29782BAA08A
BAA38DBEA891B9A18BB59C86BCA48CB69179AD826FB18A70AC7E68AC826DA8856FB18770
AA806AA78068A877649F78649A785F8D634C895D4667422E41251D35241C2C1C14241413
221414190E0E170E0E35231E402A1F0E0704BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1E0D8DD78564D57423B523E36
56453E573B2B4328224C3B3548352D53423B443028493E355F4C3E7B5E4C997866AD8A73
AB8B7AAF9483AF9681B09580B49078A27B62956D579C7157A47C65A77A66A7765FA77965
AA8061A47960A2755F9B6D57956D577F5543673B2B552E253E241C2C1C14251514241414
1E0E0E180E0E2114132A1D184750525B514BBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1D2DCD4A38774523A314F3C35
4C3A33493A32412B28442F24533D3552423B5C463E47373156463F594A3F6C4D3C816154
765D4E80614D8D6E5C8F725C8F6B598A614A78533D795941885B4394684F9A73589D6952
91634E91614793654F8961507B4F3F6D3F2D542C243F241C2D1C142615141E0E0E170E0D
170E0E170E0D281F1938251F000606BABBB9BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1CEC1C7674C43503F38
50413A523D3636251D3D302B54423A56453E604F47614F475E4F43605347614F42624539
603F31583E36633F337050416C4B3F5E453E68443765412E674433734F3E79564181553D
805943734C37724E3E7548376642324F2D24482F27301D152B1C142515141E0E0E170E0D
160E0D2F1F19271A19474C49312826BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1DDDEDA89645C503C34
513C354F3D35573F38493B3552423B5E4D4557433C56433B583D36644235623F30553F35
47312A4D3A31442A234D3730573F364B372F432A23452E28452A21452721513528553829
513627512C234B2821482B23482A2238251C2B1B14271615231414241414180E0E170E0D
2F1F232F1F1A4937301B30348F8783BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1C6CFC7D2C5C562483F
4F3C34534039503D355748414E393054433D513B325240395D4D4057433B563E36533C33
4D38304F3C35462D2B3E302A432A234429223A241C31211A36221B3E27204126203A231B
38221B39231B4027203A221B37221B2E1C142A1C14251514231414170E0E170E0E211413
3227224128234144445E615FBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1D6D3D28A5B52
564039534039523E3642342C5C4A4256484059484047352D4F392D4E332949362E49362E
3C2B2E3C322C452D2A3F262139242831221C32221B2B1C142D211A2E211A30221B2D1C14
241514291B1432201A2D1C142415142B1B14291B1A251514170E0E2314142C201A382A24
39251F535856535352BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1CAD5CEB69C93
5B403853413A523E3656413A493E3752413A513A3146312A3F2E273E251C42312A3F2A28
402A2735211C3823272B1C1C2615142A1B1B291B1B251514281A19241514291B1A251514
291B1A2D201A281B1A261514180E0E160D0D170E0D170E0E281A1A271A132214132F1A13
4F5552504D4BBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1EDF6F3
9D857A513B324F3C354D3F3851423B54473F56403D462B24422D2635241D32201933231C
35221B2715152414132B1B1B2A1C1B231414281B1A251514271A1925151438241F1A0F0E
2619192D201B2B1C1B180E0E170E0E1C0E0D271A19281B1A261A193B26214A3326554A3D
261C13BABBB9BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
EDF6F3A0807556443C4A362E54443D56473F5E4B424B3B3346342C3D25292A1C1B35211B
2A1C1B31221B2E211A291B1A2414142414142214132414142214132E211B261A1A4A3E44
3F3C3D3723292615152B1C1B2D201A2D211A281A193E302A412E273B2721543D34535350
89796CBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1EFFCFAA07C72634E4648352D4E40395B4C44644D454F382A49322834231D281B1B
261514281A14291B1A251514241414281A1A241414281A1A2414142213133F39373B2B32
54474864554B563F3E4F403B48352F33231C3E2D253A2A25503F385D4135505250796760
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BBC1BEF2FEFA946C5A6A534955413A56494263514864534B4C332A4630284A3931
44352E36221C30211A2B1C1B291B1A2314142414142C1F242B1C1C2E201A2518173F352D
433532301F1E34241D2F211B2F1E1D39231C3A2B244A342759473873716B685956BFC0BD
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1F1FFFF8F7362563E344E3E3763554E6C5F576F5A5048322A3B2726
4429234D3B3445352D2D1D1C24141433262A35272C3B302A39292E463A37352528433C3B
4F3D3A5840384A383347352D4C3A3251453C4E3B335D4E4163615A8F8171AFADAFBFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1F1F9F9BCB1AD6F5A535240395B4840655D5D73635C6A5950
655A55523D3B4D41405D54586259574E3C39483A4348383B5B50524D3F3D5A4238443A38
61473E5A3D365A3C2E5841395B493D6751426C4533475153897C6FBFC0BDBFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1CED8D1E3E3E68D7678624F49574B49636469756A67
70625B796C626F605E645C546A5A586C554B5F4C43513F3F46332B523F3B59473F534039
60433769483B6B4C40735446654437685854A1908869615ABFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC0BCBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1F1F9F0B3B4B9AEA69F766C777C7173
8C83888D7F80806C6379676076645C806B6778645E7D675D76645E6D5A4D68595178655D
6A5C516B584B63463C6C6460A6A09F9A948A898383BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC3C0BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1C6CFC7E6E8E19CA5AD
A6A69EBCBCC7B3B3BAB2A4A58A7B84746C727867657B655C6F61597D675F6E5C52675245
71594B75766EB7B7AF7C8079A49FA2BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1C6CFC4B4B9C0CED3C9D4D3D2AEB2B2B2B9C2ADAEAAADACA8ADAFABB0B2AEAFB4B4
AAA7A374776FBFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.511074 0.245293 0.732558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C73533F
826F627C6B687C746B7C67607C746B7C6F687C6F687C6F687C67607C6B5B736357785F54
6F5348745A4E6A53476F564A6F564A6F564A6F564A6F4F4367523F6B52496B523F6B5249
93ADBA7C7C7C7C7C7C7C7C7C7C7C7C7C73747C81817C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C74757C7D7D7C7C7C7C74757C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C74757C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7B5945
816F6A7C6B5F7C746C7C67607C746B7C6F687C6859746153756153755D4F6C564C685247
684E436C5448634D4270574B6F564A6F564A6F50446F50446752466B52486B523F6B7075
93AAB67C7C7C7C7C7C7C7C7C7C7C7C7C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7B7C7C78787C7D7D7C7B7C7C80807C7C7C7C74757C7D7D7C74757C7D7D7C7C7C
7C7C7C7C7C7C7C7C7C7C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C74533F
7D6C607C6B647C6C687C6F687C6B647C68617460515B5D5873594E714B47674F436B584C
6F5A4E6F5D506F55496B52466850446850446850446852406752466B52466B52468FA8B9
8F95987C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C74757C7D7D7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C73747C81817C7C7C7C7C7C7C7C7C7C7B7C7C80807C7B7C7C80807C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7B533F
816F6B7C6B677C6B647C6C647C68607C6B5C7B6B637C6D69846859845C5F715C4C78564A
78544F78544E6E46416750446B52466B52466B52466B524673594F6A52466B524693ADBA
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C5945
7C6F637C6B5C7C6B647C6B647C6B647C6B637C736E7C726A7B6A6278655A735D527B6054
7B635873554E7B63556D4C45734B4673615B6A514573524673534667504473605392ACB9
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C5A45
7C6B5F7C6B677C6B5F7C6B647C6B647C736B7C6B647C68617C6F687B6A62806C60776555
785E59775D52745D4E6F4F4A6E5B4B6F56476F5A536B51456852466752468782838BA0AC
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C74757C7D7D7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C6342387F604B
7C6B677C6B5F7C6B5C7C6B687C736B7C6B647C6F687C726A7C736B7C67607C6B637B6256
806256775E50775E5273524E7356476E4F43675347674D3F7352466A52468997A3828E92
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7B7C7C80807C7C7C7C7C7C7C7475
7C75757C7D7D7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C241A157E5C488B7A68
7C6B687C6B637C6B667C6B677C746B7C67607C6C5C7C70697C68607C68607C6B5C7C6B5B
745753745B507857536F57456B4F426B564A6F52466A52467460536F584B91ABB8818484
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7B7C
7C7F807C80807C7C7C7C7C7C
7C7C7C7C7C7C7C74757C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C5B4F57090201CAA495816F61
7C736F7C6B637C736B7C6B637C6C647C6F687C72697C6B677C68597C55567457496D5046
75564C785E50705E5367534474534A6E594C674F3D6752466C5347684D428EA9B67C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7B7C7C78787C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C8584850E0604846952D5B3977C6B64
7C6C687C68607C6C647C68607C6B647C6C647C70687C6760746454755451745E4D6F574B
755B4F71584C7058466A50457050446B50446F50437352486A524673594C89878A7D7F80
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C74757C7C7C7C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C100805786054CEAA9B816F617C6B68
7C6B647C6B647C6B5C7C6B647C6B647C736B7C6B647C6860733535783B3D703433703535
74373774574A6B4D426B4D446F483E6753407052466F5246675240744B4169544885959B
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7475
7C7D7D7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C5B4F5166514BD0AC9D7C68607C6B5B7C6B68
7C6B647C64557C64557C64597C6C657C6C647C52527C5756733334703D34672C2475433F
6B3B3275443F623E38684C41685240674E427453496F52466F5246734A426F5D4F765E52
7F84867C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7B7C
7C80807C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0B0606987760826C5A7C6B5C7C6B5C7C6B68
7C6B5C745C4E75594E7D70637C6F6B7C5D4E7435376D342C64443C522B1E6E6C5B7A6A60
622820692D266B3D346A473F6B57496B4A356C56437052466F52466F52466F56496F574B
8D96987C7E7F7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C74757C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C403133442B1FD9B093816F6A745D517D74707C6B66
7C5D4E6B4E3E6841388463656C2D2E20060378555070473E7B6D6385908C823E38603D32
4E34255F564E4230236D2E266450406C4B33734E47735A4F79604C6E51466F594C6F5246
725B4F7F7B787C7E7F7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C74757C7D7D7C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0D0707A3836898857E7C6B5F7354478275707C6860
7C5B4D613A2B633A332E0A0A656E697B938CBAC7C083909784959A818B8872534481A09C
838282636063371F19301C11653A2B715B46744D46796556795D507359496E52466F5044
6F5A4D7282A077777A7D7E7E7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C635D6D050101D7AC8D826F637C6B5C7B695D8176717C6B64
6C41354C342252221A260A06AD7364876251754B447D79767C604D7C65526B413A7A7477
6C42357C6B62684738675C533A1F176D392B6E4E457B65507C6A5D73594D6A52496F4A3F
6F534767716D62584D6C697A7F7F7E7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C241A150D0605583629DDB899816F627C5D517C5E537C6D617C6B5C
6A3F34705E51897B718F9281BA928E7B675C70514B72584F76333164403B6427256D2A25
60251F6F65575B3026613F4148312B3A0D067E564D7F67507D6B616F53426A4C42674F43
705C4F6F62558D8D966C65798E92877C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C74757C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C63565E000000160D0CE9BCA89788737C64587C5457746B5D7D73657C5558
6A463C5C3F2F897F798176717C68657B73687F7E75837970847767756A587F6657776A52
776958725B4B78333569332E53231842120E6A271C7B63507E645A6F54426A4C43674B40
7453476F574B1F161389848786847D7D7E7E7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C60596A745F46C98D76D6AE917D6C5C7C63577C6D627B5E5A8171627C695E
6A544468463B8D7F727D6D667C6F687C6B637C6C647C6F687C545473554A785E536F574A
74534A624E3D694C41635A43695647715C4E795855856C487C63567057456A4C4367523F
7455496F5A4D1B1E1FA9A09B7F83848184847C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C795A488A6B577B716C776D5F79685B7D6B5F7C6F6A7C69667C7E717C6B66
725A4F725145704F437B6F627D746D7C6F677C6B637C746B7C6557735D4C704A3F705946
634C3C54483E65453564423664453664413664473678624F7E645B74544762453D674B40
6C53426853470B0C0DBCB4CB9197997C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C746C6D7D5B46745D526D503E5C5C6384685A816F6B7C736E7C726A7C736B7C6F67
7B5353765A4E724D42826E6082726D7C70687C51527467577D68596B4C43705044633F34
634F45623E356B483567493F6F533966493967463483615679574B6B4D4262483D6B4E42
6B564873594F020507B4A0988A8E877C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7B5B488164576B4D43674E427B746A905B557C716B7C746B7C6F687C6F687C6F68
7C65577B65526E5543755347837A757C746B7C655F7B7569816F6972524F73594D694D42
735B4D623D33674639674A40705144734D457F5E5281695D6B4F436B50446F52466A4D42
6B56426C5347030607432F28A6A1A47C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C5A45746459532F217E74678A6567816F627C766B7C746B7C78777C6E667C6F68
7C675F7C6A5D6A52467459497E7B6D7D6D657C68597C736C7C6B63735B4D66493C6B4D42
67524667493F6E523966453A7051457E5C55816B5D735D506A594D6F584B675246675246
6B55487360554C36244F271E3729258F92927C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C5D516C37285C24215E4036727E78856E627C76627C6B687C746B7C70697C6B617C6F68
7C6760746454735B507B7062857A6E816F6374554E7D6E617C52536B4F3B663F37674B40
60453A6C4B34543B3065413A7863557E64567D65566F574B6A54486F4D426F50446A5240
734B407362556543396A4D47AECAD1CFD3D47C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C46406A342F61312D6B6553867F6F90736B7C736E7C6B667C746B7C6F687C6F687C6860
7C6859736354815F54776B5E826F6B7C736E7B686481766C7C5B506A564562443D60473B
5C413561443863473F80645581695B7965587D62566F574B6A53476F4F436F4B466F4B46
6B4B4270655F5F382A6C4F439CBDC97B7B7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C6457
7C53426A46385A412F746A58918373816F6B7C746B7C6F677C6B647C68617461537D685A
7C5555735E5179584E74645882706C7C6C5C7C68617C6B647C54536A473C61453B63473B
66493D625246745A467860527A5E517C625674574B7051456A54486F483D6F4B40674E40
67554074655F6E43366E5B4F707B867C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C6C402B
56302630201A4B342A8675698C7F707C6B687C6C647C68617C68597C6456736455795955
6D554C755F55786A5D786E608273667C6B647C6B677C6B647462546B4E3E614A3F63473B
674A3D6E51457356487E5A56795E51755B4F705E5374594D6A564A6F5549675447674D42
6B4E4874625F60281A7067596A3F3693A0A17C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C612817
1A100B34242031201F9C816E8778727C6B677C6B5C7C6B5C7C6B647C6B667B6E69806C68
765D5574514B6853447A635679695C7D6C687C6B647C6B5C73544E6643395B3C3D644835
604338715145735D4F7452466C574975544F6B4E426C5246634D426850446750446B4A3F
6B4E496C57475837226A564368393593BDC87C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C6C6569362C
3F2C2437241D332220BE947987786A7464567D6C647C6B5E634E4566514450382D523A2F
5138345B39396D5243715246725E5383716D7C6B647C6B6373535065493B5E4333674630
5F4A406D4D405E4F435B493E6A5347715E52634E41705A4D6F564A6A52466B52466B4A3F
6B4E496B56463F221A4A20186C403194BDC77C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C744E3C6B4039
060302110E0C241A18CDA0837D70627C6458816F637C6B5C715A4F57453B43342B2A2727
1F1A1A351F15593D2E4720184822198571627D6D657C6B64735B4D65483B5E4333605039
573F3675594C765E51795B4E7B55486B4C4758463C765A4D6F564A674F435C4B405E4B40
6D55496B554642251D592A1F7E433498C3D37C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C8584857A4B38653F37
1211121E1410321815DFB29381726578665A7D6F627C6B5F7B6A6661493F8868622E2622
1F120F331A124037345F372A876A599E9A86827B767C7B7973615165443B4F382D583F2E
280A07704F405E402B4C382F3A281F5E483C5C4E407656436850456750445A4439634E42
754E495C4539321D1A59352883544BA1D4DF7B7B7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C75757C7D7D7C74757C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0A01017B402F6B5449
241C1916141A21130FDDB79779685B7C6B5F78675B7564597D6C68716051795C50554539
8560508152387F543C96674C8F6B5B8273648279747C70697355456542395C3D2D5D4135
4A2B23645C572A29270403043B231D3F38301E161148342E4530226941315B4B41635044
754E42453B2E221814412820916A599CC5CE7777787C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C78787C81817C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C0C04030903032807032F201B
08080E110F0D2C1712E8B99978675B826F6B623B38694E4384726E7B72697F6B66785E59
71514470574A7C5A4F896C5886675D7C6E60827C787C6F687350496552475E42315E523B
6D45347B65576944350B090B442116372A27231A1867402F6E463785644F664B41624E42
7555421D17172017123B1F1795453490B3C07878797C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7F807C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0500003222182D16132B211C
0B07092C1813331814DFAC8D81685B78685C7A67606D605053382E533B30443228322420
2B1C1737271D432920492B217261567A706282746F7C68597350456557485E3E33664433
634E39715B4A6A51456152479A654E6C4333663E2E9B624D855C406756496C52416D574B
634E4213100F2215123F20188732249ACEDA7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0801001C0E0A17110F1D130F
1D120E1E1510362824C19478846D5F7B6F62816F6B7968607A6B5D73524C4A424379514B
6F493A7858476D483A8A64549C927F8A7A74816F6A7C5554735D5065564A5E383A3C2218
40251C69533C6D53436B52407251466E55426A574B80624C6050436B4E4D634E426D5342
45382E07080817110F9D614B6C2F21A6DBE57C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C74757C7D7D7C7C7C7C7C7C7C7C7C7C7C7C0E04021E0D0A1F14101B1310
0D06062114103C2A259C6F58876E607D70637C6B687C736B7B71697C706C85857CA18E80
88857B918D85908881998A788078698277737463547562557466546E5A4F765E53675443
43292931241C20161358372E70554A67523F6A5242634E4264453B5441366D4F47734E42
1D16130E0B0B2C231E8E4632461E15292C2B8E8D8D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C0905042118161E1410201310
160E0A2615113A2A2599654E9378688274667C6B687C746B7C6F687C78777C77757C7775
7C6E667C78777C6E667C6F667B6A5D816F637B6758775F5478584E7763577B6659795C57
695955805C50533E363F251D241B1537221D2E2B273F2A22432C2272524C7B5346644739
0C0B0B18100E26191A2C0E0A34120D2B2F2EDBDFE07C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0E07063B282517110E201310
1F130F28191A392A257C5540836B5C8475677C6B607C6C657C70687C70697C75717C7470
7C736E7C78777C6A607C6F687C6F667C6B5E7C6B5F735B50786256785E53786457785A57
6E5E506E584A6451436C55466C5343684232593E2F804E3F725B4D804F4F5D4F404E4135
0D0C0C1D120F1B1310150E0A2B1915393532D6DBDC7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0F05032D1E1620181521130F
250F0B2B181537231850382D8963538576677D6C607C6B687C746B7C78777C6F687C7571
7C74707C74707C6A607C6F687C68597C68607C645773544B786457786256785E53785B51
6F57497351456E5347695145785B4D75574A7E605181594B71534D724D42664C3B37251C
130D0D1D120F2B18141B130F2314103723199780838284847C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C090301332927241A17281613
150E0A2014101F130F41271E67412B8F78698270637C6B687C746B7C79787C736E7C6F68
7C75717C6B617C6B617C6F687C67577C6B60745C4E745F54785E53785C51785B50785E53
6F574B6B53476B564A6F5D506B52466F50446A52465C4A3F5E4E425E4E40473B30141414
0C0A09231719160F0F140E0A0E06062E1915755A55A2ADAC7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0E04023025232E221F271B17
2717132214102B1D19412F2B4B372D987262846E617C6C687C6C647C716A7C75717C736E
7C78777C6A607C6F687C6F687C675F746457745C51785B50785B50785E53705E5371574B
70574B6A53476F564A6F574B6F53476B52466752465A4A3F734E4262473B322520150E0E
251A17120A0B150E0F0E0606170F1026151167544EB6C2C57C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0C0706332927362925302320
271613130E0A2D181543271D603B2B91553D8673647D70647C6B647C6C647C716A7C7571
7C74707C736E7C6E667C6F687C67607B6B5A775F53705A5071574B7958536F584B745145
74544F6A54476F564A6F50446750446750446445396A4B4063413539302B2318141C1210
140E0A140D0F130A0B170F0B1910112F1914E9EBEBB3BABC7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7475746D6E0905052F23203528252F221F
1B100D271C182E1E1A2F231E613E2D7B51428676698374677C6B687C736B7C736B7C7978
7C74707C74707C6A607C6F687460527D645573544B775B507B5E52745A4E705A4B745347
6B5D516B56476748446850446752466B52466A4A3F6050444D3A2F443228221812211412
17120F1C14101C140F18100B1D14102F1914F9FFFF7B7B7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7B7C7B7E7F0705043E241B302421352824
2F231F2A1D192E211D3521185A463B5B3C2F8360517F72647D6C687C6C647C70687C7069
7C6C627C6C627C645A74615374594C79685B74574D70574571584C705745745A4F745A4E
6A564A6F54486F4E436A55466B4B406B4B405C4B404D4135462F25281B1B18100F16110F
140E0A170F10120A0B090606130A0B4A2A25EAF2F27878797C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0E0606332017332A27372926
281D1A25151235221833252246392F42231C7B5142867E6E826F637C6B5C7C6C657C6859
7C685A7C685A7C68617B6B5A775F53785C51704B41705145745451745B4E745A51744D42
6A54486F50446F50446752466B4A3F64473B4C4136462F25281A1A22191418100D18120F
21130F170F10120A0B130A0B331A16FFFAF6C5D2D37C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C1B12112B211E3125233C2825
2E1D152B1F1C291C183226232C1F1B3326246643327B614B7C6B5F7564597D6C607C6B5C
7C6B5F7464587564597D6C5C73544A704E437057456B4F446C574B6C57487554486B4C41
6B53466F48446753466752406444395C473B483D32331E1A21191419100D120D0A160F10
221310150E100E0606140B0B311A15EEF4F47878797C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C1C140F2B211F362925312420
2D221F201518271A172F221D3729263320173F241B624B3C73574C7354497A6356755E53
7565597464587860547961556C544B67493E6C51446B4D446F4B406F51457050446B5044
674B40684B4060483A5D463A4E3E35453227402D231F161216100D16110F150E0B130A0B
130A0B090606090606321B163E1F15EBF3F47C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C493E452D1F1D3428242F221F
3D2F2B2F1E152917133B2D292C201C352824251A1745392E3C2D2656372C71594C61493E
6A575369534F695347725C515F473D473229553A30634030694C41684E42683F34684C41
674B3464473C5C4135573E324C3E3238221E2D1A141A11101B110E150F0B120A0B130A0B
0F06070A0607150B0B281611D1CBCBD0DDE17C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C777678231C14261D1A302320
322421221C192015173623192F232040312D332723352723392B294D32294C3528352E2F
34302C442D224F3E314E3D323629253B2920412B204E372655352B573D2C664131554035
49302650312952382E40332E3725202A171222131118110F140E0A110A0B0E06070A0607
0A06070A0607201511301A15F5F6F68184847C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C30282E251C1A392B27
30292530232018110E31231D3E312E3D2F2B3F322E40332F4B3B3147382E3A3128302424
321F17351F1D3C251F3C2B25291F1F3123213D241E3F261A3B241F4A3528463127392920
4430253D281E3C2F2834221D2F1E171D1311221A18120E0A160F0B120A0B0F06070A0607
0B06072615111A101187635CE1EAEB7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C635C66221713302420
2F232031231F2F2320402F2A40312D3F322E33272332262338211E43251E3420182B201F
2318152F24222315122C242128201F281E1A241411211916211413271512271C15271B15
291D162112112414121F131120141214100E140E0A10090A130A0B130A0B0A06070A0607
26151B261510372925F4EEEAA5B2B47C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7A797B3A343229201D
312420372926302420443631281D1A3B2D2A251B183629254A342A3329252A22202D2422
2A1E1A422C281F141529231E2615122515121C110E19130F1F120F2917142718141C110F
1C110F1C110F2817141C120F1E130F140E0A170F0B120A0B130A0B0A06070A0607150B0B
34201B2A1813E3E6E6CFD3D47C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C5B4F57211210
3629263729262F221F261F1B372A274637322C26222D201C3E241A1F17152A1E1A2B1F1B
1B151B29211C1D14152A18131E111719130F19120F160F0B1C13101B131019130F140E0A
110A0B160F0B211310140E0A110A0B160F0B170F10120A0B0A0607130A0B1F151132201B
301A15D8DBDCD8DFE07C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C797879271F1B
2B231F3528252F221F362925352B27342724251B18251815281B1719100E2F221D211617
21161720130E1E1117150E0E10090A160F0F170F10120A0B180F10120A0B170F10120A0B
170F101E1510180F10110A0B0906070A06070A06070A06061810101A100B140B0B230F0B
CFC7C8D9E1E17C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C706F70
3F3431291E1A302320312A262F28243E2E2A2E2224261512281B1818120E21141017110E
1F130F10090A120A0B160F0F170F0F130A0B180F10120A0B181010120A0B301A15090606
1910101D1410160E100906060A06071006071A10111A10101A10112E19143A241A7E4C37
EAF3F58184847C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
706F703E2E2C3029262A1F1B3E2E2A3D2E2A382B28241E192E221D1D1117170F0F201310
170F101A130F1D1410181010130A0B130A0B140B0B130A0B140B0B1D14101910102D2D3C
383131211318120A0A170F0F1F15101F151019101135241E2D1D192E1914593429D2D9DD
AABEC87C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7876763E312E3A2C282C201C2F272440332E372B27331F16251A1719130E180F10
110A0B180F0B170F10120A0B130A0B181010130A0B181010130A0B140B0B332F312E1E2B
47352B43322D34272649373032231D1B130F2C1D192F1E19392B274F2B22D9D5D5B8CBD0
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7D7D7D6B6A6B3A271F3C312D382A264535303D302C3E312D231917271B17392824
2C231E2314101C1410170F0F181010130A0B130A0B1E151A170F0F1D1410191011281E1A
372720100B0C140F0C18110E110C0D1D110E2D1E1A35211869402FA699A5BFD2D67C8080
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C6F6D6C3D352E241B183729254C3D394A423E392E2A261A17231718
25151234252129221E160E0F130A0B23191E23191F2F251F20171C42302A1A1218533F37
3324262E231F3A292431221E382824503D2F362824714633CDCBD0ACBFC98A918C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C6F6E6E7E758340332E362925342926393740483A3653433F
564C453326282A292B463B4B5D4F473A292A302732382726463D4C3E2D252D211F49362F
3625223C241F3C241B3529264E372C6A4231331F18D5D7D7AABDC77C80807C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7877787F858141353D40332E33333C5C4E4B4B4547
453E3A433A37564F4F5B46404B3B323025224235303223222C201B2C1F193B2E2A372926
47271E4C2D244C352B5A423947271F614C50A4B8C1C6D3D87C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C75757C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C6F6E70A8AFA99C99A74B3F4A5E4D4C
766B7A66545659433E483A35493C39594447624B454D403D664E46514137584844624A45
4E3E34483F373326248A7B88A6B4B8B2C3C8AAB6B47C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7F807C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7A797B787C7AAEB0A6
9FA7A77D79839997947874874B4655514A59453A34443B384B3D3A443A374639373F2D24
383027B9B5BAA7AEB4C1C8CA939D987C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7A797C858880787B7D838A83A3A79FA2A59BA7A4A6A7AEB0A7ADAFA6ADAEA9AFB0
AEB8BDBCC1C77C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.511074 0.488926 0.732558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(112) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
747376747376747376747376747376747376747376747376747376747376747376747376
7473767473767473767473767473767473767473767473767473767473767473766C4E3D
78675D746462746B6674605B746B6674676274676274676274605B7464576C5D53705950
684E456C544A644E44685147685147685147685147684A41604D3D644D45644D3D644D45
869EAD747376747376747376747376746B6E74777A747376747376747376747376747376
747376747376747376747376
747376746B6D747375747376746B6D747375747376747376747376747376747376747376
747376747376747376746B6D747375747376747376747376747376747376747376745544
79686674645A746B6574605B746B667467627460536B584B6B584B6B5548634D455E4A41
5E473E624D445B473E685046685147685147684A40684A40604D43644D45644D3D646C73
86A0AF74737674737674737674737674737674787A747376747376747376747376747376
747376747376747376747376
747376747376746F7274737574737674787A747376746B6D747375746B6D747375747376
74737674737674737674737674787A7473767473767473767473767473767473766B4E3D
73635974645E74636274676274645E745F5A6B584C5255536650496743415E463E635147
68554B68584E695147644D435F4A405F4A405F4A405F4D3D604D43644D43644D4388A1B4
888F96747376747376747376747376747376746B6D747375747376747376747376747376
747376747376747376747376
747376747376746B6E74777A74737674737674737674737674787A74737674787A747376
747376747376747376747376747376747376747376747376747376747376747376744E3D
79676674646274645E74635E74605B74645674645F7B69678065587E5A5E6E594C725147
724D4A724D4A69403E604A40644D43644D43644D43644D436D544C654D43644D43869EAD
74737674737674737674737674737674737674737674787A747376747376747376747376
747376747376747376747376
74737674737674737674787A747376747376747376747376747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376745544
74685D74645674645E74645E74645E74645F746C6A746C6674655F7061576C5950755C53
7560566D514B7560536A4A446D45436D5B58654E446D4D436D4D43604A406D5B50879FAE
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376745543
74645A74646274645A74645E74645E746C6674645E745F5A74676274655F79695F716253
70595671594F6C584A684B4869584A68504269544F644E445F4D43604D437F7C818397A7
747376747376747376747376747376747376747376746B6D747375747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473767473767473767473767473767473767473767473767473767473765A3830725240
74646274645A746456746462746C6674645E746762746C66746C6674605B74645F745D54
795D5371594C71594F6D4E4B6D5144694A41604D4260473B6D4D43654D437E8D9B78858C
74737674737674737674737674737674737674737674737674787A747376747376746B6D
746A6D747375747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473767473767473767473767473767473767473767473767473761C120E664938837464
74646274645F746463746462746B6674605B74635674676174605B74605B746456746456
6B51506B544C70514F685141634A3E635147694D43654D436C5B5069554A879FAE797C7F
747376747376747376747376747376747376747376747376747376747376747376747376
74787A74787A747376747376
747376747376746B6D747375747376747376747376747376747376747376747376747376
74737674737674737674737674737674737674737674737652464F080202AD8E8679685E
746C6A74645F746C6674645F74635E746762746C67746462746053744D4F6B4C4262453E
6B4D4570584C68594F5E4E416C4E47695449604A3A604D43644D425F473E8199A8747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376746F72747375747376747376747376747376747376747376747376
7473767473767473767473767473767473767473767D7B7E0A040280654CD5B69A74645E
74636274605B74635E74605B74645E74635E74676274605B6B5C506B4E4C6B5849685148
6C544A675147685141644B41674A40634A40694A416D4D45654D436D54497E797D737173
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376746B6D74737674787A747376747376747376747376747376747376747376
7473767473767473767473767473767473767473760903016F564BD1AFA379685E746462
74645E74645E74645674645E74645E746C6674645E74605B6C2F31703035682B2C682B2E
6C2D316C4C4363473E63474068433A604D3C684D43684D43604D3D6C453C5F483E778287
747376747376747376747376747376747376747376747376747376747376747376746B6D
747375747376747376747376
74737674737674737674787A747376747376747376747376747376747376747376747376
747376747376747376747376747376747376524648735955D0AEA274605B746457746462
74645E745C4F745C4F745C5274635E74635E744A4C744C4F6C30316839305E28216C3D3A
63372F6C3C3A5C36335F453C5F4D3D60493F6C4D45684D43694D436D463F69574C6B5146
726F70747376747376747376747376747376747376747376747376747376747376747376
74787A747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376747376747376070403755D4A786352746456746456746462
7464566B55496B504873675D7468667455496B2F30622B25593C3548291D626959716D63
5C28215F282263362E65413A64504564463364503E684D43684D43684D43685045685046
82878B747274747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376746B6D747375747376747376747376747376747376747376
74737674737674737674737674737637282A492B1FD3AC927968666B554C736B69746463
7455496346395E393277565B6324281703025C434168473E75696186989781403B58332B
44322353574F382F235D28225C46396445316D49446D544C725C4A694E43685449684D43
674E44726865747274747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376746B6D74737574737674787A747376747376747376747376747376747376
7473767473767473767473767473760B07068D745E92807C74645A6C4E43786A6874605B
7456495B34285B342E2308084D5D5A83A9A4BDD6D27F99A47E9CA67987876C594A80AAA8
888E9364646A34201B251A115032266852416C4944725E5372584E6D5547694D43684A40
6854496776966A6A72737275747376747376747376747376747376747376747376747376
747376747376747376747376
74737674737674737674787A747376747376747376747376747376747376747376747376
7473767473767473767473765A5365070202BB998178675D74645674655B79706D74645E
633B31452F1F481E18240B079C65597E51426B3E37736966745744745A47633A336F656B
63392D7B645A734F3F71655B36201957302663443E705E4B7564596D554B644E4768463D
684C42606661574C405C586B727175747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473767473767473761C120E020000512E21D8B49879685E74554C74544C746359746456
643C326E5C528C847C9FAA96BD9D9A75635C684A47674B456A2728593132591F1F62201C
561A1661544A532A225E393C4E322D350E07674943755D4B74645C684E3F64473E604A41
68584C695A4F8986906A627781837D747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376746B6D747375747376747376747376747376747376
7473767473765A4C56000000120D0BD2B2A2928573745C53744D536B645A736B61744D53
64413A53392B7C716E79706E7465637472677A7F777F7B747E7B6B726D5A7B6A5A737057
736E5C6D5849722F32662F2C53201646130E60231B695345745A54684E3F64474160463D
6C4C42685046160F0E6D696A7F7D77737275747376747376747376747376747376747376
747376747376747376747376
74737674737674737674737674737674737674787A747376747376747376747376747376
7473767473765B55678F7058EFA58AD8AF93736356745D5374695E74595779675D74655A
64534364443C82756A73635D74676274645F74635E746762744D506C4D4670584F685148
6C4E475C4B3B5F4A3F5B5B43665B4B7565567D605D7E6948705A4F685141644741604D3D
6C51456854491E202193908E727678797C7F747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
74737674737675554283644F746D6C71695E6F605673645A74686674656374796E746463
6C564E6D4F4568483E6E6157736B6574686274645F746B667461546C594A68443B685040
5B47384C433A5B3F335C3C325C3F325C3C325C4232715E4C765F596C4E445C403A60453D
644D3F5F4D420B0D0DA3A1BD878E96747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473766B63657354436B554C624635525059776057796766746C6A746C66746C66746862
744E5071554D6D4B417A655A786664746762744A4C6B5B4E735F5263473F684B415B3930
5B46405D3A3365423361463D694F376146376142317A5A5172504663473E5C433A64493F
6450456D544C040709978B857B7E77747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376745442795B4F63473F5E473E756B6288544F746765746B66746762746762746762
7461547462506952426C4D42786E6B746B6674615C7471677968666C4E4E6D554B644C42
6D574B5D3A3161413761453D684C426D49457C5C537B665C634A41634A40694D4365493F
64503F644D42080808372823838288747375747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473767455436B5C534C2A1D746B5F835F6479685E747066746B66747072746863746762
74605B74655B644F466C554774726573635D746053746C6674645F6C56495F443963473E
604D4360473D694F38614237684B417658537A675C6D584E64554B68554A604D43604D43
6451466D5B535D3E29572A1F2B201D6A6E71747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
745348632D21521A1A57363067757377685E74705E746462746B6674676174635B746762
74605B6B5C506C564D756D627E746C79685D6B4D49736259744A4C6346365F3A3360453C
583F366445304D362D5B3C37715E51765F53745F52685148644E4468473E694A40654D3D
6D463C6D5A4F61413972524BC3DCE5D0D7DC747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
74403D642F2C5C2E2C645F4F7F7769886B66746C6B746463746B6674676274676274605B
7460536C5D50795950716459786766746C6B74656479706A74564D6452425C413B584238
553C33583E355D433D7B62557B6659725F55745C52685148644E44684A41684643694543
64463F685E5A59352864483E90ADBB747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376745A4F
744E3C64463754402E6C6454877B6E796866746B6674686274645E745F5A6B584C735F52
744D4F6C544C6F51496B5C5278676574635674605A74645E744E506441395C40385D4339
61463B5D4F456C5745715B4F71584D755B526C5147684A41644E4468433A68463C60493C
60513D6C5E5A69413769574E626C786D6C6E747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376633926
4A261E2419143B2D26786C6382776B74646274635E745F5A746053745C4F6C5C4F6F504F
624D456B584F70645A70695D786B6074645E74646274645E6B5D50634C3D5C463D5D4339
61453B694C426D504576545372584D6C544A68584F6C554B64514768514760514660493F
6449456C5A5A582518685D5165392F868A8A747376747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473767473767473767473765B2517
150E0A291F1C291D1D8271647D6F6C74646274645674645674645E746463746867796967
7159546C4A475E493D6F574E6F5F5673636274645E7464566C4D495F3E3654373A5C4233
593F35684B416D574C6C4D436250436C4D4A63463D624A405B473E5F4A40604A4064463D
6449456450425136225F4F3E5F343286ABBA747376747376747376747376747376747376
747376747376747376747376
74737674737674737674737674737674737674737674737674737674737674635D64362D
48302837251E2F201FA986717D6F636B5C4F73635E74645A5A463E58453A432D25422C24
422D2A4D313262493D67493F66524A78676574645E74645F6C4E4D5F453959403161422D
59453D64483D54483E4F423A5F4C4267584D5B4B3E685449695147654D43644D4364463D
6449456450433A20193E1B165E372A86ABB4747376747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473767473767473766B4636633A33
0404030B0C0C1F1917B1907974685C745C5379675D7464566D564D5240383C2F27212324
1415172419114533263A1A14391913705B5173635D74645E6C56495F4539594031594C37
503C336C5348725B4F77584D765146644542513F386B5349685147604A4155463D54463D
63514564514341251E55291F743E318BAEC1747376747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473767473767D7B7E7548385F3A33
1914142016122F1815C5A188796C6170605773675D74645A7465636149408C6964342924
1F12102D191234313152342A846B5B9797857874717475766C5E515F42394A342C50382C
2209075C40365338254130282D211A4E3E3555493C6C503F5F4A40604A405640365D493F
6C4945553F362E1B1950322879524B95C4D3747376747376747376747376747376747376
747376747376747376747376
746A6D747375746B6D747375747376747376747376747376747376040000542419634E45
291F1B18151B1F1410BFA48B6F605674645A7060566B5C537363626D5E5172594E5C473A
986B59925B3F87563D96674C89685A7A6A5E786F6D7467616C4E405F3E375A3A2C593E33
4D2E265E5956212527010405291B1933312C14120F34282636271D5A382A55453C5D4C42
6C493F40372B1F171336251E7F615490B6C16F6F71747376747376747376747376747376
747376747376747376747376
746F7274777A74737674787A7473767473767473767473760601010401011E0704171413
03060C0F0F0D2A1813CFA98F7060567867665A34345D413A776664746C677A6A68775E5B
6E4E446F554B7D5B528569587F635B75685C7873707467626C4B475F4E455941325A4F39
6B46347D6455724636100C0D3D20163026242119185D3B2D6843357E604E61483F5D493F
6C513F1A15161C1511351E17813C2E809BAA6F6E71747376747376747376747376747376
747376747376747376747376
74787A74787A7473767473767473767473767473767473760A03023122192D181427201C
0A090A291813321815C59B827960567060567566606A6152473028412B2334251D231A18
1C1512261D1732201A38221B5F514B6F675C786B69745F526C4B405F5145593B33613F32
5D4937685646654E43775C4EAE71577547366E402F9E624E855B40615146644D3F6A5448
5D493F14110F2015123A1F18772F228AB7C5747376747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473760E04021B0F0B14110F1A1310
1D120F1D1511322724AA887077635974685E7968667565607E706474544F483F4377504C
764C3D7D5B4A6E493C896456988F7F837471796866744D506C554D5F5248593539351E18
341F195A4635634D3E644D3C6D4E437056436C5A4D7A614C594C4264494B5D493F634D3F
40342B08090914110F945F4A6B312393C5D3747376747376747376747376747376747376
747376747376747376747376
747376747376746B6D7473757473767473767473767473761408051F0F0B1F15111B1410
0D07081F141038282488635177625773675D746462746C66746C677B73718D8E85A49588
8C8E8596969196928E9A90807B7468786F6D6B5D506B5D4F6B615069554C735E536D5A48
452C2C281F1A131010402B26624C44604D3D654D3F5D493F5C3F384D3C326348426D493F
1A14120E0B0B2C231F7E4130401C141E22226A6A6C747376747376747376747376747376
747376747376747376747376
74737674737674737674787A7473767473767473767473760D08072019171E15111F1410
16100C241612362824895C49866E61786B60746462746B66746762747072747173747173
74686374707274686374686374655B79675D746053715950705149715C53756156765A57
725F5B8E65595E433B3A241D1715112319172022212F231D36251D674B47764F445C4236
0D0C0C17110F241819240D0A27100C282B2BC3CACF747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376140A093C292518130F1F1410
1F141027191B3628256D4E3C726054776A6074645A74635E746762746761746B69746C6A
746C6A74707274635B74676274686374645B74645A6C564D705D5370584F705C52705553
69594C695648685345775B4B785A486B4535593D2F7E4D3E745C4F7A4C4E54483D453D33
0F0D0D1D1310191410140F0B251916333230BEC5CB747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473761408052A1D15211815211410
24100C2A181534221846332975574B786A5F73635A746462746B66747072746762746B69
746C6A746C6A74635B74676274605374605B745C536C4D46705C52705D5370584F70544B
6851446D4A41694E44664E4378594D79594D82625580594D6E4F4B6D4A3F61483834221A
130E0D1D13102A18151B14102115113121187E6C6F706F72747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473760D0604302827231A18271713
15100C1D14111C131039241C5738267A685C78675D746462746B66747071746C6A746762
746B6974635B74635B74676274605374645A6B55496B595070584F70544B70544C70584F
685148634E4463514769584E644D43684A40654D4355463D54493F54493D3F372D101313
0B0B09211719151010130F0B0D0708281815644F4C8D9899747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473761408052F24222D221F271C18
2718142215112A1D1A3C2E2B41342C82655A77625874636274635E746761746B69746C6A
74707274635B74676274676274605B6B5C536B554C70544C70544C70584F68584F675147
685147644E44685147685046694E44644D43604D4356463D6D493F5E42382E221E150E0E
261A17130C0C140F0F0E08081710112416125A4D48A0AFB5747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376100A093028273528252F2320
271714130F0B2918153F251C5C3829834D3878655A73675D74645E74635E746761746B69
746C6A746C6A74686374676274605B74645771595068554C6751476F514E6851476C4A41
6C4D4A644E44685147684A40604A40604A405C3F3665453C5D3C33322B281E16131B1210
130F0B130E0F130C0C17100C1911122D1915E1E6EBB2BBC1747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376746B6D6B63650D07072C221F3227242D221F
1A110E271C192D1F1B2B221E573A2C6F4B3F786C63786B60746462746C66746C66747071
746C6A746C6A74635B7467626B594C735C4F6C4D4671544C75594F6C554A6854476C4E44
63584D6351446043405F4A40604D43644D4365463D594C4246372E413026211813201513
1813101C15111C151018110C1C15112D1915DCE7EC747376747376747376747376747376
747376747376747376747376
74737674737674737674737674737674737674737674787B0C08073A231A2F2320322724
3024202A1E1A2C211D3321185142384E382D72544973665B73636274635E746762746761
74625A74625A745B536B584C6B51456F60566B51496851416751476851416C544A6C554B
645147684E44694B4165514364463D64453C55463D463C33402B2323191A16101015110F
130F0B160F10110B0C090708120B0C462825D2DCE16F6E71747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376140A09311F17302826342825
271D1A23151232211831242140352D3A201B69473C78716578675D74645674635E745F52
745F52745F5274605A74645771595070544B68433B684A416C4D4D6C544B6C544D6C473E
644D44684A40684A40604D4364463D5C4238463C32402B232318181E181317110E171310
211410171011130C0C130C0C331B16FFFFFFC7D8DD747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473762117152C22202E2422382724
2D1D152B201C261C192E2422281E1A2D2322573D2F6953426E5E546B5C53736359746456
74645A6B5C536B5C527363566C4E4668473E685141634A406250466250446C4D4463473E
634D43684340604D43604D3D5C40365542384339302E1C191E181317110E110E0B150F10
2014101510100E0808130C0C2E1A16CFDBDF6F6E71747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473762016112A211F3528252E2320
2A221F1E1618251A172C211C342825311F17362119504036604A436648406F574E6B544C
6B5B526B5C5370594F6F584F634D465E443B62494063474068453C684940674A40634A40
60463D5F463C584236543F364539333B2D2438281F1C161114100E15110F15100C120B0C
120B0B0907080A0808301B163D2016D1DBE0747376747376747376747376747376747376
747376747376747376747376
74737674737674737674737674737674737674737674737651444E3222213227242D221F
3B2E2A301F16281813392B282A1F1C322724231A1839332B2D2622412B255F4B42563F38
5D4C4A5D49485D494166534B5740383D2C2547332A56382A5F453C5F493F5F39305F453C
6046305C4238553C3350392F46392F33201D2718131711101A110F15100C120B0C120B0C
0F08080A0808150C0C251611CDCDD3D0E0EA747376747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473767676782A2218251D1A2C221F
2E2320201C191E16183222192D221F3D2F2C332724322622332827422E273C2D23272528
25272532231A3F322840332B2A212031231C38261E413022472E274B35275B3C2D4C3B31
3E2A22442A2549322A382F2C30211E2515111F131117110F130F0B110B0C0E08080A0808
0A08080B08081F16122F1A16DBE0E5797C7F747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376362C35281F1E372A27
2F28252F232018120F2D221D3A2F2E3B2E2A3C312D3F332F493B3043372D342F28292222
2C1B152D1B1A301F1C312420221B1C29201F35221D37231931201D3D2F253A2B242E251E
3B2C2235251C322A252D1F1B2A1C161A13111F1A18120F0B15100C130C0C0F08080B0808
0B08082616121A111282625DD6E0E5747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376685F69291B172F2320
2C221F2E221F302420402F2B3D2F2C3C312D3025222D2321331E1C3D211C311D17281F1D
1F18152A23211F151225211F241F1D241D191F14111B17161B13121F13111E18141F1914
211A151A11101E12111911101B131212110E130F0B0F0A0B120B0C120B0C0A08080B0808
26161C261612372925EBEBECA2B1B7747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376757476443D3C2D2320
2E23203428252F2320413430271D1A352A27231A173226234633293029252622202A2321
291E1B3F2B281F151626221E2315122314121B110E1713101C120F26171424171419110F
19110F19110F2417141B13101C1310130F0B16100C130C0C130C0C0A08080A0808150C0C
32201B2A1913E4E9EED0D7DC747376747376747376747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473767473767473765E5059271513
3528253428252D221F221E1A3329264436322B26232A1F1C3721191C1514261D19281E1A
19151A241F1B1B14152817131C111717131017131015100C1A1410191410171310130F0B
100B0B150F0B1E1410130F0B100B0B150F0C171011130C0C0A0808130C0C20161233211C
2F1A16DBE1E6DBE6EB747376747376747376747376747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473767473767473767575772F2621
2C24203227242D221F352825322A262F2522231A17231815241A1717110E2B201C201617
2016171F130E1C1117140F0F0F0B0B150F0F160F10120B0C171011110B0C160F10120B0C
1710111D1511171011110B0C0A08080A08080A08080A08081811111A120D130C0C200F0B
CEC9CEDAE5EA747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473767473767473767473767A7A7C
4B3E3C291F1B2C221F2E28252C27243A2C292D2224251613261B1817120F1E141016110E
1D130F100B0B100B0B150F0F171010130C0C171010130C0C181111130C0C2F1A160A0808
1811111C15101610100A08080A08081008081A11121A12121A11122D19153C251B834F39
E0E9ED797C7F747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7A7A7C4C3836322B27281E1A3A2C293B2C29362B28241F1A2C221E1D13181610101F1410
1610101A14101D1611181111120B0C120B0C130C0C120B0C130C0C1C15101811112D2D3D
3A343522151A120B0C17101020161220161219121234241F2E1F1A2D1915563329CFDBE5
A7BFCF747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473768483864C3A373C2D2A2A1F1C2A25223C312D372B28332017261A171A140F171010
110B0C17100B160F10120B0C120B0C181111130C0C181111130C0C130C0C322E312D1E2A
44322946342E392A294D393335251F1B14102C1D1A2D1E1A372A274F2C23DAD9DEB7CED7
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376737375757678442E263E312D372A2741322E3A2F2B3D312E241B18271B183A2925
2F251F2416111C1511171010181111130C0C120B0C1D151B1710101D1611181111241D18
32251E0D0B0C100E0C14100D0E0C0C1B110E2B1D1A332118663E2DAA9DACBAD1DB74787A
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473767473767473767B7B7E463E37231B18312623473A3748413E3C302D271C18211618
2314123325212B241F161010120B0C22191F241B202F262021191D42302B1C141A503D37
3325273024203C2B2533241F3A2925523F31382925704634D1D1DBAEC6D5838B88747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473767473767473767473767B7A7D968B9D4839353226232E242234343D493C39594743
5B514A34282A29282B483E4F65564F3F2D2D302832372827483D4E3E2E272E221F46342D
3424213B231F3B231A3528254C362C694130361F19CDD5DBA7C0CF74787A747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473767473767473767473767473767676789197954D3F493F332F303039554948494448
423C3A433B385A51525C464048382F30242242352E312321281E19281D17382C29342825
43251D4B2C244B352B5B423947271F5A474EAAC3D3C6D7E2747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
746A6D747375747376747376747376747376747376747376747376747376747376747376
7473767473767473767473767473767473767473767B7A7CBFC8C4B4AFC050435058484A
786A7E6A575C59413E463733463A37594448644C4851423F6C514A56453A594944644C48
4F40364440382F2624817688B2C5D0C1D9E2A7B6B7747376747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
74787A74787A747376747376747376747376747376747376747376747376747376747376
747376747376747376747376747376747376747376747376747376757476858884BCC0B8
A5B0B084818DA1A3A58580984F495C4C475A3F37333F37354539373F3735423635382921
332C24B6B4BEC0C8D2C9D6DB8D9996747376747376747376747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473767574767E827A767A7C8E958DB3B7AEB3B8B0B8B7BDB8C1C7B8C2C7B9C2C8BEC8CE
C3D0DCBCC5CF74787A747376747376747376747376747376747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.511074 0.732558 0.732558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(135) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
738787738787738787738787738787738787738787738787738787738787738787738787
7387877387877387877387877387877387877387877387877387877387877387876D695A
74766873756D737B7273736B737B7273797073797073797073736B7375666D6F616F6B5D
6960536B6255655D50675E50675E50675E50675E5067594B615A47635A4D635A47635A4D
79979B738787738787738787738787738181738888738787738787738787738787738787
738787738787738787738787
738787737E7F738485738787737E7F738485738787738787738787738787738787738787
738787738787738787737E7F738485738787738787738787738787738787738787757160
777872737567737B7073736B737B727379707371616B6757696757696354635B515D574C
5D554960594D5B5448655C4F675E50675E5067574A67574A615A4D635A4E635A4763797A
79A2A9738787738787738787738787738989738B8B738787738787738787738787738787
738787738787738787738787
738787738989738283738485738989738B8B738787737E7F738485737E7F738485738787
738787738787738787738989738B8B7387877387877387877387877387877387876B6758
70726373756C73726E73797073756C736F676B695C546560605E5565504C5F5248635E51
676456676759696253635A4C5D55495D55495D574A5D5A465F5A4B635A4C635A4D83A7AF
83A0A2738787738787738787738787738787737E7F738485738787738787738787738787
738787738787738787738787
738787738787738181738888738787738787738787738989738B8B738989738B8B738787
73878773878773878773878773878773878773878773878773878773878773878775695A
77767173756F73756C73726A73716973756475776E807D76807A697D6F6D72695B725E50
725953725955694D4961554A635A4C635A4C635A4C635A4D6A6155655B4D635A4C79979B
738787738787738787738787738787738787738989738B8B738787738787738787738787
738787738787738787738787
738787738787738989738B8B738787738787738787738787738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787737160
73786873756273756A73756C73756C73756E737D77737F757579726F77666D6D60756E61
7571616D62567571606D59506C504C6C6662655D506A5A4C6A584B61574A6A695A7C9C9F
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787736F5F
73756773756F73756773756A73756C737D7373756C736F67737970757972797F6F717663
6F6962716B5D6B65556A5E55696855675B4969625A635D505D5A4C5F5A4C7986867D9EA6
738787738787738787738787738787738787738787737E7F738485738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
7387877387877387877387877387877387877387877387877387877387875B4A406B5D4D
73756F73756773756473756D737D7373756C737970737F75737D7373736B73756E757165
79706071695971695B6D5F566D5E5069594B5F56485F54456A5A4C655A4C748F95749396
738787738787738787738787738787738787738787738989738B8B738787738787737E7F
737C7D738485738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787738787738787738787738787738787211F1A534E3F7D816E
73756D73756E73757173756F737B7273736B73726273776C737169737169737564737765
6B645F6B63596F5F5A69614D635948635E50695B4D655A4C68695A6964557E9FA2778F8E
738787738787738787738787738787738787738787738787738787738787738787738989
738D8D738B8B738787738787
738787738787737E7F738485738787738787738787738787738787738787738787738787
738787738787738787738787738787738787738787738787545860130B0B7C767277786C
737D7573776E737D7373776E73726A737970737F7773756F737161735D5B6B574E615047
695B4F6F675767695A5F5D4F6B5D526961535F59455F5A4B6156495D5347759397738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738989738283738485738787738787738787738787738787738787738787
7387877387877387877387877387877387877387877A8F8F130F0A7E785CBFBC9873756C
73726E73716973726A73716973756C73726A73776E73736B6B6D5F6961596B6756696154
696153655E51675E4A655A4C64574A63554969574B6C5A4E655A4C6A6153747773707D7B
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787737E7F738787738B8B738787738787738787738787738787738787738787
7387877387877387877387877387877387877387870D0A076E6A5DC0BBA977786C73756D
73756C73756C73756473756A73756C737D7373756C7371696D3D3F6F373C673134673034
6B32366B5149635348635349674F445F5844655A4B675A4C615A466850435B4B3E6D7E7C
738787738787738787738787738787738787738787738787738787738787738787737E7F
738485738787738787738787
738787738787738989738B8B738787738787738787738787738787738787738787738787
73878773878773878773878773878773878754585A8C8A83BBB4A473716973756673756D
73756C736D5D736B5B736B5C73726873726A735A5A7357596D44436743395F312768433E
634037683F3D5E3C3B5D4D435D5A465F554868584D675A4C695A4D6A5449696254645142
6B706B738787738787738787738787738787738787738787738787738787738787738989
738B8B738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
7387877387877387877387877387877387870F0E0D504D3E74725D73756273756473756D
7375646B6758695E537074667378707365566B3E3B61312B59473D4934255C755F6D816E
5E352A5B2C24633A3265463F63584D63543C615B44655A4B675A4C675C4D675B4D675C4F
78847F738280738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787737E7F738485738787738787738787738787738787738787
7387877387877387877387877387873B373A5D493AB6A98C7778726B655B707873737771
7365586656455D453B6F595C632D311A0303463E3B67584C7573688BB8B0814E4758372F
45432E4F6657363829532B245C463B61503A6A53496A5F546F6A54695D4D676153675A4C
6050436B6860738280738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787737E7F738485738989738B8B738787738787738787738787738787738787
7387877387877387877387877387871615146F705E898C837375676D615274736C737169
73695B6044355B3F352309093D595793DBCCB1EADD7FBCC07DB7BD7796936F826C84C5BA
8FB0B0697B7C3A2E271F1E133F302562554568564C6F68596F65596D6653695B4C67574A
675F5160778F64747E708282738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738989738B8B738787738787738787738787738787738787738787738787
7387877387877387877387875B6677150E0D86806D747666737564757B6C77807673756C
634C414A3E2A47261C2E0F097F544876504269463D706D67736953736851664B436A696B
63493C8075658371597D7E6D33271E442C245D48406A66517373626D6659655F53675347
6756495F6A5B525547545D6D6B7D82738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787211F1A000000523C2FBAAF9177786A736559736156737062737562
685344746E618FA491B0D8B4B1B1A4756F67675852634F47662F315935375929275E1F1B
561D1B5A4F4656392E6242425D463D300F0750403C6E6351706F6169604C6556485F594B
6564556963548894966D7684758985738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787737E7F738485738787738787738787738787738787
7387877387875B5F67050605100E0C9FA1918B927D736D60735F616B7167707A6B735D60
68554C55433271726B77807C737E7575897A7B978A7F94877D997F76856B7C846C748B68
7484696D604F713D3D6937315A261A501A13512118594A416E6259695E4C65574B615246
685649675B4E17110E555D587B8C83708282738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738989738B8B738787738787738787738787738787
738787738787627180B2A98AFFCEA3C1B18E707262736F61737D6A756964777168737B69
68695569574B787567706E6573797073776E73726A737970735F606D5D556F675A696155
6B5D525E5A465B5B495B6E4F69715A7D7E6680746B746D4C686151675F4D65574B615C47
685D4D675F512F32306E7C766B817F778F8E738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
7387877387877A6F567F756075847F717C6D6C6E61707567737872737B7373887C737773
6F6D6170645565504468655870786E737B7273776E737B72737A666D6D59675145675C49
5B56424E4F44584B3B5A44385A48385A46385C4E386C6855706A5F6B5B505E4E455F5046
6158465D5849161514798AA07E98A0738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
7387876B7677706B5B6B655761513D525C626F6E66777671737D77737F75737D73737B72
75636473675D705E4F756A5C746F6973776E735C5C6B6458706F5F665C4F675C4E5B4339
5B4F4760463C624C3B5F5245665A3F61533E5F4C387260536F5C4F6354485D5145635548
635B4E6A61550C0D0E666E666E8278738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787756A56776D60665A505F554B75746481635D73716E737B72737970737970737970
737A667576606C675169584972736B737B72737A6F7582767778746F65616D6659675F50
6C625360493C5F4A3E5F4F4364564B6C564E7B6B5E77726363594B63574A695C4D655649
635B4661584915110E26201C5B676C738485738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787736F5F6B6D5E503B2A6E72637F6D6E77786A738070737B72738280737C74737970
73736D73796C6864576B66536E7966707066737161737D7173776E6D6B5B615546635448
5F5A4C615749685D40614D3D64544771645C7774666D67596566586764555F5B4D5F5C4D
635D4F6A695C7A5D3C5D33231F1816475558738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
73665A633D315220205A403A6077726D7B6A73806A73756D737B7273776D73756A737970
73736B6B6D5F6D6B5E757F707B83767778686B5D56706C60735A58665444614A3F5F5044
58493E6150384D413557463D6C6657706C5A706B5B696154655B4E67544869574A655A46
6A52446A635566554A7F6A5BCFF9F2BDE0DB738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
73585668403D603D376364537B7D6B817A71737D79737771737B72737970737970737169
7371616D6F5E776B5D717264747671737D79757E77778077736B5C6863525E5247584E41
55473B54473D5E4F46766F5D7772616F6D5F706A5D696154655D5067594B67524C69504D
6352496566605A443461524482A3A5758989738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787736D60
736751685D49595139686B567E8271777870737B72737B7273756C736F676B6758706F5D
735D5D6D61596C60556B685B74746D73726273716773756C736162685047604E435E4F42
6152445D5B4D68644D6C65556D645673685B6B5F5267584C655B4E6751456752445F5544
5F5D4668685E6B554868625558676B657376738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787634F3C
4A302626201A36332B6B6E637A807073756D73726A736F67737161736D5B6D6D5D6C5E5A
615D5169655A6F74676F7A6A747A6973756C73756F73756C6B736066614E6055485E4F42
5F50436856496A5B4E715F5A6F645769615367675A6B66586560526762535F60515F5649
63534E68635F583222656052654233797F79738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787603E2E
1B140D26221F251F1F62655C76797373756F73756473756273756C737773757A76797F78
736D656B58525D51456A60556C6C5F70726C73756C7375646D5F58614F455644455C4C3C
584A3B6254476A6254685A4B605B4C6859536351466055495B54485D55495F574A635447
63554D61584853493059533E5D413B799DA2738787738787738787738787738787738787
738787738787738787738787
73878773878773878773878773878773878773878773878773878773878773766F6A564D
5D46383A2B212E25228279667679696B6D5B70726A7375695B564A554F4141362B3C3027
3E343049393A5E5045625045625A5072716B73756C73756E6D635E6356495C503A5F4C35
5A50435E51435150444C4D425956496264545B5A4A655F51696052655B4D635A4C635447
63554D635B4C3E2B22381D1753392B779A98738787738787738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387877387877387876B5C4B664F44
0A0605090D0C1A1A17817E6A707365736D60777666737564726D5F5650443E3B31212929
0F1819191A12363126361E173217135D514770706673756C6D6B5B6358495C4E3C58593F
504739655C4E726959786858745E4F634F49524B42645D50675E5061594B555246515246
5F5D4D635D4C4B36295432246840337B99A0738787738787738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387877387877A8F8F776656634C40
2E25212019132B1A15918975777C6D6F72647076687375677579736C6254917E74433A30
211612261A13293130483E317F79638A99837482797389856D756763574A4E41364E3F32
250C084938314F3F2A3F372C2B271F4442375553446459455D55475F574A594D405B5346
66534D55493F3427224A3A2D6C594F86B3B7758989738787738787738787738787738787
738787738787738787738787
737C7D738485737E7F738485738787738787738787738787738787080202321816665E51
3C30271C1A201B15128689746C6E617375676F7063696B5E70726C7277676F695971624F
A9886B9A704B8962418D745380735F757163747A7273776D6D6253635246604A375B493B
574031555B55202C2F0003051B1A192B312C101411242626302B21503C2C5750435B574A
6655464442342420192E272067625282ABAA718585738787738787738787738787738787
738787738787738787738787
738283738888738989738B8B7387877387877387877387870B0606090706120502080D0F
0609100F110E261A14968E796F70637476715D43425A47406F6D67757F777B837D7C766F
715F517368597E6E5F81755F7B7264737465747D767379706D605A6362565C533F5C5D41
6C573E7F6F597E5A431712113020162B2725221F1C4D3C2D624B3B7469546354465D5346
665D48221E1D1D1A152F211864382B71858B6E8383738787738787738787738787738787
738787738787738787738787
738D8D738B8B7387877387877387877387877387877387871C120F2F261B2C1D1721211C
0A0A0A251A142E1B1691826E776E616F6E5F7882756D756245372D3A2B243028211F1F1C
1818161F1D182A221C30231D5150496A7365747770736F5F6D60506361515C4C41614839
5B553E62604A675F4F947E64B388657B563E754D37946B538168475F5B4B615B496A6151
5B55491F1C161F17143322195F2F22769A9E738787738787738787738787738787738787
738787738787738787738787
73878773878773878773878773878773878773878773878721160F19100B121210171410
1C15101916112C2B267D78646F6D6075786A7778707A7E7588907E78685E4D4C4E765F58
7E5F4A7F6A546E574585735F8F97817F837C777872735D5F6D655C6363555C464737261E
30201B4D46365F5844635A446F5D4D766A516F6C58736D5358594C6355535B53495F5846
4440330D0F0D1213107C624C663B297AA7A9738787738787738787738787738787738787
738787738787738787738787
738787738787737E7F738485738787738787738787738787291F1721110C1E1611181511
0A07071B1410312A25665A4B69665A70746673756D737D7375817980938999AF9BA2B19C
92AF9F9AB4A79CB4A897A992798472747E766B6F5E69715D6B725D6C675A7676637A775E
4B3935231F1B0C0F102E28265851485F5A47675C485B55485C4B414B46385E52496A5349
221C18130F0D292721603E2E402419171A19495357738787738787738787738787738787
738787738787738787738787
738787738787738989738B8B7387877387877387877387871E1D1B211F1C1D17121D1511
16120C2017122F2A256C584777716274776973756D737B72737970738280738584738584
737C74738280737C74737B7475796C777666757363716B5D6F6055716C5E7572627A6F67
837F729B7F6C6A554734281F1014111717181A232328262031292160514B715A4C5C4E3F
17131217131020191A1A0C0A1F110D2A2E2C92ABAA738787738787738787738787738787
738787738787738787738787
73878773878773878773878773878773878773878773878729221F3C302B1916121C1511
1E1611241B1C302A26554B3B6060536F736673756573726873776E73776D737B75737E79
73817D73828073776E737970737B7473776B7375676D695C6F6E606F675A6F6A5D6F655E
6C69596B6A57746A5584745C816F566A513C5B4533785745766B5970565353524645493C
1915131C151117151111100B1D1A162D33308EA7A6738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787271C15292017231D191F1612
22100C271A152F23193932295E54496E6E6170726573756D737B72738280737970737B75
737E79737E7973776E737970737161737169736D626D5F546F6A5D6F6E606F675A6F6356
695F506D584C6B5D50695D4F7A6A59806E5C8575617C67566E5A536C5849635341392B20
1A14111C1511281B161B16121D16112A21185A5555647072738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387871E19122E2D2A241F1B261A16
13110C1915111813102F231C43352466635674746673756D737B7273807C73817D737970
737B7573756A73756A7379707373657375656B67586B6B5D6F675A6F61566F63576F675A
696154635D50635E50696759635B4D67574A655A4C5554475155465155463F4236151B19
0B0D0A1E191A12101111100B0B07072018154B4542738987738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787291E172D28242D282426201B
271B1720171227201B35312D37362F645D546F695D73726C73726A73746B737B7573817D
73828073776E73797073797073736D6B6D626B675B6F63576F63576F675A67675A655F52
675F52655D50675E50675C4F695D50635B4D5F5A4C5954476A55485F4E41332C261A1312
261E1A100C0C1210100C07071511121E17124647437F9B9C738787738787738787738787
738787738787738787738787
73878773878773878773878773878773878773878773878722221F2F2E2B332E292F2A25
261B1612100C24191538271D543C2B6E4C376B665870746573756A73726A73746B737B75
737E7973817D737C7473797073736B757767716D5F676559655F526C5E58695E526B584C
6B5953655B50675E5067574A5F55495F574A5C4B3F6550445B473B35332E231E181E1613
11100B121010110C0C15110C161212281B16BADAD6A5C7C4738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787737E7F6B74751E1B182A26222F2B272C2723
19141026201B2A221D262420483C2E6050426B6C6172756873756D737D73737D7373807C
737E79737E7973776E7379706B6B5C706B5B6D5F5471635775695B6B64556762526B5D50
6365566360505F4F4A5D554A5F5A4C635A4C65554858574A474437453B2D272017201815
1816111A17121A171116120C191611271B169EB9B7758989738787738787738787738787
738787738787738787738787
73878773878773878773878773878773878773898975908F1D1B1736271D2D2722302C28
312B2629211C29241F30241A44443A433C306053476B6B5E70726C73726A73776E73776D
737266737266736D636B67586B62536C6E616B6458675F4C655E4F675F4C6B62536B6456
655E50675B4E695A4B655D4C63524663504455524647473B40352A241F1E181413131310
11100B1310110F0B0C0707070E0B0C3C2A269CB4B26E8383738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387872A231F2E241A2E2D29322D29
26221D2218142F23192E292438372E33251F53453A6B7163747666737562737268736F5F
736F5D736F5D737167757767716D5F6F615667524767574C6B59566B61566B62576B5448
65594D67574A67574A615A4C6354475C4E41494639403429241D1D1F1C1617130F161511
1E1611161112100C0C120C0C2E1D17DCFEF3B8E2DD738787738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387873736322E2B272B2825352B27
2E22192A251F231F1B2A272424201C272726453E30574F3E656457696B5E707263737564
7375676B6D60696B5C7072626D6155675549675F4C63594A605C4E605C4D68594D635649
63584B674F4A5F584C5F5A465C4D3F554E4147443830241E211D1616130F100F0B121011
1C15111411110C0707100C0C271B1693ADAB6E8383738787738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387873332292E2B26332E292B2823
2927241D191A221D1928231E322D292E23192D221A3E3D34524A426050466A6055696156
69695D6B6D606F695C6C6558635F545F554860544963544A67504467534764554963574A
5F52465D5244584C3E53483D45453B3A352A382E24201C1514120F13131013110C100C0C
0F0B0C0607070707072B1D173822179AB2AE738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787686F7B3C312F312C282C2723
38332F31251A271A15352F2A28231E2F2C28211E1B2C312B222623312B26534B4254493F
5853505A53525A554C625F54584E433F382E41392F503F2F5B4F425D53465D43385D4D42
5F52395C4E3E55473B504236484236352923261B1619141219141013100C0F0B0C100C0C
0C0708080708120C0D1F1612B2D1CFBBE4E2738787738787738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387877F99953D3E3026231E2A2622
2A26221F211D1D191B2C23192C262239342F342F2A2E29252D2C2B37312B302C2323282B
1E292728251D38342B39372F292926302B22342B213834253F3229463A2B5646334C4335
3C312940302946382E3837322F2722261A151F161317131011100B0F0B0C0C0708080707
0807080808081B17122A1C179FB8B6778F8E738787738787738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387877387874D535D2F2B28342F2A
2D2E292E292517151026231E36343038332F3B38333F3C364642353F3F3330352D272624
291E17271D1D29201D2C262222202125242430262132261B2B231F3531283330272C2A21
383227322B202D2E282C231E2921191A16131E1D1A11110C13100C100C0C0D0808080808
09080822181218121272665FB0CBC7738787738787738787738787738787738787738787
738787738787738787738787
73878773878773878773878773878773878773878773878773878778878C382F292D2823
2B26222C2622312B263C342E39342F3A37322E2B272B27242F211F39241F31211A272320
1D1B182526231B17141F222022232122201C1B15131719171715141813121919151B1B16
1C1B16171212191312161311191513121310100F0B0D0A0B100B0C100C0C080808080808
22181D221813352D27C1E0D898BEBD738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787778F8B5D6865332F2A
2C2823322D292D28243D3A3426221D2F2D29231F1B2E2A26413A2E2E2F2A252725292824
28231E3A2F2A20191A22231F201713211613191310141410181410221915211915171210
16121016131020191519151119141012100B14100C100C0C110C0C080708080708120C0D
2B221C281C16C9E9E4BDE0DB738787738787738787738787738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387877387877387876D747B352622
342D29322D292C27231F201C312F2B403C362D2E2927231E30231B1D191623201B25211D
18171D1E201D1B18182519151A131914141115151113100C17151116151114141011100B
0E0B0C11100C1A151011100B0E0B0C12100C151112100C0C080708110C0C1D18122F241D
2B1C17C6E9E3C6EDE7738787738787738787738787738787738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387877387877387877A9490454840
2E2B262F2B272C2723342E2A2F2E292B2925231F1B211B18201C1916131027221E1E1819
1F18191C140F1A13181110100C0B0B1210101310110F0B0C1410110F0B0C1310110F0B0C
1511121A17121411120F0B0C07070807070707070707070715121218130D100C0C1B0F0B
B7CDC9C4E8E2738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
73878773878773878773878773878773878773878773878773878773878773878790ADAC
5E5D562B25202A26222B2D282B2C2837322D2E292A251915241E191715111A141014130F
1A14100E0B0B0D0B0B121010151111110C0C141111100C0C151111100C0C2A1C16090808
1411111916111411110807070807080E08081812121913131712122A1B173B2A1D7C593E
B8D1C8778F8E738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
90ADAC5F564F34332D26221D36302C38322D36322D25251F2926211D151B1410121C1511
1410111816111B1812161212100C0C100C0C100C0C100C0C100C0C1916111411112C3342
393C3C22181E100B0C1611111E18131E19131713123028212E231D2A1C174D362CB6DCDF
9CCBD0738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
73878799BAB75F575040373228231E2628243736313A342F33251B261F191A1711141111
0F0B0C14100C1310110F0B0C100C0C151212110C0C151212110C0C100C0C2D32332A212C
3F362E4840363D34314C4139362C241B171229211B29201B342F2A4D3428C4DFDAA9D5D5
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
7387877084858CACAA544637413B3437302B3B37323936313D3B3625201C271F1B392F29
2F2C242319131A1712151211161212110C0C100C0C1A161C1512121B1712131010201F19
2B27200C0B0D0D0E0C0F100D0C0C0D191310271F1B30241A5D432FA1ACB1A5D1D4738B8B
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
73878773878773878792B5B555574A25211C2C292542403B474B46403E3728211C1E1819
211613322A252B2923161212100C0C1F1B21221E242C2A22201D213E352F1C181E474039
332B2C322B263B312A3329233A30294F473738312A684D39C0DBDAA8D9DB7F9C96738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
73878773878773878773878792B0B0ACBBC6504B432E2A26292724323B434B4A465B564D
5C6055353030282E3048495968665D413634302E38342C2D4746543B342E312A243E372F
342B263A28233A281D352E29493D316448353B281DAFD3D29CCDD2738B8B738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
7387877387877387877387877387877C9692A8CEC65C5A623F3C372E353B4C5051495053
414642474A445B5E5B5A5147464037342F2A413C32312A27241F1925211B36322D322D29
3F2B214A33284B3C305B4A3E462E24504B51ABDDE5B5E0DF738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
737C7D738485738787738787738787738787738787738787738787738787738787738787
73878773878773878773878773878773878773878792B0A9CDF9ECC5DBE0565563545154
777B8C6F6B6F5B4E4847423C45443F5B525365595257524A6D615659524457534B655A52
4F4D40424A3E2E2C29717A88B6EAEEC5FFFB9CC2BD738787738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738D8D738B8B738787738787738787738787738787738787738787738787738787738787
738787738787738787738787738787738787738787738787738787778F8B9ABAACBFE5D4
A6CEC38DA5ADA7C7C792A4B7565E724852653D413F3E403D41413D40413F403E3B342E26
323229A6BEBFD0FCFAC1F0E887A9A2738787738787738787738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787778F897B968D7C9A949EC1B0BBDFCBBEE4D6C2E2DEC2EBE7C2EDE9C4F0EBCBF9F6
CFFFFFADD1D2738B8B738787738787738787738787738787738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.511074 0.97619 0.732558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(158) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80686C63
6A6C626A6C666A706A6A6D676A706A6A716B6A716B6A716B6A6D676A6C6368695F67655A
655D52645C5161584D60584D60584D60584D60584D6054495E54455D54485D54455D5448
6774766A7D806A7D806A7D806A7D806A7A7D6A7C7F6A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A76796A797D6A7D806A76796A797D6A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A76796A797D6A7D806A7D806A7D806A7D806A7D806A7D806E7369
6D6F6C6A6C626A70676A6D676A706A6A716B6A6A5E646052616052615C515E554E575149
575148595349584F455D554B60584D60584D6051476051475E544B5D544A5D54455D6F6E
67858B6A7D806A7D806A7D806A7D806A81846A80836A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A81846A797C6A797D6A81846A80836A7D806A76796A797D6A76796A797D6A7D80
6A7D806A7D806A7D806A81846A80836A7D806A7D806A7D806A7D806A7D806A7D80646960
67695C6A6C676A69666A716B6A6C676A666264635B525F5C5658525E4B495B4B455D564D
605F53606155645D515D5449574F45574F455751475754435A54475D54495D544B778D92
7790946A7D806A7D806A7D806A7D806A7D806A76796A797D6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7A7D6A7C7F6A7D806A7D806A7D806A81846A80836A81846A80836A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806E6C63
6D6C696A6C696A6C676A69646A6A656A6C606E706A7D7672787569746C6A6F645A6B584D
6B534F6B53516449485E4E475D54495D54495D54495D544B635A5060564B5D5449677476
6A7D806A7D806A7D806A7D806A7D806A7D806A81846A80836A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A81846A80836A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7369
6A6F616A6C5D6A6C646A6C676A6C676A6C6A6A73706A77706E73706773646869606E685F
6E6B5C685D536E6B5C6B574F664A49665D5B60594F6354496351475E51476360546B7C7D
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7067
6A6C626A6C696A6C626A6C646A6C676A736D6A6C676A66626A716B6E7370717A6D6B7161
67635E6B665B645E51655C53646253605344645C565D594F5754495A54496C767870878D
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A76796A797D6A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D805849435E534B
6A6C696A6C626A6C606A6C666A736D6A6C676A716B6A77706A736D6A6D676A6C6A6E6C64
716B5C6B63566B6358685B5368584D6454495A4E425A4F4463544960544964767A6A8287
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A81846A80836A7D806A7D806A7679
6A72766A797D6A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D8028221F3E3F38707466
6A6C666A6C6A6A6C6D6A6C696A706A6A6D676A695D6A6D656A6A656A6A656A6C606A7062
64615D645D56675956655C4C5D54455D584D64564B6054495F6054645F536E80806D8386
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A8184
6A84876A80836A7D806A7D80
6A7D806A7D806A76796A797D6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D8052555F2212114A4A506D6F67
6A736D6A706A6A736D6A706A6A69646A716B6A77746A6C696A6A5E6A5857644F4C5B4943
61554B6760546163565B584E64584F645A4E5A54435A54475A4E45574D436471736A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A81846A797C6A797D6A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D8071858720161074725AA1A1846A6C67
6A69666A6A656A69646A6A656A6C676A69646A6D686A6D6764665D615F56646054655C52
60594E5E564C6156476156495C51475D4F4564514966544A605449635A4E645D59676D6E
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A76796A7D806A80836A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D80170D0B68655DA5A6996D6F676A6C66
6A6C676A6C676A6C606A6C646A6C676A736D6A6C676A6A65683E42673138612C32612A31
642B336444425D4D455D4D45604B425A51415D54476054495E54435F4A3F533E345E615F
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7679
6A797D6A7D806A7D806A7D80
6A7D806A7D806A81846A80836A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D805255599A9B979D9B906A6A656A6C636A6C66
6A6C676A665A6A62576A62566A69616A69646A56586A4F54684848613F385B2F27603C38
5D3D356035375B363857453F5754435A4F445F514860544964544B63504664594E584034
5E58546A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A8184
6A80836A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D801B15132B2D296A69586A6C5D6A6C606A6C66
6A6C6064635661585067685F6A6F686A5F54643E3B5B2C2855423A473427536A58637B69
5B372D5328215D322D603E3A5D4E485D503B5A533F5D544760544960574B60534860554B
6868636A75756A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A76796A797D6A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D803E393D6B55479189746D6F6C645F59676C6A6A706C
6A5F57625244574239614A4F5E2B312104042E2B2D61574D6E675F87B3AE7B4E4855302B
4445314860523537294626205739335A4A39634C4463574E67635164594B605A4E605449
5541375E524C6A75756A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A76796A797D6A81846A80836A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D80251F1C4E564F797D766A6C62685E536A645F6A6A65
6A665C5F4437583C332509082C434598E3D49DD6CB78BABF74AFB76D87896C8D7980BCB2
8EB1B3697A7B41332C1D1D132F261E59483E5F5248675D52675E55686251645649605147
60574C5561745966746775796A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A81846A80836A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D8058617327171650524D6A6C5E6A6C606E776A6D756D6A6C67
5E4C444B3F2E44251C38120B5E352F693D35613E37675A566A64526A5F4C624B4560565A
5E483D7D6C5F8B7B63837F6F33281F30211E533D395F5A4A6A6A5B686258615B51604F45
604E455A59494B4C41494E5C5E6D796A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D8028221F0600004F3B32948B796D6F646A5F566A59516A665A6A6C5D
66574A73696089A490B3DEB89DA5986E656261534F5A413C5D2B30552C33542828561716
51191A4F3A37563B32613D3D674A432F1008392B2D625449666358655D4C6152455A5549
5D5C5064574B7E85856A717C6472776A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A76796A797D6A7D806A7D806A7D806A7D806A7D80
6A7D806A7D80585B65130B0A150F0D68766F7D83746A665C6A5B5F646763676E646A585C
66554F523F31605B586D76766A7B726E837775918678908474977F73826A75836D6F8A69
6F81666757496B3D3E67342F5D251B581D15431A14463433625650655A4C6155495E4D43
5F4E456052491D0F0C3B3D38707D7A6775796A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A81846A80836A7D806A7D806A7D806A7D806A7D80
6A7D806A7D80637381C7BEA2FFD1A5A1947967695D6A695F6A77646E63616D64626A7765
66685768584D675F5567625B6A716B6A706A6A69646A716B6A5B5F685855676056655C54
64584F5B5745535947586A4E67715A7D7F667D7369665D455C544661594B6155495E5745
5F564860574C3F3A364953525E70706D83866A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D80777058746C5E6E7F7C6B756A63655B676C626A6F6C6A776F6A7C766A706F
6C6D636C64565D473F5C534A676C646A746E6A706A6A706A6A7866686959614D44615445
5852404D4B42514739543F35544235544135574935625E5066605864554D5B4B435A4A43
5A5143575145241A174E5C726F84916A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D80646F73676961645F535B493A4F53596165646D6C696A73706A77706A736D6A746E
6E61646F635E6C5D4F6A5A516A615D6A6D686A595A64585167665B625B5161594E583F38
5847435E443B5C47395A4D4160533D5D503C5A473665534967554B5D4F455B4E435D4F44
5D534A635A501B1112373F3C5D6A666A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806E68586D675E6258515B514A6E6656735D5A6A64656A706A6A716B6A716B6A716B
6A78666E715F68665260514466605B6A706A6A786E6E78726D6F6F6C6563686258655F51
665A4E5E483D5A453C5A493F5C4E4866524C74645A6D675C5D54495D514764574B605246
5D53435A51452617121A14143238416A797D6A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7067646659503E2F6363577465666D6F646A75686A706A6A78786A75716A716B
6A6D6B6A736B66635964625163685867665E6A6A5E6A736A6A706A68695C5E53465D4F45
5A54495E554963583F5D493A5C4C42665C566D6A60686155616255605F535A564B5A574B
5D564C6360568E6944623323180D0C232A326A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A61595E3E364F1F1F583B395562615E73646A75646A6C666A706A6A6C656A6D666A716B
6A6D6764665D68695E6E786C70786D6D6F61645854675E576A5655624F455F4A3F5A4A41
55443B5A4A364C3E3450413A625B4F666354666255655C5261554B604F45645147605443
634D4163574E64564E846D5CCCEAE0A1C1BF6A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A5B5D6643425F3E395D564A706B5D736E696A73736A706C6A706A6A716B6A716B6A6A65
6A6A5E68695C6D655A6B685D6A6C696A73736E7B756D75716A695B6660535B514755493E
5243394E413A5B4B436B66576D675A67655A666258655C5261584D605449604D49644A4B
5D4D465D5A565845365A4A3F6D7A7B6E81846A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A685F
6A695566614D59513A5F5D4C6E6F646D6F686A706A6A746E6A6C676A6662646055676658
6A585A685856635B52645E556A68636A695D6A6A616A6C676A5E62664E485F4C425A4B40
5D4D425A564A5F5D4A625C4E635B506A5F5564594F61534961554B604D43604D415A4F41
5A56435F5D5367564C635A4F4C4D505862686A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D805E5243
472E2628201B302E295A5B546C70656A6C666A69646A66626A6A5E6A665768665A635855
5B584E615C55676B636771656A6E616A6C676A6C696A6C6764705F6262515F52475A4B40
5A4B40634E4462534A665754675B5360594E616056646256615A4F605E515A5C4E5A5246
5D4C4A5F57565534265D5146603D2F675B566A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D805F483B
24160F261F1D241D1E414847696A676A6C696A6C606A6C5D6A6C676A706F6E7372717A74
6F696464534F5748415F554E6362596769636A6C676A6C60685B565E4E4755424357473B
544539594C4263594E5F544759524760534F5D4A43594E45584F45574F455A51475D5045
5D4F485A4E42524C3550463557403A6772776A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A6F6C6A605B
6D4D3E3E2A2030242058564F696A5D6466576769646A6C655852474D463C3E322A352822
382F2C42353756464159463F5A4D486664606A6C676A6C6A68625E62554B5B4E395A4734
574B3F564A3F4C473F464840504E45595B4E58574A5D574C645A4F60564B5D54495D5045
5D4F485D5349422D25341A16463025636E696A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80645B50625147
1709070F0C0C1B17164E564F66675D6A665C6D6C5E6A6C60706D60564E44403B32242728
111518131611292620321B162C110F48353267665E6A6C6768695C62584B5B4C3D54543D
4E43365B53486D62547362546C594C5D48454F464059544A60584D5E5449524D434C4D43
5656485D5649523B2E51312459362D66686D6A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80718587726C62624D41
442E282719142B18145A5B546D7266676C61676C626A6C626E736F7065598D7971513F34
2717132417122228293E3B3174705D7781706A756E6A7F7E68746A62594D4F40374B3930
2A0D093625254838283C312829241E393830524C41585041574F435A5147584A3F564C42
5B4C4852443D3B2A2544362C5C50487083866E81846A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A72766A797D6A76796A797D6A7D806A7D806A7D806A7D806A7D8012050411050C625A4F
4D382C251C211D15124C575163655B6A6C6267685E61625967696370776A6764557E6955
AE8C6D9B714D855B3D7D6B4E7268576A61576A6B666A6C65686056625449624B39594539
5E46354B4D4A222A2F070406121416262826131210181C202A251F443327554A3F565146
5B4F434740342C231C29231E4D4F466D817F6B7E816A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A797C6A7C7F6A81846A80836A7D806A7D806A7D806A7D80150909140B0B0D040200030A
0F0B1116110F2819145C5D5667685E6A6C695B4343533D3B615D5A6E777475817D797570
6E5C517165597A6A5D766A59706A5D6A695D6A6E686A716B685F5C6260575B53425B583F
69573E7B6550835B45241514281B142A2121271F1D3E3228594439665E4E6050435A4C42
5B56442D211F231A162D1E174529235C575C687A7E6A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A84876A80836A7D806A7D806A7D806A7D806A7D806A7D80311D1931231A301E18211D1A
120B0B2618142F19165A544E6D655B6765587382756B726340312932201D2C221D1E1D1B
1816171A1716231D19291C1A413E3B5F675C6A6B656A665B685F51625C505B4D435D4338
564F3C595743645C4DA78669AF86657B543D774C3684614D7760445952455A5647665B4C
564F462D2219231714301F1946281F5E62666A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D803622191E0F0B17120F1B1310
2215111C15112A27234F544C6161586E6F646D6F68777B7688938276675E514A4C6F5B56
7F5F4C7B65516B55447A6B5A7F82727478726D6F6C6A585D685F5B6260545B47483A2520
2D1A1840372E56513F5D54416A594B7769526E695667634E54544A5D4F4E564C46565143
473E331913101612106254445E3A2A5C6C6E6A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A76796A797D6A7D806A7D806A7D806A7D803F2E2328120D2315111D1511
1107081D13102E242144413B56564F67685F6A6C666A736D6E7B777D948B9AAD9A96AB99
8EADA094AFA499B3A88CA18E71796B6A736C64695C616D5A646A5A6964597275627F7B63
513B37221A190C0C0E1E1D204C46405A5445645744564F4457473E484135564A44624C46
2D1E1A1D110F2C241F43312741251A160D0E272B336A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A81846A80836A7D806A7D806A7D806A7D80322B2827201C221712221511
1C120D2216112C24214D443B635D546A6B616A6C666A706A6A716B6A78786A7D7F6A7D7F
6A75716A78786A75716A74716E736B6D6C5E6E6D606B655A675B526B645A6E6B5E766C66
8A85779F816F72574932251E0F0F0E101114181C2024221E2C251F55474468534857493D
2518151E1310221718170B0A1B0F0D3029275E6F736A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D803F312D3F2F2A2017131F1511
231511271A1B2E26233E3B334C4D4661645B6A6C5F6A69616A6D686A6C656A716D6A7573
6A797A6A78786A716C6A716B6A74716A70686A6C6268665B67685C67605667615767615A
696356686856796C5789765E846F56664F3A5A41316D5041736656634E4C4F4A4344463B
281A162115111B141015100C1B18152C2C2A5C6C706A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D803C2A202C1F162A1D19231612
25100C2918142E20172F292444413C5E5C5467695F6A6C666A706A6A78786A716B6A716D
6A75736A75736A716C6A716B6A6A5E6A6A656A665F685B5267615767685C676056675D51
65594D68534968584D67594D7765577F6E5C81715F73615269534E655446604D3E3E2B21
2517132115112A19162016121F1511271D15362F3253585F6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D8032261D302B28291F1B2A1A16
19110D1B14101B1210281E1931281E4E4A436A685F6A6C666A706A6A74726A797A6A716B
6A716D6A6D666A6D666A716B6A6D636A6C5F64635664655A676056675A51675D54676056
655C525D584D5D584D6461555D564B6051476054495250454C4F434C4F433F40351F1D1C
130E0B201819181011160F0C1107071E1413342F2F5561636A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D803F2C233025223027232A201B
2C1B17241612291E1A312C29302F2C454542615A536A69636A69646A69626A716D6A797A
6A78786A716C6A716B6A716B6A6D6B64665F646358675D54675D546760566160565E594F
61594F61584D60584D60554B64584D5D564B5A5449585045624F445D493E392C27241613
2B1E1A160C0C170F101208081A11111F1511343635596C706A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D8036312E322C29342C28332925
2A1B1719100C24171435221B4C3528563D2E5A524967685C6A6C646A69646A69626A716D
6A75736A797A6A75716A716B6A6D676E70666B685D6161565E594F63565365564F645349
64534F61554D60584D6051475A4F455A514757473D604A4156433938312D2A1F1A251714
170F0B181010160C0C1A110C1B11112819168DA9A98FAEAE6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7679646B6F3227242B23203028252E2622
1F15112A1E1B2B201C26211E3B332A50453C5A585266675E6A6C666A736D6A736D6A7472
6A75736A75736A716C6A716B64675A676257685B526B5D546E6358645F51615C4F64584D
5D5E505D5A4D5A4B47574E475A54495D5449605247545146474237493A2D2F2219261815
1E15121E16111F17111B120D1D15112719155D6E726E81846A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A81846E888A30272235241C302420312926
362C272C201C2B221E3022193A3A3339362D4C413B5E59526769636A69646A6D686A6C65
6A69606A69606A6760646055645D5263655B6461576159495E564A615949645C4F645F53
61584D60554B6457496056495D4D435D4A41524D4347433941352B291F1E1F1414191310
17100C181010150B0C0E0708130A0C352623647073687A7E6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D8041322E2F221A302926332B27
29211D2618142F20182F2623322F292F231E3D35305A5A536A6C5E6A6C5D6A69616A665B
6A66586A66586A6A616E70666B685D675A51614F46615049645350645953645C53644F45
6153496051476051475E54495D504557493E494137413329291E1E241C161E14101C1411
2215111B1111160C0C180C0D2E1B17AFD2CB9FC5C36A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D804C4944342C282C2523342825
3222192D241E261D1B2B2422251D1B26252434332B433C3258544B61625967695C6A6C60
6A6C6264665C61625667695D685E556151486159495D54475955495955496053495D5248
5D5147604B475A51495A5443574A3D52493E494237342520281D161C130F160F0B181010
1F14111A1111130808160C0C251815546468687A7E6A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80464138352C27342C282C2522
2C262322181A251B1928201C332B272F2119271D182D2E2B413B3756454060554E615951
615F5764665C676258635B535E5C525B5348594C455D4F47604A41604C435C4F455D5147
5A4D43574D4155463B4F423B444139393229392C23281E171A120F19131019110C160C0C
140B0C0D07070E08082A1A16372016606C6C6A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D8078818E4637343329262E2622
37302C36261B2B1A15342A272A211D2F2927241D1B2327251C201F242220443B374E433C
504848534B4D534E495A574F554B423F372F3A332C48382C54483D574C43573F3657453D
5A4D3857493A5243394E3D34483D34382924281A162114131F141119100C150B0C160C0C
1308080F0808170C0D1F141190B0B29DC0C06A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D807E9A964F4C3D2B231E2B2320
2B232023201D21191B2A1F182F2420372F2C382F2B2D25232C28282E2B2826231F212226
1B2223211F1A302B2633302B2A2726302923312820302E23372C244033274D4131493D31
392D283B2B2643332B3934303024222B1A152416131D131017100C150B0C1208080E0808
0E08080F08081E16112B1B166273766D83866A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80606572392F2D342C28
302C283128241D151125201C352F2D37302C3B3531413A35443E333D3B312F322C282422
291C17251A1B241A1A29201F261F202421232E232130221A28201D2E2A252E2B252C2720
362E2531281F2B29252E211D2C1F19201614221C1918110C18100C160C0C1308080F0808
0F08082516121C11125F58558495946A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80809195483833302522
2D23202E2421362A263B302C372F2C3934303028252B24222E1F1E37211D341F192A211F
201B182523211E16141E1D1D252120241F1B1C15131917171914131810111915131C1915
1C18151A12121B11111912111C1412181310150F0B140B0B150B0C160C0C0F08080F0808
25161C251613362A2590B0AD86A7A86A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80728A87717C7A3B322D
2E2522332B273027233A343029211D2D2826271F1C2E27243E362D302D292826242C2523
2C231E382B28261A1B23201D2216132415121E13101913101C13102318152317151B1210
19110F1A12102218151E14111D131018100C19100C160C0C160C0C0F08080F0808170C0D
2A1F192C1B16A5C1BFA1C1BF6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80757D85452F2B
362B27332B272E2622211D1A312C2A3E3733322E2A29211D2C201A221816251D1A281F1C
1D171D1E1D1C2018182717141F13191913111A141118100C1B141019141018131016100C
130B0C160F0C1C131017100C130B0C18100C1A1111160C0D0F0808160C0C22171231221C
2C1B16A7C8C5A7CBC86A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D8077928F585951
342C273028252E2622362C282F2A272B2623271E1B251B18211A181C1310271F1C221719
2317181F130F1E1217160F11120B0B170F10181011150B0C180F11150B0C170F10150B0C
1A11111E1612191111150B0C0E08080E07080D07070E07071A11111C120D160C0C1C0E0B
98ADACA3C3C06A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D809ABBBB
6D69613026212B23202C29262D2926352F2B32282A291916271C191C15111C131019120F
1E130F140B0B130B0B1810101A1111160C0C191010160C0C191011160C0C2B1A15100808
1810101D15111A11110F08080F08081308081C11121E13131B11122B1A163D281D72523B
8A978F6D83866A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
9ABBBB6F635B39322E29211D352C29372F2B38302C2A26202B242023161B1910121F1411
1910111D15112017121B1211160C0C160C0C160C0C160C0C160C0C1D151118111130313E
3A3A3C26191F170C0D1B11112218132218131B121230251F32231D2B1B1646302995B8BE
89B1B76A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D80A2C9C86F635A4438332A211D27242235322E3E342F35251B2B1F19201711191111
150B0C180F0C181010150B0C160C0C1A1111170C0D1A1111170C0D150B0C2D2D2F2B1F28
3C302C4C40364335324C3E373A2B242017122B1F1A2A1E1A342C284C3228A3BDBB92B7B9
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D8067797D97BCBC614F40453A34392E2A38312E3A34303F3A362C211D2B1F1B3B2D27
342B242719131F16111B12111B1212160C0C160C0C1D151A1B12121F1712170E0E211C17
29221D120B0D120D0C130E0C120C0D1D1210281C19302219543B2B919B9F89ADB46A8083
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D809EC7CA6160522C221D2A24223E3937474743463F392E221D201618
2415133428243028231C1212160C0C221A1F261D232D2721261D213C312E23191E3F3734
352A2B382C273D2F293628233C2E284D43353B30295D4737A5BFBF98C5C5748D8C6A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D809EBFC2B6C7D1584F482E272429222133373F4E4B485D544B
5C5D543830302C2C2F49485668655D453633332C36342A2C47434F3B322F362B2439302B
372A263B27223B251D382C2746392F5C423242291E89ACB089B5BA6A80836A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D807A9693B2DAD569646C413A3730303543484C484D51
4142404A4A445B5A57564D43443C3539302C42392F342927251C17271F1B362F2B332B27
3D28214930264B392F59463B472C23464148A1CED89BC1C26A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A72766A797D6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D809EBFB8CEFBF1C8DEE05A57664E4A51
7273856F6A715A4B46473F3B44403D5A4F516354505B514A6C5E555B5143544E47625750
4F4C4140463C302B295E6776B0E2EABCF7F289AAA86A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A84876A80836A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80728A87A4C5B6B6DFD2
9DC5B88DA8B1A3C4CA96A8BA5B6076444D613C3F403E3D3A3D3C3A413F3E3F3A39322B24
332E288EA4A7D2FFFDAFDFD67A97946A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D80728A84708B877A9992A3C6B4B8DDC8BCE5DBBFE1DFBFE8E5BFECE9C3F0ECC9FBFA
CCFDFF95B8BA6A80836A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.754707 0.245293 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
69.000 12.813 moveto
(deg) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D90634E
9D7D6D997A7399827899766D998278997F75997F75997F7599766D997A67907163946D5E
8B5F518F6656855E4F89615289615289615289615289594B815C46845C4F845C46845C4F
ABB8C2998E8D998E8D998E8D998E8D998585999291998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998A8A999392998E8D998A8A999392998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998A8A999392998E8D998E8D998E8D998E8D998E8D998E8D936751
98796E997A6A99827D99766D998278997F75997B6C957B709A7B709A7667917162916D5C
916354906555875D4E8E6455896152896152895D4E895D4E815C4A845C4C845C46846C68
ABA2A3998E8D998E8D998E8D998E8D998988998D8C998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998988998988999392998988998D8C998E8D998A8A999392998A8A999392998E8D
998E8D998E8D998E8D998988998D8C998E8D998E8D998E8D998E8D998E8D998E8D956851
9E7E73997A70997E73997F75997A70997F75957764897266A0705D95685C8C6B578B6A5B
89625389615384594C845C4D8A60508A60508A5D4E8A5C49855C50845C4D845C4A94979C
948685998E8D998E8D998E8D998E8D998E8D998A8A999392998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998585999291998E8D998E8D998E8D998988998D8C998988998D8C998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D93634E
987D72997A6F997A70997E74997B71997A6B93756C816F65866656915A587F5D49886152
88655A88655684594B81614E845C4D845C4D845C4D845C4A88605080584A845C4DABB8C2
998E8D998E8D998E8D998E8D998E8D998E8D998988998D8C998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998988998D8C998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D996751
99796E997A70997A74997A70997A70997A6B997E7399796F93716394675E905E568D6150
8D60568A59538D60547A4C44835B4D836859805544885C4D885F50815D4E886455A5ADB8
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D996B55
997A6A997A6F997A6A997A74997A70997E74997A70997F75997F75937163926A5D8F6256
94665C8F62558F65568A575184574B895E5384665C8455448A5C4D855C4D967C759B9A9A
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998A8A999392998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D8D6D64AA917D
997A6F997A6A997A6B997A73997E74997A70997F7599796F997E7499766D997A6B936D5B
92675D8F66598F66588A5A5389614F84594B856356855D4F885C4D805C4DA1999F9D9492
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998988998D8C998E8D998E8D998A8A
998F8F999392998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D5F463DCC9F8B9B7A6C
997A73997A6B997A6A997A6F99827899766D997E6F99837E997B71997B71997A6B997567
95645A956B5994665C8B63508B594E8B615284584A805C4D8D645584584BA0A8B3988C8B
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998988
998787998D8C998E8D998E8D
998E8D998E8D998A8A999392998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D89767A2D100BF0C7AC987965
997E7799756C997E7499756C997E74997F7599796B997A6F997B6C996D6C957A63967563
9A7165946A5D90665C8C5E4D8F5E4F846051855947855C508963538A6151ACB9C3998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998988998988999392998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D9D92913A1C168A6A64876862997A70
997E73997B71997E74997B71997A70997E7499837999766D9576639A6562956A5A8B6354
94695A956A5B906A57855F538F5D4E8B6050845D4B835C4C805C4D886051A19EA19EA4A7
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998A8A998E8D998D8C998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D48281D9A837B7E5D52987965997A73
997A70997A70997A6B997A74997A70997E74997A70997B7190544B94675C905B4E905E50
8F5D4F8F785F8B614E8B615089584985604B8E5C50895C4D815C498D5A4E907668AFBFCC
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998A8A
999392998E8D998E8D998E8D
998E8D998E8D998988998D8C998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D89767548322A896B5E997B71997A67997A73
997A70997667997A6B997A6E997E78997E74996E68997A6F90474390493F8C3B3395504D
8B433A955950815C4A8A624E8A5C498556488D604F895C4D845C4A885345846353988277
AABFCC998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998988
998D8C998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D371E1AF4C6AD9D7E75997A70997A6B997A73
997A6B956E609A70619E8271997972997263955455965B4E9260598434279A6056944343
812822903E348B504580594B84664F84533D895F518E5C50895C4D89584A895E4F896455
A7AAAD99999D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998A8A999392998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D775F5F4E392F9E837498796E95725E9E877B99756B
99725F8C6955915E51A9887E91574D601B0DD7958790413B8D645A794C447A302581634F
7E3C2F8A403E762D21A34036806B55895A3D885A4D8864538E604E84554A896051895C4D
997F71AAB2B799999D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998A8A999392998988998D8C998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D331A18CE9C8297776C997A6A9065589D8B82997B71
996958834F3A8753456A1814BF9F955E15137D453E8B4A4591544A987D728A3C34804C49
683728633E36521F16602213AF4F3B8D70538D52478E6B5B8E6553895E4C84584D895D4E
8963549996A4A6998C9E9997998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998988998D8C998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D8D7E861E0805E9BB9B9D7D72997A6B936B5F987671997A70
915A497B4B32813125460D06B886799B96859A807A9EA8A9997D7499867F8C63599F9A95
916758817A794726223C26244A160EB1553C936C59996F59936E638A5D4C855A4C895446
89635385878D907E82A59DABAAA497998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D5F463D4D28247D57509D8572987969997262997A69998377997A70
874B407A5845723A33460A107D383A8D62529062579A7C72A06960927763924F43955749
8D59499F957E844D3F725551402C244F0A01BE786498775A9877698B5F4D855A4E85594B
8E5F50847062898890746271ACA9A0998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998A8A999392998E8D998E8D998E8D998E8D998E8D
998E8D998E8D8D7A7E18070332130FDCA1909271609976669969639579619E7C6C996D66
875A4682523DAD9B91987C6D99676293635D8D61598B5851914E4A834845864541833731
833B3A83564889464075413761322442130E7C2C1FB18C6F9E7A688B644D85564B815749
8D635389685856362CDED9E99084869E9997998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998988998D8C998E8D998E8D998E8D998E8D998E8D
998E8D998E8D7D67721D110800000C816E659E7E6F997163996F6993666298876D996B66
8752487B4739A088779E8881997F7599756C997E74997F7599695F906D57946A5C8B6350
8F5E4F81554490484587463C75332F5E26245D232588583C9E746990665085564B815846
8D5B4F8963542E1D1DC2ABA4AAA3A7988C8B998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D886B69957A74936F618F6A589979699E7A6A99796E996B66997A6D997566
8A6050844E438E6151A594849E8781997A7099756C998278996860905E53905E4F906E59
875A4A7E58498A533F8554448559448551448052448C61509267568F614F815547855B49
89604B8A5F53241413D6C2CA9F978A998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D9586869E745C9572669675638D8082A9795E987D72997E7399796F997E74997A70
93615889634F844E42977B6A9D8C83998379996A649588739E7F708C5D50905B4D87523F
876854774B3D7E553F7F4E4283553B7B4B3E7F4C39966D5E8E64558B5D4E825447845648
845F4C8860500F0306D9BBB8B3B1B6998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D937569987C748C614F8C63518D7F799A6B67998776998278997F75997F75997F75
996860936257865647945F53A3938A9982789968649372659879698A5D508A5E4C804A3F
83594B7745387F4F3E7F54458859458353418157458C61528B594B8B5D4E84584A805245
845F4B895F53100506613F38F9F1F0999392998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D996B5595766B8049389E847695696298796999767299827899837C99796C997F75
99766899715E8757488F5E4C9E82799E837D997B6C997E7899756C9065588757498B5D4E
855C4D814D407F4E397B4940885C4D925F549267558A6152855E5089584B85584A85584A
845B49886454261A172815155D453FFFFFFF998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
997E759164528D514483664F928375AF7469997669997A7399827899847D998077997F75
99766D9576639065578D685797756698796E956D639E8D7A996E6C8C6E53865449855B4B
815646895A4278493B8A51408C6555926358986D5F8B6354856152895D4E845D4E805C49
88574B88705F77473651322C383D48837473998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
996056874E3F7C3A328465539081739A7C72997E6E99756B998278997F75997F75997B71
997B6C907164986D5E8F78689D7D72997E6E93675E98766899655B875E4F814E41815243
7C4E3F84533E7B4F3F85594B8C61538E695A98695B8B6354855E4F89594B89574D845B4A
8457458E6F637D4733895D51AFC2CB938988998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D99827A
99686187443F793D318D675BA08675987972998278997A70997A70997F75957B6C9E7F75
996D67907B62996C5D9579689D827B997E6F997B75997A7099655C875C477C55477C4F40
7B4E407651448756448C6256946959936E5F8F665790625385615289544789574B85564B
855B498D6A677F47377F594A9D9BA3B1B0AE998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D91614B
8E5D4E7446348F503DA67E6BA08371997A73997E74997F75997B6C99766C907667997065
966D629A6F65947461946E609D7C71997A70997A6F997A7095685F8C4F457C50437C4F40
7F51437F594A825F4C9263588E695694695A906A5C8F5E50855D4F89594C855346855245
845A4C8D7063813A278E7B6C80554CABCDDA998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D834029
4A22146C3A2F572C25D39D80A28578997A6F997A6B997A70997A70997566937465926A61
895E528F625791725D9F8270997E6D9E7E77997A70997A6B9069608759477E4C4780553C
7B4D418D5C4D8863538E5C5090685895655A8B6451906A59875D4E8A6050855D4E845346
84564F896656793D298D5F4C8A4D45ABC5C9998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998681814234
391E153A1F18492522CA977CA2857895766C9E7E74997A668D695D9C796B8E64559B7260
97685E975A53956B54946B599B806EA3877F997A70997A6B90615781544478493D7F4C3B
7751458854458561518B5C4C94635394695C8755488E6354845D4F80584A845C4D845346
84564F845F4D6331207C37229C5D46B0CADA998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D956D5D8C5B56
2604013617113F1F1AE6A78A987C6B997666987D72997A6B84605474514470493A5A3B34
58312A7E3B27A05F4B843C2A8C4A34C4B19B9E837D997A70906558815044784C387B523B
77453B8D61517D5A4C77574A815749845E537D5C4A97685789615281594B7C5749855749
8E5B4F845B4D57291F66281C8D4835AFD4DC998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D9D92918E5844825045
1C0E101F0C093A1613E2B4959878699470629E7D6D997A6A9371676D483B6D524A2A1D1A
2D13114B1F1469443A893B2A7E493E9678699D807A997D76906450814D417044347C5137
511309AC7A608A5B3F8157497846349E66567C5A4C91624D8A6053855D4E734F417A5A4B
8C5A4F7C5644572820773828934B41AEC6CB938988998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998F8F999392998A8A999392998E8D998E8D998E8D998E8D998E8D3C100BFDAE8C8B6355
3018161D0F152D100BF3BC9C997969997A6A9475669A7A6A9E7E77845F508E5C534C3A35
2B22242C1A1748362E744D428D5A50977D6C9D8B8399847D906B5B8151446E42326C4537
4D20196D4C465D382B1D0304833F2D6C4B3C552B1E975F4B8650359D614B785A4E7A5547
8C564B674739451F18683125B66F5DAFBECA958A89998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998988999291998988998D8C998E8D998E8D998E8D998E8D401B163919144D060093513C
30141A26120E341512E5B7979475669D7D7288584B967B64A9908793796B8D61547D5145
79514174504170463884604A9064599372629D8A82997F75906255815C4B784331724E3B
6F393067524E44333009010550201453342E361E18784431764938885A44764D41765A4B
8C5B4840211F412217522218B45943B7DEE79A8F8E998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998787998D8C998E8D998E8D998E8D998E8D998E8D998E8D1801003A1E16310E0D3C1D18
190508351712361411E2B19298796994796D8D5D5B7A4F41865747A07B67906C5A825349
793F31844D368E503B90513BB48D779F7C6C9D817A997F709062598163547847387B5037
7A563E8D5D4F7B51471F1F24291C1D3B25213D2C2667473B734B3779584C8958457A564B
7A56452D15103415125022179D3827BBE2EA998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D1A0200290C0828120E2E120E
240E0C25100D452421CF9377A9827093796998797288675A6B4438693C355D473F764A3F
4C3129583C325F362C784B3F8B716295756B98796E996D6390725B815E5078443F65311E
77402A9B76518E6051845C4B7E544A654436613D368453427B524284564B7A5A458E604B
67473B1C0B0928110D8D4E3E612017C4DEE6998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998A8A999392998E8D998E8D998E8D998E8D20060324080525100D23100C
1501022D120E442925B37B62B288759E8271997A73997E7493746681554E614545774C49
72453C70473D693F367F4E418C6B5D9D817B9571649A6C67956B5E8563557E514D562D28
441C195A32205E3321AE664B9D6E5B855C467B58487A56488053437651448F5D53825A45
40231A220E0C2F1E1A97493469281A5F4E49FAFBFC998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998988998D8C998E8D998E8D998E8D998E8D2109072E1411260E0B27100C
1A09062A100D442925A66B53AA85739D8170997A73998278997F7599837C997D73997D73
99796C99837C99796C997A6C93715E987D729376688F6D5E946C5D8F70618D6A5C825A51
5034333C23212A1E1A4E251B5D32228A4A3873523E834A357A4735926357805547805244
240E0C27100C30181949110A6C1D10453531E0DDDD998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D200B0A3B23201C0C092A100C
250F0C2C1415422722935D46AF826EA98B79997A6F997E7899837999847D998A8799847E
997F7599837C997B6E997F75997A6C997562997A6A90695B946B5D946A5C947564946761
8566597F554D5D3E383E2C293725214D2A2354392E6E473A5E4439834A47815D49784B3C
220C0B260F0C24110E220A07431612523530E1DEDE998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D250B083E21192A1715250E0B
2D0B073216144023196A4335B57D65A88D7A9E7E6E997A7399827899837C997F75998A87
99847E99847E997B6E997F75997B6C997B7199766290695B947564946B5D946A5C946B60
8B66588962537F5E4F7654477253475E3F3661403775483C79554B7E4F45765143553526
281110260F0C3014111E0E0B2C100D4A271CC3ACB0BBBFBC998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D2108044228242D16132F1310
1D0A062F110E2F130E5B2F2291583CC29C8A9D8271997A73998278998885997F75997F75
998A87998077998077997F75997664997A6F956E60956C5E946A5C947060946B5D946A5C
8B63548B5E4F8B615284615384584A895D4E805C4D7C534685564B855649734738371D18
200B07311617200B0C200C07160103411B15956E67CBCFD2998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D2008043B252339211E2F1613
2B110F250F0C321916492B25663B2AC5886FA98B78997E77997E74998981998A87997F75
99837C997B6E997F75997F75997668957662956E5F946B5D946B5D946A5C906A5C956657
906657855E4F896152896455845E4F84584A855C4D7353468256487252435133292B1310
2B1714180507200C0E1401021E0B0C2D110D7F5A53D1CFCF998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D230B084027233F2723361F1C
2F120F1D0A073918144D2A1F633E2F9D624AAD907F9E8276997A74997E74998981998A87
99847E997F7599796C997F7599766D9375638F685A906759956657996A608B6A578F6253
8F655A85614F896152895D4E856050855D4E805344805A4C7A4E3F66423847241B2E1311
1F0C081E0B0D1905071D0A071D0A0D351511ACA09D8A7B7A998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998A8A958B8B210E0D402622442B273B231F
270E0B2F18153117143F211C79422E915643A6826FA38674997A73997E74997E74998885
99847E99847E997B6E997F759572649E7A6B90695B8F6B5D8D66588F62569066578F5E4F
8B65598B5D4F85584E8A614E855C4D845C4D8050437B55477344365E3A2E321A13301311
1E0E0B210F0C200E0C1D0A0623100D371512FAFAFA938988998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D9989889382821A070649261D3B2623422925
321C192E1613371F1B3C1F1669463A804432AF7A66A48E7B9E7E77997E7499837999847D
99857F99857F997C73957B6C957364997969956457906653956A5E9066538F665A8F6253
85615289615284554B805B4D845749845B4B7C5749734E3F693E2F4B272233161124100D
1F0B071F0C0D1A06070F01021D0708502722E2E8E89A8F8E998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D1D09083C1E14422A28412825
361E1A3114113E22183C2420583C2F622E23A96952AD94809D7D72997A70997E78997F70
997F75997F75997B759375638F685A9470609064559066538F65598F69538F66568F5D4E
856555895D4E895D4E815C4D8453468052436F51426940314B2722412117270F0C22100D
270F0C1C0A0C180507170507301411958080806E6E998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D2B1412331B173F2521492B27
371D15331C1A3419154227233E241E502D278D4D37AF8166AA90809A7A6A9E7E73997A6B
997A6A9576669A7A6E9E7E6F9065579063549066538B594E9064589064559565558B5A4B
8B5F5089584E85604D855C49804F447C524366463852281F3C20172A110D1F0B07200C0D
2B110C1C0A0C1400021A06083A1713F9F8F89A8F8E998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D351E193821203F27233F2420
3E231E2D1415351B163B221D4128253C1F165C2E219A664DAC7D67A07C699F82709A7A69
9A7F6E95766694716299796991695B8C57499064508B5D4E895A4B8964538F60508B5D4E
8557498A574B815646815A47784F3F7242326840303B1D162B110D24100D1D0A07190508
1C07081001030F01023415113A1811E7EEF3998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D472E2A29130F4029253B231F
462D293218122E1311432B27371F1B4529243519146B4635764737A66049AF846F926A59
9B7B6E96746496715C9B7464885F50794C3D8E5644945B448F5E518A5A4B8A52428A6251
85573F8052497C4E3F774C3C6A4C3C572C244F2418321612270F0C1D0B07190607190507
1400020E00021905072E120E94746F897C79998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D7C676E260E0C321B19402622
412723341F192F13144524193B2422482E2A38221F40272152342D703C2E874E397A534C
7A55459256429169558E624F764A3E71412E6C3C2B834B328B4C3B8958418F513F7C4E40
7B4733844A387B4C3C6842376134284B22183A161229100D1F0B071A06071401020F0103
0F00020F000224100D321411EBE7E7988C8B998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D3B242128140F412824
3B272338211D200E0B41231D492E2A462D2949312C422C284C332C53352C553328522E2A
512C20592E276D392A6D4536512F2A573028602E215F311E6632277C47317943306E3C2B
6E3E2F6331236A3D315B2E244C271D351511361A161D0A061E0B071805071300020E0002
0E0002270F0C1C0A0C6F4A43B4B7B9998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D614C55200C0A3B2420
3D26223D2421311D1B3C2522482E2A4B332E422925482D29502A2458312545291E3E2724
381A164727233C16124F2E274427223D211D3E1813401F194019134C1D16532B1C4E271A
50281B451A14471C163F1A153C191425110D220D081A06071A06071905070E00020F0002
270F15270F0B36211FAF99988E7E7D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D8E7D83321819271210
3D24204128253B221F4D342F361E1A523631371F1B472C2852302842252241231D3E2420
341C1948292628111238231D37161335181429100D26120E2E110D3816123717122D120D
30130E2E110D38161229100D2C110D1E0B071E0B071805071905070F00020F0002190507
351B182E12108A7F7E837473998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D644D50240E0B
3D28254128253B231F39241F4A2E2A49312D35221F391F1B542B1F331C193D231E3A211D
2A151B3E251D2E131634171229101626110C25100D1E0B0726110D27110D28110D200B07
1C0608220C082F110E1F0B071C0608200C071E0B0C1805060F00021905071F0E0B2C1514
30141181717081706F998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D8873782B0F0F
331C19442B273B231F3C27233E2A264A2D2937201C331A173A1C172A110D3D231E2E1516
2C15172A120E2B1118210C0C1C0608210C0E1F0C0C190607200C0D1A0607200C0D190607
1E0B0C220F0B1F0B0C1A06070F01021001031001031001031E0B0C1C0A061A0608300E09
887575867A79998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D543C39
1E09082E18154026223F2A263D2925482D2A3720202F130F321B17210E0B2F120E25110E
2C110E1A06071C0709200C0E1D0A0C1905071F0C0D1805071F0B0D1805073215120C0002
210C0E24100C1D0A0C0E00020F00021400021C0A0C1A090B1D0A0C3114102F19134B2C25
B2BAC7988C8B998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
543C391A06052F1F1D381F1B49312D462D2A422A282C1815371D19230D131E0B0B2A110C
1E0B0C220F0C200D0B1D0A0C1905071905071A06081905071A060823100C210B0D31232C
2A1B19220B0F1705061C0A0C1E0D0B1E0C0B1C0A0C351E1A27141331131058302594837B
8D7A76998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D5637351B080733211F371F1B452F2A5135303A2623351B132B16161E0D0B1F0B0C
1A0607200C081F0C0D1906071905071E0B0C1805061E0B0C1805061B0608382929311927
4C393136232524141732201E2715131E0D0A2F1816331A1741282444201A867271897B79
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D9E9392553835230B083A2A293A242150373249312D432A252A13112D1714311E1C
231514210C09200F0C1C090C1D0A0B1905071905072410161C090A210E0B220E103A2422
472A26230E102D16112E1611240E0F2B110D351B183C1F165D392E6B575F998B83998D8C
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D4F2C24260E0B311B184C302B5B413C4E3B3738221F291311311718
35181338221F2818151A080A19050728141A2311152E1C192210173C251F1A0A104F362E
351F202F1C192E1C192B18152F1C1B3B2621301A195E36297D6A697A6365958888998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D4F362F1D060325120E472C28533934504045452A23382525
3A272631191A3427263B272E2F201B2513182E1E2939211E3D2E383B221B301C1C4B312D
42262441221F41241B3A27254B2F275B3A2D321D18A68F888D7471998D8C998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D826D733E24231E0909422C244237416C504B543D3B
533E384632324234384C3739523D3A3B2625412D30361F233E2523432925462D2A412825
5329214E2B254B2D264E353047251E72504C6A5347867472998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998F8F999392998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D4F363E33181725161D3625296D544E
6254574E3B31543E3A54403D583F3B543A3B4E38323E2D2E452F2D3828234D36354E3633
472B2456332C4926228F6C6B5838294F282A8D7C7D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998787998D8C998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D8E7D834C384756393F
6C536060434B614335432A29432F2B6448496140355D433E6245405A403A563D385C392F
573E348F7C7A2E120F69494F938485998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D8E7D88978587826C7755404E4C3746472B2C462826462E2B462926402321391810
381A11887371998D8C998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.754707 0.488926 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(22) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
787375787375787375787375787375787375787375787375787375787375787375787375
7873757873757873757873757873757873757873757873757873757873757873756E4A39
7E695F786464786C67785F5B786C67786863786863786863785F5B7864576E5C54745950
6A4D4570554C664E466C52496C52496C52496C52496C4B42634E3F684E48684E3F684E48
91AAB9787375787375787375787375786A6C78787A787375787375787375787375787375
787375787375787375787375
787375786F7178787A787375786F7178787A787375787375787375787375787375787375
787375787375787375786F7178787A787375787375787375787375787375787375724D3B
78656078645B786C6B785F5B786C6778686378645A73645D79645D7960566F5B5270584E
71514871554B674D4471554B6C52496C52496C4E456C4E45634E42684E45684E3F685F61
91969D787375787375787375787375786E70787375787375787375787375787375787375
787375787375787375787375
787375786E70786F7178787A786E70787375787375786F7178787A786F7178787A787375
787375787375787375786E70787375787375787375787375787375787375787375734E3C
7D686278645F78686378686378645F786862736052665C57805C5075544E6B574B6B584F
6C52496C524A674B43684E456D51476D51476D4E456D4E41684E48684E45684E427A8C98
7A7679787375787375787375787375787375786F7178787A787375787375787375787375
787375787375787375787375
787375787375786A6C78787A787375787375787375786E70787375786E70787375787375
787375787375787375787375787375787375787375787375787375787375787375724A39
78696378645F78645F78686378645F78645B72605B615C586B544A734A4E604F406B5249
6B554F6B554C664942635145684E45684E45684E45684E426C5249634B42684E4591AAB9
787375787375787375787375787375787375786E70787375787375787375787375787375
787375787375787375787375
787375787375786E70787375787375787375787375787375787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375784D3B
78655F78645E78646378645F78645F78645B78686378645F725C547454506E4D496F5247
6F524D6B4B496E524A5C413D674D45675A5163483D6C4E456C5148634E456C564D8BA0AF
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
78737578737578737578737578737578737578737578737578737578737578737578513F
78645B78645F78645B78646378645F78686378645F786862786863725C547257506E514A
7455516E524A70564C6A4646664B436C524A67555068483D6D4E45684E457B6F6E7F8B92
787375787375787375787375787375787375787375786F7178787A787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
7873757873757873757873757873757873757873757873757873757873756A524D897363
78645F78645B78645B78646478686378645F78686378645F786863785F5B78645B72584D
7255516E554D6E554D6B4B496A5246664B4268554D684D446C4E45634E45878B967E7F81
787375787375787375787375787375787375787375786E70787375787375787375786F71
78737578787A787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
78737578737578737578737578737578737578737578737578737542342FAB7F707F6A60
78646478645B78645B78645F786C67785F5B78685E786C6B78645F78645F78645B786057
73514D73584D7455506A51456B4B446B5249674B42634E4572564D674B43869BAB787476
787375787375787375787375787375787375787375787375787375787375787375786E70
786F71787375787375787375
787375787375786F7178787A787375787375787375787375787375787375787375787375
787375787375787375787375787375787375787375787375665A60180E0CE8BCA4786557
78686878605B78686378605B78686378686378645B78645F78645A78585A736352745F53
795B567459507055506B4E42704E46665249684B3E684E486D554A6D514790A9B8787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375786E70786F7178787A787375787375787375787375787375787375787375
7873757873757873757873757873757873757873757C77792316146F585388726978645F
78686378645F78686378645F78645F786863786C66785F5B73605379505373594C6A5149
75594F75584F70584B664E48724E456B5147674E42674E45634E456C5249878D957D878C
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375786F71787375787375787375787375787375787375787375787375787375
78737578737578737578737578737578737578737531201B7766607C645B786557786464
78645F78645F78645B78646378645F78686378645F78645F6E413D74534E704B43704D45
704D467066546B51446B51476C4941685244714E486C4E45634E41724D4672655D8FA6B4
787375787375787375787375787375787375787375787375787375787375787375786F71
78787A787375787375787375
787375787375786E70787375787375787375787375787375787375787375787375787375
787375787375787375787375787375787375665A5D251D1A87716678645F786457786464
78645F78605778645A78645E78686778686378575678635E6E3536703F396B332F764747
6B3B36764F49624D416D53466D4E41684A417252486C4E45674E426C463F67564C7C716B
899FAD787375787375787375787375787375787375787375787375787375787375786E70
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375787375787375221717DBAB957E686278645E78645B786464
78645B73584F795C537D6D62786564785C53734146744B436F4F4C642D257B5851774043
6224217238326B4740634E446859486846376D5249714E486C4E456C4B426C52486C554B
8B99A1787C83787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375786F7178787A787375787375787375787375787375787375
7873757873757873757873757873755646492B241F9F8777786560735C4F7D716B78605C
785C4F6A5447704B458A74706F4540441B13B67E757038356E5B555C4744622D27645246
5F312A6E3D3E5B2B23863A34645F4E6D4D376C4E476C564C7153466648426C52496C4E45
7C6E6589959C787C83787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375786F7178787A786E70787375787375787375787375787375787375787375
7873757873757873757873757873751C1213BB8C74816C6678645B6E50497E767378645F
785449603E3167443D501A199E89833F1A1B7457536D434573504C786F68682925614D4E
4F352D4A38373A1B174F2319934A3A73634C724742715E5371564A6A4E43664B456C4E45
6C554C7C859A847E777D7C7E787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375786E70787375787375787375787375787375787375787375787375787375
7873757873757873757873756A626D0B0707E8B7977E696378645B72575078656578645F
6F463B593B2B642B252D110FAC8377807F717965637D8C9078635C786C676A4C477F8383
6F4F466164662D1C1C2A27273D1A16994E3B775C517C6251745E586B4E43664B436C473F
6C554A68767F72676A85819189877E787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
78737578737578737542342F3B242360443EA08C7778655B785C53786459786C6678645E
6538335A4B3E5A363630151C7442476F574B70514C7A6A647E524D6F6153703D38764A42
6C473D808170613B3355474928242143120CA66E607C69527A665F6A4D42664A44684A42
7153496761596F77835A5164909289787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375786F7178787A787375787375787375787375787375
7873757873756A5E640E0A09291816E0A5947B685A7860577854547365547D695F785857
6546396345379088837869607853547254516D54516D4D4A73444363403F693C3B663430
66393A674F456B3937593934462D242C15136F3026967D6680685D6A5142664742634A41
72554A6C584E3F2F2ABDB7C87672737D7C7E787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375786E70787375787375787375787375787375787375
7873757873755B4D5B00060005111B85766C7D685E785C54785C5B72555478725F785757
65433C5C3A32877C717D716E78686378605B78686378686378544F6E58497459506A5146
704E4662473C723E3F673F38592F2E4627284B272B75573E81655F705545664742634B3F
724F486C554C15171ABAA7A289878D787476787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
78737578737566515179645D725B546E594E79645B7D645B786560785758786A60786058
684C4265403A715449857E737D716F78635F78605B786C6778524F6E4D46704D44705C4D
674A415F49416E463969483E694C3E69453E64463E725749775A5170514662463E684D41
6D52446D514A131315CEBBC885857D787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375736B6D7D5946735C57745E526B686E8A645078696378686378645F78686378635F
724D4969514365413A7A6D617E7673786C667854537371617D685E6A4942704A42674539
67574A5B3F3765493965443E694B3860413A6543367C615871554B6B4D4462463E684A41
6852456C524906090DD7B7B396979B787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375725A5178635D6A4D426B51456F6E6E7F5857787268786C67786863786863786863
78524F72514A65463D75514A837F7B786C6778525372615878655C6848426B4E43613D37
674F465B3A3265463A6549406E4E3F67473D674C4172574E6B4B426B4E45674B4263473F
6852446D514A02080C5C413BE3D7D978787A787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
78737578513F73605B5E382E7F726A795A5978655B786564786C67786C6B78635B786863
785F57785C5065463D704E437F736E7D6C6A78645A78686778605B6E504966463E6B4D44
684E4563403A64453560403C6E514777534D755B4F6B5249664E466C4B43684B42684B42
684F436C564D081215201A1C54433FE0DBDD787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
78625D6F4B3E6B403A62524278786F8F605B78655B786464786C67786C6A786762786863
785F5B7360536E50496F594E79665D78655F7358537D756978575A6A584465423E684D44
64493F6D4D3B5B3F356E453C725A507757507A5D546A51496651486C4D44674E45634E41
6C4A446C6155593A2F372C2C2F4D5B827E80787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
784740653B335D302D685E4E76746B7F696378685F78605C786C6778686378686378645F
78645A6E5C537859506E655B7E696378685F72535078655C78504C654D4262403A64463D
60423969483A5F433B6E504772574E715A517A59516A5149664E466C4B426C4A45674D42
684A3F71625B5F392D6D504996B6C4726E70787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375786660
784E4A65363459342D725F5586786C786564786C6778635F78645F78686273645A7D6862
7858576E645379585073655A7E6D6B78685E78646378645F78504C65493C5D463E5F433B
60443B5C48406E4C3F72564F77594F745D5470554C7051486651486C463E6C4A44684A44
684F41725E5E623A2F644F46818B978E9090787375787375787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873757873757873757873756F4737
6C484055382E7044378D726585736778646478686378686278645A78605A6E6057795C57
745852795D57746154745D557E696378645F78645F78645F73534F6A40395D433C5F433B
65473D644E4469524577555071594C75594F705950704E46664E466C4B4368484068473F
684E4572615B642F23716D6263484491B6C3787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375602B1C
321F1754342E472B27C0917984736C78645F78645B78645E78645F786058726058725754
694D4770514C705F507F6C6179695E7D686778645F78645B6E544F66463B5E3F3E644937
60433C7351476C564C724E4871584E76554F6B544771584D674D446D5147684E4568463F
684A486D594D5B302473574A6D3F3C91BAC4787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375786B685F2B22
1B19162D211E3A2525C4947A84736A73605A7D68637864576A544E7A625A6C50477A5C50
75534E764A47765B4A775B4F7B6B5F83726F78645F78645B6E4C496043395A3D37654335
5C47406E4A406954496D4D4376554A77595267473F71554C674E46634B42684E4568463F
684A4868524548291F63322581514197BFD1787375787375787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873757873757873757353476A4443
170B0A2B1B18362220E2A3877A695F78605778696378645B624C4656433B533B33443331
452D29683527865445673429704132A799897D6C6A78645F6E50496040395A4032604738
5C3D3874554B634F475E4B44684B4368504A604D417C594E6C5249634B42604A41694A41
724F48684F453B211D5227207A453697CAD8787375787375787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873757873757C77796C3F30613F3B
040C111B1413341C1AE4B49578655C745C547D695F78645B725C584C3831554845151A1B
23171741221A5B413B7335296A474084776A7E6D6C7868676E4F42603C3752392F614734
3C1511956E596E4D396349415D3B3080584D604D447855466D514A684E4557433B614D44
734E4860493D3C221F6234297F484197C2CC726E70787375787375787375787375787375
787375787375787375787375
78737578787A786F7178787A787375787375787375787375787375291210DB8C71695149
15141715141A281714F4BC9C79645B78645B74605779645A7D6867624B42714E4A2A2C2C
1D222724201D3E3732694A4079544D7A6F627E7674786C6A6E5348603F3950372D543D34
341C1B5F4D4A473229180C0E6F3A2D5A453B4328207F52456B44328153445B4D46614A42
734A444B3C33301C1A582F27A3685996B6C5716D70787375787375787375787375787375
787375787375787375787375
786F7178787A786E707873757873757873757873757873752B181626161547100C7A4839
22161C1E17152E1A18EAB8997460577E696365453E7665558A7A7772645B6D4F495E433D
5D453A58443B593F376E58487656527463587E76747868636E4C45604A405A372C574538
57332E524E4C2F2D2C04090D4C251C4533302A1F1C6D42346343367654435B443E5C4D44
734F412A1E1F31211A45241EA855429CCCDA777274787375787375787375787375787375
787375787375787375787375
786F7178737578737578737578737578737578737578737503000331221C29141535231F
150E112F1C19301A19E4B19178645B74645E6C4A4C5C443B68493F7F64576F564B63423D
5C352D69433372443673463695796A7F6A5F7E6D6C78685E6E4C486051485A3931604534
614A3A73534A5F443F051A232824243027252F2B2861473D614636614F476D4B3F5F4B46
614A3F1813142A1A1846251D92382AA3DAE6787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375030003231411231816281816
1F15142318163D2725CD92778A6D6272655B78656466534C4D3933513533443D3A60413B
392D29483A334D332D65473F786E637966617865607858536E5C4D604D465A36374B2B1F
5E3A2B82674B725249684E446247424B3B324B3936704D4060473D684A46614E3F725244
4B3B35110F10231715884F4054221DB0DCE7787375787375787375787375787375787375
787375787375787375787375
787375787375786F7178787A7873757873757873757873750600021D100F211816201715
150B0D2819163E2C29AC765F9676687D6D62786464786863725F57614545463F43654947
573F3B584540523B386A4B42705F567E6D6C735C53795857735A506451496043443B2725
311C1D4A31244C2F24935845815F52684E3F5F4B41614A4164463D5C453E73504A694E3F
2A1F1B1712132A222094493750241D4E4A48DAD6D8787375787375787375787375787375
787375787375787375787375
787375787375786E707873757873757873757873757873750A0304251817211514221715
1711102818163D2C299E675293776A7E6D63786464786C67786863786C6B786762786762
78635B786C6B78635B78635A725C50786963725F576E59507458506E5D546F5951634A47
332A2F2B24241C201F4327204D30257141345B463A683F32623E327857506A4B4264463D
1310112016142B1D1F4218135A1F17343433DEDCDE787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375060305302423171212261715
211614281B1C3B2B278A59459774658A766A78645F786867786C66786C6A787172786C6A
786762786C6B78625A78686378635A78605478645B6E544D745951745950746157745454
64554D6147434034332B2929292725412B2743362F5F42384C40397144456450415B4037
110E112116142118161F12103D1C1A453734DEDCDD787375787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873750B040633231E211A1A211514
2813112C1C1B39261F5F4136A2715E8B7A6D7D685E786464786C67786C6B786863787172
786C6A786C6A78625A78686378645A78645F7860536E544C746157745951745950745853
6A554B6A5148614E465A47405948414738334D3C3761423B5F4B4664443F5B473D3D2D25
1A1315211614291A191A1514291816412A22B9A2A79A9F9F787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873750A0304372928251A19271817
1B12102A18162A191651302682523BA88B7D7E6D62786464786C67787173786762786863
787172786762786762786863785F5378645F73584F735850745950745D53745850745950
6A51496B4E466B524967524A684B426C4E45634E4560463F694A44694A41573C33261B1A
1911102B1B1D1D13141D1411160C0E3B201C8B6A65B5BDC0787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873750601033127272E2221271A19
2417162116142C1E1C422D2A59392DB37E6A8A756978686778686378716E787172786762
786C6B78625A786863786863785F5773605373585074585074585074595070595075554C
70554C664E466C52496C554B674E46684B42684E4557463F694A4158463D3A2B271D1516
231C1A170F111D1416140C0D1C13152B1916765954C3C5C8787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873750A03043428263528262C2120
271716191210331D1B442C24573B30905B47917E727D6D6678646378686378716E787172
786C6A78676278635B786863785F5B7260536E554D70544D75554C7958546A584C705148
70554F6651466C52496C4E45685147684E4564463D634D446142394B393433211D221717
1C14111A1215180F111B13101C1316301B19B3ADAC7E7B7D787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375786F71736F710A0709352725392B29312422
201413271D1B2C1D1C3825216D40307F4F418D7669837266786464786863786863787173
786C6A786C6A78625A786863735C537D645A6E544C6E58506F554D70524C70554C704E46
6B564F6B4E466849456D5145684E45684E4563433C604A4257393144322C231A18261818
1A15141E16151D15141B1310201716321B19FFFFFF726E70787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375786E70726A6C0503053E2721312726372927
281E1E281C1A2F222034221C5F453B6D3F32976D5E857A6D7D6867786863786C66786C6A
786C69786C6978635E73645A735C5279645B73504970554875585270554870554F705249
6652496C5148674742634F45684A41684D44604A4157423950342C3824232619161F1615
1C13111D1416191011110C0D1C11124A2B27E6EDED777274787375787375787375787375
787375787375787375787375
78737578737578737578737578737578737578737578737503010433211A372B2B372928
2C201E29191836251E3326244D3B32522C2495604E9184757E696378645E78686778685E
7868627868627864637260536E554D745C5370504770544870554F70594970554C704D44
66554B6C4E456C4E45634E4568463F64463D53453C50372E38242331211C2015141E1715
2216141A1315170F10160F112D1B19A396967B7A7C787375787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873750D0608271D1B3527253D2B29
2C1F1A2B1F1F2D1E1B382927352622432C297E493896745E8A796F79645A7D686278645B
78645B73605779645E7D685E6E50497051487055486B4B4571554E71554B76554B6B4A42
6B51486C4945685245684E4164433D60463D4B3C343E24202C201C2316151B13111D1416
271815191215140B0D191011361E1AFDFCFC777274787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375170F0F292021352826352624
33242125191B2D1F1C33252237292833221C502E25875D49916C5D80665A7F6C61796459
79685E736057745C5379645A6F534C6B473F7154476B4D456C4D446C554A7251476B4E45
684A416D4A4464493F644C3F5B423958392F4F372D2A1D1A2316151F16151B1210180F11
1B1011110C0E110C0D301C1A351E19EBF2F7787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375231919191312342927312422
3B2D2B281B182719183A2D2B2F22203A29262D1D1A5E43366340358A534290716271574C
7B675F765F56765C4E7B6056674D445B3D3571493D774D3D7250496D4E446D453B6D5349
684A396446426042395C41385041384128243E241D261A182016141A1311180F11180F11
140C0D100C0D180F112C1A1695807D87898B787375787375787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873755B50590E0708281E1D352725
3828262A201D27181A3D281F3025253E2F2D2D222238292545322E61392E7147375F4643
61493F76483B74584A715246593D3756372B56362B6C43317143396D4C3B73453960443C
603D2F6840356142384F3A344B2F2839211B2E1A182116151C1311180F11140C0D110C0E
110C0D100C0D2318162E1B19F3EEEF787476787375787375787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873757873751911111B1513372928
3128262E23211B14133A26223E2F2D3B2D2B3C2F2D362B2A41332D46332D463129412C2B
422B224A2C285A362B583E343E2B2A472D284E2C244E2F22542F29664131623C2F55362B
57382D4F2E25553831472B263C26202A19172C1E1C1912101C1311170F11140B0D100C0D
100C0D2517151B13156B4C47B7C0C3787375787375787375787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873757873753E35410D0A0A312624
33272533252427201F3628273E2F2D3E312F3729273B2C2A422A26492F27372821322626
2E1E1B3C2927321B18432E2A362625322321341C1936221E361D1A41211C442B203F271F
422820381C1A3A201C341E1B321D1A1F16151F1412180F11191011180F11100B0D100C0D
25171D2517142F2524B9A9A87D7A7C787375787375787375787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873757873756C646C12090C1C1515
3326243729283124234233312C201E4534312C201E3C2C2A462F2A372625342421332624
2A1F1D3E2B292016183126222F1B192D1C1A231615221816281715311B192F1C19261815
291916281715311B192317152717161A13111C1311170F11180F11100C0D100C0D180F11
32211F281917909091827E80787375787375787375787375787375787375787375787375
787375787375787375787375
78737578737578737578737578737578737578737578737578737578737541353C100C0C
3229283729283124223026233D2C2B3F322F292222312220492B23281E1E332422312321
231A2036272225181B2D1C1924161C2217142117151C13112218162418162317161D1311
1A10111F14112A18161C13111A10111D14111C1315170F10100C0D180F111D1615291C1C
2C1B19837F81838082787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375665A620F0507
271E1E392B29312422322826362B293E2C2A2C211F2B1E1C33201D231615352623271A1C
261A1D25181525171E1E14141A0F121E14161D1415180F101E15161910111E1416180F10
1C13152017141D1315180F10100C0D120C0E120C0E110C0E1C13151B13101910112C1612
897F81898A8B787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
78737578737578737578737578737578737578737578737578737578737578737532282A
0B080A241B1A352725352B293329273E2D2B2C21232718162B1F1D1D15142A1917201716
271716180F111B10121D14161B1214180F111D1416170F101D1416170F102E1C1A0D0B0D
2015162118151B1215100B0D100C0D150C0D1B13151912141C13152C1B18291E1B48312B
B8C7D3787476787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
32282A0805072621212F22203E302E3B2D2B352929231B1A2F211F1D14191C1314251815
1C13151E16141D15141B1315180F11180F11191011180F11191011201715201416292630
2621201E1317160F101A13141C15141C15141B1315302320221A1A2C1A184F3129938E8A
7D7C7F787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
7873753425270807092822222F22203A2E2B4433302D25252D1E19231A1C1A14141D1315
180F111E15111D1416180F11180F111C1315170F101C1315170F101A1011322C2E2C1E2B
4237302B23261D191D2C2524211B1A1A14132A1D1C2E201D3729283B231F8980827F8284
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
7873757D787A312325110A0B2D292A3026254535323B2F2D362926211818251C1A2B2222
1E1A1B1E14131D16151A12141B1314180F11180F1121181D1A12131F1614211719332525
3F2C291E1516271A18281B1820151625171530201E34221C543A30645B6691928E787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
7873757873757873752C1A17150F0F261C1C41302D4D3D3B4037362A21212218182B1C1E
2D1C192F2423221D1C171013180F11241B2020181C2A211F1E171D362924161218493832
2D2124251E1E29201F251D1C292021352A26281F1F55372C7B76786C6871797677787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
7873757873757873757873752C23210D0A0E1A16143C2C2A443532403A403628242E2729
312A2A281D202A282831293129262220191E27212C322522342F3B33251F251E20443330
3526263624223626202F282841302A50392F251E1CA597937D777A787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
78737578737578737578737578737560555E231D1E0F0A0D362B2637353F5E4946433838
433935362D2F3734394235384438362C2324362D312D21243527263728253B2D2B372928
462924402B273D2D284134323A2621634B4A5A5954817E81787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
78737578787A787375787375787375787375787375787375787375787375787375787375
7873757873757873757873757873757873757873752C232E2823231B1F2B2924295A4A46
514D533D35304338374338374639384335384036332F2B2D392F2E2E2927413637413433
3A2B2646322E3A262480686B4A403846393F7D7A7C787375787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
786F71787375787375787375787375787375787375787375787375787375787375787375
7873757873757873757873757873757873757873757873757873756C646C2D2A394B4043
5A525F4739424E40362F292E302A2A5241454D3931493B3A513E3C4639354638364B342D
443831857C7F221D2064565F7A7779787375787375787375787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
7873756C64707970716056633A36433E3A47382F2F392F30393537393032332C2D2E2320
2F28267F777A787375787375787375787375787375787375787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.754707 0.732558 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B71513D
806E617B6A677B736A7B665E7B736A7B6E667B6E667B6E667B665E7B6A5A716256775E52
6D5247735A4D6852466E56496E56496E56496E56496E4E4365523F6A52486A523F6A5248
93AEBB7B7B7B7B7B7B7B7B7B7B7B7B7B72727B80807B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B75757B7E7E7B7B7B7B75757B7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B75757B7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B775641
7D6C657B6A5E7B736D7B665E7B736A7B6E667B695B74665B78665B7862546F5C516D594C
6E524670574A664F4371584B6E56496E56496E51446E51446552446A52466A523F6A6869
93A0A77B7B7B7B7B7B7B7B7B7B7B7B7B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B77787B77777B7E7E7B77787B7C7C7B7B7B7B75757B7E7E7B75757B7E7E7B7B7B
7B7B7B7B7B7B7B7B7B7B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B74543F
7E6D637B6A627B6D667B6E667B6A627B6C63746353625F597C5D5074534C6A57486C5B4E
6E574B6E594C6B51466A52456C53466C53466C51446C52406852476A52456A5244839AA6
8385877B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B75757B7E7E7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B72727B80807B7B7B7B7B7B7B7B7B7B77787B7C7C7B77787B7C7C7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B77513D
7D6E687B6A647B6A627B6D657B69617B6A5C7767606D6660755F507B5355675645715649
71574F71574D6A4A426553446A52456A52456A52456A524470574B6750446A524593AEBB
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B5641
7B6C627B6A5F7B6A657B6A627B6A627B6A5F7B70697B6D6577655A775E5571564E755A4C
755B526F514B745B4F6347406C4E456C5F55674D40705245705447655144705C4F8FA7B4
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B5843
7B6A5E7B6A647B6A5E7B6A657B6A627B70687B6A627B6C637B6E6677655A796358735C4F
775B5573594D735B4D6C4C486A53476E55496B5A526A4D406C524568524581797785969D
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B75757B7E7E7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B684F4787705C
7B6A647B6A5E7B6A5C7B6A677B70687B6A627B6E667B6D657B70687B665E7B6A5F775F51
795D54735B4F735B4F6F504B6E56466A4E4368564B684F4270524567524589939C808889
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B77787B7C7C7B7B7B7B7B7B7B7575
7B78787B7E7E7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B352C259B7563857364
7B6A677B6A5F7B6A617B6A647B736A7B665E7B6D5F7B716C7B69617B69617B6A5C7B675A
745650745C4F7758526D56456C4E436C56496B5044675245735C4F6B52478BA4B17D7E7E
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7778
7B79797B7C7C7B7B7B7B7B7B
7B7B7B7B7B7B7B75757B7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B625A5F100906DEB49F7D6C5C
7B706C7B67607B70687B67607B6D657B6E667B6D627B6A647B695B7B5A5A74614F725C4F
785C53775E51715B526A52437352476A574A684E3E6852476D56496C524591ACB97B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B77787B77777B7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B81808019100C796254A88B7A7B6A62
7B6D667B69617B6D657B69617B6A627B6D657B71697B665E746555785454745E4E6D564A
765C50745B4E715B496851477251446C53466B51436C524667524570574A898D927E888B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B75757B7B7B7B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B22171178685E9D80737D6C5C7B6A67
7B6A627B6A627B6A5C7B6A657B6A627B70687B6A627B6961713F3B774C4871443D71463F
7346407363506C52436C52466E4B406854427152476E5245655240734E446F60558DA3AD
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7575
7B7E7E7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B625A5A3F352EA5887B7B69617B6A5A7B6A67
7B6A627B65577B675A7B675D7B6D687B6D657B58567B615C713735713F366A312A774743
6C3C33774C4562493E6C53446C5240684D417354486E52456B5244704A406B5B4D7B6C62
8799A27B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7778
7B7C7C7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B17110EC29A82806D607B6A5F7B6A5C7B6A67
7B6A5C745D50785D527E72647B6C687B5F52743F4072443A6C4D465D2D2176615579524E
62261F6F342C6C443A674D426A5A486A4A366D55477152476E52456E4F446E55486E584B
8D9B9F7B81857B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B75757B7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B4D4142342A20B797817D6C65745F517E766E7B6761
7B5F506B55446D4A4089706D6F3D3935120A9F7168713F3874645B6D65606F342C624C3E
583427684743512D217D362D645A486D4E35705047705A4D755A486A4D446E574A6E5245
79695D878F917B81857B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B75757B7E7E7B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B140E0DB38B718B78707B6A5E7155498079737B6961
7B5A4B613F2F66423942131189827A574A4691827B7763657B6D6B7D7D766D3D336F6F6C
64554E544947371D16412013824433726249734B43756354755B4C6E55466A50456E5144
6E594C79869E807F7A7E81817B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B686470060402E3B393806E647B6A5C7761577D6F6B7B6A62
6F4639543A275D281F290D08AE7D6F847666785F597E89887B66597B6D616B4B437E8080
6F4D406D6A66442F27413D373A1B1488463374594C7C655179655A6F55476850466E4A3F
6E56496877796D64617C7C8B8788817B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B352C252718165D4137BA9D847D6C5F7B5F547B65587B70657B6A5F
673D346455456D534C564742916161755F5271534C78655D7C49436C574B6C3730733F36
683C317A79675F392E5A4646342A243E0E069766587E6A517C6B606D5242684D43684E43
71584B6B64587B828C615C6D91968B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B75757B7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B685F640505031F120FE5AF9B8776647B65597B5756746B597E70637B5A59
67493B6044338F88807D71687B5E5C77635B7567607760597B5A526B5248734E466D4A3D
6D4D456C55477138366038314B2A1E34130E6D2B208C755D80695D6D5542684B43654C40
7356496E5A4D31261FAAA8B27D7C797E81817B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B5D56642E2C1C52413CA68C7A7E6D5F7B62567B665F775B587D75617B615B
674C406140358B7F717E736D7B6E667B67607B6D657B6E667B5752715A4A775E526D5648
735247624C3C6F453F664B3B603F37573D355D3A3A7C604180665C715845684B43654F3F
7353486E594C161A1BB4A59F878A8D7D7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B6E5850816A5D77675E7364557A695C7E6A5E7B6C657B615E7B74687B675E
6D55486B493F715447827B6E7E76707B6B647B67607B736A7B5D54715649714E42715D4B
664D3F5B4B406B473767473A674B3A67453A64483A755D4B7B605573554662483E684E40
6D54436C54490D1010C9BAC98B8F8A7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B746F707E5E48745F56725C4B66666B8969557D6E687B70697B6D657B70687B6B64
77524E6F57486B483D7F70618077727B71697B565474705E7E6C5E6B4D43714F43664436
6656485E4036684A3766473E6C4F3763453966453480635775584B6C4F4363493E6A4D41
6A554670574B010608CAAEA99398967B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B775E507D675D6B50436A524475736D875C577B756A7B736A7B6E667B6E667B6E66
7B5D54775C4E694F3F76544984807A7B736A7B5D59776C607D6C626D4F486F554764453B
6C55485E3C32664739664B3F6F50416C4B407155487960546C4E436C51446B4F44674B40
6A55436D5449000607513932CDC5C77B7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B584374655B5A372980766981605F7D6C5F7B6F687B736A7B74717B6B617B6E66
7B665C7B6556674D4173554680796E7E706A7B695B7B706B7B676071574B674A3E6C4F43
68524565463B684B3663433A6F52467A58507B63546F594C6855496E5247685044684F44
6A5344705C5022221A311E1A463934C2C3C37B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B645A6F4637663730614D3E767C738D685F7B6F5F7B6A677B736A7B716C7B6C647B6E66
7B665E74655571574D7565567F70647D6C62745A527E76687B58596B574166433B684E42
62493D6D4E38583F336B453A755F517B5E527C63556D564A6855486E4F436B5144675240
704C427064555E3F334B3A35617E88A19FA07B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B4A42673B325F322C6A62507D7A6D8770687B70667B67617B736A7B6E667B6E667B6961
7B695B7162557D5E52736A5D806E687B7066775E597D6F647B574F67534462433B62483C
5F433766483861463C765A4C7960537560547C5F536D564A6852466E4E436E4C456B4E44
6A4C4071655D5F3B2B6D51479ABBC77777787B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B695F
7B5449673E365A3B2D7364568B7F6F7D6C687B736A7B6B647B6A627B6C637466587E6C60
7B5A577165547A5B5074685A80716D7B6D5F7B69647B6A627B5550674B3C5F483D61463A
63473B5F4D42715341755C50795D5079625573584C7153476855486E493E6E4C42684D42
68534073625F673F326855497B8791888D8C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B6F4834
634136453025613F318B7567897B6B7B6A677B6D657B6C637B695B7B655A7165577A5D57
725A5178615777685977665A8070657B6A627B6A647B6A62745C526B483C5F483D61463A
66493D6850446E55467A5952755D4E765C50715E527355496853476E5146684E43684B40
6A504673645D622E1E716D5F67463E93B1B97B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B612C1A
271910462F273C2622B38C7586786F7B6A647B6A5C7B6A5F7B6A627B675E77696079635D
6F564D73534C6D5D4C7E6C5E7A6C5E7E6D697B6A627B6A5C71575067483B5D3F3E644A36
60443A725246705B4D745247705A4C77574F6C544570584B664F436C53466851446A4A3F
6A4D486D5A4B5A35227058466C3E3993BDC67B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B6F6A633327
29211A2F221B352321C3947986786B74655A7E6D657B6A5B68554B735E5261493D6B5144
684B456C4542735A47755A4C78695B84756F7B6A627B6A5F71524D63483A5C4135664533
5D493F6E4C3F655447664D41725649755D52664C4071594C6B53476750446A52456A4A3F
6A4D486A554544271C592B1E7A4C3A97C0CE7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7455446B4641
0E06041E15112D1E1ADBA3857C6F617B65597D6E647B6A5C69554A56463B4C3A2F392F2C
342622532D1E744C3B5A2D216035279B8C7B7E706A7B6A6271574B63453A5C4332604C37
5A3F3675594B6B574B6953487051446A50495D4C3F7A5C4E6E5649654E435F4C40654C40
7153486A53453D241C54281D7C443499C9D77B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B818080734735634139
070E0F19120F311A15E4B3947D6D607763587E6E617B6A5E77655F5541376A56501D1F1C
1F14113A1E144F3D376B36287656498F86758076717B7370715A49634238513A2E5D4531
33100A87634F684A335A443A4E35287353465F4F427858456C534868514458453A624F43
7450485F493B37201C5E3527814D449CCBD47777787B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B78787B7E7E7B75757B7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B1B0A07B772596B5449
19171613131823140FEDBA997A695C7B6A5E77665A78675B7E6D6969574975564C3B3831
453B364833265743347B5744825E527F7364807A757B716C715748634339553B2C574034
3C221C61534D3A2F270D07075A31254E413533211869483B5B3D2A784E3C5B4E44624E42
744D43483D30291B164E2C239D6A599ABEC97576767B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B77777B80807B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B1D100D180E0C390A055B392C
15101416130F2B1813ECB99877665A806E6865433C715F4F897A75776D62755D55695048
654B3E624D41674B3F79614D7D5F5679695C807C777B6E667151486350435C3D2E5A4B38
603B2F62585046372F0407094723173E2F2B251C186A41306745367C5B4760483E5F4F43
745341231B1A281D15402219A14F3B99C5D17879797B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B79797B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B0100003021182814112F211C
0E0A0B2C1A142F1814E4AF8F7D695C77695F7258556351436044386E57495E4B3E4F3832
482C235539295F3A2D633D2D8872637E6F6180736E7B6C5E7151486356495C3D31634633
624D39725849634B42293130553E334732294433297852427050396453486D503F655247
624D4014120F2517134222198E3626A1D7E27B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B0200001E100B1B1410211511
1B120F1E1511382723CA9377897062776C5F7D6C686E5E55604F435F423C46413D6A4941
4E392E5B473A593C31745347877D6D8170697D6C657B5A55715F4F6353485C393845281B
5132237861457154476A5242694D4359473857463D775744604C3F6A4D48625040715443
483C320A0B0A1B14109156435D271CADDCE77B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B75757B7E7E7B7B7B7B7B7B7B7B7B7B7B7B0702001B0D0A1D15111B1410
0F07072316113B2B26A6745B9275667E71647B6A677B7068776A5F6D59555F5D597E665D
6C5D5470635B6B5B547E6557776B5E807470746255785F5774615269574C69504A4C3A30
3721203F2B1E39251B7C4D3B7B5D4F68523F634F41624D4164473C59453A7151496E5040
231C16110E0D28221D9248334C22183E3E3BBEBEBF7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B0704032117141D130F1F1410
140E0B2415113A2B269D6750947A698073657B6A677B736A7B6E667B74717B716C7B716C
7B6B617B74717B6B617B6B617765567D6E64776659735E52775B507362567561556D534E
483F3D4C3B34312C2640261C3B271C59352A483D3257382A55382A76574F714F4364483B
0E0D0D1A120F271A1A38120C4A19102F322FDFDEDF7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B07050433262214110D211410
1D130F261919392A2484584290736289796A7B6A617B6D687B71697B716C7B76747B736E
7B6F697B74717B695E7B6E667B6B617B67597B6A5E715A4F775F54775E52776558775956
695B4F6750464E4139443B3443382F50342A4B3A2E6C473A5B4B40774948625140564236
0D0C0C1D130F1C1411180F0B341A153F3631DDDCDD7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B0B05032F20181E18161E130F
24100B291A1636241A593E31996D5A8A7B6C7E6D607B6A677B736A7B74717B6E667B7674
7B736E7B736E7B695E7B6E667B695B7B69617B655671574C776558775F54775E52775C53
6D584B6E5347675246604D426551455A453B614B406E4C41674F486A4940604A3C3A2B20
15100F1D130F28181417130F2415113C271CAD96999299987B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B070301332925221916251613
160F0B231511231511492C21774C339F86768071647B6A677B736A7B78777B6F697B6E66
7B76747B6C647B6C647B6E667B66567B6A61745D50745E52775E52775F53775C51775E52
6D564A6C52466C56496B594C6A50446E51446752455F4A3F654D43654D40513D311C1816
110D0A26191917101016100B0F0707341C1682645EAFB9BB7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B0703012F26232C221E251A16
2216121F1410291D19402E2852382BAA7B678976677B6D697B6D657B746E7B76747B6F69
7B74717B695E7B6E667B6E667B665C746556745D51775C51775C51775E52715E5274584C
71584C6852466E56496E584B6B52466A5044685245584A3F6E4D415C483C352923181210
221A16120B0B1710100F0707171010261611705750C0C6C87B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B0905033228253428242B211E
251612140F0B2E1A16422A1F5A3C2C915A428E7C6E7E71677B6A657B6D657B746E7B7674
7B736E7B6F697B6B617B6E667B665E776757735C5071594F74584C7A5B546D5B4C735347
73574F6855466E56496E514468534668514464473B674E4262433743362F2B1E171D1411
15100B150F10130B0B16100B1810112D1914CAC5C49495967B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B75757473730707063125213629252E231F
1B110E251C182B1C1832231D683F2D7E51418B78698476687B6A677B70687B70687B7877
7B736E7B736E7B695E7B6E667461547E675A71574C735C51755B4F73574D715A4C735246
6C5B506C5346684B446C53446852456A524567483D604E42533B30443329211913221513
16130F1B14101A130F17100B1C14112F1915FFFFFF7777787B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B77787776760304033C251C2F2522342824
281F1C261B172C211C3221185C453A663E2F906A59847A6A7E6D697B6D657B71697B716C
7B70697B70697B675E746658745E517A695C74564B715847745B50715847735A4F73574B
6856496E55486B4C436753456A4C406A4E425F4C405343374C332830211E1E1411191310
150F0B181010130B0B0A0707150C0C492A24E9EFEF7879797B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B050403312016332A27352925
291F1A251613342319312521493A2F4B281F8C5C498E8473806E647B6A5F7B6D687B6C5E
7B6C607B6C607B6964776757735C50775F53715145715647735750735C4B735A4E734F43
68574A6E51446E51446552456A4A3F64483C5045394C352930201E291E161A120F191410
1F130F161010120B0B120B0B2D1915C9BCBA999C9D7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B110C0B271E1A3226223B2925
2B1E16291F1B291C183427232F231D3B29257447348D6E5686776A78675B7E6D637B6A5C
7B6A5E74655978675D7E6D5F71554A7152467158476C4E4470584D70584A77574A6C4D42
6C54476E4B4468544568524064453B5F483C4A3E3238221C261D161C130F150F0B171010
231410150F100E0707140C0C321B16F9F9F97879797B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B18130F28201E342824322420
2F231E201717281C182F231E352925312018482A1F7857438666577C62547E6C5E786558
786A5D7465597761557A66596F574C6A4A3F7055466C4F446E4E426E55487253466C5144
684C406C4C42624A3D624B3D56423750372B483428241A141B120F191310160F0B130B0C
150C0C0A07070A07072F1A15361E15EDF2F67B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B322B2C1F18143328242E231F
3A2E29281B15261714392C282C201C362823281B17533F3253392E764939856A5A6B5447
75635B715D54715B4C786255644D42533B30664538704A386F50466C50436C44386C5346
684C3664483F5F43375A41354E41353D2620361F171F15131B130F15100B120B0B130B0B
0F07070A0707140C0C281711AE9D9AA5AAAB7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B67636814100C251D1A312521
332622251E1922161738251A2E24213D2F2B2D24213528223F2F2A58362B6240304E3E3B
4E4037623F30665040634C3E4B362F4B32254D3225603F2B663E326548356E45355B4438
56392A5F3B2F5B3F33483831422C23311D162716131B1310150F0B120B0B0F07070B0808
0B07070A07071F15112D1915F6F1F17D7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B211D1D1D1714362A25
2F28242D221F17110E35241E3C2F2C3A2E293B302C392E2A43362D45352C403127392927
3A261C4027224D2F244C372D3426243C2924462920472C1D492B235A3D2C57382A493125
4F3529472C204A352C3E282035231B231612261B18130F0A16100B120B0B0E07070A0707
0B070723151018101076554EC9D1D27B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B4D4852140F0B2F2420
2F252130242028201D382A263D2F2B3D322D3328243629253D2621452B2234241C2E2421
271B163526232A1813382A252F24202C201C2C18132B1E182B1914351B1637241A342219
3623192D1714301A1629181429191418130F18100C110B0B130C0B130B0B0A07070A0707
231519231510302622D2C3C08E91927B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B737074211D1B1F1916
3024203529252F232041342F291F1A40312D271E1A382B264631283327232E231F2F2421
281E1A3E2B271D14152C241E2918142818141E130F1B15112214102C19142A1914201410
2215102014102B19141E1410211410150F0B17100B120B0B130B0B0A07070A0707140C0C
31201B271713B2B1B0A19FA07B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B4B4349150E0B
3229253529252E231F2A231E392C2841342F2823202D201C43281D221B182D211D2C211C
1D171B2F241D1F15162A19141F13181B140F1B141016100B1D14101D14101C1410160F0B
130B0C19110C241511150F0B130B0C17100B171010120B0B0A0707130B0B1B14102A1C19
2B1915A6A3A3A6A5A57B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B6E6A6E17110E
271F1C3629252E231F322824342B26382A26271F1A261B172C1D181C130F31241E221718
21171821151020141917100F130B0C181110181010120B0B191111130B0B181110120B0B
1710101C1510181010120B0B0A07070B08080B08080B070718101018100B140C0C26120C
A69B9CAAABAB7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B4B4847
1E1A18241B18312521322A262F28243C2D292B2121241612281D1918120F2416111A1410
211410120B0B140C0C171010160F0F130B0B181010120B0B181111120B0B2D1A15080707
1A11111D1510160F100A07070A07070F07071810101610101810102B19142E20185C3C2E
CED8E07D7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
4B48471B16142824212B201B3C2F2B3A2D29352A27211B172C201C1A121617100F211410
1710101A130F1A1310171010130B0B130B0B140C0C130B0B140C0C1C14101A1111282833
2B26241D1115110B0B1610101A14101A131017101030221D241A172B1814523227ADABAA
90979B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B4F49481C18162D26222C201C332B2741332E2F27242D1E1622191817120F181010
120B0B19110C181010120B0B130B0B181010120B0B181010120B0B140C0C302C2D2B1D29
43362D332927241D1E362B27251D1917120F291C192C1E19362A2541261EAAA1A1979FA1
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7E7E7E494342201611312C293127244335303A2F2B382C27201815241A172E2421
211D191D120E1A1410160F0F171010130B0B130B0B1D151A160F0F1B14101B12132C221E
3A2A23160F101D15111F16111710101F140F2C1E1A3221185C3C2E7F747EA5ABAA7B7C7C
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B473E3A231E1A231B183B2D284C3E39433C382E2623211815261919
2818142F2420221E1A140E0F130B0B21191D1E171A2A221D1C161A392B241511154C3B32
2D2223271F1C2D231F271E1A2D22203E31272C211F603D2D9D9799868B938183827B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B47454139353A27211C382B263D312C3C3A3F3C2F2A3B3230
3F37332A202128282738303A3C352F281F2128232C3225223A3440362720261F1D45342E
34252237231F37241B3028254532295A3D2E281E19B9B0AD9093987B7C7C7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B6B676B474945211B1E382E2833343D5C4C47453E3D
433C373A3331423F414B3C3A453A332C242239302F2D21222F242031241F392D29352925
452820442C244230274A3A333E261E624C4C787F7D9D9FA27B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B78787B7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B47454A5B5A564E4F5A352F355B4D48
605A634D433E4B3D39443A36473B374B3C3D4D3F393A34324A3B373A332B493D3A4D3D39
41332A4637303526228570766F6E69716F739093927B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B79797B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7370744B4D54736D6A
76757C5D555C6C645B4C47503A363A51454D493A31463C384E3F3A443A35453936453228
3E352C9A93965757588983878589877B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7370787F7D796B686F57595E66666A635F5A655E5D656665656262615F5F5F5A57
61615F9995987B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.754707 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(68) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A6D513D
7D6E61776A6677726A77655E77726A776E66776E66776E6677655E776A596D6256735E52
6A52476F594D6552466B55496B55496B55496B55496B4E4262513E67514867513E675148
90ADBA777A7A777A7A777A7A777A7A777171777F7F777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777373777C7C777A7A777373777C7C777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777373777C7C777A7A777A7A777A7A777A7A777A7A777A7A745641
7B6C67776A5D77726C77655E77726A776E66776759706356726356725F5169584D675449
674F446A5548614D426D574A6B55496B55496B4F436B4F4362514467514767513E676B6E
90A4AE777A7A777A7A777A7A777A7A777878777D7D777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777878777676777C7C777878777D7D777A7A777373777C7C777373777C7C777A7A
777A7A777A7A777A7A777878777D7D777A7A777A7A777A7A777A7A777A7A777A7A70523E
7A6B60776A62776B66776E66776A627769617061515B5D57735A4E6E4E4964524567594C
6B584C6B5A4D695247675145665144665144664F4366513F64514667514567514486A0AE
868C8E777A7A777A7A777A7A777A7A777A7A777373777C7C777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777171777F7F777A7A777A7A777A7A777878777D7D777878777D7D777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A74513D
7B6E68776A64776A62776B6377675F776A5B7468607069637963537C5759685848705549
70554E70554D6847416251436751456751456751456751446E574C65504467514590ADBA
777A7A777A7A777A7A777A7A777A7A777A7A777878777D7D777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777878777D7D777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A775641
776C61776A5D776A63776A62776A62776A6077706B776E6674665D7360566D584F745C4F
745F546D524C745E516449426C4C456C5F57654F426E51456E5346624F436E5E508DA9B6
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A775843
776A5D776A64776A5D776A63776A62777068776A62776961776E6674665D78675B715F51
735C56715A4F6F5B4D694D486857486B5547695951674F42665145645145807D7C859BA4
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777373777C7C777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A61483E7F6652
776A64776A5D776A5B776A66777068776A62776E66776E6677706877655E776A60746053
785E54715C4E715C506D504C6D5546684E42645448644D406E514565514585949F7D8A8C
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777878777D7D777A7A777A7A777373
777575777C7C777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A29221C896754857665
776A66776A60776A63776A6477726A77655E776B5C776F6977675F77675F776A5B776859
705551705B4E7357516A5644674E42675549695044655145705E506955488BA7B47B8080
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777878
777B7B777D7D777A7A777A7A
777A7A777A7A777373777C7C777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A5B535A0A0504D5AB997B6C5E
77706D776860777068776860776B63776E66776E65776A64776759775657705B4B6B5549
72584E735D4F6C5C516452436F524868574B644E3D645146695447664F438CAAB7777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777878777676777C7C777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A7F8181100B087B6551BFA088776A62
776B6677675F776B6377675F776A62776B63776F6777655E706353725351705D4C6A564A
725B4E6E594C6C59476550456E4F43675144694F426C51476551456E574B85898D7A8284
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777373777A7A777D7D777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A170F0A746357B695877B6C5E776A66
776A62776A62776A5B776A63776A62777068776A6277675F6D39377342416C3B376C3C39
6F3E3B6F5C4C674F42674F446B493E6453416D51466B514562513F704C4269594E859BA3
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777373
777C7C777A7A777A7A777A7A
777A7A777A7A777878777D7D777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A5B53544D423BBB9A8C77675F776A59776A66
776A6277635577655677655A776B65776B63775453775B586D34346C3E34642E26724441
673B327248425E433A664F4266513F644D417053486B51456951446E4940695B4D756459
7F8D92777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777878
777D7D777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A0E0B0AAB87707D6B5C776A5D776A5B776A66
776A5B705B4E725A4F7A7062776C68775D4F70393B6B3B32634840532B1F6E6657765E56
5E271F693029674036654A406758486749356955446D51466B51456B50446B55486B574A
8A979B777E80777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777373777C7C777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A42383937291EC9A38A7B6C67705D507A746E776863
775D4E66504067443C826968693433270C0788625B6C433A74685E757A757639315D4437
4F3325604F48462E22723129605544694C346E4E466E594D735C49684F446B574B6B5145
7261557F8483777E80777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777373777C7C777878777D7D777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A0D0A09AA866C8F7E76776A5D6D53477D767177675F
775A4B5D3B2C613E35350F0D747770646F69A5A59E79797D7C81827B837E6B473A748783
6F6B67585455341E17371E12713F2F6F5E47704B44736355735B4D6D56476850456B4F43
6B594C72839E777A797A7E7E777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777878777D7D777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A615F6D020201DFAF907D6E63776A5B7464597B726D776A62
6943364C362454241D240C08AD7869836B5A72544D7A807E77625277685866453D78797A
694639706A63523A2F514C44391D16793F2F6E534878655077675B6D56496550476B4A3E
6B5447647372645D557071817F827E777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A29221C180E0D573A2ECDAB8E7B6C5F775D51776054776D62776A5D
643D3366594A78675E6F6D61A57A787462566C514B715E55753D39634A42642E2A6C342D
602F27716E5E5833295A42433A2D273B0E06885D527B6850796A606A5241654C42644E42
6D5A4C696256808790635F728C9288777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777373777C7C777A7A777A7A777A7A777A7A777A7A
777A7A777A7A6159600102011A100DEAB5A18D7F6B776357775556706A5A7A7063775657
64473A5A413089837C7B736B77625F746A60757269796C647C685B6C5D4F755A4E6E5A47
6E5A4E6C584871353560352F4B261B38130E6B291E816B567C665B6A5341654B42624B3F
7054476B584B251E1996949B7E7F7A7A7E7E777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777878777D7D777A7A777A7A777A7A777A7A777A7A
777A7A777A7A5A56654B44308D6759BF9D857A6B5C77625677685F745C587B726177645C
645041604238897E717A6F68776E66776860776B63776E667755526D5649735D516A5648
6F52485E4D3C69484061523E604A3F614C426949477E66447A64586C5744654B4262503E
7054486B594C151C1DAFA29D7F85877B8080777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A6F584B826A58746B6471675976675B7A6A5D776C6777646177786B776861
6B564A6A4C416D51447B74677A746D776C6477686077726A7760546D584A6C4B406C5A48
614C3C54493E654536624438624838624338604738745F4C7961576F53465E463D644C3F
695342665347090E0FC3B6CA8B9290777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A706D6D7A5B46705D536B55435D60668267567B6E6877706B776E66777068776C64
74524F6E584A6A4A3F7D6E607D736F776F67775251706A597A695A664C426C4E43614134
6152465C3E3566483663483E6A51386146396345337E625673574A674D425E483D674D41
6755476E574C000508C1A7A08B928D777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A745C4B7B6458664D42644F4274736B885B5577726A77726A776E66776E66776E66
776054745F4F675141725347807C7677726A77605B7470637B6C656B504A6D564963483E
6C574A5C3C32634639634A3F6C50426C4C4275594C7A6458674E42674F43695044654B40
6755426953470006074A342DB8B2B5777C7C777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A7758437063595232247B74678262627B6C5F77726877726A777573776C62776E66
77655C776659644F436F56477B796D7A6D6777675977706A7768606D584B62493C674D42
64514562473C684E376144396C5145795A527A66586D5A4D65564A6B5548645044645044
6754456E5E52322C1F3E231C3E312CA6A9A9777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
775F54693D2E5D2D285B4539717D75856A5F77725F776A6677726A777069776B61776E66
77655E7063536D584D746A5B7E74687B6C6170564F7A716377545466523D624138644C41
5D473B694C35533C316543397461527960537963556A564A6553476B4D42694F4365513F
6E4B416E62545D413557433D85A4ADB8B9BA777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
77474064372F5C312C6763517E7C6D88706877706977686377726A776E66776E6677675F
7767596D62537B5E52716A5D7D6E6877706974625E7B726777584E6454435E433B5D473B
5A42366146375E463D785E507A6456736255795F536A564A6552466B4E426B4B45694C44
674B406D655D5B392A694F4498BBC8747878777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A77655A
775244644236563D2D7067568B80717B6C6877726A776C64776A627769617063547A695C
7756556D605176584E7065587D706B776B5C776761776A6277535064483B5C463B5E463A
61483C5D4F436F5643745D51765D507761556F574B6C51456553476B483D6B4B41644D41
64543F70635E66413368574C72808B7E8483777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A69432E
58382D37281F53392D867567877C6D776A66776B637769617767597763576D6355765A55
6B564D725F5573685A73695C7D7065776A62776A64776A62705E52664A3C5C483D5E463A
63493D6850446D5547795953735D4F725B4E6C5D516F564A6554486B5247645144644B40
674E4770625D5D2A1C6D695B65423990A7AB777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A5D2918
1D140E3A2923352320A68671837770776A64776A5B776A5D776A62776861746A63786762
6E58506F514B67574778665976695C7A6B68776A62776A5B6D554E624539583D3D604835
5D43386F51456E5B4D7151466A584A72554E6750436A5448614D42665144644F4367493E
674D486958485535226A5644663B3790BCC7777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A776D66613428
2F261F31231C322220C1947983776A7063577A6B63776A5C61504768574A543F355B4439
59413B603E3C6C554470554871635680726D776A62776A606D514D5F473A594134634531
5B493F6A4C3F5E51445D4A3F6B5447705D51614D406D594C69544865504467514567493E
674D486755453E241A4E251B70463593BECA777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A70503F66423C
08050316110F281C19D6A183796E607763577B6E63776A5B68564C53443A44362C2F2B29
28201E4226196444344D261C512B208D7E6E7A6D67776A626D584B5F463A5943325D4D38
553E3572584B6D5A4D6E574A725245674D4757493C755A4D6B5549624E425A4B3F5E4B3F
6C54486754453C241C54291E7B433396C5D4777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A7F8181724835603F37
090F101C1310311915E4B3937B6F627364587A6E61776A5D74666156453A765F5822231F
1E1310361C13463A366336297C5F5095907D7D77737776736D5C4C5F42394C382D58412F
2B0D097A584760452E503D34412E23664D415A4E41745643665146644F435644395F4E42
724E485A473A311E1A5935288050479CCFD9747878777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777575777C7C777373777C7C777A7A777A7A777A7A777A7A777A7A100604965743665348
1A191814141922140FE8B89876675B776A5D7366597265597A6B68685B4C73584D423E34
624E4363432F694B38885F488664567D72637D78747770696D55455F4238553B2C574034
40271F615752302B27090506492A21453C32271C15573D344D36266D4736584C425F4F43
724D42433B2F231915462A2196695898C1CB717575777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777676777F7F777878777D7D777A7A777A7A777A7A777A7A1209080F0907310904432C23
0D0C1113110E2B1813EDB9987366597D6E685F3E39695648827570746E6575635D6C5650
674D406552456F52467E66527E6259776B5D7D7B76776E666D4F485F5044593F2F584E39
6340316C5E53543D3207080A462217392C29231B1868402F6845367E5F4A5F493F5D4E42
7254411D1918231A133C21189B4A3792BBC8747777777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777B7B777D7D777A7A777A7A777A7A777A7A777A7A777A7A0000003022182A15122D211C
0C090A2C1914311814E4AD8E7B675B73675C725F5A645849563D335D483B4D3D323D2D28
37241D432F234E31265334277A695B786E607D726E77695A6D4F455F5648593D32614433
5F4D396F5949634D4340413B775240583B2E53382B895A4779563C635448695040665448
5F4D4011110F2316124021188A34259BD2DD777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A0200001D0F0B1913101F1410
1C120F1E1511372823C79477826D60746C5F7B6C686F625A695C4F65494444413F6F4D45
5B4134674F406142357D5B4D8F877682746E7B6C677756536D5D4F5F54485938383D2419
462C206E59406C53446751416A4E44604D3C5E4E43795C485D4D40674D4A5F4E406C5342
433930080A0919130F975B46632B1FA8DBE6777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777373777C7C777A7A777A7A777A7A777A7A0703011C0D0A1E15111B1410
0E07072215103B2A26A271598971627A7062776A66777068746D637064606E716A8D7A6E
7671677D786F7A716A8977677870627D757070625372605570635267574D6C564E564739
3A252436271D2B1E1767413472584C64513E6350415F4D4160453B5443386C4F476D4E40
1D18140E0D0C2A231E914733462016323533A3A4A4777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777878777D7D777A7A777A7A777A7A777A7A0504032018151E14101F1410
150F0B2516113A2A269C664F9178687D7265776A6677726A776E6677757377736F77736F
776C62777573776C62776C627466597B6E63746557715E5273584E7162557463566F5752
544B48634B4240352E3E261C2E2118462B2339342C4831264A312671544D74514460473A
0B0C0C19110E261A1A32100B3D160F2B302EDEDEDF777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A07060536272315110E211410
1E141027191A392A24805641876E5E827668776A5F776B65776F6777706977747177726E
77706A77757377695E776E66776C6277685A776A5D6D5A4F736054735D51736457735955
675C4E66534755483D55483C5646395A3B2E503C2E744B3C6453467A4C4B5C4F3F4E4035
0B0C0C1D130F1B1410170F0A2F1A153B3531DBDBDC777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A0905032D1F171E181520130F
250F0B2A1915362419543B2F8F67568578687A6B5F776A6677726A777573776E66777471
77726E77726E77695E776E6677675977675F7763566D554A736457736054735D51735B51
6A57496D5145665246614E436B5549644E426C554875524669514A6B4A405F4B3B35271E
120F0E1D130F29181419130F24151139251BA28B8E878D8C777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A050301322926221A17261613
160F0B22151121141044291F6E462F957E6E7D7062776A6677726A77777677706A776E66
777471776B61776B61776E66776556776A5F705B4E705E52735D51735C51735B4F735D51
6A564A675246675549695A4D6750446B4F436551455A493E5E4D425E4D3F483B30161615
0E0C09241819170F10150F0B0F0707311B167B5F5AA7B2B2777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A0704012F26232C221E261A17
2417132014102A1D19402F294D382CA07664827163776B68776B6377716B77747177706A
77757377695E776E66776E6677655C706356705B50735B4F735B4F735D516C5D516E574B
6C574B6552466B55496B574A69524667504464514556493E6D4D415B473B31272115100F
231A16130B0B160F0F0F07071810102716116C554FBAC3C6777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A0706043128253428242D221F
261612140F0B2D1A1542291E5C3B2B90573F8776687A7064776A63776B6377716B777471
77726E77706A776C62776E6677655E746858715C516C594E6E574B7659536A594B6F5145
6F554E6553466B55496B4F43645144644F4360453A654C415F42363B332D241B151C1311
150F0B140E0F140B0B17100B1911112E1914DCD8D7A3A7A8777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777373706F6F0506052F24203529252D231F
1B110E261C182C1D1930231E643E2D7B5141867668807466776A66777068777068777776
77726E77726E77695E776E66705F517A65566D554A715B4F745C506F584D6C594B6F5246
675B5067544664494366514364514567514565483D5D4F434D3A2F4132281F1913211513
17130F1C14101B141018100B1C14112F1915FFFFFF747878777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A7778787479790204033C251C2F2521342824
2B211E281C182D211C3321185A463A5E3D2F8764547E75667A6B68776B63776F67777069
776D64776D6477645B706354705B4D76675B70554B6C57456E594E6C57456F594E6F584C
6555496B5347694D42655445674B3F674C415A4B3F4D42364631262A1E1C1A131017120F
150F0B171010130B0B0A0707150C0C492A24ECF0F1747777777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A050504312016322A27352925
281E1A241612342219312521473A2F45261E8256458780707D6E63776A5D776B6577695A
77695C77695C776761746858715C51735C516C4D426C53456F55506F5B4C6F594F6F4D42
6555486B4F436B4F4362514567493E60473B4B43374632272A1D1C241B1519110E181310
201410171010130B0B130B0B301A15E7DCD8AFB7B8777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A110F0D28201C3126223A2925
2B1E15291F1B281C183226232D211C3627246C45338267507D70637265597A6B60776A5B
776A5D70635772655A7A6B5C6D53496C4F446C5745674E436A574B6A5748725548674C41
6753466B494364534564513F60443A5A473B453D3133201B221B151A120E130E0B171010
221410150F100F0707140C0C321B16F6F7F7747777777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A16130E28211E342824312420
2D231E201617271B172F221D35292531201743271D6C513F795E51735A4E786659726054
72675A706357735F5376635669554A64493E6A5244674D436B4C416B52466E5144674F43
644B3F664B415D493B5C483B4E403647342941302520181318110E17120F160F0B130B0C
150C0B0A07070B0707301B163A1F15EFF3F5777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A383337241B193228242D231F
3B2E2A2B1D15271713392D282B201C352824261B174B3C3045322A643F32786152624E42
6B5C56695750695649715E525E493E49362C5A3F33664533684D43664E42664135664F43
644B3460473D5A4236553F334A3F3338241F301D151B14111B120F160F0B130B0B130B0B
0F07070B0707150C0C281611C0B4B2BBC3C6777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A6A6B6E18150F241D1A2F2420
322521231D1920161737241A2D23203E302C2F25223527223B2D2951342A553A2C3F3634
3E38315035285746385643383D2F2A402D22452E23553A285B392E5B4230674332554236
4C342754352C533B3041352F3A28212C1A1423151219120F150F0B120B0B0F07070B0707
0B07070B07072016112E1A15F8F3F47B8080777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A2321251F1A17372A26
2F28242E231F17110E33241D3C302D3B2E2A3C312C3B312C46392F45362C3B3128332625
3422193A231F432A214230282C222135262240271F41291B40272150392A4C34283E2D23
473227402A1F41322A37251E3020191F1412241B18130F0A160F0B130B0B0F07070B0707
0C07072515111911117E5C55D7DDDE777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A53515A18130F2F2420
2E24203023202A221E3C2C283E302C3D322D32272333282439231F42282033221A2B2220
241A163125222616123127232B221F291F1B271612251C172517142D18142E20182C1E17
2E201826151229171423161224171316120F16100B110A0B140B0B130B0B0B07070B0707
25151A251510332723E6D9D598A1A2777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A727476282826221C19
3024203529252F2420423530281E1A3C2F2B251C19362A254732283228242B231F2D2421
281E1A402C281D14152A241E2716132617131D120F1A141020130F2A18142819141D130F
1F13101E130F2918141D13101F1410140F0B170F0B130B0B140B0B0B07070B0707150C0C
33201B281813CCCCCBB8B9BA777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A4E484E18100D
3329253529252D231F28211C372B274335302924212C201C3F261C1F19162B201B2B201C
1C161B2C221D1E15162A19141E12171A140F1A1310160F0B1D14101C14101B1410150F0B
130B0B18100B231510150F0B130B0B17100B181010130B0B0B0707140B0B1E15102E1E1A
2E1A15C0BFC0C0C2C2777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A6F70721B1814
28211E3529252D231F332824342B27352925251D19251A162A1C181A120F2F231E221717
21171821140F1F1318160F0F120B0B17100F171010130B0B191011130B0B181010130B0B
1810101D1510181010120B0B0B07070C08070B07080B070718101019100B140C0C24110C
BBB1B2C2C6C6777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A585B5A
2B2724251D192F2420312A262E28243C2D292B2222251612281C1818120F23151119130F
201410110B0B130B0C17100F171010140B0B181010130B0B191111130B0B2E1A15090707
1A11111D1510160F100A07070B07071007071911111810101A11112C19143322196D4432
DEE6EB7B8080777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
585B5A2A221F2B27232A1F1B3C2F2B3B2D29352B28221D182D211D1B1217170F0F211410
170F101A13101C1410181010130B0B130B0B140C0C130B0B140C0C1C14101A11112A2B37
312C2B1F1317120B0B1710101D15101D141019101132231E281C182C1914553328C0C2C4
9BAAB1777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A5E5E5E2A24213229252B201C30292540332E312926301F16231A1718130F181010
120B0B19100B171010130B0B130B0B181010130B0B181010130B0B150C0C322E2F2C1E2A
44362C3A2D2A2B22223F312C2B201B19130F2A1D192D1E19372A26472820C2BBBBA6B5B9
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A7A7C7C5456552A1E18352F2B3429254335303A302B392F2A211916251B17332622
26201B20130F1B1410170F10181010140B0B130B0B1E151A170F0F1D14101A12122A201C
382922130D0E18120F1B1410140E0E1E130F2D1E1A332118613E2E928691B2BFC0777D7D
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A5555522D2A24221B18382B274B3D39453F3B322A26231916241819
26171331242125201C150E0F130B0B22191E21181D2D241E1E171B3D2D271712174F3D34
30232429211E3326212C201C32252246372B302521684130B5B1B597A5AE828986777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A55595658555E322A25362A25372D2939383F40342F463B37
4A423C2E23242828293E36424B423B3124252B252F3526243F3846392A2228201E47352E
33252238241F38241B32282548352A61402F2C1E18C8C4C29BA8AF777D7D777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A6D6E705E66622F282D3B312B32343C5B4C48464141
423D383C36344B474852413D463A322C24223D332F2E22212D221D2E221C392D29352925
45271F472C24453329503E3641271E604C4E8B9C9FB1B9BD777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777575777C7C777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A55595C7F857F7274803E373F5A4C49
69626E574B49503F3B443A35463C3850404155453F413A3757453E443A3150423F56443F
46382F453B3332262386757F88919090999E9BA4A2777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777B7B777D7D777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A7274765C64668F8E87
888D9169666F7F7D775F5D6B403E474F4752453A32433B374B3E39413A35433936402F26
393229A9A4A87C8286A4A6A989928E777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A7274787E817B6D717569716F82868480827A838181838A8A838888818686828583
858D8EAAABAF777D7D777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T1P00`40o`000?l0003ooooooi7oool0
0?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool0
0?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`006_oooaSQh>00
1^;Me=NhXn70Zn70/n77^N70/`CQb;X01n77^N70/N:oZ=VgX=Z]U]6PRm:NR004b9R300K8UX38T7W0
T7O0T7W0T7NgQg44hN3P0^7Qh@03hMOHhN3PhN3P00OQh>0Joooo6>?_k`06i>[Qg<^ehm6lhm;3hmS9
hm;31>?IbP07hmS9hm71i=2ig<VagKnWeK>MeK6J00C=[9D01/fZTlfURlJUR/JURlJUR/BRR@KSknl0
0n?Xin?_kn?_k`07hno_6_oooaS2^kT01[jSTl2NR/:PTL:TUl:RUL:TU`C2YYT01l:RUL:PS[jKQkbE
PKN9MKF5L[20K@04[Wm/00J^NVNYN62WN6BWN62WN6BiY9`4`[^i0/:f]@03`[Rg`[^i`[^i00O2^kTJ
oooo6:nRWP06Z8A`/8il[hf1[i>6[hf0[i>61:nCQ@07[hf0[hejZ8QeZH=`XWMUXgUWW7=Q00BMM680
1Ye^G9M_F9Q_GYQ_F9Q_G[>/[0B_XYh2[ibH00>_Xin_XYj_XYh01jnRWQcoool001[oool01^7Ph>7O
gn7Ngn7Ph>7Ogn7Ng`[Qh>000n7Ogn7Ngn7Ph005hN3P00SRh=WH^ZKQ`:[Q`;7QakWQ`;?Qb;[Qa[D2
hL>`00SO`k3O^jWP^:3F[iOEZ93>W8K?VX?6Uh82b9R30/REP005b91l`91h`91i`9V3]hej00CQh>02
hN7R00?QfMWQh>3Qh>001n7Ph1[oool01>?_kn?`l>?`l>?_k`;Sl?0:hno_0^?`l0KSknl02>;/i=_:
]>?A^^?Ba>?HbN?B`n?Ib^?Hb0;UfLP02>KIb>KA_nK?]]o7[]nnYMNbVmJ`V<j/UP;=[9D2cJZC00G=
YHk6YHW6YH_6Yhk4WXD01>?_k`;Sk^h00n?Wi^?_kn?_k`07hno_6_ooo`06`[^i`[Zh`[jm`[^i`[Zh
`[jm2/:k^@03`[Zh`[jm`[^i00G2^kT02;nUU[fKR/:PS<:TV/:RUL:TUl:VVL:UU@;1YIL02<BUUlBN
SKnKQ[^EOk^;M[J5LK60K;61KP:^Of`2[WaX00FYN6BWN6:WN62WPG6iUhP01<:k^@;2]kH00l:e]<:k
^L:k^@07`[^i6_ooo`06[j:N[j6M[jNS[j:N[j6M[jNS2ZnRWP03[j6M[jNS[j:N00F_XYh02:Z6LZ^:
NZn=NjnCRZn=P:nCQZnCQJnAP0:/TXD02;2BQK2=O:Z9MZN4L:QkJ:EiIiicHJ5gI@:MM682WG5O00FG
KeZHKe^HKeRHN6^cVY001:nRWP:_WYX00jnOVjnRWZnRWP07[j:N7?ooo`006_ooo`0:hN3PhN7RhMSI
hMkOhN7RhMWIhN3PhMoOhMkOhMoO0^7Ng`CQh>000n7Qh^7IfN7Ph005hN3P00SQg=?O_jOQ`;;Q_j_Q
b;[Q`;;QaKOQa;<2gKbW00SC/YcG[9OGYXo@Y8o8XHc8W8O9VXG0T7`2aIAo00?5UH35T7S7T7/00/2@
O003_i1e_kB^hN3P00GQh>000n7Ogn7Ngn7Ph007hN3P6_ooo`07hno_hnk^hnSXho3`hnk^hnOVhno_
00GSl?04hno_00?Sk^kSinKSknl01N?_k`08iN_Ri=:lhm73hm:lhmW:hm73hmW:iMS60^G@^@08h<V`
g/F^g[nVe[ZScK>LcJbGcJ^EaZF>0/n[T`03cjZCcjF;cZF?00;6YHh00l2MNl2l/^?_k`05hno_0^?`
l0SSknlJoooo00[2^kW2]kK2];?2_[g2]kK2]KC2^kW2^[S2_[g2^[P2`[jm1<:k^@03`[Nf`[Fd`[^i
00G2^kT02<6VULFSTL:PTl:STL:VVL:PTl:XV/6SS`:jW8X02<>GP;fAOkR?N;><N:j3L:ioK:]jJ:Mh
I@:_OVX01jmlJ:mhHZahIjMhIJMhI:f@OjfITP06`[^i00?2^[S2_[g2^kT01l:k^A[oool02ZnRWZnN
VZnMVJnWXjnNVZnOVjnRWZnQWJnWXjnQW@:_Yj<4[j:N00>_WYZ_Wi^_XYh01JnRWP08[8Qc/i62[hf0
[i61[i>5[hf0[iB7[8ij0Z>9N@08/hMaZh5`Xh9[X7i/WGETWG=RVFeMV6mM0YidH@07WW5OWVmJVVmP
V6mMV6mJXI68XHf500J_XYh00jnQWJnWXjnRWP07[j:N7?ooo`006_ooo`;Qh>000n7QhN7Gf>7Ph002
hN3P00?QhN;QfMWQhN800^7If@cQh>002>;Me=RhYN70[>70/^6o/N76^>70/>;1/`;P_:T02<BfY]:/
VmJMS/ZHPlZLR/ZLRlZFQ<RDP0C0T7`01<2CNl6AO<2@O;N7L@OQh>000n7Qh^7IfN7Ph007hN3P6_oo
o`?Sknl01n?Xin?_kn?_kn?_kn?^k^?Wi^?^kP02hnOV3>?_k`08h^[Qfl^ehm6khm73hm;3hmS9hm72
h]720]O9/`04`<6adKRUdjbKbjbE0/^bW@03cJfGcJ^CaZF>00?6YHh01<JVRlJTS/JUS/BRR@OSknl0
0n?^k^?Wi^?_k`07hno_6_ooo`;2^kT00l:f]L:h]l:k^@02`[^i00?2]kK2]KC2]kH00/:e]0c2^kT0
2;nSTkfNS<:PS/:PTl:SU/:UUl:PTKnMT0:`UH@02:J<O;F1MZalJZeoK:f5M:f5LZ]lJZUnJ0>WN6D0
1JMhI:UkIJEfI:MhIKVTW007`[^i00?2]kK2]KC2^kT01l:k^A[oool2[j:N00>_W9R_Xin_XYh00ZnR
WP03[ijJ[inK[ijJ00:_Wi/<[j:N00RZQ72[SWj_SGf_SH2_THB_TH>_SGjZRWd2VX=c00RGNVVTL6NG
L5^KM6:KNFZKNFNIL5jGM5l3V6mM00FHKeZJLEjDK5ZHKefc[:`01jnRWP03[ijJ[inK[j:N00N_XYhL
oooo000Joooo0^7Ph003hN7RhMWIhN3P01?Qh>001>7PfN6jXn70[^70/@;Q`;805>70/n71[N73]N73
]N;3]]VlY>:[Xm>TTM>OR]:JS=>OT<f:O/:<O<:DQL6BO/2@O<2?NlREP<2EP[V:M17Qh>0Joooo0^?_
k`03hnk^hnOVhno_01?Sknl00n?/i>?:]N?A`P03hm7301CSdL;SdK_Sd<;Sd<;Rd<7Lb;;T^K3C/igC
[9SDZicC[9g;Vhg5Xhk5Z9?6Y8g6YHk6YHo=ZY?6Yi;3X8PAhno_6_ooo`;2^kT00l:g]/:e]<:k^@0C
`[^i00C2YIK2Vh[2X9?2X9H2`Z2C01C2X932XI32WY;2WY:oVX^lTH6nQ7bdPVjdOVnbNW2cOW6UJf2V
MfFVP6jUM62YN6FYNVNYO6RYOF^fWYHA`[^i6_ooo`:_XYh00jnNVZnOVjnRWP0C[j:N00B_QW:_RWb_
SH:_SH@2[hf001B_SGb_Sgn_Rgn_RgnZQWFYOFnXLfZRM62RLVBOKFBQLFBAH5FFKefFMfFDJEFJKefJ
LV2GLEnJM6:^Xj<A[j:N7?ooo`006_oooaSQh>002>7Of>70Z^70[>70Z^70/N70/^71]>70/P;QaKL0
4>78^^;3]]ZnZ=Z^W]VYUmZZUM6KRmZUTLZ@PLR:N/VPTl2BO/F@O<N@O;jGR<FOR`SQh>000n7Ogn7N
gn7Ph006hN3P6_oooaSSknl01>?/iN?A^^?A^n?A^PCSdL<3hmW:00oRd<7Jb;;K^J[L^ZKK^JCE[IgL
]Z;=WY3=Who=/jG6Y8g?YHk>YHk3YY;9[I@02>?_k`;Sl?07hno_6_oooaS2^kT02<:XV<:PS<:PS/:P
S<:PU/:PTl:QUL:PT`;2Z9X04<:VVKnJRkZBP;V6N;b9NKV7M;F1L[MoLZ]bIJifJJ^5NJMdH:mhIJah
IJn8NKFKS0S2^kT00l:j^<:n_L:k^@06`[^i6_oooaR_XYh02:n:MJn=Njn=OJn=Njn=Q:n=P:n?PZn=
P0:_U8L04:nCQJZ6MJMnKZEeJ:UjK:EgIZ=fIj9_I9UXFYe_HYUiK9QYEIi_GIY_GJ>3MJVHSPR_XYh0
0jnQWJnWXjnRWP06[j:N7?ooo`006_oooaOQh>002Mo;`]_DcN70[>70Z^70/>70Zn71]>70/^78^P02
hL>e013Q`KCQakWQ`;?R`J[J/icJZIWJZICBWhcCV8S:UX37SWW7VXS0T7c1T7bjT7gG_kX8hN3P00OQ
hN;QfMWQh>3Qh>3QgmoQg]kQg]l00^7Ph1[ooolGhno_00KVi]kVl^_SdK_SdK[SdL;SdK`2hm7300oS
fL[Sd<;Sd<;SdL?Sf<WSdL;Rd;SJ`J_K^Z[K^ZCD/IcD[9[=ZY?>YY3>/9d00/JUSP03aJF=g<k6hno_
00OSknl01n?^k^?Wi^?_kn?_kn?`l>?al>?`l002hno_6_oooaO2^kT01;fWW/c0/L:PS/:PS0;2X940
0l:QUL:PTl:VV@02`YjB0132XIG2XYG2X92oV8:jSGfiRGZiRGNbOW2bOff[NVN/OF^/P6nYN6FUN6Fe
UXc0Zj@8`[^i00O2]kK2]KC2^kW2^kW2^[S2_K_2_[d00/:k^A[ooolG[j:N00VVSXBlZYR_SGf_SG^_
SGj_SH6_Sh:_SH2_ThD00Zn;O`0@[hn2[hf0[helZXA^Yga^YGY/YGYYWg1TWgAQVFiLVWEUVW=SVVmM
U6mM[9NB/9fE2:nRWP07[ijJ[inK[j:N[j:N[j6M[jFQ[jNS00:_XYhLoooo000Joooo5^7Ph00:]9N8
c/g3aJFIhL2[hL2chL2]hL2/hL2chLNihKn_0^76]`;Qa[P03^70/>71/N6fXN6^VMVUTmZVSM2FPm2H
PlVAO<6@O;nEP/VEPK^<MMSBdPcQh>000n7Qh^7Jfn7If@02hN3P6_oooaKSknl02/NgYnkcj/VdZ>?A
_>?A`^?A^^?A^n?B`n?HbN?B`P;SfL/2hmS900kSdL;SdL7Uak7U`Z[L^JGM^J3FZYSF[9G=Y8k6YHk7
Yi;=YI32WhOKg]h<hno_00?Sk^kSi^KSinH00^?_ka[ooolF`[^i00ZCNVkOb;ZeSh;2X972X932X8_2
X8k2Y9O2XYG2Xi<2`ZVO0/:UU`0>`Z2A`Yf>`I1o`I1j_8Ui]hM`/gY//gm/ZgITYGQU[7e[ZgIU/iZB
_K2^3<:k^@03`[Nf`[:a`[Fd00;2^kTJoooo5ZnRWP0:OFYNekJVZHEf[hf1[hel[hei[hem[i>6[hf0
[i610ZnGS@:_TH<03Zn=OZn:NZamKJb1K:UkK:9hHj1^HJ1dHYU/FYA_GIidHYU[FZZOWZ^KU`b_XYh0
0jnNVZnJUZnOV`02[j:N7?ooo`006_oooaKQh>002[BGR<k=`lFUVN70Zn70/n70[N70[>70/n77^N6o
[`;Qa[L2hLJh00kQ`;3Q`K7Q]Z7Q[YWIYI?JYXg@UX?@V8?9TGc1T7boUH;9UH6kS7GHd]8<hN3P00?Q
hN;Qf]_QfMT00^7Ph1[ooolFhno_00[7]jO^ln[9]:SSdKcSdL;SdK[SdK_Sd/?Sf<WSd/82hmW;0^?H
b@0>hm72hm71iLNaiL:Zg;VUgKVPeZZHeZbEcJB>aZF>ajNBcJF@`Yn7fmkN3>?_k`03hnk^hnKVhnOV
00;SknlJoooo5/:k^@0:TgY^glRj]Hn2`Z2A`Z2@`Z2;`Z2>`ZBG`Z:E`Z>C0/:YW`;2YIL03/:PTL:M
S/6@Ol6@N[b9NKN7L;=jK;=oK:]fI:EhIJamJj]fIK>JT[f`[Pc2^kT00l:g]/:b/L:e]002`[^i6_oo
oaJ_XYh02WeZG]NfYZV5MZn=PJn=O:n=NJn=OJnCQZn=P:nAP@:_Uhd2[i6300j_SGj_RWZ/OFf/PFbY
NfbRN6>PKV6PM6:IK5ZDKefNM6:IJeZZWij[ViL<[j:N00>_WYZ_VYJ_Wi/00ZnRWQcoool001[oool2
hN3P00?QgmoQg]oQh>004>7Ph00;gMCGQ4HoDEYJf;ZVhL6/hL6chL6dhL6chKnahLRjhL>f00;Q`:`0
3n76]N6i[>6eYMjbV]nhWmVXV=RYTmNNS]6NQ<ZCOlNFO<N@Nkj>N/FIPl2>N00BhN3P6_ooo`;Sknl2
ho3`4N?_k`0;iNc^U6=GPHEkflZchm6lhm72hm73hm72hm;3hmW:hm3100;SdK/03n?Hb>??`NG@_>K>
]>K?]mbjZ]fjYMjaWmFaULfVT<jZT<jUSlNVSln`V<bZTP0Bhno_6_ooo`;2^kT00l:j^<:n_L:k^@0@
`[^i00^j[[1N;RReWX^mVhG2XI?2WI32XIG2WI32XiK2YYW2WXl00/:PSP0?`ZFE`YVA`J6:`Yj6a9^9
_8am^XUi^81^]H1ZZg]X[7YS[7QWZWeY[h9]_jZR01;2^kTJoooo0ZnRWP03[j6M[jNS[j:N012_XYh0
2j>EU4X]9]>dWJ^:M:n?Pjn:OJn?PZn:OJnAQ:nCQJn;NP02[hem00n_TH2_QWn/TGV^SGR`RGVYOVnW
NVbSLf6SLenILF2JKUVJKf2KMF:NMV>f/:l04ZnRWQcoool001[oool2hN3P00?QhN;Qf=WQg]l03n7P
h00<h>3QSEm:`[Fc?ci6hL2bhKn[hLJhhKnahLJhhL2bhKnahLJi0^77^@0@hKj^gk^ThJRMfZJAcin:
ejB?f:B;dZ><aYF0d9AobIF0`Y1h`I1l`9=o^Xilgm[I4N7Ph1[oool2hno_00?Sk^kSj>SSl?003n?_
k`0<h^k]X7aT`L;6>ca5hm73hm:lhmS9hm;3hmS9hm73hm;3hmW:0^?Hb@0@iM70i/fhiKZ_gKVRe[BM
g[ZSgKZQeKNPcZZCeZ^CcJZCaJF9aZF>aZJ@aJ^Hi?;c4N?_ka[oool2`[^i00?2]kK2];?2_[d03l:k
^@0<`k^jJT<eZHn@GT14`Z2C`Z>A`ZFG`Z>F`ZFG`Z2C`Z>F`ZVL0/:RU@0@`Ij;a9>7`Han]hMd^8Qd
_Hah^Xae/8Ac/GaX/giZZgaWYWQRYGQUZG]X]IfEaLS:4L:k^A[oool2[j:N00>_WYZ_WIV_Yj<03jnR
WP0</JBOEcdaVWikLU=A[hf0[i61[i63[i64[i63[hf0[i64[iN90Zn=P00@[8]h/7mf[7i^XWQVYgaZ
Zgi/YgiYW7EVXW5OX7AQVG5LUVmKU6mMVW5P[9nK/kFe4JnRWQcoool001[oool2hN3P00?QgmoQh>3Q
fMT03n7Ph005RE]8jN;MC4m?f;ZVhL2[00;Q`;801N70/>70/N70/^71]>70/P02hLJh013RY9[IVhcH
R7oHQg_APgOAUhC@VH?@VGo8TGc7SgO6T7_8T7c8T7RoS7K3SWSA/jX<hN3P00?QgmoQg]oQh>000^7P
h1[oool2hno_00?Sl?3SknoSinH03n?_k`05XWeUk?Sd@TY4flZchm6l00;SdL<00n?A`^?A`n?A``02
hm730^?Hb@0@i;j`g;bXgJVJgJVFeJFBeKFLe[2He[2CcJR@cZF<cZF?cJF>cJF;aj><d:jGgmG>3>?_
k`;Sl?03hno_6_ooo`;2^kT00l:j^<:k^L:e]00?`[^i00EbBSW8^kEN@SZmVhG2X9400/:PT`05`Z2A
`Z2F`Z2C`Z6E`Z2C00;2YIL04;j4N;b=OKYlK[YmKKEjJ[FAMk>2K;>2JZihIJakI;5hIjihIJUhHZag
IK:<NL[6b@c2^kT00l:j^<:n_L:k^@02`[^i6_ooo`:_XYh00jnQWJnRWZnOV`0?[j:N00ERASNbWiM^
CT:[RWB_SH400Zn=P005[hen[hf4[hf0[hn2[hf000:_TH<01ZQbIZV1LJMcI:MfIJ=dHj>9K`:PMV40
29e^G9YbG:5_H9e_GIM_FYi^Gj:7M[g2b0b_XYh00jnQWJnWXjnRWP02[j:N7?ooo`006_ooo`;Qh>00
0n7Qh^7IfN7Ph00>hN3P00gMe=Cjkne8Bd_Qa[SQ`;7Q`:_Q`;;Q_ZgQ_JcQ_JGQ_k3Q_k7Q_[800^6e
Z`0AhZRLf7Q^efQLcfiYd6aScf]Xd8IeaHYfaI1hahQd_hmgb91lbI1l`8iebHaj^hYefm;?00_Qh>00
0n7Qh^7IfN7Ph002hN3P6_ooo`;Sknl00n?^k^?Wi^?_k`0>hno_00gUk>cHi>94C4KSf<WSdL7SdKcS
dL?SdL3Sd/7Sd[_Sd/CSd/?SeLH00^?@`@0;i;b^gI24gX9deXR0eX=heXV1eJ>=cjB<cjF;cYb7ajF:
00;=YHh01<JRQlfPS<R[U^Kgn0_Sknl00n?^k^?Wi^?_k`02hno_6_ooo`;2^kT00l:g]/:e]<:k^@0>
`[^i00fj[ZjFQ7iTBT;2YIO2X8k2X972X9?2WXk2XI32XHo2XiS2XiK2WI800/:QT`0A_W]b^V=J^5E<
^F=O/eU@^FUP[WUT[g]V[gQR[75O[7]T[WQUZgQTZG9MZgUW/Y20c=[Q00_2^kT00l:g]/:e]<:k^@02
`[^i6_ooo`:_XYh00jnNVZnOVjnRWP0>[j:N00RSUI5`FTmfFDf_TH>_SGZ_SH6_SH2_Rg/2[hmo00>_
THR_THB_RGh00ZnAPP0AZ6MNYeeCXe98Z65LX5I<Z6UNVG5MWWAOWVmJVVUHWW9NWFmMVFmJVVQFVG9P
YXj1_<cE00^_XYh00jnNVZnOVjnRWP02[j:N7?ooo`006_oooa?Qh>003H5NEInKV]No/n70[^70/>70
Zn70/>6mZmnbVmngX^6jYN6lZ^6TU`02gXQk01;MVHg@JUO;P7?6MF[@H5C3Ed[@J631MF[0R7O0SVbn
RW;6T7_8T7c8TWc8RWO8Uh;1Th3QgM`?hN3P6_oooa?Sknl00iIlL=??bmcBb@02hm7200SSdKcSdL;U
ckkVbK3TbkGSb[GSd;kU_[42iZVJ01;W/jSMPFgISX;=N6oEM6K@M6CFQGW6T836X8[6XX37WhS>YHo=
YHk=Y8k=Wh[=[9K;[i_SlO4?hno_6_oooa?2^kT016=4?N?8^/2SV/:PT`?2X9401/6IRLBGP/FQSL:K
SL:LRl63OP;2O6h03L24Nk=A@[a/H[=ACJi4>k9?@k=REjE/GJMkI:MbEZYgIK5hIjihI@02[WIT00>^
PFjlYIg2`L<03l:k^A[ooolC[j:N00eB?SO/bkR`THR_SH:_SGj_SH6_SGj/QGJ`QgBcTgn_RWj_RGV/
LVh00ZicIP0BZWQ_WT`m[6UNY4a9VD0gXU55X65FU6UJV7ENV6Q?VfmPXFmPWFmMWF]JWFmNWGMU/ZNT
[j^/3jnRWQcoool001[oool4hN3P00?QgmoQg]oQh>002n7Ph00>d;^lj<Jb=dE<f;ZVhKbUgkn[hL6]
hKb[h[JHeYn5dj2Ah9F7ZS0LbIZ70]R4O00CdgmedIjF]fEHaHQaaXQ[^6UO[591_EI9_WAW_Xa_`8M[
`99jb9J0bY9lb9=ob91l`i1kflBihMgL00kQh>0Joooo1>?_k`;Sl?0<hno_00kNfMWJdl8nCeGKb[CU
d;OTd[cSdK[Sd;kUcJoO^IoN_j_V]Z;2DcSaaZl2gI>901?CSX;4T8BaM6;>ZHkDVh39MF[1J5CCM6C7
U8;7Xh?6WGk6Yhc<YY3=Y8k=YY3=YHk@/9[Vj>7SlO403^?_ka[oool4`[^i00?2^[S2_[g2^kT02l:k
^@0>[9VIV85cJeYF_I^:`Ib4aJNE`Yf;`Yb9_9Il^hEbaij?_h5bT2`HiZZG0[YPF@0C/fmUXV1EV4Hi
ZX1XZf=?Zdi9Vcl`_514YGQTZWMHZG=MZGeW/7]VZgAT[W]X[WQU]i:0c<_:`/7300k2^kTJoooo1:nR
WP03[j6M[jNS[j:N00^_XYh03YB2P7EREHA^I:^:NZb9L[>GQjn:NZn9MJJ3K:MgIkVGR:YdIW`c8=nU
U0:WETh04j5/HHiCAXY3=9MiHiMGAia<B8/o<[5BAYEhHi]^DIY/FIYeH:1`GIUYFYeaH9e_GJV=OKbo
`:n[[00>[j:N7?ooo`006_ooo`;Qh>001>7Ogn7Ngn7Qh^7If@cQh>003Xm/I8V6RZfAPn70Z^:kZ=N^
Vn76^>6n[N:MOLn<L:4X8L^LV>>HUVlk>P;D[Z<05=:ESMRVW^CLbmR1N/FFR[27MZ5PDFdh8ja>@;F0
KKn9K<R=O<RKQm>RQLZAO<REP<RBO/>GP]_;amoMg@gQh>0Joooo0^?_k`;Sl?000n?^k^?Wi^?_k`0;
hno_00jNQGb[YJF_WHcSdK[TcK_La[7Sf<WSckgT]9?FYhRjBCc^`[_9LFeU8AT2d9f;01CARWWK/:;S
el_>LFNcQW6]RG:[M6:<E3_?L5c1W8C7W7k<XHk<[IOD/YG=Y8k=ZY?=Yi7@/IKXi=WTlO0=hno_6_oo
o`;2^kT01<:j^<:n_L:g]/:e]0c2^kT03VM7@[bISJF0L/:PS;jDQ<2RTl:UUl:FQ;MkGk5fGi4T7]V/
Y9Pa;G4M5@:bIeT05;ERD[f=P;^2N:]>Ai5@?8UHAgho<W8_7;mF@jQnHja_FK1nK;21K;:0J:]fIJil
J:imJ[NLU<Zk[LG1`0g2^kTJoooo0ZnRWP04[j6M[jNS[ijJ[inK3:nRWP0>DSdgaIb9Wg]][hekZ7m`
/9N:[i63[h9_Wf]CWV]IPBdVcZVOO1hFMb`Q0YmDAP0DY5Q6ZhAdY5mDUTY1OT4[N4dnJcT]KCDT^Ea9
W7aPWVIDX7QVX7IRWg9MVFaMWG5OWGARZIZI^JVI/j^W3JnRWQcoool001[oool2hN3P00?QhN;QfMWQ
h>003>7Ph00?gm[NODQ1;3e8ekRRhL2`h/B]f:bJhL2bh;2JfIQ`_U]1X2PGJ3Dg_::Fgk^]00;Oa[d0
5N7CbN7:`N:n/=F`W^2mZN30]LFUU9Q^IE`c9ie@@;^7KlB<N=6TSm:RSM:OQLR>NLR>N/NGP/6d^lo4
a]_Jg@0<hN3P6_ooo`;Sknl00n?^k^?Wi^?_k`0<hno_00oVko29HEILI6GLbkGSdL;RckWK^jSSdL?V
aZoR[hO=MeV[A2j2FeS4b;_VgM000^CVg`0EhnSShn;NiMK8g/nii]K4em7;[Z:FQV]RL4Ti`WAMbJF:
cZ:=e;BPe;:KeK6EcJ:;cJJ?c[:Pd=7Mh^KVi_;`00cSknlJoooo0/:k^@03`[Nf`[Fd`[^i00c2^kT0
3kfd]e0Z99f4M/2NSL:PTKnGQ;fAQ<:PTkn:M[5gEJQ:=WLL3i]UGk:[W<B[XP02aLC101G2[jW2/:bl
V8c2/:6oVhZ`X9emFE=Q>SEH8aRiFd>_PVZfP6^gRWVbP6b`OVR^Lf2^OFV/UY2bXjg6_lK<b<003<:k
^A[oool2[j:N00>_WYZ_Wi^_XYh03:nRWP0?YYZK?2LP`j6;/8io[henZX5aZhAi[hf0ZWMSVFQ;UdPh
HR<HZWabYjBE/9ZB00:c]k@05JnGSjnLUjJ2M[6WVjZ5MIZ=RfA3?54d;UDY7kMRBJ=mIjUkIZImKimb
GYa`GIeYF9eeHYZATJ>DV[N`]kbeY`0<[j:N7?ooo`006_oooa3Qh>004;BGR6e0><>SXRlf@]RjY>6l
Y>6jX^6mY^70[^>dWMRIQ[ZEN[ijKFm;A]>:P]RRT0;EUXP05MfXX=fQSmf?N/a[FmB4M/V=NmjPQl>3
MK5mKeXE2IiJD;f:N<nRRMZ]T]:KPlNFP<J=NlVBO/>cY;j^Z/2ic@0<hN3P6_oooa3Sknl04<NgYi5V
Flfo_SI1B=_:]>?@^>?A^N?C_>?A`^C4[]:UT:f9KYQCCFDo=m>JSMfhX`;O]ZL05NO<`NO7[^N_U]RB
O]nZV=ZdWNFiWlBNSJN<O74a8<61KlJSSMFfVmfoY=F_V<jZTljORlfYU;jo[kbi/lcBh@0<hno_6_oo
oa32^kT049=jKVXn>:N6PfIBC[fKR<:LQl:QRl:VU<:PTkV1L:UeHI9D@W<J6g4Y9kAeI[Z6MP;0U8L0
5LNGSL2LQ<1iI[U]GKUlK;nOR;QmJIebIgEBAe/?1KmdH[65JkZ?NkN9L[1mK:aiIk5gIJ^5M:JLUi^6
RKnh_00<`[^i6_oooa2_XYh047eZGV52?9AeKh5[Gj^:N:n9MZn@O:nEQJn=PZ9[G9=YE8=6=ed?3gL`
;J9^GJMiJ@:_SH005KB7NjZ@N:]]G:U]GJEdI;2OQj1/FXYZHEe7>eTL4/1nJZF1IZZ5Lj9gHia`HIY^
G:5^GYUnKYR@ShUeN[J_ZP0<[j:N7?ooo`006_ooo`GQh>000n7Ogn7Ngn7Ph007hN3P017OemY7;2<n
8ahJ;SR_SHGQ_ZOQ^ZSQ/IkO/YkQ^JOS]Ig=Q6S9W8_H^jWQaJoR/Z_L[J800]BXW00EdZ^LgYB:c9Z<
c8Efc7MZ`VmTbXYkaFYJ^eQ5VcPZI2@N/g=ZcIj6fZbBdYb0b8eh_hijb9J2SE4nb/:n`;?200;OgMd:
hN3P6_ooo`GSknl2ho3`2>?_k`0Ai^k_GTTkFd4g@4E7[YF<hm6ihljiiLB]i<>^hlnii<R]eYf0e[VU
flVchljih[RbfJjS00;@Z9`05M6VW=ZET<VKT<Z1MlYgK/F2ML^QSlB4L;]dGYYA?ga4=lfKR]JgVmg0
Y=F_TlfRRlNVSlf]UZMeGNodm/;1d@02i?7`2^?_ka[oool5`[^i00?2^[S2_[g2^kT01l:k^@0A_K6c
=A`E?adHRFANXWU[`Yj:`YJ7`IQoaIV6`YV:^Hab[g1GaJBD_If8`YB6_hEo]gid00:bMV`05KE`JK9T
H:]UGZY?BJY<B:IQEJe/H9mIBi19>6dV77T[8<2=M[fBN[N;L[1kIjUeHZamJJj3L7a=?>SVlJbLY@02
aL702/:k^A[oool5[j:N00>_XIf_Yj>_XYh01jnRWP0AYYNF;24J?BLQ/X=fVWAT[h]i[h=e[8Y`/h]i
[hIiXWMOVfQA^Z6CZhah[gebZWA/XfiS00:OIU/05JANEiaGDiUFCiM4?YM6@iIPDiaPEHaFBG]9>EXZ
8Gdi;;ZBN:n9M:9kHia]G9M[FYieHYejIfe>@>CPkYn?TP02/j^W2ZnRWQcoool001[oool5hN3P00?Q
hN;QfMWQh>001n7Ph00Ai>3SkmOFAEED;3U0gkn_hKnXhKbThZVSf;JShLB[hj^MeIJ0/gi[gkb^hLRj
hL6chKna00;Qb;X05N6j[n:iXmVXTmZVTM6NQ=2GOL><MLn2LlEiJkE^GYMGDY5BBL>AO=RUSM:LP<RB
NKn;MlRBOZ=bIE12?m_CdP02f=;B2^7Ph1[oool5hno_00?Sk^kSinKSknl01n?_k`0Ahnc]];^o0C4h
:3a4i=;2hm2ihlVdh[Zcflbehlnji;J[e:F=_IN0i=?5hmW:hm72hm;300;SfLX05N?>_nC?]MbjYMfi
X]FaUMFYSm2JQmJ;P<AmLJU[GHiHD9YSF<nYUMfiX=F_TlfTRlNNR/fWTJJ4M7IVG>KZj`02fmkN2^?_
ka[oool5`[^i00?2]kK2]KC2^kT01l:k^@0A]:FZKeYI008?DD=6aJ>C`Y^7`YF8_hV3_JB:`YN9^Geb
ZfiJ/8IcaJVN`ZJI`Yf@`Z>F00;2YYT05L:FRKjIP;b<NKN7LKF0JZigHK9XGK5NEIm;AHHj<gH^;95@
?[V7N;Z9LK1kIjUfH:adI:imJVU7?iQmMLc3a@02_K2^2/:k^A[oool5[j:N00>_WYZ_Wi^_XYh01jnR
WP0AVXJ:Ac<[000:J5QE/i61[hQe[h9hZWYcZiMl[h5gXVYOU5m=ZHUg/iV?[i>5[hYm[i6400:_ThD0
5Jn3M:R6KJUnK:9hHj=cGiU[Ej9MEIiFC8a3?G@d;V/^:XiI@jf1M:MkI9a]G9M[F9i/GYedHU0l=JjG
Skba/P02Zi^G2ZnRWQcoool001[oool?hN3P017Vgm;7`<WRaK;J[Y_G]j7O`:[Q^ZKQa:kQ[JWQ`JkT
`JWDXhc6QG;CZIGO_k3QbK_Q`K<00^70/`0EhL^hhZ^Of9n8f:>:ci]obi5l^hU[_GmZ_HMZ_GmZ_XAZ
]h9k_hicdIf8d9Mlahah_XmcaHmjLT<iCDe5^jn]00cQh>0Joooo3n?_k`0AhNcXb=7Nh/nhfkZUgL^d
i=6jhlZdhlnjhkVchm6jhlfee:nHcYj8glRbi=;5hmS9hm7200;Sd/<05N?Fa^Bi[]feWMfjXMJ_U=FX
T<RPP<NHPLNQPLNHPLNJPKnDRlFQP]FbV]F/T<jSRlNUQlnUSh5MD7IaG/:n/`0<hno_6_ooo`o2^kT0
4KVXYK:PYKnHQ;V:M[nLR<FPS<:KR/:GR<:BR<:MR;^ANjmfIK5hILFYULFWWL:SU/:MT002`ZBG01G2
VHfnQ7ZjPfnjSWJaOFR/N6FZLENXKUZXMEZXK5ZUKUZWLFF^Nf:ePff^NV>/Mf:ZNf6_NVU?;BNRShRc
XiD03<:k^A[oool?[j:N016QRXNTSHbZPg2UNfN]S7VcSG^_RWZ_PGJ_QWR_RWJTNVJKIUJQLV2fXHjc
Uhj_Sh6_RWd00ZnCQP0E[h5fZ7=XYgISYh9/WW1NUfiLW6QAV6QFV6iFV6EFUFIFVfeNXGANXgIQVFeI
VVmJVg9KWW9R?RhY_:VVZY^:00b_XYhLoooo000Joooo3^7Ph00BhMkNgmcFhKbSg[:JfkjcdkNTf;RU
hL6]hL>ehL6dhLVkh[bag;2Le9V3aX]kekBQhLJihL2c0^6iZP0EglFdh[VOf:B>chA^ciMn`XI//H=[
^85X^GmU^H9T^7QP]HA^b9N2d9Z3d99l`8Qd`8Yh`9=k@b<V:c8dako>00cQh>0Joooo3^?_k`0BiO3`
i>kViM2hi/jgi]W<g/^bfl^ehm6khm32hm73hmS9h/fnfl2Xe:RAc:>@g<fhhmW:hmC60^GD`P0Ei=W9
iL^agKNOeYf4e[6DaIb0^9^0_iEk_i9g_iAh_hid_Yb3c:bFe[2HeZN@aYb7aYn9aZJ;EShkHEmMem_]
00cSknlJoooo3/:k^@0B`KRgaJjM`Ib9`Yf8_JVRaib1_Ij<`Z6@`YjB`Z6E`Z>F_i64]X]d[g=Q]8Me
`:NG`ZVL`Y^@0/6ZU@0EaJRG_8ij^X9_/G1J/HM/X6aFWG1GXFQEXfY@WVIBXFA>[7aX/85^/h1/[WIS
Yg5OYgMRZG]U;1<FUh:1b<;?00c2^kTJoooo3ZnRWP0B[9nK/i9l[8Ui[XejYiNB^Ha_Zhin[hmo[h]o
[hn2[hn1ZWa^XGYRVfEEYXAb/9Z=[iN9[hEk0ZbKQP0E/iB4YWUWYg9QWVQCWWeTSV9?SfUATV5AUFA<
SUi>TUm:XWUWX7MUX7=QVVYIV6UHV6mKVW5N8aXK^J:P_[Ro00b_XYhLoooo000Joooo3^7Ph008h]cB
f<g9h[ROejRAdj:7_Jj]hKJThL2c0n78^P07hL^hhZjRg:Z?chmjeJFChL2chL^k00;R[ZT05MRjZ>Bn
ZM:RSM>JQ<:1Kl:8L;QgI;QoJ;N2LL:9K[b;MKV5L=2FP=2EP<VBO<69ML2:Lkj?NV0`9b`U:9F>RP02
hMkO2^7Ph1[oool>hno_00SRk^SKhMkUbk7N_ZGC]Yk1`/3Sc;KSd/<3hmW:00OSe/KR^K3L]ikFYHoM
_j_Sd/?Se/L00^:j/`0<flZdhlbee;:Ke:RAaI=oaI^3_hih_iIk`9R2aIam^YQo_9Al0]JZT`07cJB>
aYb7aYn7ajF?K4TlDTU6b<Jn00;Sl?0:hno_6_ooo`k2^kT02;n^YKfZYKbAN[R;M;BDQ;2@S/:TSl:T
U`?2YYT01l:ISKn6O;AoJkQjJL>SU<:TUl:IS`02_hj401FmVhNkSW^bP6b]L5nVKEbPJ5FQIU:QK5NV
L5ZVKeFPKURVL5fcNVNcO6R[MVBUKefWMf6ZNVTi6QIB>CGPfM@00/:n_@[2^kTJoooo3ZnRWP08ZY:7
ZiB<YWeWXg]VXX^0YH5k[iN2[i>60jnCQ@07[h5fZWEZWViKYg9R]9b?[i>6[h5h00:ZP7<05J^:MZAh
IYmbGYQRDYIWEhiMC99QCY9WDiQZE9IVCi9VDIY/FJ1^G:1aGiU[FYAVEYQ_Fi]bHRXN6ee9@^gVh`02
[jNS2ZnRWQcoool001[oool>hN3P00SQgmSQ_ZKLX87=X8g7WHgH^ZCQ[:GQ`;<2hLVl00SQb;[Qak[Q
`jgS/9SAXXG=U8;O_JoQa[D3hL6c01CR`:gIXHg@VX?7T7c8T7ZjP6JiNFBgPFjoSGk8TH7BW8OBXXc8
UH77TGc7TWc0RgW0UGkIU6aF<bY2;bh2_kVj2^7Ph1[oool>hno_00SSk>GUdK[T^9WF]j?8[Y[Kb[CS
^kGSd/<2hmS900SSfL[Sf<SSd;WT_ZGE/YGFZIOTdlGSf<P2hm7400kSdL;Tc[gM]:7F/9S>YHk=XHZn
TGNoSGS0V8?5Whg;X8gD[9OE/Yc=YI02cZB>00G6WXW6YhfhUGIBASeWEe000_Ghn0[SknlJoooo3/:k
^@0B`ZRH`Ij<]G]R_IN5/X=e_I^8`Y6=`ZBG`ZRL`Z>D`ZJI`Z:B`YZ4^HA_]H1X_Hf0aJJK`ZFE0/:Q
V00>`Yf@_Y>4]Gm^/h1/[7QUZFiMX6I?WV9CYW9P[WMX/GYX/Wm//81^[WIU0ZafI005YgAPZGeXLddl
>AlMG4<o00;koOd:`[^i6_ooo`j_XYh04Zn:MJb;O9aYE:j?OjAhK:^:N:n4OZnCQZnERJn>OZnCQJn=
Njn6L:9aGJ=bGJj9OK>ERjnAP0:_ShH05Jn:OJQnKj1_H:1cHIY_GIMSDi5OBHiLD9Q/Fj5^H:9cH9mc
HIabHIe[FYY/FYY[FYQ/FIYdH4li<3@V961AB`02o_oo2ZnRWQcoool001[oool=hN3P01?Qf]CP`[7K
QW7GXHZdOfgA^jCQ[:CQ`:_Q`;?Qa[OQclGQb;[QakWQ_ZkR`:OCZ9K@YXoH^Z?Q^JX00]nkY@0EhKja
h[BNfJ68ahagaHQb_Xa]^WaV^gmT]h5`_hmmcib=fZJAdYf7b9Z3bIF0`I1h`8eg`99oc9^5`XQ/QUA8
009:A4@:hN3P6_ooo`gSknl04n?_k>KNcNJYT=foXl6FO]o9]>>k]>?A_>?B`n?Ibn?Qf>?Ib^?HbNGA
`>C>]]>cW]:cV]_:]NG?_P02i=Bm01GSeLOUcKCM]ig>Xhc>X8S7XhC5U7c8V7RoUH;5X8gE[YoM^J;E
/Y[=/9S=ZY?6YH_6XXc6ZIC<ZY6_SG5J<R800T<j<P[SknlJoooo3L:k^@0C`[B^_ij=_GMT/hecZhA_
bYR8`Y68`Z2A`ZBG`ZZO`ZbR`ZJI`Z:E`Ij;_Y>0]8Eb^8ag_I^:`IV;00;5[9H05L:MUKbIO[EoK:ag
I:YdGjYgFj1VDj]/DjMcHZiiJ[Z6MkN7M;23Kjj0K:]lJ:EhHZUeI:V5LJAaFh=D@dXQ7P02HD<n2/:k
^A[oool=[j:N01>_VY6ZQgBWKUfMP6JPQG>mQWR_Q7R_SH6_ThJ_Uhf_UX^_ThF_SH2/RgRXOVbRMfBX
PFf[RWb/QWT00[>MR@0E[hV2YXM/WfmOVVmLUf]IVfiESUm>W6E@Vg1OXG5SZWa]XWQVW7ITWG=QVG5O
U6mJVV]LVWi[Sf5=K4Pj@RTW009bEe0:[j:N7?ooo`006_ooo`gQh>004n7Je>32/M^6LMNQR[AoKM6k
Y>6/Y>70Zn70/n76]n7?aN78^^77^N6n[^;0Ym>XU]2VSmRjXn6iZP02gk^U01GQ_[7R]9kIXHS7S7O5
R7:nS6fjO6JkOfBgPG2oSgg?W8gJYY7BWHO8VX?9UH31T7S0SGO0TWo<VhG2R6b6E4P00TY4A0[Qh>0J
oooo3N?_k`0Chno/i]k=iZV@gKnS`IInglVdhk^dhm6lhm;3hmW;hn7HhmW:hmS9iM70i<jfdk>Nd[>J
flZeiLnn00;Te;d05N?EanG=]=fgWLjSS<jPR<NSQ<FDO<RHN;nEP/FPSMF^WmfiX]FbV/f`V<fZTlJU
RlJRS<JYU<bZTJn=LEXb8P02@cXb2^?_ka[oool=`[^i01?2]:joWXfmMfBcSG>[Q6o:V8S2THS2X972
Y9O2ZYo2[:;2YYW2XYG1WX^nTh2dQG:hS7NmVh[1VH/00/F/UP0E`YfE_9Un]Gm/[7MTZWAOZWMKX6IC
ZfaCYg=R[WUZ^XIg]hMd/8=_[X1/ZgaXYGQRZGETZHEaY75KPeA3BR4N009Q@ch:`[^i6_ooo`f_XYh0
4jnJTJZ7M:M^GIf0IZ25Lkf6N:n4N:n=PJnCQZnGSJnFRjnCQJn=P:b;N:QnK:9gI:R1KJ^:O:b6N@02
/if901F_RH:VQfbOKenJKebGJeVKKUF>GdjLIE2KL5nQLF>ZO6fRN6JLMVBMLf6ILEnDKeZJJebJOV^?
HDe/B3Y2:BL00W9GD0Z_XYhLoooo000Joooo3N7Ph009hMCBhjJFdWi[`6iU`8in_K:UhL6_hL6]hL2c
00;Qb;X02>76^>76]N:o[]RgX=ZaW=NhYN71[n;5/@;H[:805N70Y^>XVm2IO/F4L;f0Jk=kIl25JJUo
KkV5M<RMRLnRS]ZVTM:NR<RFP<R=O<V<O<2=MLJ<OLN@LKj6L[IkIP02h^7R2^7Ph1[oool=hno_00KS
i^;T_J[ETgk6Q7O2XI71`kD2hm6j00_Sd/?SfL[SfL[Sf<WSf<STd<3KbK7Ka:kLbkGSdK[Rc[T00]^k
[@0Ehljgi;R/eJ^?cYZ4aYN0`IAlaYYj[Hek_9B2c:jIeKBOgKVReK6JcJZCcJ:>cJ>>aZ:7cZ:?cJF5
aif8`IEm00;Rk^h:hno_6_ooo`g2^kT02L:PV;V0KZ]NCjMZFjb8NK2IS<:QSL:MRl:TU`02`ZJI00S2
YIO2YIFnVhbmUH6iV8C0WXc2XHfoU8<2_I6201G2Th:iQ7J^MF2ZKU^SJUNTJeBRK5BJJEVVL62`Pg6j
QgFgQgB`P6f^NVN^MFF[MfBWMEfaP76WKUBZMFFjXYX00[ng]P[2^kTJoooo3JnRWP09[h=gXVeKUUA7
V6aKWhIgYH]n[hmk[hYj[i>600:_ThD02:nAPjnAP:R8N:^3L:F9Mk2>OZn?NjYmKP:[Q7@05JmnKj9d
IIUWEIMVEI9SDIIVCi5SCi5TEIY/G:1hIjYkJZ9hIYacHIe^G9e[GIU_FYQ[EZ5kK9AQBY]_H;F_[P02
ZYjJ2ZnRWQcoool001[oool<hN3P01CQg=OQg<oSYYG@PFRoMF^kUHGH^ZGQ`;?QbK_Q`;;QaKOQ`k7O
aK?Q^JgR^JCG/icQ[YWG]j?Q_joQa[H2hL2b01GQ^k3SYHkBUh30QG2iPFbaP6f`PVfgQgG6VXGAXHgA
YI3HXXcBWHO8TWc8SGO7R7O7RgRoSGc;VhVjPFbhQG@00^7Ng`[Qh>0Joooo3>?_k`0Dho3^hn_Ti;:T
e91jahUn`ZRFflZehm;3hmS9hm73hmW:iMW7i=W9hlo0i=6hgLR`iLB]g<^fhm;2hmS:0^?A``0Ehlfn
i;^PeJbDaYZ3_iEn^95m^9=m_iZ7cJjHe;FOeKVSgKRPeK:JcJN@cJ:<cYb<cYj;aj6@c:ZF_Y=kbjND
00;`o?`:hno_6_ooo`c2^kT05<:f/<:VWkUcJZUMCJa^Hk>?OKfKSL:TUl:SU/:PTl:XV/6UU<FXV/:I
S[jQQknEP<6IQ<2QT/:STl:UVP;2X9<05L:DQkV5K:]iIZ=/FIiXEYQXEj5ZEjMeIK>4LKN:MkF9M[Z6
Lk23KjifHjieI:aaI:adHZamLjQaGj1]FKFJU002e=GC2/:k^A[oool<[j:N01B_W9B_R86RH5RCDdJN
KV:ZRgV[RWj_ThJ_Sh6_SH2_U8N/TX6cU8R_QW^XTGJ]Pg6/RgN`TXJ_TH6_THL2[hf001F_Og6RMEfF
KE^AHe:>HE29HU:FI5:KKf6TNFNVOVfSNfVWNFJLMVBMJeVMJebJJEbJK5ZNMfnEHDjAIeF[WId00/C1
_@Z_XYhLoooo000Joooo3>7Ph00Dh<nkein6_GeP_7MR/7m/`ib;hL2[hKnahLFghLJehKj/h[j]ek:O
g[VPgjJOfK:NfJfIek:MhL2bhL2/0^70/P0EhL:_hZRIdXmi`8E`^81/^X9_/XYh_i9mb9Z6cin:f:RC
dJ:=dYV4b9Z5aheiahUe`8Mh_i9maGiOaXUg`H=[00:gX9l:hN3P6_ooo`cSknl05>KTdNK0YM>NOMFF
Nl6GOlZ^Vn?A_>?B`n?Ib^?Hb>?A`NCA`=g9/^K?]^Jk/]c3[MbjY]c3[n?A`n?A^`;SdL<05NG?_nFe
Z=FQRlJJPknEOkjHP[NORLFWSLb^UmJdWMfjYMFbW=F[ULf[ULjMRLjLQlJMRLNYSljFM/jTT<JNQP02
a<O82^?_ka[oool<`[^i01BoWhZmRWFTJe:cJeBePVbhT7k2X972XiK2Z9[2YIG2WY6nWXjoUhG2VHK4
ShFlUGnlSG_0VHW2X9?2X8h2`Z2C01G1UHVlNVn[L5nSK5VQJURPL5jNMf:^OFZ`Q6nhR7BjS7VeP6j`
O6Z^NVR/Ken/KefWLf:/QG6ZH4JaR7NULV800[W6cP[2^kTJoooo3:nRWP0DZXA^Yg]YSf==XfIA[X=^
[HYh[hf1[i64[iB7[i60[h]oZ8]k[HMg[XIf/89gZHI`ZGi^/8]m[hf0[hem0Zn=P00>[81dYVQMUVEE
TF=BTVACTFYITVmKXGASX7UUYgaZYgi/Xg9QW71OWFeM0YYVEP05V6aKWWi/UeHoXHEeU6YN00:cbM<:
[j:N7?ooo`006_ooo`cQh>005>:mXII<;YMEAV`o>HQZH/fXV>70[>70/>70[^70/^71[^:kZMZnZ]b[
Wm6RT=JNSMFaVmNfX=noZ^70/P;Q`;005N:jZmV[T/j:O;j3K;IlIkF1K/2<N[j@NljFQ/nLR]2HPljP
R/nJPlFDOlNEP<2>NL28Mkj8NLFBL;=ZD/F>NP02]faI2^7Ph1[oool<hno_00OTck>YJdNaMF66GE6_
SWgD_JWSdK/00^?A`P0;hm73hm6jh/Vcf/RbfkVZeKRSgkZWg/bdgL^di=:lhm7300;SdL805NC>_]g0
YMFQT<NKP;nCO<6HPlJPS<NUSmN]VmJbWMJaV=NiXMJ`V<n[TljZTlJRRlJLR/NPT<bSPl:3J/nVT002
a8Ya2^?_ka[oool<`[^i00RgPfUg?2B=CSm[>C70SWJnVXW2X8k2X942`Z2C00[2WHRoV8BjTX:fQ7Je
QWJkT7c2XXboWh[5XiC2X9<2`Z2A01FnUXVeQfn/Kf>UL5FOIeJXLV2YNFN/N6NfPg>iQGBcQ6jfRgJa
P6b_OVZ/O6RWLV2WLFBZNf^UJ4jYIe:_LV<00[VNTP[2^kTJoooo3:nRWP0DWfQ?IC`XP511IClfbYUn
/I20[hem[hen[hf2[hf0[hYfZXMcYgi_XG=TXgUYYhEa/YF0[I1l/i65[hf00Zn=OP0EZ8=fX7EOUfAI
UFU?Sf5AW6aKVW9PWfmPYGYYZ7UZX7UTYGm/WW=QWWAQVW5OV6QHV6UNVgEUTEU3WFUFWVIJ00:c[jX:
[j:N7?ooo`006_ooo`[Qh>02hMkL01CUd/SAMeaQ=b]Y?3Q9B4o=Z9GQ_ZcO_k7Q`:_O]YcI/IgCX8S?
W8G@Whk=ShG=TH;4TGcEZ9?E]Z;Q`;82hL2c01GR_:OKXXo8S6nhN6JhP6R^NfNjQG:oT7_2SW[4VXG?
UhG6TWk9VHC1TGc0T7c0SWW0R7O0RWbcJU6OCSB^LUH00[I[G0[Qh>0Joooo2^?_k`;Sl?005>?Ld/22
Ife??gaGCVeWI]BmZ^GA`NCB`n?A^^K=/nS?^nG1Z>O2ZNO1[^2/WmR/VLn/UMo5[Mg<]n?A``;SdL80
5NC=]]bdX<bNPkn>O;nENkZANlRNR<nXT=2VSln^V=JYUljWTLf[ULJTS/JUS/JRRlJLR/JOS[j3I[I_
C/BCLP02a8]l2^?_ka[oool:`[^i0/:h]@0D]XYnP4HcCbXPGS8^V7AW_YZ:`IjAaJ>F`Z29_IJ2aJ2?
_8ij`iJ1`I22_Wec^HE_]8E``9j8`jBD`Z2C0/:PT00E_Y60/We[YF]HXFACW6YGXVUGZ7QU[W]W]7eY
]8Ac/GMX/GeZZgaZYGITYgQUYg9PYg5TYgMUTE4jVDT_/G1D00:lXJ4:`[^i6_ooo`Z_XYh2[inI01BM
JUYO>R]8<2MG=c:aR7FaT86/RgncTHB_SGNVPg>bTH6WP6jbRgR^PgJ/LfVXOFJUOFV_TWjdUhV_SH02
[hel01FXNfbKKE^@H56BGdj<I5>FI5>ILV2OLEjVMF:UNFZNJebQM6:IL5nDK5ZHKefHJ5RHJEjHKeem
BcN=C3BXKeH00[Nd^`Z_XYhLoooo000Joooo2^7Ph0;Qe/X05>;0/E`F44PR7D<Z9Se4C<nYU^6nYmRh
X^70/>K1Z<JHPKZ9L8QQEVi9@HE@>Z9XFk=MAK1J@l2HQ]nm[`;Q`;805N;0[M^SSlR;L;J4IKAeG:j4
L[b:MkN@OK><NL2;N/>EOk^AOLRHPlRFP;f=N;Z=N;b;Ml2;O;adFY9<>Hm?@002[F152^7Ph1[oool:
hno_0^G[h00DiMG7Lc<WId8fH4LnJfEVeKbXhm6ifl^ehm72h/fec:bDb::6X7i^T6]LZg9GaH]jbgmQ
c85Sg<F_i=?50^?A``0Ei<jmg;>Pc9n3_iMg_h]a^IZ5_9V5]9j;]Ij9aZ>?cJjDb:NAcJbEcJZCaZ:;
b::;b9j:aYj>_HM/W6==WVUF00:lQ6<:hno_6_ooo`[2^kT2`JVK01BlThY73PU881U99b:TNffjUH;2
WXZmWXg2X96hTGjRMfBMKUQkDdU_A3ZBCCJbKEbXECf/GDCB]j75YY/2`Z2C01FnThBbNV^UKEFOJe2L
GdfTMF>OL62GLV6MLV2WNFVWOVRbP6b^OfbYNVNSMF:XMF:]M6BWM6F<Ccb0>RZECC/00[NRU@[2^kTJ
oooo2ZnRWP:/SGh05:IlLc/I4d@Z8TT`:/FCOZZ:Mjn;NJ^>Ojn=OYmjJHeZFHUSD6iAAfQ7?Ha@>Za_
G9UD?imOAlbhX[>ER`:_SH005JQnKi]YFi1SC8mTC8]IBiY`GY1XFHUXF91YFIQaHYAcGZIhIIedHYM^
G99[FYU[FYm/GYQ/GGA5=WHl;I=C@002];Zf2ZnRWQcoool001[oool9hN3P01OPh>7Tg=7Tg=7KXXVU
FU0_5aHj7QdM<SkH/ioI^J?O^:?Q`:[R`jkQ[iNkUhNBHe5<:RI8:R9PACnFI56LIUZDG5GG/il00^74
]`0Eh/>cfjV@`h9[/WIJRbTFV6MH^85Q^H5XZVmF^HA^_HMg[HUcaIAnaiF0`8Yd/8Mc[XMg_HQcZV=A
TeQ6UEiC00:]DCl00n;Qh^7Ph>7Ph007hN3P6_ooo`WSknl05n;^kN;WgN;WgMbgWJ5]HT<`:e4j=4UD
F=_3[]c9/nC;]N?A^^;@^]VjXJbMRhmcH615?FA7>H1TEjikI9e_HIUWG]c3[P02hlo101GTc[gL^J3:
V7joTG2OB2niT7W8Wgc<WhG4Sg;CXh[6WHbjWhS?ZiC>ZY?5WhNhWHNiWH[6X8ReO6JTL5ZSLF800[QZ
D003h^k^hno_hno_00OSknlJoooo2L:k^@0G`k^j_9^;_9^;/WeZGS8_:Q0>?aXHSgQ[_IJ4_9N3aIj:
`Z2<_iZ9YgYVSfePFcdb@AlLDRLLL4ToVe4mSTm3V69F`9^<00;2X9@05KjCOk9lJImVDIiYBgHQ4K9n
IJYfEZMdH9iSBkUnJZ=cI:IiHjmnK:alJ9i_G9YcHJAcI:=dGXI8>Xe9=i]BAP02]Hb000>o]kK2^kW2
^kT01l:k^A[oool9[j:N01NaY9nVNfNVNfNLK5e2;2TY71Q19R:hV8:[QgJYQG>cSWb_SG^ZQWJ<IE9o
HEE6=bhk9b=B<2A`DDFDCS^7Cd>HKUn`SH400Zn=PP0EZ7aWVfUHRUa9SfE9IbTK/HAZW6mCUVeLSUi9
[GUVTVaMWG9MWWATVW5ORfEDS6aKVFaNTV]FLT<gQ4XhV5E900:bYZ400jZNVZnRWZnRWP07[j:N7?oo
o`006_ooo`04hMkNhMkOhMoOhMkO1N7Ph00GLbXQa;:Ua;:UhZbE]6AA?RHa:QPG7bTgekNQhL2ZfKRR
gkfVgknZi/Bcb9f7jJVCTGMYIe=8K512LF]RWgATaYB3ekNS00;Qa[L05N;;^m^]Tlb8JjYaGJeYCfi1
?XMOER0737U9?7=CAfm2<I1YFjMaDKF0IKj<M[23L:j8LkMmJXM>?6m0=hYVFP02]VaN00?[jNWQh>3Q
h>001n7Ph1[oool01>?al>?`l>?`l>?`l0GSknl05hi;??o^f_o^f^G0Yk1fHU0oADDd;EA>Dmg;]>?A
^]c:/nKB^^CB_>;>_Lb/UmB`WVa_ITiCCF1KDG1eKjB1L/bZU]c<]`02hmW;01GTgLkL_jG;Vgj_QW2Y
MeeoEDfQNVY09RBRKEV@Lf2?HdbiT7[3TVc;X8;5XhbhUh:iW8O0U7nHJ5:;GDjVP6l00/63L`03joOf
hno_hno_00OSknlJoooo00C2_K_2_[g2^[S2_[d5`[^i01MQ8AWod;Cod;BlRgM`?38`6R8a516NNFbo
W8S2X8blVHK4XHc5XiBhT7n`O6bEK65=>SPk9bEB>cAaEDjIHeJdS7W0YYH00/:ZW`0E_Z2?/X9^WfI?
SUa:O40aM4<mO4m19PH8SddjNeE5KSd[YW1LY6U9]GYOX7MUVVeLY75QUFEDK3T/MS/`[FiL00:jUY<0
0lFm_<:k^L:k^@07`[^i6_ooo`04[jFQ[jNS[j6M[jNS1JnRWP0GDbPPolJXolJXYGYYE3@]:b8V=20K
b9b6[Hai[hekZHQf/8ml/i65WgQWX6mRLUM>?C0`=BHTCchhLeE<U69FYXMd/9R<00:_Uhd05JR8MY]^
GHUKAgmGAfLi;G=>Ag1>?RLE58aB?gMJBFI1<J5aG9QVB:]eGHi^GhaWEYUYFh5MCE`h;G=1=K=cH@02
]JNZ00>^XIf_XYj_XYh01jnRWQcoool001[oool01>7HfN7Gf>7Qh^7If@CQh>0067i3?7A4?B`002`0
091?@5P]>3HO73HP8@/T<mVhX]NhYN2ZUMBWT=>cWn;3]]c0[MRYUlFCOlNGPk22K:Z0Jl2HP=6MRmN`
W@;Qb;X05N;2/m^^V<R>L[V0HZiiGjA_GZEkJc4K82XM6V4m>EDk=EM4>H]WFY5aGK]mIK67Ljj;M91@
AV]0<5Tb9fA:?`02_7aW00?YinOQh>3Qh>001n7Ph1[oool01>?Xj>?Xin?^k^?WiPCSknl069MTFHeT
F5<O65<O6<5kI7A<DU4l<ddk>3U7C=c:/mc;]NG2Z^38[=k=^>;@`MW6/M2`W<>SS<:TSZZ;LjZ>M/:W
S]B^V]c4/0;SfLX05NCC`]boY/bMP[jALjj6KialKI>5ND8d=4Tj<GYKDVUFBg5OD9InKIZ2Jkj@MkRM
QkVNQim[GH5MB75=?XM/F`02cZN?00?/n?OSknoSknl01n?_ka[oool01<:d/l:h]l:g]/:e]0C2^kT0
66Pe;eld;TP304P30:QOBDdT;C@J5SXJ6XQaI[bIQ/2NS;Z8M;jMPlNZV[nNSkN<NJYhIj5bGYiaGXmN
BYU/EZalJ[N8M/2QTP;2YYT05KjEQ[:6LJEWD9UVCY1EAX9KDfeABah<4DDO5f8l=TX^9g56=XEIBI5S
CIaUDiQcHJAdGfhk=Edd9Ed[89]HAP02aKfd00?8`;o2^kW2^kT01l:k^A[oool01:nMVJnSWjnNVZnO
V`B_XYh065Tg;e4e;TlE3dlE3j5UCd@[<38U7c/U8[JEP:V8M[2>OZ=fI:bAN;VNTJZ;NZ=gI9EVEHiV
DhYTDX5FA8mYDimbHjIoKK2ER@:_ThD05JQnKY]dH91KAXQOBX5=@GIKE5Y8@QTF64h]8Ui3?4@c:gM>
?GmHAhiSCH]OChU/FiU/F5/j=5@h:U/c::URC@02_lg<00>bYZ:_XYj_XYh01jnRWQcoool001[oool0
0n7Jfn7IfN7Ph005hN3P01R;BT9:;2E38R138R0f7QhS3A8e7R0h7QdM;S[H]j7I]j3Ub;S=UHNlPFW=
VX?8Vh>hQG>VIEFPHT^ZKEB_JE;2UGgEZIKG/Id2hLFd01GR`ZgKYYG8UGfiNf2`R6BeP6K3U7gBTWY;
CTi_CD1kETYHEE2@KURXNFNnTGFlQg>`R7F3C3M7929B<2IM?C000ZY<>@[Qh>0Joooo00?Si^KSinKS
knl01N?_k`0HTF1EGDHjECXdECXdDCTd?RXZCCXfC3TcBE9Efl^dg<^dhLfobif?cYn5j<B[h/:WeZZE
aXQc`XQYbY5ccHe`gKVLg[fXg<B`0^?Ib@0Ei=?0g;VWc:R>_i=d^9ah`IAjaJ>=YhYj;DM;I5Q=L6EJ
EF5LSW]W/HejajB7_IR4^9b7SfA<GT0iJD/lNeU800:nME`:hno_6_ooo`03`[:a`[Fd`[^i00G2^kT0
658U8DHU7CdF5CdF5D0M6b<93C/K6C/I5hmeJ;fLR;bLRkb>QZE/GZ]dGlJLQKZDOJaiJYiLBj9SB:aY
D:iXC/ZNQ<:FPl2LS@;2Z9L05KjEQk:7MjE`FiiYC9YaDZQ_Fj9aHFM8@bPP9Th`:eDl=Ea7@85GA9IY
FZYfGIi^GiYaGE/a94<N6ePZ7hTm;@02_Z6H2/:k^A[oool00jnJUZnOVjnRWP05[j:N01Pj8Aa4;RDk
81dk81e2:bDT5aPl9b8l9B2hUH2[S7VYS7fUMFjAH56KKE^fTgjXR7BJL6:?FDRFHdZPITnRIdk0VX:b
RWR`Sh<2[iB401FXOW:KN6R@HDj>HdR<JDjLJeZ@IEQ5=SDZ8RA7<Re;?3ESC49kET>9IENKK5F=IUV<
JEI8;bE0:2=H<bJDAC@00[g0_`Z_XYhLoooo000Joooo2>7Ph00HV5Q2<Q8@:a/I:a/I<ATH<Q/I7QDF
@c4`<SQ0djjJh[ZTf;ZUi/FheK:N/X5a[WibYX9cVg9SRFEJSFECUg5RV6aRajJEf;ZV0^6i[P0Eh[bV
fjRAb962YU]4X5@mYGmO_8mb`91ga9=m^haeXgIUVW=R]XAb`8Q_/8Me_8mc]h5YB2/T:a`IATM5Kd<d
00:E=RD:hN3P6_ooo`SSknl069Y/ED/_9dPh<4Ph<4`f;dPf<3Ta;5a:AEaGEmk5[n;:]=_:]N7>_lB]
VZ^9N;>BPJJ@OXekKH5^HhabH9AjJiMeJLRcWm_:]0;Scl005NC@]mbhX/bTTkIgFkUfF;jQNlRUR<JU
S<BTS[>EOimnKJ61KknGPLJLOkRMQlRUQl2IOei7>dPh<5UIE7IEA@02[EY32^?_ka[oool8`[^i01QI
;24c3```61@`61@f5Q<_518W4Q5::RR@J5c7WXVoVhRmVhfiU8FKKej<Ed^9HeJ?HeA]Bd1/B3meB3^7
EdVBIUVbS7bmVhX2`YV;01FnW8:bQ76UK66=BS>GDSR/QEj]NfFWN6BTLf>>HU61DTNCGdjOJeRWLEbJ
Lef]Nf6EJ5Df71L`5a=_ASeY;R<00[V@R0[2^kTJoooo2:nRWP0H?R@L<adH<B@N<B@N=b8N;b0L:b0L
C3<^/85]^I5nZXYhZhYnXGe^Q5U9O4i3MUa?Q5a<Gd@iI4LmK4HiP5A7SfaMY85bZhYj0Zn6N00EZ8U`
VgAST5mDO4PcRUDlYH=OWg9PV6mLTVQJNeM7Lda2SEe<SfAAV6UGS6aFWg9KPEm?;R<M<B<MOe13Ic4W
00:o]KD:[j:N7?ooo`006_ooo`;Qh>000n7Ogn7Ngn7Ph003hN3P01R[LE`o514]5aH]5aHS61L?0@PZ
5aLi;Be8CDfmWH[O]j;Q`:_Q`KCRa;SPa[7@X9FMT8k:X9NjTXBlVhb[RGc:VhWG^JGQ_jh2gl6]01GQ
Zj3L/9[=ZI;8SX:;CDE[>Bi/@RnTLE^hRgC7T7W3TWB`R7BnRG2ZOfZlQWZbQgF@DSi=9b0d:RTa>CBU
DSX00VXh<P03`L;2hN3PhN3P00OQh>0Joooo0^?_k`;Sl?04hno_01RZPVaB;bM4<ba4<b`l=2h/7am5
=2iAB4=^KFO@^:?TbkGSdKcSdL?Rd<7Ga:ngThZ@QXBjThVYQGBXRgZRPWC:YY?Lb[GUd<02i]3001GU
^[7L`:W:/9bgSHB>GU:7FDJAIT_=VG[;Yhc>YH_5Y8NhW8O7X8BhV878WHngWHNOKUEQ@cQ9A3eDED^c
KE400X]QEP03m?oohno_hno_00OSknlJoooo0/:k^@03`[Zh`[jm`[^i00?2^kT066Dj;cD=2RdC4BdC
4BPD4AL11C4E4T@/:HaYFl>JQLFQSL:PTL:QUKnKS;24MI1OFhEKFIYOEHmHBXaGBI=JCJioKl2PTL6K
S0;4V8h05L6;PKB;N:MhK8YAC6L`:V`j:G=3;KeiG;F4K:ahH:9fGiYaGjEaFiM/FZeeJIicGFhn;S`L
5cDS8G13=Hi0;002LDi700?hooo2^kW2^kT01l:k^A[oool2[j:N00>_XIf_Yj>_XYh00jnRWP0HAb`S
<AXE;R4L;R4L:R0L714B=2<MB3HaXGQT_9Ao/i9o[hf1[hn2ZXMgVV]NNDm;OU5<Qdm3P4dnNdPiRE=4
WWIV/924[8Qh0[23N`0E[7e`WWUXTfIMLT8lFC0ZId8`KDPd^7ULZgiXVVmHT6]HS6UHUFQERFEFWfmR
TVaFFcd_=2@N=bdXQDlmOSl^009/FU<00o[ooZnRWZnRWP07[j:N7?ooo`006_ooo`;Qh>000n7Qh^7I
fN7Ph003hN3P00nEL6U9;BT_5aH_5aH/61LN4Q0R51Dl;Be=CdfWRgcG/IgQ`:_Q`;?Qb;[QbK`00^7:
_`CQbK`00n;3[MRhX^;7]P02f[NP01GI/icJ/9_CZiOF[9[CXhnKKfYlETeC=RaU>RbBFTZAJEJRJe6J
J56dOg2SOfbnQ7=_=Rhj7AX`7R<d4a5e:1`00WI3?003=2l^hN3PhN3P00OQh>0Joooo0^?_k`03hnk^
hnOVhno_00?Sknl03i^3NEe6?DHb;4Hb;4@d;SH]9S/`:eE8@fa/I;JSTMc4[n?A_>?B`n?Ib^?Hb@02
hmO80n?Hb@04hmS8h]2ifl^eh]S70]_9/@0Eg<R`fl>/dkZVdKRT_:2>OVYVKemDJE11RUe8^X5Z/Xec
`8a]]8Q/`IV6Z99naiZ8OU14DSTaBCXiES8YUTPe00:8Ge800e]BB^?_kn?_k`07hno_6_ooo`;2^kT0
0l:g]/:e]<:k^@03`[^i00mL?CQ07a`_4Q0_4Q0^514P3@X[4A16;2V5H5:aS7[0W8S2X972Y9O2YYW2
Z9`00/:TUP07`Z>D`ZRL`Z>D`Z>C_iZ4_Ij=_j:B00:iUH405KbEP;VCOkB;NJf1LXYOEEhh=T/a:eH^
8flm:j1MBI5XDJ1SBIIOBJ]fIYEZFJE^GTdS7SHG4cHK7TTD3WhV6002Hchh00>IRXO2^kW2^kT01l:k
^A[oool2[j:N00>_WYZ_Wi^_XYh00jnRWP0?@blY?2LR;ahJ;ahJ;b0L8QXF;alLBCHaUVaI[X]h/8ml
[hf1[i>6[i>5[iF900:_T8401jn>OZnERJn>OZn?OJZ6L:^>OjZ=O@02YH=`01FYPg6UPg6RO6bIL69^
Bd=><Bdn;bQF=BYZA3>HGd^6Ie6EHDV;GDRPLV><I5BEIUHm9R4d8Qdh9bM=8QYi<2400UQ5?P03_;:_
[j:N[j:N00N_XYhLoooo000Joooo2>7Ph00HZgadFClm:a`J:a`J:aPG;APG;1dR?Bh^DTe9Y85adjjK
hL2YhKn`hLJihLJghLo6hM39hM;;hLVlhM38hLRjhLVlhL6/hL2Z0^:nYP0EfK:LfJRCfJnJfJnKg:VI
bjBBcI>1X7]]OV1DJ512PeI8NfQKUG1PRVML^hIh]X5/KCD/<AXH9APG7a<A=Q`L009M=cD00c`f=N7P
h>7Ph007hN3P6_ooo`SSknl06:Z=Q6IFCd4f;d4f;dDd;T@d;D<h=eA8@g9ZH;fORmk6/>?A^n?Ba>?I
b^?Ibn?Rf^?Qf>?Pen?HbN?Pe^?Ib^?Hb>?A^N?A^P;TckL05Mc2ZmbjYMc3[Mc1[=bjZ/baXL2JRh]l
L6eRF6UMD8M[FgijJi1jJIAjK<NMRlBGP7]>@TTe;cld;S/_:5Dh<P02ME9:00=TFU;SknoSknl01n?_
ka[oool8`[^i01QU@cm<<2dW4a4W4a4`514]4a4a61]5:bMoFDVgRGG7XXk2X8o2XiS2ZIc2ZYo2/Jc2
[ZK2ZZ32Z9c2ZIg2YYW2Xi?2WHO2X8`2_YJ201FlT7flS7VlUX:lSWndRGZXNfnAHUQVAd5A=C1H=Ri/
ASYeEDQgDdJ;EdnUMF:OJ5E:81``518Z518V3Pa56AH00Ulg<P03WY2<`[^i`[^i00O2^kTJoooo2:nR
WP0HAc8]Ac@`9QhJ9QhJ<R0L;R0K<b@SAcD_Rf9?]8Ue^IN4[heo[i68[iN9[iN=[ifG[iR?[i>7[iF9
[i:4[i>5[hmm[hYd[hek0ZR2L00EZGm^ZGi/ZHMdZGeaWWY/UF]PNE=;E3dhAS8]ECP`HdPlLeA7KE13
R5M?UFmJSV1?>b@P<20L;24M:A`GBBHP009L@CX00kne/jnRWZnRWP07[j:N7?ooo`006_ooo`SQh>00
4JY`FU<d:TX^:dX^:bXI5c4A3cHN7D4[9E=3?HYbI<6NS=noZN70Zn70/n79_>78^^7?aP02hM3900GQ
d<SQb;[Qa[GQa[SQ_ZP00^:jXP0EfJnJfK:LfJRCfJjGfZFDdj:<bij8a9=m^95n[XUeWWUXV7=S]Gm_
/hYe^ga`X6I=HS8Z<AXH=ahM9ATH9QLF0091:R<00e5=C=GBdn7Ph007hN3P6_ooo`SSknl04J^3KFQ?
@Ue8@Ee8@D4d;DT^9Tdj=5M6?G1QEZVCOljhY>CB^n?A_>?B`n?HbN?Ib^?RfP02hn7H00GSh=KSfL[S
f<SSf<WSdKT00^C>]@0Eg<>]g<:[g;ZUg<:[gKVXe;RPc;6Ja:B=/ij:XXmlU7i^Uh1^]Y9o]i^7_Y24
Zh1ULde1BCD_C3Tc?3@]@3</009LAc/00gilMnWgm^?_k`07hno_6_ooo`S2^kT04FPn<Th/8chR83hR
82`C4C@>2cPJ6DHX86Q7?:j0J[fLR<FSS/:PTL:TUl:XW<:VVL:a[002`ZjV00G2ZIg2YYW2YIG2YIO2
WXL00[jFPP0E_9J2_91m_8ai_91o]hUi/XIcZ81]Wg=RU6mOPUe>Ne=7QUU:VFYLW6eMW6MKP54lBB<N
<1@B=aTG9A<A;a<A009=:R400ib<S=GJel:k^@07`[^i6_ooo`R_XYh04D/`9dXc:STZ9STZ9RdO6cDL
5cTV8TLb:6a?@[>4K;>FP[>AOZn=PJnCQZnERJnCQJnMU`02[iR?00F_TXB_ThF_TH2_TH>_RgD00ZR3
L00EZHMdZGm^ZGi/ZH5bXW][WgUVUG=QS6QHQ6EELE95Kde1OeE7RVAGSV=FRf9EKTdk?BPS<20L>2DP
9QlK<R4L009?=BX00k6QXlW<ajnRWP07[j:N7?ooo`006_ooo`SQh>004YETCePn>D@[9d@[9cdR81lB
42`F5RhI64hc:VUA@;2;NmNgX^70Zn70/n77^^7Bbn78^^7?aP;QclD01>78^^77]n70ZN6mZ`;Q^:00
5MVXTmV]UmV^V=VXTmZVTM2NR=2HPlVLQl2AO<REP<6@O;f>NKZ8LkZ8N;=mIg56?2lI4cDP91hA5b4B
40h12002<AdM00=@A42LR8_Qh>001n7Ph1[oool8hno_01:KNF5/ETeHA3aHA3aB?3Hi;BI8<be:=Rm[
DD:;M5g;[Y_LbkGSdKcSd/?SfL_Sh=OSfL[Sh]X2hn7H00CSfL[Sf<OSdK_Uckh2iLVa01GL^ZGL`Z_L
`Z[L^ZGM^J;F/I[F[9G=[9O6Y8k=ZY?6YHk6XX_8W8O8W8_2U7^6HE9:=RY?>c/i;Rdm;bL[7al00Tlj
=003MFQO^:f^hno_00OSknlJoooo2<:k^@0BG3HYDc<^?20L?20L>QXH8`d:=1@B=AHCGS@XRea3ain<
`:6=`Z2A`ZBG`Z^R`ZZP`ZJI`[6/0/:/XP04`ZJI`Z:?`Z2?`IV90/6DP@0E_8ai_9=o_91m_8ai]hMd
/h1]/gm/Zgm/YgIT[WaXYGQUXg9PZ75QZ75RVfEAFc</;A8=>A/N90hA9Pl<5`4500917AT00h1QF/:h
^L:k^@07`[^i6_ooo`R_XYh04T<[8Thi<cTX8cTX8cTT82DK5SHQ7CLS7V0n<91SBLJQS[2BOjn=PJnC
QZnITJnCQjnCQJnMU`:_UX/01:nCQJn=NJn=Ojb5MP:/PW005JUnK:V5LZV1KjUnK:9hIZ1cHJ1dHYUc
HYQ/FYeaGiA_GI9XF9UYFiUYFXYMBdhe;B`N63XV9RLL6bPM5a`B4P02ABXS00>=KfO6`/>_XYh01jnR
WQcoool001[oool8hN3P01:EI4mH?SU4:bM4:bLm8R0O4Q0/5QH^6AQ><bYYDD2`Rg_G]j;Q`:_Q`;?Q
ak[Qd/_Qb;[QclH2hLo500CQb;[QakOQ`:WQ_J/2hKRP01GIZ9?I[IOI[YSIZ9?JYY7@WXS@V8?9W8O0
TGc8UH31T7bmSWVjR7>jR7RcOFMaAS`_6A<e82@N4ALQ4Q0>0@P00S4M7@03D4A0W8R;hN3P00OQh>0J
oooo2>?_k`0BVgUQK5I=F4@lF4@lDS`f>BdVB3<]BSH_Je52RgAMbjjKg<^ehm6lhm;3hmW;hn3GhmW:
hn;J0^?Qf004hmW:hmS7hm6kiLnn0^G9/@0Eg;ZUg<:[g<:Zg;ZUgKVRe[6JeZbEcJbGaZB>cJZCaZF>
aZ:;b9b7b9b;`YAkQV5BBSHZCc/k>Bh]?BlW:alO009?>S@00gEXGkR][^?_k`07hno_6_ooo`S2^kT0
4U`f:E<c;S`P73`P73XJ62<=2S@D4SDF4ehd:8]L@lNOS<2QSL:PTL:TUl:[X/:ZX<:VVL:a[0;2[:80
1<:VVL:RSl:PSl6IR@;1U8405Kb<NKbCOkb@OKb<NKN7M;>0KK=oK:]oK:MfI:ilJ:EhIJ=bH:QaHJQa
HY]UDE/c;2dB3CTK7R@>4BH?31L11@02@AdI00>0HE[2^;W2^kT01l:k^A[oool8[j:N0193:b9>>C<i
:2<i:2<i920U6aHf8Adg8aiP?S2@HdW6XHj`TWn_SH6_ThJ_VI6_ThN_ThF_WIL2[iJ;00B_ThF_SGV_
SGn/QGH2[89`01FYOVbYQG:YPFnYOVbRN6JPLf6PM6:ILf:HK5ZMLEnDKefBJ5RIJE^IJEZ:GD]>=Bd/
7QPj9RHW71/X7ALL4Q800TDZ8`03SFmWa/;3[j:N00N_XYhLoooo000Joooo2>7Ph00CZg5KCSHaDS/i
DS/i?BTW?R4O:1LF=R@S?c<cGDDnOFMHdjbHhKnZhKnahLFfhLo6hM;;hLVlhM3800;Qb;X00n77^^6n
Z>6mY@03fJjH01CIZ9?HZ9?GYI3HYI3BWXS8V8?8Uh;9WXS0TGc7T7c0SWVbR7BcQ72KIUAN<2U1:RPE
2@lP4QT=0@PK41H28A@E00=8?SmfHUkQh>001n7Ph1[oool8hno_01>ZPfeQD4MTE4eTE4eB@SaA>c@o
<Ra=?cUGBdIhGe6QR77Na[3Sd[cSd/?Sf/cSh][Sh=OSf<WSh=H00^?IbP03hmS8iM6iiLng00?L`ZX0
5=bjYMfjYMjiXmfiXmFaV/f/ULf/U/faV/JTS/jUS/FRRkNLQkNJQ:N0Jg5<@5A4?C0U9C/_<2XN7cD]
;08l<2/00fULF9J3N^?_k`07hno_6_ooo`S2^kT04fDl<4T^:TT^:dT^:cXN73PH5RXB43PN74X^:V]1
<k60IlNSS/:SU<:SU/:]XL:a[<:ZX<:XW<:YW@02`ZJI00?2XY;1WXO1VHD00kb@O@0D_8ai^Xai_HUf
^XUf/81][Wm/[X5^Zh1]YgIT[7QUWW9PWW5OUFiKNe11BB<M>B4N6`H:9@lC5@058@dA0RdB4003Ke1;
/inK`[^i00O2^kTJoooo2:nRWP0CAbhTASDaAC<^AC<^>BLS=R<N;1lK>BTTCCLaJdPh_8U_^IV4[i65
[i64[i^@[ifG[i>7[iF9[i:400:_ThD00jn=Njb;MJb5L`03ZH5_01BYOVbWOVb[NfVWNfVLLf6MM6:M
MfFILf6HK5ZJKef;J5RBJER6IUEZBcho:B<g:B@O5QHW7AdJ4A8U6a/2<R0K00=iGEK2]K:_XYh01jnR
WQcoool001[oool8hN3P01RPO7AI?SYB?SaB?Sa?>SLm8R0R4a0d7Qe:<R]TC45/G4joUH?O]j7Q`;7Q
_k7QaKKQclKQd<WQd/_QbKcQb;[QakWR`K;J^J42f:nI01GGYI3GY9;JY93AXXcAW8[BWHS8V8?8UH37
U7o7UH2nRG?1S7N`P6^[L626CC]B:RDR4Q0R4aTC20lK4A0H3QD00RlM7@036ATKO71^hN3P00OQh>0J
oooo2>?_k`0HXhf3K5I=I5I@I5I@H55;DS`f?2lWCSXdH4i2LfIHPgUXck>Oi<^fhm73hm;3hm[<hn;J
hn7Hhn3GhmS9hmW:hmS9h]70flRa0]g1ZP0Eg[VSgKZUgKZSeKRPeK:MeK:JcJbEcJZCcZ^CcZZCaj28
aZ><^9N0^hagV6UCITDl?BlW?30`;R@U=B`V<RX[0097>3<00bLO5WQ]IN?_k`07hno_6_ooo`S2^kT0
6693?U4b;Ddb;ddb;dH[:CXI5b@>2cdK6E4_9VQ6>HiTD<2KR<FQSl:PU/:SU/:]XL:a[<:^Y/:ZX<:S
U<:VVL:RUKnMRkVBO`:jSWX05Kf9M[n<NkN<M[F6LkF5M;23KJioK:ilJ:anJZalJ:EaGZEgI9YZEi1N
D6dl;D@O6bD?32D?4a/62R0=2al<4002=aTG00=UC4J1IF32^kT01l:k^A[oool8[j:N01Q7<R]=>35:
>39:>392<B`i8alV71Lo9b9C>2iXBcfFJUBhV8JcTX>_SHB_THB_Vi2_WIN_V8n_ThN_SWj_ThF_SH2Z
RWNUOfd2Yge/01F[NfV]OW2ROVVSNFJSNFZLMV6MM6:MLEnJM66JLEnEJ5JDKUf<He5nFDaN?2ln9b8W
7APV71dO5QHT6aHS6Q`00SXU8003R79[QVaU[j:N00N_XYhLoooo000Joooo1^7Ph004hMoOhMgMUFmW
CcXh0U@o?@0:DC/h=QhK?BHU<B<R?R/ZHTPmQ6AE/7i[eJnLhL2[0^71]008hLNjhM39hM39hM38hLRj
hLFcgkf/h[ZR0]Z^V00EdjVDdJ6;f:2@dIj8d9^5d9V8ai60aIB0ai1l`91l`Hmi]X=`]giWZFaEJCh`
B2DQ:aXH8ALF8QLG6Q0?8ALF008_7Ad00`/31>;Qh^7Ph007hN3P6_ooo`KSknl01>?`l>GalI^4NVEE
CP9YFE<02VADCDdi<U90>TLl=eQ6@7aSDYUlJL6HP=g5[n?A_0;SdL<02>?Ibn?Qf>?Qf>?Pe^?Ib^GG
a^CB`NC>]@;K`ZX05M>jY=FcWMfcXmFaV]J]V=J[V/jXTln[TljUS/JUS/JQRknGP/BCNk63JWQGAUi0
=d8e;SXb;3Xb;C@[9CXb;002B3Pd00<m;2CRk^kSknl01n?_ka[oool6`[^i00C2^[S1^kYL@3]=<Bh2
DSHc00Y;;b`c5Q<j7a`e71Y59b=gAcJDGdbeQ6k3Wh_2X942`Z6E00S2Zj;2[ZK2[ZK2ZIg2YYW1X935
XI2nUX82^I1m01FdRGNePg:jQGJeP6fcPG6cO6f/N6R_OVR/N6FWN6FUL5jOKEbLHe28E4=A;29171TX
514V4Q4U4Q4O30XV4a400SPI5`03UHB0_kNf`[^i00O2^kTJoooo1ZnRWP04[j6M[:>O@c<]BSPb0Tll
=P0:AcD`<R0L>BTT=bLSAS4ZNdhkU65>[XIa]9B0[hf10Zn?PP08[iVA[iR?[iR?[i:4[i>5[8]k/hmo
Z8=`0ZF1K`0@XWYYXgEWYgUYXg=QX7IWX71QVViOWWAOVVmMV6mMU6EESfMFRe]9MU11AS0V?BHQ0RPO
6`039ahK8aXF:B0L008l9B400lJm^ZZNVZnRWP07[j:N7?ooo`006_ooo`KQh>001>7Qh^;Lg8QQF5@h
;`9>>3D03EE0?U4j>3PU944^;4H^9U58A81JBJAhJ<^TT]noZ^6o/N76^N76]`03hLg300CQ`k7Q`ZoG
]j7Q]Yh2f:F<01GGY8kHYHcAX8[AXHcBV8?8WHO9Uh31Rgc0SGS0S7NmSGRgP6^ULUYlB41I;2H]71TR
4Q0L4ALE2@l50@PC20h00Sd^;P0360d>jNOWhN3P00OQh>0Joooo1^?_k`04hnk^h^GUSWAYJ5960V5B
C00=J5UCGe5:C3hhETQ1FTPlJV5IVGAO_IR4eknZi=:lhm;3hmW:hmW;00;Sh]T01N?QenGIanGGa=g;
]>G7[`02gKVP01GN^ZCM^J3E/igE/icE[9G=/Y[=ZI?6WXk6XX_6Xhc6XX_4Uh2cRg6AI5M`BCe7>30m
;bLg;Rha9RHS7al`9RH00UA8@`03@C8Zk?Sghno_00OSknlJoooo1/:k^@04`[Nf_jj]DC<_E2lW0TT_
;@0=D3Db@bTW=QdJ@BHSABHNIDPoRe8o]h5]`:6<aJ>D`Z>F`ZVL`ZZO00;2[jP01L:ZX<6UU<6PSknL
R<6?O002^XUc01FmS7ZjRG>eQGBePg2`Ofb^Pfn[MfNUM6FWMF:WMfBSMF:LJUN>FdM[>S=<8a`^5a<U
3``S3Q8M1`/?0@DN20/00T`[9`03S7ijb<2o`[^i00O2^kTJoooo1ZnRWP04[ijJZYJB>RXUDSL]0THg
<P0=CCXe?bhZ=RLR@2lZABlVJU14R5A1]8=_/iV5/i65[i64[iN9[iN=00:_Vi801JnDRJbBPJb<Njf<
NJalJ`02Yg]V01F[OVnWNfJSNFZSMFBLM6:MMVBIJebDK5fHJeZHKebBJeZ;He5nEDAO?CE4:R<^8QdW
71LV71dQ5aLE4Q8R5aL00U8e;`03][6^/ZJR[j:N00N_XYhLoooo000Joooo2>7Ph00A[7adBC4XF3dh
F3dhDChlBcDa@RDRABdVBCHdE44jKDTmQ6=D_hn0ekRRhL2^hKn`hLFd00;QaK<01N76]^;1/]ZiXMV]
UmR]U002f:6<00GAW8GAWhcAX8KAVX?BW8H00/REP00>b91l`8ii_XA`^GmZYG5JO4Y1J3`]>QhK:ATH
:QPG714F5@T@50P?:1XK0P0=5P03G4I6hN3PhN3P00OQh>0Joooo2>?_k`0@ZHf3GDXmK5M>K5M>IEI@
H4m7F40iFTTlGDm9K5a?QVEEY8A_cjbIg<^ehm72hm;40n?Ib@05hmS:h]70flRag<:[gLBZ00;M^:00
1MFbV=FdW=FcUmF`V=FbV`02cJZC00k=YHk6XX_7VXC3V82cRg6AIeUnF4EB>C92=Bm2=2de;2``9BH^
92Dn=302000000=D>C7SknoSknl01n?_ka[oool8`[^i015S@Si79aiC=31C=31><c15:RHo7AY7:1m7
;BYM@3E`?c:UKUS0VHG0WXg2X9?2XiS2Z9L00/:XVP05`ZFJ_if;^I9o_9=o^Xmi00:jRG<01KF5LKF8
L;F5KkF0K;25L@02[WaX00jYN6FWLV2UKU^JK5V>GDU[?3AK<B@f5Q@[5A8]4a4P3A4K1P/I1PX_5QD2
ABPX00=X@3_2^kW2^kT01l:k^A[oool8[j:N0155<B]6;bA>>cE>>cE<>CA2<B/l9b96<RM6=2mNB3]/
@SFXLebhV8B`SWn_SH:_THR_U8@00ZnDR005[i67ZXYgYGm]ZHAbYgiZ00:WO6H01J=iIj=lI:=iIJ=c
HIaiI`02WG5O00jGKefHJ5REIUF7IEAnEdEO?SIB=RTc8Ad[8A`^81/S6a/O5QHM5AHd8al2K4e:00=d
DTb_XYj_XYh01jnRWQcoool001[oool8hN3P01S5YIiG?C]<=S9<=S9H?ceB=B]5<Bhk9RE;=C55<BmH
A3mZCD>SMVCA/I_O_JKO_jOQ`;3Q`:[Q_ZOO_JGO_joR^j?HZ93HYH`2d9J001G>Uh;>UhK?W8K@VhC@
Sg_8TH37Sgc7T7RnRW>mQ72aNF>9DT9Y?Bdi7A/U514N4ALX61LO4QL=0@PC20l[6a`00Q482@03jNOW
hN3PhN3P00OQh>0Joooo2>?_k`0H_[2YIU=<HU17HU17K5UCI4m1FDY3Dd0jHU17GTe6LV1ERfYI_iV2
h<jgi]:ji=:lhm72hm6jiM6ii]:ki=;2i<fegKjUgKVP0]JZT`0EejbFejbKe[:KeZnGeZF?cJRCcZF>
cZF;ain8aYZ4^XmgVVeIOEQ5DcXb@34X>Bh^@S@^>Bh^:QhO;b@VACHb0095=2`00nchmn?_kn?_k`07
hno_6_ooo`S2^kT067IJETPZ9d/^:D/^:EHf<dPY840V93dO74`_:TP/9e`k=8Q@?[N6KLRZUlBQS<FS
TL:PTL:PS<6NR/BQSlFSTkjDP;Z;M[Z9L`:cNVP05KJ1L;J1LKV5LK=mJ[=jIjihJ:akIJahHZE_GZ=^
Fi5RCgA0<UT`93PH52P@32@>4RlD4B8>4AD01A/62cPI5`02VHR400?8`;o2^kW2^kT01l:k^A[oool8
[j:N01QE?cU1;RQ9=Bm9=BmC?3I3<2Hn;RTm:RA;=c57=BeJ@3N=Ed>dRFnjWhf`SgbcTH:_SGj_SG^/
RgV`SgncTH6XOffWNfRWNfH2X6iO0ZEgI`0CZ7UWX71NX79PWFiOVW9MVVmJUFEFTVIEOU]:IclcCcDY
=R<N:AdG9a`M<R4L91/L6Q4B81HG?BHQ00;8_k`00k:VXZnRWZnRWP07[j:N7?ooo`006_ooo`SQh>00
6<:STVM<B58n?58n?4`h=U<k>C`S9ShY:3l]:e4n?4T`:58h;h5ODK>7L=>[U=FaVmnjX]nlYN6nYmVf
WmNdW^2jX]NQR/jCO`;@VX005LR<MlRCO/JDOm2EP<N=N<F=MlF3L[^7L[J5JjQ]Ej1WD6e1<ChN6bdL
6AlB41@83Q<83`H120@122XJ6cDQ70025P/;2^7Ph1[oool8hno_01S0/J9fHeaTEU1TEU1RDT]XE4eC
?caFACiGBD9UEU1MBci_ETRTPVc=ZXkPbK3Nc;CVdKWVd[[UdKWLbK;Mbk?Vc[GN]9cGZi<2e[2C00o=
Xhc=ZiC>Zi?FZY?>XX_?XXc>VhS7XHS4WH2jR6jaPfV0G4QG>c97>30i;RH00S0U9P0491lO8QhO@C@a
B3Xb0T8c;0[SknlJoooo2<:k^@0HO61GDcLdCC8_CC8_Bbh[CRl[>A`M?b<O@bPUCS<`AbPOH3H[WFaD
_Hec`ij7`Z:<a:6;a:B>`Ij:_9N3_if8_iJ2^7m[]X1Z0[>0J00E[WMT[X5//GiZ/gaX[7ER[gETZW1O
YGIPWfiGUUa8S5U3FS4U>aPD;QLC8`h;6`L;7@L;40453`05<aHE>a/F00:?PH4:`[^i6_ooo`R_XYh0
65a8?TTg=4Xh<TXh<TTe<4Xe;SPV9Ch/9T<b;4`i=4H`9V8n<IiaF;J:L[>AO;6EP;2@O;2COjb;NJV6
M:f=NZZ2L:=`GZEgH@:PLel05Ie^G9egI:9dHJ1aGiY[FYi[G9MYFIE^FHiUDHMHAGeF@dhd:CPS7RhR
7BDK5R0F5b8G5aDB4QDA4SPS83hW8002^[Jh2ZnRWQcoool001[oool8hN3P01S_h^UcD4]F@3iF@3iA
>cQE@T5A=2Xj8219=cI4<2iD@3i1:RMF@S]iEdVWLek4U83BXHWBYY?D[I_D[YOEZiKFY8c3S7:iOFH2
_h5V01G4RgG5Qg?5Q6k5RWG7SFjnQ6jmP6^dMf:ZMf:?FDUc>beF:R@f71TO4@lF2@lD20l<00P400P@
1`hN51Df=CL00TPb;0[Qh>0Joooo2>?_k`0Hf]oPMf5GJ5UCJ5UCI5A=IeYDGd`oCc/fGE5;FD]3JEUB
FD@lMf5CW7UTc9Qmg;NOh;fShL>]h<Rah<R^gl>[g[bRdZN;ci^10]6OP@0Ed:>=cif7cif4cjB=cZ:4
aiZ4aYN0_i1h]I1hWW=OREU5K4LlCCP`>BhV<BHV<2DU:AhO8AhO:b@U>S0[?30X0094:QT:hno_6_oo
o`S2^kT069F0ODd^:4le<Tle<T/_;58g=4<U7SPI6D/b;T8X958e<D4Q7Fa8>XIGAKQfG<NHPK^>N<6J
R;jIQKjGOl2FPKJ7LZMbGK1aF`:dMU/05K5iIjmcHJm`FjmkIjaeFZE^Gj=ZEiaUDXmUDWU5>6Tc94XR
73<F4R<>2a`72a/72QD010d011T52R`C4F@o=`02I3hd2/:k^A[oool8[j:N01Q`FDlo:b=;>SE;>SE7
=C1@?CLo:b<g925:>SA1<2Y?>S<o:RA_DD62FTRaM5blTgfXPVf_Sgj/RgN/R72_R7FPN6FCIeBQJeL2
YVmG01FRLF6NK5^NJ5FNM66JJe>EIUVBHe6;H4ioH4i[A3MP>2Y3:R@b8A`U71LP5QLP5QHJ4A8C4A8N
5AHb8AalET`00WIHCPZ_XYhLoooo000Joooo2>7Ph00Hj^_YYXEjCcDbCcDbCcXhBcLeAcLc>b@W@b/T
DCXhD3lnF48oA3<bGDU4JDi4RUQ6Xg=XUfmOZGIP]8Ic]HQa/GeZYfeESEY50YITBP0EZFM?]7QN^WmU
^G=N/6mI/ViB[g5LX6YJT5A6N40`ERLS>Q`I8Q8@5`T?3@480`070`080`076Q@E;A/L10D700;Hd]8:
hN3P6_ooo`SSknl06=oZjZ6>Q69>Af9>AfEECV9BC5iABE@n?5a7>fADCV=HDFMHDU]=AgEUFXEZFZ]j
H/2FQKRCOL^JP<nZTljYS/VLQ[f;KZAgGP:aPF@03l65JLRFNLVHO<J<ML><LLJ=K;n=M;64L:EaGHeM
B6e4>e8h<3d_9c<V9RXN7`028AhO00@P7Ahe<2]4=S8b:R82fmkN2^?_ka[oool8`[^i01RcXZESA3m5
:2E5:2E=<Bi<<2e3;2Lj6ae::Am;<2iA=c=;<2i8;BUO@SYgB3ZGFdFLKV:GKEZ^LUZ`Q6j^P6ROK5^F
GTJ6D3/2VEe201FVH4ZYKeF]K5JRI5:PHTZVHdVMI52<FD^1BCUY=2I>81/g5a<U3``M1`/E00@>00D>
00@=00@T4A0d5aJ8NGD00[f`[P[2^kTJoooo2:nRWP04VH:3BC8/@2hZ@2hZ0T/h<P0B@38[>BDTC3<X
AcHbD3dhAC@_B3H_G4HmMT`mTEm8SVYOS6YHXViHXgiYXGQSSVEEQeU3O50m0Y5M@`0?Vem;W6aCX6EA
TF1@T5i7Uf19Sf1>OEI9MDTjGSP[BBTS=B8M9a`G8AHG6Q4B00<D4A800bTO6cPS8;V^[002Zi^G2ZnR
WQcoool001[oool9hN3P01ONc=ERAT5RAT5=>cU>?Sa>>CLZ7AXj:b]D?c]E@T5RCT]OC4UMC4ITDT][
D4I^ASiZ@CMS@CahASV7FdajD4M/B4AgASX00W93<00ENTPhSUM6U5m9WEe5Uf5;QTlkR5A6Qd/mKd<f
CbPTARXV91<@7Q4?5@T?30080`070P0781@E5PhE?dA69aXK00cQh>0Joooo2N?_k`0GdM3DK5Y?K5Y?
H5A=HEI@HE5;@SPaEDI2J5Q?IeYDLVENK61JJf5HMFQNPFUJQF9FPF1@Of1EUVMCXWaWTViPQVEKSV9@
00::H4P05IAVDJUfGZimHKAkGZalHi]ZDZ5aGYaXEHEOCVM3>Um5?3h_9cT^9S0U9BPN7b0M7QlM7SP`
:c0Z:deDD3X[8`0<hno_6_ooo`W2^kT05hUdM4HZ94HZ94/a;TTb;dL/:RTE4dDX9E@g<U8g=5To>e@j
=eLn=f13>fQ3=fPm=VDk;VLl=Gi6=HEHAVi4?6]0>7@m;P02LCdX00mj@C:@ECjBEcn@DS^<E41m@c63
CCii@C=U>2a97a]48QhU3P/S3P/K1PXD00@00Pd01004:14@7@`@FT4mLUmL3<:k^A[oool9[j:N01MU
DDTk:R<k:R=:>3=6>394<RdY81a7<RaB?CM@?CMD@Sa>?3ME@SUMACaRACQQ@CYO@3=T@CUiBcYlFDMS
ASeUA3U]@C800V]3;P0?M4DgREQ1REM1PU8mP5=0LdDdNTm1KT<fG3``@bPR@R/V9Q/F9Q`G7aHF6A4A
008C4A8012`O6b8J6fI;A9>8Q@b_XYhLoooo000Joooo2N7Ph00Gl>_[QUmNQUmNCSPfD3XhCCXhDCXh
@3@dD3lnHDe:F490FTA1GShkK4DkIT0dEchiARd[D3LcAB@RECPdG3hiC3@aA2DS0099:bP034TU84dT
8Ehg:V0i:e`f:ETY958U8D`X94XU8S4M6R0B41X;4@8D20l01`@020<01b0D820D5T4`;`HC79F0O@0<
hN3P6_ooo`WSknl05mkXjHI^JXI^JV5BBfEECV5DCUmABe5;AV=HDG9UGVaLEG5PF7EJDgmSDgQMC6aJ
D5m8@FYBBF10>G9FC7AJD6A?B612>`02ITU000aV@SQ]@cYmF4AlEd=iED9eB3a_ACYYASaV@SU;>S4m
;bLf:2P2<2DU00LQ7QlP7Ahh<3Dh<2]BAd8F5QJCOgL03>?_ka[oool9`[^i01NTU9QA<C1A<C19;R]<
<Bi:<2e3:RQ1:RQA=c=K@3aC=c=H>cMN=c5X?c9J=b]@=C159B5C<Ba77Q]K=S1G=Bm;;2Q981`00TdX
8P03CB4KEb@MHcHV009P<b@045PT7UDT7DhT7T/Q730H52L@31l831`72Q/72Ph010d012PA6RPA3chW
9Ee3@i9aJ`c2^kTJoooo2JnRWP0GQ6m`?BTU?BTUASD`BCPbAcHa?S0[@S<^D3dhEd<mCS/fE40jFSde
Hd@fE3``BcXd@bdWDCPaARPSFClfDSXcB3<]B2XT009;<BT034/[8eH_9Uln;E/j:e`j:e<]9E8^9T/]
9TP[930S7BXM628G5`8P5QH01a<A4A@A4R`O8b`O6Sh_;8EZIi1cK@0<[j:N7?ooo`006_ooo`WQh>00
5nCUhm[7cM[7cE/o?Ddh=U4n?4hi=UQ7AD/e<EU5@e4i=E<o?Em;@ePo?5Xk=e<h=4Tc<4`h=chV:SX[
:T0T8T4T8S8L6P02:1TH00d_6QTj81hm7ahd6aTc6aTc71Tm81hb6AP_6APR4Q0M4@lE2@lC20l00P@0
200540L>9QhP>1lP928SBTA400gQh>0Joooo2N?_k`0Gh^g]a/;8a/;8IE9;HE9;IEI@HE9;JUiHH4m7
LF9KIUA;JEYCL65GK5I@L5A;J599G4a5Ge5;DT0oDdI0FD0iFD4iBcPa0093=Rl03DXg<5<k=EHk=Dhh
<4li<4lh<5Hk=D/e;dTe;c`_9cL^9S0U9BhT9@028AhO00D[92Do>CI<>CHR6Q93>S803N?_ka[oool9
`[^i01Nl/;=oIFQoIFQ19B9:;R]><c19;BYG?CU5:RIM@3a9;BUC=cAN?CEC<BiD;bY>;RY2:2A><2hg
6aho:2=27Q]17a`c5a@00RdF4`0;=1HC?a/H@1`H=QPC>1PD=aLC@A/H<aDB<aDC9@l<8Ph;008K1PX2
3P0400DI1@Xb71`f61QB=c9Q@ch03L:k^A[oool9[j:N01NVU9EL@SmL@Slh9b97=C1<>CA6=2mE@Sa2
<B]KAT15<beA?CQK@3M>=S5?=Be:=Blo;bU?>3<d92=0<R]1:2<o:B@c8Qd00RlR7P0;=R8M@2HQ@2LQ
=R@M>B@N=b<M@BHQ<b4L=28M9Q`G9A`G008O5QH2514B00DN5AHh:2Hg8b1]EU1bEe003JnRWQcoool0
01[oool:hN3P0^cTiP0BREQDDchlDChlDC/h@34^H4]7E4E2ETA1@c0^ECP`CC0[BC<`AS8_=B@_>bl]
@BH[>AlP<1`X0RPI608N4@l04b8H5b@H5bLI624B41H93adA3bXH5b8B41H93ahA3a/@5QD93`@021<8
3a`E5BTP8BhK73Pe=CP^;`0>hN3P6_ooo`[Sknl2gnOX01::Jf=TEU1UEU1TE4eICDIdI5eUFeEWFeAJ
Bd=^EDQTCD=QD4QMCDI>@4EGBdAH@T5@>cI9>3h2@cD_0ST^9P0C?C@^?c@^@cD_?BlW<bHV>RhVAC@^
?BlW<bHV>BhV=Bd/<2DU8AhO;R@U=2l[?CPeA3Hb<BPP<B0H00kSknlJoooo2/:k^@:VUIH055Da;D/c
<4hc<4/_;4</:5/n>U<j=TTb;d@X95`d:DHX94T]:DHZ9cDN9T@/9SdM8C/L6C8G7bdE4R`E4P8S3P/0
4bTD4R/D4RhE4bH?31h72bD?2c8E4RD?31h72b@?2b4=4A/62Ph011/62R4@3bdI6C<G5UHh<eHb;@0>
`[^i6_ooo`Z_XYh2Qg5_01A0:bE8>CA<>CA7=C12=BiF@C]A?cU3=C13<2YL?2m1<2Y7=Bi4<Rdd:2]5
=Bdj9RLl9b8b8RH_8Q`^8A`29Q`G01</8Ad^8A``8QdX71LR5aLY7ALe8QdW71LR5aLW71LU6a/O5QHD
4A8O5QHU7QXa928f8b1[CdU[C4D03ZnRWQcoool001[oool:hN3P0^KXiP0D_IfKEcXhE3lmDC/hDchl
AC/iET4oDCPd@RdZ?2TW>AdJ?bd[>B<X>B<W:aTJ<1`W7a8I6@X@7Q4I714G0QH9400B6Q0F5@T?714G
5PT@6a0F7aHF6Q0F5`T@10480`07104710486@lF5Pl>4`P>9a4?>S/l=b//3n7Ph1[oool:hno_0^7[
k00D/j6PIU5:JEUCI5A=I5I@FUA>KEaFIUA;FDQ1EdDnDcXaEdU2DClnD3lnACHaBCPn>bl`=RLW>Bh`
=bh^0S4V9P08=Rd/<BHV>2h^<BHV=Bd/>34/=Rd/<bHV128N7`06=2//<2XU;b@V@bhW>SP`<R8I3n?_
ka[oool:`[^i0[VZ[00DL4m?B2TWDSHcBbl/Bc8_Ac8_EcTeBBhY@2DQ@R@P>1PDA2TU>AdO>1dP<1HD
<aLP9PlB80P<9@lC8`hA0Q`72`0B8PhA7@L;8`lB70L;8@dA9A8@8PdA7@L;3P043`053`453`0580`A
7@/:6`H;<Q0<GTA0FCTd3l:k^A[oool:[j:N0Z6;S00DDCHc@BhZCc`fAcD`B3PbASTdE3liAC@^?RdX
@bhW=R<MAC<]>2LV=bLW<R<N<b<X:1dL8aLH:1dM9Q`L0R0F5P0B9QdL8ALG9adM81HF9A/K:AlK9Q/K
8AHF514B5A4B5A8B5A4B91/K8QXF81HG=AhHLeUDKeE>3jnRWQcoool001[oool<hN3P01CgmoNBN7=;
=35?>SQ<?C]@@3iDAD=B?3m0928l9bHZ6aTZ5aLZ71T]6ATH2Q4F2@lN4ATK4ALC20lK41L25@T@018I
3aHE2A0]6a`50@PH3aHQ5aLM4QL50@P400P:00LF3QDG3aHF3QDa7Ahl:R8o?CXG2POHd]8?hN3P6_oo
o`cSknl05=SShX9fL5]<AFEECV9GD6EIDfQMEfADDUDn=e93?48f<4Dd;TDh<DLe<3@W:3<V9cT^<3D/
;BhT9CH];P8`9BH04S@[;30U9T@f<R8N7c@/;C/c;SL^;R8N7b4N7bHM7S0Z:blZ:c0Z:dLh<dY1=cm9
AbPK5=_NgPoSknlJoooo3<:k^@0DW8N4D38`?bDRCC4^Bc@aC3DbDcTfB2d_?1/H?24O:Q@B<QDC;ALE
<QDD7PP<7`P<90lC80dA6`H:8PhB0Q/62`0B8@dA6`H;=1PF3@048PdB9a<A8PhA3P053P044`047@`@
70/?7P`@=APF=QlI@B`ZJ5QK_K2^3l:k^A[oool<[j:N01AiGEDj91lj:bI;>399>cE9>SEB?SU3<S4j
9B0l:bH[81`e8ah^8ahd8QhQ5aLS5aPW71dT6a/O5QHU71d27aHF00LU6a`O5QHg920B414W71dZ8A`T
6a`00Q@A4P096A4B8QXK81TJ8aXK=b@O=RTRB3@_S8J<Zi^G00n_XYhLoooo000Joooo3N7Ph00@moOg
Tg=^CShkAc8_E4A2EDE3GdU6A3@c@Bd[<Q/W7A4G:aPG7A4G9APG81HF6Q0F0Q@83`0;4`L>50P?50P?
4`L>8ALG60lF@cM2;blf:APU5PT@714G008L5AH01aP?5CDX:C@T934M7U8i=D@i<heYF@0@hN3P6_oo
o`gSknl04=SShX9cK5]BC5e=AFQNF6MMEfmPFUM<AUI6?dPf?3L^;DDd;SL^;Shd;CPa;3@[;08`9BH0
2blT9S0U9S0U9RlT9SXb;S@[;5E=D3i1@Chb>34V9SD/;@02=2l[00Lb:R]9@Ce5?3Q7>3=SDDU6=2:;
ID/04>?_ka[oool=`[^i012LQhA=;ba0;2U5:BID?3QB>CID>CLk9B=1924^51`R3Q4`514R3Q4X4a4T
4A0O31426`L;01@K1P/K1`/K1`/K1P/V4a4R3A4m:c<]7b0Y41PK1`XP3A4P40lP3`lN2a0i8R4`6QXe
5aII=2a[B3V<H4l@`[^i6_ooo`f_XYh047UMECLR7C/`;4<a:e91?50n>Dll>3P[9d0]:2dO8bDL6c8Q
72DL72XP6bLN6b<J6`HP5QL042TP72LK73/b=RlX92XL7alF5R<K6b@M6R@L6R8J6c//:30T8SLS7e`l
<WmQDXeYFQ2_XYhLoooo000Joooo3N7Ph00@moOgTg=^CShkAc8_E4A2EDE3GdU6A3@c@Bd[<Q/W7A4G
:aPG7A4G9APG81HF6Q0F0Q@83`0;4`L>50P?50P?4`L>8ALG60lF@cM2;blf:APU5PT@714G008L5AH0
1aP?5CDX:C@T934M7U8i=D@i<heYF@0@hN3P6_ooo`gSknl04=SShX9cK5]BC5e=AFQNF6MMEfmPFUM<
AUI6?dPf?3L^;DDd;SL^;Shd;CPa;3@[;08`9BH02blT9S0U9S0U9RlT9SXb;S@[;5E=D3i1@Chb>34V
9SD/;@02=2l[00Lb:R]9@Ce5?3Q7>3=SDDU6=2:;ID/04>?_ka[oool=`[^i012LQhA=;ba0;2U5:BID
?3QB>CID>CLk9B=1924^51`R3Q4`514R3Q4X4a4T4A0O31426`L;01@K1P/K1`/K1`/K1P/V4a4R3A4m
:c<]7b0Y41PK1`XP3A4P40lP3`lN2a0i8R4`6QXe5aII=2a[B3V<H4l@`[^i6_ooo`f_XYh047UMECLR
7C/`;4<a:e91?50n>Dll>3P[9d0]:2dO8bDL6c8Q72DL72XP6bLN6b<J6`HP5QL042TP72LK73/b=RlX
92XL7alF5R<K6b@M6R@L6R8J6c//:30T8SLS7e`l<WmQDXeYFQ2_XYhLoooo000Joooo3^7Ph00Bn?Wj
TfmZFdQ6A30^DD4nGde:HDY7B38X@B/X9aTI6Q0G5`T?6Q0?714G5PT?50P?6@lF4`P?0QT?5P0@4`P?
4PL>=c<g<B<bDdQ?Fdm=Ac<k?cDg>B/[9ATH=2DS<28SCC/iESXd=c4bM55:4N7Ph1[oool>hno_01;F
h>22KfUTG5EIBd=YGEIcIEi]GeUIBSeDA3hn<c0f;Bhc9RHf;BHg;Rha9RH`9BHd:b`^92D2=2//010^
92D_9BI=BdU7?DIUHVEQGee?ADU7ATA7@3`l<be9?SU7?CUPE4ePCdHb:21`C3/Ahno_6_ooo`k2^kT0
4Yb3Odh^;4Pb;d8X958j=Ui2?Dlf<d4U7CTP7bHB4R8=4Ad72b8>2b<>4Q`72a/72b0<4AX62P8P3140
41X62Q`72c`];SDM:eA2@TPd=S@N9CLU9C4L72DB43DM73HN7D/a;Th[9ETi=7aBAa72^kTJoooo3ZnR
WP0>NUQ?=b8M@C@_@C0ZCd0jFdDoB3Td?bdT=bPV9ahL9Q/L8AHG9QdG9Q`M0R0F5`0D91/K7QDF91/K
91/K7QDF81LG?SHd=bPbE4Q2@SDe<2@W>2`Z<2DR9QhJ=bPT>BTUBSPcC30YKe5;Pf9H4JnRWQcoool0
01[oool>hN3P01;Og]oooon<HUIVD4a@?3YGBDMVDDeSD4e5:bPn:2Lo<Ble:b/W5aLR5aHL4ALJ41HC
20lD20l27aDR010L4APP5QHH3QDl<c52<SHY61d`81dZ71/W5a`b71Xb92=6;RIE@cYSGe]VAT3QfMTA
hN3P6_ooo`kSknl04^C`l>7[jX9YGFmTGEmCCFYRG7IXHG5TGEM4>e52?4i7@TA0?C``;3Xb;3D/;C@[
;2hT9C0U9P8i<CL043D/;CPa;3@/;EM@BUa>CTHf=Tho=TPj=4@e=D`h<DXo>EY8?69JCe]LDFY6=>?W
iQ7SknlJoooo3/:k^@0BaKjmXHV6DBdWDC/iAbl/FD4mG44mES/f>QhK>AlM>RDT;A`M9a0?9A8A80`A
7``@6`H:6`L;0RHB6`0@80`@914@8`lC@Rh/C2l`;ADH=QdI<a/H;1@G=1LD>B0MABHNFcddHTU7P5M9
`[Fd4L:k^A[oool>[j:N00jcYj=mG5@n9Am9?3Q4=C1HASmF@ce@?3Dg9R4g:2@i;BX]9B<Y71TW7a/2
8aXK01@O5QHP5QLZ82@Z82@S6QXX7Q/W7Qm3=S9=>3H]8B4g:28e9b8]820d8adk:bI5;bIOA3YWD4j=
KEj_Wi/A[j:N7?ooo`006_oooa3Qh>004?WkoHIVFU<j=E8n?6YHEFiNG6]EDClY:3DQ9T4T8TLf=3X/
:QhB61@83bLM:BLL:08_9bL03b/P;C`b=2HJ9C`g>TPg>U4j>3`_<3//:Sla<4<k>D<b<5I8@Da3?8YX
E/Nka00BhN3P6_oooa3Sknl04=OQggeYG6ECBfYJE7a`JGYaJg=VGe51>dlm?5U1>EU?BD]3?CH];C0U
9Slh?C`e>`93?c/03d4i@De8AC/c>51>C5U?CEmABTY4@D]3?De7@Te<B556@EmKDD8h9giI@<S4c00B
hno_6_oooa32^kT049UmMU0^9dHZ9eHj=VQ>BF5;Ae8h=3LM6cTM7d4O6d</:C<P7B0<41/72b`H8BPE
708b7ah03bXF8ChY9R8@6DXe<D8Z:d8Y9cHR8SDP7CPT8cl[:3/R8U/l<Uhn<ge<?k:NX`0B`[^i6_oo
oa2_XYh047E@@ShU7T0_:eE0>VE@BU]:A4Tf<C@U8CXX9clY8d4c;S8X928I6R0F5blT:2XP8`8d:RH0
3b/Q9d4b;2<L850o=cl`;cd^:SHZ9c@X93P[:D0b;CTZ9em1=Fe@AWaCBJB@T00B[j:N7?ooo`006_oo
oa7Qh>003oWhnYf?R61=Be<o?FE=BVeRJ75NG5e=BeM=CdXd>4Tn@UE<E4a7Bc`_=3hc@`02@38k00iD
BU54>3aE?CTo=SYRAT9G>CQG>2mD?SaHACiSCdEX@C@n?Cj=Je[QfMTChN3P6_oooa7Sknl03mORhG5_
GEmFD6UJDgi[I81kNgQ]IUiHE5UEEEQ9AeaFE5iKFTQ;BdE0@Dm9E002DdY<00iNG5aDCDaSDdeDCdmc
GeMWDTeWDTESEU1VFU5[HeQ`F4U9?SF;I4[SinHChno_6_oooa72^kT03iV4ODTY73hV8e<g=6A8@fAD
Ee`o>TL`<4H_<3lS9D8b<TPd>3LV9BlK83PV=002@2PZ00i:>3i2:RQ4:bY9<cAF=cA?;Ba?;RI:<S1D
>35P@cQ=;bIdEDb<G4_2]K@C`[^i6_oooa6_XYh03gEIC3@E1SDU7e4m>61<AEiCDe@m=48b<4<b;c`Z
:3lh=4Df=cHY92hR9CL^=P02@34]00i7?412<BXn;be=?CU@>SI<=31<=B]6>3AC?CEPAc]4<RZ=KV:=
I5J_Wi/C[j:N7?ooo`006_oooa;Qh>003^SYim_?f7iWKF1<BUQ<DFaZLg][K7MUHW]/IfMIG5iHF6eM
HfeEDE]9A`9;>T<034Da;eE0@UU5@e4n?6A2>VY6?V]9@W1@Af=1>G=MFiQdIUY4?1GQh>0Joooo4^?_
k`0>h>[[/JfeLVQUK61JK6EVOh24QWagQGYcPgafJFAUIFQWNW=hNVaTJ5eK0UaAE`0<GTi8KEeLJeeG
IEI@MEa@MEeCM5eDMF9GKUU=QWI/QEm4ECXX5N?_ka[ooolB`[^i00jfYZUmFei6:bYC>SAC@dYcGUm[
DTmYDTaRC4YC?d=E@dISCE1G?S]A>C/2A2/c00a8;BaC=cQD>CI><c1P=biN>39L>C9O?cUG<b]jFE9i
Ac1/@cPE`[^i6_oooa:_XYh03Yf7Qehj=CDQ74hl=4i7C79NFF9>BF9@B5Q6@de0@E=4AEi=C4dl>4dm
?P91<C@034Lf<Tll>E4n>D`i=5dk<UTl=ELm=5U2>e8g;WQLE798<GQGC1F_XYhLoooo000Joooo00?Q
g]kQg]oQh>004N7Ph00<nOSfT8FAR7efK6AeRG^0SH>9RWamPfiZP6e/OfQUPf]/LemN0WQRGP0;JeYL
HE1;HeABLf1NIeI@LEA;JD<oN6EPUGafOV5HSGUm01KQh>0Joooo00?SlO3Sl?3Sknl04N?_k`0<en;S
HEMNFEQ:K6ifUY6@RXb9Q8=mQh1jRh>0S7igQg]gM6eX0WQ_J@0;If=SHUeEJfAOM6eXKfEMP6IJO5]B
R7MWN5]8GSLWRgMg01KSknlJoooo00?2_K_2_[g2^kT04L:k^@0<VHB7C28U@2<NCce4P6UVMVETJ5=;
K5EAKUMFL5E@K51?GdM20UU2@@0;E3/lBSDaFD0oGdE2F3/eJ40hGSD`RVILJSHSEaT@S6][01K2^kTJ
oooo00>_YJ6_Yj>_XYh04JnRWP0<MEUI@1HA=1PCASPhNFEMKUmKGD/nHe1:I5A?Ie9<Hda9FDHn0Tho
?00;Cc/hA3H`ED90FD@nDS/cHT8iEcPbSVaRHC4JDaX@SG1]01J_XYhLoooo000Joooo00?Qf]_QfMWQ
h>004n7Ph00:i>GSjN3UQ8>EX9>C_kK6[:2WZ9:@RWMoOg1gQfa^0XQ/I`09NfMTRFaYMV1JLeQ>Of5F
LV]RTXImHeQE]jF^01SQh>0Joooo00?Si^KSinKSknl04n?_k`0:h^g]a/WDIfAfSX63[JZfU8^9Sh9d
RH1lSh>0V8=n0YN3O009SWmhUh=kQGM]RG=VTWa^LF]KH5I4D3`e]jZb01SSknlJoooo00?2/[72]KC2
^kT04l:k^@0:_;2cSgJ3Gca9Oe]RRF]dOUQ?JdPnIDa7Me]JNUQA0WQIE009MUQCMeQAJe19Kda1LUA9
OfEKBAhBG2d/YhfB01S2^kTJoooo00>_VYJ_Wi^_XYh04jnRWP0:YYBEKe9LFcDiMU9HMUEGL4ThF3P/
Ed<iL5QCLEA90ViFC`09KeM@JeA;I4m7JDe1J5=7QfeT?142HSDcWXF501R_XYhLoooo000Joooo6^7P
h006i>GRd<_Kj>;Oe<SDVIBRViNY0Y:9Q`07TXJ4TXN5U8V7SXF4QWE]JfAJhMWI01[Qh>0Joooo6^?_
k`06h^g^d]CVh>;S]K74MWF7MW>30VeWGP07KF9IKF5HK61HHUM=FTLcIea:hnOV01[SknlJoooo6/:k
^@06_;2f^:Ja]Z6WRVanHdAGH3e60U/e;P07FcD]Fc4ZF2hWD28GBQX:MeM;`[Fd01[2^kTJoooo6ZnR
WP06YYBJZ9>FWH>8L55MF3Q4E2h]0U4Y7P07DB/PDBLLC28GAAH6@Q<0Of5F[inK01Z_XYhLoooo003o
ooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00A_ooo`<0001Ioooo0`0005[oool3
0000F_ooo`<0000aoooo0019oooo00<0003oooooool0FOooo`030000oooooooo05[oool00`000?oo
ooooo`1Joooo00<0003oooooool0;_ooo`00:?ooo`@00004oooo00<0003oooooool00_ooo`800004
oooo100000;oool300000oooo`<00003oooo0P0003Goool400000_ooo`<00003oooo100000?oool4
00000_ooo`<00003oooo0`0000?oool20000=oooo`800003oooo1@0000;oool200001?ooo`@00002
oooo0`0000?oool300000oooo`80000goooo0P0000Coool200001?ooo`800004oooo100000;oool3
00000oooo`<00003oooo0P0002_oool002Soool00`000?ooooooo`05oooo00D0003oooooooooool0
00000_ooo`040000oooooooo00000_ooo`040000oooooooo00001Oooo`040000oooooooo0000>_oo
o`030000oooooooo00Goool01@000?ooooooooooo`000005oooo00@0003oooooool00002oooo00<0
003oooooool00oooo`040000oooooooo0000>oooo`040000oooooooo00001?ooo`050000oooooooo
oooo000000;oool010000?ooooooo`0000;oool010000?ooooooo`0000Goool010000?ooooooo`00
03_oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool0
10000?ooooooo`0000;oool00`000?ooooooo`03oooo00@0003oooooool0000`oooo000Yoooo00<0
003oooooool01?ooo`050000oooooooooooo000000;oool010000?ooooooo`0000;oool00`000?oo
ooooo`0400000_ooo`040000oooooooo0000>oooo`030000oooooooo00?oool300000oooo`030000
oooooooo00;oool010000?ooooooo`0000;oool400000_ooo`040000oooooooo0000?Oooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00@0003oooooool00002oooo00<0003oooooool01000
00;oool010000?ooooooo`0003goool00`000?ooooooo`03oooo00D0003oooooooooool000000_oo
o`040000oooooooo00000_ooo`030000oooooooo00@00002oooo00@0003oooooool0000`oooo000Z
oooo00<0003oooooool01?ooo`040000oooooooo00000_ooo`040000oooooooooooo0`0000?oool2
00001?ooo`@0000koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`02oooo0`0000?oool200001?ooo`@0000moooo00<0003oooooool00_ooo`030000oooooooo
00;oool200001?ooo`<00003oooo0P0000Coool40000?Oooo`030000oooooooo00?oool010000?oo
ooooooooo`800004oooo0`0000?oool200001?ooo`@0000_oooo000Xoooo00@0003oooooool00002
oooo00@0003oooooool00002oooo00@0003oooooool00005oooo00<0003oooooool0A?ooo`040000
oooooooo00000_ooo`040000oooooooo00000_ooo`040000oooooooo00001Oooo`030000oooooooo
04Goool010000?ooooooo`0000Coool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000
oooooooo04Goool010000?ooooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`00
00Goool00`000?ooooooo`0joooo000Yoooo0P0000?oool400000oooo`800005oooo0P0004Ooool2
00001?ooo`<00003oooo0P0000Goool20000B?ooo`800004oooo0P0000Coool300001?ooo`800018
oooo0P0000Coool200001?ooo`800005oooo0P0003coool00?oooonAoooo003oooooTOooo`00oooo
oi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooo
oi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo000Joooo67V:R`06NH=k
MG=WNGM[NGQ`NGYbNGQ`17UkL`07NGYbNGM]NGEXMG5SM6YKLFAGL69D00A/Ge800faMCf]JBfQJB`02
J5Y;00=XHU]iRX]iRX/00WV:R`9iRHX00gV6QgV:RgV:R`07NHZ;6_oooaR7ViH01XVNUX64M8N9N8N8
O8N>PHN8O0B7SH401hN>PHN9OHV:N8>5M8F1KgmgIh5gIP04NW=S00IjLV9lKUifKUafKUifKUa]GD/4
Qi^F0XNLV003QiFAQi^FQi^F00N7ViHJoooo69n]Z@06XJfRUi1lWiF1WiF7Wi^<WiF719nKS@07Wi^<
WiF6XIJ0VY1jVhUcU7iZUWiY00B>NFD01XihHi1cGHUcG8UcGHUcG81WD`BO[JT2WjjY00>OYZ:O[JVO
[JT01in]ZA[ooolH_lG100K1aKZfY8noZYFoZY^o/J6oZY/5_k6Q00JoZY[1Zi>iY8fkW8BcT7ZeSgT4
[8Yd00J/RG:^Q6bVQ6ZVQ6bVQ6ZJMEl4_lG10[o6`P03_kfj_lG1_lG100NoaL4Loooo000Joooo00Ii
RX]iQ8EiQHIiRX]iQ8EiQHH:NHZ;00=iQ8EiQHIiRX/01GV:R`08OXV1NWQaNGMZNGQ/NGYbNGQ`NG]c
NGIX0WA/F`08KfaKKfQKKV9FIEeBIEa@IU]?IUU<Iea?0VaODP9/FTd01F]JD6QJCVQJBfQaK6QgM`04
NHZ;0WV?T003NH^<NHZ;NHZ;00MiRX/Joooo00J7ViJ7Ui>7UI67ViJ7Ui>7UI4:Qi^F00>7Ui>7UI67
ViH01HNKUP08S:>LQXQlQhUhQhQhQhj1QhQlQhf1QhUi0X>1KP08OX5^OWe^P7UZMWAUMWATMFmPMfmP
MFmP0WYcH`9jKel01Ga^HWI^GgI^GWInLFecJP04Qi^F0XNPV`03QiZFQi^FQi^F00N7ViHJoooo00JO
[JVOZJFOZ:BO[JVOZJFOZ:@:WjfY00>OZJFOZ:BO[JT01In]Z@08Y;:XW9>3WiF1WiF3Wi^<WiF7Wi^=
WiR50Yb@NP08Ui1jUhYhVHIbSh1/SgiYS7MTSWIRRWIR0XiiI@:>MF401I1cHXUcGXUcGHV3LX1iK@04
WjfY0Yna[@03WjZVWjfYWjfY00NO[JTJoooo00JoaL6o`kno`KjoaL6o`kno`Kh:_lG100>o`kno`Kjo
aL401Ko5`@08`lVo^ZJD_jZD_jZH_k6Q_jZK_k6Q_jjK0[jYT`08^ZVC^Z>?_9n8/YR1/YAl[H]e[hYc
ZHQb0Zb:M0:/Qg001Jj4L:J4JjJ4K:J?NYZ2L@04_lG10[o8a003_l2m_lG1_lG100NoaL4Loooo000J
oooo00YiRX]iSi1iQHIiQHIiSi1iRhaiRX]iQ8EiQHIiQ8D2NHF617V:R`03NHn@NH^<NHZ;00EiRX/0
27AnMgAbHWUgKgUbK7UkLgUgKgUaJWA`IP9TK6@0261SFV]HDVYECF]ODfaWFVaXFW5VF6QJC@9RETX0
1f9JCF9JB6MJBfQJCFQJD7f1OWfAT`06NHZ;00=iQ8EiQHIiRX/01gV:Ra[oool02XNKUXNPVhNFTXNE
THNPVhNJUXNKUXNGThNETHNGT`:7UI44Qi^F00>7X9^7VYJ7ViH01HNKUP08PiZCPHA`QhUmQhAhQhf1
QhUmQhEiPhIj0WR1M@04KgQ]NW1UNfaQNgAT0WYkJP0;OgYYMViOLV]LLV]LLVmOLViKMfiLMViOMViR
Q7i_Q9NB00J7ViH00hNGThNETHNKUP07Qi^F6_ooo`0:WjfYWk6]WjNSWjRTWk6]WjZVWjfYWjVUWjRT
WjVU0YnXY0BO[JT00ina[InZYYn]Z@05WjfY00RLZInJTWZOUHNOTX:OVhfOUHNOU8FLU8@2Thim00R9
Q7>BO6bCN6JAOFV>PVf>P6bCOfZ9Lel2Qg9N00N7MF67Le^;Lef9Len9Lf:DPVnDWYT01Yn]Z@03WjVU
WjRTWjfY00NO[JTJoooo00ZoaL6ob<Bo_[^o`Kjob<Bo`;foaL6o`kno`Kjo`kl2_l6n1;o5`@03_lS4
_l2m_lG100FoaL402;k3^;^XSknZVknXUKnaXKnZVkn/W;j/VP:hYI402:fLQkBEPKJ@N[6AO:bCO:b?
NZn>N:J4KP:WQFl01jN7L:N4JZZ4K:J4KZJ4L:V8L:VXXP06_lG100>o`kno`KjoaL401ko5`Acoool0
01[oool2NHZ;00=iRHYiQXMiRX/00WV:R`03NHn@NH^<NHn@009iRh`<NHZ;00QnPg]jLfeiMg1iMfmi
LV]iMViiMfUnNg<2Sh1i00R2P7>0N760K6=gGe9gFeAgFeMaDdm[ETd3J5Y=00EXFU1]H5=/GU1XFTeX
HU/01gV:R`03NHn@NH^<NHZ;00MiRX/Joooo0XNKUP03QibHQiFAQi^F00:7ViH00hNPVhNJUXNPV`02
QiZF38NKUP08S9jFQXAhQhUlQhUmQhAiQhUmQhUiS8j10YjBQ@08S9:4RheoSgmeQ7=SQ6mTQ6mWP6]R
O6]O0gI^G`05MViRNW9RNg9RMViOKEe;00N7ViH00hNPVhNJUXNKUP07Qi^F6_ooo`:O[JT00in^ZInV
XYn]Z@02WjfY00>O/JfOZZJO/Jd00YnZYPbO[JT02:B]XYb@P9nEQInEQinBQ9nHRInEPjBIRP:`Vh/0
29^JR9jBPZ:3MIMiIIMgJ9MgJY=aI91aH@>9Lel01HUcHXagHXefHXUcGh1WD`07WjfY00>O/JfOZZJO
[JT01in]ZA[oool2_lG100>oa/:o_KZoaL400[o5`@03_lS4_l2m_lS400:o`;d<_lG100S3aKZjY96o
ZYNoZY^oZ9Vo[YnoZYS3[Ih2bJbI00R`ZINhXHjnTX:aRWBaRgVaRgZ`QWF^Q703YXA^00FVQ72WQfnY
QW2VQ6jJMEl01ko5`@03_lS4_l2m_lG100NoaL4Loooo000Joooo0WV:R`03NHn@NH^<NHZ;01=iRX/0
17V9PGUhIWUgIGUgJ`9iMfl057UgLgUlMGV1N7V1N7ioNWEoK7UdJW]aIW]bHGEVFW]bHgYOEW9ACG9Q
GVaQEVeJCFeGBf]JCFeUF6e/I15iRX/Joooo0XNKUP03Qj2KQiZFQi^F01>7ViH018NSW8N8LhN9M8N9
N0:7RGd058N9PXN=P8NBQHNBQHbBRX>CO8V8O8R3MXR3KhAjJhR3LXYdJ7mVGgmbJg]fJ7Y^GgY[G7a_
GgYfIg=XEA67ViHJoooo0Yn]Z@03Wk6]WjZVWjfY01>O[JT019nbZ9nCO9nEOinEP`:OUHL059nERinI
RInMSYnMSZBMTYZLPZ6?PIb9N9b7LIUoKIb8M9aeIi1[Gi1gK8eiIhacGha`GI1eHHakJ8E`Fa6O[JTJ
oooo0[o5`@03_lS4_l2m_lG101>oaL401;o9_knVS[nZUKnZV0:oZY/05;nZW[n]V[n`X;n`X<>`XkV/
Tl6NTKNHQ;NDO[J>OKREP[J3Lj]nKZ^7N:V8LjN4KZN2K:j7L:N:MIikIA6oaL4Loooo000Joooo67V:
R`08NHEnNGMZNGM`NGMZNGM[NGM_NGadNGM_0WUaJP0@NG]cOWmjOhEfNW]ZMFeTNW1RLFAGMFQLLFQH
K5Q8LFALJ65FHUY=IeY=LgAcMgmo27V:R`03NHB5NHF6NHZ;00IiRX/Joooo68NKUP03QinHQhUhQhUl
00:7RGP00hN9OHN=PHN9O@02QhEi0127SH6<TXZ<UhB8SG^3P7>8Q7=oMfN5P6j0NVUjJUUoMfafMVQb
KUmgKUmlO7EoOgH8Qi^F00>7Ui>7UI67ViH01XNKUQ[ooolHWjfY00RO[ZBOUH6OUHFOUH6OUH>OUHNO
VH^OUHL2WiB5012OVhfTWI:QX8VNTgnJR7NNRgJDOFZLQW6CO6V>KUZCOW69NFN7Len;Len=PGJBQgX8
WjfY00>OZJFOZ:BO[JT01Yn]ZA[ooolH_lG100Roa[foZYBoZYNoZYBoZYRoZY^o[IjoZY/2_jbL012o
/J73/:>m[iRlXXjiVHNlW8JcSGZlUh6`R7F/OVZ_T86VR7>WQ6jZQ6jUSGj[TX08_lG100>o`kno`Kjo
aL401[o5`Acoool001[ooolGNHZ;00UYGEAYHEUiMg1iMfYiMfUiMf]iO7AiMfmiNg<00WV1N00@NGad
NGYbNGMcOWU_OgITNVeNNVaOMFEJMUmDLEe?IeA5IeU;KEY=K5Y=J6eYMHB727V:R`07NHn@NH^<NHZ;
NHZ;NHB5NGn1NHF6009iRX/Joooo5hNKUP09O7]`MGQ`QhUlQhUhQhUiQhUhQhf1QhUmQhf100:7TXD0
1HN=PHN>PHN9PXb>P8b:M002R81`00V4Nf^5LfJ0LV9gIeIgKf1jKUmkKUm`KV61SHT028NKUP07Qj2K
QiZFQi^FQi^FQiNCQi:>QiFA00:7ViHJoooo5in]Z@09UXb0T8j3WiF5WiF1WiF3WiF1WiV;WiF7Wi^=
00:OWHh049nIRinKS9nERjBIQj6BNIj8MIj7M9V1KIUiJI=hHh]]F8]fHhacGhecGh=fIYNJU@RO[JT0
1ina[InZYYn]ZIn]ZInYYInUXInXY002WjfY6_oooaNoaL402K^/Wk>_YKnZUknZU;nZV;nZUKn]W[nZ
VknaX@02_k2P012o[Ijo/J6oZYk3[IRmXhZlVHJlVHBfTWfgRWV`RG:ZOfVZRWJWQ6jYQ6jNPVnfZjD8
_lG100Nob<Bo`;foaL6oaL6o`kno`;bo`Kh00[o5`Acoool001[ooolFNHZ;00Xi=Bi0Bd9gMVQiMf]i
Mg=iMgAiMg1iN71iNW9iLVD2NGM[0WUfKP0>NGMYNG]/M6iVM6MNMF=LM6IDJee<JemBLEi@K5Y=J6EH
LFMHLW5YNXb=37V:R`03NHn@NI2ANH^<009iRX/Joooo5XNKUP0:EEQ>Bf9IOh9cQhUhQhV2QhV1QhUl
QhQlQhj1QhAe0XN8N0:7RGd03XN9NHN>OH>5N8=lL8=hK8ElIg]bH7]cHgmbHW]^GgEfIgmjJGQ]FXJJ
U@b7ViH2Qj2K00>7VYJ7ViJ7ViH06_oooaJO[JT02VeRE6akKi:9NInEPInERinERInEQInEQinKS9nB
P0:OUhD2WiR900jOUH>OVHJLSgfLQWFJP76KPfZAN6:ANFFCMV:=Len8NfRCOFV:M62LZ:@<WjfY00>O
/JfO[j^OZZH00Yn]ZA[ooolF_lG100ZEOfjIXYJ[UhRoZYFoZYjoZYZoZYNoZY^o/J6oZ9H2_jjL0[n^
W`0>_jZH_jfJ_Z>?_Y^6^IB1^iIl/HUc/HYd[hI`ZHA^Y8Ye[h]eXGiX^[^i3;o5`@03_lS4_l?0_l2m
00:oaL4Loooo000Joooo5WV:R`0:>CD^@4]2MgIXNGM[NGMcNGMdNGM`NGQ`NGYbNG9U0WUgJ`9iMVh0
3WUgJGUkK7A^IWAWGWESG7AVE6]MC6]ODW5ND6aJCFQUF75WF79aJGZ<S@aiRX/00gV?T7V@TGV;S002
NHZ;6_oooaJ7ViH02UEHCT]RFGn2LhN9N8N9PXN9PHN9O8N8O8N>PHN4M@:7R7P2QhUm00j7RGV7SWf3
QGR3O723N6b5O6MkLV1kLf=oLV9kKUmeMVMoNVUhKEZ6VYD<Qi^F0XNPV`03QiZFQi^FQi^F01[ooolF
WjfY00Y]HUA/NfnBRGVOUH6OUH^OUHVOUHFOUHNOVhbOTX02WiN50YnHR@0>WiF3WiV6W8mmW8IeVX1a
Vh=ZTGQRTGUUTgIRSG=OR7]XTgeYRWAPW:RT39n]Z@03Wk6]Wjn[WjZV00:O[JTJoooo5[o5`@0:UGm^
VJ:FZiN8_jZE_jZN_jZJ_jZG_jZK_k6Q_jRF0[n^W0:o[Yl03[nZV;n]V[jSSkjKQ[VDPK^FO;69Lk6:
M:n6L:V4KZB:MJn;MJ5nJ;Zk^@boaL400ko8a;o3`;o0_@02_lG17?ooo`006_ooo`9iRX/00gV4QGV5
QWV:R`0@NHZ;00]TJ6la71XW;SQjN6iiO75iNg=iO7AiNg=iLV]iNg=iPGd00WUgL00?NGIXNFEOM5UF
JUE;Kf9CMFQKL6aLJV9GLF9ELF1CIee:IeY;HeA8HUE:If5I019iRX/Joooo0XNKUP03QiNCQiFAQi^F
0127ViH02gR3Pdln>AHV<8J8O8N=NhN>PHN=PHN>PHN4NHN=PHNBRP02QhUl00n7RGV7OG63L6YjK5mn
NFJ3NfaoP6akMfYoMfJ0LV=gLUigKUaaIeUbK5e^GD/04XNKUQ[oool2WjfY00>OZJFOZ:BO[JT049n]
Z@0;TiJFFcL^8C0fW9>3WiV5WiV:WiV;WiV:Wi:4Wi^=WifB00:OUHD03inHQIn:NiaoM9EkJ9N6KiZ4
LYN7LI=nKIAnIi=gI8]hGh]cGHE]FhMcGh=YE@0BWjfY6_ooo`:oaL400ko3_ko1_[o5`@0@_lG100Fh
];AjACXc@dJjYY>o[IL00kn]WP03_jRI_k6Q_k2S00:oZYL03kn^VknRT[jJRkVGP;ZOQ[VGQ;RIPKJ?
O[>?M[27LZZ9KZZ4K:=oJjN8LImiH`0B_lG17?ooo`006_ooo`9iRX/00gV?T7V5QWV5QP0?NHZ;00an
T94_91UnO6J9Qg5iMfmiLVaiMViiLV]iMViiMfmiLV]iMfl2NGYb011dLFM_KUmdJ5edIUU/H5=[Ge9`
Gde`HE5WFTe[ETYaFTmbFTi/FTe]H5=XEDYdMG<ANHZ;6_ooo`:7ViH00hNPVhNFTXNET@0?Qi^F00R:
WYY<AcV7SWUfNFR7RGf7Q7R7RGf7Q7T2QhUm01B7Q7V7R7f7SX67SX63QGUnQW63Ng25O6]iLfAjM6Ao
M621MfAdKemkJeaoKf9oKUmkKUmjLV=`FTV1Q7`AQi^F6_ooo`:O[JT00ina[InWXinXY00?WjfY00bQ
/:aKA36GUXAVJ5^OUHNOTX:OV8VOTXBOV8VOUHNOTXBOUhT2Wi^<012LTX:GTGVLQ7JKPfn@NfNBOFVG
OFFFOfR9MF6ALUjCMF>@Lej=Len<MfB3IE:JVY<AWjfY6_ooo`:oaL400ko8a;nn^ko1_P0?_lG100bo
a/=mEd2]YYYEEU:oZY^oZ9Fo[YnoZ9Vo[YnoZY^oZ9Vo[Yl2_k6Q012nZ9NjYhjnUhVkUX2_SWRdTG^h
TGReTgZXQg2aQFn_Qg:[Q6^YQ6jWQg:NNFBk]k8A_lG17?ooo`006_ooo`9iRX/00gV4QGV:RgV;S00?
NHZ;00DR6A=hMfjBTXYjN6iiMf/00WUgK`05NGMYNGM[NGM_NGadNGM_009iMVh047U>CgDl?g0e>G0b
=g4c>759AV]EC6]EBVaDB6MGAVMJBfaJCF]JB6QA@ee1=6EKDPaiRX/00gV4QGV5QWV:R`02NHZ;6_oo
o`:7ViH00hNGThNKUXNJUP0?Qi^F00Dn>c:7ShB2RH66R7b7RGP00XN9O@04QhUiQhUhQhUmQhf10hN9
O@03RFaWPeMEOe1@009oCDd02gmLEg]/H7]/G7YZFgMZF7E^G7Y^Gga^FgEWEVaDAFmPC`0<Qi^F00>7
Ui>7UI67ViH00XNKUQ[oool2WjfY00>OZJFO[JVOZZH03in]Z@05Cc/[XJBHLgQaW9>3WiF100:OUHL2
WiF300>OUHNOVH^OUHL00YnHR@0@XGE]VVALUeUDUeIAU5E@U6MLTG=RTG=NSW1LRg1IRW=MSW=OT7=K
R6aGPem;R7EU39n]Z@03WjVUWjRTWjfY00:O[JTJoooo0[o5`@03_l>o_lG1_l2m00noaL401GA@?<C2
^69VH[ZVTknZU@02_jZK0[nZV003_jZK_jfN_jZK00:o[Yl04<6?PkV0M;QbJ[QaI[=^Hk>0Kk68Lk68
Kjb3K:Z1J:V4K:b4KZj4JZAnIj=gHJZAP`boaL400ko3_ko1_[o5`@02_lG17?ooo`006_ooo`9iRX/0
0gV?T7V;S7V:R`0>NHZ;00eTJ6Vl^[R8QGmiMViiMfeiMf]iMfmiLF=iKF1iKEeiLVMiLV]iIF<00WUI
G00ANEYGL4HmJSH/JcljJd8iJcLhJchmHTY3HUY8IeE9J5M;K5Y=LEY@KEQ;LEe@GSl`JE]A00]iRX/0
0gV?T7V;S7V:R`02NHZ;6_ooo`:7ViH00hNPVhNJUXNKUP0>Qi^F00=hPh3BfM=gNWD00XN9O@08QhUh
QhUmQhEeQh5aQh5]QhAdQhAiQgee0XM`K@0ARGU`OeeCNe15NEA<NeQ>NDY9OEIBLUmELViKMfYKMFYL
NViOOfiRNViNOfiOJTlmMFQG00^7ViH00hNPVhNJUXNKUP02Qi^F6_ooo`:O[JT00ina[InZYYn]Z@0>
WjfY00fCUY;Pg]MYK6JOV8VOUHJOUH6OUHNOTWnOSWbOSWNOTX2OTXBORh000YmoN00AXH5eUemATe11
SeE;TEM;Sde9TeeCQfIFQg=KRfeJR71LSW=OTg=RS79LTg9POUY4T8=e00^O[JT00ina[InZYYn]Z@02
WjfY6_ooo`:oaL400ko8a;o0_Ko5`@0>_lG100fh];3bj>=KGUZo[YnoZYZoZYFoZY^oZ9FoYI:oYHbo
Z9JoZ9VoYIP00[nJT00A`IN9^6iQ]V1@[fAK/FEH[emI/g=TYgUWYhAZZWeXY85Z[8A^[hA`Yh9Y[h5]
WG9K/jNL00^oaL400ko8a;o0_Ko5`@02_lG17?ooo`006_oooa=iRX/03BLR7Q/U8gEbH7UgIGUgJGUg
JgUgJGA`HFmSEgA^HgUhK7U/GWA>AP02JSD`019TC49F?BiMJEM/NfQ[?cAM:b=[=Bm/@3aXDD]XF41S
Ed5WFT]/FTe/GU1/F4]/G4m/GE5iP7`?NHZ;6_oooa>7ViH03DE6?Q/`;h64LHN9M8N9NHN9N8N9NH>6
MGihJH5nL8N8MhN1LH=/GP02NU18019gI5Q[F4Q[M69hQg9mFDa/@cUkBT=kE4ifHe]fKUEaJU9eKUaj
KUmjLf9jJUajKf1cGdb7T8H?Qi^F6_oooa>O[JT03E93>CY9AINBOYnEOinEPinEPInEPibBOYN4LIZ;
NInCP9n>NiafIP02UEU=01:AKEj5ET64M66<OVZCE4B3@3>AC46=Edf9J5^9LU:5KU>:Lef>Len>Mf:>
KUb>MV:7JeJOY9`?WjfY6_oooa>oaL403G=FBFI_K;JXU[nZUKnZV;nZUKnZV;jXTkZLQK^QS;nVTKnU
TKj?OP02^G9T01:gQ7F/I4jWO6ZYOFbcGdjSD42aGE6YJ5bVNVZVPV2SOV>YQ6b/Q6j/QW2/OVZ/R7:S
OFRo_[P?_lG17?ooo`006_ooo`AiRX/00gV4QGV5QWV:R`0;NHZ;00i@CDn9LF1dKV5jN75dK6=dLfei
Ng=iK69cH4mUCT5ZC4i^>CX_20H^;BX2L61E01=kIEfG][:4DdeR=bmBDSYAHE8o>b];:B5S>3=SDD1]
DTE]G51bJEEaHE1/H5=/FTeM@SEYEDQiP7`03WV:Ra[oool4Qi^F00>7Ui>7UI67ViH02hNKUP0>JFi[
YIF1Gf9IQXQlPh5ePH=hQhj1Qh5eQGUUMVQGM5eIP5MCBbHQ>D4i0WmfJ@0CR71VX[bdSFQOLdm5J6eD
HG5OEE92FD0gLdY4LFMENVIDNViOOWYVP7IRNW9SNViOJU=4MF=AQi2600j7ViHJoooo19n]Z@03WjVU
WjRTWjfY00^O[JT03X=nN[RMQe9HDIbCPib>O9ZAPYnIRIn>OYj5K8mbFhe[HYUQF6<N4UeDA`:GMFL0
4iaaIJndZiQQEHQIAh1_DGMZEfY;=g8n<HI@AHE/DhaZDhadH99nIY=iHXigI8icGh5OBi1kJInTW00>
WjfY6_ooo`BoaL400ko3_ko1_[o5`@0;_lG100j/WI[E]9e5D4njYYBnYI2kYiFo[IZoYIC0WX:bRW2^
QGRlOFn<;Q^>MVD2^81b01>hNFg2Zj:ZJ5VXLUbUOenIKEf?DcnFCSnTI5JSOV:WNUnWQ6f]S7>`R72/
Qg:/Q6jQN6:cW8bo_[P03[o5`Acoool001[oool2NHZ;00AiQ8EiQHIiSi1iRh`<NHZ;00he;b/nCD]j
NW9iMfYiKEmeIeiiMViiM6QbDd9VASP_2`Ta@D:`j]nC_;L2QL7401B0[[MjQhQnZ9:@]ZfM][YfP7m>
?CDM7Q<^8aaPAcmXFDYbGU=bI5YfJeQaGTe/FTe/G51MG6ATKGYdP88=NHZ;6_ooo`:7ViH018NGThNE
THNPVhNJUPb7ViH03U=DC3]CE7j0MHN9N8V5M85dIhN9OHN:O8I^FgMPCTLW8d1>C<3_hXZZX`:Ab<@0
58^a]8J?Rhk3[9fdZ:Rn_HF@R6EJCc0h:c/g<6aGCgE]FWi]H7igJXEoJH1bGgY_GgY_H6YTG79mQ86@
S0f7ViHJoooo0Yn]Z@04WjVUWjRTWk6]WjZV39n]Z@0>HE97CEeMRX=eWiF1XI1lUh5`WiR9WiF4WgIL
SVI>GAdEHemKbmW=Phb60Z?1^`0DWZVYW9B>YLR`[ZNJ/K>^T8YnM5A5?BlLEcHYOUi?R71GTW9QTWe/
VHEZTgIOSWEQSWAQPFmTSI2DVZBP3In]ZA[oool2_lG100Bo`kno`Kjob<Bo`;d<_lG100j2I5QWLG:K
RgboZYC1YY6fUhBo[YnoZYS1Rfj_Nf23:AjDOGOK_KEkJ6@2_;Z`01BhXIfjWIG5e;k4UhbnZ9nTS7bA
GdiL>B>0ASNKL5jTOf>]PFj]SGZgUGR`QVj/Qg2/QG2QPW6b[:^k_[/=_lG17?ooo`006_ooo`9iRX/0
0gV?T7V;S7V:R`0<NHZ;00mYLh0f8b0U<3AeLf=iMfUnQ7AjNViiMfm^G55OCCQ?;1m85P];7aa^?cI_
Bd000WANEP0ENGAPNF]FLeeDJeQFKUU<SgMVXHieT8=c<RTP;1hLFT4iIe];MVmOMF]PL6EHK5Q;K5=8
IeQ1E5I;DUENJGF200aiRX/Joooo0XNKUP03Qj2KQiZFQi^F00b7ViH03gb;SeE6@0hS;H64L8N9NHbH
Q8J7MhN9OH1hJWIZDV=8=f<b9T8P7gIAAgiUEP02PFeO01F7RgN7P6Z5NVehIUf0MVJNRGFbYhfMTH12
@SLf<RmWEDYcJEV2Ofb4P761NfUjKEijIeUgI4QTK5mQJ6MeQ8`038NKUQ[oool2WjfY00>O/JfOZZJO
[JT039n]Z@0?UYjRGSdc4BH^Ui1hWiF3Y::;W8mlWiF7VH=`T75ANTD^LRHDBR0MR69EUgQW00:JPgD0
5InLR9nBO9j8N91gJYV5LK2EP[VSR9b4LdHe9dlb:GeMC8Q_FiN6L9V5LiJ1JXiaGHi]Fh]^DWakLWen
OI2JX00<WjfY6_ooo`:oaL400ko8a;o0_Ko5`@0<_lG100nk^keiBChI<CVfY8boZYS3/i^jWXZoZY^l
VhFgQf:NE3ZA;QYG;2ZRPG>jVHP00[^RU@0E_kNV_jfL`:BC/Y:1_:6<bJZIaJR@XWe_FCX[MDDfW7=N
YWmZ]9Io]YF0]I9h[89/[7m[ZX=XWiRDYInN/kNk00boaL4Loooo000Joooo47V:R`0@>CD^2PD3GD]2
MFaSNWQZNFaONFAHNFiNNGMUN6YIQG5WU:ZDa^2mTiR=NfMUL5eF0VI5?@0EJSXlI3HiI3HbHA`HH2@R
F3LcJ4`nL4A0NUM>;@l7<R<TJ5=:LFMHM6YFL5a<Iee?If5CLEY<R8J0Mg^0Ig1j00aiRX/Joooo48NK
UP0@EEQ>9BDPL6QOGUaHQXQhQh5aQgQZQgm/QhUdRXMcUH=gWKBJc^:nRYF7R7EaOgAX0WEHC@0EN5QF
Me1?MUE<L3H`LT8nITDoOFYIPEaCT79V?2TP>30`LV5IOGITQH5[PG=PMg=RMG9ROfYIT8ioQHf8KWN0
00b7ViHJoooo49n]Z@0@KF9D=28IQG=XD51>W9=oWhiiWhMcWhigWiEoXXmgYhEeYJZ>cLJVPgmbW7M`
Uga/0XiTEP0ETfQRTF1HTEi?R3daS4a3OeA8Ug=MTf5DVFmP@AT<DCD`QFQJTWmXVhU^UWURRgQSRWER
Tg5MWYN7U9>>PhRC00bO[JTJoooo4;o5`@0@UGm^FCH[YXf4@4A9^ZJA_jF>_j2:_jF=_jZE`j>:`I5o
/Z>6bjJ>NfYO]h9i^91n0[5mKP0E]hV0]h5c]gUUZUI6/6YMXg1P_8ab[WAU[7YZEQh?MDU0XGYY/95h
^ib0]HacZXUbZH=_[h9]/JBDZj:KWij/00boaL4Loooo000Joooo1GV:R`03NHB5NHF6NHZ;00MiRX/0
4FU]M1LB3Q8?3CYADH1oLgUaI7UYJ7A^JGAdJ7UUI7QUGF57=VIGD7YmNgV9Ngj<P8BHS002QIN;01F0
X8N4RG62S7ElT71lPfQbETUgBDIf>S=]:amV8QPj5A16;Bi[FE1dIUI`H4m[E4QXDdQ/F4`V5@hi>Reh
P7l00WB0PPYiRX/Joooo1HNKUP03QiNCQiFAQi^F00N7ViH04Gb7Qc8b;2L[9aho@X>5NXN5MHN1N8=o
Mh63M8MmMHZ0M7AOCFiPEHJ<Q8NLRHbKSI:TU@02TJ>D01F;[I>DUh2=W8>9WGj9Sg=oI5N3I5f6DTR1
ACUk?S90:BE@>C]gJUf5O6^1Mf9lJU]eIeUjJee0<RQ1AC61RhP00X6@S0Z7ViHJoooo1In]Z@03WjVU
WjRTWjfY00NO[JT04IJJVS@V72TN5aPh>hn5NInBOIn=P9b:OIZ>NYn:OJ:;NH]SBhE]GibGRinVT:BO
TJJUUP02Xj>C01FNZi6XU7fNVH2KU7JKQF^AHU>FJ5fFDD>@@S23<b=77aMX@cn=M6:KQFjFO6>@Ke^8
KE^>LV1B<R9SI5>BU9D00YZTX0ZO[JTJoooo1Ko5`@03_l>o_l6n_lG100NoaL404K^h]dX`93lW7aHd
>In:OknXTKnTTkjMSK^PRknRTL>QRjefFjF3LkZYVKnfWl>YW/6ZW002_:NH01Fh[IO4UXFfW8NeT7Re
PVb[K5faO6f`HE2ZDSfG?2YI9af;FeB/RG>kVX2eSW:^P6ZTOf^/QW5fAS:@SX:YXjT00[^n^`ZoaL4L
oooo000Joooo1GV:R`03NHn@NH^<NHZ;00MiRX/03WN9T^cJa?o=YHMiIGAbIGUeJ7V1JWi/J7YZIgV4
KGQfI7UTEfUGBgAZG`9iNg<067UbJgUkLgUkLgUYJgUUH7EXG7AVG75REF]QCEeRC6I_E7IgH8^3JXAc
JFED@F=FAG1SDg1PCf]NBfQKBfaLD5A9@Bhe=6UfL`9jS8d:NHZ;6_ooo`F7ViH00hNPVhNJUXNKUP07
Qi^F016<Xj?olmobcJQbK5f1Q7F7RWR7TWR<P7R6NWB7V7b:S7V;O6a_GDn1Nfb7SH67SX67Q7T00XN=
P@0EQh5mRGedPg]/QGa^OgMVOGMQK7QNMgmVQXQ`V95gS81dJE]>KVIBOgQWPGMRO7=NMFiLNVmPLVQL
92`YMHAk00:6VYD:Qi^F6_ooo`FO[JT00ina[InZYYn]Z@07WjfY016S/[;ojm[7ZheNG56JTX2OUX2O
W7nTQgnLQgbOXXBRTGbOOVZ0He6JRWVOVhfOVHZOTX@00YnKS@0EWhf5XHYkVXAaVh=bU7iWTg]QPgUL
SWaRUX1XXHAZSg1TLe=4PfeGUh1ZUWaST7MMR75LSWAQOVAD;2hYT9R@00:LZ:@:WjfY6_ooo`FoaL40
0ko8a;o0_Ko5`@07_lG10175bLWoiMZCQgI8CDZkZ9JoZi>o[973VI2jWXno/iK3X8flSGJILEfkXY6o
/J6o[IjoZ9T00[naX@0E_jBI`J:>^IN1^iJ2/hmf/h]`XhEZ[h9//85[[geWV6UNQ5I8XX1Y^9Al]Hib
[XI/Y81Z[8E`VW1O?3Pb/k>]00:j^kT:_lG17?ooo`006_ooo`miRX/04HV5JgagJgj:QGYmLG1^HWAg
JWUhLGV4N7V0NgUkN7ilL7]aH6M;@FEEBGAcJ7V0MgUkL`02NGQ`01EiR7=iM6A`F4]`Fd]VG4MLE4QJ
CciNACUNBCUNB3USD3UYGe=]HeMaGUA[ETYWDDQSEdIREdP`8Q`^?4YcPHh037V:Ra[oool?Qi^F016H
Wh>5RGn<W9:8SGmmP721RGR7R7b7V8F7RhB7SXF>ThB:Qg=eGe9bHeF1Pg>7TXF7SX400XN8O008Qif5
RHQgOg1POg1NMg=LL6YKJFICKU]>0ViOCP0;LfI>M6eRN79ROg=VOFiNMfIKLFYHLV]ICD4h82lbNHJ=
00b7ViHJoooo3in]Z@0A[ZjDUiF>Y:JGWY>2UHahVYF1Wi>3Wj:<Wi:;WiV<YIf9WX]cRVACRg=PVY60
Win@WiV:00:OUHL05InXSj6?O9MhHiMjHhiiGHM`G7iZD89OC89UC89RC8IYC8E_HXYfHIAjJI=dGh][
FhE`F8M`Fe@h;2Pd=8Z@U@0<WjfY6_ooo`noaL404L[6/JnZZ/>fY;bQS[FQS;^ZU;nVU;ncW;nPVKn]
W<F`VKZIP:UfHjf=N;^WU[ndY;n]WP02_jZK01Fo^Z;1WXfhSGJhSgJ_S6n[PfbNO5nQLEbQN5bQLebT
NEbONVnTPfZcSGVcR6jZOVZSPFJWPV]^A3Dg?cZRWil03;o5`Acoool001[oool>NHZ;019dOX1dO7Id
K5]ZED9OGUiZKVajLfeiO7EiPGQiO7AiP7MnLG5oKfQkIeQbF4meIUeiMfmiJ6H2M61I01EdLFAcK5e`
I5IVAceVCTM[CD1TCCiTE4AYEd5XEcmTC3YZDdIbG4m[FDaZEdYXEDUXEdi]H5<P5AH?71UPJFD037V:
Ra[oool>Qi^F01:3Thn1UI23PFejKEUcM6edP7b6Q7R7SH27TXF7SH67TXF<RHB>Q7Z:OV]lI5V1MFN7
R7f7PGT2Pg9Y01F1QGF5QG9oNfYgGe=gI5UlIEEbHU=bJEIfJEAgK59bHDibHU9nKf1kKf1lKUifJU]f
JUmjLV8i<c404@eYLF`038NKUQ[oool>WjfY01:LYZ:JYYjLSWJEO6>>QG^=S8:LT82OVHVOWHjOVH^O
Wi2TU8bSSGjNPFZ?JebGPg:OUhVOSh@2W89e01FJU86NT7RGPVf>He6>KEb>JE:2IU24JU>7JU28KDj4
HTZ4Ie>BMV:AMV:BLen9KEZ9KUj<Mf8i92465Q61QH@039n]ZA[oool>_lG101:n`;fk`KRnYH^iUgfe
XIF^XI>jY96o[IZo/:2o[Ijo]:C3ZIk0WhfjSgNZO6^fVhNo[YnoZ9X2_Yf>01Fk[9W0YH^hUGf_MV6_
PffZNV2KMenPN5nQMebSNUZPL5JLMf2]R7:aRW>cQFjVOFRVOV^WQfm;:bLE8b6QWj@03;o5`Acoool0
01[oool>NHZ;00QnNf]jMF]cJ5eZG5=kJ5=hIf=iJVUiN703NG]c00MiR7=nNfUiLUa/EdQ`GeMiN71i
R7X00WinN@0ENWQeOWE`MF]PMF]JLUe?Je=4I4ToI4i2I5=<LUQ?OFUMM6QKJee?JeY=LEi@K5U;J5M6
HeM8<QdF2P`=7b<W009iQHH:NHZ;6_ooo`j7ViH028bDPhJ:OhF1Lg]dIhQeFgmlMHMjLhN8O0>7SH40
1hNMQHb=NhZ8L7U[FG]ZGHN8O8NMRP02S8b501F6R86>SXB4Og66PFioKEilK5YbGU9bHU=aIUeoKF28
NF]mMFEkLV9kKemoLf9kKEifJUQaJeU>?38C7QlK8Al00XNET@Z7ViHJoooo3Yn]Z@08Y:JDW9Z>WXah
Tgi[W7iRShIoWhMlWiF70inKS@07WjR?Y9>0X8ibT71JTWMWWiF7WjRC00:TTh/05IbCQjFHRIV5LiZ4
KI1^Fhi^F8AOCXAUDH=YFi1`G9IjIhefHY5hHi5eHI=gHXe`G8U^F8E`Fe4_8QDG5CLk>002WjRT2Yn]
ZA[oool>_lG100S3`;6j/j[0XhbfU7jgT7>VViFoWXnoZY/3_k6Q00No^Z;3XY6oWH6_PVZbSG^oZY^o
^ZH00/>QV@0E^ZJFaJbI]YF0^99iZgYVZWiUX6iJX7AMWWQWZgmVZXA_XgmZ/HUb/HM`[hI`ZGmYYWiV
Xh9[ISLX:2<QGf1K00:o`Kh:_lG17?ooo`006_ooo`iiRX/04WV5OWAaH6=?>faTEWaZJ7YhJWUjK7Uh
L7V2OWV0NgUkLgUjMWUoMGQaI75[F6aVE7A^HgUfJ09iO7003WUkLgUhJ6iODF]IC6MJCF]ND6eMA6Q?
?FA@A6iQFGM/HWEXFg1[GFaWF09WGU001FQKDFeUFJmlDF@d8`h71P026AhR2WV:Ra[oool>Qi^F01:7
WiR3QG1iKUQgL625NW:6R7R7QgN7R7b7THR7ThZ7SH67SXJ7TXF:R7QoOfUgKe^1Og27RGT2Qhel01F7
SX69Sgb0MfIkKf1gKUmlMFAkL5MgI51aHUEhLVJ2NFj4Nf^1OfijNVUgLV9gLf9fKV9jMVK8V6Y`BSPL
71X00QhT8PZ7ViHJoooo3Yn]Z@0BWjjTW99jTgIISWYWUh1eW9=oWhn0WiF7WinDWj2DWi^=Wi^@Wif;
XY1kU8EZSWIPVXimWiR50YnIQ`0EWiV:XIV4V7iZTGIRRg=OT7MRRg1BR6A<PfIDRgEVU7e]VH1/UXE`
SWeYRgIRRgMRRG5QS7]Vci9RJ3`Y8QPC0095BDL:WjfY6_ooo`joaL404[o6_KjXSkV>KZb=NJn@PKZV
TKnNTKnZVkncY[ndY[naXKnaY;n`Vl>QR[>EN:b6L;^UU;n^V`:o[I/03[n]W/6]V;VAO;6:LjZ4KZj6
KjEkGJ=bFIifHZF3LZj8MkJ?N[FEOZb;M@:ZQW001JJ0KJN:L]fHJVXn;CTX8P02NW]i2[o5`Acoool0
01[oool=NHZ;01=iLfU^DTQO:bMYAd=KFeMUOFYiNVYiMf]iN71iMVaiNW9iNg=iNW9dLFMiN6UkOW9k
NfijN6IdIEh00WAUF`0ENFEOLeaAKeQ8Ie56HTa0He4kF4DiFDPmJE]?KFIFLFIIM6IIL5iAK5U<LEY=
K5Y8KEA6KEY?M6=IV7MSdmK;00:=Xj<:NHZ;6_ooo`f7ViH04hN;P81cIW=:@WeQFVIQFFn>N8N7N8N9
N8N8O8N8NHN>PXN=PHN>PH>5NHV?O8R=OhJ7MXJ8Lh=mL@02PGEX01F7OG65M6R1LUmgIUQcHUAaIe1[
GTmYGe1dJE]hMV=mMVR5O6^1Lf=jKf1oKemkKU]jJUQjJUf5O6nXS7?@aK<00Wb>RPZ7ViHJoooo3In]
Z@0CWijBVH=cSU=5UFeONVIJR9QoWhmoWiF1WiF7WiN6Wif@Wi^=Wi^<W9:2XIV2W9:0VXehW9=lW8Yk
00:JQG@05In;OIj2L9QjHX][FHQWE8E/CgmPC7iRC8E/FXYiI99mK9^3KiIjIXifHY=eHHecFha_FHaa
H9R0KK27J[nXU`02KWYg2Yn]ZA[oool=_lG100^o^k2lXi6eKe^gR7BGLf>ZZY6oWY6oZYFoZY^o[Ybo
]JT00[naX@06_ZRG`JfD]ij;]9Z3^ZJ>_Z:A0[^OR`0E_jFE`9b6^Y1eZWiXZ7YTXgiOWg5JWW=IWgQV
Y8I`/8el^iJ0]Heg[8Yc[hM`ZHAZYh1XYh9_]91j_X]]ZX9c009NHEl:_lG17?ooo`006_ooo`eiRX/0
4gUcJFiBB5l[9fU7@e]KEfEmJWUjJWUgJgUhL7UfK7UjLWUkLgUjLWAaIgUhJG]nLW]kKWYhIWAUGP02
M6EK01EiIEmcG55_F4QWDDIRC41SDC]HACUIB3eYFdm]IUIaIUUdIUU`GU5/FDaaFTe/FTQ]E4I]FTmd
HeVHMf?Ce//00XfSX`YiRX/Joooo3HNKUP0CQh^0P7=VLdY2OF5JIV5IKhihQhMhQhUhQhQlQhQiQhj2
Qhf1Qhj1PhEiRHmlR8eoQXMfQXQcPgea00:1MFP05HMmLHEdJ85bGgMVF7=RE75WD6]NCfUOD7AYFgQf
HgefJ8ElJh5cHgY_H7m_Gg]^FgYZF7YZGHElKjR<Lm35/`02O8j:2XNKUQ[oool=WjfY01>OWY:IPg>>
DdFEKEmjIUZ8V7nOSgnOUH6OUHNOUhJOWI2OVhfOVhbLTX:QVH:LTX2JSGRLTgbLRW/00YZ5M00EWh]m
WX9`V7YRRf]IR6MDQFa?Of1<OV9<QFaJRWUTTWe/Vh=_UWYVSWIRTgEQSG=KS6mIS75PV81]/8MZ_jRG
009^NWL:WjfY6_ooo`foaL402knk/;bSTKE_FkN8M9McHjZZTKnNTKnZUKnZVkn^W;neZ@02_k6Q00Jn
Z9O1[IBgWX^dVX>jYXjnXY42^in;01FoYIG0W8JjT7FZOVRXNVBSOUnOLEZNLeVON6JTQW2`SGbkUX2e
SGN/RW>_Qg2YQ6ZWP6RWPVndT7ZnRffZPW<00UiQG`ZoaL4Loooo000Joooo3GV:R`09NG9dN5AAKdU1
J558N6MHN7A]NGajNG]cNGQ`009iNg<027UfKWUfJ7UeIgYaHgY_HWEcKGUlNWj9O`9jNWH05GUhIWQ[
GV]MCf9@@ei;?UI6?fQCAW1WF7AXFW9ZGG5YGGAVFG1RE6aMCfaDCG5AD6QDBfMKEFIB@6=?@FeRF`02
OXn@2WV:Ra[oool=Qi^F00V7T8j:LV^2IEQfGEB1KemoPgR7SHF7SX67R7`00XN=P@08QhUmQhUiRHYi
QXEdR81`PHAhQhf5S9b=0XJ7P00EQhmhRX1bOGITLfIFKf9CIU]BN6UHN7ATOGEUOWY[OG][QGa[PGMV
NW9RNVYOOfIRMVYNMFUPN6aHLF=BL5M600:<X9/:Qi^F6_ooo`fO[JT02InOW:9kKiMUE8UMDY9dHXn>
P9nISInIRInEQ`02Wi^=00ROV8VOV8FQUX:LT7ZNRWNGT82OVHfTYY<2W8n501FOVGnRQgNCNV>8JEF3
I51iGTn;JeF5M66=MV>BP6fBPVnKPfnFOVV>N6>>KenCJf:9Keb:Kf:<L5J5Ie>1H4d00ZBa[@ZO[JTJ
oooo3Ko5`@09_kZf`i>3]WEQYVQLZH5_YZ2A_jfM_jfJ_jZK00:o/J402;n^Wkn^Vl6[UkZTSKbNRKJT
TKn]WL>fX@:jWY<05Kn]T/>IRK><LJQiHj9eGiQ_G:QkH9UlJJ=oK:f@Nk2CO[^FP;F?NJb9LZb0KZmn
L:J0JJUoKjb3IJ=hHiU[EP02`lS42[o5`Acoool001[oool<NHZ;01AiN6miOVUhL5]ZFT5XFDYbJf1j
N6aiN71iP7MiMfmiLFYdK5mdLF1iIF=iHem`IUYdIEYeKfEiLVEiMVX2NGM_01EiKFihFe=_ETYWDdIX
E4ITFTeUH4eYGTi/HEAfIEUaHeI`GE5`GU5/EdY/E4IWEDIWFdQXGe9eHeU]GE1AAD000V9ZK@YiRX/J
oooo38NKUP0DQhn3QiZ3RXYbOW5HMFAEN79VQXQgQhQlQi:5QhUmQhEiPh5bPHEaQgeeRGQaOGa]PgMY
PGm_QhAeQhUi0XN9O@03QhF1RWAYPVmN009gJET047=/GG1aGGA^G7QcI89gJ7mhJ7mdI85cHgY^GWYZ
F7MZF7M^FgE^G8AlL7]]GUe=?P9`NWP:Qi^F6_ooo`bO[JT059nRUYnYTZ:>M9=`DhQUE8YiJIbCP9nE
QinOT9nEQinDQIb@OIZDOYn:Oj66NIF8Lib3L9N<NInBP9nHQ@:OUHL05In@RJ9mK9MeH8Y[EhQZEX=]
FX1aFXEaG8aiIYMoK9B0K9MlJ9IjIXicGhi_FH]]FH]aFhQbGiN0Kh]^FWAHB002SIBA2Yn]ZA[oool<
_lG101Bo_[Bo`jo3W8FdO62TKenQQgJjYY6oZY^o]:BoZY^o[9bnZIJk[9JoXYG1X8jeWXNnV8>fXHbo
Z9Jo[Y`2_jZK01FoYYc3TWffR72WNfFSN6:MNFBJO6FOOVRYRgJdTGbcU7jhT7ZeSGN/QFj/P6RZOFRZ
P6ZTPFfcT7fUNVBEKU`00[Ff/`ZoaL4Loooo000Joooo37V:R`0DKVQHES``=b`S>SD^FeI>LViSNGM[
NG9[NG5ZNGIXNG5ONG5SL6=LJVEFKfALMG=YMGQZMGATNGM_NGM`0WUgK`0EM7i[LfmNKe]=Ie=6I554
KE=7JUM>KUaFLV5GK61CL6QLLF]ML6=EK6MHIf9CIeU;J59>J5YEHT0_Idm3K4@b009XCT@:NHZ;6_oo
o`b7ViH05827Mf]KBe9;?Ti>AF9OE7YgJXN9N8N4NHN5NHN9NHN5LHV5MGehKGYmJWigKH>4Mh>8Mh63
KhN9OHN9O0:7RGd05H>COHF7M89aHGMYFG9UEW]VEgEZGgQ_HgicIgUcI7mkK7moKX5gIWYkJGMfI7M]
GWIVGgEZH7=NBWEMCg]KAP02KDho2XNKUQ[oool<WjfY01BIUh:7Ie9]DCaYDd=eI5F=OfnOUH6OTXBO
U8FOV8FOTW^QTWnEQ7FERW:GP7FJSWfJSg^GSWNOUHNOUHD2WiF701FLWXFNS7NGMF2:JeN4IeB;JEJ5
KUj;M6BBNFV@NfNGQ76DQG2FO6N>OfZ;N6>;L5b9JUj8LF:8H4F:IE>=H4L00X1REPZO[JTJoooo3;o5
`@0D_;>N/8E/V6Y?U6QCTW9PYhel_jZE_jRI_jbL_jjK_jRB`JRE]Ib9^J:8^YB9^J2=^In:]Z29_jZK
_jZG0[nZV`0E_[2I`9b8]XA]Yg]UX7IQYGQSWGi[YHE`[H]h[hih^9N1/iEn]Haf[8mhZXE_ZWmYYWY[
Y89_Z79DZGMTZGAI00:JOWD:_lG17?ooo`006_ooo`aiRX/0579QDS8N4RdS7bDN7S4h>g5/IgUgL7Ug
JGUgIGUgKgUkN7ilNGn5O7mdKW5MEVE?AfYLDW1ZGWAbJ7UgK`9iMfT05GUYHFiMDfE<BV==@5m;?61@
A6eMD6QJBfIHC6]KE6]BBFIFBfIIC69FBVMJCFQHBfQEBf=AAF5J@5M4<F9;@@02J5ID2WV:Ra[oool<
Qi^F01B6QGA>?Be3?CHh=cD_?3mjNFn7RGb7RGV7RGB7RGf7SXF<SHF<UhV>R7moM6QfI5]gKf9mNff1
Q7B7RGd2QhUi01F9PGF0N6YhIUicHUE_HE1/HUEjKUmdKUaeJeeiKfAkJ5aeK5igKf1bJeagKemfKUif
JUaaHeIdMUYTDd1bIUL00Ve:?PZ7ViHJoooo39n]Z@0DWhmgGcPPEc`_@c4Z@dA2T8=fWiF5WiF3WiEo
WiF7WiV<Y9N;XJ2>Xhn2U7a/SfmQT7e[UHQeVY9nWiF70YnEP`0EXHenV85]SfYOQVICPF==OVIDS79P
Qg=MS79QSgMXTG1OS7ISSWIRQg9NRgEQRG9MRFeLQFQHRGQGN5@lQf]H00:0DD<:WjfY6_ooo`boaL40
5<6XSH98:W]=?Ehm=65GDJfEQ[nZUknZV;nZUKnZVkn]W<>YVKf_Vl2NT;>@O[:7Mk6GP[FORK^XT[nZ
V`:oZYP05L6TTkVHP;1mKZAgH9ibFi]fHZN1KJ>4K:f6Ljn;NK66LJf<MZn:LjN5KjZ7L:J2K:ImJZ=j
JJV8IIIQB:MoJP02VUe;2[o5`Acoool001[oool:NHZ;0WUnNP0DOWagRU]8@B/P<bDQ>ChnLFaMM75O
M79[NGM^JF1@FU53CChb@C8YAC/dCSlnHDa7HTa2IEA;L6YQNGM_0WUgL`0ENG9YM69FJUU0I4`iHe52
G4i2ED]1D515FE=8HV5AIV1AIea@LF=EK5i@J5Y=J5Q;J5E;J5M=DCL/>QdGBC<U009SDDD:NHZ;6_oo
o`Z7ViH2Qi>;01B@WYJTMf1B@SI5?SLZ>CejNFN3QG61Q7V7RGelNFE/J5QSFd]ECD5JF4aQFEAaH5Y_
H5=dIe]kNV^7RGd2QhV201F9RWb6NfamL5EbHDmcIE=XHU=VGe9RIeUXIeU_Lf1gMVEeKf1oMfIkLV9f
KUmfKUifJUafJUmXE4I<>2mEB3T00VM4;`Z7ViHJoooo2Yn]Z@:OYYh05:NXW[5`EU@g9d`e;2li?923
KibBNiZBQ9nEQIJ5KHQhI7mXDgAMBWQUEWaRFHQXGHEXEhedI9:7MInEQ`:OUH/05J6DPYf1KY1cDhAR
C8EWDGYSD7]TDgU]FWm]FhEiI8ikIhYdHI=lIhefHXUcGhUbGHU]G8U^GgYB?V0e96]==`02Nddi2Yn]
ZA[oool:_lG10[o0^P0Dakncb7ULI3d]Hche>D55[IF1_ZRB^jRI_jZG^ij4/9EoZXE]XGeWY8=aYGY_
ZWi_YGiY/8ij/Yj:_jZK0[nZWP0E`JVD_I=o[h9RX71JXGIMUG9MW7ISWH1[XGm[YH]d[h]fZHE`[haf
ZHI`YXA^YX9/YWeZYWi^Vf=:PTH_SF9800:FFDH:_lG17?ooo`006_ooo`YiRX/2M71T01AcI5LN2PL>
30`G5aDX>C]aK61iLFAjLf=iMfV3O6aVFTa>ASX[;B`C6AXC6Q8Y9b4k8QXc5157<2]dKV<2NGM_01Ei
N6QdIUIZETAOFD5IBCQPEDUgIUMmJ5UcGe5XCTQMCdMOF4e/Ge9[GDmNE4QEE4QOFd]XFdeUAcIG=2IF
<b/00VA7@`YiRX/Joooo2XNKUP:3S7l058F2LCTW8RDW9BT_;1@a=gejK8N5MHJ4L8N9NIBCP7UbHVAR
DT98@RXe<bLd;3Pl=E0n<dL_:Dll=H5oL0:7RGd05HV?O8IoK7e]FVm]E6]PC6]VFH=fIHQjJGibHWIS
FG1WG6YZGGYcHgabHVmZFfIZFfa^G7I^GgaTD6E<?Ea5?@02IcPX2XNKUQ[oool:WjfY0YbMS@0DWXik
?aP?:Q/E;2@N6c8gTXAbWi9mW91hWiF3Zif5SGMRNVIADTLm>C8[?3<SDT4eJ3h/HC8TK554VXim0YnE
Q`0EXIV4WHA^T71HPFi@OF17O6YHTWMSU7aWS7AQRFUKQFiMOg1OSWUUT7QSPfmKNfmKPG5LRG5OSF98
L4DaJ44d009h@Bd:WjfY6_ooo`ZoaL42_[VZ01C0Z9EI7aA49Ae2;BDW>d2`Uh>oZ96jY8boZYS9/9J]
RW:MNV5dF4]K@SQTAS5jEdV@DS^:BSFBLV:kYI@2_jZK01G1[IRmUWn_P6FNO5bKKU>FNFFYPVjXR7>Q
PVfVO6^VPfnMPVj/RWB^RG:RP6ZLP6ZOP6ZVP6jZL5>6CSQmBc`00Y5>=PZoaL4Loooo000Joooo2GV:
R`0GOY2APhAkPhAkLe];G3Xb8aLC9AHC;3HiNWU[MGIXM7=WNGMZOWmgQWIWVH1eHTTk:1TE7aLB7BDV
?d0eMfaKLfmRMGY_009iR8@05GV2N7AXFEm;?e@n<c<@2C4P854n;4Li;3</8clm<UiBAEaDA69FAfMJ
CFICAEmBAV5BBei<@TXe;4Li;UY=A@02KUiK00=nSi1iRX]iRX/01gV:Ra[oool9Qi^F01N:WYZBXYRB
XYR5MV9lFThe;bXc;RXB9c26R7N3RGR1Q7B7RGR<TXFJT7fRSh1kI5<m=2h^;bX/>3M<Ed]lMVEcJen1
QgH00XNFS00ERIR<QX=_M6AFIUE8BbdS>S4_HEE2Fe92BTPkCe94KfIHIfIELV]IMfmON6YIKVIHJfIL
Kf9GHe96EDm3GeaB009_BCd00hbPVhNKUXNKUP07Qi^F6_ooo`VO[JT05j6`[:R_XZR_XYamIHIBA30N
638P6Q0V;YbAOYZDOiZ@O9nEPJBMS:jEOZV>OH1MB3hX7c8T6cHd;eeD@hA^Fg]TF9NAOP02Wj6E01FQ
XI:MRG69IU9iEd=J8Q9@>C5gFd5cFD9QBcQYFTN3JUUhJeF7LUb;MF6;KEQoJUMlJUb3IeIdCciTBSU/
EdX00Wm:?003Y;6]WjfYWjfY00NO[JTJoooo2Ko5`@0G_lK3a/Nia/Ni_I9gX5a=?28K@2HO4R/e^Z:=
^JN@^jB?_jZD`k2LbZB;]IF3TfE@D2lVARdRDD4iO61<TfiLQf9G]Z:=00:o/ZD05L6cX[fKPJUgH9QY
D7T/67=AA9UaDYQ_EXUPBI5`FZ9jJ9=lI:N5KJZ7L:QnIiYjIYIjJZ9jIIENBWmF@X5ND002U4`k00?3
b<BoaL6oaL401ko5`Acoool001[oool017UoPGV5QWV4QGV5QPEiRX/05aX91`T<4`T<4gAVF6I4=BHM
8aLC4A`_<g1^HWUgJWEbIFm]HGAbJ8>7NG9/FYajHkbALimbD8EH>gMXCg9UE79QEWE`IP02NGI/01Ei
LVIdI5EdET5SBSa_D3]7@d4Y<3D20PD?5ALU9bDE5Q8G7R4a;298>2YRDD=OETUQEDIFB3/g:b0X8am2
B3l00VeUG003OHj?NHZ;NHZ;00MiRX/Joooo00B7TXj7UI67Ui>7UI45Qi^F01Lf:B@C:2hC:2j6OF^3
HTlk=cXX:bT27BQmP727RGR3QGAnPG61Q7BDW8anOfZdUG_2X82RPF69ITYfLeafL5ilK621OFh00XN8
N@0ERH]nQX1]QfmHLf1@Pf]CD4e8@4Y;61dN82h^=C`h;C8/:3DeA4DiETloM6MFKVUJJfYHK61AD4Pj
>3Xe@e58009`EdD00hfQW8NKUXNKUP07Qi^F6_ooo`04WjFQWjRTWjVUWjRT1In]Z@0G@ahE?TM5?TM5
WXI`T5]5>BT/91`G1AdVUHahWiF1VY1kUhijVY9nZjFBTXA/a9Mk]i9dTfmBPEXoLfeFP6eISgASUh]h
00:OUhH05J6IRIf7L9U`E85NBhiTB5I4?U18A1D<2c@]9T8j<C/]8D0l=Ea:=FeF?hM/Egm[FGa]F7mR
Cea1;d<d:U=BA@02PEa:00>V/jnO[JVO[JT01in]ZA[oool01;o0_;o1_[o3_ko1_PFoaL405f@[7gUj
LWUjL/2JPZ]VCTP^<S<Q6`dR;KFQS;nZU;VTS[ZUSk^XT/VfXZfBN]bSR:f9LHMWD7iJ@gI_GI5cH:Z4
L[JPS002_jjL01G1/Z6mW8:eOf6IJeJTK4iWAd1bF4lX4A1J?cAPBSiL?BaYEDV4H4FAKE>UOVNJNVFF
OFJOLeejCCQO?c=]GU000YURD@03b<c9_lG1_lG100NoaL4Loooo000Joooo00AiQHIiQXMiSi1iRh`4
NHZ;01PP4Q0M51820002000010TC3aDD4@hR5a@Y=3MeLVEeLfe]DdmPAT5ZHEUnPGf4SXR:PGYkI5R0
KV63Kf5kJEUhKemfK5meLFL2NG]c01EiL6]dKF5ZGd]WGD9cGT>4HdbBI4`U5aLJ5Q8Y81lY8R0d;REJ
AS]TG4a/EDETDTIQFdTj:B@X7aTZ7QLb8ah00Udn>@03N8V:NHZ;NHZ;00MiRX/Joooo00B7UY:7UI67
X9^7VYH4Qi^F01Pl<bhj=C0A6ATA6ATE7R4^;30Y:bLb<2`;8B^3QGB1Q7R1L6M`GEEdL6:<TXZBXIJI
U8V:NF^?PW:=Ofn1M6B1OVZ2NV^1OFh2Qhf101F9RX26Q7EmMf5hL5B0M5N=KeNPNV4l<c4S;2Pj=S<m
?CPi?cMSFDiYJ5UlJEIcIUQ[KU]EASho>S8j=Rh_<bl00V8e9P03Qi^GQi^FQi^F00N7ViHJoooo00BO
Yj>OYZ:O/JfOZZH4WjfY01Q;;BE6;bHC1`<C1`<b8Qde8RHY7QL_8Q`67RRJT7^GT82JNVb:K5f=P6jT
WI:VYiRZUhRJO6VNQ72GO6R<M5nBPVZGP6jGRGL2Wi^=01FQUXRMS7R@N5f9L4n<L52CJe:RME`f8QlQ
7QQ2<2Y1<b`n>Be/EdQbIU><JE:3JUMlLEYS@3E8<bDo;20i<RT00WU6=003XJn[WjfYWjfY00NO[JTJ
oooo00Bo_[^o_KZob<Bo`;d4_lG101Q]?S=W@3@Y2`HY2`IS?31B;S8l9Qdm:2858BbiY8jfY96nU86_
RGJ^V8G3/:?1]J?3XY6bRWFeT7^VPVbMO6JYSgFdSgbfW8P2_k6Q01G1[9fmWXR_QVVTNeZPN5ZOL5V[
O6E29b@^91aI>cAE?CA?@cIoHe:3KUVVMUbMNVJFP6R2CT1R?biD=BM>@CH00YQNB@03a<W6_lG1_lG1
00NoaL4Loooo000Joooo00=iT95iRhaiRX/01GV:R`0HABXT;b8I;QhH;QhH6aTG3PT:8AHC:APE;30c
NViRMFiNQ9:2NWUZBcT]?2TR>BhU:RTS8AhL81`H:B<L<24MA3hiJV]OMG1V0WUaI00ENG5NM6IHJUY=
J4PlGeDoH5U3LFECaYAc[8=WOeDmOThhNU]:N615H5A5Hei<LV1?GeE;>b/O8QLD:ahH=BDM009I>SH:
NHZ;6_ooo`03Qj2KQiZFQi^F00F7ViH066E>A3li<3hg<3hg<2X^;28T8c0]:cL`;18R:hJ0L8>0K9>V
TXZ:NeiBA514>E1;?d=7?S/l=cDf<3dn=D<k=55>AGMjJh5nK`:7QGD05HV:MHIlK7edI7MND6iZDVaY
DH1jIMZYQJN<LXMVChQRC7EUEWe^EViUE75bGX1bGViZGUM:>CD`;3Tf;c@i<@02FbHH2XNKUQ[oool0
0in_ZinZYYn]Z@05WjfY01Q]@cLo;24m9alm9alY81`N4a4^7a/d8A/@8BVLS7RJS7FY[YRLRWQeFDA_
EDA^FTQPDD9D?cA?>RaH@c9N@35]GDf@Q7:GRWL2WiB101FQUWjMPg2@N6>8H4aoKDinJdnBOFCKX7^?
Mf61FD:4F49]G4f2JDilIE65MUb?LeeoKEaQ@R`f8adm:b0l<RH00Vh^7PZO[JTJoooo00>o`l2o`;fo
aL401Ko5`@0HR4i0CS<VBR`SBR`S>RHQ;QPF?2HQ@2LP4RLa^Z6<^J69akbX]Y:1VVmGWWMRW7aTSVeK
PEI6NU4mPU]4R5M3UGQT/IJ3]Yf90[n/V@0E`JfD_IJ2[hUaXg5GVWeJVgQK[8Ybh9emMfQKP5U4R5a8
Iea@S6mEUG9MXhIZZ81YVWeYO4deBB/SCc<VCS`^00:9>RP:_lG17?ooo`006_ooo`QiRX/064db91X=
2Q4A3Q4A3QHA3QlD41@B3b@U8R/i>FYVFgihJWYhK8V9PY^PSh9^HemADGEQFX]VDX1UDfmHAga[FWef
J7akLgYhL@9iIFL05GU/IGA[G6YDDDD/9C@M6T4g;EmG@FQJAWIRD8EaFGM]FFQSCemJCfQECemBBemG
AUI8>1dG4a4A3di;?e`l:`02DChi2WV:Ra[oool8Qi^F01Q]Ed@]9R<T:RHT:RHX:RHa;RTU:RLc>cLI
<SMdMVR<R7R6R7NHW9:Y/Yf>PG=cIf=oM6ZFNFF7Lf5iJUR1MfInMFR5Qg^6R7`2Qgei01F9PGR6P6im
KfMKB3i9=c5=BCi/JU9fKUR4MV:CQ6b4OFQ_L5a_KF1fJUi^IUi/JUQ/HDlf=2dT:bM7Dd]SDT400ThT
5PZ7ViHJoooo29n]Z@0HN4hg:QL@8Q`E8Q`E9Q/E;QlG7a/E=30Z6blcSH9`Y9=oW9>0[ZJI][2JV7e/
PVQPRG=UV79LR6]HOV=>QW5NQG1QUhenW9>30Yn:PP0EXHioWHMbT7=WKTDdGCHYHU8nPG1CRG=IUGYR
WX=WS7MPNFaFPFmMRFeKOfYLPG1HOfA==bPN8QdFA4]1IDHb009O9aP:WjfY6_ooo`RoaL4069=I@3XL
53<S6c<S6cLQ6S`T72/O6T@f<2@e>ZjHQ<>VTKZVTLZfZ<RcWJR2L9efJYYmKJ1gHXi/FhYXDi5dHHm_
HZnJRKZVU0:oXYL05L6UT[fIPZn5MHmD?h99=HAZCin1HjJ4J:j8L;6:KiajI8]cGIilJJImIYYjJIn1
IYmfG4`a9C<S6dM=AFm:=`02MR`K2[o5`Acoool001[oool2NHZ;00=iQ8EiQHIiRX/00gV:R`0HFD8d
:14<7Q8?7Q8?5Q<@20@65a0>9R4O:S8aF5I>M6mSNGM[NGadOXF0Sj>F[K:OV:^LWK:WWk2VYKR]TJ2@
O7]/MGU^M7EW0VmjH`0EM7=SNVmRPH5YThI_Fd0k8aTI3@h?7B0QDDU0IeY;LEi9GeE9Hdm3DDPiGTm8
JU9;>RHO8A@@9R8N:BTSBb/N008E20H00ahR9GV:RgV:R`07NHZ;6_ooo`:7ViH00hNGThNETHNKUP03
Qi^F01QjJ5Dk:bD_:RL_:RLX:bPK7QlX:BHb=S8S>3YPI5V1Og27RGR7SH6<UXjN]J>i^jFI/:2W^jjV
]JR/_k6DYIB7QgJ1QgN3RWT2OXme01F3Q7B:QGB?U7ZTVX9^FE0e<2lS:RL/>3EMFe1gKUj0Le]^JU]c
IUIRGdi/HeUeIUiEA3Ti<2Xf>3@R=cAOAcL00RTM600392XXQi^FQi^F00N7ViHJoooo0Yn]Z@03WjVU
WjRTWjfY00>O[JT068IRC3TK4R/K5B/K5B8L5Q<;2b@J5C0[9RTh=gM`HIZ<NInEPInIRjBQU[2hY<6c
WYZWVK:cYJb[W;:eYI^LRYV:MYNCOibFPP:GVWl05Ib<NZ2=N:2GNZjCO7E>@d0Z8c<W7DQ0=GASDX]c
GI9gFWm]FXIZEGARC81WFXEZG6<o;S/T6c8/9B8`:G12;002=a/D00=:D4jO[JVO[JT01in]ZA[oool2
_lG100>o`kno`KjoaL400ko5`@0HXg1GB1lF>20I>20I;b4K7`l><b0J?S8/>4A2V8Id^j6<_jZE_jfN
`k:VbL2[c:bKWYjE`:bP]Z6B^Z^KYIF5/Y>0]ZJA_Z^G0[Z^U@0E_Yb=_j29^::6`9B1Qe=7GCH/ESTY
ME]9UGQSZXA/[8IXVWeXY7aSTW=LWgQZWGYYPThiD2`Q?S4Z;3TaSdlf009G;R@00gf3P;o5`Ko5`@07
_lG17?ooo`006_ooo`9iRX/00gV?T7V;S7V:R`03NHZ;00m6?cXW8AhM5A4M5A4L4a0F40`I4`lU8Alg
>3APFE1eL6AiMf]iN71iNg=iPWh00WV7Q`07NH1kNH9nNH1kNH1lOWmeNW=SOWY[009jLF<05GEVFWY]
H7]cI8EhKj:CPZb6MWaKCBhU7Ph@3Q4D5QhQ8RXX8S8[8U]9A6aGBV=@@S4N6A`C41`E5`h921X@3002
=RPU00<f?d5iRX]iRX/01gV:Ra[oool2Qi^F00>7X9^7VYJ7ViH00hNKUP0?IVAL>c/e;bdY;bdY;R/X
:2XT:2XW<SHb<40oI69HPGi`QhUhQhQlQhf1Qi6800:7Ui801hNCRXNAR8NCRXNBRXbBQHJ4L8b>O@02
R8Ed01F3O6f8P728QG>CSGjdZ96dU8B;Kf0l>c@S:RHV;bhd>cTn@cU5ACUVFe9dJEYcIUM=>c@`;BT]
;2dM8R4]:RD00T`n>00382<QQi^FQi^F00N7ViHJoooo0Yn]Z@03Wk6]WjZVWjfY00>O[JT03g5PEC/^
9R`M5b`M5bXL5R8I4B<J5C4[9S@o>gAZG9N:MinEPInEQinKSInOU002WjBK00NOX9BOWiBOX9BOWiBT
WH^LT7RTVhP00Yj@NP0EVXQcWXYfW8agYY:1_ZB<[hMgQf9B?c4V<BDK?c8[BT0fETHeFDLeNV1CP6YG
QVUFDc0U;alH:QlN7a@??B0F009E=bh00b4U8Yn]ZIn]Z@07WjfY6_ooo`:oaL400ko8a;o0_Ko5`@03
_lG100n>KV9==2/i8Q/i8Q/g8A/]7AD^7aU0<Ra1BDF<NV^fWHVoZYFoZY^o/J6o/jH00[nfZ`07_kBV
_k>V_kBV_kBW`k2K^ZB<`k6M00:lY8d05KVNQkbNR;NMQknQSLfVSjaoLh]RDe4i;58d9V]:?79GAgiL
AGaKAIMaHY=gHjAiIFdj;D0U7CPU93<K55hZ7002KT8g00<V9bFoaL6oaL401ko5`Acoool001[oool8
NHZ;01QIAd0o<2`M5a<M5a<I4a0N514P61XW8b4]<bi8BD5ZIeaiMfIiLVMiMfmiMVaiNgAiPGeiQXEi
PWiiOgUiNg=iP7aiNg5iMfX2NGAU01EeLVAeJ5aeJEeeK61jK5ifLen=Mf2GOFF<LEUVCc]O@S5[DT=j
IeMQCdYICdQ?CT0c81XM4a0E4Pl>3`/C5Q@00RXX9P03=Ci0NHZ;NHZ;00MiRX/Joooo28NKUP0HNVeS
CdM1<30[<30[:R/X;b`X<30`=CLe;ClmCeA;M7AWQhUdQhAdQhQmQhQiQhb0Qi:9QiRCQi68Qi>;Qhf1
Qi::Qhj1QhUh0XV:N00EPhEdPg]/Pg]/Ph5`RX1`QHQbWhadY8mfUX5YKV9>K5E5L6=DQ7ETIV1FJf=K
HfEECShe;b`X9R/V82PT8bd[008j>cL00b0T8XNKUXNKUP07Qi^F6_ooo`RO[JT068IYGDlm=B/Q6R/Q
6RLL5R/M5b/Q83</:3<m=f=LChf1L9nEOInBP9nGRInGQYnMT9nQV9nVWinOU9nRUinKSInOU9nIR9nE
P@:QUGl05IZ>NIZ4LIZ6LiZ:MZ27MIR<M:b:L:B5K91cFf]F@G5??79OCHQ_G6iLD7mWFgQWDe@b9R`M
5b8K5A`H4B@O6P02@38/00<S9bFO[JVO[JT01in]ZA[oool8_lG101RSN6]MA3`h9Qhh9Qhe8A/h8Q/g
9RA2<bi5B462Ken^UhBoZY:oZ9Jo[Yno[Ybo]JRo^:jo^k>o/jJo^Jjo/J6o]:No[IVoZY@2`JZB01Fi
XHZiUh6iVhJiWHRoVHJcVX?1TWZYQFn?KeYaF4F0EdAkIeJDLf1nIERON6ZJMf1/>Rdk8a``8AXZ7ADg
9Al00UHj<`03:b`Z_lG1_lG100NoaL4Loooo000Joooo27V:R`0AE3d_:alF:alJ:alJ7Q@A7`h;91HB
:AhF9RDQ>S/gHU]BM79VNGM[NGQ`NH9nNG]cNG]d009iPGd01GUoNGUkLgUfJ7UfKWUaJ002NFUM01Ee
JEeeLVAeJ5aeIeQdHeEfGE5fHUAeHU>2K5b<MF>9M69gHeAcEdm^G4]/DD=;<bH]6aHM4a0V61DK514G
4Pl00R0J500371PHFE]PNHZ;00MiRX/Joooo28NKUP0AM6=A?CP^?cPb?cPb;bdY<2LS=2hY=c@]<3Pd
?DM3JfMLPHAdQhUhQhQlQi68Qhf1Qhb000:7TXT01HNCRhN=PHN9NHN9OHN5N@02RH5`01F3Nfb3QGB3
Nfb3O6V5N6R5M6B5MfJ5MVF>OVbGR7>APfmmLV9oJEijL5ilIEIRCd16>30_;2Pf<2`];BTW:RL00Rh`
:P035QPCI6QWQi^F00N7ViHJoooo29n]Z@0APUi8@2hQ?b`T?b`T:QhG;AL@<B0I=RTN=S</CTi4PG=T
VY9nWiF1WiF7WinDWi^=Wif@00:OXIP01InRUinKSInHQInHRInBP@02XHeh01FJQW>JSWVJQ76JQVnK
P6fIO6RHOVVFNVBIOfZNQ6fEO6N4KU^=JU^9Leb<IUEaCCQ;;B8/7ALc8A/W7QLS6aD00S0U70038B4L
PH>2WjfY00NO[JTJoooo2;o5`@0AX6eDDcLXD3@[D3@[=R8K>Q`D?bHOAC0UBSlgJV5DWhQf^jRB_jZE
_jZK_k>V_k6Q_kFX00:o^:h01Kni[[naXKn^Vkn^WknXU002`JB<01FiVhJiXHZiUh6iVh:kU82gT7Zc
SgV`R76/RWFZRG>NOVVAM66SMfJPPFVVLf>>GTER=RXk8aa09b0c8Q/`81X00T4]8`03=cHaZ:NU_lG1
00NoaL4Loooo000Joooo27V:R`0BASLZ<2/X:1lL:1lL9aTF4`l<5A4?5A0>8A/G9R@LBT<kMFmSNGM[
NGQ`NGafNHJ5NG]cNG]d0WUjLP04NG]cNGY_NGMVM71Q0WAaH`09MFQLMF=HMFMKMFQLM6IIJf9DJemB
LFQJJ5i@009/FTd02UiHBeEEAUEEB4]8>bLT810>2a/F614>410=2PP41P8F4A400b8S8TY<C7V:R`07
NHZ;6_ooo`R7ViH04VILBd51?3Xh<cXh<cPb;RDY92HZ9RHY9Rha;Bdf;di=@X5oL8N9N8N8O8N<OhNH
ThN=PHN<P0:7SX8018N=PHN>PXN9M8>6M@:3QW@05H=kK8=gJH=lK8=kK8ElJg]gIW]cHgmkJWIbHWY_
Gg]^Gfm^GVIZF6IZFf1PDD51>RHY92d_;b<W:2<W8aXN7`0292TX00<T;BY9Ad:7ViH01hNKUQ[oool8
WjfY00IaET14>34j:b@j:b@f91dO614291XE00Tc:B0j=RUVFT^GS7VOUH6OUHNOVXbOYYnOVhd00inM
T004Wi^=Wi^;WiEmW99n0Yb@NP0EVXAaVX9_VXIbVXAaVh=_TGiYTGUUTh1/RGIRSWEQSG=OPg9MNfeH
NfeKM69>BcT_9AXB:b4P7ALG7QL@4P/:008T71P00b`]9eeGDin]Z@07WjfY6_ooo`RoaL404XiSBeM0
>4Xb:DXb:DDZ8b`M5C<P6CDQ6TPc:5A7=XMbHKJQS;nZUKnZVkn`XKnk/knaXKneZ0:o]JT01;naXKna
X;nZT[jXT`:nY8d05KVGPKVHP[VKQ;VGPK^FP;6?NK6:M:n?NZJ6L:b7L:V4KZ:2K9amIYamJYMcG6Q5
>3LQ5c/W9R/L6bdL51h>3P02=2<N00=0>cAiK6ZoaL401ko5`Acoool001[oool8NHZ;0196=bX`:bPX
7a`X7a`W6AHC3``E4@lE40hQ6aLV91a:@c]eKf=iMf]iN71iO7IiQXEiNg=iNg@2NGYb00AiNg=iNVmi
MfIdL642M75S00UeJ5aeHeQeIe]eJ5adIUU[HUA[Ge9aJ5YXGU000VaJC@0:GUQ;EEE6EEE8BdPk9b@P
40h;6aHH4@h@40d:20@60QHA4@038R<RBTa<NHZ;00MiRX/Joooo28NKUP0BIUa;@D4l>SPc>SPc>38^
9BTT9RXV9RTV;S4];CH_CTe2PGm`QhUhQhQlQhaoQiRCQhf1Qhb00XN>PP04Qhf1Qhj2QhUdPhIe0X>6
M00EPg]/PgMYPga/Pg]/QGa[NgMVNg=SOg]ZMW9RNVmONfiOKfiNIVYHIVYKH61A@D4j9RTT;Bl_8bLX
8bLS6QhO008T:BP00b@]:TU7@XNKUP07Qi^F6_ooo`RO[JT01W5F@4@h<CX[93X[93HT7AlH4@8T6QD0
2C<Y83Xf:FIJBiN<NInEPInEQinJS9nVWinKS@03Wif@00BOVhfOVh^OUGfLTWh2W91j01FJQ76JPVnJ
QW:JQ76KPfnAOVVANFFCP6b9MV:>MF6=Len3LUekKEQkKE]dHTi;>BlU6Q8[8B0M5aLN5a0B2`X00R@L
6003;2dWGEMCWjfY00NO[JTJoooo2;o5`@0BSV=;Ed0hBS8YBS8YABXS;1dE<b0I=B4JB3<XE4LfQg9Q
]Z6<_jZE_jZK_k2Q_k^c_k6Q_kFX0[neZ@04_k6Q_k6P_jZB_ZRC0[jTS@0E^IN1^IR2^I^4^IN1^iJ0
/Hmi/HYd[hmjYXI`[8M`ZHA^XX9/W7eVW7eZUg=LJ4Dh=b4G>bLV:a`K;A`D7Ph>008d8ah00d0k=7U/
J[o5`@07_lG17?ooo`006_ooo`QiRX/04eU0<bhU8C0Y9C0Y9BLP72XJ5ahD4B@M6BTY:2X];3Di=fYN
E7UbJ7UbJgUbJ7UkM7V6QGV2OWUoN@02NG]c00=iNWIdLFQdL6800gEWF`0DMFQLL6QLJf=FL6=FL69D
K5mBK5a?LF9DJ5i@IeY=IUQ;JUE9J513ASD]:QTE:QhK3`T;40d?2P@64Ph@0QHB400392/[A4a>NHZ;
00MiRX/Joooo28NKUP0CNVID?c/e@T4l@T4l>3Pc?3<^;b`X=3@`=Cdj=d4o<d0nM6eQQhAdQhAiQh=d
Qhb0QiRCQi68Qi>;00:7SH400hN>QX>5NH>6M003Pga/01B3NfaoNfajN6QoN6R1MfIjLf=jKf1oMfIf
LV9gKUmhKUieJU]gIUIMDDE2=Bll=c8Q8b<S9RLL7QlT9bP29BTW00<X=SDk?SZ7ViH01hNKUQ[oool8
WjfY01>6HD]0<BU3=c13=c0f:b@i9AhY7AHa9R0e<Rhn>cA3ASf=NfZOTWjOTXBOTh:OWI2OYYnOWiBO
XYL00YnKS@03Wi^@W9:1W99l00>JQW8059Z4LIN4LI:0K9N0K9InJHiiIHifHY=nJHUfHX]cGh]bGHE]
FXIYEFa??dLZ8CXZ8aTA41hG5Q<;2adG5P8P6QD00bdb;dQ6@In]Z@07WjfY6_ooo`RoaL404j=_EU0i
<5@o=e@o=dD`:DLZ8SDQ6Sl/9D<h<e=4>eiGBZjCOknXT[nXVKn[V[neZ;nk/kncY[ni[P02_k6Q00>o
/JBnZ9BnZ9000kVKQ00D^IN1^9N1]9An^9An]Hmi[8Yd[8Qb[hmiYXI`ZXA^Z89/WGeXX7USRUm<GC@X
BC4Y9ADD;1`K7Ph>:A/J0R`N6@03?S/hFe5<_lG100NoaL4Loooo000Joooo27V:R`0HCDM2<RdZ<bdY
<bdY<b/W9aXG4`l;7ADB;b0IAc@XB3P[GDm4M6mONGM[NG9[NG9XNG]dNH5mNHJ5NH1kNG]cNGYbOW]`
NWEV0W1/GP0EJf=FL5mHM5mFLEeALE]DL5iDK5mBK5Y=IeI:IeY=Hdm2K555Gd/nACPb=2HN:1TE4@d:
4Ph@3PT;4`l;4`l?008Q5aD00fMiO8JLWGV:R`07NHZ;6_ooo`R7ViH066e]ID=3?T=3?T=3?TA2?CPc
;RHX92`/:C/f;dm7>dM6>fEKCX5oK8N9N8N4NHN3M8N<P8NBRHNHThNCRXN=PHN>PHb>PHR9N09oPG00
5GYhJ7edJ8EdJ7mdI7m_I85cIWYcHgY_GgM[G7M_Gg=VEg]WF6iRDeaBBDe2>3dd;R@W8bDX:20R8bDX
92<W9`02;bh/00=;FER0THf7ViH01hNKUQ[oool8WjfY01QjJEi6>S94>S=4>S=4>30f9AhQ614Z7aTl
;29B@C=>ASMlIeJJS7FOUH>OTXBOTh:OWI2OXIROYYnOX9BOVhfOVhbTVHZNTgd2UhYe01FBP6bEOFfK
OFbDO6RDMfRFNVV>NFF>MF6;LUj;MF66JUJ=K5UoI51_E4EJ?Be0:1lO5a0P61LH410N5a4L5QD00R`P
6`03>dM7OXR4WjfY00NO[JTJoooo2;o5`@0DUgQ/FD4iE44jE44jE3lgAB/S;adE>BDOC3DYHD/lGUA4
Vge[^j6:_jZH_jRI_j^J_kFX_kR^_k^c_kBV0[naX@0I`jfM_:N?^9f6^9f6]9An]I5o^i5n/i1j/h]i
]Hei[8Yd[8M`ZXE_ZXM`Y7aUZGiXVWEOTVIDN4XgE2lV;A`D;QdL8a@D:Q`D9aXI008h9B000bXa<Gim
N[o5`@07_lG17?ooo`006_ooo`IiRX/017V4QGAjNdHj=BXT8@8^:BH02RhW91dE4BLM6RDN6b0O7C8`
:4Y3>U]BBW1[H7UgJ`9iO7@027UlMWV1OGV1OGUoNGUkLgAdIWA]H7UYG@9jIe/05G]/Gg5WEg1TEW5R
E6]TE6]SE6MDCF9FCFMJCFQJCFaKCUmFBE=;?EI1<CHV72DI5AXD4APD41TE4A<?2aLC3`027aLD00<W
;C1nSi1iRX/01gV:Ra[oool6Qi^F00B7Ui>3SXYVH5Lk?3L2?T0k00Xo?cX`;bXh=C4c=C4_=S<j@S]?
DdYRFU1kNFb7RGP2Qhf100R7S7n7TXV7TXV7Th^7SH63RWV1PG69PG02R7a/01F8P71oNfMoMfQoMfIk
MfAkMfIgJUmbJemgKUmfKUmkLF5_JEYWHe=[FTQ<@CDi<Rd];BTY;2PZ;BPU:2@W:bL00Rd^:`031P@3
S:2KQi^F00N7ViHJoooo1Yn]Z@04WjVUW::NLE]@?C</0T4g<@0:@CD^;R0I=RPR;bLQ<2XU@C`aFe94
MF1ATXEdWiF10YnIR`08WiZ<Wj6HWj6HWj:GWi^=W9R4VXilXHeh0Yj6LP0EW8MdU89ZUgi/U7iYTGeV
TGaYRg1QQg5QRg=ORG=OSGEPPF]IO6E@NUQ1DSPW>RDM:AhH8adF91dG7QL@8Q`E008Z81/00`820ZBa
[In]Z@07WjfY6_ooo`JoaL401;o3_kjn^Xi[GTll=@9C@CX02U8n=ShV7TD^9c//9D4a:eI6>G5NCY9_
G[:JQknZU@:o[Ih02;n`XKnh[[nh[[ni[[naXKj^V[^UT/6TS0:lVh@05KNIQ;>CN[R@O[>?NK6=M[6<
NJZ3L:N4L:Z4KZJ4KZV4KIijIIedGIMVCFM1;d`/8cHS72lQ6S0R6bTK52hQ6@02=bDP00<10033b<Bo
aL401ko5`Acoool001[oool6NHZ;00AiSi1nUIE3>34c91`2;R@P00d`:RLg;RTX7a/X8Qh]8QT`=C0f
=bi8?SIVFU5dLVQiLV]iMfmiMV`00WUeJP05NGE/M6aOM6]ML6iRM6mQ009`He405F]OD71SDG5TE75W
FW1ODVaNDG5QCfaKCFQDB6QAAUiDB5=;?T/m<30S8B<G5ADB414>2Q4=3`d82`@41PX72P02;2<Q00<e
=CQhRHYiRX/01gV:Ra[oool6Qi^F00B7X9^<YJ1RG551?3<2?c`f00e1@Se8AT0h=c8h>C@l>C0hAD12
Bd5?C4=aJ5b1Q7B7Q7V7R7f7R7T00XN8NP05QhYnPh5bPh9bOH1`PhEc009oN6@05GYdHGmhI7mgI7mk
JX5cHgYcHgmgHW]^GgIZFgIVF6mZFfMRDemGB4Lo>CXb;RP/:2@W8b<W9alR8aLN7a`Q8P02=CLe00<H
4@n7ViN7ViH01hNKUQ[oool6WjfY00BO/JfT/jm[EDQ3<RH2@38Z00e3>C98>S8d:B8g;BHl;B4l?cQ@
BCUSDdF8MFFJTWjOTXBOUhVOUhH00YnIR@05WiZ<W91mW91lUHahW8mi00:GP6P05I9mIYN0J9AnJ9B2
KIIiIHijIY=kHheaGhU_FhU[FH=_FgaTD71H@e8h<3lW7bHM5alG41dF5AP@40d;2aD?3`02=2`X00<D
3@fQ[j^O[JT01in]ZA[oool6_lG100Bob<C3a/>5HE=D>bh2D3/c00eE@S]G@3Q1;RM6=2a:=2M<Ad1[
ED>2IUJXS7ZkZ9:oZ9Vo[Yno[Y`00[nbY005_k>V_ZVF_ZVD]J6<_Z>;00:hU7X05KBANKRDN[>@NK>C
O;F:M:b=Mjn;LZV0KZJ0JZInJ::0JYeeGhmXD6m6>UH`9SDT72dL52TK6R@E51P>3R4C4`02@3<^00<B
2`[4bLJoaL401ko5`Acoool001[oool8NHZ;015KB48]8a/`:BD`:BDa:bPX8QhT61D[7aL]9R<];2L^
9R0d<2aME4eeLf=iMfEiLVMiLF@00WUaH005NGIZOW]`NWEVMF=HL5a?009`FU401G5KE75PFW5TEg5I
C71KC`02K5Y=00i[FTeXF4]SD4=GB3];>bl`8b4X7aPL510G4a0M514D3a0?2@/@2@/V61D2QJ6P00>@
Z:QiRX]iRX/01gV:Ra[oool8Qi^F015mKfDl>S91@3U1@3U0@Cdk>cDf<Bdj=Rhl?CTi?cTn?cPi@3]U
GE>1Q727RGB7Q7B7QGD00XN5L@05QhUiS8j1R8UhPgQYOgET009oL6@01Gm_I7mcJWmgIgm_H85_H002
NVmO00ilKUmfKUicIUI/Ge1OEDI7?cXn>S0`;RTY;2P];2PV:2PQ8b@R8b<c;b/2Hg]i00>3Thn7ViJ7
ViH01hNKUQ[oool8WjfY0169Jehm;b=4=bi4=bi2>38l<2Tf91dj:alm<b`m>2m7>Bi:@cUlIeZGT7RO
UGnOTX2OU8400YnDOP05WiR5Y9V:WY=mVX=_Uh1Z00:GNFP01IAgIYAkKIAnJIAfHYIgI002SWEQ00j@
Len9LUf6JEEoHTi`ET5B>C17<R<_7aPU7AHY7ALO5aHI4A4J4A0/81X2AeiO00=hOg^O[JVO[JT01in]
ZA[oool8_lG1016UNFa==RUG?cIG?cIC@3U>>C17:bA9<RI=>S=@@CMPASQWEDNKNf^fY8boZYFoZ9Jo
[9T00[n/UP05_jjL`jfM_:N?^IR2^9Mo00:hSWX01K>;M[>>O;>@N;>:LkF;M@02[8M`00j^Q6jVPVbT
NF>OLef?Idm_Ac]P?B]19Qdd8Q/e8Q/[71XU5A@T51@f91l29CPl00=]I6:oaL6oaL401ko5`Acoool0
01[oool8NHZ;01QZIEhf;b`Z9B8Z9B8b:BHb8aX[91lQ71XX8b4Q7A/S9RHZ;bU0=bePF4a_KF5dLV9i
MfUiMfYdLFA_KEedLVEiKF1`G51`He42Jee=01EVG4aVG4m[Fdm[G4m[Ed]/E4eWEdeWFTQSDd9ND4=G
BC`l:b@]8API4PlA3PXA3@lH4Q0D3a0:1@H=2@XL5A<00QlU:@03N8V:NHZ;NHZ;00MiRX/Joooo28NK
UP0HRXb2BDM3>S/g>S/g@T0kA3`b?3`e<S@a>3Xe<SDb=3hk<D0kB4@kK6UJOX5aPHA`QhUiQhUhPhEe
OX5]PHAeRHEdOgATOgQT0W]bG`0EMFmMMFmPNFmPNg=RNf]LNVYOMfYOMfiKLfYGKfIFK61ADTLl@c/`
;B`X92LS8bLW:B/X9RPX71hO7b8R:B`Z008100000hNKUhNKUXNKUP07Qi^F6_ooo`RO[JT069Z=PDXl
=C`a:S`a:TDg<DDa93``:34W8CX`:C@[9CXh<Cdm<ei<?XIiIIN>NYZBNYnEPinEPIbBOIN>MiZBP:6@
NiMnJIN0J0:AN6405HafH8afI8mgI95iI95`GHi`HH]`Gh]cFhI]EX=YEGeQCEm2<d/c8bdN5b0H4AdF
5BDK5R0H5Q@;2aL@42HN6@02000000>Q[j^O[JVO[JT01in]ZA[oool8_lG101RhWY5K@c]=>C5=>C5G
@CYF>B];=bi1;BM<>316=2eA@c]FB3eoHU2ZU7jjYHnkZ8noZYRoZYBnZ96jYHbkZ9K1YXjhU7bhU7X2
/HU`01F]R76]R7F_RgFaS7FaPVb/Pg2ZPFjZQ6ZTOVFRNF>KL5UkCceS?R/n9Ad`7QD[6aXb8A/]71/O
3PhR51<c8ah00P810@03a<W6_lG1_lG100NoaL4Loooo000Joooo27V:R`0HH5]?>S4/<bdY<bdY:RHS
:bLU81PJ8A/I91lL<B/X;B4I8A`H9RXX@c/eH4i5JeaBKfAHKfUMM75TMFePL6AIKVYMJUmAIU=:0V]I
C@0AK556K597IeI:JeY=IeA8HUA6HTe0FDU0CdXn@cT]@c8W;R<I618?5A8@4`l;3PT:2`P:008410H0
128G52lM5C0_;S0_;PYiRX/Joooo28NKUP0HP89bCTa4@d<n@d<n>Sdi?Cll<c4a<S<`<cHa@44m?3T`
;c<^<3/iCTe4KfAHN6mROWQZOWa]PhEePh5`OGQYP89`NgMVMFQL0W]_G`0ANVMHNVMIM6]LNfmOMfYK
LVYHLf9DJemDHf9CF594Ed/nAClc;B`X:2`X9BPT828R7B4R008G7Ql012l^:c/d;18:1A8:1@Z7ViHJ
oooo29n]Z@0HTHAaDd@jA3XcA3Xc?3<]@3D`<R@R<RLQ<b/T@SPb?BhQ=2`S@ShfIUM8RG=QT7e[UhMc
UhYgW99mVXahUHEbVHehTgiXS6mN0Y5fH@0ESVaISViLRG9NTGEQRfmKQfmIR6IDOfEDN6I@Je<oJD`h
CCLV;QhG9QdG7aPA614?5Q0@3P/:3@/;:QlJ=RDK008?20@:WjfY6_ooo`RoaL406;:HPfM>A5A1>UA1
>Tdl=5<n=d8Z:4<_:4<b:e=0>Dde:4Xg;6=AA8]`G:f?NK:GP[ZPR[ZSSKjXTKVQRkFLQ[bTS;JANJf2
K`:aRW005JanJ:b2KJR5Kk67L:Z0JZN0J:QgI9mhI9YhGheSC8UMAVM2;T4U7CDT72`L52@D4b8D51T>
3QL>3SDS7T0Z7`023PL42[o5`Acoool001[oool8NHZ;01RIXJmA?c`b:RLb:RL^9b@e<2dg:1`W6A@_
:2HW8Ah^:RTQ7A/L8b8K8R0T9B99?CMKCD=KCd]PEEAPFE9UGeAUEd]>@cM3>S02D3h`00iNCT1RDTIR
Ac]RBT1WE3eSD3iNBciI@cMD@cM1<2T/71LS5Q@L4a0C3P/23PT;00D:10H510H>2@/E4@meT9D00XRK
W@YiRX/Joooo28NKUP0H]<C;IU]E@d8m@d8m?cljA4E1B44d>34/?Cdi>3Td?T8n<cHb:3Hd;3Xe=3hh
ETm7KFEGJfAKL6aVL71UM7=UN71PI5m@EE960V1EAP0>KF=CLVIHLUm@LUmCMfYCLfIAKf9CJeY<IeY<
ETa1@CL_>S4/<2dX9BLS0R0R8`0571hO61hO7b8S92PVHW]m009gPGh:Qi^F6_ooo`RO[JT06<G9d6Q@
B4Di<TDi<T4e;THm=TPe9CDS73dc;SP^9d4i<c<Y8c4a:cdj<515>75MChM`GHIaI8YiKXYmK8eoK91j
IGaUD6iGA@9hFdD05H=YE8MZF8MSChMVE8]_DHIYDH=TD7eLBGMLBF=7>4/_8ShU7BhN5alG41TA41PA
41<;2`h;2aL@41hI55AWJ@02JFaX2Yn]ZA[oool8_lG101SPf=ehETeG@S]G@S]B?SIFACiG>b]3:29<
>cE8=BeC@S]4<2Q9?SEOC3ikGTbIN6J]RW>[RgZ_U8>_UX6`UH2dT7RRNf:EKEL2W75G01FTO6FWNVJW
MUnWNFFZP66TNF2RMEnKKENEKEMoED=W>b]E;RDn91`/71@U5A@T51@N3PhH3PhQ51<Z7AQ7D5800U]A
B`ZoaL4Loooo000Joooo27V:R`0HTjjXIF5@;2DO;2DO:B@Q:2<P8R8O7QTK91`F;RHQ=2l/>C4]:B<R
:RTY:R`Y9R@N:BTY82LV9RHO=c4Z>cL_=S4/>S4X=R`R0S<`900??C0UB3PZEDPeE44d@c@]A34XC3T_
@cTc=bTU<AlG9AHD6a8@4@h:3@T;2P@6008410H010D41QDC42<H5B`e>09jS8d:NHZ;6_ooo`R7ViH0
6:C2]X:2L3ln=cln=cXl=cPj=SDk=c4b<S<c;Clm=d53?d]9@cPi=cY0?SI2?CHj<d13?cI0?3Y1>4Y9
@4i@ADi>AE5<@DU5>@93Ac/03di7>UU?@6AOBVMGAeM=A5I:?Ui@A5MAB4a3?4Hj<CT`;2h/:2@W8b0R
8a`N7`035ahO00<T:RLa;b`;3`h00XJJU@Z7ViHJoooo29n]Z@0H^<g2RgeY@3<Z@3<Z?C</>S4Z=S4Z
<2DS=2LN@C@/@SXdC3lg>2lZ@3Xe@CdeBC/^EdU0CDHlE4PhI5=4IeU7IUA5IThlF4<a0UM8=00EI4Te
L5<nNF98NeQ4KDm0KDdiLU91JE53G40dDC<T?R@M;QdG7aL@6A4@4`/;3@/:3@/;3@/:7AXE;20K10/:
00:LZ:@:WjfY6_ooo`RoaL406=;Le:>7M58j<E8j<Dll=D`j<dTj<T4[:4@_95<m=E92>ea6?TLg<EI6
?eU:?fa=?85QE7IMCX1QCHe^G8mbG8m[FHYQBWQC?@9iFD405HQK@iAXCiYcF9eYDY5SCY5QAi=UChUQ
D7]??fdo;E@/93lT72dL52HE51h>3QL>3AL>3QL>3BPO6CPU7`061P02^[^i2[o5`Acoool001[oool9
NHZ;01N0Q990=C=0=C<a:bP^;BT`:BDI5A4N7Q`c;b`e<2dl=c=1?3M2?C<l?3<`=2hZ9R<[7QTT71`T
6aX/8b4[92<U92D`9R800S4S6`0E:R8M<2/U<RhV=2`R?C<X=R`Q;b/U=2DO;b<K8ALD81`I4`l;4Ph;
3`T;2PD61P@61@@671<@50l@Cdi=H6=S00aiRX/Joooo2HNKUP0GWZZcEE1<EE1<@44l?d<n@D4l;2lY
;C@b@D<nA4E1Bde7DE5:Ce56BE57@D]3?Slh?CLa=CHd=C@a?c`g@Clj>3dl@Shi0091>c805C`k<d51
>TA6?4Y5>Dm;?TQ5>492>TTo=T<m=3Da;C<d<2HY92@W8b4S8a`N7aPN7aLN7b/[9b@W9daGE4M3?`0<
Qi^F6_ooo`VO[JT05k2_]eI5?UI5?T4g<D0j<d8f;bPP62dY94<j<dHm=Tm6?U99@519?4i:?TU5>DPh
;dHa9ch`:T@`:50m<Thl<d<h<ddh;P02C3@V01E9=RUC?c=GASEMA35PBSMF@2eB?c=G>Re<=RPi9Ahe
:24R614N5a0I4A0D2`/>2`X=2`XU6aDM5QE6C4Tl=c@039n]ZA[oool9_lG101O>`LMWC4=WC4=@?cQ@
@CYB?CHf9Adm<2]D@SYFACiPCdMQCdMNCd=PDdMQCd9RACUP?c5H?SIS?c=`D45/BcmNACiXA3L00VE1
;P0EId@cLdlnNEI1PEDmP5U3Ld`gLThnMDPgIT8bCbdTB2lW<1dE:a`D9ADD7Ph>5`h=5Ph=;alI9aXI
Ada9<BPV00boaL4Loooo000Joooo2GV:R`0GVj^]F4I1F4I1;RHS;2@Q;2HS=b`X=Rh[=2l/>CDa<2XW
:bHT;20O=b8N=R4J:b<P7Q/I8b<P6aHD6a`L9R<Q8QlL6A@C008F5QL05AHC4Q@?41PF4a`J5A/I5AXC
4QT@41PB4AXC4Q@B3`h=2Pd92Pd82`h92`D51PD41Q`C6Q`C4C8Y96AoPH>IVP0<NHZ;6_ooo`V7ViH0
5k77`79UGW9UGSlm>Cdl=cdm>DU4?T92?T53?dQ;AD52?C`n>Sdi=TLk=DPk<Sdl=S4e<C@j=Rd_;2dc
<STl>3Dh<b/^:`02:Bl^01DY;BXV:2P[;b/`=2d^<R`_;BX/:RP/;2X];BXX;2PP9R8P8b<O8R<P8R<H
7QlG7Ql[:bl[:bU0?SQ5GUf2Thh038NKUQ[oool9WjfY01O3clYfG5AfG5A0<bdo<b`n=2e8>C4n=S12
>SA<A3a4>S=1=c52<Ba>=B]=<bM1=2/c:B<h<BX`8Qdd;2Lo=2dg;RL^8Q`00RhU800E;R4K;AdI=BPO
>B`P=RXO=b<L<alI<B4K<R4K9ahG71H@6Q4A5a0@614@3P/;3@/:9A/O9A/G?S8Z<DU;QXf900bO[JTJ
oooo2Ko5`@0GgMkJRFALRFALD3`dDC`eCcdeEclhBC/eDT8kGTe5Ed<lET<kF3dfI48eHSl`ECleAc4Z
CCXaA2XSCCL`EclfBcL_@bXS0095;RP05DDZ8DDW8E4e:5Dh:E4f9e4/8d/X8DP[8dPZ8SPU72/K52LF
5B<D52@D51P>3QL>3BlO8blO6TTg<1/`=8n7P`0<_lG17?ooo`006_ooo`UiRX/05h>IU92JVY2JVT0g
<R`V8c4[:2hW93Pd<2PR7RXX9RPQ7R/W93`g;S0^:bPW9B/V8b/T83@Z9b@K71hN71lF4b4E4QXB3`02
4a4>00dF4PlN5Q@O5A@G40lD40hF4@lN5Q@J4a0H4PlB3PXB3P/?2@/>2@/00PD41P053PT;81/G9aXF
QiRISJ>S00eiRX/Joooo2HNKUP0GTZbQ[Kbi[KbiE51:?Cdi@44m?cljADQ3>c/e>Shj>c/f>chjBDa2
@DE0>cll?Cdi?C`g@Clk>3Dd;S@a<2l[<bhZ;B`X008U:RH03BP[9bh_:c0]:bTZ9bHY9RP[9bl_:bd/
:2T[9bDW8b@W8b4S8b0R8`025ahO00DO8R<]<B`g<Ri^NWMlSXX03HNKUQ[oool9WjfY01NX^k6j_;Vj
_;UD@c/n<be2>390=Bi7@3Tl<2To>38n<RXo=S1<ACQ4>cA0=Bm0<b`m<BU1=Blf9bD^:B<a8Q`c8A/Z
7AL00R8K5@0=9Q`F;R4K<20K:1`F9Q/F9adF;b4K:QdF9a`F81L@7QL@6A4@610@008=2`/01AL@42LR
7C@S7EUSHFijM`0=WjfY6_ooo`VoaL405lK?am;5aM;5aF98?dll=5=0>E0m=EM8@Dhi<5A3?E4k<U90
>Ee=@5M3>eHn=U<l<ddh<4ll=DH]:ch`:T<Z8d@Y8SXT7002<B4J00df8Q/n9b119R0j8a/h8Q/i8a]0
9b0j8Q/g8Q/^71@Z71@U5A@S51@00QL>3P058A@C<RLR@BPS@DA4GV5O00foaL4Loooo000Joooo2WV:
R`:?V9h055Dk=SD[:34[:2hW91dM6S4_;3/f<S@a;BDQ7RPO6R<I5R<N6bDP71XG7APL6alI6B8E4aXB
6A<B41@C408B3P/04a@B3a8B3a8B3a0>2P`82Ph=2QDA3Q4>2P`82Q4=2a8>40l92`D41Ph92aXD4BTP
6bDH5I2UYI2VY`0>NHZ;6_ooo`Z7ViH2Y[Je01A_FUA5@Ce0@Cdo?cX_=C52AT57BTA6BD<f>C@g=c4g
=2hd=S8f>3<]<3@Y<c8c<c4b;B//;30U:bPV;2P292LS014U:bLT:bLT:bLS9b<N8R8P9R8V:RHT9b<N
8R8S9R<T9bPQ8b@G7QlP8R<Z;2Pf=S4c;b`00W^<R0j7ViHJoooo2Yn]Z@:j`;l057EABDHh<T8h<T4e
;S0[94M0>4Q1>TQ0>3H^9c/_9CXY8CH/9SL]9R/S9bXY93<V8c0P6bXM8B8L5b<M5P8N5a004b0K5B0K
5R4L5QhG41P@41/F42<K5AlG41P@41dF41dG5QTA40d;2aP@428L5S0W82hP6fQeLVQcL00>WjfY6_oo
o`ZoaL42e]?B00^:Fe9F@3UC@3UB?SI2=2aLBT9FB41IB417=Be?>Be><bT00TTf;P07?2/^?38/ABdZ
?bHQ>B@X<B8L<R8K008[71@04bdQ6RhQ6S0R6bdL52@E52TK538P6RdL52@E52/K52TK6RDE51L>3R<D
52`P6SPZ93TU7e=HEU=CDP0>_lG17?ooo`006_ooo`YiRX/2RJBN01AcLVXf;RT^:BH^9b@e;BT[:RLY
9b@X81dR6aPL6API4PlR7A/N5aTP5aPJ4@lI4AL?3A0;20X@3@lA3A023PT;018@3@l=20/@3@l>2@/B
3Q0G4a4A3Q0=2@/510H310H310D410HB3Q0D3`/=2@XD2`V0Shn:W9d?NHZ;6_ooo`Z7ViH2V;N[01B@
UX]9AT0n@3/o?cY6@chj?c/i?SXk>SDd=C0]<Rl];2Pb=30`<30b<2l[:RL[:bhR9bPN8R8R9RLS9bP2
828T018Q9RLO8R<Q9RLP8R@T9bPW:bPR9bPP8R@G7QlE7AlE7AhF7QlS9bPT:2<O8R8T925]O7QfPGh?
Qi^F6_ooo`ZO[JT2[/Bj01BMTXM:>S91=c51=Bi6>S<j=S0n=c0n<2Te:B8]9R4]7QLb:B<_8b4a8b4W
6aHX7B0M5aLH4A0L5QHM5QH26A4A00TK5ADH410L5QDI4A4M5aHQ6aHL5aHI4A4>2`/00P`:2P073@/:
7AHF71L@5a0?8A@?GVYWI6YX00nO[JTJoooo2[o5`@;:eLh05;JLTe]0>5=1>U8n=UI1>TTn=e91>U4j
<DHa:Sl^9chU748a:SlZ:40Z9cDQ73PS9b/L72HE52XK6bTK6`8U5A@04RPJ6B@E52TK6RDE52TK6RdP
6RPK6RHE51P>3QH=3AL>3AL>3RPJ6RLJ4b8D4blJ4dmEDU1=B`noaL4Loooo000Joooo37V:R`0D^MSH
OgQ`<BPS:B@Q:RTV;2XW<c0/<RX/9aTG8a/H61@A5A0>514>618>3@T:2`P94@d?4`lA3PT;4@d?0Pl9
2`0B4@h?3`T;8aLD1`D73`d?5A8@4`l@1@D61@@62P@650l@5Q0A4`l@9APE>BLLJ4diHV1FNXb=3gV:
Ra[oool<Qi^F01C=knZDTXQ3@CXj?3Lj@3/m@Se1AT54@T8h<Rld<bl[;BTV:BHW:bHY:bHP8R<M8B4S
9RLU:2PP8R<R9RL28B<T018R9RLQ8b@a;R/J7b0P9RHV:RPU:2PH7QlG7QlK7QlT9bLW:BTS9bLc<2e7
?C9WFdU6?2f6VYD?Qi^F6_ooo`bO[JT05=_bkYB6Nd8e;3dc;3`g<3li<T@n=dDh=SLU7S<V82HN62<J
52@M5RHL5QXA4AL@3adF5QhG5aP@41`F5@8I4A404Q`F5ATA4BdO6Q0<2aXE5B4K5QlH5Ph;2`d;2a8;
2QdF5AhG5a/F5BlQ744_8E]<>cH]8IbXY0nO[JTJoooo3;o5`@0DkOKcWHEjDC/bCc`eCClhDD8kE4Lo
ET0mAR/T@RdV=B@M<R0I<b<L=B8K9aDE91@C:a/K:Q`K8a@D:1/J0RDE500B9aXI9ADD>2@O6Pl>9QTI
;B0K:a`K60h>5`h>70h=9aXI:1/J9QXI>bHQBS<VEDXm9Q`C^[^i3ko5`Acoool001[oool=NHZ;012i
f=R2LVXi=2lW8Adc;2Te<2`i<bhZ:2<X8alP5A`B3Q4J4Q0B3Q0G514I5A4C3a023PT;01@=20X>2@/>
2@/=20XG4a0?3Pl^<3dd>3`Q5al?2@/D3a0K5A4K5Q4D3a0Y8ah^8Q`U6AE0;BMmU9b4WJ0@NHZ;6_oo
o`f7ViH04<g_jYR=PdY:A3Pi=452?DA6@DY:@ca1>SPj=C<^<b@W:B/[:2@W:2T/:2X]:2DX:08P8R<0
51lR8R0R8b0R8alR8RL[:20V9ci5C45;CC8`=R8S92HX:2/]:B/^:B@X9cLh=3di<c<a;4Q1>f]lOX6A
Ra27ViHJoooo3In]Z@0@fo;^Uh1eBClg>BhW@cXdAShgCD8i>cD]=bhV;alT7QLG9a/F7QLF91dG8adF
7QLF0QPA400;5a0?614@614@5a0?8Q`F6QHE?CU1>C`m;20U6Q4A7aLG008S7AL01adG5C<[9CLZ8blR
74Pg;UmZJXB6OP0@WjfY6_ooo`foaL404>gflj20MEI4?4Xf;UA4?EI7?ei;@T/k<dHd;3dU:BXL6cDQ
6bXL6c4R6bhQ6RTK6P8T51@0528D4b@D52@D528D4bhQ6bHJ6TXnA3ll?CLS:BHE5B/L6bdP6RdQ6RPJ
6Ch`:T4^9c/W8E@m=5=CD8UiK12oaL4Loooo000Joooo3GV:R`0@^MSHPW9Z>C@_9b4M<b`Y=C0/>C<^
:RPS:2<O81DL4PhA6Q8@4Ph@5a@A6ADA4`l@0Ph92`0D3@P:3PT;3PT;3@P:5a<@3`h?;S0m=3Pl8ALO
3`T;50l@6aDA6aHA50l@:B<N;R8L9ATE@2dWOIBLQ9fP47V:Ra[oool=Qi^F013=knZHSH=:BT@h>CA1
@Se4AT5:BT<l@CXh>SDc;S<T9bT[:bPT9bPY;2PZ;BPU:2P2828S01@O8R8P8R<P8R<O8R8W:bPP9RLn
ADa1Bddb<3HR8b@V:2P[;BT[;RTT:2Lg>3@m>C<c<Ba8@C][O7j1TH/@Qi^F6_ooo`fO[JT04=_bkYN0
MDTo=cT^9d<j=4Hn=de2>C/e;CL^9RlO91hG5bLK5QhG5R@M5b<M5QhG5P8H4A002aL@3aPA41PA41L@
3b8L5QXF5Cdi@CTl?B`P9AXA4AlG5`028adG00LM5aDc:bDg:R<_8Qa8=biOJVZ4QWh049n]ZA[oool=
_lG1013]m_>PP7EFA3a:=RiDA3eFAcmNBd9;>c=6=2`m9BTZ71/e8A/Z71/a8Q/^8AXY6aX291@D01@R
51<T51@T51@R51<^8A/V6QY:?T@o?3dg8bTV5AD[71/]81X]8AXX6QTn<2Y1;RLk9b5D?CACDe29NF`@
_lG17?ooo`006_ooo`iiRX/03/3UiH9`J4Lk=RLQ7RDU8c@c;d4g<S<U72XO6A/E4A4>40d92a0=2Q4=
3`8>2@/0518>40l:2a8>418>40l:2``82RL[;2DM9SP_;Te4>T<e=4Pl=cL[9A/E4RHN6B<L6C4[:4Xc
:HZKVhRKWA5iRX/Joooo3XNKUP0>do_fUhZ0Ee9;>3Td=S`h@dQ3DTi8@cdc?3P`;BhY8RLX828S8BHR
8bLW0R0R8`0D8bLX82<T8bLX8bLX82<T7R4R=Cln<c@iAD=3G5Y>Dda9Ddi8AT4k;BhZ=CD`<C8_@44l
EDPnMX>0OhV54HNKUQ[oool>WjfY01;Oo?RGOG9FB40h;RLj=Bm7@S]DACe2<B@j:b4X7QPL5aHI4A0K
5A0M5QDI4A0H4A0M5QHI4A027AHF010I4A0F3`lb<c8_9Ra6?CeID4A=?C];@3Y0<b/W7aPb9b0]9Am1
=c5C?C1TKF]lNWDAWjfY6_ooo`joaL404^olnZ1lLV=>ATPe;Di0>E]<A6A=ADlh:TTb:3@S7BPK6bHE
52PJ52TK6RDE52@D52PJ6R@D508X6QX042@D528C4cli=c/[<UA7B6AEBeHo?Tm0>dPe;c<S73h]9CXZ
9E0o>5e1=E1BD7UWH16oaL4Loooo000Joooo3WV:R`0@M8F6^=cLLE];BCdf>2l[=C4^>cLb@Cdj:b8N
:AhK=b`W<B/T8QLC6A@@510A4`lA0Ph92`8F4QT041@@4QPD4@h;31`M5b8P7@d;3@d=30`=2``;3ATA
3b4J62dR6Ddh:HR>T7R=UGV;S15iRX/Joooo3XNKUP0@PIFAcOG`QWITFUA;AdE0@TI1Bde7DEA>?S/e
>SLbAD4k@D4j<RlZ:R`X9RTX9BPX0R0R8`8V:Rh042HY:RT/:1lS8bde;S0f<b4V9R0X9AlV920U9R/[
:30a;S`i<599>h:;QVehNXNJUQ67ViHJoooo3Yn]Z@0BVZRTgOWeR6YGFd]1Ac/cAClhD4LoE4]4?BdU
>2XS@3D]>c<Z:ahH91dF7aPG7QLF610@614@0R0K7`0@7aPH8Q`F6A<B;B/S<R`Y7aLG81/E7ATD7ALF
:AdG;B@O?2dQDD0`NGehJVYZWjZV4In]ZA[oool>_lG101:k`Kkbo_ZDK5YZDdUE@CYFBD9SDDQTDd]<
<bY6<2Q:>C54=Bhf8Q``8AX[71/Y6aXS51@T51@2;1lT010[71`^81XU61Lo=Be3=C8`7ahd91d_8A/_
7Qdi8a`j:bA:=2MIAcQcLF]XFEJo`;dA_lG17?ooo`006_oooa1iRX/04;kWk6mZG2hV82LT8Sdj=dU9
AD]5?b`R7Q/E5b4E4c4X92dX8aHA4Ph92a`H7R0K8`8W92003b4L8CH_;AlH7SDb<S<[;3T^:CX^:C<X
8cT^:4Q0=CT_:EI4=Y>RXiJc/7b@S`0BNHZ;6_oooa27ViH04=?ooh>2LD50>3Hj=dY=BEMLEUeME3hk
=Bd^;S<^:d4o>Shn>2PZ:R0R8b``=30c>08e>SD03c8d=d92@C4a=Ce2@T=2@D]6@4M3?T8n>4M3?59B
AdM5?UYDB8>?RY:WVhFHU00BQi^F6_oooa2O[JT04>3ooh=eHd<e;3Xc;E19@e]GCemDBS/]9B/P7c<Q
73ld;CTa:B8I61PA42LQ9BXS:08`;2D03bdU:Cdf<bXQ93Xh=T4g=DXj<T4e;cda:D8f;T]5>D<h;eM:
?7AkMI2FRINQX00BWjfY6_oooa2oaL404?7oohmcHUHn=4hn=f=ECVaOEfmJD4Pb:S/W9T@Y8ddk=4De
;BdM72@D53<V:SDW;08k<2X03cTY;THj=cDU:4<l>dlm>UQ0>4Xh<dLe;D`j<U55?4hk<ee>@F=QFXn1
LJn][`0B_lG17?ooo`006_oooa5iRX/03kkMh/WBg5eCCR/W92TT8cDj@U9@CUiEC5aLECP`<B/]<4U9
EVMSGd8f=30/=P02<2P^00i6@Tdg<C4i;BHa;2Ti;BPj9b@j9Qdh;BQ3>2mH@398;21]RI24XZEiRh`C
NHZ;6_oooa67ViH03m?emM;Nh6eYHc/n>S/l>DIADf5UHVUVG6I[HdQ7ACe3A5ILHfiaKE1;Ad12B002
?Si300iCEEU4ATI;ASdk?S]:ASm9?cY9?CA8@ce?C49ODTAKASQILWF1UY27VYHCQi^F6_oooa6O[JT0
3n3gmlO8afQKDclf<4<i<di?DFAMF6EICf1METHi=cdj>E=AF6APG4Pk=c`e?@02>c<f00iABdm1>SU;
>c4i=31>?SE:=Bi:<bM9>S9?@cMNBc]L?2]@HfJ4Rh:OZZHCWjfY6_oooa6oaL403o7inKba[FmJDe90
>E]8@6EMGG=SG6YID6EJEE8m>de1@5eDF69IEdhl>DPj@`02B3Pk00iKD59=?ceJ@SQ4>SQQAciJ?CIJ
?2iH@CUKBCeWDD9/AC=7DE>9O6no`;dC_lG17?ooo`006_oooa9iRX/03XjYXlk^k7I_N48l>S0a<cm8
CdaAEDA6A51ABUeJEeA=A4Hn>Clg<D8j<08c:bX0324K5RHQ7SD`;34[:3`Z8TXa9d`j<5]5>TL^9D<o
AJG1c8^SY1EiRX/Joooo4XNKUP0>W[b`g?chRHN<DE5>@DI4BEYNG6EUE5]GHVQNJ6UTGEmDE5=>De59
DDi30T=2@00<<S<]>3/gA4I1@44mBD8iEdPmFTi4IUM;EDDlCDmAY;RkOXj95HNKUQ[ooolBWjfY00jc
b;kOlO26NGeBBD=4@3i@F5eRHF1KEe5WHeQVGe]LEdaHCd]HBT1AASX2@SPf00`d:B8m=2i7?SM2>39>
>RiJ?c9MASUWCd1G?31DCDbRYjEcNWDEWjfY6_oooa:oaL403/kHdN?SiXefN69?BEM;BF=TJGEZIg1R
FgU/HVmPGVALE6YJF6aEBem<@`9A?cl034Hc:e8o>eU7?e=0>F13=fU8>f]<@7=DAVE4=fQHE:6@R6UQ
FQFoaL4Loooo000Joooo00=iOh5iQHIiRX/04GV:R`0<_]gDf?[hdmoPGei^D4iEMWB5MVmiGe1;C4A0
BDE1GeAEIEIC0V5FCP0;KEmHGE95Ddi7IEQBD4i5@TLm<bdZEEeY]M_W_^[WQ9ZJ01IiRX/Joooo00>7
TXj7UI67ViH04HNKUP0<doGUeoKbe=oHKW=oGF5VOX6:PX67K6ENG5]EFEYDK6QUKfMR0W1[H00;MVmW
JVAGGUiEKfYRGF9HDEY?ADE0EV9V]MCJ^MgCPI:>01J7ViHJoooo00>OYJ6OZ:BO[JT04In]Z@0<h?OZ
amWI`/FnK6UeIf=VPWj7Pg]oLF9II5YBHEQ@LF=PKemI0W5RE`0;LVALIUU;GEI<Kf9IGUU=Ee95C3de
GEmP[[k1ZkfdQ8^901JO[JTJoooo00>o`;bo`KjoaL404Ko5`@0<lOW`/kBi[ZJOMVagO75cS8>8SGn0
P6aSNFMPMVALP6]WN6AN0WeWG@0;MVANKEY=J5UAN6EMJUaAJeQ;HdHlK6APYZ2OVYB:RH>301JoaL4L
oooo000Joooo00=iT95iRhaiRX/04gV:R`0:PiVD`=_<^=[CXl:eWKBo[LOCYK32IFQoAe1S@DA70TA2
?`09?clmAdA3@Chk<blW>3<[PY:CgOooY/_4OY>C01QiRX/Joooo00>7X9^7VYJ7ViH04hNKUP0:TZbQ
dNgI]=G>Y<2_Z<;8/LcD/;c4MWf=EF=_DU]L0UIHDP09CUE@FE]GDE=>A4LnBd]2NXR3gOceVk^_Q9JB
01R7ViHJoooo00>O[j^OZZJO[JT04in]Z@0:Z;^af^_MZ<2oY;FW/;k7/L38[jneNgN4GV5[GUUI0V5G
C`09F5=<I5UCFE18CT@hEdXmMh1ic=kGS:6HTIVI01RO[JTJoooo00>o`l2o`;foaL404ko5`@0:a/o7
i^SQW:F]YZJN_;c7/k>j/ZBURW^4M6abN6MU0W]UG009Kf5IOFMOKUaBIe95LEU;MGI^]kN_O81iY9nR
01RoaL4Loooo000Joooo6WV:R`06PiV@Ni:ASZZO^=C5`=c<a^OU0/OQh@07anGUan[Zc>o_d_[ndoOm
RJ>UNH^<01YiRX/Joooo6XNKUP06TZbKQYjKW[^[aN3>`Mc:a^OT0/KPf`07a^3La^KQc>_VdOKfd>o_
OiJ@QiZF01Z7ViHJoooo6Yn]Z@06Z;^]VZZ[/lJhbm[?^<W0_M?E0[[9a@07^/W6^/k:_m;>`MWI_m3>
NHR2WjZV01ZO[JTJoooo6[o5`@06a/o4];W0c]?9e=?B[[:b/[W20Zf^ZP07[JbX[Jn[/;:^[kBdZZNS
M7M__l2m01ZoaL4Loooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00A_oo
o`<0001Ioooo0`0005[oool30000F_ooo`<0000aoooo0019oooo00<0003oooooool0FOooo`030000
oooooooo05[oool00`000?ooooooo`1Joooo00<0003oooooool0;_ooo`00:?ooo`D00002oooo0P00
00Coool200001?ooo`@00002oooo0`0000?oool300000oooo`80000eoooo100000?oool200000ooo
o`@00003oooo100000;oool300000oooo`<00003oooo0P0003Koool400000_ooo`@00003oooo0P00
00Coool400000_ooo`<00003oooo0`0000?oool20000=_ooo`@00004oooo0`0000;oool200001?oo
o`@00002oooo0`0000?oool300000oooo`80000[oooo000Zoooo00D0003oooooooooool000000_oo
o`040000oooooooo00000_ooo`040000oooooooo00000_ooo`040000oooooooo00001Oooo`040000
oooooooo0000>_ooo`030000oooooooo00?oool010000?ooooooo`0000;oool00`000?ooooooo`03
oooo00@0003oooooool00002oooo00<0003oooooool00oooo`040000oooooooo0000>oooo`030000
oooooooo00?oool00`000?ooooooo`03oooo00@0003oooooool00002oooo00@0003oooooool00002
oooo00<0003oooooool00oooo`040000oooooooo0000>oooo`030000oooooooo00Koool010000?oo
ooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`0000Goool010000?ooooooo`00
033oool002[oool01@000?ooooooooooo`000002oooo00@0003oooooool00002oooo00@0003ooooo
ool00002oooo00<0003oooooool0100000;oool010000?ooooooo`0003_oool00`000?ooooooo`02
oooo00@0003oooooool00003oooo00<0003oooooool00_ooo`040000oooooooo00000_ooo`@00002
oooo00@0003oooooool0000loooo00<0003oooooool00oooo`030000oooooooo00Goool010000?oo
ooooo`0000;oool00`000?ooooooo`0400000_ooo`040000oooooooo0000??ooo`030000oooooooo
00;oool5000000Goool0003oooooool000000_ooo`040000oooooooo00000_ooo`@00002oooo00@0
003oooooool0000`oooo000Zoooo00<0003oooooool00_ooo`800003oooo00@0003oooooool00003
oooo0`0000?oool200001?ooo`@0000koooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`02oooo0`0000?oool200001?ooo`@0000loooo00<0003oooooool00ooo
o`030000oooooooo00;oool200001?ooo`<00003oooo0P0000Coool40000??ooo`050000oooooooo
oooo000000;oool010000?ooooooooooo`800004oooo0`0000?oool200001?ooo`@0000_oooo000Z
oooo00D0003oooooooooool000000_ooo`040000oooooooo00000_ooo`030000oooooooo00?oool0
0`000?ooooooo`14oooo00@0003oooooool00002oooo00@0003oooooool00002oooo00@0003ooooo
ool00005oooo00<0003oooooool0AOooo`040000oooooooo00000_ooo`040000oooooooo00000ooo
o`030000oooooooo00Goool00`000?ooooooo`15oooo00@0003oooooool00003oooo00<0003oool0
00000_ooo`040000oooooooo00001Oooo`030000oooooooo03[oool002Woool200001?ooo`800004
oooo0P0000Goool20000Aoooo`800004oooo0P0000Coool200001Oooo`800018oooo0P0000Coool2
00001?ooo`<00004oooo0P0004Soool200001Oooo`800003oooo0P0000Goool20000??ooo`00oooo
oi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooo
oi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooo
oi7oool001[ooolHO7al00IcDcn2Kf9lJfQlM6]lIf1lM6/4O6mX00MlIf1lJe]cHeMhGeA_DdQdFTiZ
DdL016mFBP06Kdm3Ie8oJe99Je8oJe99Tjfj17alO09lLg@00gb1PGalO7alO007O7al6_oooaQdLgH0
1Va>?GQWGGATHWA[IWAPFgA[IPAdIf801gAPFgATEfaMDg1ID6Q>AFaDBVA>A004J55700IXBT5PCCeT
CDETCCeTCDF6WZd4M7=f0WA[KP03M7MjM7=fM7=f00MdLgHJoooo67>7Q`06KFUJM7IXLgE]Lg]bLg=[
Lg]b17=iL007Lg=[LgEVKFmQKf]MJF1CJf9EIEe@00AWGU001VMIBf5JAf=JCF=JAf=JCGVGV`AcQhL2
Lh6100=cR8QcQhMcQhL01g>7Qa[ooolHJWf000IXK6=ZK69ZK6IZL6YZKFMZL6X4JW5[00MZKFMZK6=X
JEmWIEYUGE9TG55QF4d0161HC@06H5A9GUA5GEA8GEA5GEA8IgAf16YmP09ZNWd00fYlOfYmP6YmP007
JWf07?ooo`006_ooo`06O7alO7AeO7emO7alO7AeO7em2WalO003O7AeO7emO7al00ElO7`027]IAH5_
JWa[GgadK7aWH7adJga_J7aXF@9dHE<027EQDgEMCfaFC6QBAfQ>@faDB6==@W1GB`9_ETX2Ke1400EW
DTI[DTQ[DSm[L7FCZ[H017alO09lNg`00gb0P7alO7alO007O7al6_ooo`06M7=fM6]]M7=eM7=fM6]]
M7=e2WAcMP03M6]]M7=eM7=f00EdLgH027AEA7UXIWATFWA[IGAPFgA[IWAWHWAPD`=[F4/01f]EB6==
AEi:@Ei7?V9=A5]7?VQ@AP02J5570VQ:@005H4e3I4e5I4dmI6acQZ2_00IdLgH00gAhNWAcMWAcMP07
M7=f6_ooo`06LhN7LgioLhB5LhN7LgioLhB52W>7Q`03LgioLhB5LhN700EcQhL027EaH7MhLW=eIg=k
L7=cJg=kLW=iL7=aH@9[IeL026UWEfUSE6=KDEeGC5eEBF1ICE]DB6ELC`9WGU02IeM:00EQFTeSFTiS
FTMSNGYiXZT017>7Q`9cRHT00g>;Rg>7Qg>7Q`07LhN76_ooo`06JWf0JWIiJWUmJWf0JWIiJWUm2VYm
P003JWIiJWUmJWf000EZOH0026icJFe_K6Y/HVY`IfY]IfY`JVYaJfYZGP9TH580265PDV5LDEiECUMA
BEMAB5UCBEQ?AEeEB`9PF4d2H55700ENE4]ME4YME4EMKfiWQH/016YmP09ZPH@00fZ0PfYmP6YmP007
JWf07?ooo`006_ooo`0:O7alO7]lO7QhO7emO7]lO820O7alO7AeO7emO7Ae0WamO@AlO7`00gakO7b0
P7alO005O7al00QdDcmmK61lJfAlK6QlKfQlJfAlJ65dH542FeeH00QcFDiaBdMWCd=[F4a_FTi_GE1_
EDU[DTH3J51400IXDT1WDTI[DTI[DTJ?Z;V?UIP6O7al00=lM7ElOGelO7`01galO1[oool2M7=f00Qd
Kg9dLgEdLgIdN7YdLgIdJfedLgEdJfd2M7=e1GAcMP03M7QjM7=fM7=f00AdLgH026]>?G=SFGATGWAS
HWAWHWATGWAOFV]HC09BEE<026I@BFM3@Ei6?V=AAfQEBfQHCVUAAfA=@`=OBT001Um=?F1=@fA=@fA=
@hRQ]8R?UPIdLgH00gA[KGAcMGAcMP07M7=f6_ooo`0:LhN7LhV9Lh:3LhB5LhV9Lh^;LhN7LgioLhB5
Lgio0W>4Q@AcQhL00g>9RG>;Rg>7Q`05LhN700Q[IeQ`LV=cMFacLVicNG1cMFacKfM[JE`2E6EP00QP
GUEUD4aODTQSGU5WI5IWIeUYHU=SFT`2GEE900MMEdYMFTIOFT]SFTaSFTf3Yjn3X:801W>7Q`03Lgio
LhB5LhN700McQhLJoooo00YZOH1ZPHAZNGaZNGeZPHAZP8=ZOH1ZMWUZNGeZMWT2JWUm16YmP003JX64
JX23JWf000EZOH0026AYH6MYG6Y/IfYYIVYaJfY/IfYVHVASF`9BGe`025IHDUi;BE];AEeFCF1ODf1Q
EFAMDEeDB@9GCdD01eMAAeMD@eYDAeeDBEeDBgN=TWN@U006JWf000=ZMWUZNGeZOH001fYmP1coool0
01[oool2O7al00=lLgAlPH5lO7`00WalO003O7]lO820O7]l009lP80<O7al00QkDcn1Kf]lJfMlJfAl
K6AlJ61lJeakJf<2O6eY00R4J5V4G5maG4ahETYhE4mhE4i^AT5WD4@4Je9600AcFDmZDTI[DTJC[KX7
O7al00=lNgalP81lO7`01galO1[oool2M7=f00=dJfidMgYdLgH00gAcMP04M7QjM7=fM7QjM7Qj37Ac
MP08M4hmNFMVM6ARM6ANM6=NM61KM6AFM6AO0W]YI`04P6EHOUYNKUU<LU570W9=BP03JD0nH4Y0I4e3
00=TCD<016eDC6E=@fA=@hJN[@QdLgH00gAhNWAcMWAcMP06M7=f6_ooo`9cQhL00g>1PG>8R7>7Q`02
LhN700=cRHUcRh]cRHT00W>;R`acQhL027EYFWMfLG=eKg=eK7=bJW=aJG=eI7EgKP:0OGH0281jJGe_
KG9YFg9ND79IDg9IEFU=BF5EBP=SFT`01F=JCFYQEFEKCF=JC7VGV`07LhN700=cRHUcRh]cQhL01g>7
Qa[oool2JWf000=ZNWeZO7mZOH000VYmP003JX64JX23JX64009ZP8<<JWf000Q^K6=]K6UZK6UZK6MZ
JFAZJVEZK61^L6X2OGIb00QhMFUdK6Y_I5Y[F4e[Ddm[De5TBDQNCTL3GEA900EME4]SFU1PET]ME4UW
M7H01fYmP003JX64JX23JWf000MZOH0Loooo000Joooo0WalO003O7]lO820O7al01=lO7`00gaIAGa_
Hga[G003O6]T01AlJf=lLfilLVYlLVYkJV9hIEYcGE9kH5AkHeQcEDikHeE]C4EcBdIcHE]ZDDEcDTIc
DdIWD4AcH5>B[;TAO7al6_ooo`=dLgH00gAhNWAcMWAcMP0BM7=f00=dEDAdJ5edI5H00gATGP0?M6AO
M6aZM6aVM6aVM6EOL65GK5U@MEaCMF1FKE5;MF1CJTY4KDE3KE]HIDi4009]CD<00f1:@6eKD8NO[P0A
M7=f6_ooo`9cQhL00g>9RG>;Rg>7Q`0CLhN700AcLF1cN6QcMF9cMFX2LgE/01AcMFicOGMcOgEcOgEe
NG9_MfI]KF1eKV5eLF5]HUIeLF1]FE1/D4a/IV9UGE1ZFTaZF4]QEdYZJEYlW9lALhN76_ooo`9ZOH00
0fZ1Q6Z0PfYmP00CJWf000AZLfUZKf5ZK5eZK6@2JVaW01AZK6YZLg1ZMg1ZMg1^Lg1WLfAXJF1^J5m^
JeaXGE=^Jea[EdmVBTUVGE]PFDmSE4USDDMNDDMSH5A[O7dAJWf07?ooo`006_oooaQlO7`017aJAGa[
Gga[Iga[G`9lJf@057acJga[I7aXHGaXHGa_J7]ZHX1/H7MUEGQNFGMMDWAMCVm?BViKBfmFAfmJDf]A
AFQBAVMBAXN2Ph^P[0QlO7`00gadMGamOGalO006O7al6_oooaQdLgH017AE@gATFWATHWATFP9dI5h0
57A/IWATGWAOFWAOFWAWHWAUGgUYGg5RDg1IEW5ICfaHBVQ;B6UHBVQ@@VUDCfA>A5m=@f1=@gmlPH>G
Y`QdLgH00gA[KGAcMGAcMP06M7=f6_oooaQcQhL027=_Gg=eIg=eKg=eIg=eJW=eK7=mLg=eK09cKfL0
47=iL7EiLWUoKg5fHfmYHW5[GF]UEFYNEFUXEFMKBFURFV=MD5eJC5mJC7V6QWfNYPQcQhL00g=nOg>4
QG>7Q`06LhN76_oooaQZOH0026Y`IfY/HVY/JFY/HVY/I6Y/IfYcKFY/I`9ZIV8046YaJficL75jKF]a
HFMSGV]VFfANDFELDfARDf1CA6ALEUeICeMDBEYDBFafN727S@QZOH000fYfNFYiOFYmP006JWf07?oo
o`006_oooaMlO7`02F=2>7mPBga[Iga[Gga[G7a[J7acJga[I7a_J002O79Z011lLf]lIf1lJf=kHUJ0
HUIgGU1gGU9cDTicETM^Cd=WDdMWCCmcDTIZDTJ9Uj>2SY88O7al00MlNgalP81lO7alO7alM7ElMGEl
OGd00WalO1[ooolGM7=f00UJ>31bDT1dI69dI5YdI5IdI69dK6IdI5idIf800gA/IP0?M61KM6AOM5eD
NEeCLEU<LEU?KDi;KE54JDY1H4e2H4LkKDe3IDe3OXfKN8F<00UdLgH01WAhNWAcMWAcMWA[KGAZKGAc
M@9dLgHJoooo5g>7Q`09FdY0Jee=LgE_LgEWLgETLgE]LgecLgE/LgU`009cOgD047=mLg=cJg=eKWEa
IGU`H75YFG5YFfeOEVeND6UIBemFB5mDAFYJC6EJC7B?UGBCUPQcQhL01g>9RG>;Rg>7Qg>7Qg=nOg=l
OG>4Q@02LhN76_oooaMZOH002EQ9@eiCBfY/JFY/HVY/H6Y/IVYcKFY/IfYaJ`02JWM`011ZLfeZKFMZ
K6Y^K6AaJea[HeI[HeQXFe=XF4eTE4UJCT9JCdASE4UPE4UTMWYZPXL8JWf000MZPHAZP8=ZOH1ZOH1Z
MWUZLWIZNGd00VYmP1coool001[ooolFO7al00XT6QEnG4R;NVQlJfQlJf=lJfIlJfMlM6]lIf1lK5`2
O71Y0WaXH00>O6]LO6]KM5MCM5]@N5MCKeM5Jdm2JeI:Ke96JU96M61CKeQ;TJ^hPHB437alO003O7]l
O7n0O820009lO7`Joooo5WAcMP0:718>ITThPgATM6ARM6AOM6ASM6ARM6]VM61KM6=F0WAWH@9dH5/2
M6AF00a[DE1[E4a`DDmXDD5SBSiSDDMYCD=UCD=/Fe1YEDZ7WjiiO7l=M7=f0WAhNP9dLgHJoooo5W>7
Q`0:8AlJDdhoOH5^LgE]LgE^LgEaLgE_Lg]bLg=[Lg9R0W=gK09cLFT03W=eI7=gIF]TGf]SFFmOFVUQ
CF=IB6=ND6UKCFEJC6QYFVUTEGjOXWN?SPacQhL00g>9RG>=SG>;R`02LhN76_oooaIZOH002RPR7cho
>71dIVY/IVY/JVY/KFY/JFY`JVY]IfYYG@9ZKFD2JVYU00iZK61ZL69THEeTGEIWFEIUG4aME4EMF4eT
ET]PE4UOH5ATGe=^P81]PhH<JWf000=ZPHAZQ8MZP8<00VYmP1coool001[ooolFO7al00XT6QEnG4R;
NVQlJfQlJf=lJfIlJfMlM6]lIf1lK5`2O71Y0WaXH00>O6]LO6]KM5MCM5]@N5MCKeM5Jdm2JeI:Ke96
JU96M61CKeQ;TJ^hPHB437alO003O7]lO7n0O820009lO7`Joooo5WAcMP0:718>ITThPgATM6ARM6AO
M6ASM6ARM6]VM61KM6=F0WAWH@9dH5/2M6AF00a[DE1[E4a`DDmXDD5SBSiSDDMYCD=UCD=/Fe1YEDZ7
WjiiO7l=M7=f0WAhNP9dLgHJoooo5W>7Q`0:8AlJDdhoOH5^LgE]LgE^LgEaLgE_Lg]bLg=[Lg9R0W=g
K09cLFT03W=eI7=gIF]TGf]SFFmOFVUQCF=IB6=ND6UKCFEJC6QYFVUTEGjOXWN?SPacQhL00g>9RG>=
SG>;R`02LhN76_oooaIZOH002RPR7cho>71dIVY/IVY/JVY/KFY/JFY`JVY]IfYYG@9ZKFD2JVYU00iZ
K61ZL69THEeTGEIWFEIUG4aME4EMF4eTET]PE4UOH5ATGe=^P81]PhH<JWf000=ZPHAZQ8MZP8<00VYm
P1coool001[oool2O7al00=lM7ElOGelO7`047alO00;FdmG2@81bZBEPFmQO7=_O6]SO7=[O6]SO6aT
O6mXO79Y009lJfL03gaXFGaEEWAGBFe@AWEFC7QND71NDfMCA7ACBViIC6M??FMBAVaCAfQ=@XjY]P0B
O7al6_ooo`9dLgH00gA[KGAcMGAcMP0@M7=f00]BATl80P:]SXIiJ5idK6YdI5mdK6IdI5mdHeidIf9d
K6L00WATHP0?M61CM4e?Jda2HTDnJde5L5Q<J5U?GTi1K4i7JEA9H4XjH4e3I4e2GdLnPIVX019dLgHJ
oooo0W>7Q`03LgioLhB5LhN7011cQhL02eAHH1<;2gafLWMhK7=mMG=gKW=mLg=gKW=bJW=iL7=oM`02
LgE_00mcLF5cGE][EdiQD4MYFdm_IeMWJEYOGDm[GE9YHE=OFDEOFT]QETUMDdMeTiL04W>7Qa[oool2
JWf000=ZMWUZNGeZOH0046YmP00;DUEO8Q8ABTY@KFmWJW=]JW1ZJW=]JW1ZJVUTJW5[JWMd009ZK6T0
3fYZGVYHEfA?C5]9@f5EBfMPE65SEU]HCVAHCfAJCUYD@eYDAeY>AEM=@fAaL`0BJWf07?ooo`006_oo
o`9lO7`00gakO7ahN7amO@0?O7al00b5Q8D>1PB4JE;E/iMlJfAlK6QlJ61lK6AlJ61lJfAlK6AlL6P2
O6MP011dI5AeE55dGTe_Ed]eFdmaF4a`F4IZD4E`D4A[D4A_D4=cDTQZDTIcFDb9QhYmOh0AO7al6_oo
o`=dLgH00gA_LWAcMGAcMP0>M7=f00amNgh:10:0IDcE]YYdI5idHf9dH5]dHeidH5]dI5idHeidIf82
M61K011[G51[CTa[F4UXDDQ/E4YWDDMXDD5TBd5WBT1SBT1YBT5]CDEUCD=]E4UnNGecLG<AM7=f6_oo
o`9cQhL00g>9RG>2Pg>4Q@0?LhN700ajShlC3`YnN5bo_9QcMFacLVicLFUcLVYcLFUcMFacLVYcMfh2
Lg=[011[KEmYHEU[IeIYHEAYHE=UGU5WGTYUFTaTEdYSEDUYEd]/FTiUFTaZHE=dMg=`OG/ALhN76_oo
o`9ZOH000fZ1Q6YiO6YiO@0?JWf000aaQHLP5Q1dLUZQXHAZK6MZJFIZJVEZJFAZJVEZK6MZJFAZKFP2
JVeW011TIUeQGeITH5AUG59PFDiNETaQETMQETULDDMMCdETDDUVE4YPE4USFTiTGEUWKFhAJWf07?oo
o`006_ooo`9lO7`00gadMGalO7b0P00?O7al00D@20EhH5C>ZY^1Kf5lJfP00Wa[I005O6]LO6]TO6]T
O7=[O6]T009lJ60047<e=GPk?G0d<g0e=G@g=gAGBV]=@V]=A6m8?VMC@71BAVmBAVMB@7A;@FUDB8FE
V`alO7`00gadMGamOGalO002O7al6_ooo`9dLgH00gA[KGAcMWAhNP0?M7=f00D90`5_ET_A[j=iJ5id
I6800WATGP05M6AFM6ANM6ANM6aVM6AN009dH5/02V`_<G0`=FP[;6P[;V`]<Fa<@f=7?V=7@6Q3>V1=
?09XCD<0161=?Fa5?5m8?WN2Q`adLgH00gA[KGAcMGAcMP02M7=f6_ooo`9cQhL00g=nOg>7Qg>;R`0?
LhN700D=2PM^JUg0^jUgN6acMFd00W=eK005LgETLgEZLgE/LgecLgE/009cLFT046dm?flg?6La=6L`
=6/b=V]ABF=CB6=CBFM?A5mHA6EJBfMJC65JAVQ@@e];?VenO0acQhL00g=nOg>4QG>7Q`02LhN76_oo
o`9ZOH000fYfNFYmP6Z0P`0?JWf000DG3@]XIEfUYYU]KfMZK6H00VY/I`05JVaPJVaTJVaWJW=]JVaW
009ZJVD01VPn@VLa>64/<V4Z<F@[<fA4@P9MCDD0261;@UYA@EeDAf1DBEiD@em:?e<n=5iQG`aZOH00
0fYfNFYiOFYmP002JWf07?ooo`006_ooo`9lO7`00gakO7b0P7alO00>O7al00MKCe5VDD_@[9elJ61l
Je]lJfQlJf@00WaTE@04O6AIO6aUO6aTO59B0WaGEP0;Lc<dL3ddIb`TMD<oJc/bMD@oHShhJ4a1J590
Idi2M5=9009_DTH017=:@VmMCgINDWn4QP]lO7`00gakO7b0P7alO002O7al6_ooo`=dLgH00gAhNWAc
MWAcMP0=M7=f00MBATQcFEG@[Z9dH5]dI5MdI69dI5h00WALC`04M5aBM6=NM6=NM4Y<0WA<C`0AK30a
J3T`GRPQK3djHcL_K3`jG3HcGdDlGddmH4ToK4e5J4e3JDe3KDHoJEM<Je56LVm`00adLgH017AhNWAc
MWAcMWAcMQ[oool2LhN700=cRHUcRh]cQhL03W>7Q`0=E5QJS8Z3^kBTLg5YLgEVLgE]LgE/LfeMLf]K
Lf]LLg9XLg9ZLeYJ009cEeT04Fe4@fM3>Ela9fQ3?V=0=fPo?Ehl>ee=@eeJAUmEB6QHCFMJC6UJCFYD
BFURE6AA@V]`J`0;LhN700=cRHUcRh]cQhL00W>7Qa[oool2JWf000=ZPHAZP8=ZOH003VYmP00=DUEI
VY^GWI^@JVYUJVaSJVaVJVaWJVIJJV9GJV9FJVUQJVUTJUIH009ZCe@04FQ8B64o>5/_9f0l>5dm=F0e
=e/f>5M5?eMD@eY?A5mAB61DBFADBf=@AVAICUQ0=5iHE00;JWf000=ZPHAZP8=ZOH000VYmP1coool0
01[ooolCO7al00<;1PJHMf22K5X00Wa[G008O6]XO6]LM5a>MEU>OG1SO6m[O5e>M3Dg0Vdd;00<I4@l
DR/NKVaKNVYPHRPPJBdVJcddJTLoJeM9JdXeK5I3L5960VmBAP04KeI9KeM;SIJHO7io3galO1[ooolC
M7=f00<710=eGDYhHe800WATEP08M6ARM6AFJeE9Je18LfMMM6QVM5E9Jbl`0V8[9@0;FC`eB2TMHVUI
LFeSG2PQGbPRHcH^ID4jI515I4HcI50n00=XCD<016Q@AFQ@AX:7RgAbM0mdLgHJoooo4g>7Q`0=3`h=
D4dnM79MLgERLgETLgE]LgETJfMHJEiCL7AVLgQ`LfEFJchk009Q<B/04UU7?DTd9EaeGff1KUhe:U//
96<j<VE6?f=HCF=D?65KA6EJBfMJC6MLCFMKCFMLCgR4Og>2P0mcQhLJoooo4fYmP00=6aDC:bdYJVUH
JVaMJVaPJVaVJVaPI6=FHEQ@IfQOJVmXJUmDI3hk009K;2P04UE2>TLd9e=ZF6=kJE/g;E<X8Edb;F0n
>Ue>B5e@>eYC?eeDAf1DBF1GBf1CB61EBfQXHfYeM@mZOH0Loooo000Joooo17alO003O7AeO7emO7al
00]lO7`03T0a<d@[7mV`Th5_JWAMDGedL7a[IWaMCV]>?VQ1>8ASIF`];R060gQED09`Ach04g]]HhF@
S88n>60m<Thd9EmFCT8`8fd^9VA@@6a;<g=>Ag=JCgUPC6iAAVmIC6mBAW9KCgmkN7anO`0>O7al6_oo
o`AdLgH00gA[KGAcMGAcMP0;M7=f00hg:2Y9:aoC[99iJ6I[EDacJfUdI6=dEDUSASUN>C9gEU]S92PG
0`9L@d42J4Ln01=eJF66V9N1@3]H<b]4<R=CEdlh;b=M:29LASUTAC5]BDA]E4abG4YYCT=XE4UXCD=W
CTAbJ6EdLW@03WAcMQ[oool4LhN700=cOWmcQ8EcQhL02g>7Q`0>>cLjGDTj]ZV<MgQbJfEKL7QcLgMa
LfEHIUI5GDDkKeULHbda6P<3AShk0VMHC00CMG=XRkR`PDi7F3L_AD<^CfIG=SPYDb/TG4HkHE0jJU=9
JUmDKfYDJEe=If5CIeY<H513JfQPLh:000icQhLJoooo16YmP003JWIiJWUmJWf000]ZOH003Shi?F]E
Ai69M6e_K6AOFFM/JVY`K6YOEf9BA5M2>F5:Ceh[<B4412h[;@9QEdd04fiWGhNc[W]>B5D`:dA5<DQP
DSDg:DHV85Li<eY:>F=<A6=GCVMSDFAIBf1JCV1DBEE1=eiBC6YeM@0>JWf07?ooo`006_ooo`9lO7`0
17adMGamOGakO7b0P0alO7`03Pd71j>3J9R5OWa[Gg=DAh9eL7aXH7aKCF4j:f<j<bh:2VE^JG^CS;[7
`0:3T9L058BEVX6;R79CA86PW8>2PV=PHcLO6C0L4FDj:g5KAWA=AWUUEWUMD7=IBFiBAVm@A6mJCG:2
X7MgNWenOPelO7`Joooo0WAcMP04M6]]M7=eM7=fM7Qj37AcMP0>2`L6SGANTX1lM6AJK4i3N6YXM61K
M5I9Fc@XFc@^8`P8CEeJPjVT_MKB0WnIY00DOYbVNHN7K5U:P:ZXR8jCI6AZ=20K9AXAD38VJ591K4U4
LUiCLUQ>KEE7JDe3J4Y0J5A9IgJFJVYbLg9e3GAcMQ[oool2LhN700AcOWmcQ8EcRHUcRh/<LhN700hF
5AA_L5j9S8=cMFM]HE9dLfacLFUcJE]PA3EK?cDS2@TmFENCflbaj]d2Okc001Am]kegUY=_PVb4aKZ?
/;1YNg`j;RLO7Q<o<2EREDEXETa_J5U_IEU]IU=YFdaWEdYWGe5PMhmTM7i`PX8=LhN76_ooo`9ZOH00
16YfNFYiOFZ1Q6Z0P`aZOH003RDO74iFCgUmMVY/HVQNDfYTGfYZIFYVG5m4=ePl<bD922a3AISSe9gF
b`9h^[l057B_]ff7RFb=NH2l/Xja/fUjNd4c;1dM4blV7UU8?UmBB6MMDVMNEFQRDFAFBF1AAf1GC5EQ
M5UVM6MeN@eZOH0Loooo000Joooo0WalO003O7]lO820O7al00alO7`03f=MK@D10MN/SH9_Hga[G7]Y
GH5fLGa[I6a1=D`d8U8R6RH:1ZecI8MRDGE;A002OGUf01ElH4elIE9[@CYjM7M/@SElJf9XAcQWG5<j
7aM]>B]^CTEkIE1lJUecFDeZDTU_BSm_DdMWLFeRF4e/JGYoOgh037alO1[oool3M7=f00=dN7YdLgId
LgH02gAcMP0?FU=U1`82^iV1N6MMM6AFM6EKNG1]M6ANHc/aABlOB1hH90/7W6EIOU52Jchg009cJFH0
5GAGA7AJAf<j<fmUJf<i;G]TFW=??g5UFcHP6EL`9V=4?W1NBgETFFeEBfA>AfQ6?FQ<@V1VHEM<@5aH
Jg9aM@0<M7=f6_ooo`9cQhL00g>9RG>;Rg>7Q`0<LhN700mKIWLE3Pf6P6edMVIcMFAeNfagP7IcMFaS
C45:?RY79Q`^3`UoE4QfD49YASd00W1]I`0ELfUCLfQAIT]3JVU[HdTlP7EUPg5IOGi]<bLNA2`TGDQ0
JVIALg=RKFIIIEmCIe=7IeI9GfYKDUE7E5e]Jgf200acQhLJoooo0VYmP003JX64JX23JWf000aZOH00
3eQQLbLG5U1BCFY/GVY/H6igJVeeKFY/Iei<A4/o;T@U73PB2ehe;fTm=F4n=`02IeYF01EZI59ZGdaR
BdEPEUYNB3emK5n;Nf>3Oflc:1l`8AiC?CUOFTYZJU]XHUQQFe5PCdEPCTEJFDU;C459CUaNKGT036Ym
P1coool001[oool@O7al010T6QD=1PEH=RWM^9V1Kf9lGE5lGU=lKF5lJeaZ?cA`GU69Ng6?TX6jTXik
Iea`DD/2LUQ?01Ef<c5T@3]T9bE]:REP9Am_IEMK<2IQ?d58<B/j3@InETeoIe1mJf5_Dd9ZC49WCd=`
G4m_HUF=SII/IGV>TXL037alO1[oool@M7=f010L4Ph2001A;R7H]9QiJ5idEDadE4adHeUdI5IT?39^
G5:<Q7bOZYJmWIYeHeaXBTL2Id]501EZ9bQI<C9I7amR81aF6QIQE4YC:R9N>Ca><Rde3PMWBD=eGD]d
I5aXCSmTAciPBT5XF4aYFTn9QY1ZHWN1Pgd037AcMQ[oool@LhN7010Q7aX0001B?2nj[i5gN6YcIEUc
HEIcL69cMF9XDdAdKV6?Y96`f;Ba/JAeKfMWF582Hdm701EV;c5I=CMI:BMN7a]F7A]JCdIF>BiR@T9M
ASd`3`M@@3a^He5`Kf5YH4aUETQOFD]UI5EYHeB8U9I]MXAeRHD037>7Qa[oool@JWf0010X8Ql6001?
>c:DRgU]KfAZGeIZFE5ZIUYZK5eVEdYcJF29Y92cg[RMYIQ^IF9QDdl2FT4l01EM:c1E;3=D:2QF5aIA
6AY?>SMF>c9Q?CeWBT<_40Pi:beRE4UVHeQUGDaQDTEJEDUMG51TEd]nQHEZLGaTLWL036YmP1coool0
01[oool5O7al00=lM7ElOGelO7`01galO00AHeIN00005Pd<jKbXUhQcO6AHO5AGM6]MOG=UO5EHJTHl
G3l_RGmiPGIaO6QUNg=XOgie00:3NG005HAgIgEZF7mVEgMZDWMYF79KBgPc=FTc;U<S648B3VXW77]S
D7iTFVmD@VY<@fM;@7ACAfmGBalF4hV4QhJ4O@02OGin2WalO1[oool5M7=f00=dJfedLgEdLgH01gAc
MP0AFTaF00004Pd;d[:RTXEcM5aCM4eCJfAJLf]QM4eCI44jDcT[O75^NG1^M6ESM79WNWmg009oNg@0
5GikJg9]FW]ZFW=`Eg=^G6eHBG8_<VH_;5<P5THC3V0S6fUCAGAJE6Q>?fA7@F16?Fa<@VQ@AQH?3VeY
JWmmM`02Lg9e2WAcMQ[oool5LhN700=cOWmcQ8EcQhL01g>7Q`0AFemW1@H540h<Wj6ARi9mLfePLemQ
Jg5WL7Y[LeePJ5E<ED<bLG9[Mh1lLgieMHUjNiN:009oU8L05GfIOgJ5Jgb4K7B;J7B4JFePCg4m?FTg
<EXV6U0J4e4Q65U:@FiRFFUNC6EGBf5BAVQFBFMKCQLA3UEMF7^<P`02L8:22W>7Qa[oool5JWf000=Z
MWUZNGeZOH001fYmP00AF5]U4`/:5@l=J7I_OH=dJVILJU]OI6MSIfiTJUQLIUE?DSlaH5]HKGIfJW]b
KX=gMI66009hT8@05GBGOg>2JWF3KFn:JFn1IVMGBF/m?VLd;edU6ePM5D<J54Hd<f9FD6EJC65EBEi=
@em>AF1BBAd?33/m>71mNP02IgEi2VYmP1coool001[oool5O7al00=lNgalP81lO7`01galO00AH5UZ
M5m6bHefeZjAOFaLO6=GO6eRNeiJPG5RO6UNJUA4J4HkSGmbOFeVO6mXO6]SO6aT009lKfP05GaDE7=E
BWQNDfmGBWACBV9>?FU<@F=J@fUFAg5LCWUHEHE/B7aSEW1GAFY<@fMB?gAEBFmJCA/N7jVPVgn3Q002
PHB42WalO1[oool6M7=f00=dN7YdLgIdLgH01WAcMP0AFeEWSg1HkjF:f:nCLf=FM5eCM6UNM5UGNFMM
M6EJI5=3I4@lPWEZLf=MM6MRM6AOM6=N009dIf805GA=D6a=AW1HCfQAB6a>Aea;>em:?e]K@fIKBgEU
EWePGGiYB71JCfQA@FA7@F1=?FaAAFQDBAhP8I>@SW9fN002NGao2WAcMQ[oool5LhN700=cRHUcRh]c
QhL01g>7Q`0AHW60/ZV:oljS`K6>L79RLfmQLgeZMFUTMg5XLg]YJ6UEJEM;N7EWL6iULgU`LgM^Lg9Z
009cNG005G=OH6eMEFmWFVUQEF]MDUiJAU]KBE]^CfUaFWenIX1dJgA]C6QQDFMOCFEGBf5LAfQMCFMO
DBlb<6ilMV^1O`02Mhn>2W>7Qa[oool5JWf000=ZPHAZP8=ZOH001fYmP00AHg>1akjRom6UXIAiIfUM
JVUOJWMTKV=QKFARJWMUIVQGJ5Q=IemEIf9KJW5[JW1ZJVUT009ZLF/05FYKGfQHEFMPEVELE6AHCe]G
AE=IAeQZCVMaFWeoIWecJFIMAEaDAV5IBf5EBEiGAEmFB61GC3lj=TUCDUi`L002KH>62VYmP1coool0
01[oool?O7al015iFTR:JeMkLFagKEmiJ5]mJemlKfYlJFIlOW5lJfIbFTmbDDE`Cd=kKf9mM6elKfMl
Jf<00WadJ`0EO6EGLee<L4XoL5U6Hd`lE4PnIDDeI48fI4DfI44fI4LfN69?OVAKM5A7HTDmId]0K5=2
J5=72``=_;C;TINI00alO7`Joooo3gAcMP0AMEE2PfA?M6e/LFUNKf1FLfAJM6QVM6ESM7U^M6ASK5I>
KDm5J4PnKV5GLf]UM6QRM6AO009dJfH05GAQE6aIBVQ4>fQ@@5]7>4a3>U/o<e`l<U`o<U`l<Ua2<W5N
C7IOFFa>A5a0>V15?FA=?em=@P/=3J>Q_HN>UP0<M7=f6_ooo`mcQhL04GY_EWmeH7F4Og5lKFa^HG1e
Ig=hLW=kLg>8O7=gLfm]HG1TEFE@A6QUF71hKW=kLW=gKP02Lg]b01EcNVI]KEUWDDEWG4UKET9>CdAH
Bc]JA3QJB3QJASQLCSQ/J5E`JUm[Fe1NCTEOD4IQF4IMF4TF5AAiRZ1nV:0037>7Qa[oool?JWf0011g
L5QdK5i^Oga[MFYSIE]WK69ZKfaZMfmZO7IZL6m/KF=/I5IMAcmLDdYWK6AZM6h3JW1Z01EZN6IXJEUQ
CDAQE4EHDT1=Bd9AAcUD?cED@SED@CEGBCERGU1VH5QTEDeKBd=JBT=JDD=GDDDT6QM>G79_Q94036Ym
P1coool001[oool>O7al019dK6emFdIdGE9]D3iLG6>4J5Z1Kf]lLfilLVYlLf]lKfMkDe=fFTibCD:2
KV22LVelL6QlDE82M6MG01EmJ5U[C4=`D4AS?cASCdER?SE[B3EWBCm_DcUVBCUWASB3HEIiEd][CD9R
B3e[CT9[ETQcFDl21@NdX9R:SXL037alO1[oool>M7=f00Q[HfEcE4=[EDaRASEBD5UgH5MiIfIdK6X2
M6aV00QdJ69dCU1aEDe]Bd5jIEYhIVAdIf9dBT`2Je]>01EcGe9SAcmXBd5K>C1KAT1M>S=U@S=QASeY
CcMQASMQ@S5jFU5bD4ISAciL@cYTBCmTD4E]E4`41`VGRhEkOWL037AcMQ[oool>LhN7019[MWM`Je][
IEMQDCeBG69_KVIgMW5cOGMcOgEcOG=cNg9eHfAcIee`GTmeJUadKfUcMficG5`2JfAH01E`KemVG4mW
G4iK@cUKCdMPASaRC3]ODTEVFSmQDciOC3QbH5=_G4mSE4QMDDESEDQSFdiZHED<3@iVKVI^PWP037>7
Qa[oool>JWf0019TKg=WJF5TGe=KBCY?DeUQIFA]K6UZLg1ZMg1ZLfeZM6i^HFA_Hei/GDmZFU5ZHEeZ
KFQZFEX2I5QA01EWIU]RFe5QFDiH?cQHAd=NA3]LAcUJCD5PDceMD3aJAcIUDdUWED]MCdEKCT=MCdAM
DdYSFU0K4A8g?caMJVH036YmP1coool001[oool>O7al00QkFdR1I5M[CD=WCT9kM6Z@FeElLF]lM6/3
O6mX00MlIEMkIE9^ED=eDdN3NWElM6]lIEl00W]eJ@0EPFmYLU9?LeU=JDe2Le]=HSdcIdHiIdY0L554
Lde5OeiBPFUMJdm3Je14Ke96JTe2JeI2K5=70`H7@blXYZ6T009lOGd:O7al6_ooo`idLgH027AD@WUK
Cf=7?ei7?WE[HXQDCgAWIGA[IP=dIf801gAQE7ARD6UB@Va=@WQ^JgA[IWAQG002M75W01EiJ6I/CTi]
ED]TC49]Ed]M>S5Q@CMQACeXC49]BDElG5=kIUaSBT5SBT1YCD=UBCmTD3mTCD8820Pg:2>3PXP00WAc
M@YdLgHJoooo3W>7Q`08MFYFMfePIUY@GeE;MGATPF=MLg5^Lg]b0g=iL007LgYVMGIPK6MAJEQ9LW=[
Lg]bLgY_009ePWH05GMhM6mUHFeVFFMOD6aRDf19?5m:?Um?@fAFBfaFCW][GWMbHf=IBf=GBVULCFEF
BF=KAV5HBADA3RHP75]WK002LhB52W>7Qa[oool>JWf000Q^J5Q]IeiRF55KDDY^IUIcGEYZI6EZL6X3
JW5[00MZN6I^LEmXIU9PDDAVH5]ZL6YZN6h00VihLP0EKFm_K6ESJ69HIEmAIUY>GTPmFTDlFTToG4i8
IU9<M6AJKFMLGEA9GE57I5M;H596GE=3FU559QLB6Q@D<SQ1009ZNGd:JWf07?ooo`006_ooo`ilO7`0
4WaJAGATFE<_8GidIhYUIh5_HWafJgadJgahMga^IWa_J7aWGgaZGFYBAWAIBGikKGe]IGaXF@9lLf`0
3Wa[Hg=KCFI9?6]=@VMBAVM9?fiB>FI5>W1AAGiLEH5[GG=MD6YICFmHB`9WDTH01F]EB7=PED`f94lW
7SLY9@02Si:B2WalO1[oool>M7=f019dED=[G5=<:QedJen3GfAiJ5idL6IdJfIdL79dJ6=dIf9dH5]d
IE]TCdI/EDMdLVEcHeedH5<2M6aV00idI5m/ETUOA3USAciPCD=PAceYCcQQ@SMXBd5fF5=jIea]F4iT
ED]XEDX2H4e300ETDDI]Fe=M?RUG:Ql[81d00VY^L@YdLgHJoooo3W>7Q`0BLfmOJfeND3/ZKW9SOfe^
MgQZLh1`Lg]bLh:0LgadLgU`Lg=]LgU/J6AGJfICKWUVL71VLg5Q0W=mL@0ELgM^KF]KHEE6HeA8GeY<
HEM9J5e0HDdmI5A7LFALMgAVKFMIIFIHIfAEGe]=Gea=Hee?JVULNUdlGC<S7aPF0097EEP:LhN76_oo
o`iZOH004VY`IfAVFE0n;f=SEgAUIVe_I6YeJ6Y`JVYhN6YeLFYaJfY]JfYcJfISFFARDF=XF6MVGVYZ
GP9ZLfX05FY`JVQYG5iCAUe?AEYDBEiEBF=H?ee9>Ua<@VILEVeZH6QQEF5REF1ODeYFBeYGBeeFC6=P
EXiYA68c8aP=30028bXb2VYmP1coool001[oool=O7al01=lGE5/=bQL925N@3IbOWR5KV9lMV9lJfQl
M6]lL6UlJf5lKfQlIf1dI5AcFe1kL6:5NVj1Kf=dEDh00We^H@0EO59CJdlkISlgId]0H4DjK4/dE3/`
ID4jN6=EOVAFOFEFKeM;JUA8Kde2Ke14JU90Ld]0Lf9EID<iJTe7[/[A00;?dm@:O7al6_ooo`edLgH0
4gACB6<]8E8J6ULf<6MeLgMXGWA`GWATHWA[IWAWHGASFgAWHWAPFf]LD6aFCGE]HWidK7UXGF]=B@02
Lf9I01EdBTaSASIO>S=PACaH?cITAC1==ReK?3MaGU5fGe=dGe9XDDQTCTAXAciYBT1UCCe]ASa]FTmQ
@CUbDT_3g>D00]3Gg0YdLgHJoooo3G>7Q`0CLfIJHcdaDR0PFT0jH7MbKG]ZLh1ZLgE]Lg]bLgM]LgEZ
LgU`Lg=[JfeOKF]NMGm`Nh=fMgQXJeeF009`K6005G=JF6IDA65:?em@A5Q9?V5@>4e1=EM6?FaVEg1/
FW1[FfUQE6EKCVMDB6UGBVEJAVYBA6YSEFIEBWmZFloilP02_N3K2W>7Qa[oool=JWf001=ZHEUN?SI?
7amH>cUEHV5NLfAZMFAZK6IZL6YZK6EZKFIZLF]ZKFMTIUeXJEi^N6a`N6e]Kf5TF5@00VMNE`0EJUIE
HTm5GdXoFTY1ED@kFTXfC3hdD44jHU]?IV=DIV9EIEaBHEE;H4m5I557H5A3Hde1HeM>I5I>Q6eLc>[P
00:Q`Kl:JWf07?ooo`006_ooo`elO7`04gaMDF`g:5`T8Ei0=W9nN8E^HWafHWa[J7adJga`JGa[HGa_
J7aWH7ATE7=KD7]`HXEjKX5_HgAECP02OFiQ01ElDU=[Cc]V?cMWBd1PACY/BcAD>c1U@CYhHeEnI5Im
IEI_Ed]ZE4Q_CD9_D4AZDT1cBd1cHUEU@cUZCDN^b]400/oCe0YlO7`Joooo3GAcMP0CM5=8HbdQDQXJ
EcH`IgEcMfQNM71NM6ARM6]VM6MQM6=KM6MRM61KJea@K5I=MFeROWA/NFQMJde9009cHUT05GA:C6=6
=Ulj<f15?5Po=VA5<4df;E/l=g5NDGIODgAODVQAB6A>A6Q7?VU:@6E=?Fe6?6eJCf51>G9BBl?Li@02
d=OL2WAcMQ[oool=LhN701=cIUYS?C5B821J@3YPMg9]NfYcP6YcMFecNg9cMfecMFYcNG1cLf][KEm]
JeieOg1kPgIgN6Q[GEH00W1/H00ELeYHIUA4HDXoGe14F4TnHE0hCD4eEdHmK6IGL6aJL6]KJF5DIE]>
IeA8JEM:IEY6JU94JV=EIUE:OfYKcoWb00:mh=/:LhN76_ooo`eZOH004fYQFEhn=TlO7ePk>EERHEic
I6YeI6Y/IVY`JVY/IFY]IVYaJfY]IfAVGFQYGVihK71hKFe_HFAHE002IeiG01EZEUERCdEOBSmJBT5E
A3]JBSI<?SA@@CYRFdmVHeAVHUEUG59QED]PCdETDDMPE4=SCD5SEdiTETj4KEc<j^000Z71_`YZOH0L
oooo000Joooo3GalO009O4I0JS@_HC4]JfECQWm_T7=[O7=^O6]VO7A[009lKfP027aXH7aXFG=SE85O
E7M[GX9_JgacKW]XI0:1MV`03WaKD6YFAF94?F17>ea1=F54>6=7?h1TEH5YFgUUF7eREVmGBfYCAfm?
@`9_BdH01F];@W1UGelh:Va?@ibmb@02Ng]l2WalO1[oool=M7=f00Ud@3eT;baL;RaTGdmoMfV8JfId
K6]dI6=dJfH00WAWHP08M61KM61CK5e@NEU@LFAIN6MVM6a[M6ET0WU`JP0EM5I=I592G44kF48hEC`c
F3heGD<mNf9ENfIILUmEM5aBJ558I4i4J4Y1J4I3JDE3I4HoJ5iJFCDXI4PnT:fk00adLgHJoooo3G>7
Q`09LeQFJ40mH3dgHfACNge[PGYaLgeiLgMaLg]b009cNG0027=aJG=aHFe_GWM[GG5bI7AfLG=mNGEn
M`9gP7L05G=[G6QSDUiBAeQ>@EE7>eA7?Ei?AWI_GGMbHFm]Gg1ZGFUQE6EMD6MIBfMBC6U@CF=BBFEV
H5Y4=65BA8:SY@02MHV92W>7Qa[oool=JWf000UZFeeV@d9O?SUMETY`JeecKVUZLg=ZL6aZL6X00VYa
J`08JVYUJVYNJ6ULKFEJJfQMJVaYJW=cKW]e0VeeL@0EJVUKIV1CFe57EDTnDT<iCT4jFd]3JfIGKFMJ
IfEJIV9HIEaBHEQ=H5A9H4e9I4Y;GDe6GEYFF4DfFTXoKGYk009^PH@:JWf07?ooo`006_ooo`alO7`0
57aTEgaC@VY6>5Y1;gAZF963Lh5_JgadJga_Iga[I7aXHGAQDgeXFWaEEG=NDGUHCWATF89`K7a/G7aX
H@9lJf@05GaDDfY7?655>f=7>fI9?F9BAWAJAWQPDWYNDGaREWAGBg1AAFYDB6m8?Fm;@6M>@6ME@7AU
Gfi3=ViKCg1kQP02O7em2WalO1[oool<M7=f01AdFTmdCSaTASMD@2i/I5B7NfiiJ6IdJfIdJ69dI5id
GeY[F4acGe9dCDm/E4a_DDU[G59hIfEdHeIdH5X2M6AN01EdCU1T@CUL@3QM@cUQAS]MCdE/EdEaFdma
F4eeFe9/DDMXBT5TCTAX@cYXASaPBCaPDCe/GUYY@CMYEdiRK7P00Ve/KPYdLgHJoooo37>7Q`07LfeP
LfMAJ5e9FE4iJ6]FOX9aMgQ`009cNg802g=eK7=_If]WF71_GG=MGFeQFFaPEF]XFgAdKG=bHW=aI`02
LgE/01EcHF9XD4MPCT=NCd9QDTAMFdeXI4e/IEE]I5IcJ5][Ge9WF4aUFdiWDDEWDTAOEDAOGDIXJ5i[
EDQXHUEHIf/00VEcMPYcQhLJoooo36YmP00DJVQOJVUEIV5=FE4jGee<KVmTKFmXJW1ZJWA^JVaWJVIR
I61EIfIHJUQJJ5QFHe]BI5iEJVQSJVUMJVYQ0VY/I`0EJUiRITi8Gda2FT]0GDe2FUI:Gee:HUa>He]@
JUmEI5U?HE=9HEE;H4e3H4e1FTm1FUI3GeeCIeI<HeY?C4e@009HHVP:JWf07?ooo`006_ooo`alO7`0
56a0:eH`9S0P6T/d:XIeJHaoL7a[J7a/I7aXHGaXFGaTEW=TEGUIEFeEC7EOEGQZGGQ^H89cIWa[I7a[
I`9lJf@05GARE6]>?V5:?f=7>fM:?FiAAG=FB7iJEWUNDGEKCg1NDgAICFYFBVmEBFMDAfM=@V]>B7AR
Gf0X6W1WFFXo=P02Tj2Q2WalO1[oool<M7=f01AS>BI:9QhT6A@k;BIhK6>2Mf]dI69dHeidGeYdH5=d
G4m/G4m_D4mRCDE[F4m`I5Y`JEehJf1dI5idI682M6AN01E[GE1SC3eLASeM@cUQAC]YC49]D4EfE5=b
F4e/E4YXF4m/ED]TDDMXDDMPDDIPBCmTBDE/FUYH9AQXGE5U>Bl00XJ:RPYdLgHJoooo37>7Q`0DHdll
BS0V9R0J=S<[JfiSNX1`LgE]Lg9ZLfmWLg5QLfeKKFeMK5iJHEeAJFEJKgAWKgYZM7YYLgE/LgE_0W=e
K00EJg=PIV5>H5E8GTm2Ge13J5I9JU]>LEmJKfAGJF5CIfMJJfIHIF1BIf9CGf1AGeI9He=>J6=OF38R
IF1BID8c009iOgT:LhN76_ooo`aZOH0055iB@dL^9RPP6c0^:EYKE6a`IFY/IVYYI6YVHVYZGVYVEfQV
FV=HEE]HCV5LEFM[HfMaIFY^HFY/IfY/J@9ZK6L00fA`Gf9RDEmBA`02FT]0011SCTARDdYVEeAWFe=P
FDiQH5ITHUIQFTmPGU5JG4iJDTIMC4YOEeIE=2IMDDIP?Bl2Ie]F2VYmP1coool001[oool<O7al00MQ
:1LJ40/d920a81nLPFj7N79lJfL00Wa[G00;O6]TO6]VNfiYP6aXMUeEM55;J5=4NV=FNFULOFaXO6]T
009lJe`05G=DCVI3>E/l?FA8=F13>75AAG=MCgABAVaGBGEDCf]>@VaBAV==@VQ@A6M@A6]:?f]>BFaG
AePg8VYF@fPi=@02Tkg82WalO1[oool<M7=f00MK9ALE3PXY7a`Y7Af2LFAmKfadI6800WATEP0;M6AN
M6ASM6QWNFUWLEUDK4Y7GTTmKeM>KemFLf=RM6AN009dI5H05Fa=BEln=U@g>Ua2<eTo=FQ;@FeGC6a=
@f9@@fa=BV=6?F9:@5]7?Um:@61:@6A6?FA9AFA@@U4f8Um??Uld<P02QZ^j2WAcMQ[oool<LhN701AP
?RhK50dV8QlU7amRIEafNG=cMFmcMFAcMF9cMFacMg=eNWIiOgQcKFE[F59MDDEZH5E/K5m`LVacMF`2
LgET01E]GeQQCdEFA4ELC3aHBS]RE4MZHUAXFT]PFdaXFE=SDDIPEDUKE4QMEDUOEdYSE4MSEDeQF4QC
BC1IDciM@C/00WVMXPYcQhLJoooo36YmP00DGdPk91H?9QlM91dN@DQ7JFYWJVaYJVaPJVaMJVaWJW1_
KW=bLGYdKfUTI5=?EdQ1GeE>Hf9IIfUSJVaW0VY/H00EJ5]FGTi7ED93EdLkE4DiFDa2HeU>GeA7FE97
H5=?GDY3FDi5F4m5Edm5FU57GE15GDm8FTi2DT`eD4HeEd0j009WLWL:JWf07?ooo`006_ooo`YlO7`2
O6aU01AY=R`o;2@g91dc8R2nU7V7N6YdI5ImK6AlJeiSCTEVDDA@>2eB>RmA>3AK>CU]DT=aDTIbGU>3
LFelJf@2O6]S01EcDe1UBC]N@c=WAS1OBT1]CD1NCd=KBCiZDdMaGU9SCT5`FTe_ETYZDTI[DTI[BSm[
CTU[ETHo8QY:81Q/@3400YBma`YlO7`Joooo2WAcMP9dHed056@f;DP`:3LU7RlP7jV6LGe_Hf]LCg=S
GWATFUY6?UQ5>T<]9D8/948]:Tda<V99?FM9?fIBBWQWIGATGP9dI5l05Fa>CEm5>EU0<F52;EU5?FA8
?EA8?Tm2>Um<@VMHCE];?VQDBFUAAfE=@fA=@fA6?FA9AFA@@cXP6ChK5Uhg:P02QZ^d2WAcMQ[oool:
LhN70W=fK`0DJUI=GDHh>R/Q;RDRPWUVMWUYJfeKL79ZLgEYFeI:EDm1@CH[?30W?S@`BCTjGU15HU15
HUY@LW5[LgE/0W=eKP0EKF=NHeI9G50jGd`eFU13GU53DE14C4e2FEI9HVADFeY:IEmAJF1BIE]=HeY<
HeA7HeE=He]<?R/R>1dGDcT[009gVYP:LhN76_ooo`YZOH02JVm/01AZH5]]CChn:R0`921HETmYJUeT
IUMWJFAZK6EHDTM=AS`n<RXe:28h;ba2=CMFAT5IASmJCDQVI61ZK6L2JVaZ01EXHUiRED]KCSUJAcAG
BcmFBSm<Acm6B41@CTEIFdiHEdYMEdaTFTmPET]ME4UMD4EMCdQMDdU2;BDd6QI6<2D00V=^J@YZOH0L
oooo000Joooo2WalO09dCS`056]0>@H30Q4>32@J6<fPPge`HWaTF85_Hga[G75JCeM5>d<d:bXW9alJ
6SDO5ETm;TLP64PR6HEaHWe]I@9lJf@05G=KCFE8>ei3<f1@>ELo=WEIC7INDGUKCW]EB6]<AeQ6?7IJ
CFmFBVM?@ea;@5i;@6eEBF]EAT8U7ETZ7gi3=002V<?C2WalO1[oool:M7=f0V]6=P0DHcXc10@32``<
7aTG/I1iM6QLM5aCNFMMM6AFKEI=DT0h?2lW8B<T51DG91TAAC<V>QXD>ATCL5]ALf=M0WATGP0EK5I9
GdDiFD0aFD`gD3`cK5=8LU]?MeQ=MU56I4E2DClhJe=9J557H4Y1EDHmE4HmHe55I553@BDNEBTOM3ha
00:;[/4:M7=f6_ooo`YcQhL2Jea;01AVCd@:1PD93@`J6QN1OVY`LfEcKF1gMVIcMFAbKEmFD4@n>c4Q
:BT?61TI6Q8f<BHf7QLb5a=MDDM`L6H2LgE/01E]Je]SF4ULCSaHFCm@AcUUG4ibJEUhJ5QdGTmSCdUB
Bd9TGE1WGU1QFD]EDTIADTIOGDeSGDa;=RUD<RAX@3<00W^IX0YcQhLJoooo2VYmP09TFe00569AAaL9
1`l<31/G5TiFCfIWGFYVG6e/GVY/H71]H5I>A40k<R@W:14E61<F4BTV838K5R`A3dPe<VMVGP9ZK6L0
5FQYG69HBe]<?EAD?Di3=U]CB6eRE7=RE6aIC5e8ADm6@5UDBV1HCEiDBE9=@da=@eIFB5eFBE8k;U4a
95Tf;@02IVQ]2VYmP1coool001[oool9O7al01N5Q8EjBcQjBcQU?cLB4A8N510b61GO/Y>1LVEhIUYm
Kf9lJemkJVIQBCn8J68^9R8O4Plc6Q90=cAO=bZ7JUVNVXJ2NgH00WakN@0ELf5AID@kCcP]F3l^:0X7
L4m0GT0[C3P_>RPOGTPlG4i0MUI3J515Ie14FT@iHdi2MDi9G4Di<QdJFCDXPeA;00:Qe=l00g]kO7al
O7alO007O7al6_ooo`UdLgH05gekOWE8>7E8>5lj<aTD520F4RlH5LFQR7U/HG1PEg=WGGATFWAUHf59
@8aYI3@Y91lB42dI4S@a<E8d:XA[FiNGQGQdL@02M7Ef01E/GU5O@SU:=2a@>2`R2@ML@3IC>2E1<2P]
8AY>?SEEBCa/D3mOBT1PBT1F@3IMBCm/BDEE?cH^6aU@<RQiDT/00YG4d`YdLgHJoooo2G>7Q`0GNXn?
MfIFMfIFHda0;RDQ81TC:aXETHUeMga]Kg9TL7IXLgEWMGUcK69DTGid@cX`8AHB9QXC:C4`B3haOgUS
RYV3M89i009cRHD05FeeIf=GBTi1=Tho<RD<24Th<Dlo:Slg;2/W7dA2=eECA6AIAEeEAemGBUU=@5]C
AVICCEE9?c@W8TXj;FaIC`02Q[>g00=eRHUcQhMcQhL01g>7Qa[oool9JWf001MaQHMbK69bK69RCD54
;RPW6A@[61AJFeA]LVIWK65WK69ZK69^Lfm`IEV=NG5A?c@W5a<T5a8R:2Tn>c5dL5egPG1ZMFh00VYo
OP0EJ7AZHUU=Cd0gBcT`:Pd9=RDUB3PX?34X:B@N>CP`DTa1F511Edm3FU57F4XoETa2Fda8DT@m>bXU
A3H/G518009`PhH00fj1Q6YmP6YmP007JWf07?ooo`006_ooo`04O7EeO7emO7AeO7em1GalO00G2P41
Nd0_Nd0_JeA991`I5Q@J8A<?gKNGNFQKO6]ON6MKMFAIOFaXLF1ANEa@EDDiQF1@PE8hOe@lUVM<Sf]K
PW=TPWUd009lL6T05G=EAFE2>E`m;Ee1=DX[8fALEbXY9`@313/S7Clh<1hF4DPd;TD`8VU1<E];@F=@
A7E>@TDk;R8H544X895ZF@02W<G>00=gMgQlO7alO7`01galO1[oool017AZKGAcMGA[KGAcM@EdLgH0
5`@005@T6E@T6F=>ABTO6aPE6alD4;nTRfmPEWATFW1PEV]LDg=SHVeNDG9ICUa7>YQ[FI9K?hMF?IIW
C8UXFWYZGWQ_K@02M6MQ01E/CT1O?SMJ>RaI?S==;RINFEHQ9BL110DY6aTc<B`D4Pld:2Hf9aeJ>2YE
ACaMC49/BCm0=b/O5a<f9AioHE@00Y2f`@03KfmaM7=fM7=f00MdLgHJoooo00AcO7ecQ8EcOWmcQ8D5
LhN701L80P8b61Hb61IVGU4l<2LL6R0K5A:6RGA/KV5cMFM_L6=YJei`LVabMfM_JEUaHTnYR6^JL4^9
HT6=M5>0LemeLF=dNW800W=gK@0EKF9CHe96H4XgFdTkEd0aEE]E82`_00<56aXI:c4/41@A92HV<2/Q
D3`/Ee13FeM:IUE6A48d920I;RLPIf9B00:2ZjX00g65QG>7Qg>7Q`07LhN76_ooo`04JW9fJWUmJWIi
JWUm1FYmP00G4PD44@D<4@D<HUY?CCP/9A`Q7ADBC5MAHfEKJVaRIfQNHF9IIfUSL7MZIfAEOVUE[Xa]
Vg5=QE/mOF]>LVQGJV5GJV]V009ZK6D05FQPEV9DBF9;>EU5>Ei6=D]=BR8Z;`L41Q8D5RHX9Q<B41PL
82XU7d@c9eE:?eIAAU]?@dM0=2`S72TS7Te?AP02KH5o00=[OX5ZOH1ZOH001fYmP1coool001[oool0
17ahN7b1PGakO7b0P0AlO7`060`40`T30bP70bP70blP6`P83Q4?3B`G4^RiVGQWFh9_Jf8k>6U>@hAb
KW]bJGm[IWQNFG5AA71GBWaJChU/F8IWGGa^H89lN09lKfP05G=@BFEBAei2<EiB>fe5=7]UEfU4=@/9
2d@Q5SLZ9b<J66M0;fi6=hETCfI;@F9>@WEE@QdG5b0G4S/O5iE5=002T;?000=hN7UlO7alO7`01gal
O1[oool017A_LWAgNWAcMWAhNPAdLgH060H10@@10Ah711h711LD4`<630l?3BXH4lnYSg1PEWQWIUXd
=5e1>WMVI7A/IgYZJ7MNFfi>A6mEBgeKDXEYF7mSFgEXG7QcL09dIf805Fa;Aem>AEU1<UY?>F]6=7eT
EG96=Q0<3CdP5S0V924I65dk;FQ3=GiPCV58?ee9?faA?aXE5Q`E4CDN5h4l;P02P9^Z00=_KW5dLgId
LgH01gAcMQ[oool017>2Pg>8R7>9RG>;R`AcQhL060/61PT71Q850Q850PP=3`H940lA3RHJ59J>NFm`
HgAfLEe3@UY7@6m]IgEoMg^3OGafKg5ODG=XFGi^Gh5eGg]bI7=dIGAmMP9cNG005FePFV=REUaC?eaM
@FaG?Wm_FGiJ@aLB4C0P5R/W9B8O74dl;F9;>gAYE6=DAUeCAVIMB28N7AdJ5BlQ66@h:`02LHF;00=^
Ph=cQhMcQhL01g>7Qa[oool016YiO6YlOfZ1Q6Z0P`AZOH0061D92A@;2`d40Pd40P032Pl;4AHA3bPI
55aMEVMXGVY/JE]3@e<m>f5MFVigM7F1OGUeL6iLDG5UFGYZGGIZFG1ZGFYYGFY^J09ZLF/05FQOG69P
Ee]C@U]H?fUG?W]UD8=KAB@E52PK52XQ8BLO7Chb:5U4>FINCV1@@eY<@U]FA2dQ7b<J5RdN5dDY8`02
G5ML00=XNWiZOH1ZOH001fYmP1coool001[oool00gaoP7b0P7alO005O7al01P5000b8QP]5Q<]5Q<[
8A`;1`T/61<c61CO[8f1J5]hJ5ajIf1]H51C>2iC>c14<RPb920[71Lg9ae3:B19:b5bHEIjL6:2M6l2
O6QI01EcD4EUEdQN?S=VA3=SCSUaFdYZDDEQDTNJIDi/@c=V?RjKHTf5G41WETU/DT5]Ed]SCT8C40lR
5A8o81R7<R@00Y[>fPYlO7`Joooo0WAhNPIdLgH060X30S4R6BdH52dH52LP70X92RTH4c8H5LFKPWUP
EW1PEWEVH6YQDTL`:44[8c@U7B<J61`E4RHM5c8P6SPR6emABfmWG7Q[J@9dGe805Fa;@5mAAETk<f4o
<Ue9=fQFAVE>@gMLCZiaEgE7=Vi0;iiRCXEK@65AAVA=?fYDB5e9?a@A3b0E4SXO67L_8P02R[O52WAc
MQ[oool00g>=SG>;Rg>7Q`05LhN701PL4Pl_9Q//7AL/7ALQ8A`:2PXU6Q@^6aJAPVigKV5_KUmhPWE]
MF95=bdj:b@`:24O7a`H61HO7APZ8Q``8aeAD4UZLfEdMg02LfmO01E]H51SHE5LC45QB3UKECiRH4YW
GdnDOVBcR6EkESieCCNDJe>1J4MOFd]QFdUZHE5KEDTO71HO5a@c8QUO;b800WJJWPYcQhLJoooo00=Z
Q8MZP8=ZOH001FYmP00H<AdI<B<J<1hH<1hH8AdJ4P/;9QPD;aTFFUA>KFEKIfEHLh9eJg9S@34Y<R0M
;28M7QdK61HG6QLF8adI:A`J@ChkGfMLJV]U0VYVF`0EJ5mAHUa@Fde3GD<hETllFEM3I5a=YhIY[hIU
Ne@mMd`fQ65=Mf14FE95FUI7IU]<ETm6;B8I8aLD<1lIARPO009NHVH:JWf07?ooo`006_ooo`QlO7`0
60P101`>2QLA3aLA3adC3adB3QhE43HX9<6DN8A]Gg]_HX5_JgUXH7Y[GG=BC4Y2@gUABfm9>WQHAfe8
>XYTE9bBOhYjM85_JP9lEE@05G=MD6EFBUhh>S`R640U76UC?6eC@f]B@79AAViE@VYGBh1RC61@@f]>
CF=>@VeC@TDh;PL821LA3ieQBf`_8@02Y]_U2WalO1[oool8M7=f01P>108K3`/D4@lD4@lJ4a0M4PlM
5A4b9bBZR71gHeUdJ5iiJ6IeIF1nL6AdE4m8?d=gD4afC3emFdY^BCb9I5JHSgn3M75iJ6H2M4e@01E/
EDeODTQI=CTe7QPd7aUJASESCCiTCCa]CT=`ET=/FTejHDaIC49TBD]MBCmSCCm0=2/82@TD4@nDGdY[
<B<00Y?5d`YdLgHJoooo27>7Q`0H8AH?6A0;4Q8@4Q8@5a@@71D@6AHA;2/VOGQTKfePMGQZMgQ`NWie
R91nN6QNCDa>MUmHOUm:OfYDKUM5QG=OSiN1Oh=lMgQb0W=MG`0EKFELHf=EG4I7=bHN<20KCDHfGeQ4
HeY4Kee=MVYAKfaHLfeCF5U<HeECFe=9GeQ6A40c3@l=4Q<@O69<IS/Y009jYjT:LhN76_ooo`QZOH00
63HR6Ah?2aLB3aLB3a/C428E4A`E4BXW8dmDC65QF6i_I6e_J7MkMXRCPWIWGU5:C6mKEWmOC7]UDF]E
A7Y[FWn2LWAhLVe_K09ZF5d05FQOFf9PE5]7B3XU82dJ640g;UIA?eeD@FYIBgMYDViYEVMSCUADBUe?
CUI<AUIA@dLn<aTC41HB469DA5hj:P02G6a^2VYmP1coool001[oool2O7al00=lM7ElOGelO7`00gal
O00H3P@27Pd:7a@@7a@@6a<@3@H68A@@?2XUW6mHQfiPOG1SO6]XO7=[Ng5YO71/QHElXHj0R8EkTHf5
T8R1VHYhP7QYPWMcM6=D0WERE@0EM6IDKUY?MUiCIeA3@bTY<B@L81HCF3L^L5E:Ie8oJU92Hdi2I4Dk
E44fKDm7Ldi27AHC3P/;;2<NSTHbAQhE008Y;2/00hj=SGalO7alO007O7al6_ooo`9dLgH00gA[KGAc
MGAcMP03M7=f01PD20DO3`/O5A4O5A4K510=1`PO510h:2B8He5gHUMcIeedI69dK6IdK6MkLg6=SXFT
UHR<SXFFUY6FTXjJT81kM6QhKfe[GE02Jee?01E[HE1YEDacGU=]FTQ5;2`X7aXC4110:bIRC4APCCeU
CCmMBCmL?cQ=?39SB49]BClJ518>2`//8amn@C1071@00QhR8P03JVY/M7=fM7=f00MdLgHJoooo0W>7
Q`03LgioLhB5LhN700=cQhL062TO5b4A31hF4AhF4APE4@X71a/D434Z9FIJBfUVFW1dIW=eKG=mLgF1
NH2CRIV_Vj:aW9:_WiZdYibdZ9NYTWV4LWAnMV]_GP9YLEd05F]bGFaWFWIfHgYgGT/i=B<O6``?42hX
9UQAB5mJAfMLB5]EB5a;@D]6>5iBBFYCBB8L61<?3BTW8F0n;T0T6@025aXI00=9DeMcQhMcQhL01g>7
Qa[oool2JWf000=ZMWUZNGeZOH000fYmP00H?bhS:18=8aDA8aDA7ADA4@L87A<@;R@QA44kEUI?IfQO
JVaVJW=]KW]gOIB;VZfJUZ^ISZfPU:nTVK>XS:6>LGU[JW=/I6UL0V5]FP0EI6YJJFAILWEROg]SDC/g
8QXI30`>7QdPC4I0FUA5I5M4ETm4EdLnB44eETY4HTa6;AhJ7A4?;2@O@c4W@BDJ008F3@h00bL[<fYm
P6YmP007JWf07?ooo`006_ooo`9lO7`00gakO7b0P7alO003O7al00l91@@Q61HN510N510P4a0F3PXV
5A4j:RFIIDjCN6R2M6IlJfQlM6]lKfQlN7L00WagM@07O6iVO7QgO6iVO6mVNfYMPFmSNfMH009gGe@0
5GQHCWMSEg]VFGULEfUIEH1LD5<n=SlU7B@K5CLR7Bh[9clZ8T</8W9BC7]CAVA7>@`;2aP@3RHI6R`>
2S@B3@02:bl^00?Kgn1lO7alO7`01galO1[oool3M7=f00=dN7YdLgIdLgH00WAcMP0?3@P781TG7QDA
7QDA7a@@5Q0<91HB=RPTREa9QViQN6]PM6ARM6]VM6MRM71b009dLG<01gAXHgA`LWAXHgAXHgAUFgUW
GGAPD`02LEU@01E`DDUaG5=eHEIfFUMbGe^>IEUN@c/j91dG5A4S6ALP8R4_8adf9AeWBdMfCdAL@SH=
30`G4@lT61TT3@XW40`00RP[:`03`l[?M7=fM7=f00MdLgHJoooo0W>7Q`03LhV9Lh^;LhN700=cQhL0
3ahM6b4O71dG4QdG4QdE4AHB320G4RlZ9FaHAgMaHWAgJG=eKG=kLW=iL7>2P002LhF400McO7AcPX1c
O7AcNgAeNFagMVIeLf<00W5[G@0EKf1ELFaNMG9RNVmWPgmbVgm/JUE7=2PO41@A5aLH6R<S:2HP<BTQ
H55;LEY<G4ho5a<B5a<@81TJ6P`:7a4=008Z;R`00i:[ZW>7Qg>7Q`07LhN76_ooo`9ZOH000fZ1Q6Z0
PfYmP003JWf000lb:bPW81`R5a8R5a8R5A4L4PdR5Q4/925=A3]SGEAZJf5ZK6IZL6YZLF]ZN7P00VYm
O`07JWEaJWQhJWEaJWAaKW=[KFaNKVeP009[IEX05FMKDV]TFVi[GWI/IXZ5Min1Kg9GBC8U7Pl?3Q0A
51PL82@R7R`U7eE7A6QCB5M9?BDH5AhC428G61L;2Q/?3@02<2TW00=NKg=ZOH1ZOH001fYmP1coool0
01[oool8O7al01P>1`Hk:2DG4@hG4@hP4a0O4`lX6AXi:RElED23Jeb4MFMlJf1lK6ElL6QlL6UlMG5l
M71lLfilN7MlJV1lKfQlKfIlJeilJel2Le]@01EhHUIhGU=hI5MhFUM^GU1^F4YTDD=/EDI/Dd=X@S9I
?Rn0CSmbFdf0CdmMCd1>@CD=30`M4PlK4a0E3PX[6AD00STe<P03e]_LO7alO7al00MlO7`Joooo27Ac
MP0450X9?2TU61<?61<?0QlD400:9aTK=RPUKDhlLV1DMfYPM6AJM6=NM6MRM6MQM6]Y0WA/JP06M71b
M6=KM6MRM6QSM6AKM6AJ0VaFC@0EL5eCL5Q?L5aBL5ECJEU<JEI8J5=5Me];N5Y8JdDeFCd_OTdnM5a?
NTa>E4PmACdc3`d=7A<@6A@@50l;9ATF008c<S000kk5bgAcMWAcMP07M7=f6_ooo`QcQhL062TR7c``
:aTF4QTF4Q`E4AhF4B@K730Z9UE;>f1PDfmcIW=eIG=bJ7=gKW=gKG=kMG=nNG>1OG>2P7=gKW=iL7=k
M7=gJg=eI`9]JE`05Fm^H6mWFVmZGFmUGVaYFF]ZEgAZEHAdG85_EVYA?5]5<gQGAGI[FG1FDe=BATE9
?1TE4a`E4ALE4A4@2adJ5P02;C<`00>>YjIcQhMcQhL01g>7Qa[oool8JWf001Po<Bdo;bXP5a<P5a<O
5A4S5A4W6Q/^9R<n>c=<CDIQI5]ZK5mZJF5ZKFQZK6EZLFeZMG=ZNGYZN7QZLFaZLF]ZM75ZL6QZK682
J6IK01EWJ5aWH5IWHEMWHEYYHeIXJ5IiK5N9MUj4KeIVCcYJ@C5]D45cIUISCTa?BT=4AS/X6QHQ5A4K
510E40`K61D00R`/:P03G6a`JWf0JWf000MZOH0Loooo000Joooo27alO00A3`D3;AhF81PE81PE8A<?
9@l;:aPE=b<HD3P]RF=CQGIWOFaPO6]XO7A[O7QgO6mXO7Ea009lM7001GaZH7a_J7aXFGaXH7aTE`02
LeA;01EhI5MhHUIhGU=hFe5_EdUcDDE^DdMYDDEhFdeeEdYnH561FD]aDdebCD9VC3/g9A`C3@dM4Pl[
61@K4`lS51000SLS6@03Uh23PXB4O7al00MlO7`Joooo27AcMP0A50P5:QdE8APE8APE8A@@910<:QPE
=28HAS<YMEM;N6YOLf=JM6ARM6]VM71bM6MRM6]Y009dK6X01GASFgAWHWAPDgAPFgALD`02K4e601E`
G59`GE=`F4m`E4]XDDA]BT5YCTAVCT=hFDeiFDf2HUF0FDe^Cd]]BSmQB3Pd8QXC3PdM4a0Z61DK510Q
5A400S4Q6003OVa_L6mbM7=f00MdLgHJoooo27>7Q`0A9a`E:B0G8adI8adI7aHB8Q0<9aXE;b<I>C8Y
GUA9KViQL79ULgE]Lg]bLh:0LgU`Lg]e009cOWT01G=gKW=iL7=aHG=aJG=]HP02KEmD01E_JUe_KV1_
IeY_HeIYGe1]F4a[GE1YGDmjJUV0KUb5MF5lIeI^FU=/F4USDd4i:b0J514L5A4X6aHK5Q8M5Q400RXQ
6003FUEEI71bLhN700McQhLJoooo26YmP00A?2XP;1lF:QdI:QdI8aHB9A0<:APD;R0G;bTTA44lGUaD
IfUOJVaVJW1ZJWQhJW5[JW5]009ZMG<01FYaK6YaJfYZGVYZIFYVG`02J5]B01EWHEMWJ5aWH5IWGE5U
FDeXDdUXF4eWFDegIEMoKUb1LEmcHE9YDdiUE4IPCChn:b4U5a<Q5A4Z6AHP5Q8O5A400RLM5@03=Rlb
DeQOJWf000MZOH0Loooo000Joooo27alO00B2@<1<bTW91XG91XG:1HC5@h:81@@7a<?@BLNId4[SgQY
PW1SO6]XO7A[O7UhO7=^O6mXO7Ea0Wa[H@04O6mXO6MGO6]PM5a>0WAOE00EN5iCN5aAN5]@N5iCKeM;
Je=7JeI:Kee@Je96Ke14JU96G4XoGTi2GTi0Ac/`51@D30X98aLI5Pl?50h:3PH6008^6AD00gEJEJ:]
[7alO007O7al6_ooo`QdLgH04Pd6130X9b<J62<J62LG4aD@31dD4A`C43TT75Lh9WYXG7QWGGATHWA[
IWA`LGA/JWAWHWA[J@9dHe/017AWHWAPDgATFV]EB@9[FE005G1HCg1DBg1DC71HCfQAB6=>A6=AAfUH
CVA=@fQ:@6E=@eE6?EA9?eA9?Clg;A0C4`/;2B4G6AD@41<?2`d72002:1PE00=TCdb=V9UdLgH01gAc
MQ[oool8LhN7018N6A8^;BXT7a/T7a/V6QHC4@`I5A4H4a0_8aa3=BAVHeIdM6IcMFecNg9cP7acPGec
NG1cNgD2LgEZ00AcNG1cLfEcMFE[IeP2Jf]M00a_IeY_HEI_HeM_IeYYHEASGE1SGU1YIeUSFdeWEdYU
FTaEE4L2DEE600Lo@SHE6aT;3@XN6AXB414A40/;1`L00R0H5@03BdE2LhV7LhN700McQhLJoooo26Ym
P00B<RHM<2/X:AlK:AlK:QXF6A4=6a@@6a8@:1hI<BPNCTY3JVQOJVaVJW1ZJWAbJWUjJW5[JW5]0VY]
IP04JW5[JVeSJVaOI6=F0VAUFP05If1FIeYAIeeDIf1FIEaB009MF4d01FAQEEeFBf1AAf1DBE9@A@02
C4m300Lo@3DO7A`C3P/P61TH414F3``A1`L00QhD4`03=2l_EF5SJWf000MZOH0Loooo000Joooo27al
O00B2@<1<bTW91XG91XG:1HC5@h:81@@7a<?@BLNId4[SgQYPW1SO6]XO7A[O7UhO7=^O6mXO7Ea0Wa[
H@04O6mXO6MGO6]PM5a>0WAOE00EN5iCN5aAN5]@N5iCKeM;Je=7JeI:Kee@Je96Ke14JU96G4XoGTi2
GTi0Ac/`51@D30X98aLI5Pl?50h:3PH6008^6AD00gEJEJ:][7alO007O7al6_ooo`QdLgH04Pd6130X
9b<J62<J62LG4aD@31dD4A`C43TT75Lh9WYXG7QWGGATHWA[IWA`LGA/JWAWHWA[J@9dHe/017AWHWAP
DgATFV]EB@9[FE005G1HCg1DBg1DC71HCfQAB6=>A6=AAfUHCVA=@fQ:@6E=@eE6?EA9?eA9?Clg;A0C
4`/;2B4G6AD@41<?2`d72002:1PE00=TCdb=V9UdLgH01gAcMQ[oool8LhN7018N6A8^;BXT7a/T7a/V
6QHC4@`I5A4H4a0_8aa3=BAVHeIdM6IcMFecNg9cP7acPGecNG1cNgD2LgEZ00AcNG1cLfEcMFE[IeP2
Jf]M00a_IeY_HEI_HeM_IeYYHEASGE1SGU1YIeUSFdeWEdYUFTaEE4L2DEE600Lo@SHE6aT;3@XN6AXB
414A40/;1`L00R0H5@03BdE2LhV7LhN700McQhLJoooo26YmP00B<RHM<2/X:AlK:AlK:QXF6A4=6a@@
6a8@:1hI<BPNCTY3JVQOJVaVJW1ZJWAbJWUjJW5[JW5]0VY]IP04JW5[JVeSJVaOI6=F0VAUFP05If1F
IeYAIeeDIf1FIEaB009MF4d01FAQEEeFBf1AAf1DBE9@A@02C4m300Lo@3DO7A`C3P/P61TH414F3``A
1`L00QhD4`03=2l_EF5SJWf000MZOH0Loooo000Joooo27alO00C3P@2<2DS;R8O;R8O9a/G9aLC8Q@@
:adI@Bl[BcL]V79RQ6iQO6aXO6aTO75ZO7EaO7=^O7QgO6YP009lKfP00gaWGgATEgALD@03N5]@01Ah
GU=`GU=aEd]`Ed]ZDdM_ETY_Ed]_DdM[DTIWDTIJBSmcCT9RAc/b9B0E3PhU6QLB2P/E3Pl>1PHG3a02
9QDA00=WE4jf`/ElO7`01galO1[oool8M7=f01<D20D_928]8Ql]8QlW71PW61@R5A4Z7AXl;R]1=2b2
IEYgHUQdHf9dHeidIf5dJfUdK6YdL79dHe/00WAWHP03M61KJeaCJeE<00=`E4`0571HCfQHCfMAAfQA
AfA>A6QAAfQ@AVU>A6A=@f1=@eI6?Fe9?ei2>2hR7QD>3RHJ5a<<31@?3`h821L@4@8T5Q800eY=B:2_
]GAcMP07M7=f6_ooo`QcQhL04bTN5bdX92dX92dX92HP6bLK5b0G4RLP6cDa;CLf;fAME6mYGG=bK7=b
JW=dJg=kMG>1OG>2P7=gKP02LgU`00=cLfe[KF9[Ie/00fmSE`0DKfMJIfMJIEmBIemBIEe@Iei@Iea?
JEe@He]=GeY<FEA7JUE8Gdi1<b`V6Q<B9QhJ40`<4Q0@30L75A4B0QhG4P03ATM3Oi^LLhN700McQhLJ
oooo26YmP00C?b`S<2DR<2LS<2LS:R0K;1/G91HB:AhJ<B`Y<2l/ADE2HEYCJVUSJVUTJVURJW5]JWUj
JWQhJW5/009ZLF/00fY]JfAVGfASF003IeeD01AWH5IQH5INFDmQFDmQF4ePF4ePED]TF4eMET]JE4UH
D4ERCdAMBChi;2LT5Q<[7QXF30`G3a0B20PJ4A427aDA00<d=SEIK71ZOH001fYmP1coool001[oool8
O7al01P<1`Hc:BLf:BDf:BD`8b0W5Q<C3PX]61E39aeP>b^AECf6LfAmL6AlJfAlK6AlLFYlMG5lM71l
LfilKVIlKfQlIf1kJeYgGe<2L5Y@00QaEd]iF5=_F4]dDDEdE4mZE4M_ETY_D4@2Ie1400]TACUZBd1S
@CDi<2/S61@L4Q0D3PXD3@lC2P/G3`/I41400RlI5003jN_[/kZlO7al00MlO7`Joooo27AcMP0A40X9
<2PW=BPU=BPU;b<P9aLD4`l;:APE?bDLG3PYPddhN6EJLfMMM6ANM6=NM6MQM6]Y009dK6X01GAXHgAW
HWAPFgATEg5ID002J5E<00QWDDM_DDiXDDM/BT5/CDYTCTAXDDMXBT02H4Y000]L?cIUACaM?3<b:bPN
5Q<K4Q0C3`/C3PlC30`G40`I4A800RdI5@03hNK[/[_1M7=f00MdLgHJoooo27>7Q`0H8R8O;bh[<bhY
<bhY;bXU9Q/F4Q0<91TE>2LME3`[KT`gJfIHL7AULgEZLg9ZLgA[Lg]eLgiiLh5mLgadLgU`Lg=[MGMW
LFeO0VMUF@0EIEmBK5iHJEiBJeQ<JeUCIE]@Iei@IeM:GeE9GeM:G4/oIE14FdLk=C<^8ahH7QHC4A0;
4Q0@4@`<5A4<5Q8B008X6aH00k[JeZG7a7>7Q`07LhN76_ooo`QZOH0063Ha;S8/:C@/:3@/:3<Y9BXK
5aT@32@G53DR6d`e:5Hm;UYBBFMXG6Y/I6YYI6YYHVYaKFYeLfYiNVYeLFYaJfY]Ifi`IV]XG@9QHEH0
5EiICf=FDfEFCfACBFACCf5ECF1HCF1AAeY?AEYAAeM7?F1:@EI3>CPa;BXO6RDG51L?2aP@41H<31XA
31/A4@02:1TF00>=ZJV?[ZiZOH001fYmP1coool001[oool6O7al00AlM7EdKFh91@D_8b02=BPU00X_
8QlK40dW71P^7QX_8aiQ?RekDD:6MVV3M6MlJfP2O7=[00QlNGQlM71lM71lJV1lKfQdH59mI5EcE4/2
Me]@01EkGU9dFTi`FT]dDdM[GE5[ETMWB4AXD4AWDTI[DTIZBSmPD4A=>Rm4<RPR618Q518G4PlL510L
50lH40/M51000RlI5003nOooNg]lO7al00MlO7`Joooo1WAcMP04M6]]Jf=U3@L7;28O0S8W900:;B8O
6Q4>9a`I;AlK:b8NEcX/Kd/oN6aSN6]PM6AR0WA/IP08M71aM6aZM6aZM6=KM6MRJeU<Lea?K4e60W5D
C00EMEU?K5E:J5A7K4i4HeQ=He54H4=0GdY0H4e3I4e3IDHmFDa2ASL^@C0V8APC81DC61<@71DA71D@
614<71DA008]6AD00mcWk7AcMWAcMP07M7=f6_ooo`IcQhL017=nOf]dMAhK62XV8P8_:bL02R`W8aTD
42HP6bXR7BHT84Pl;V1@@V]/HG9eJ7=eK@9cOG<027>0O7=nNG=nNG=gKW=iL6][G71[FfeOE09aHeL0
5GEYFf]TEFMRDV]MD6=UEV=PD5m?BUeEBUmJC6=JC6EEB5QGBTM4=dDk;BLP5b0H5APF4AXG4QXG4AHB
31TF4@029a/F00>N^KMeRHUcQhL01g>7Qa[oool6JWf000AZMWUTJflb9b@[8b02<2PU00X^9R8O5A4Z
7Q/[81`V8Ahk<bY@ACaJF59VIeiZK6H2JW=]00QZM79ZMG=ZMG=ZLFaZLF]TIeYWHUMXFe82JeeD01E^
HeQTGe5QG4mTF4eMGU1MFTeJBdMGCTMJE4UME4UPDTMDDDI7@SM9>Rd_8QTV61DN5A8N5Q4O5a4K4PdM
5A400RLI5@03GFibKX64JWf000MZOH0Loooo000Joooo1WalO004O7]lNgio1`D4?R@K0S0T8@0==BPT
;b<O:QdI;R4M=B4HFTHkFc`_Pf1AOg9TOFaXO6aTO71XO71Y009lK6801GaTFWAQDgAIC7UXFgAGC@02
L5M500QaF4a`EdEdFTmdFTiZETY_E4Q_CT=ZEDH2Jd]000]LBd1=@CE6;bDX6a/H40lF4@lD3PXG3a0B
2P/91PHC2P/00TXZ9@03j_;bN7QiO7al00MlO7`Joooo1gAcMP03M7Qk30P7>R<J008_8b003C8W930T
82XN6R`Q7C<Q6552>4hh;G9DBG=VFg=SHWASGWAWHWAWH@02M69J00EdFe=[F4a[DDE_H5I[DDT00VQA
@@0EIe57J551K5A:K5E;I557J4i4JD]1IE53I4HmI4DlEDHmAS`c@2/S8aTJ5Q0@5A4?4`l;5Pl@4@/<
2@L84P/<0096:2D00m;LhFm^LGAcMP07M7=f6_ooo`IcQhL017>9RGF@SadK5cHW7@8]9b803C0/:34[
9RTQ72TT7c0T6TA4>T<l<61CAf][GW1bK7=bJW=gKW=gK@02Lg9V00EcKF=[IeQ[HU=/KV5[I5P00VMO
C00EIEi?Iem<Jf9CJfAFIEi@Ie]>JEY;IEe<He96He14EE96AdLk@3DZ91lN61@C4a<@4A0;4a0A3`/<
1`L73P/<008l:RH00ibd/Vj3Pg>7Q`07LhN76_ooo`IZOH0016Z1Q6j8RS0W8SDT708`92003C4Y9SH/
9b`P72/R7S0R6CXj<cTf;Da1>eiIDVMYHfYYI6Y]J6Y/I@02JVUP00EZIf1TH5ETGE9SIE]THEL00V5I
B@0EGUI:HEU9I5a?I5mCHEQ=H5E;I5M9H5I9GDe3GDY1DTe3Ad<i@CD[:AlN7a@D6A<@5a0<610@5@/<
3PL84`X<008e9R<00fA`LfQjOVYmP007JWf07?ooo`006_ooo`QlO7`04@h61S<P5c<Z9c<Z9cLY9RPM
6RDE4SDR63<U8THi;d8S77]A@XInKX9_Hga[G7a/IGaXF@02O6QJ00ElJ65kJeYgGe=hG55`Bd400W1A
A@05M5AAM5]>M5YAM4e2JUA8009_D4@03VMBAV]:?fA7>da1=TH_9BPJ6R8I51P@3APB3b4C3aL?418:
2a<:2c<J5P;on_H00lGBdgalO7alO007O7al6_ooo`QdLgH041@:2C4O5c0X9S0X9S@X9BLM6R<E4S8Q
634T8D0e;CXP6fU7?7QaIGQWGGATEWASGP=dGe801GAPFWATEg5ID71DBfQ3>`02J4Y100E/CDe/E4]/
E4e/AciTCD@00VQ:@00;H4e3I4HmG48hAS`b@2/S8aPH7QPC5a4>5a<@8A@@5a0A008C30`013<K5_oo
ooooolOHg@UdLgHJoooo27>7Q`0A:R<O;R@J;RdY;RdY<RdY9R8M8QPD;b<I;RTT>3L^<bDODdDjJg5S
M7IVLgERLg9XLfmO009cKed01G=aIgEgIg5]GfmQEVMBA`02IeM<00E[FEI[HEI[HUM[E4QUFDd00VMG
BP0>HEY<HeA7G4i1BDHi@3@Y91dM7a`F5a<?5QDA7QHA5Q4B40`<4P`<;QdG0]cnl`03^>;MLhN7LhN7
00McQhLJoooo26YmP00A@C8^;b8J<2TV<2TV<b/W:B4M9QPD;b0H;bHS<RlY;b<N?CD`FUYCJVaNJVaM
JVUQJVIK009ZIUP01FYZHFi`IV]XGFMJDF5?AP02HE1900ETDe1TFE=TG5=TCdEQDdT00V1AA`0>GUA9
GE15EdTnBD4g@C<Y:AhN91`F7Q@@71@A8QDA6a4A5P`<60`=;Q/G0ZoBb`03WlG3JWf0JWf000MZOH0L
oooo000Joooo27alO00H6a8A:b4N<BDS<BDS?2PU;QdE:alL:A`H<RHS;1lK<bHTIT<bNf5;O6]OMFAI
OFaPO6]LO6]OM6AHMFAIOFaLLeA:L4i3L5M50V]?A00EK5M;K5M8MEA8Jda1Je=6KdQ4Ie=6Ie90I4@i
G4LkB3db<ahJ8ATD6A0=4Pd:5Pl@8Q<@5@h@3PH650/;<AXE00;^m?@00gQhNGalO7alO007O7al6_oo
o`QdLgH0624G5B`R82hT8RhT8SPW92dM5B/P72HL6BhT8RPN6RdS8ULm;fUC@ViNE6]LDg=SFGATEWAT
FV]LDf]LDW=SEVa>AVQ7?VQA@@9SBT005F9@AV9@A6a=A6=7?V==@fQ3@61=@f1=?Ea0=UE2>4<i<2hL
6AhH4aLA3Q4>2aD?420D41D@40h821<<32hJ5P02cm_O00=_KW5dLgIdLgH01gAcMQ[oool8LhN701Pg
=S8^:bL[:2D[:2De:bL^8QTZ9AlS7a/Z9b@T81`W9bI5?S1GCciUI5MYJei`LV=cMFAcMFM[KF1YJea`
LV9]HEEWEDUWGd`2HeU:01EPG4iPG4eXFDeSETUSF4]WCdYOF4aOFTILCCmECT57A3P`91hQ7AHF4`l@
3`/B414L5A4D4A4<1`L@30`W6aH00Y>]Z`03KX>3LhN7LhN700McQhLJoooo26YmP00HC4U4=2`X;2DS
;2DS=2PU<R8I;B@N9QdK:b@R9AdK9RDT=3<[@c`bF5A;HF9IIfULJVaPJVaRI6ILHF9FIfUMJ5iEHE58
HEU90UeDA`9IEDT04f1CBEeBB5eAAf1;AeYABEYD@eM:?E99?TU2=c@U82PM5Q`C3aH?2aP@41lD4AXA
4A<821H<32DH5@02E6AX00=XNWiZOH1ZOH001fYmP1coool001[oool8O7al01PL50l[8Alf:BDf:BDa
920]8QlP5APW6QL_8Qdg:BHc81Lo91]RBcacEdacE4UjHeIeGU=eIEUdI5QhH5AiHEE/E4]WBCi/DD@2
Jde400m_Bd1_DDE`D4A[D4AWBd1XBd1PB3YMASY>?SE5<RM0;B<O5Q8F40dF4@lE3P/00Q<:2`891PH0
138K5ShO5N_cm>_cm0YlO7`Joooo27AcMP0H81HA:R4O=BPU=BPU;R<P:R8O7QHH9AXG;24L=2PU<AlG
=R4ID40fH4Y3ITQ0KeM>JeA<Je]BJeaCL5U?KeQ?Hde6GT@kHTU00V=7@00EJ4DlJ4U0IdY0HdY0H4Hm
GdHlF48fE3lfACTc>bdT>2PO71HA510>5A4?5A0<4P/<4P/;2@L82PP8<1/F?B0F00;Afn0:M7=f6_oo
o`QcQhL063<b:Bh[9S<^:C<^:B/X8bTW91dI6R8M6BPS7S8]:BhS6BdR6Shm=59:@V1@AVYPEFUQEVUY
GF]]H6mYG6aUF6=OE5mEB61DB@9SE4X05FM@A6MCAfAEBF=GBUmBAUeBA5Q<?U=8?DE5>cXe:SP^920L
5A@B3a<C41<A310<30l;30H71`L71b/M5cPR5`02V[:^2W>7Qa[oool8JWf001Q6@CPe;2Ld;2Pd;2P/
9B8/9R<R61XU6aTX81`c:bL_8ATW7AP];R]1>cMFAD1PEDiQFE5QGeMTIUaWHUQSFe=NG59KDdQIC4D2
GDm701EPBT5PC4=LCdEMDDMJCD=GCD5EAS]?@S]4@CTi<RTi;2<X7QLJ4PlI4a0I4@`F30`D2``=1`L>
20PZ6QHg81H00V1/K0YZOH0Loooo000Joooo27alO00HBCi5;AlM=2PT=2PT;b8O?Bl[;ahE:ALC>bdY
;20L=BPT9AXGACT^?2dVESL/LEU<HDTnJUMCJE=?JE=7LUaAGdLmAc8YECX`0V=0<00EJDa1J4i2J3ld
J4a1Id/dI4LlG44eEchbC3hb>28N;AXD6Q4@6a4>5@l;4PX;4`X;3`H72PH75@/;:1HAdL_;00;@gN4:
O7al6_ooo`QdLgH06554CS8R8C8W938W92dR7c/^:S0O5RPH4cT[:2XO738W92<J63Tc:bdV8T4[9Em;
@UHo>5e<BUe9B5e9@FICBeM0>3d/9DLc:P9F>2X03Um5?5m9?eli<5m5?616<5a2>5Dl<e0i;dHi;c<P
7BLH4aLA41XA3aD@308B2``01@l820X821D<32DF4Lg=d`02d>3Z2WAcMQ[oool8LhN701QXKg/l<Bla
;2Pa;2P/9b<h<bla9AXW6QDe;bXX8ah_;2PQ7Q//<B/R9R<a:bICBd9DBCmHDe1JDe9JEDaRGeAHCT<o
>2i1>Bl2D3l_01EKCd9MDdIM@cQMCD9ODSULCSiEAc]@@SI8@SHe:B<V6aHI518I510C40`?2``@30`<
1`P81`PB30dO5Q:bdLl00[_ThPYcQhLJoooo26YmP00HN86>ASLd<bTV<bTV;RHR=c0/=RHK:aXE=2XW
:R4M;bTW91dK8bLU720O928PA3/gCT<lD4Q8Dd]=Ddi9FUM?ED]2?cL_>S</0TPh;00EE4PmEda3Eclf
EdDmFTdhEdTjDT<iCSddB3dd>2TT:1XF8A@C7a@A6A0<5@/<5P`<4`P83`P85``=7a@AT;2b00:M`<0:
JWf07?ooo`006_ooo`QlO7`067MfN2<L52HM6RHM6S0S838T8B8L6B0E5cHS6BlS840a;C<W8cDW8cT[
:Ddb:D`e:3D^;c@`;4@]8Tln<Dhm<SHY9C/Y844[809>=bH03eDe:eLm;6I1<EE0=DT`9U0a:E8h;T0c
;SLU82XG4R8C4APA3a@>2Q4:2`h61`032PH700<P5A4`6QGem_H00X64Q0YlO7`Joooo27AcMP0HMWIh
:R8H9AdJ9AdJ;28O;R<P81`I7QHH<R8I;B8O?Bl/<bLT<RHR<bPW@RhW?2dS9bDX9BLU<R<J?c8X@3<[
:R4P<B<L>2HN0T4`8P0?AbhWBcDWFc`]C3/a?RXRA2XUBC8Z>2l/<24N9ADA7a<A5a4?4`l;4@/<3PP8
008:20P010/821lF4RlJ5]_Pi@9iO7l:M7=f6_ooo`QcQhL017nIUCdn<2HS7RHS7P8Z9R804QlQ7AdI
6b`S6B`V8STd;c@_:RhY9Bd/:cLa:c0/8b<X:ahY9bPU7CPd:cTg;bTY9S0[8S@[8@8h=2D05Clb:DHj
:eI6<da3=C`a:D0`:DHh;SPg<RlW8RHJ5AlF4aLC414@2`l;30`720P71`P720P821/G4RXL5inh]P02
Mhn>2W>7Qa[oool8JWf000AnVYI?C3d[8ah[8ah2:b<P018S81dQ6A/Z7aP_920g;b`h;b/]9B</:2P^
:bPV8alQ8RHK8R<Q7aX`:bHc<2/Z9bH`:B<a:202<2hS00lg;2A0<bM=@C59?C4i;BPk:bI3<b/i=30`
928[6QDT5Q<M4a0G40`E2``B20P00Ph820043`P87QHA:a/FHW=f0Vf3QPYZOH0Loooo000Joooo2Gal
O00G<2P^9A`J9A`J>B/W<2TU<2<P614><B<M?S4^?Bl[?c8^@3<_Bc/aAcP^>S4X<2@T<QlG=AlM?2DO
?2/U:AlO<B<Q?B@N008o9QX05C/T7dXe:4Ha9cTY84@`9CdX7S`_:3@R7BlN5adC4B8J618>2QH?2a8:
2`l61`X61`/61bHE4AX@4HMSG>7Zj`0<O7al6_ooo`UdLgH05cH/=BPO7RPO7SLZ9blX9BlS81PB3bdR
7CX_;S/^:S`a;Clc;dTk<4<g;C@_:2TR8R`K5BdK6S0O734T828K72TP7cDR7@02=b<I00la81dm;bDj
:b@^9Ahk;28e9A`b:RD]7a/Z71HJ4a4O6QPB3`/E40`C30`?20P00P/820049QHB6Q4BPV9Me^3U37Ac
MQ[oool9LhN701M=Ded_:bP_:bPd;bX];RT^:BDG5A0V8ahf=30h<blk>3<o?3I6@SDo?c<`=BdW9R@Y
7QLW7AdY81d/9R8R824U92@`9R400S8V6`0E:b<O=C4X<c0W;2XQ>38W<R/P;BhX;2<N:B4I6QHC7QdJ
4A4<4a0<40`<3@P820P82@P88QPB618BLVIO/<_700acQhLJoooo2FYmP00GH6Eb>Bl]>Bl]=2`X<2`X
<BPT7ADA9B0L=Bl]=c0/>cDa@CXeA3hc?C/a;c8/:2@R:A`G9AXK91XJ:B0O9QlP924S;R<Q008`8QX0
3bPP7BhZ9Bh[9B`W83H^9C4X7b/Y9BhQ7B`O6B0F528L6APA31P@31H<31<820023`P800@U5Q8L4A9O
F5F4UI@<JWf07?ooo`006_ooo`UlO7`05f=LIR8G4b8G4c0T82lS834S7blS840_:T0a;Clb;S<W8c8V
8cPQ7T<U7S@P62/P7b<H5BlT8R<E4R`T8BPP7bPN6R@D4@028ATF00`Q51<W5A8W71DW6aDY7AHQ4Q4T
518O4a4P518D40hD3PX@2@X24`X;0PX61`059QDK9QD@=bTUm>kZYK:d00alO7`Joooo2GAcMP0GJ5mY
:A/G:A/G;b<P;28O;R8O<2@P@2l[?Bl/?34]<2DR;B<Q<ahL?B4L<AdG:1lM7aPE:R<Q7aDB9B4O91lM
91dI7a@A008K5aH031/C4QlC4AhH51lI524J5AXA41hB4ATA41/C4Q8A3Q<?2`l:2`8B2``01`X820/8
22HF72HF4SLY9N_[k::a]`0<M7=f6_ooo`UcQhL05gR7S3P_:CP_:BdX8b/V8R`V8S4[9S`d;STd;cXg
<Rh[9b/W92lQ7cTT7c4Q6RLS81dK62DV8a/G51lR828S8B8P71/E4`025aTG00hG5A@H4a8I6ADK6aHL
6aHG4Q8I4a8F4a4I5A<B4a0@3`/=2P/@2``@30`220P800DR61dR61<e;BO1h=RH_[d037>7Qa[oool9
JWf001N0TIE8>3=8>3<`9B8]8b0^924f:RHk<2`g;b`i=30`:2D[928^7ahg8Add7aTZ8AlP6aPU8b4N
5Q@N7AdU8B0T7a/L5A<00QTG5`0>6A@C610A6ADC71TE71PE6Q8B6a4A6A8A71@B61<@5@l;50/;5@/<
5P`<0Pl820059AHL9AHC=RXUT;2]QZNX00aZOH0Loooo000Joooo2GalO00GNWUk>S@b>S@b:B0M<B@P
=bTV<2@PA3Ha:1dJ>bdZ9A/H=RTUBS@Z<bTU:R8P;B@R:QhJ@R`X7a@E:B<N9QDB9ADB714>008I4`l0
0alB3bTG52LH5003714?00LX5a@L4PlN4`lD3PXG3`/B2P/C2P/00PX61`055@/;=20K:QPChnKVcm?D
00elO7`Joooo2GAcMP0GMGAfA3dlA3dl;B<P;R<P=2PU;b<P@C@`9adJ=BXW8aXG<RHSAS<Y<2TU9R8P
:R<Q:AhK?b/X7aDF9R8N8aDB8a@B6a4>008G4a000a`B3bHG52@G50036A4?00DT5a@K4a0L4a0C3`/F
40`00Q<<308:20P01AD<338P6bXI4nCYk]3Gg00=M7=f6_ooo`UcQhL05gN?ReeXIEeXIC<_:R`X8c8]
:BdX93dj=2HR7Bl]:B<O6bhZ9T4j;Rh_:RDW9BTX92PS7SX_:R0I6R8S7b0G4b4F4aTC400251@@00dH
510R6ADQ6ADG4Q0F4Q0F4a0P6ADI5A4I510B40/D40`@30`A30`00PP720054P`=:b8L:1`FbNWT_N3K
00ecQhLJoooo2FYmP00GLXZ7LGajLGaj>c8];RDR<b/W<2LS>S@`:B4M;BPV9alL;RLT?SH]<2dY:2HT
;2DS;2<N>2/X9QXK8b0M8QHC91DB7Q<@008I4a002a`C42<H5B<G5A/B41TA3aXB428H5AhD4AdC41P@
31T@30025P`<0Pl820055``=:QlI;1/FYL6oXL6o00eZOH0Loooo000Joooo2WalO09KCeL0524B43HY
9SLY9RlR7bHO6cLZ9dHg<R`V8RdP73hT6QlG5BXN6R/O6a/E6bTQ71dD5BXH4ahA5aTC3aTB3`8F3`/0
4a`C41/C41TC3a@>2Q4:2aH?2b4C41@>2Q4:2aH?2aL?418:2`X61a<:2alE4C8P6c0J5MSKg=SOh00>
O7al6_ooo`YdLgH2GU1I018W5A<e:2Dd:2D]8QlR7QXc:BI4=S8[9R<Z7a`g8ATL5A@V7ATX7QXI5AXT
7a/K51DX5a<L4AL25a<@0QD@300C6Q@@6A@@5a<@4`l;40/;5@l;7Q@@4`l;40/;5@l<5a0A4``<2PP8
4``<81HB<b4L;aXFfn7VfnK[00idLgHJoooo2W>7Q`9]M7/053DV8S@]:C8]:B`W8alP734_:d0l=Rd^
:BLS7S0S6adI5R<P6bDQ7APG7AhP7A/H62DI5AXC6A@D4ADE4@8C40`04aLE4AHE4A@D414@2`h;314@
31XE414@2`h;318@31DA4Q0<30P7214<31dH4RlT7B/L5lKYhlK]i`0>LhN76_ooo`YZOH02MGf501A5
;b/f:bLc:bL^9R8Q7AXa;2Xn=c<b;RXY8Ad/81XR61HU7AXX7a`M5adN7A`P61PW5a@O4aTI4a4J5142
610<01<K510I510H4a0F40`C2``F3``L4a0G40`C2``H40`J4A4F30d?20PF30`R5a8a8Q`/6aJWb<FW
blP03VYmP1coool001[oool:O7al0WUhN@0<9alK:b<O=BPU;b8O=RTU=B/W=2LT9A/H9APE:1/G6A0>
;b8M0R4F5`0681<>7Q4G5@h>40T:5Pl?5`l@0Q8:2`0960l@4PX;5`l@4PX;5`l@7QD@60l@4@X;2@H7
008:1PL01`X61QP@41X@2a@;2b<?2lo7b=WQh@0?O7al6_ooo`YdLgH2MGEg00`_9R4/920b9b@]8Qle
:2Db:RH_9B8S6QLS61DT6QLG4@h[81`281HG00HO4`hL4ALD3`l?2`/E3`lF3a024P/<00PG414A2``F
3a0B2``G414M5A4G414A2``42PP800HH4A4J4PdC30`P3`_>bLkJiNX?M7=f6_ooo`YcQhL2NYB@01A5
B40^:bH_:bL/9b<d;RX_;RT[:BDS7a/Q6aPP71TF4a0W8QhN61TO61TL50lJ4aPA410<2`/B410C4142
3`/<00TD414?2``C414?2``E4A8J5a8D4A8?2``71`P00`L71`065A8B61<=40`<6`l;]lg9a>SR3g>7
Qa[oool:JWf00WNBS`0DF5UA=2`W<2PU;RHR=R`X;bXW:bHS9ahK9A/H8AXH71<@9alL8QLI8aLH7a<?
7Q8G5PlA4P/;5`l@610A0QD;300B60lA5@/<5`l@5@/<6Q4A7QHB6A4A5@/<3PP83PL83@L73PL76Q4A
718=5P`<70h;V:f/Xl?03fYmP1coool001[oool<O7al01A`Kg0o=34Y7QX`8b0a:RH_:2@n;RX^8R@V
5A8X6aPH4PhQ510G4@hO4`l@2@XB2P/F3`lG3`lC2P/H3a024PX;018H410B2P/`6QD91PHI410M510F
3Q091PH:1PL@1PLJ414J410J414^6A@j91YnC3OZloF1Q8@?O7al6_ooo`adLgH03WYjO4/n?2TO6b`R
7bhX9B`W93X/:BdR92DF4bHK61LB3ahD41HA3QdC3`8@2`/011D?3aL@41<<31L@408C30`01aPA4A<<
32lJ5PX821PA4A`E41H@40022PP800T@20PJ4A8J4Q8J4A8]6ADl9A^3CcWPjNeiO7l03gAcMQ[oool<
LhN701B@[JaNGEH[9B0Z9R8[;BP[;2Pg<Rd^:BXU6ADT7QTG5A4J510D4`lJ510>2`/=2`/B410E4A4A
30`D4A4240`<018E4A4@30`Z71H920PD4A4I5Q4D4A481`L81`P>20PH4Q8I4a<G4Q8Z6aLk:QelFCjh
dLQgShh?LhN76_ooo`aZOH0059Zk^feYHC0V8B/S82`Y9RdY9SD_:c8X:RTI5RLL6A`E4A`C41TB3ahC
3a@;2a<;2aP@41XA4AH<31T@408F30`01aT@4AH<32/J5A0821P@41dE4AXA4@023`P800TC20PL4A8N
4a<K4A8[6QHm:1ebDS^:Uhm]PhH03fYmP1coool001[oool=O7al011`Kg0n;R``:BHZ7a/n;RXm;RXh
:bPT7QT^8QdM4ALG3`lP4a0G3a0J4`lM510H41024`X;00/D2`/C2P/C2P/D2`/M510I410];C`h<C4Q
4aPB2PXG3`l00QlE40076A0A=B@N;AdI;QTDFC@Yd]WMZ[k8011lO7`Joooo3GAcMP0@NWYlC3Pf<R/W
:1hJ>R`Y>b`Y=R/X91lJ;28N7A<H5Q0@7a@@5Q0@6Q@@7AHA614A0Q8;300;4``<4P/<4P/<4``<71D@
614A;Bdm>S@e8QDJ4P/<5a0@008P5Q801aTB4S@T7bhO6RdI5EHc:LoKiJNoc`0@M7=f6_ooo`ecQhL0
492][5mFCc@c;BHR7CH`;3Pb;CHb;BDU7bTV8AdE6a@@4Q`E4A@@4APF4A/H4QHB4PH@30`041TF4A@A
4B`c@STl?28H7Q0;31HA4AhH4ahI4aLC4S0X8BhS7BXL5ddf;;KLgic;d11cQhLJoooo3FYmP00@V[^k
Kf=K>C8^:B4M=B`Y=bl[>30/:RHP:b@P8aHK6A0B7a@A6A0A7ADA81LB6a8A1QH<30077ADA614A<34n
>SXl9QTO5``=6a4A008R61<01a/B4S0U7c8S7B/K5TH`:IFh_XVa]`0@JWf07?ooo`006_ooo`elO7`0
471_L3h^;30Y9RXO6ch^:Sd^:SP[:2@N6BhR7AdA5aL?3b0C41L?41XC3adD41P@408C2P/02a@;2a<:
2a<:2a@;2adD41T@42d]?3Pa<B4C618:2QL?3`027aD@00LI414e91h]7AT^6AAI=2WBfMfZ_/P047al
O1[oool=M7=f011jNWa<>3Hb:bLX7QXj;2Tk;2Tf:bPT7aX/8QhM4aPF410O510F410J510M5Q4H4A42
4P/<00/C30`B2``B2``C30`L5A0H4A4];Cdj=3DR5AXB2``G41000R0F4P076A8B=2@O;QlJ;ATEES<Y
cm_UYko?011dLgHJoooo3G>7Q`0@T:f/GeI?=3<]9R8M=S0/>38]=S8]9BDO:BHQ7ADK510B71DA510A
61HA6aPB5Q8B1Q0<300@6AHA514A;3=2>C`l8QPN40/<5Q4A7QPC7QTC5a<B<2PQ;R<M:Q`GCCH/]]cO
W<_@47>7Qa[oool=JWf0012J^k]_He/i<RhY8Ade;2Tg;b/h<2`Z9R0[920S5Q/I418O514I414M5A4P
5a8K4Q465P`<00LM5A4H4A4`<Chj>S`V6AlG30dK4A400R8H4`076a8B<2DO<R<M:a/FAS0YUKRnRK6g
011ZOH0Loooo000Joooo3WalO00BN7If?S4^>R`X;20L;bLT@3<^=b/W<alF9AXG6A<>60l@4@X;60l;
5`l@4PX;4`X;610@4`X;0QP@400@4`X;50/;<bla;Qh[AcD[@c8]=2LVBCL`<R<M6a<?;1dI;ahI>B/W
Cb/RfMGE^<_@4GalO1[oool>M7=f00j4PhI<>SLl;BXZ7a`Z9B8l<Bdg:bPc81LV6QLJ50lG410A2``G
40/F3a024P/<00@H4A4C30`H4A4H4A424``<00hb;S4]7RY4<RU6=2hi:RU=>C<e9AlK510/7AX]7QXg
:RM?;2?JfMjgc]LAM7=f6_ooo`icQhL04YVj]emGD40g<RPS7RHX93Lf<CXd;c<U6bHO6AXG4A@A4@l;
31@@31<@4@l;310<31DB4Q4<308E4Q80414<310<32db<bXQ;3lf;TQ0=Sdd<Da1>CH/91/G4RTQ6bTP
6c@_:Tdd:<COfZWEeA5cQhLJoooo3VYmP00BX/W8Kf=JA3Pc:R4M9b@R=C8^?S@_=BDK:alI81LA6A4A
5@/<60l<610@5@/<5P`<6Q4A5``=0QXA4@0@5``=5@/<;Bd_:alX?30/C40f@cDbC3hg>R/T81LB:alJ
:QhJ=2`XC38XXkfkT[Ni4FYmP1coool001[oool>O7al011mOGe[JV/j9all<Bdh:RI5=C0m<2`n<BdS
6ALW6aLi:2@/8ahS510L510G3`lH41024`X;0QhE6P0@5`l?7A@@6A0A:1hJ=bLP40/<50l<614>4@`=
7A4>;AhJ=B4HJD0_YYVU_m;FO8204GalO1[oool>M7=f019cLgEeMWQ4;RHn<Bdg:RM1<Rhj;b/m<BhT
6aPW6aPj:BD_9AlT5Q4L5A4G410H4A4C30`B2``27ADK010G410M5Q4H4A4T7APb9Ah=2``@3P`D40d>
30`K4@h[7AXc8AQV?RfZWJbjdM]dN7XAM7=f6_ooo`icQhL04W24QHb/ZUA6=d4k=3L`:c/g<STf<Cdk
=RDP72LO6cT_:Bl/92<I4aXG4QDB4AHB4Q4<310<308J5Q`041DB4Q/G4Q<@420O6B/W80`;3@d>30l@
3@`<3ATC42LO6c0T6Ue3;j6//JGAe7>;Ra5cQhLJoooo3VYmP00@IgUmUkblHDm0ACXd>BhZ>34^>S@`
?cXf;24M:alK>bdW=2/T9aTC7aHA6a8A6a8B0QH<308M5AX041/B4QlG4QL>3R4L5bTR7A8;3A8=31<>
318<3AdB42PL6C0R6E@k:i6KWhV]]6Z0Pa5ZOH0Loooo000Joooo47alO00@Kfe/?CD^91/H=bTUC3di
BT8n>BhZ9QXG8aLH9ADB=2DQ:B8N5Ph?4`X;8aTN8aTO0RlU7`0?81LL@S0Z6Q8HDclg<b@V;R<O>RTT
<B8N>2PTD3d_=RPTLDHccL_@[;o9RY6<019lO7`Joooo47AcMP0@Ng]nAShg8a/H<BHSAcXgB44n?30]
9a`H8AHH8a@B<bDQ:b@O5Q0@4P/<8QTO91/P0RlV800?8ATM@S0[71@JD3dg<bDW<2@P?2/U<b@O>RTU
DSla>2TUL4HddM7K[/KEPh^8019dLgHJoooo47>7Q`0@T[FeEEM:9B4L;2TU@T0kAd]6@3hg:24L7QPI
8AHC<RXU:bTS5Q8B40`<7a/Q8QhT0R`Z8P0?81dQ?SD_71PNAd0i<b//<R/V>c4Z<bTS>S0YCdLg>34Z
J4di`=_JZ=WKOibF019cQhLJoooo46YmP00@W/O:HF1B;28M:R@R?STgAdM3ASli;R8M81HH91DC=2PT
<2PS718B5P`<8QXO9QdS0RdW8@0?9QdQ?34^8aTN?cLd=BX[>2`W?BlY=RPS?2hXCD<e>c0YGDLgYKno
V<G5M8f<019ZOH0Loooo000Joooo4GalO00?Kfi^OWF3@3<^=RTU=2TV>CM0B3XfDd<oETa5<bHX:RT[
AS];GDm7>RTZ<2Lb008h9bH03THmC3h]9BdQ7dTf;cHU8S`T7c`T6cDY9Thg;6Y2<C<O6=GGejZmagb0
P1=lO7`Joooo4GAcMP0?NgYmUX^MB3Te<RHS;R@R=3@mBC`iFDM3Fe5:=2PZ:BP[B3i?IEI??bd]<2Pb
008g:2L03TPmCSh^9bhR7dHd;C@T8C/S7c/S6SDX9D`f;6U1<3HO6LgEfjO0cgAhNQ=dLgHJoooo4G>7
Q`0?T[2`[;_6D4]3;RXV:BLT<S]3BdY6FeI=G61E=C0`:2h`B4UIJ6IM@CHd<2hh008d;2d03TM6E3/d
;S4Z93hg;c@[9SXX8cXX7CD^:DTm<FA8=C/X7JoCdYc=dW>;Ra=cQhLJoooo4FYmP00?W[o2]/OAF4m8
;RLT:B8Q<cLoCT]8GEA;G5eD>30`;2`_BDQFJ6EMACHc<b`f008d:R`03TM3Cc/b;cH[93T`:cLZ9S/W
8S/U7CP/9dHi;ea2<T8Y7XV//8Ve^VZ0Pa=ZOH0Loooo000Joooo4WalO00>N7MhOhF1@CDm@3<^<c<l
G4i;BdE7AChj@cXgETm?FdI0Bc/b<2DR@SD`0S8S8P0<;20K;1lI>bhZ=bTVAbLNC2dTC3D[FT8iAbLO
HDa@Y;S1a]?H5GalO1[ooolBM7=f00ifMWRAUiE=?dTo<bl`<3UEBDQ9A4Q2?3Y3>cQJDE9LAT18>2l`
9292=Bh2<B<Q00`X7QTX7ALh;2Td:2E39Ae;;2A;=B]K@SU79amJAdjZ`m?6en8EM7=f6_oooa9cQhL0
3WbFTZS>aUaJHSll=bhe>da@DDU@Dd56@TM:A5]NFeYAAdI0=c@_:T4l<P8a:RL032@O6BDQ6cHb;C8]
:Cl[8DXc:4/l<5]:?TH^951;DJ_MiKGPgaEcQhLJoooo4VYmP00>NYJC/][EJFA/@CXg<30e@dQ<B4eA
@D90BTY4FeYGETe3A3`e>C0/@ST_0S@Y9`0<9A`G9alK=Rl[<b/W?BPQBC0VBcT_FDHkAb`SAT58XLkH
Vl725FYmP1coool001[oool00gaeMGamOGalO00AO7al00a_KW2X[jVLVJM;?dYNCDafJgYVE5II@ci8
>SE9?3UIA4MRBdD2CD0m00]VCTIA@CMHB4ARBTE>?SA8?cLc9RB:NhRV];Rb`lRZ][@05WalO1[oool0
0gAZKGAcMGAcMP0AM7=f00akNWbob<Bd[l1@@e1HB4YhJWiZEeaI@Ci6=c=6>SMIA4QTC4P2DD8o00]/
DDYFACYIBDATC4Q?@3I4@3P_9RB1MXRbaM31fN:W][L05WAcMQ[oool00g=lOG>4QG>7Q`0ALhN700bB
/:W=nNc5fn1FEF=DDEAgNha_JfmKCTQ7@Sa5A3mKDU=UFE82Ee9:00]]HEIIDTAGDd]UFU9?CD12BSh^
;2UaNXRfj^k5oo^L`[d05W>7Qa[oool00fYbMVYiOFYmP00AJWf000bN_kS>no78g^1JEfI>BU5bLhE_
JW5JBdI7?c]4@3eJCe5SE502Fe5:00]/GUEKDD=DCTMREe1?C450AS``:bUNIgJ`h^Zlmo:9ZZP05VYm
P1coool001[oool00gaoP7b0P7alO00CO7al00YjNG]hO7Z^/:JOYjMmNH>IUiAhM8M;AUEABUU5>S@2
A3/h00U;?CY4>SM6>CLo;B@h<2Ni]KZW[[C1b<ZCWIP067alO1[oool2M7Qj57AcMP0:MGAfQHR4_<2h
YK2`Q86=XJ>UQH2HCdULC4MJ?cLc0Slg=@09ACTg?cLe@SHe>2TQ<b`T][Bn`<SBbMKKSIVF01QdLgHJ
oooo00=cSHecRh]cQhL04g>7Q`0:Mhn;V[Z/_nGDY/k3SJF]YlO7TZBgEUibB59U?D4o0Si0?@09@D4m
@44o@3hk=2hV<S8YY[jod?cj`O3XQjVR01QcQhLJoooo00=ZQ8MZP8=ZOH004fYmP00:LXZ7Y<Ff]]oB
WLFhSJRaXlC:UZRjFf1fA4eQ?3m00Shm>P09?C`j@Cln?cXi<R/T<bhXSZBWd_om[moFNYND01QZOH0L
oooo000Joooo6WalO006NWUlQHR0N7]mPhZ3XjNOXZFK0ZNTYP07Yjj`Yjf_YZf^ZJn`[[Rm_<77O820
01YlO7`Joooo6WAcMP06MGAfOX9jMWYlSYF=/kN^/kR`0[Rg_@07^<77^<;7^L;8_/S>`m3L_<G?M7Qj
01YdLgHJoooo6W>7Q`06Mhn9NiJ=O9ZDW/6`^mo;_^CF0/;RgP07`^_W`^gYa?3[boWfcooo[M7BLh^;
01YcQhLJoooo6VYmP006LXZ4L8^7NYVBXlJd^=g8_>GK0[oQg`07_nSU_ncY`o3/bO_jc?goUKRjJX23
01YZOH0Loooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00@oooo`<0001L
oooo0`0005[oool30000F_ooo`<0000aoooo0016oooo00<0003oooooool0G?ooo`030000oooooooo
05[oool00`000?ooooooo`1Joooo00<0003oooooool0;_ooo`00:oooo`<00004oooo0P0000Coool4
00000_ooo`<00003oooo0`0000?oool20000>?ooo`D000000oooo`0000000003000000?oool00000
00000P0000?oool400000_ooo`<00003oooo0`0000?oool20000=_ooo`D00002oooo0P0000Coool2
00001?ooo`@00002oooo0`0000?oool300000oooo`80000foooo1@0000;oool200001?ooo`800004
oooo100000;oool300000oooo`<00003oooo0P0002_oool002goool01@000?ooooooooooo`000002
oooo00@0003oooooool00002oooo00@0003oooooool00005oooo00@0003oooooool0000ooooo00<0
003oooooool00oooo`050000oooooooooooo000000Goool010000?ooooooo`0000;oool00`000?oo
ooooo`03oooo00@0003oooooool0000moooo00D0003oooooooooool000000_ooo`040000oooooooo
00000_ooo`040000oooooooo00000_ooo`040000oooooooo00001Oooo`040000oooooooo0000?Ooo
o`050000oooooooooooo000000;oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool0
10000?ooooooo`0000Goool010000?ooooooo`00033oool002coool300000_ooo`040000oooooooo
00000_ooo`040000oooooooo00000_ooo`@00002oooo00@0003oooooool0000ooooo00<0003ooooo
ool00oooo`030000oooooooo00;oool00`000?ooooooo`02oooo00@0003oooooool00002oooo1000
00;oool010000?ooooooo`0003goool00`000?ooooooo`03oooo00<0003oooooool01?ooo`040000
oooooooo00000_ooo`030000oooooooo00@00002oooo00@0003oooooool0000moooo00<0003ooooo
ool01?ooo`040000oooooooo00000_ooo`040000oooooooo00000_ooo`030000oooooooo00@00002
oooo00@0003oooooool0000`oooo000[oooo00@0003oooooool00002oooo00@0003oooooool00003
oooo0`0000?oool200001?ooo`@0000noooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`02oooo0`0000?oool200001?ooo`@0000loooo00<0003oooooool01?ooo`040000
oooooooooooo0P0000Coool300000oooo`800004oooo100003coool00`000?ooooooo`02oooo0P00
00Coool200001?ooo`<00003oooo0P0000Coool40000;oooo`00:oooo`040000oooooooo00000_oo
o`040000oooooooo00001Oooo`030000oooooooo04Woool00`000?ooooooo`03oooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00?oool00`000?ooooooo`17oooo00D0003oooooooooool0
00000_ooo`050000oooooooooooo000000Ooool00`000?ooooooo`17oooo00<0003oooooool00_oo
o`030000oooooooo00;oool010000?ooooooo`0000Goool00`000?ooooooo`0joooo000/oooo0`00
00?oool200001Oooo`80001:oooo0P0000Coool200001?ooo`800005oooo0P0004Soool200001?oo
o`800004oooo0`0000Coool20000B?ooo`800004oooo0`0000?oool200001Oooo`80000loooo003o
ooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003o
ooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003o
ooooTOooo`006_oooaRISXd01Y1SCYemKIUjLiV2N9UfKIV2N0BIOgD01iUfKIUjIi1aHiA]GX]ODHmV
EXENC`04RF5B00J9FD^1G4J4G4n4G4J4G4n[^<84VHj=0YV5Q@03VI:AVHj=VHj=00NISXdJoooo67Qc
M@06KTXiOVUON6ATN6aWN5mKN6aW17QXH`07N5mKN6AGKUaDM5U@JTe5L5E<ITi600A/DTT01Va;@V=>
?fQ>B6Q>?fQ>B96Z^@AhLgD2N6Y/00=hN7YhLgEhLgD01gQcMA[ooolHNg]k00IaDCf0KV5kJVMkLfYk
IUikLfX4NfiV00MkIUikJUYaHUIgGU9]DTMcFTeXDTH016iFB@06KTi3IE8oJU98JU8oJU98Tjjk17]k
N`9kLW800g^0P7]kNg]kN`07Ng]k6_oooaQgNWX01VeA?Ge^HGMZIWMbJWMUGWMbJPAgKVH01gMUGWMZ
FFeREW=NDVYBAfmICFEBAP04JeE900I[CT9RDCiWDDQWDCiWDDR@[KX4MgYj0WMaL@03MgmoMgYjMgYj
00MgNWXLoooo000Joooo00JISXfIRXZITi:ISXfIRXZITi8:VHj=00>IRXZITi:ISXd01IV>S@08TfMA
V7U^VGYZVH9mVGI]VH9hVGmeVG]/0YEkL008VW]`VWIWTG5RTFeLTF=DT6EEQee>SVAE0XUQDP:9GDh0
1H5LBXALC8ALAXA/J:^RX`04VHj=0YV9R003VHf<VHj=VHj=00NISXdJoooo00IhLgEhKg5hN7YhLgEh
Kg5hN7X:N7=e00=hKg5hN7YhLgD01GQcM@08LTdkN6EPN6AKN6a[N5mKN6aWN6QSN6AJ0W=TG@08NFAM
NF1FKe]BL5Q>LE58LEE;Ide4LEE;0VaBB@9/CTD01F=>@VQ>AFQ>?fQOHI6FW@04N7=e0WQ^L0YhLgDJ
oooo00IkNg]kMGEkOWikNg]kMGEkOWh:Ng]k00=kMGEkOWikNg/01G]kN`08MeI1OFaUNfYNNg=]NfIN
Ng=ZNfiVNfUK0WAVF`08N6IKN69DKeaAKEU<KU96L5M:ITm3LEQ;0ViFB@9^DD@01FEBA6YBAVYB?fYX
JI>PY`04Ng]k0W]gN003NgalNg]kNg]k00MkNg/Joooo00IgNWYgLg=gO7agNWYgLg=gO7`:MgYj00=g
Lg=gO7agNWX01GMjNP08M5I1NfaWMfYMMg9/MfENMg9ZMfiVMfMI0W1SEP08LV=FLUmAJEQ=IeA9Idm4
JUE8HDe2KEM:0V]EB@9[Cd<01F9AA6MAAfMA?VM[KY2T[P04MgYj0WMhN003MgemMgYjMgYj00MgNWXL
oooo000Joooo00ZISXfIRHRIRHRITi:IRHRISHbISXfIRXZITi:IRXX2VI>B19V>S@03VHV8VHf<VHj=
00FISXd029EXDIinLiUjL9UnLiUoMIUjL9UoMIEgI0:9LVH02:1`GIEXG8a[Eh]ZFhURDhUQDhAIC8AL
C@::H5001hYMCXYLBHELD8ALCHALBYBGW9B6Q@06VHj=00>IRXZITi:ISXd01iV>SA[oool01GQcMGQ^
L7Q_LGQhNWQ^L002N7=e00=hKg5hN7YhKg400WQhNPAhLgD00gQ^L7QcMGQcM@05N7=e00=cCSamJ69h
I5l00WQXH`03N6AON6QRLf1B009VG5L0281LD7EDCV]GBf]HCfaBBFaBBVM;@fQ>A@9]DDL01fe>AFe>
@FQ>B6Q>AFQ>@WZ<V7YfN@06N7=e00=hKg5hN7YhLgD01gQcMA[oool02W]kNg]gN7]gMg]nOW]gN7]l
O7]kNg]eMG]nOW]eM@9kOWh4Ng]k00=kMgQkO7akNg/01G]kN`08M5@oOVeSNfYRNfeVNfiVNfYRNfaS
M6=C0V9OF@08O5e@M5=<JUM8K5]>KUM;KUU<Je56JU950VaCAP07K554K590J597JU95JU94PiZVPhF7
00IkNg/00g]eMG]nOW]kN`07Ng]k6_ooo`0:MgYjMgQhMgIfMgalMgQhMgemMgYjMg=cMgalMg=c0WMl
O0AgNWX00gMhN7MmOGMjNP05MgYj00Q`DSijJf1gJV9gJfIgKVIgJV9gJF5`HE42FeeG00QcFTi^CTUT
DTEWFDa[F4a[FTeYDTMWDDD2IU5400MVCd=VDCmTDDIWDDEWDDB6X:j6S8h01WMjNP03Mg=cMgalMgYj
00MgNWXLoooo000Joooo0YV>S@03VHF5VI:AVHj=00:ISXd00iV9R9V=S9V9R002VHf<39V>S@08Tf=>
V7ebVGY_VGY`VGidVG]aVGY[TgE/0X5_I@08QVIFTEYHOee9R65BR6EJR6EFQ5U;PF5>0hALC@05Q5a:
R61@P5Q:Q5a=ZkS200NISXd00iV9R9V=S9V>S@07VHj=6_ooo`9hLgD00gQZK7QhNWQcM@02N7=e00=h
KW1hLgEhKW003WQcM@08LTXiN6USN6AON6AON6QSN6AON6AKLV1K0V5LF008JeA:LdY>H4m0Je99JeE?
JeE<ITU2He550fQ>A@05J4i2K599Hd]2J4i5TJZi00MhLgD00gQ^L7QcMGQcM@07N7=e6_ooo`9kNg/0
0g]bLW^0P7]kN`02Ng]k00=kMgQkO7akMgP00W]lO0akNg/027MA?Ge^J7]ZI7]ZHW]]IG]YHG]ZG7MW
H09]IV0027EOD7]CEFMFAG5FBG5GCg5GCFY:@VECA0=ZDTD01FYBA71GBfM@A6YBAI>^^`07Ng]k00=k
MgQkO7akNg/01g]kNa[oool2MgYj00=gLG5gOgmgNWX00WMjNP03MgQhMgemMgQh009gOGd<MgYj00Qd
DCekKVQgJVAgJV9gJf=gIemgJU]dJ602L6US00QiHe=lEeUXF4Q`EDU`EDi`EDeXAd5RDD<3Ie5500EW
DDA^EdaUD4AWDDF@[KX01gMjNP03MgQhMgemMgYj00MgNWXLoooo000Joooo0YV>S@03VHV8VHf<VHj=
01>ISXd019UWDIUiKYUjL9UjM0:INW0059UjJiUnLiUiKiUiKi=aHiAWGY1NEXeQD8ePEXYIDhePE7Y<
A8=KCH=XFH1EA8QLCHQOD85MCXQTEJF]^16ISXdJoooo0WQcM@03N6i`N7=eN7=e01=hLgD017Q=>gQU
GgQTGWQTH`9hI5l057QTFgQXHgQTGgQTGg9LE7ADD6i=BFmBAfmBCF];BFiBBUa1?FM=AFMJDF=8?Fa>
AFaAB6=>AFaFCH^P[a5hLgDJoooo0W]kN`03NgMhNgalNg]k01=kNg/017]F@G]/HW]ZGg]ZI@9kJV80
57]ZGg]`JG]]IG]]IGMUFWMNEG5FCWEJC7EKDVmABgAKCf=7@6a>AFaOEFM=@71BAG1DAfEAA71LChnW
]15kNg/Joooo0WMjNP03MgQhMgemMgYj01=gNWX017MF@GM/HGMZGGMZH`9gJV8057MZH7M`JgM^IWM^
IWAVGG=PEVeHCgALCgAOE6eBC7ANDFA9@Va<AFaOEfE?@ViAAFiCAV9?@fiND8fY]Q5gNWXLoooo000J
oooo69V>S@08VF]EVGYZVGY_VGYZVGYdVGY`VGidVGY`0iUoM@0?Tg5STVYMSf9FU6ILSf9ESfEFRUMA
Q5M;REiCQ6ILQ5E4RUa=QEa=UWaeViZJ00RISXd00iV:RYVCTYV>S@06VHj=6_oooaQhLgD027QA?gQT
FgQTGgQTFgQTHgQTGgQXHgQTG`9hJ68047QXHg9LE79GD6iABWAEDFiBBW1FC6Y6AVI;@faBBVMED6Q8
?Fe>AFQ>AG]_KWn;TPQhLgD00gQ_LGQhNWQcM@06N7=e6_oooaQkNg/027]H@g]ZGW]ZI7]ZGW]ZIG]Z
HW]`J7]ZHP9kK6<047]^IWMUFWUSF7=LCgMKEG=ICG=KCFa<B6YCAfiEBF]JDVY=@6aBAFQBAH5iMhFF
W@QkNg/00g]eMG]nOW]kN`06Ng]k6_oooaQgNWX027MH@gMZGGMZI7MZGGMZHgMZHWM`J7MZHP9gJF40
47M^IWAVGGQWFg5ODG=LEW5JCfmKCFU=B6QGB6]EAfUIDFM?@VIAAFAAAH1mO8FKY0QgNWX00gMcLgMl
O7MjNP06MgYj7?ooo`006_oooaNISXd02He]I:ZAOIUjKiUjJYUjJiUjLiUnM9UjL9UoM@02VGU_012I
OWBIMVfINV^CKE^BIef?IUV?IUR:FU>9HDn4FD^5HeJ5GDn8G4f0G4fQVInMU988VHj=00NIRHRISHbI
SXfISXfIRXZIShnITi800YV>SA[ooolGN7=e00=ZDTf9Lf=hI5l00WQTF`04N6ATN6QSN6AON6QS0WQT
G`05N6QSN5mKN6AKLUQ=LUEA009^EDd02F];BFYBAVI;@VQECFQ=A6a>AF=>AHN;UWioP@08N7=e00Mh
KW1hLgEhLgEhLgEhKg5hLgEhN7X00WQcMA[ooolGNg]k00UXCdN7L5akJVAkJUikJUakJVMkL6QkJV9k
KVH00W]]I@05Ng1XNfINNfYOMemANEeD009cFdl02Fm@BfiFAVY>@fQFBfQ?@W1BAFMBAHVCW828R@08
Ng]k00MkMgQkO7akNg]kNg]kMGEkN7QkOWh00W]kNa[ooolGMgYj00QQB3ioIU9gJVAgJUegJU]gJVIg
L6QgJV83MfiV011gL6QgIEigJV1dH5=hGUAaG4iaG51]D4a]EDIXCT9TE4QTCD1^DDEUDDF5U9mmRX`8
MgYj00MgN7QgOGegNWYgNWYgLg=gMGEgO7`00WMjNQcoool001[ooolFVHj=00YOASg<Wh^KNVbINW>I
NV^INVZINVnIPWRIMVfIOVl2VH=n0YUkL@0>VGY[VGEWUFAJUF]IU6ILRf=@ReU>Rf5BQ5Q:P5a=SFAE
Q5Q;X:RcV8b;39V>S@03VHV8VHN7VHf<00:ISXdJoooo5WQcM@04@S@_Zgm`OfYPN6AT0WQTF`04N6AO
N6aWN5mKN6QN0WQ/J`9hI5l03WQTFgQPEg=ACG=HCGAED6YAAF];A6]BBFM;@V=>AG9FCFM;@hJKZgQd
MPahLgD00gQ^L7Q_LGQcM@02N7=e6_oooaIkNg/02SD/9I]eHhEcI7]ZIg]ZGg]ZHG]ZI7]cJW]VGW]]
G`9kLF`2NfUQ00ikJUakIeYdEU1dG4mgF59]ETE/CT=/ETU[D4AWDTEcG4m[DTN;Y;5mOWh<Ng]k00=k
MgQkNGUkO7`00W]kNa[ooolFMgYj00XY8Qb9IeB5MVEgJVIgJV1gJV=gJVAgLVYgIEigJe`2MfmY0WMW
G`0>MfYKMfQIL5EAL5]>LeMAJUI4Idi2IeE9JE14IE55L5i@JEE8RjNdNh2037MjNP03MgQhMg]kMgem
009gNWXLoooo000Joooo5YV>S@0:GdHmc9n;VgY/VGYcVGY[VGYZVGY_VH9hVGI]VGi_0YV3OP:INg40
3YUjJiUeIiETFYE[FIAVG8]SD8]ICX]QDXAHBX1LCHeTEHAHBj2X/iR<R`bISXd00iV9R9V7QiV=S002
VHj=6_oooaIhLgD0148d;j]oL7mZH7QTI09hI5/017QTGgQ/IgQOFgQXGP9hK6/2N6AO00ihI5]hH5Mc
DDecF4edEE1ZDDE[BdA[DTUWBd9SCTEbETeWBd>6Vj]hM7H<N7=e00=hKW1hKg5hLgD00WQcMA[ooolF
Ng]k00Xe;2FKMF>5LfAkJVMkJUmkJV5kJVAkLfYkIUikKEl2Ng5/0W]YH@0>NfYLNfMJM5I@M5a?MeQB
KEI5K4i3K5I9Je14Ie95Lea?Je97RjBaOGin37]kN`03NgMhNgUiNgal009kNg/Joooo5WMjNP0::B8L
RFMDQGIUMfYVMfYPMfYSMfYTMg9ZMfENMf]L0WM_J@9gIel03WMZFgMXFG1EDG1KCW=GDFYFA6M>@VME
BFU@A6EAAG1ND6UEB8^W]7^0P0agNWX00gMhN7MkNgMmO@02MgYj7?ooo`006_ooo`:ISXd00iV:RYVC
TYV>S@0@VHj=00^9MWX]40_`ajbHNFFIOWNIMFbIOWBIMFbIOWBIOgFINF/00YUjK`0?VG]/VFe/UGYS
UWESVW5UU6YMT6ILS5i=Sei?Q61AQEU7QEa@RF=CRV5A[;W301:ISXdJoooo0WQcM@03N6maN7QjN7=e
011hLgD026IJH1P>3>RlY7QUEgQXJ7QPFgQXHgQPF`9hJ6<04WQTFgQTGgQTGgQTFWQHFW=SDWAODgUK
EWAID71ED6]>@W1>AVIBBFQ;?VQ>B6eEBVeAAi2Y^19hLgDJoooo0W]kN`03NgEeNginNg]k011kNg/0
2f9JGa091]jdWge/G7]`K7]WH7]`J7]WH7]]IG]^IW]]HP02NfYT00mkJE]kFUYdHDmbG4mhG5=gGU5a
Fe9ZDT=cDTMZEdYXCSiXDTM]ETU/DTFA[;T04W]kNa[oool2MgYj00=gLg=gO7agNWX047MjNP0;Fe=J
2PD4eJ^INfaNMg1]MfQPMg1XMfQPMf]SMfiVMfiU009gJV@03gMWFGMFEg1KBf]EBG9HCW=MCfaLDFAB
@fmBB6QGBfA>?FAAAVUDAfI?@hbZ]`0BMgYj7?ooo`006_ooo`:ISXd2VHV800>ITi:ISXfISXd03IV>
S@0<WI:A>Q`FRVYTQfQRVGY`VGicVG]aVGidVG]aVGY`VGidVH=i0YUfK@0@UGISVVERUFYJRf=DU6UJ
UFYKT6YGQEmCSee>Rf1@Q5e;Pea<P5a=R61AXIjQWZBW4IV>SA[oool2N7=e00=hKW1hKg5hN7X03gQc
M@08O7Mi8aHDKeQCR79YN6AON6QSN6AON6QS0WQTG`0DN6QSN6aVN5mKN5mKLf1CNE1CLeU<JU59MEU?
MEQ?L5Q;ITi8LTi5Je57Idi2Idi5Hdi5K599QhfEOHN<4GQcMA[oool2Ng]k00=kMgQkMgMkOWh03g]k
N`0<PH206A0<NF9DZ8]jNfYRNfeVNfUQNfeUNfUQNfYRNfeUNg5Y0W]VGP0@M6EEN5ADM5i>KEI:MUa@
M5]>LE]9J557LU54K5=6Je53K596Ie95L5M:RHfBOXR;4G]kNa[oool2MgYj00=gN7QgMWIgO7`03gMj
NP0<Oh6140/8NfEA_j28MfYRMf]VMfMOMf]SMfMOMfYRMf]SMfmW0WMUGP0@L6=CLU=AL5e<JUI:LU]>
KUU<K5U7IE15KTm3Ie54JDm2K557IE55KUM;QHV=NX:44GMjNQcoool001[oool2VHj=00>IRXZISXfI
SH`03iV>S@05B2PMVX=kOUeBV7UUVGYc00:INW001IUjJiUjM9UjL9UnM9UjL002VG]a012@E4^DIeb@
Fdj@GU2?GDn?N5n;HDj;HE29F4V5H4^>G529G4f1G4V=FTj@MVR__l`<VHj=00>IRXZITi:ISXd00YV>
SA[oool2N7=e00=hKg5hLgEhLgD03gQcM@05<B0KMfIPO6AKN6EGN6AT009hI5l017QTFgQTHgQTGgQX
H`=hI5l046i1?GACCW1;@g1=AG1=AW1VE6]AA6]AAfa9@FQBA75>B6a>AF=>@G9=AW9UGHnV]0ahLgD0
0gQ_LGQhNWQcM@02N7=e6_ooo`9kNg/00g]eMG]kNg]lO00?Ng]k00DR5a5hJ5jMP7=mK5akJVL00W]Z
HP05NfYLNfYUNfYRNg1XNfYR009kJF40474o>gM<B754?G56?g=6@7=SD6aB@faBAVi;@6QD@W5BAfiB
AFEB@7=>A6mPEHfS[@akNg/00g]eMG]nOW]kN`02Ng]k6_ooo`9gNWX00gMcLgMjNWMmO@0?MgYj00DG
3`YdHeNfUHMkK5igJVH00WMZHP05MfYKMfYSMfYRMg1XMfYR009gIel046di=g=2@F`k=f`l>Fln>fmL
C6M?@VM?A6]9?VAC@FeAAV]AAF9A?g1<@VUICXFKX`agNWX00gMcLgMlO7MjNP02MgYj7?ooo`006_oo
o`:ISXd00iV9R9V=S9V>S@0>VHj=00f9MWE8<RZ9JejINg6INVNINW>INW2IMVNINV^INVjIOWRIOWBI
KVP00YUjK`0AT4M3T4ToS3/cUE1=Rd<jUEU@PEa:RV9>RUa9QEI8SF1?REa=Q5a:R5=5Q6=CV89gZ[o<
00^ISXd00iV9R9V=S9V>S@02VHj=6_ooo`9hLgD00gQ^L7QcMGQcM@0>N7=e00eVFUdU7AZ7LFIhI5mh
I5MhI6AhI5mhH5MhI5YhI5ihJ6MhJ6=hEeH00WQSGP0AKSDfL3liJc<_MTM7Jc/fMTm9HTe1KE=6KDi1
J4Y1LU98K4i5Idi2K4HoIeI<O75[RIn]00]hLgD00gQ^L7QcMGQcM@02N7=e6_ooo`9kNg/00g]gN7]l
O7]kN`0>Ng]k00eRFUXo=BjUR7]kJF5kJUYkJVMkJV9kIEMkIeYkIeekKFQkKFEkF5H00W]QG00ALCLe
LClfJS4ZMdM3K3`cMda5HTTnK5=4K590J4e1LeA8KU95Je94L4Y0Je]=NfaRQiVR00]kNg/00g]gN7]l
O7]kN`02Ng]k6_ooo`9gNWX00gMhN7MmOGMjNP0>MgYj00eKDeA=@S^kVXagIemgJUUgJVIgJV9gHeEg
IEIgIEYgJfEgJf=gE5<00WMKF00AKC@dK3hdI2hVLTA1Ic/bLTQ2GT<jITm2IU4oI4e1L5=8Je55JE54
KTU0JE]=MFAIOhfB00]gNWX00gMhN7MmOGMjNP02MgYj7?ooo`006_oooa>ISXd03CLN6_C6[IenMIUj
L9UjJiUjLiUjJiE^H9Y`HIj2LIUiLYUbHiEDE@02UU]>01:BH5V4=2NJH5JD@d>1:2:@?SB;D4F0FD^4
ITn4Dcf9Ge6>G529G4f9F4Z9GTn9I5FWZZfIVId?VHj=6_oooa=hLgD03B8G5m^[UGiXHWQTGWQTFgQT
I7QTFg=HCgULDge]HWQUI7QLDg=1AP02M4]3019_CdaT;BEkF55g@4=R925b>39[Ad1SCTAXFDQXASM]
DTUaCTQ/CTE/Bd9/DTQ/ED^;VJ5hO8<?N7=e6_oooa=kNg/03ALA3/:JPX1]H7]ZGg]ZG7]ZIg]ZG7AM
D7QMDWibI7]/J7]ODW@o@002LT@j019/CDIM;B5fHEEiDTiR9Qm_=2a/A3YWCD9ZFTQZBSI]EDMaDTM^
DTE^CdA^EDQ^F4^=VimkPHD?Ng]k6_oooa=gNWX03@h;2Z^7L7e[G7MZGGMZFgMZIWMZFg1KCW9JCgY`
HWM/J7MMCg0i>`02Jc/b019SB41C:am^IUMfGUIN9amY<2UW@3IUBT1WF4QWBCEYEDA]DDI[DDE[D4A[
EDQ[EdZ:Ui]gOX0?MgYj7?ooo`006_ooo`BISXd00iV:RYVCTYV>S@0;VHj=00igGem>>BnNPgBHNFjE
LUjNQg^IMF^ILUn<JEFAGU6YR7jAEdeP6`gGUHL2T44k01>=I5YiC4Aj<2F1Hdmn?2n:@3if;B6S@3J0
JeF9FSf8FTf8I5>>H4j4EDZ9H569G4fIOg6Z/[NIVId03YV>SA[oool4N7=e00=hKg5hN7YhLgD02gQc
M@0>ETI9:b@OWhMgN6EPLea?OG5[N61LN5a?JUA7L4]5RWA`KdE0A1/C]Wie0W0h=@0CKU]EG4M4HRdW
I596Gc4ZKSdnFb/SQSXdI5m>KDdgK4i7K5I<LE=6ITQ2K599K4i5O6iURIFLN7b300ihLgDJoooo17]k
N`03NgEeNginNg]k00]kNg/03Te1@S@Z8;NGPGe/IGAODGifKW]WHG]OD6]EA6e:@8U`KFlm>CDB2Yma
J09a?cP04gATFfeUH6ld;69<?UPd9fQ7@e4]8Gdf;FAJB6e>=G1@Ag1JCGEJB6Y=A6iGBViBAGUYGHN?
TG^1Q@0>Ng]k6_ooo`AgNWX00gMcLgMlO7MjNP0;MgYj00i2>3Tg:Ak9XhYkK6M`GE1jM6igJ6=gGDiV
D41WA3b2JFQY=3<W30N8HU/2K4<j01=dJ5ieNWEf>C5MA3M?<bEPCdQ6;R9b<BUPEDAYC3A^CTI^FDec
G4UXCdA[Ed][DDEbHEEoQ8=gOX003WMjNQcoool001[oool2VHj=00BIRXZITi:IRHRISH`<VHj=00hc
6QS>W8:GMfbINVZ@IERMRh:INg6IJER3CcZ7DdEZ61BoWiEN5A=mACh2RdY501BAE4ZHOG::?3B0C4UX
=bQS?SIB7aIP8Q>_Cc^=L5>=DTN>Je^>IE>9GTb4F4f9GDj9HeBIUZBVVHbNVIL=VHj=6_ooo`9hLgD0
0gQ_LGQhNWQ^L00=N7=e00hL4Q>kS7B1K6IhI5]^D4UnMW=hI5mhE4UP?S5WA3e@6QVNRH<o6Q]dEe<2
KD=501AcD4ahKfQX:BEQCDi?=Be:>3Lj6aM?8aVCBSYcHdabAd9aGU=aETYZCT=VBdE/CTE/EDalQIZ4
OWMmO7h=N7=e6_ooo`9kNg/017]eMG]nOW]gN7]lO0akNg/03Q@>3K>;LH]hL7]ZGW5EBH1iLg]YHG]J
Bf4o;fI2>D8C4HV2NUM:AY62N`9gHfD057]]JgemMVdm<fm_K6AECUA9AcLM5T4P4h94<g9RBG=;@gES
E7EKC6iEAVY@AFiAA6iIC7V6WX1oNWj1P@ekNg/Joooo0WMjNP04Mg=cMgalMgQhMgem37MjNP0>3@X9
ZXI/SgifMfYMKE=7OGIaMfMOMeY;GC//HChe=@l=M7M`I6mYYJFN0WUiO@0DO862Nh=nJdLjM8N3Kf]W
F5AE=1hG=ahBLCl_Kei7L4]4Lf=ELe]=KEI7J515Jdm3JeU<LX>NMgYiNWin3GMjNQcoool001[oool2
VHj=00>IRHRISHbISXd039V>S@0?SGj67PP5jK^KWGebVGY[Tf]OV7IaVGY`TEY9Nd/bPC4UAPd6^8Ii
ViJ5VX1j00:NZ:T05IUmM9V6OhaSFInJUI5WF85jNDLV8S`V94XF3[5E?9=/FIU_FI=^HhYMC8EJC8UD
AXUSDhF7SI1nPZFMZjZTU`0<VHj=6_ooo`9hLgD00gQ^L7QcMGQcM@0<N7=e00mZHVd;1`OX]iMnJF=h
I5]bEe1hIFEhI5m_AS]I>b]T:bD]4@n/PgN0Og5iIF<00Wf<T00EN6=LN6aWJTa7Oh>3Kdm6HFAV;A`L
:RLW?AXFVDhkMeaAO69AM5iHJdi3IT]3K4LoK5E:J7IoLVMZQH6ARHMn00ahLgDJoooo0W]kN`03NgMh
NgalNg]k00akNg/03fQTL0H40^>cTh1^I7]ZG7MQEge_Jg]ZHVm6>E@j9edX7bT=2:imKhAfIWQOF@02
OXV801EkIUUkKF5[Bd=nP81_CD1]JVI4;bM1?CLj6aB8AS=dFDalIE5iIEY_EDMXD4I^BSm^ETUXMgU]
I65lO8^7R84037]kNa[oool2MgYj00=gN7QgOGegNWX037MjNP0?HEm]0P81gjn@OFiSMfYKM6AINg9]
MfYRJD<fC3HTE2@M90`8[GQYPf]JLUA=009jP7h05GMRDWMXF6I5?GQiNVU6>G1ZHe8j;e5<A3TM5WTo
;fiCB7QUD7MWFfeFBFE@Af]:?V]DAfAcLVAMEG1aPGn2OP0<MgYj7?ooo`006_oooa2ISXd045m6?DdX
97eGD9f5LYQiJIUbHYUjJIV3MiUjL8M;@7YHAG8j<dH:47dh>XeRDY1RE`:JO7805J1YH99gHi9?@iEG
BHeIBInEOXA=?g9EDD0/94l:0KihI9QgFYQgJH]OCHEJCXEIBhiOD8A`HXV8T7ARLJbYX00<VHj=6_oo
oa1hLgD0448d;c/T8f14?Z2<MgQUFgQLDgQTFGQ/IWQTGVDh<eY;?UXf=S0E77A2AfmGBg1AC09jJV@0
5GiBCFmQDg0m>7I:@Va7?H21L64k<eE7BBPT8D<B3:I^H7aYDWYVGfY=@VI:A6Q:@W5CBFMQFFmgPeYA
I92BR@0<N7=e6_oooa1kNg/043D/9BLH5Ue1=kZMQ7e/Gg]OE7]UF7]`IG]ZGfLm=6AEAFeCC5I7@Y5Q
HGEODW5CC09hIEd05Ga9@faGBf`g<7<o=VPl<GYiIeli;UY6AS@Z93h>1YMVF7iZDGa[H6eB@VQ=@fQ>
@g5HBf]TF7^2S65LKI6FR`0<Ng]k6_oooa1gNWX042TR71P>3ELj;/f[SW]/GgMMDGMPE7M]HWMZGF@m
<fIIBWQWGVm]HJEjN7AREVaAB`9aGUD05GDm>F=:@V@^:V`d;F0_9g5^GUPc:EY2@cX]9c/>1XQMDW]X
D7UZH6YB@FE<@VA>@VeJC6UREX27T6=OLXbBR00<MgYj7?ooo`006_ooo`FISXd00iV:RYVCTYV>S@07
VHj=016=NWhH1`<b4`oLXI2BLF2IMVJIJF>ENF6NO6bIKFJ7FTJ2DSf]Vi6HO6fIIf:CHef=HET00X]H
D@0ETDi:PdQ5QTE1PcLaPc/jPeI8RDI0MD4gHC8T@Q<>O2`O/Ha_WWYXRfA=QEI;PEM9SF=CRFQHESH/
g]WYT8B600:NVIL:VHj=6_ooo`EhLgD00gQ_LGQhNWQcM@07N7=e015ZGV@>2PTY61KPYIAkJ5YhH5Mh
E5AcIEAmJEmhF5MUASUSACN@R8=hJF1hDeAbE55]E5400Ve=BP0ELdA3Hd0oJC`kIS@`ISTjIdm5JcTg
FCTdARdT;1DCKc0VUWeVP6QMJU52ITM2HdY1LUE:K5Q>?blZ_KO8MW9c009mO7h:N7=e6_ooo`EkNg/0
0g]eMG]nOW]kN`07Ng]k015XGf@51@<O4PoU[i^7MVAkIEUkEeIdJeUnL6=kFUUWBC]PA3>?R81mLFQk
GUagHe]eIf000WMPF@0ENeYBJe98Ldi6KDXmKDe5K5E7LCPfH3PaBbXN=1<>KB/PS7EMP6UMKEE2J4]3
IDa0LeI9KUY=<BHOZZRbOGai009nPH4:Ng]k6_ooo`EgNWX00gMcLgMlO7MjNP07MgYj015QFF010P4J
40gZ]J6=Of]gHeMgEEI`JUYjL6=gEUMTAcYJ@C29PgakLf]gHUmdJV1eLVT00WU/I00EO6QKK5e?MEY>
KUY7KUY>K5Q8LCDeH3D_BbHK>1<>JbTNPF]FO6IKJU=1ID]2HT/oL5A7JeQ;9AhIUYBKOWmj009jOWh:
MgYj7?ooo`006_ooo`FISXd00iV9R9V=S9V>S@07VHj=015mIg8M4@P000b1KVFNOVnILF>IKfVCIV:H
QffIJfJ7DTQkAcVPR7NNR86IOgFIMFbIOW@00YUoM@0EVFUOT6eGU6YLRf=@Sei?PEE4T4Q5QdHlMC<_
GRHTGB<UR5PlWWAYT6I@QEI;PEQ6SE]?RF=D;QdM`Z^TZZ>W00:HS8/:VHj=6_ooo`EhLgD00gQ^L7Qc
MGQcM@07N7=e011KCE/01P054A^5MVamJ5ihG5AhG5]bEEAhLUmhEeMU@caL>S:7O75mLFihJ6=hH5/3
N6QS01EhE4m^F4UdFE1ZDDI`CTIRAcab?SmW?cQI;bi69bQ;9b]eEcj1IEm`EDEVAd9SBcmbCdQ/ED`E
5aZjYj:9Qhd00WQdMPYhLgDJoooo1G]kN`03NgMhNgalNg]k00MkNg/04EeFI2h/7591?:J<NWi]Gg]R
EW]VGgMKF7eeHG]QFfM<@650=H]oLGicKG]^IW]WH7]]I@02NfiV01EkEe9aFTYgGU9]ETQcDTMRC3a_
ACmVBc]P?cMG?CEM>SYlH460IUaaF4EXBd=UCcmcDdQ^FD`F6Q^dYIn7RXd00WenOPYkNg/Joooo1GMj
NP03MgQhMgemMgYj00MgNWX04EYFID]4<8eWFKnMQGY[G7MREWMXGgALF7]bHGMTG6A@@F12>8UnLGY_
J7M^IWMXH7M[H`02MfiV01EgEE9]ETUcGE5ZETQ_DTQNCCaYB41QDSiPBSmQC49YBDMnITAjI5Q/EdAU
Bd9RD3i`E4Q[FD`E71f_XYeoQHL00W^0P0YgNWXLoooo000Joooo3iV>S@0AR6]YUGYdTfmQSfYHVGUY
WWYZVGU^VF]VVGY]VGEVRV1@Q4i3SV5AYIB4WXN1VGY`VGE/00:IPWP05IUXH91NDi1NCi1^FHMJBWiH
BHYC?hEDA8EIA8EAA81BA8aQD99WEXmQCh5EAhEKBHUPBhYODb@D4mK2bYnGRP0<VHj=6_ooo`mhLgD0
4FIADGUTGG9KE6iICWUTFgeTFgQUH7QGF7QZH7QPF6Q<@VE0>W5DBHEnLgeaKgQSGgQPF`02N6aW01Eh
DTm^CDI`CDA`G4eWBT5OBD5^ASUYB3iYC3iYACiTASibEdUgFU5`DDIRASiXCD5]DTA]DDXC4aG>^lR5
QGd037QcMA[oool?Ng]k015^F521JUegIeicI5EjJEanJUikK6EkHEikM6QkIei]EDQ[BCmaE4N2Nfin
MW1kJfAkIf000W]cJP0ENeeDLEI9LDi2LEe;ITdoFd]0JdLgIdLjId/jIdDjI4PjMEe;Nf1ELeE6HTPn
J4i0KEA3K5A93A0@bK[9Rhn:00akNg/Joooo3gMjNP0AKeQ;PVYHM6]TLFMIMVMKNVYMMfaWMfAQMgQ[
MfQQJeI:JTa1KE54NgAWNWA]MfaTMfQP009gLVX05GMPE6eHBVa;@6aJB65<?5A9?VE5=V94>698>693
>617>7AOC7UQEfmCAUi6?FA<?fUC@VICA`T>3l>fbX^BT00<MgYj7?ooo`006_ooo`jISXd04YF6QYid
G9EbIYIeHhf0PZUiGYQmLYUnLiUiKiUnM9UjL9=QF8USChA>@YMkJYf<PiV3NIUZI0:ER7<05IioL8aM
D91KCHMB?hMXE7M;?GiE?gm>@X=E>g];?Wm<>II]GXiTEH]MCX9DAhAFB8AOC8QPD0l31]Vk^;>a]P0<
VHj=6_ooo`ihLgD04W=[KGeIAW=LEgANDV]XKXYTD7QYHgQXHgQTGgQXHgQSGg9=BFUA@fE1>WY]HGif
LgQ/IWQDD`9cLF405GeXGVY9@W1:@VM5>FMGBU/o=fE9>FE4?VU;>611>VE3=WaQF75EBf]=A696?VQ:
@FQBAFaBB@H93MNg/iJGV`0<N7=e6_ooo`ikNg/04WA_L7iNB7AOEW9LBfIVJhUYEGe^J7]`JG]]IG]`
J7][I7MBCVmGB6]8?Gm`HH1gLW]aJG]FE09dL5h05Gi/GV]=@g5?@fI4=VIFB5i0=VQ:=fI7?Va?=f=5
>FI5=81SEgEHBfa?@f=9?VY=@FYEAW1GB`462<Z^ZI>HUP0<Ng]k6_ooo`igNWX04W1]KGYKAW1MDf]E
@eePIX9WEW]^J7M`JgM^IWM`J7M/I7ABCfiHBVY:?ge^H7ecKgM_IgMBD@9`JUT05GYYFVI<@Va>@f51
=65BAU`n=FI8=V=8?VYA>656>F=5<giREW=GBVM=@Ui8?FM=@FMEAfiGC0052<6WX8^BS@0<MgYj7?oo
o`006_ooo`jISXd029=eJIQlM8aQChaSDHeoNIY[IiV7MYV2N0>IOgD01iUXH9=REhIFAiAODj>CRYV2
N9UXI002Tg9U01FHNFV:GE2:GTb0BSn3FD]gACQoCcioE4F8FDF3Dd61EdF<HE:;FD^;GDj4F4Z0DTF4
Gd^9Ge<@1@IQ?cSilO000YVCTPZISXdJoooo3WQcM@08LUYAN6=MJTe2Je55Kfi^OeQGN79XN6aW0gQX
H`07N59?LU5:IDHmME5:PgmkN6aWN59C009bHEP05GQUG6Q8@V]>@f4m=fM?AU/j<VE6>VE9@6i>?fM7
?FM<@G9GCV];@V]>AFM;@V=7?fQBA6eABP8835a1>n?Gf@02N7Qj2WQcMA[oool>Ng]k00QgGU1mIee[
D4=ZDTAeLff7G5MkMFYkLfX3NfiV00MkGEAgG4iYCcmfE4V4P7YkLfYkGET00WM/H00EOFaRKDm8KeE7
I4DkK5E8GS`bITLiIT/oKe11K4]0LEE8NF1DK4i3K554Jdm4Id]0JUE3KEA900H7DCTbcLG7009kOWh:
Ng]k6_ooo`igNWX01WALBg]TF6I=@VA?@WAcJhQKE@9gLVX3MfiV00MgH5AdGdmWDD5bDdN0O7IgLVYg
H5/00WA`H`0ENfaUJe1:KEI9HdPnK5M:G3`bHdHiHdXoK512K4a2MEU<NVAHIdi2Idm3JE14ID]0IeE2
JE=700H7BS@]^;:e009gO7`:MgYj7?ooo`006_ooo`jISXd04YU[EIEfJh19>9j4MYEYHYQiJIUfLYV2
N9V3O9UiK9UoMIUfJ9UaGXMGB8mNC9j2NIj3OIUkK0:IOWP03YUeK91UF8MGBH]MCXELCH5=@7m>>G]9
@8QLCI9OE99WEHYQDXEND8UHB`:5F4X01HAKBHQTE2HJ5bPE5Ee5?`02oooo2YV>SA[oool>N7=e019h
DCmcH5]N>2ioLVYiFUUhIE]hIFAhK6MhK6]hHe]hJ6=hGeMhG51UASe`CT=oLfimK6YhI5X2N6QW00ih
H5]^D4UVASi[CDAXCTES@3YTACEP@3a^DDMgDdeeFdm[DTUVCTI/Bd<2J4]200EXCd=/ETd84QDP6QaD
@cl00^3Kg@YhLgDJoooo3W]kN`0BNeQ3M6EKFSLYP7IYPF1OOFaONfmXNg=ZNgAaNf]QNfiVNfILNfEF
Ide1LeE6P7U^OW1ZNfUK0W]`J`0ENfMPLEM;IdXnK4m3J595IDHkJ4/fHd<jKe96NUQ@Nf=DKeU<J5E9
KU97J514J4m4JU=4L5a@8R8J<AhJASTd00;2`l<:Ng]k6_ooo`igNWX04WMH@g1SFE8b97]dIh9RHW]/
GgMbJ7MbJWMeLgM/HWM^IWMUG7MVFFA?@fmFAg]iKGY]IgMWF@9gL6X03WMXH6eHBf99?6M=@VAAAF97
?6Q>=f54>FaAAGUJDWYVF6eJCFEFBV]EB09TD4@01FMDAFiNDS8/7chS73ha;002YZVY2WMjNQcoool0
01[oool=VHj=01>IOWFAI5:=DDB3ITnBPgF_M6VIMVVINW>IPWRIQ7fIP7NIOgFIMVfEMV>@IEN=J5NG
MFJHNFjEKF<00Yj=NP0EVFi/S6iCQUA9QE];PEI6REY2N4TkRU50S6EETV=HV6eORf=DQF5BREe>Q5e>
P5a9R5M;R71OMdLfDC8/>3e800:3M7<:VHj=6_ooo`ehLgD04gQRGFm;?V]0>V9B@WQhKhmPFgQUFgQT
I7Q/IgQ/JWQWHWQXHgQOFg=PDfi@BFmICWUVGGQUGg=HD`02OGEY01EhEeYZF4AU@SiXCDATBCm]CC]K
?cE^ACabFU1gEe1jGEAZDDUVDDQ/CDAWCTESCT5/BTA/HEEI>Rlg;2`_CE/00X9nP0YhLgDJoooo3G]k
N`0CNfAJKdHgISL`HDdnMWacSFQONfmONfYWNg=ZNg5/NfaTNfiVNfINM6EELEM=MFEFOg1TOFaRM5YB
009nMVP05G]HFF]G@FI3>fQ>@V99?Fe>>5Po<f]5>WEODG]NDWaSEFeFBVQEB6i?@f]AA6MB@71<@W1T
EEho<d/j=F5nR002XInP2W]kNa[oool=MgYj01=gGeAY?BiM;BQKACUaOGF5JUmgLUmgJVIgLVYgL6Ug
Jf5gKVIgIEi`He=]F4edJU]nM6QkK65`ETl00WYaH`0EMeADIU8mHT4hI4a1GDLkJD`eDc`aID<iM65B
NF1CNF=EJUI:IE=7Jde2JDm3IE4oKT]1KV9DGD4eEd<mQJB]00:h^KX:MgYj7?ooo`006_ooo`fISXd0
4iUnMI5TDXeAA8=VCi:3MJmdJIUfJIUjLiV2N9V4OIV0MiUoMIUfKIEfHi1UEheXEiMeIYQiKYE]H`02
WXej01FIKVb<KU>6E4V5Fd^1ETJ9FT9hBC^:DD2<IEFBHeRHKEn;HeB5HE:9GDj4GDj0G4V8Ed^8L5mg
AcIA<R`h?DP00X=dL`ZISXdJoooo3GQcM@0CN69MKd/nJd0jHU92N7Q_Sf1KN6EKN6ATN6aWN6aZN6MR
N6QSN5mKLf1CKU19KeU>NFIMN6EOLeQC009mMFT05GQGFVYHA6E2?VQ=A6A9?fe=>e/o=Fi5?79JD7MG
D7YME6YABFIAB6a=A6M>AF=>@Fa:A6aQEETj;cL/;2m=F`02PWj02WQcMA[oool=Ng]k01=kI5Y_ASMV
=c1QCCifO7>=J5mkKemkJVMkLfYkLFakK6AkKVIkIUidIEEaEdeeIEIoL6AmK69dFU800WifJ00ENeQI
JeM1IT<kJ4i2HTTmKDhhF3lcJdDjMEmANeiBO6=EKEI:J5E8KTm3Je54Ie90L4a2L6AEGSlcBcXeHGj8
00:QWj0:Ng]k6_ooo`egNWX04gMOE6Tm;Ud]:5]5>G5mMHEZGgMbGgMZIWMbJWM`JGM[HGM^IWMUGW1S
DfeHCGAZFgidJ7]/HG1FC`02NW5S01EgE5AVDSeR@CQTC45MAc]YC3EC?35U@cUdHE9iH5=iHeEZETYU
DdM[CD9YCd=UDCm^Bd5^HUAM@CEG@cf5Y:d00[Ri^PYgNWXLoooo000Joooo3IV>S@09VF1FQdhoO3Xb
Q6ECT85cVWabVGi^VGE[VH9h00:IOgD029UkLIUkK91aI9Q]GXmhJ9emLYUnKY=WGP:HMVP05IUUFhMN
Ch5>@H5B@ga>?hAC?W]??hEIBhaQDhiYFYQYFh]SE8ENChUIBhUGCHAKBXAGAHi_Hge7<hUMDJo2b`02
ThV82YV>SA[oool=N7=e00UhAd1U>c=M<2eXGTifM6]oJF=hJ5mhH5ahK6L00WQXH`08N6AON6AJKUaC
N5U@KVEKOVUSN6QOLU=@0WQUG00EN51<IDe2HT0jI4HmH48iJDPjGd<kKU17LUM>LEYANUUAJU59ITi6
K4]2K4Y5Ide2J4XoLF9KGcT]KE19U[K4009bKW0:N7=e6_ooo`ekNg/02G]:@VLk<Ulb;6YRD7ejKHM`
J7]`IW]WHG]cJP02NfiV00QkJF5kJE]aHUEmGU9cJUf0KVQkL6IgGUT2OFmT01EkEdmWDdAR@c]RB3aO
@cMVB3QQASafFTaiH5=eH5AlGe=]ETYXDTI^CT=^C4E[CTAZC41aIEeO>b]]DDNJ^lL00WMgN0YkNg/J
oooo3GMjNP09MdM0I3L_G34/If=AOWa]R71XMg1YMfQSMg9Z009gKVH027MWGgMWFFeRDg]NDW5ZGGe^
J7M`JGARGP9kLVL05GMHCVAD@ei3>ee7>eY2=V56=ei6?GQND7YTEW=REGUODfYFBVEBAV]>@V];AFU<
A6M;@6eUGE/i:VU?A9Rkb002M7Qh2WMjNQcoool001[oool<VHj=00RIPWZIJ667A3mi?C6=Ie^PQWFH
NG:IPWP2VGY`00ZIOgFENfbNOgFIKFN@Nf:IK5fENFRMPW^IOVnINgD2VGY`01FIIEb7G4MlEDMlCd1k
CT1fDDB7ETB<HUJDJEVCKUn?IUN@HU>5HE:9E4N9Ed^5ET^5FdV=JVMoAcMoFDZMVj<00[6`[PZISXdJ
oooo37QcM@0DN6IPN4i:ICHdFC@]LUmEQWQ/N6ETN6aWN6=ON6AON6QRLfAJOFQRN5QGKVACNEQ@LfEJ
OVe[N6QNN6AS0WQTG`0EN51<IDTlGDHnGd<kH4@kG4Q0KT`oLUI?MeU?M5eDL5E<L558IU58K4HnK4Y4
J4Y4J4m1LUiNHSX_I4m6PH^G00:>T90:N7=e6_ooo`akNg/057]YGg]DBFLn=UXk;G=TEX]oKge/J7]c
JW][I7]ZHW]/HgAVF7i/H7]JEg5UE7YKD7AXFX1aKG]]Gg]YI09kJV805G]ED6M;?5m8?F56>V=7>em=
@W5C@GELD7UMD7UREG=HC75CAfQEB6i9?Vi<@VQ=@VQC@7=RGfLo<VQEBG^7T@02R8f<2W]kNa[oool<
MgYj01AgIEYgDTAT@SIF?Be`IeJ;P75kK6QgLVYgK6AgJV9gJF5`HeAjJEagEUE]H55fF4i`IEQmL6]g
JeagIf42MfYR01EgDe1TB3]LAS]NASYQB3aMCd=_ET=dGE5fGE1gHEE_Ed]/DDEUDdM[B3e[Bd5TCD5T
E3m`HeiV@C=XEdabP8/00Wj4P`YgNWXLoooo000Joooo39V>S@0DTF5;SUe>M4HdSe0mYWi[X8=aVGYc
VGidVGmeVG]/VGI/T7IWVG1UUVeRVVmUU7AQU6iPWGaaVGY`VGY_0YUjL00EUFQOS4m5O513O4m0Oe53
OeU:PUm<TV=HSVUFU6UJT6YLSei@QEe?REU<QE=6QE95Q5Y<SG1SPCXWSW]/P5E<00:[cMX:VHj=6_oo
o`ahLgD04Vm7=fa8@5Dh;W14=hebIHEcIgQTI7QXHgQXHWQTFWQPFViPEgULEgAHDWUMEgAQE7AMEGiY
H`AhI5l05G=CCfY0>Ee3?5m3>fE7?FA>A6UBAGMED75IC7EICg1ID71>AVI>AVa;@fQ8@6Q7?fQ>AG9Q
Ff@_8g5]HV=8A002TKK32WQcMA[oool<Ng]k01A_B3AS@CI5<2EQ?c6;MFN9Nf]kJVMkKFEkK6=kJE]k
IEYaIEMjGEMbFU5hHEMgJ5UgIUZ0L6EkJV9kJV@2NfYR01EdG59[B3aOB3eQASYVBCeXD4A^EDIjFE9e
GDifG51aGU9cEDUXDdM^DDIXCT=XBd1ZD4IcI5eR;QiaKEmWASh00Y>a^@YkNg/Joooo37MjNP0DJD<^
F3P]=bPODcT]QWEWQga]MfYVMf]SMfUQMfMIMf=GKF=EMUYEJeI=LUmELfQJLfULOG1UMfYRMfYT0WMZ
HP0EL5iBITXlG4PmGTHjHdTmJ514KEE7NEUCLee?LU]>K5eAKeI:IEA8Je97I554I4]0Idi7L69MGBXL
KFUKID8i00:@Yj/:MgYj7?ooo`006_ooo`bISXd028=0:DXR56`j;eL/9M>MP::5N9UjKiUjJ`:INW00
2YUeIY=dII9ZHHUNDXmREi5bGIn2L9UnKIinMiUjL0:INV/05I1YH8MIAgi<Ah1E?7]=@HeLCHQSDhiL
D91XF9EUFX]TDI1ZFHMMCXYPD8EMCXACAXAFChUVEWTm:HeOC8Y=A@02ZlG92YV>SA[oool<N7=e01AP
:a`b7aMD=2i7:bO0TGV4LfahI5mhI5]hI5ihI5mhH5QbH5QbEeAYCDM`DDa`Ge1oK65iJEimJ6MhI5l2
N6AK01E^E4mVAS]N?ciTBCMP@cacDDM/ETabCTQaF4ifEDm[E4MaF4eWCDA]DDMXCTEXASmXBTQ]FDeK
<2AcEdY]?c`00Y6ja0YhLgDJoooo37]kN`0DHB`J9aT@ARlW?2HR/haeQWQ_NfYTNfYLNfYONfYRNfMN
MfUPNF=MKeI=Le=<KEe<OVaNNVaNOVeYNfYR0W]ZG00ELEM@IdPkGClnI4XfH4@jLU96L5]=M597L5Y<
MeM?K5A5L5Q;ITm3K5=6J554JTXoJTe8KEY;FSDRL5Q6K3hi00:C_LH:Ng]k6_ooo`agNWX055dY61dD
3SXY8cDS8:J6LH=gL7MZI7MZFgMZGGMZHWMXHGAZHgQWHViHD6mABfMGAgQVFGIYG7Y[J7MZHP9gJU/0
5FeECV95>EPm?F18=Ee3>6mAAFiKCG5AAVYHBW9ECVM@@fYDB65=@VIAA6A?@fM9?VM=B6UHB5De8VYF
A6Hk=`02T;c72WMjNQcoool001[oool:VHj=0YV6P@0DPD8d>AhE>QlHBBDRbYMlXXEhUGI/WWidVGYV
SFUMW7U[SVAEVg9PUfQNUeYCUF]DU6]IVh1^XhMoVGY`0YUjJ`0ET65GPEA4N4TmOd`kMe55R5A5QF5A
Rea<U6=CU6ULQeE8SV=DQ5e?P5Q:Q5a=Q5=6Q5I?Q5m=Hc4PO3LRW5e600:`b]X:VHj=6_ooo`YhLgD2
N6]X01AO:b8K6AH]8Ahj9BG4U7Z4LfYcH5YmJ6=hI5MZE4ijHUY/D4MjG51eDdifBTMfFdYgFdmkJen3
LVmhI5l2N6AK01E^C4UP@cUJ?CMU@cELAd1^BT1YE4U]CD=fEDYgFE9WAcmaEDaWCTISBd9XCTEXASmX
BTQXDTE8:AmS<RF1DD400YNod@YhLgDJoooo2W]kN`9kKfX056<c9bTQ6RlR6cDS8L>DNHIhJgAUFWi]
IG]ZFfQEBg=NDV59?F]AA6Q;AFa5@W=JAgEJC7QYFhAeKg]ZHP9kJUl05G5BCF=8>Ua1=FI5<ee9?fi<
?fEDAfI=@G9FBGEMDVI<@75IC6]CAfM@A6YBAFY:?fY=B6YEAD@W75T[7WY<>P02Ul3>2W]kNa[oool:
MgYj0WM]IP0DHC@X;bHO<B<L<R8P`IAiPgMZL6=GNV]SMfYLHE17J5M:E3leFd@iFD4kH3hlK5E4L5E8
LF=FP79]MfYR0WMZH00EKE5=GdLjFD4dHdDaFdToJT`oGU54GDXoJeA7L5eAHDe0KEU<JEA8IE14Ie55
IdTnIde8IeE5?R@JCRDKL4He00:C_/X:MgYj7?ooo`006_ooo`ZISXd2UFeM01B<FeHV104f5a4o7a[V
YhZHO6^IMVJHOG:INV^4H5AdDDA`BCYJ>cAH<BYn>bNPGd^4?2Z<BSC4/I^NPgd2VGY`01F@IER1D4Ah
C3QkDS]gAC^=HE5mFTagEdZ1EdV4GU=mG4ZGJ5N9HE:1FD]lEdV5EdV>Fdn4FdeG:AmV:1b=B3D00ZoD
g0ZISXdJoooo2WQcM@9cDdL056Y4@aL;2R/K63HR8>:SQgYYGgQPEgQYHgQTFf9<AUI3>e<k<d@c<DD]
:FPe9hIDAFLd:G11<ZNIRGe/JP9hI5l05Fi@BF10>EY0<V17>5`m>7AEBf=?Aei;A6Q;@fQ@BV1=@GaI
CVaBBF=;@V1:@FU:@G9?B6Q?AC/Q7E8W87Y5=P02Ul[H2WQcMA[oool:Ng]k0WAEA00DJdI13PH47QDA
;AhJfj>5O6mQNfEIOFiTNfYLJEE:ETHkC3X_>Bl/=2HRDbdNM4`kFRdQH3DWVhakOW1Z0W]ZHP0ELEM;
HdDjG4<bH4`gFSlfMEU;JeM;JE=8L554JU19GD`oNUa>KUI9IDi3Gda0IDa0LE=8JU=5?B@LE2PMO4@d
00:IbML:Ng]k6_ooo`YgNWX2L50o01AV@S`81@<F4@lX71WFXH=iKV1gHeMkKV=gJU]XETaCA3Y4=R`_
:bTX81i29QUTA3A=9QaA:b2=OVijKFL2MfYR01E]F4]OASYI@c9MCCQE?SEbF4]]FTe^EdYbDTEWCDMG
BCaeFTe[EDURCT9JBcmNBcm/E4QWE4Dl91aD:Aik@c<00YK5e0YgNWXLoooo000Joooo2IV>S@0GWI:A
SUQ4SUQ4PU1570h@7``9>QHCh[BEV7QYU71RWWe]VGYZTg5WKDPkKE9::QdJ;A<ABalDJD@jRC/ZOTTn
UWQYWH1j00:IOGH05I1TD85=@G14=7aA=e4C2JajH8YK?h5GBGQ6=9iVEWaJC95RCHYPDhEMCW=?@GYJ
BhaJCgaFA5LX87Lh:9=;@@02[/K;00>CRHRISXfISXd01iV>SA[oool9N7=e01MlMgU/?c1/?c1Q?c/4
314K51<d71[T]9EhIEadG5AmJEmhI5]bG5Q<>35EB4DE6Q/S5aM18QYK@C]c=BUZAd24MfYnKF`00WQX
I`0EKTm2H3`gDST_HDLd?1DAUFiIKTdiHdU1GC/`P5Q=H4e4N5E6KE5:J4i5Ed<kHDe4Ldi8H4Tm?28O
HS@YOdQ100:G`/`00g9^L7QcMGQcM@07N7=e6_ooo`UkNg/05h60P7=7=G=7=F=1>@L>3aTB3c4J5NBc
U7e]H7MSF7i^HG]ZGWMUGeE1=fYFD1dO71lD4CXN54lm=f/f:7IFBHn6MH1fL@02Ng=`01EaFTUS@SQA
>RiMAC4c40Z7HdmXBS=JA3Y>=BQcDdIOCd9hF4E/DdQXDDAHACYRCd=dD4QOBC/g81aN=BN1CD@00Yc;
e003MgMhNg]kNg]k00MkNg/Joooo2GMjNP0GOh61LTPeLTPeH3lg2@l@71<@<ATEi;>CNfmRLfAHNViQ
MfYMM6IQETDjMUmH8R<O7Q<@=Q`CASXfHcHYO5m@UI1mOGMc009gMW<05FeLC5m2>D`h;EQ1;b/=2GYH
Af15;U0m=44^8fI=@EY>@GAF@fIAAVA?@eI4>Em>@W9>B5Y7>S4N6UTe:81@A`02W<oI00=dN7QgNWYg
NWX01gMjNQcoool001[oool019V?SiVCTYV:RYVCTPFISXd05c`@2of^S?f^S8]SEC0H5Qd?5Bd@2o>l
W9UiJIUjJYAeIYYjJYinMhAOD8iLDd`j=B/R92`J5dPf;WA=@XeJD9MmK9f;P`02VHAm01F@Je^1DDA^
@S9/ACM=81U]C4IM>2/M0`B3?be/BcaE:ajGGd^6D3FMHD]hFTijEDN<ET]WAcU57aQX<BFfKed00Znn
bP03UHZ9VHj=VHj=00NISXdJoooo00AhLgEhN7YhKg5hN7X5N7=e01LY4Q3KS77KS75YDDTE51LE51XX
5aCd_9aiI5]hI5]dH5MiI5YmJ6MRBd9aCTXZ;2`M8RLT81dn=c9YBT1iE4ejKf9nMW@00WQ/JP0EKU=8
H3liD3L]E3dd=1`KGde:Ac8Y60`>KcX]FTDk@bPPOe95Jd@bPE=4Fde6HDY2LdY4Bc`c<1`JF2lWXfQI
00:F]/D00g5]L7QcMGQcM@07N7=e6_ooo`04NgQhNginNgEeNgin1G]kN`0G6`X7]g9I]g9IJeA96ALF
4a<H8a@?kKZINVULNfYNMfIJN6MKOVeYJEM9MEI<>cPaAC/fB3<VEd<dNeM4PUiBOg=TP7Ye009kLF`0
5G5GB6=3>EDk;5M0=3`R765CCCX_9`d71eXa9Di1=C<Q66U8>e/m:WQ>?5]>A69>@WA=@dPm<2TK5Th/
8ieZF@02V[k900=eMWIkNg]kNg/01g]kNa[oool017MeMGMlO7McLgMlO0EgNWX05a0619IG@iIG@fIC
B1XI61@D6B8D3nRhV7IWFgMZGG=VFG9UFGY[J6QKC7=HCD8n=69>@f=3;fU;>8QOB8ITEWebHgehM002
Mg1Y01E]EDEO@SQE>baG@3A09amQEe8`:bL91@I9:R55?38W71EG?CA==RI]AcIHC49OCd=bCD93>blS
6AE6:R6FJEP00YS1b`03LGEeMgYjMgYj00MgNWXLoooo000Joooo00BIRHRITY6IRHRISH`4VHj=01Q0
6aHi6AA=1P1=1P2CDC``51XV4Phd5A;U]iNDMFJMOG:8F4^FNfBYT8NCNF^=HEAmDDEiDD5dD45`ASR4
H4Z@I5VCLV:MRX82VGme01F@HUF1G4]h@c5bCS]_>C1WDTi4<c090@E@81AC=2hf7QQhA35fBCR8FTAf
CD5fFT^<FdQ08Am18QMB8QRdFD<00[ONi`03VXn>VHj=VHj=00NISXdJoooo00=hKg5hN7YhKW001GQc
M@0H:aPF9QHEAa0<Aa0<NTPi8QHL7QLE;QXHj[RIM61GOVUSIDDnMVEERWYgLVAKKDm9GT<mGDDjF4@k
FClgKUQ8MUIBM6=HOWId0WQXH`0EKTa5H4Y0FSL/EdDhEc<^DTi<;bd/10T=C2DLAC<`:QlLKD8dHd<f
MUA3Fd@nG4e4Ldm1:QhO<B4JAB@NZ5E200:Lc=X00gMbM7QcMGQcM@07N7=e6_ooo`04NgMgNh20NgMh
Ngal17]kN`0H7A0=60h<>@X5>@X5FcT/5A0D5Q<?:aPCk;VHMfIJP6iXID<lLEm?RGYeMfeRMEeEJE18
ID/nHTe1Id/oNF5=OEmFNFULP7ag0W]^IP0ELE58He13G3d^FT/hH3/_HUQ@ASL_10L9Ab<G?Rl[9A`H
JT4`IdDfO5]7H4PnGdm3M5=18a/J:1dE@28IXDlk00:IaM400gQiNG]kNg]kN`07Ng]k6_ooo`04MgIf
MgmoMgQhMgem17MjNP0H4PT83`T7<@T4<@T4@b`S3@`A4a4>:aPCkKVHLfIIOFiXGchiJEI8PWE`M6iU
MF=MK5I@Ide0IE95Ke96OVIBOV9IMf]MOG]f0WM^IP0EKDm8Ge14FCl_F4hiHd0aK5iCE3db1`P:AR8G
>B`Y8a/HJ40_J4DfOUm:GdToGDi2LUA17ATH8aXC?24HVdXg00:B^lP00gAgMgMjNWMjNP07MgYj7?oo
o`006_ooo`03VHN7VHf<VHj=00FISXd061P103XN5S4>3C4>3C`M61T523DG4SHD4N:aTYQiJIAiKHeM
FgY?@HIGAj1kIi1/FX9CBGTo<HA==Xi@>i1A>kB=MimlK9f1NP:IOg005I1RFH5SE7Q7>7]@=gYF?XeM
Cg]AAalO92TL7C/U8Cd/9VM7>g=;=gUHC8UHAGYFBgYFABdE43@E4U0R5idh9`02^n;Z2YV>SA[oool0
0gQ_LGQcMGQcM@05N7=e01P300<a8Q`Y51DY51De8alE3Q4_71T`6QWT/I5hI5]dI5i/BTaLA3]XBCmo
I5M_ET]S@SeL=BeY@c=bA3IcASJENFYoJUmnKF`2N6QN01E^C4QPDDQJ>C5PACAQBSYcDdYOA3l56R<X
92@`9bD_:bQQAceQASIQCdM]BcmOBdIQBSlH4a@Z6QQ69AfB>2X00Z?JiPYhLgDJoooo00=kNGUkO7ak
Ng/01G]kN`0H0@00<24H:1@A:1@A;b4L3PX;;1XD;aPDi:n?OFULMfUOLUQEHe53H4@hKUM9GT/nCcPb
B2`SECTYGcX]Hcd]R79SOVmQP7=^0W]/GP0ELE58HeI9G3daHdHcHTdiLUQ9Hd]2:C4`EChcAc8YA3<Y
N592L50iI5=8KE0oIE97HTe0518?9ALC@R8ISSHV00:Qen8:Ng]k6_ooo`03Mg]kMgemMgYj00EgNWX0
6000030R62XE4RXE4RdQ70`92R`I534H5>B]SW]WFg=WG79OFVAHBEHm<ee8>ddm<Sd]:3LT7D<_8dha
9U<d9gYYFgQ^H7ebKP9gJEX05Fe?AEmFB5Tm<V54<em=>FmIBF==@d11>gMB@5Pk;U<h:hUJAgUF?6=D
B6U@@6IDB5m=@14A3b<F4T0Q68Xd9@02Vm;M2WMjNQcoool001[oool8VHj=01PJ0P0Y30PX4PhX4Ph^
4PhT3P`U40e5927?TgNYPW2CNFVHNG:8IeY[A3QY?3EMAcmfBSm<<BUH?39O=RahBcn;LF:EMF^HNFh2
VFeS01F@LU^1GU1hA3mU<Aig@2ZKMU6>H564G4]nE4YUA3IQ?CJ4Dd9kDT:4ET]jFTF>H4]WAc/L2`TX
4@f=CSiQ81L00/CNiPZISXdJoooo27QcM@0H0`038a@A8aPF8aPF:1PF7aDD8aPF?BLUcI9gRVeRLVEK
N6ETIU=<CCTcDCDcA3djH44k>BdYB3XcCC<]IDLoN6iSNFIQN6EP0WQHD`0EKUa=H4e6FSHgBb/OGSX[
PVM;LU99J4i4HTM2Bc/bBcTfL4e0H4LmJ4Y6HDhoLU94Bc/e4@l@8aLER4m0E28M00:`g>L:N7=e6_oo
o`QkNg/0608001h@2a/D41/D424E4A/B3ahE4CPW8lZCMhU`HWM/Gge/J6iNEF1?@em2?4I1?FY9@Dhi
;U]7>UTl<GACAhMmKH5`JGe/I@9kFUD05G5OCf=CB5`i>4DX6e4b8gQQAG5DAfYB@VU=@eU7>5M6?GMG
A61<?fY=B69@@75D@dPl<PX;2Q/D495F@edW7002[McW2W]kNa[oool8MgYj01P2000M3`/I4a0I4a0O
510L4PlN5A4g:2?7U7N2KF1dK5mkK6Q_HUYYG4mUBDA4@Cm_CDEK@CAWCd1Q@SEmFdf?QgJ2M6ikK6L2
MeIC01E]GDmOE4QI>3Pm91U6;21^FD1/DdAWDD5ZCTAPCCaNCT=iG4QMCD1WCDYOCT1/Dd93>C082PTI
4`nGFdIS:al00ZSKiPYgNWXLoooo000Joooo0YV>S@03VHZ:VI>BVHj=00>ISXd062060b@81BD@3BD@
3B<@31D10RdB3T@Y9K=kH[:8MIj2LIUjLiUnM9=dIX5ECV55AGM<BG95?717?FTo=Wm>@Ha[GIf1NiEa
I0:JK6L05IE[GXESEGiACEH]:4@L6EXb85hc8JiVBie^FhELAW]HB7YFB81C@gIAA8mMDh9JAD0S6R8>
32lN6YM9=6TX6P02Gdi900?jnobISXfISXd01iV>SA[oool2N7=e00=hKg5hN7YhLgD00gQcM@0H1P02
7A0?8APF8APF81LE5@/=:1TF?R`Y[7IOUWIXOFeRN6ATN6QSLUmGHDE5ASm3IDU7EclkF4E0DS/hJT]2
L5mFOVe/LeaC0WUHE`0ELeY@I559H4=4>bLU<A`MBS4TC2lTTeQ5PEmBJ4hoGd]1HDY1I4HmG4DnLe1:
JDho:QlK5a8C:R8PU4TgD2@M009>BTP00m[Ff7QcMGQcM@07N7=e6_ooo`9kNg/00g]eMG]nOW]kN`03
Ng]k01P70P0K3@XM5A4M5A4K510?1`LS5Q4k:bJVM5^BMFInLFAkJVMkL6QgJUm]FEEOGEUnIUe/GEA`
He][FeAnIEMgJej0M71dHUD2N5mG01EdHE9YEdaYD4Y<>S0g8B0o:ahi9A]lCC]kGDmXDSmSCd5RCD5T
AcaIACYaDDU^D40S71HA3PdX8QfBB3=<8QP00Shn>`03_[joNg]kNg]k00MkNg/Joooo0WMjNP03Mg=c
MgalMgYj00=gNWX060L30A`=2QhE4AhE4A/D40h71b8E43/Z9Z9aFHUaHWY`HWMZIWM`J7A]Hg1TH6ia
JXejKWIaIgehKgYaJXUgIgQ`HWeeL71RD`9bH5D05G1SDVMGCFaFCUI7>CXU93HW7B/N5fM1=79HC6AA
?V=@@Em=@F15>eA3>6a?Afe>@1dH50h=32XS7Y57<dHP5P02<SDc00>SY:AgNWYgNWX01gMjNQcoool0
01[oool2VHj=00>IRHRISHbISXd00iV>S@0?8@T7;Q@A9Ph;9Ph;9a0<6PT6:Q0=A2TUYV]CZXEcWH5`
VGYcVH9hVGmeVH=l00:IOG<01iUiK9V3O9UiK9UjK9=aGYQmLY=fJ002SfeN01FDK5f?L66=JUb2FU5@
=3<l8b4Z7QY>9A]M<R::BSQcDSj3BSEjAcFBHeN0EDN0DT@T3P`W40``61U94@Y/7A000TDe<@03h=gM
VHj=VHj=00NISXdJoooo0WQcM@03N6i`N7=eN7=e00=hLgD03`X312DH5b4E524E528G5ALA42PH5Sd/
:IiWDY=gJWi]HgQTI7Q/IgQXHgQ/J`02N6MR00MhHe]hK6]hHe]hHeYbG51hJF=bGeL00ViID00EM5Q@
KUeDKeUAHdY7<bX_:b@T720O@bLPCC0ULD4dFdHjJ3lbHShbN5M@JT]2I4Hm4a0A81HD:adO@QPCFQlG
008d=3<00mkLgWQcMGQcM@07N7=e6_ooo`9kNg/00g]gN7]lO7]kN`03Ng]k00l710<Q5a@M4`lM4`lO
510D3P/T5A4j:bJMIe2DNVV0LfEkJVMkLfYkKVIkM7400W]aK007Nf]QNgAaNf]QNf]QMfEFOFiTMfII
009cGU805GMKD7=REWEQEFeCCTPo?D`k=34/9T0V73/W75Te:TPm<ULh:UDh:WIGCg5?@fA8>`h=3AXB
3bLJ6SPB34XI4002;c8_00?Og]mkNg]kNg/01g]kNa[oool2MgYj00=gN7QgOGegNWX00gMjNP0?1@@3
81PE7Q@@7Q@@7a@@5@l;9AHA>RXVW6I?TGQXOG9UMfYVMg9ZMfiVMgEc009gLfl01gM/HWMeLgM/HWM/
HWAVFG]^HgAUE`02LEiB01EcF4iaHUEdHeI_Ee9DBdQSBd90=Bhn9Q`^8AQ6:b<i=2a8<BI:<BIaE4ed
DDAPAcX;30`I4@hV6QXb40/m5Pl00R/`;P03g]kOMgYjMgYj00MgNWXLoooo000Joooo29V>S@0H80/:
>b<P70`970`9:Q0<9@l<;1@E@RLRTee6[h9^ZH]iVGY_VGihVH=iVHAmVHZ7VHAnVGmeVH=lVG]^VGme
VGY/VGERVGYZ0Y1YF`0EU6]MU6YLU7ETU6MQQFIIOeE=GChh?R`Y=bDQCBXSE3T^KTLjGT@iPdY7PEe9
N4/l8P`;9Pl<914>8PX7@aHB009B=C000n7NgYV>SIV>S@07VHj=6_ooo`QhLgD060H31C0T8aLB4QLB
4RHG5B4F52PK73/[9hYIAIMdIHYfJWQTGgQXIgQ/IWQ/JWQaLWQ/JWQWHWQ/JgQRFWQXHgQSFWQPE7QT
F`9^E4d05GAIDGAID7AQEgADE6AECF57@d0d<b/Y:BTW9D4[9d<f;em2>4a0>G54AFA@@E]0=a4>4B4F
524H5QlB43dL6P02ACLd00?Ng=ehLgEhLgD01gQcMA[oool8Ng]k01P71@@c9R8D4@dD4@dQ510M4`lV
6ATi:RB4F4:@Lf:9NFYkJV5kKFQkLFUkLFakMWAkLfikKfUkM75kJEikKVIkJf5kIeUkJUh2LEY?01Eg
GeAgGU9gIEQgFEIYFdmWD4I>@CU4>cA3>2m@=2Y;>Ri/AcYKBd1gBDQRDD1F@SH=30`M4`lL514H3`/d
6QD00Slf<@03gMcMNg]kNg]k00MkNg/Joooo27MjNP0H1`H5=RLS5A4>5A4>8A@@7Q@@9aTJ>BXTP5I1
QfiNPWIXMfYOMf]UMfmWMg1YMgAaMg9^Mg1ZMgEcMfUNMfiVMfaRMfQJMfYM0VeJC`0ELf1DLeeALfAG
LeUEIea>IU=7EDPmEDPlETHiFS/^D3`^M4/lI5=6NTa;G4loCT0e2``<7A<?6a@@5`l:;aXE008k=C40
0m_Kg7MjNWMjNP07MgYj7?ooo`006_ooo`RISXd04BD;23hQ6BXG5BXG5BD>2bd;1c8F540S6FY3=KEm
IJR=NYinKYUjLiV2N9V3O9UoMIV:Q`02VHAn00FINfjIOgFINfbINg6IMV800Y1YF`0EU7ETU6]MU6YL
U6]PRfIHRF9COei?MUA7LU=7GSlfHD0gMDPlNEE;OTm5MU53ECDV:14@9Pl<<1@A7Ph;;10=009:9a`0
0l>//;^o_9V>S@07VHj=6_ooo`QhLgD04@/41S<S7R4J6R4J6R4E52PC4B`L6cTV7em1=Z9aGX]jKGeX
GWQTI7Q/IgQ/JgQXHgQaLP02N6aZ00EhHUYhJ6=hI5YhI5mhH5<00ViDC00EM65GM5UAM5U@M5QCJUE;
JU58HDi6FTM0FDQ1AcPcCC`gHD8kGd]6I4@oFdLm?BdU6Q<E8AHD:AXI6QDD:APF0091:R800kVRYiZO
WgQcM@07N7=e6_ooo`QkNg/04@/50blP61hH5QhH5QhC3b@@2bTJ5SHT6UTn<IU]FXYkK7i]H7]ZIg]c
JW]dLG]^IW]fM002Ng=^00EkJEikKVIkJE]kJF5kIEH00W5GC00EMfEHMemDMeiBMeaCKEQ;KU=7Ie96
H4e2IE55FTDkHD]0KTa1Idm8JTU0H4Xl>R/P5A0?7A<?:1PD5a<?91DA008l9a`00jfFVI:IV7]kN`07
Ng]k6_ooo`QgNWX04@T50bdO5ahH5AhH5B0C3bD?2bXI5CHT6E@k;hmWEXEhJ7Y[GgMZIWMbJWMeLgM^
IWMdL@02Mg9^00EgJEigKVIgIeUgIemgHeH00VeEBP0ELfAGLf1DLeeALe]AJUM9KE55IU96HDi3JeE9
I4i2K5E8ME96JE5:JdY0Gd/k=BLN4Pl>7A<?:APD6A<?91DA008i9A/00j:;SXN=S7MjNP07MgYj7?oo
o`006_ooo`RISXd03b48148X92dF4bdF4blC41d:1RlA3RlC3U/_8Y5H?<:LRYf2LIUjLiV2N9V8Q@02
VGme00NIRXNIP7NIP7NIOgFIMVBINVnEKV000YE/GP0EU6YLU71PU6]MU6YLRf=DRei?Rf5BQ65CQ5Q:
REe>P5a=O5=6QEI;QEI9LdLh=adH80/7<AHG80/<80`75P4300916aD00iE^Il_?dYV>S@07VHj=6_oo
o`QhLgD04PX313LY:2DJ6BDJ6BLH5a/B42XH5RXI5U4`9X9B>jR;OGi]HWQTI7Q/IgQaLgQWHWQXHgQa
LP9hIf8017QXHgQODgQTGg=HC`9cF5005GAID7AMDgAHD7AID6YABF]>AV]BBFMBBVQ;@Va>AF=>AF16
?fU:A6U:@ELl<bHK6QTA42/K7AdC51dD4AH<3P02>b0L00>;JVFe_L1hLgD01gQcMA[oool8Ng]k00H7
0`4c:BDR6AHR6AHU5Q<F3`/28aDA00Y9;25gC3>OQWJ0LFAkJVMkLfYkN7MkKfUkKVIkMW@2NfaT00Ak
KVIkIUIkJV5dGE02M5iB01EgGU9gGe=gG55gGU9]ETY/DTI/ETU[FDaZD4A^DDAWDTEOBSmUCD=UCD1A
?C4L61HA3@XV6ATG410F40/?1`L00S@L5P03PVAN[kVkNg]k00MkNg/Joooo27MjNP0B1@<1<RTV8QXG
8QXG9QHC5Pl;8QDA8A@@A2TOKTH_UGi^OG1RMfYVMg9ZMgMfMg1ZMfiVMgAa0WM[H@04MfiVMfEFMfYO
L5]>0W1NDP0ELeeALeaALe]?LeeAJUI:Ie96IeE9JEY=Ie14Jdm3IE55FTTnGTe2GTdoB3/`5QHE3P`9
91PI5`l@5@l;3`L7008a6aH00g]OFZNb/WMjNP07MgYj7?ooo`006_ooo`RISXd03b48148X92dF4bdF
4blC41d:1RlA3RlC3U/_8Y5H?<:LRYf2LIUjLiV2N9V8Q@02VGme00NIRXNIP7NIP7NIOgFIMVBINVnE
KV000YE/GP0EU6YLU71PU6]MU6YLRf=DRei?Rf5BQ65CQ5Q:REe>P5a=O5=6QEI;QEI9LdLh=adH80/7
<AHG80/<80`75P4300916aD00iE^Il_?dYV>S@07VHj=6_ooo`QhLgD04PX313LY:2DJ6BDJ6BLH5a/B
42XH5RXI5U4`9X9B>jR;OGi]HWQTI7Q/IgQaLgQWHWQXHgQaLP9hIf8017QXHgQODgQTGg=HC`9cF500
5GAID7AMDgAHD7AID6YABF]>AV]BBFMBBVQ;@Va>AF=>AF16?fU:A6U:@ELl<bHK6QTA42/K7AdC51dD
4AH<3P02>b0L00>;JVFe_L1hLgD01gQcMA[oool8Ng]k00H70`4c:BDR6AHR6AHU5Q<F3`/28aDA00Y9
;25gC3>OQWJ0LFAkJVMkLfYkN7MkKfUkKVIkMW@2NfaT00AkKVIkIUIkJV5dGE02M5iB01EgGU9gGe=g
G55gGU9]ETY/DTI/ETU[FDaZD4A^DDAWDTEOBSmUCD=UCD1A?C4L61HA3@XV6ATG410F40/?1`L00S@L
5P03PVAN[kVkNg]k00MkNg/Joooo27MjNP0B1@<1<RTV8QXG8QXG9QHC5Pl;8QDA8A@@A2TOKTH_UGi^
OG1RMfYVMg9ZMgMfMg1ZMfiVMgAa0WM[H@04MfiVMfEFMfYOL5]>0W1NDP0ELeeALeaALe]?LeeAJUI:
Ie96IeE9JEY=Ie14Jdm3IE55FTTnGTe2GTdoB3/`5QHE3P`991PI5`l@5@l;3`L7008a6aH00g]OFZNb
/WMjNP07MgYj7?ooo`006_ooo`RISXd04b0813/U8cTQ7STQ7RlF4b/A3bD?338I5TT[9FHk:/F8KjV;
N9UnMiUnM9V9PIV:QiUoMIV3O9UkKP02VGme00>IMVREMV:EKUl00iA[G@0DU6YLT6YLUFIGT6IGQEi?
RF5BRFAEQ5i?Q5Q:QEa=Le=6PUI8LU93DC<Y:a<@:aLD60D780`>50427P/<0RdA3@03OeYCdLo?VHj=
00NISXdJoooo27QcM@0C1P43<BLW;R8Q;R8Q9aXI91LF8AHD;1hL@RdZFCT]/giZRWEYN6QWN6QSN75^
N75bN6MRN6a[N69J009hJ6<00gQOEg=PDg=HD003M5Q@01AdFE1`FE1eEDa`EDaVCTI/DTU/ED]WCTIX
Bd9XCTEGASmYBT5HASdj:bLM5AHS71XG3a4M51HD30dL4aD2:aTF00=fFEC3aLQhLgD01gQcMA[oool8
Ng]k01<70`4_9R</8Qh/8QhU6QHR5Q8O510Y7AU0;RQB>2^ZNfN9MVMkKFUkKFEkM6ikMWAkKfUkM75k
JEh00W]^IP03NfILM6EFM5eA00=gG54057MNDW5NDWAHC75HC6QBAViFBFiHBf]BAVY@A6QBAEQ:?fi=
@Ea8?3DY8aPB428J5Q8;2aL@40l71aL@408V5Q400g1GD<36b7]kN`07Ng]k6_ooo`QgNWX04`L40BlV
8b`R7R`R7RHJ5b@G4b0D42XM6D0_:Ddh;:1fI89aHgM[J7M[HgMaJgMdLGM`JWMeLgMYGP02MfiV00=g
IEa`HeI`Fe000g=KC`0DLeeAK5eAKUM;K5M;IE96JeE9JeM:JE96Ie14I555ETTnKDe1FdLk<BLQ5A0?
8aXF4`/;5Pl?3`L7610@0RLF4@03K5E?^/?6MgYj00MgNWXLoooo000Joooo29V>S@0H8`/8@2LS?bLS
?bLS=QlL;a8?7@X7>APDCBXOHch_WF9:[I1oWX9fVGYdVGidVHV1VHZ7VHAnVGmeVGU/VGmeVGI]TgES
SfQJ0Y1WF@0EUFIGVFYPRfYGSf9CSfEJQF5?RF5BREe>QF1@QEe>P5=4P5Y<NThoIT8hAb@K;Q<A7``8
7P/=6@D77@X77@X=008e5A400jbPWHYkNYV>S@07VHj=6_ooo`QhLgD060X313@X9SDX9SDX9R`Q82LG
5QTB43<M6d@/95Lk<91KAi5nLWe]IWQTHgQXHgQaKWQaLWQ/JWQWHWQSFgQXHgQOFg9PDfiEC@9`E4d0
5GEEC7UHE6YHC71AB71ECfIAAVaBBFa>AFQAAfQ>AFA6?F==A652>D/i=3<Q7B8G5a`D4AXB5AP?4A/C
41`C5P02<1/I00>c[JanNgehLgD01gQcMA[oool8Ng]k01P91@<b:2Dd:2@d:2@[8AhU5Q8D3`/^6QI2
:QmJ?2bAFT:>O6inLFMkJVEkKFEkM6ikMWAkLfikKfUkJf5kKVIkIUigIeMcG502LEU?01EdF4ajFeA]
FdacDdMcEdmXEDI^ETU^DDAXDdIXDDATAc]WCT9R@cM3=Rl[7QLM514E40/E3a0C2`/F40/H41400RdI
5003b/G4U9FFNg]k00MkNg/Joooo27MjNP0H1`H4<BPU=2PT=2PT;B8O9QHB50l;;AXE@RTNG3/[T5Lo
QgIXNW1TMfYSMf]SMg5[MgAaMg9^Mg1ZMfaRMfiVMfENM6QHLEaA0VaICP0EKUM;MUUCJUU;Ke55KeE>
IE=6JeE9Jdm3I554I4m3H4DjIDa1Gd8f>c<]91/E71<A5@l;50h?50/;5a0;6A4A008^6A@00mcHej>W
Z7MjNP07MgYj7?ooo`006_ooo`JISXd019V:RYF;Rb4>3D0V8P94:bL02S/S7bL>2blH5C4G53lQ77U2
;Y5F@jJ2Kj>6M9UjL`:IOW@029V8QIV4OYV4OYUkKYUoMIEbI9ijJi1YF`:?Jed05HeVF8mREY1VEhmN
Ch]UFH]MChEHCXYQCXELCHALCH1@@g]EAg=4=Uhj;S8J4c0C4Ah>2b4?320>31d:1R<@3@02=aDB00?j
n_ZCRHRISXd01iV>SA[oool6N7=e00AhKg5cKg4:1`Te9bD2>B/Y00Xa928P51<W7A//7A`h9B5]@31o
Cd6=MVV3LVIhI6@2N6QS00QhLG=hK6YhK6YhHUYhJ6=cG5=mI5Y^E4`2KUQ@00Q_EDe`DTa`EDa`CTI[
ETm[CTIXBDE]DDD2J4i500]S@caPBT9G>C54<R`S6QPV61PJ5A@N5QDM5A@K4a0P5aH00S8K6@03oooo
LVi`N7=e00MhLgDJoooo1W]kN`04NgEeM7=c1`L6<BDQ0SHY9@0:;R<O6a4>9A`H:a`H<R<MJ3l]OU51
RgQYQ7IXNfYW0W]`J008NgQgNg=^Ng=^NfUNNfiVM65DOVMJLEM<0W=LD@0EME]?LeM=LEY<Le96K5]@
K5=6J4]4K5=4J595JU95IdPmH4i2Dc/`A3<Y8ATC8QDC5Q<?6a@@6Q<?5a0;71@A008_6AD00oooogMg
N7]kN`07Ng]k6_ooo`IgNWX017McLg1_K`D61BlT808e:BD02RdS7a/A3RHL62`M6C0S7V@n;G]A@HIf
J81dIWMZIP9gL6P027MgMWMbKWMbKWMYGWM^IW1ODGYUEVeEBP9aFdl05GALD6mHCFaIBfmBAVMKD6MD
AVA9@fIA@fAAAFMAAFE8?Ee?@ddj;d4b:1lI4b4E4aLC3a`D41/D41P@2a`D4@02;aTE00?ooomdN7Qg
NWX01gMjNQcoool001[oool6VHj=00BIRHRCPX8J1`I99Qd2>bHS00e2:BDb71T^5Q<g7a/l7aIYASZ0
A3:_NVJTSW^NOWNIOWBIPgVIQ7d00YV5O`05VGacUG]/UG=TVGUYUFAG00:@IU<05IEZGY1VDhmVFXmR
DhEQDXUQDXAEBh1KCHAGBHAKBgaGBG=>?fTn;d/W8S<F4B@@3Al;1al<3AX61`l10Qd72002D2LR00?R
j>RJShjISXd01iV>SA[oool6N7=e00AhKW1bJV`50`Dn9b42<BLV00dg:BLX7QhX71X_8R0d8QaOAC]]
?c:GKEj5NVemJ6MhJ6=hK6IhK6X00WQ/J@05N6=NLfAJLeaBNFAKLe19009`EDP05GEHDW1EB71ECg1B
BFIBBFaAB6M7@V=?AFQ:@FQ=A61:@EM2>E0d;3PT8bHI5QlF5A`C4AdD5QT@4A4<3A`A4P02BR/W00?V
kNegLWAhLgD01gQcMA[oool6Ng]k00AkMgQgMWH310<l9A`2;bDR00dd:2@X7a`V6aL/8A`b8AQLACYV
?Rn@JUV4NVYnKFUkKFEkLFUkLF`00W]`J@05NfMNM6IHM5iANVULM5I;009aF4L05GAKD75HAg=JCg=G
BfQFBFiEB6]<@fMCAFY<@6Y>@Um<@5=3=d`c:30Q7QhD4ATC41D?2aP@41<;2`X71aD<3002BBXT00?Y
knmhNGUkNg/01g]kNa[oool6MgYj00AgN7QdNGT210<l9A`2;bDQ00dd:2@[8AhX71P]8A`c8AQJASYN
?Bn7I5AnMFIjJfQgJf=gKfMgL6T00WM]I005MfAKL6=DL5]=MVMKL5E;009/EdD05FiICVaGAFmICVmH
C6EEBF]CAfU=@VEDAFM;?fM<@EY;?de2=THa9RXN71XC41LB3aD?2aL@41<;2`X71aD<3002BBXT00?/
l?5dMgMgNWX01gMjNQcoool001[oool8VHj=014M2@Pl7QA2:RQ2:RQ1:2Df7QXa514n8QPl921H?2mR
;R>YJE:]U82MOG:INW2IOWRIOg000YUoM@05VG]eTgESSfQJU71PT6AE00:@IU<01HmUFHmYDhmVEXmM
CXEUE@02REe>00j1G4f4DdJ0DT=_DD9Y@35;9b918ALW3``R40dW3``L2P`H1@LG1@L`5142UH2000>0
KVjISXfISXd01iV>SA[oool8N7=e01430@@c8AXg:b/g:b/g:BP/81hY6APf9Ahc9RA=>c9B;2BEH4jA
Q7EnJF=hI5ihJ6MhJ5h00WQXHP05N6ASLV1CKUE=M5aCL517009`E4P01G1ECg1IBG1EC71=A6IEB`02
K4i500iSCTEXASmTASeCACa@=bhh92<a8A`P5A@N5aDR5Q@J4aDG3a0F3a4]6aT2XiJF00=kNWahLgEh
LgD01gQcMA[oool8Ng]k014510<a81Hc:RLc:RLe:BDY7aXU5Q<d8aTa9B59>Rm;:1n<G4V>Q7>0KVAk
JUmkKFQkK5h00W]/H005NfUTMfMGLea@MemCLE55009aETL01G=GD7=LBg=JCW=?@fQGBP02KU5400]U
DTEZBSmTB3a@ACU<=BT`81hY7QHJ4PlI510O4`lF41000Q8;2`04;ATEbKbjbKbjVIbM2G]kNa[oool8
MgYj01451@@a81Hb:RLb:RLe:BDX7QXT5Q8d8QTa9B57>Rm59Qj2ETF7P71mKV=gJUegJfEgJEX00WMY
G005MfMQM6QHLEaALeaAK4e2009/DdD01FmED6mKC6mICfm=@VEEB002Jdm300]RDDEWBCiPAc];@cM6
<RLZ7A`T6aDI4@hH4a0P510G41000Q<;2`04<1XEimcHimcH[kNh2GMjNQcoool001[oool8VHj=01P[
518c6aLo9B4o9B59:bLg7ADc71Xd6AE29b<n91i@;BN=CCN_PFJZT82JNVZNOW>INV^INVZEMVJJNVjN
OVn@IEN@HeB@IU<2ReU>01F@I5R@I5FEIEF;FT^;Ge29F4j5H4f5G4V0CdAlDT=VASQB:1ll81LZ4@dO
2`LP30d[4@`L2P`D008J1PPj5a<00_Whn003VXn>VHj=VHj=00NISXdJoooo27QcM@0@3@H89adK=BLU
=BLU?B/Y;1lJ:alO;AhK>2TW=BHR@b`YOTThUWANRWU_NFAJOFQR0WQTF`06Lf1GNFANOFQNKU19L558
L5E80V];A@0ELEE>LEE;MUE;JdY2Je58K4U5J595J4i1I4<mH4HmBc`d?R@P;20L8aHE6a<A7A@F9aPE
6A8E50/=6A0A=QhJ00;mo?`00gMbM7QcMGQcM@07N7=e6_ooo`QkNg/0614<2bLN6S8V8S8V8S/Y9B/N
5RTO6bTL63@W8blS7C/Y9GA7=8e^EXIgJWQWFgi]Hg]ZG7]ZGWAUFGQWGGi]Gg5EBW5BAW5HA`9/CT@0
5G1HCG1HBWMGBVa=@VaDAfi;A6QDAFQB@6A5>em8?4Xn<SPR72HM5Q`C3aD?2aL@42<D41D?40h71a@<
338K5P02nOWi00=hNGUkNg]kNg/01g]kNa[oool8MgYj01PA3`dX81`a9R8a9R8j:BD[7QDY7a/X71Pb
9R<]8A`f9bA/AC>2Ie1mL6=bIEUjJf1gJU]gJUe`HeMbIEYjJea]DdU/CdA/EdD2Idi301EZEd]ZEdQb
EDQWC45WDdI[BD=TDdETDCmPA3YJAc]5?C4c81/R6aDJ4PhC3P/G410R510E3a0?1`LD30`b6aH00_Kg
m`03M7MgMgYjMgYj00MgNWXLoooo000Joooo29V>S@0H=AhI>24P?bLS?bLS?b@P?R<N;A@E=A/F>b8M
@BPU?1lFG2hQVVI=[7eWX7aYWh9`VWYYVWm^UGIVU75RVGUYTFUKS5M9T6A@0X]MCP0EREY;RFACSf1@
Ree>QEM9RUM;PEI6PEY7N4loLT8bJ40`>adF:a4=910=7@X76@D870L840433`42=1DA>QPA00;Wk_<:
VHj=6_ooo`QhLgD061L?3bTP8CDX9SDX9SDV93<T8BDI6bdO73<U8SLY:3<R750^9HMMBI5/GH1VFWm/
HGUTFGUXGW=PEgALDgUTFVmCC6]7?g5DA`9[CDD05Fa=A6aEBW9AAf]>AFQ:@Fe:A6A9?fA<?e]2>EPi
;dlg;BXM6R<F5AlF5A/B41P?4A/@4A4<3Q4<3C0L6SDN6@02jo;g2WQcMA[oool8Ng]k01PH4`lX81hd
:2@d:2@b920_8ahP5aLX71P_8ahe:BDa81Q8:QmhEd>6IUMlHUAnK5ihIEQhJUedIEUgHEEjIUU_EdaZ
BSm`EDH2K4m4015^CT9^EDQbDdI/DDAXC41/C49RBSeRBceF@SM@=b]8=2PT6Q@K4PlI4a0F3`/C2``E
30`00PX71`04;aXE=QhEkO;fkO;f2W]kNa[oool8MgYj01PF4`hX8Ahd:2@d:2@a920]8ahP5QLW6aL_
8Qde:BDa81M39ae/DCmiGU5cFTihIUUbH5AbIeY`HeMcGe=fHeIYEDYTBCiZDT@2Ide301E[C45[DTI^
DDAWCd=TBcmVBd5MBC]LB3]>@3I7=2U1<2DP61<H4@hG4PlF3`/C2``E30/:1`L;1`L`6aHj7aD00^oc
m@YgNWXLoooo000Joooo29V>S@0HAbhZ:A<?@2TU@2TU>b<OARdY<QPB;Q<A@b/W=alKABTT=ATDJdHe
MTLgYV19[hA_TVYIVg]^UWATUW5LVgATR5m@ND`mSUI40YAKA00ESeiARUY;RU92RV9AQELoP599O4ho
Md`lJT`lEb`TCb@H<QHB9`l<7@/76@H76@D750023P026@D7;Q8>U7A_00:9O7T:VHj=6_ooo`QhLgD0
62<I6ATC4S@Y9c@Y9c4T8S/]:bPK62LI63X]:blR83XY9RdM6Ui3=V=0=HYC@Y1aHW5GC7]WGgIOEWIL
CW]PEVM=A5/m=G59?@9gCCd03W9@BFe>A6e5>feCBFQ:>FA6@V12>Ea1>511>44X93hT7BHJ620F51XC
4@8H3a401A@<3A0<3AP?4B`J5YF0O@02QhV;2WQcMA[oool8Ng]k01Pb:b`O61@c:2@c:2@^8alj;RTX
6aDV5a@i;2P/81`f:2<X6aMC?c9C>BifBCV5JUY[E4MeHe]aGEAaFdahHUETCD9C>c1VACP2L4Xh01E_
D4I/D4=/A3Q/DdIXC3ITB3mO@cMJ@CE>@CDm9R0f7aLO5A<K4`lE40/B2`/C2`/?1`L:1`LD30`X5a6^
WIX00ZFZZ`YkNg/Joooo27MjNP0H>3<g91/I<RPT<RPT;B<O>bhZ:adE9aLC>BdX:b0L=BPT9Q/GBc``
AC8ZI3lbN65BHTi2JeaFJEM@JEI9LEiBGTTnBCH/FSlc0VI5<`0>J4e3ITi2IT4eITm3I4/dH4LmFT8f
EClcBSlc>2@O<1dE6a@A6a8?5Pl;0Q<;2`053`L72`L75@`<:1HA`;Bb00:k`lH:MgYj7?ooo`006_oo
o`RISXd067aWKRH>338K6C8K6D0V8T4W8c@O6BlC54DT6C/T8TP^:SPR7d0W8E8d;G0l;XM>>GYCC7YE
AI9F@Y5YEHiRCgI:?W51;V`l:`:3Bc8048]<>hUH@HmA?ga>@7]7<hA:>7]<?6Q2=f4d:4/R63XF4RT@
3Al;1aX61a@10Pl10`8?00800b@@3C8D4N_Wi`02V8b;2YV>SA[oool8N7=e01QKD5T>1`PX7QdX7Qde
9bDh:2HZ81dW61Xm:1l`9BDn;bd]8R8h:BE5<RiQ>BiaAcMOAT=QBCmfB3]dF4YaDTII?CMF=b]F=R/2
K4<a01Ea@cU]C3]cACUPA3aP?BmX@3EQ@SQ?>SA;;bPi8A/^6QPQ5QDL4a4H3a4D30dA30hA30d@30dS
61H^6aWck^l00WQdMPYhLgDJoooo27]kN`0HIf=X510<9AdJ9AdJ<BDQ<bHR9AhI8QHG>2DJ;R@Q?Bl[
;B@Q=BPR?blZF3H[HT0`CShkCT0gHSl`IU10Hd`nBcH_Bc8UCC8U0V0o:`0EIShbIDPeKTDeFd@hESTZ
Gc/_FclcB3Pa@R`S<AdF9aHC6a<@5@l;4P/;3`L72`P82`L72PL77aDA;ATEm_7a009mOWh:Ng]k6_oo
o`QgNWX066Y[KQPE3b@M6R@M6RlT838U8B<M6B0F5cLT6RdS83h`;2lU8SDW8S/]:E4d:UDj;3lf=3hh
<E0e:5M6>5I3>3d_:T0]8TD^8`9E>RP03e/i;U]2<6M3<UE2=T`d9e@e;5<k<44e;cXX8B`J52<E4QTB
3aD?2a8;2`l71`032`L700<P5Q4^6QGhlo@00W^0P0YgNWXLoooo000Joooo2IV>S@0G>b@Q:1@?:1@?
@BPT>bLS>24M80h;@B<MBBhZARdYBC4/@R`XC3</DcD/EC<XDRhZDB`PFBhWKCTZKDDfDBlZEc0XH2hQ
009O<Ah03fHb9ga7<GU3<6hl:fhn;f<a8fXm<E/^94`W7CDE4CHJ5Qd:1Qh;1aP51a<00P023P0200@W
3``L2Pa_BT>d]kT<VHj=6_ooo`UhLgD05aTA4A/E4a/E4cLY:34X9RhS8A/D4cXV8Sh_;C/]:c`_;CH[
:T4c;DHc;DHa:D4/:d8[8TX/:5Xf:ePn=3h[:TL]:4h/9002CRlR00mD;bUV@C5R?2mE=R]G>2e?;REE
>357:bHl9R0Z6AL/7Q`I4Q0L4a4G3a4D2`d00Q0<3@049ALE6a<EJda7]l3337QcMA[oool9Ng]k01LQ
7AdM5a@M5a@f:RD_:2@]8QlG4@he91hl;b`j;RTk<2`i;RY3=Re5=Ba0<BLi:BLj9Qa09b9=;bA<=bdd
9R@l:BA6:B000TL/7@0EBB/SFSd/EcPZBC4UCcDYAb`PBSD/?RPP=B<K8aHB9Q/H4`l:5Q0;4P/;3PL7
2PL72`L78aD@610@MUE>bM7B00akNg/Joooo2GMjNP0G8b4U7aXG7aXG=bXV;bPT;R<O5a4><b@M?30]
>bhZ?34/>c4/AST_ACH/>c4X<bHU=28I>R<O@bXQ@S0X;28Q=BHR@2LO0091:A/05D0W8E0i:T`d:3h]
8dLb9d0Z7d4b:SLU7S0P6AlD4R@K61<?2QH?2a<;2`l71`/71``71bDE4ATA4GiLEMOMgP0<MgYj7?oo
o`006_ooo`VISXd05f5<EB0<2R0<2S/T83dV8SdT8C4M6c`U8TP^:T/c;T8Y9DP]:E0Z95Pa9DDY7ShW
93PJ5TLW8c`F4Tl^9d@W8SdQ7ChH4`02@1lI00]06A=<7AIC:aa>9aY@:1]56QA771Ho6QDl6A@U4@dR
3@P00QX61`086@D73P023`029`lE9`l;=R4O[iVHSWim39V>SA[oool9N7=e01Ln=D4=2PX=2PXa9R@c
9bDc9B@W81lf:2Ln;bdn<Blg:BLk;2Y2:RI9;bLg:24b9RH^7Q/l:BLb6aQ3;RXf9RDb8b4d71T00SHR
7P0E=QdJ@B4LA2/P?bLO@RPP>1`J>R0L=1hK<QdJ7aHE7a@B60lA6A0A60lA40/=40`=9ALM9ALD;bDT
^JVXOGYl00ahLgDJoooo2G]kN`0GCDQB50l;50l;;b@P;bDQ<2@P:20M>2XV?Bl[?C8]<bPT=RTU?BHQ
AB/R=2@L;R@Q9a/F=BHS:QPC>2XU;b@P;20L;1PC008[7QP03R/I53DK5SLT6S@R6CHS6BdG530J5RTH
52TI51PC3aP@314;2a<<2a<;2`8:1`L01B<E6B<E430V8];3`8jATP0<Ng]k6_ooo`UgNWX05e=AFQPC
3aPC3blT82hT830S82XR7S`/:3h`;3db;C8W8c<X93TS7d8X83<R6R/R82@J5S4U8RHF4S4W8b/R7bTO
6bLF4P029A`G00hU5a@]61@^81P/7QL^81PV5A8Y5a@S5Q8T5a<F4PlF40/A2P/D2`/C2`/22`L700DU
5AXU5A0c9b?VfMFHXJ8037MjNQcoool001[oool9VHj=01N>OH<b61Tb61TW4Q0m9211:2Dk8Qm==2lf
7QYB=S4g7a]7;2QB<2Q29B918adn920d71U8:BHX4A8h8adg5Q<e61@Y40d00RHB3P09;Q4=>1HB=aLB
;A8=<1<>;Q4=>1HB:A0=;14=008N2`L02AP51aT51`l00Pl00QT51cDK62hB48YoOX=dL`0=VHj=6_oo
o`UhLgD05faTK189318931`E5C<V93LY:34T8d8c<B`P7TDd<B`P7S`/:TH_:SLV9C@T8C<V92XO7Ch[
:B0F634V8RlK6BdL6R<F5@028QPF00dX5aDa6aT_71TV61DY6AHX5aDa6aTS5aDW5aHJ4a4L4a4G3a4H
3a400Q0<3@0560lA<R4O:1TGT92APWj000ehLgDJoooo2G]kN`0GLg1d8AdK8AdK7aTF<2@P=BTU;b<P
@C@_:AlJ@34]9ahJ>2/VAS4X<bLS;R<O;b@Q:1hJ?R/W7A@E;2@N:APD:1PD7Q<?008K5A403B8D42`I
52XI520D428E420D42/I51hD424D41D?2aL@2a8;2a<;2`022PL700DD30`a81/W5a>b/K2QWj003G]k
Na[oool9MgYj01MbM7HX:2HX:2HR71T`920e:BD_9212=C0X7QXl;b/U71Tf:RE7<RPb:2@[8al]924X
7QY0;2PM51DZ91hW5Q<V5a<M4Pl00QXD400=81<?:QPD:1TD7A<?7a<@7Q<?:APD7A<@7a@@50l;5`l;
4`/;50/;008;1`L01AD<33<P6bPH4lc<bkRi^P0=MgYj7?ooo`006_ooo`ZISXd2I4e@01@T3P/m:2E1
:2Dk8ali91m:;RY9<Bde8Qli7a]D:alc71Tm8ahj8AdZ5A/n9Ad^4aHd5a8Y41HV4@`U40d27P/701<V
4@dW4@dX4@dP2`LL1PPR30P_4@hO2`LL1PPP30LN2``H1@H?008I1@LO3P//5A@`5161LG21L6l03YV>
SA[oool:N7=e0T4e?00D40`<<RTX=bTX<B@R<2HS?B`[?c8_:B8R<B8PBB/S:1hN<b@R<B<Q8aXP=RLR
9APK;A`I91HL8QLD8ALE0Q`C4@0C8QPF91PF8aLF7A<A6Q0A7a@A:QPF71<A6Q0A7A@A71<E5`l@40`=
60lA7AHE:A`L;1/IPgn1Ph2200ihLgDJoooo2W]kN`9;@dT051D>2c8Y9CDY9BhS7bXS7ST/:44d;bPS
82dP74<X7B8K62dQ7B`Q71dG6blT7AlE5RXI51lC61/D3a/D408F40/27A@@014L510F3`/C2``I4@`T
5A4E3`/C2``G40/G410B2`/:1`LC2`/K510Z71T[6AFVXj>VYJD03W]kNa[oool:MgYj0Ti8CP0D610=
<bTU=BTU;B<O:24L=b/W@cD`:B@Q;20L?bHL7aTF:b0K:b0L71HK;28M7QDF:QTD7Q8G6Q@?6Q<@0QH?
2`0C7A@@71@@6a@@5@l;4`/;610;8aD@5@l;4`/;5a0;610@4`/;2`L750/;7QD@;QhJ;QXE`;o0`<;2
00igNWXLoooo000Joooo2YV>S@:8LgP052/?3c<L6D@[9c/S7c`W8chZ9TX]:CLP73<J5cXL5bXA3CdS
7RhE5R`E5bXB3R/A624<31`6224<3Ql<308I1PL02B0<3AX61b0<3AT61ah;328?2al;31X61`l10P03
404300HN2``L2PHJ1PP`3PV8MGF6NWT?VHj=6_ooo`YhLgD2IUYR01@?1@LW7Qhi:bTa928b:2Hf:bTn
;2X/8Al[7Q`c81dS5QDe9R<W6Q`V6QdU61DU5ahN51@J3a8N51HM51D260l@00TN5AHI414N51HH3a0L
4aDP5a@M4aDH3a0@30d00Q8<3P074@`>71<E6a<@6A0A;1HBRGn1RHZ;00mhLgDJoooo2W]kN`9^JVh0
51LA3RLO73HY9BhS7c8X93@[9SPZ9RLO6RHK5b`M61`C3c4T7R8G624G624E420D6AL@3a<;31PA41P@
408B2`/02ATA4A<;2aPA418;2aL@41`E41P@418;2`X71`022`P800L;1`LH410H40/D30`V4PbVVibZ
Zj/03g]kNa[oool:MgYj0Vm`LP0D6aPD:24N=BTU;B<O<bPT=2/W=BTU9AdI9AXF:Q`H6Q8?;b<N8QLG
8ALH8A@?7a<H5Pl?4P/;5a0?5a0@0Q<;2`0B6A0A4`/;610@4`/;610@7AD@610@4P/;2`L730P72`L8
2`L7610@6A0;50`<914<^k6b`/K63gMjNQcoool001[oool<VHj=01AD?3TN2@P^61E09R8o:RHm:BE8
;BXg820_4`lb6aLQ3P/_4PhU4@h/4@hJ1PLL1`TP30hM2P`I1@LO30d260D7018O2`dH1@Lb5A8<008Q
30hT40`M2P`>008?008D008L2P`J2@/M2P`a510_6A=;;2Fb^/NHS8/?VHj=6_ooo`ahLgD0538X:P/8
2R@K6SDW9CD[:C<Y9ch]:b`Q8bLH5R/O7AdE52XI5b0G5RLG5QP?4A/@4QdD5Q/B51P?4AdD5P8G3a00
4QdD5QL?42hL6Pd;3B0E5R4H5A/B5A0;3A0<3AD<3A/C5ATB51`C5B`K62TN6dPa:kS7dgQdMPmhLgDJ
oooo37]kN`0DBdQ77QXH91/H<BDQ<RXV;bPT?2dY:b4Q91HB:1dI618?91HA6Q@@8A@@4P/;50`<5a0@
5Pl?4`/;610@0Q8;2`07614A4P/;;AXE20L76Q4A7AD@5Pl@008:1`L02@l71aP@41H@41P@42/I52hP
65`l;/kHh7enOP0?Ng]k6_ooo`agNWX055QKFR/W92DM6BlT834Z9RhX93`]:B/R8RDF4RPL61PB3b<E
4ATC3b0D414;2a<;31L@3aL@41@;2aP@408C2`/04QTA4A<;2bhJ5@T71aXA4AdE41H?40X71`/71a07
1aTA4AP@41XA4B`I53<R6Fe4<]kVjg^0P0mgNWXLoooo000Joooo3IV>S@0@E3`i6PH5;alM>1lKBC4]
ARdZ@RXX;1PE=adI8`dC7P/;:Q4<7P/<8Pl<80d;7@X<0QT51`0D6PH86@D76@D76PH88a0<8@/=<B</
:Q/I8P/?5`D670X<7Pd;7P`;70X<=AhJ9a@C<A<@F30UU8=kSGYf49V>SA[oool=N7=e010b:2X81@LV
8B4_8R0n<2hk;B/e:BTS6aX_8AlM51TL4a@U61DL4aDN5Q@M5A@K4aD260lA00/I414H3a4H3a4I414P
5aDP51HY9S0V8B0N4aLF3a0J4a@00Q`E50076a<E<2<P8QXJ;1XHCc4YThj:OGao011hLgDJoooo3G]k
N`0@BdQ76aHD:2@Q:b0K?2l[>RdY=BXW8A/G;20L6Q8F5a0?8A@@5a0@6Q<?6Q<@5a0@0Q<;2`0D50`<
4`/;4`/;50`<71@@6Q4A:2Pc:bHT7A4E4@/;5Q0@6Q@@6Q<@5a0@<28M91XG:aPDDS8W[J^ZT9NK47]k
Na[oool=MgYj011HFeXZ8Ql[9b<Z7a/l;b/k;BTe:bPR7AP]8AdK4QLG3`lQ510G3a0J4a0L510H4102
4`/;01@D30`C2`/C2`/D30`L510J4A4Z:cLa;2/O4aLB2`/G410M5A0M510I414b8ahX71P/6AAE<bS0
`/BKZ[4@MgYj7?ooo`006_ooo`fISXd045@l>AX61BlO7CPO6dTa;DH]:T8Z:2`H5CLM6B<=4ah;2bXA
31h;328?320=2ad:308I1@L051X621T51aT51aX622<@324;3C4S;2XK6B8;3aL51Q`:31h=2ah<2a`:
33DN6RLD4c4C45P`9IB3NhejMQ2ISXdJoooo3GQcM@0@<RPZ20D79R4Q;b8P?S0^>bd[=BTY8a/J;b4O
7A@I71<D9APE71<E7QHD7ADD6a<E0QP?4@0;6A0A60lA60lA6A0A81LE81@F:BH`9R4P7Q<G5Pl@6Q<D
008L5A@01a/C5C0S828J6R`J64la:I>>RWelO`0@N7=e6_ooo`ekNg/044]8Aa/F52PT8B/P6c`_:cX]
:CDZ9b4K5b`P71XB5QL@3b4D41L@41XC3aXC41L@408C2`/051@<31<;2a<;2a@<31`D41XA4BPX<b/V
91dA5A4;2aH@41XD41XC41L@430R7B@J5b/H558b9jf[ZY2GVa1kNg/Joooo3GMjNP0@F5]J:R8O:bLS
:QlK?2l[>bdY=B/X8QdH;B4M6a8G5`l?8A@@5`l@6Q<@71@@610@0Q<;2`0D50`<4`/;4`/;50`<71@@
6Q4A:R/g<B`[7a<G4P/;5a0@7AD@7A@@6A0A<R<N:1`H;1TDEC<X`<;4VjZa47MjNQcoool001[oool>
VHj=019F=cDK20Lc8Alg7a]5;bYA=C0j9R<e6a<[5QHN3@/O2``J1PLP30PO30dI1PLI1@LN2``H1@H2
7P/<010H1@HK1PPh:BTa6BM<>C4f8bDT51Lb81hW5A<N3@X_61Hc6QM1:2A481Z6LW69NgTAVHj=6_oo
o`ihLgD03S@U9`P72BPR8RlR83X^:d@c<2dU9BdN6B<J71XD51dC5AP?4AhE4AdD5P8H3a4051`C5AL?
41`C5A`C5AL?41X@4C8/;R`N:d8g<2/S9QdI7B`U924K6QXD4bXM72hP7CLY:3/S7hV0PWn2Q15hLgDJ
oooo3W]kN`0BCdU871PF;BHR;20L<b/W@C<^;bLT;AhF8QTH5a8?610@4P/;6A4<610@4P/;4`/;610@
4P/;0QP@400@4P/;50`<<2`]:adY@cH]<bTW91dN=R/W9AdI5a8?:A`I;1hI=RXU@BHNZZ6QUinQ4G]k
Na[oool>MgYj00iNGUhZ924b:BD[81``:BE0<bha:BH`7aHS6QLH4`lH410B2`/I40/G41024`/;01@H
410C2`/H410H410C2`/E30`b;Rl/7RY4=R`j;BX[8R8o<B`[81/I4`lZ7AT]7QTg:RI7:232^k^V]KTA
MgYj7?ooo`006_ooo`jISXd049jCTUDh=B<;23XZ:CXT8E0g<TTa;D<Z9BXC4BdG534N72<E524<2B0?
31`931d:2`8I1@L2910F010L2@XQ3P/R3Q0j9297:RHS3Q0]5Q4^5Q4T3Pl[4@de6aPl7aIM>Bi[EenI
Rh>ISH`AVHj=6_ooo`ihLgD047ehNS4S9A4:2bdY:S0V9DDe<S/_;CHY9R4H62DL6R/R8QhJ6ahD4adF
5AXB51/C508H3a428APM00lJ4Q<O5Q@Q5aTc9BDo;2TN5AHW6QPX6aPP5AHU5aD`81hd8QaD>S1TFfJA
TXh04WQcMA[oool>Ng]k011nOWi9@d8P5Q4a;2Ta9bA3=C0j;b/h;2LP61DT6QL^924Q7ATM4PhJ510F
3`lG41024`/;0QdE6P0@5Pl?6a@@6a8C;28N>RXS5Pl@7ADA7aHA5a0@7a@?;1hJ<R4HG3`^OgAnYJ^Z
Ngal4G]kNa[oool>MgYj019jO7aDEUDZ7QPe;b/d:BE3=C0j<2/i;bXQ6AHU6aLc9R8V81/P4`lK510G
3a0H410D2`/C2`/27QDJ010G3`lM510J4Q8Z81`h:B8C3@hH4PlK510D3PhN4`l]7QXc8AQQ?RjBQY6b
_l1gOGdAMgYj7?ooo`006_oooa2ISXd044l/92H>2c4K64``:e]1?4hk=cPR7bTC4C4G63DH4cPR7bPH
5AX82QT51bPD6R<A5@8^71T03b8@5c`U7aX:44lf;SDO82lL6BhL6B/H5BlL6c/V8C0J6Ehf:GeZJGYS
IIF8R00BVHj=6_oooa1hLgD042`J5aD?3bHL744`;Ddm>d0g=RXQ8B8H62/L7RdL6BlT8b8M71L@4aP?
4B@K820H708Z8Al03ahG7CHY91HB64Th<RdQ92DN7RTP7bDM72TP8CDZ9RPO7eDg;7]fN6aXLGUfM`0B
N7=e6_oooa1kNg/044Ln>R<N6R<K63/]:4`n>D<l>2hV8b4H5BHI6BPH52lT828N6Q@>3a<;2b4I7AhG
6P8Z8Qd03a`F6ST[91DA5D`k<RdR8bLO72dS7bLN6RdR83ha9b`Q7f0m;IfGVHJ;Th63PP0BNg]k6_oo
oa1gNWX045EEDRdZ928K63P[9d/m>DDo>c8Z9R<I5R@H6BHG4c4T8BDP71D>3a<;2b8I7R4H7@8]91h0
3ahG6cd]9aLB5dlm=30S92TQ7S<V8B`P738U8THg:c0U8FQ1<;Fa]INU[X:9QP0BMgYj7?ooo`006_oo
oa6ISXd03dlf;ad60bDB3TL/:5<i=510ADDZ8cPU9CXW9S4I6S@W9S/W;RlP6bDC62hN:@02>B4N00hm
;SPk8Q/`71a;<Be29RA18Qm191/j9bE;;bMK>Rdb7ARVShR=M76ISH`CVHj=6_oooa5hLgD03b`S8@d:
3QXF53`/:T@e<T0j@3HX92hW:C4Z:RPM82XX:34Y<BTV8R0I7RLQ;002<RDR00dd;c/c9AlU7R14<c0e
9RHf928f9R0_:2Q1<2Y@>BlU7QbUUi=mMgX057QcMA[ooolANg]k00m7AD4i=CXW8A`h:bHm<B`l>Sll
;bXk<S0o=c<Z824X:2Lh<3Xl=BlX7b4X8b`00S8U8P0>>SA0=RLP9QlMAC@^=2DR=b<O=b@K<2PUAC8Y
FSd^:1hI^K2]T9>HNgal4g]kNa[ooolAMgYj00mEFEIHEEhb:RDf:RDg;BTi>3m0=2m6>cM:@S`^8b@X
:2Tn=T9;@S/a92D[9Bl00SDV900>?cQ6>BXR:20NAcD^<bDR>2@O>2@K<RPUB3DZHD0_;1hHb<C2VjR_
Mgem4gMjNQcoool001[ooolBVHj=00j2KG<n92<N2@U2;2A2=d5/D4]D?C]C?SQ6<S92=3Q<=cUB?CXk
9RE1;C02=QlS00`n9B=3:BE6;BY1:2EC:B5>:bE;;BI>=C179AibD4aZDdN6M78EVHj=6_oooa9hLgD0
3V1EGR<M7Pl:3CH[9SLe?ei9AT<h>4<i=CH];cLd>D8e>4@h=R`S93H]<@8]8B@033DW9SLX9C/]:cLY
:4HY940[9cd]:44d<SXV8F=;BUYIE85nPAEhLgDJoooo4W]kN`0>JfM[AdU58A/N>2hX<c@mG4a7AChm
@c`g>S<a@Sm1Bc`jACXc;2@R>C0_0RdQ8P0<;b@P<B@O>BdY=BTUABPPA2`T@S0WBSXc?RHNHTa<N7mm
WInR5G]kNa[ooolBMgYj00i]KW1NIV8_:2dk<B/b=3aKC4Q6@D52?CPl=SA;AdQB@Ce6>S8/928m<bl2
;R8Q00`]8Qd^8Q`i;BTe:BE59am7;2A5<bU@?SI19aiPC4j;W9na^KdEMgYj7?ooo`006_ooo`03VHn?
VI>BVHj=016ISXd034lf?S<H5bDF7CHU:FeDCV9DEdhk<E@n>UA0?EPo>e@j>dhh<P8n;Bh02dD_;CPX
8ddf=Dhf<dL[95Hc;4TV8Xm/JePh:DlX:XelO@0FVHj=6_ooo`03N7=eN7QjN7=e015hLgD01b`S;RPS
8a/O:bTT:EY:AU5=Dcde<002@cPg00=6>CQ3=CQ0=S<00Rl[;@0;>Bl^;RTW@CHg@C@c>R/VAS8^>RHT
P6Q[BT0hASToOGYl01IhLgDJoooo00=kN7QkOWikNg/04G]kN`0<AdE:FeYFCTmJ=BleFde8H5YSCD<n
BcdiA3XfAc/gBc`mCCli0SXd<P0;BS/g>S<[BCdjCCdi@C<ZASL`=BHRQG1fKfiYLFmcT9>B01IkNg/J
oooo00=gMGEgO7agNWX04GMjNP0<EEULOhEoLWB0?SLoFTa9JF9^Ed]9D3lkA3XeAS`hD411EDDo0T4j
=`0;EdDnA3XaD48oET@oASP_AC/c<RHSQWEoR96@T9VNVjBR01IgNWXLoooo000Joooo00>IQhNISHbI
SXd04iV>S@0:SWf3C3Q7ESToK5=PH4=;HD<e@bXY@bl[I4Q9HD0e0Ue3?P09HTE0FT0jESdhG3T_Echd
Sgaj;Q8?JDU?ThB501RISXdJoooo00=hKg5hLgEhLgD04gQcM@0:K6A/;BXiBd13FU9OAcU2CT0f;bT^
<2XZDT55CCTa0TTk>P09DChlASTeASPfBc@]A3PaQGao8QdPI5IONWMi01QhLgDJoooo00=kNGUkO7ak
Ng/04g]kN`0:Lg1dBdeDLfeZMWElGEELK6AKC4M@>SHjDDE=BCXa0THl>009CSljA3XeACTfAC8X?SD/
VY>FEeMHRH>7QHV701QkNg/Joooo00=gNg]gOGegNWX04gMjNP0:LWAfG6AVShj7R8fAJFI_OgegGee[
@3i7CdMBACXb0T<k=`09Bchi@CXe@cTf@2lV>C8YZJBXO8:6Y:JYRI:>01QgNWXLoooo000Joooo6YV>
S@06SWf8UhF7PVagED1>C3M6Ab//0THX9P07ARh[ARTV@2<Q>AP@>1XAR7=aVHf<01ZISXdJoooo6WQc
M@06K6A`NG1aH5IS>SI3?SY7>2l_0ST_<006>CDg>C0b<b`];R<P;bPVOgMj6gQcMA[ooolJNg]k00Ic
L7QoOGU[J6mGFEiVIVYSGeX2IEiM00MUIVEUHV9QGemOFUMQHEnIUIQkO7`06W]kNa[ooolJMgYj00Ib
M7QnPG]]LGEYLFn2QXB0PWX2Ph6100N3RXZ3R8R1QXJ2QH>5SHjZZjmgOGd06WMjNQcoool00?oooonA
oooo003oooooTOooo`00oooooi7oool00?oooonAoooo0010oooo0`0005coool30000F_ooo`<0001J
oooo0`0003Coool004?oool00`000?ooooooo`1Loooo00<0003oooooool0F_ooo`030000oooooooo
05[oool00`000?ooooooo`0aoooo000_oooo0P0000Coool400000_ooo`<00003oooo0`0000?oool2
0000?_ooo`@00002oooo100000?oool400000_ooo`<00003oooo0`0000?oool20000?_ooo`<00002
oooo0P0000Coool400000_ooo`<00003oooo0`0000?oool20000??ooo`<00004oooo0P0000Coool4
00000_ooo`<00003oooo0`0000?oool20000;_ooo`00;_ooo`040000oooooooo00000_ooo`040000
oooooooo00000_ooo`030000oooooooo00?oool010000?ooooooo`0004?oool00`000?ooooooo`03
oooo00<0003oooooool00oooo`040000oooooooo00000_ooo`030000oooooooo00?oool010000?oo
ooooo`0004Coool010000?ooooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`00
00Goool010000?ooooooo`00047oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool0
10000?ooooooo`0000;oool00`000?ooooooo`03oooo00@0003oooooool0000coooo000^oooo00@0
003oooooool00002oooo00@0003oooooool00002oooo100000;oool010000?ooooooo`0004Coool0
0`000?ooooooo`03oooo00<0003oooooool00_ooo`040000oooooooo00000_ooo`@00002oooo00@0
003oooooool00011oooo1@0000Coool010000?ooooooo`0000;oool00`000?ooooooo`0400000_oo
o`040000oooooooo0000@Oooo`040000oooooooo00000_ooo`040000oooooooo00000_ooo`040000
oooooooo00000_ooo`@00002oooo00@0003oooooool0000coooo000^oooo00@0003oooooool00003
oooo0`0000?oool200001?ooo`@00014oooo00<0003oooooool00oooo`030000oooooooo00;oool3
00000oooo`800004oooo1000043oool010000?ooooooo`0000?oool200001?ooo`<00003oooo0P00
00Coool40000@?ooo`<00004oooo0P0000Coool300000oooo`800004oooo100003;oool002koool0
10000?ooooooo`0000Goool00`000?ooooooo`1=oooo00@0003oooooool00002oooo00@0003ooooo
ool00005oooo00<0003oooooool0C?ooo`030000oooo000000?oool00`000?ooooooo`05oooo00<0
003oooooool0C?ooo`030000oooooooo00;oool010000?ooooooo`0000Goool00`000?ooooooo`0m
oooo000_oooo0P0000Goool20000D?ooo`800004oooo0P0000Goool20000Coooo`800003oooo0`00
00Coool20000C_ooo`<00003oooo0P0000Goool20000?oooo`00oooooi7oool00?oooonAoooo003o
ooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003o
ooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003o
ooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool0077oool30000YOoo
o`<0001doooo001doooo00<0003oooooool0YOooo`030000oooooooo077oool006Goool300001?oo
o`<00003oooo0`0000?oool200000oooo`D00003oooo0`0000;oool200002_ooo`<000000oooo`00
00000002oooo0P0000;oool300000_ooo`@00003oooo0`0000;oool5000000Coool0000000000004
oooo0`0000?oool400002?ooo`800002oooo100000[oool300000oooo`800003oooo0`0000Coool2
00000oooo`@00009oooo0`000008oooo00000000oooo0000oooo0000oooo1@0000;oool300000ooo
o`<00002oooo0`0006Soool006Koool00`000?ooooooo`04oooo00D0003oooooooooool000000_oo
o`030000oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool03_ooo`050000oooooooo
oooo000000;oool010000?ooooooo`0000Koool00`000?ooooooo`02oooo00<0003oooooool00ooo
o`@00005oooo00@0003oooooool00005oooo00@0003oooooool00008oooo00@0003oooooool00002
oooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00000oooo`030000
oooooooo00;oool010000?ooooooo`0000?oool00`000?ooooooo`0:oooo00X0003oooooooooool0
003oool0003oool0003oool400000_ooo`040000oooooooo00000_ooo`030000oooooooo00Koool0
0`000?ooooooo`1Uoooo001Voooo00<0003oooooool01?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`08oooo00@0003oooooooooool500003oooo`050000oooooooooooo000000;oool0
10000?ooooooo`0000Koool00`000?ooooooo`02oooo100000Goool00`000?ooooooo`0300000ooo
o`@00002oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`030000oooooooo
00Koool00`000?ooooooo`03oooo00@0003oooooool00003oooo00<0003oooooool00_ooo`040000
oooooooo00000oooo`030000oooooooo00[oool02@000?ooooooooooo`000?ooo`000?ooo`000004
oooo00@0003oooooool00002oooo00<0003oooooool0100000;oool30000J?ooo`00I_ooo`800004
oooo0P0000Coool400002Oooo`050000oooooooooooo000000;oool00`000?ooooooo`0>oooo00<0
003oooooool0100000Coool300000_ooo`@00003oooo0P0000Coool300000_ooo`@00003oooo0P00
00Coool300002oooo`040000oooooooo00000_ooo`030000oooooooo00Ooool300000oooo`800004
oooo00<0003oooooool00oooo`800003oooo100000Woool200000_ooo`<000000oooo`000?ooo`02
oooo0`0000?oool400000_ooo`800003oooo100006Ooool006Koool010000?ooooooo`0001Goool0
0`000?ooooooo`02oooo00<0003oool000004?ooo`030000oooooooo02koool00`000?ooooooo`06
oooo00@0003oooooool00002oooo00@0003oooooool0000Eoooo00<0003oooooool0WOooo`00IOoo
o`D00003oooo00<0003oooooool03_ooo`800005oooo0P0000ooool30000;_ooo`800009oooo0P00
00;oool400005Oooo`80000Hoooo00<0003oooooool0Q?ooo`00oooooi7oool00?oooonAoooo0000
\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.195393, -0.100021, 0.0110045, \
0.0110045}, {{17.75, 102.25}, {389.875, 305.375}} -> {-24.7497, -10.231, \
0.945827, 0.945827}, {{110.688, 195.25}, {389.875, 305.375}} -> {-112.682, \
-10.231, 0.945827, 0.945827}, {{203.688, 288.25}, {389.875, 305.375}} -> \
{-200.644, -10.231, 0.945827, 0.945827}, {{296.688, 381.188}, {389.875, \
305.375}} -> {-288.577, -10.231, 0.945827, 0.945827}, {{17.75, 102.25}, \
{296.875, 212.375}} -> {-24.7497, -98.193, 0.945827, 0.945827}, {{110.688, \
195.25}, {296.875, 212.375}} -> {-112.682, -98.193, 0.945827, 0.945827}, \
{{203.688, 288.25}, {296.875, 212.375}} -> {-200.644, -98.193, 0.945827, \
0.945827}, {{296.688, 381.188}, {296.875, 212.375}} -> {-288.577, -98.193, \
0.945827, 0.945827}, {{17.75, 102.25}, {203.938, 119.375}} -> {-24.7005, \
-185.936, 0.945006, 0.945006}, {{110.688, 195.25}, {203.938, 119.375}} -> \
{-112.557, -185.936, 0.945006, 0.945006}, {{203.688, 288.25}, {203.938, \
119.375}} -> {-200.442, -185.936, 0.945006, 0.945006}, {{296.688, 381.188}, \
{203.938, 119.375}} -> {-288.298, -185.936, 0.945006, 0.945006}, {{17.75, \
102.25}, {110.938, 26.375}} -> {-24.7005, -273.821, 0.945006, 0.945006}, \
{{110.688, 195.25}, {110.938, 26.375}} -> {-112.557, -273.821, 0.945006, \
0.945006}, {{203.688, 288.25}, {110.938, 26.375}} -> {-200.442, -273.821, \
0.945006, 0.945006}, {{296.688, 381.188}, {110.938, 26.375}} -> {-288.298, \
-273.821, 0.945006, 0.945006}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "After setting a mouse cursor on a following image, twice clicking the left \
side button of mouse animates the facial changes depending on the lighting \
angles. This is only effective on the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" notebook.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["Do[Show[GraphicsArray[{incColor3DG[[i]]}]],{i,angle}];", "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
69.000 12.813 moveto
(deg) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D90634E
9D7D6D997A7399827899766D998278997F75997F75997F7599766D997A67907163946D5E
8B5F518F6656855E4F89615289615289615289615289594B815C46845C4F845C46845C4F
ABB8C2998E8D998E8D998E8D998E8D998585999291998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998A8A999392998E8D998A8A999392998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998A8A999392998E8D998E8D998E8D998E8D998E8D998E8D936751
98796E997A6A99827D99766D998278997F75997B6C957B709A7B709A7667917162916D5C
916354906555875D4E8E6455896152896152895D4E895D4E815C4A845C4C845C46846C68
ABA2A3998E8D998E8D998E8D998E8D998988998D8C998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998988998988999392998988998D8C998E8D998A8A999392998A8A999392998E8D
998E8D998E8D998E8D998988998D8C998E8D998E8D998E8D998E8D998E8D998E8D956851
9E7E73997A70997E73997F75997A70997F75957764897266A0705D95685C8C6B578B6A5B
89625389615384594C845C4D8A60508A60508A5D4E8A5C49855C50845C4D845C4A94979C
948685998E8D998E8D998E8D998E8D998E8D998A8A999392998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998585999291998E8D998E8D998E8D998988998D8C998988998D8C998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D93634E
987D72997A6F997A70997E74997B71997A6B93756C816F65866656915A587F5D49886152
88655A88655684594B81614E845C4D845C4D845C4D845C4A88605080584A845C4DABB8C2
998E8D998E8D998E8D998E8D998E8D998E8D998988998D8C998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998988998D8C998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D996751
99796E997A70997A74997A70997A70997A6B997E7399796F93716394675E905E568D6150
8D60568A59538D60547A4C44835B4D836859805544885C4D885F50815D4E886455A5ADB8
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D996B55
997A6A997A6F997A6A997A74997A70997E74997A70997F75997F75937163926A5D8F6256
94665C8F62558F65568A575184574B895E5384665C8455448A5C4D855C4D967C759B9A9A
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998A8A999392998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D8D6D64AA917D
997A6F997A6A997A6B997A73997E74997A70997F7599796F997E7499766D997A6B936D5B
92675D8F66598F66588A5A5389614F84594B856356855D4F885C4D805C4DA1999F9D9492
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998988998D8C998E8D998E8D998A8A
998F8F999392998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D5F463DCC9F8B9B7A6C
997A73997A6B997A6A997A6F99827899766D997E6F99837E997B71997B71997A6B997567
95645A956B5994665C8B63508B594E8B615284584A805C4D8D645584584BA0A8B3988C8B
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998988
998787998D8C998E8D998E8D
998E8D998E8D998A8A999392998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D89767A2D100BF0C7AC987965
997E7799756C997E7499756C997E74997F7599796B997A6F997B6C996D6C957A63967563
9A7165946A5D90665C8C5E4D8F5E4F846051855947855C508963538A6151ACB9C3998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998988998988999392998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D9D92913A1C168A6A64876862997A70
997E73997B71997E74997B71997A70997E7499837999766D9576639A6562956A5A8B6354
94695A956A5B906A57855F538F5D4E8B6050845D4B835C4C805C4D886051A19EA19EA4A7
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998A8A998E8D998D8C998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D48281D9A837B7E5D52987965997A73
997A70997A70997A6B997A74997A70997E74997A70997B7190544B94675C905B4E905E50
8F5D4F8F785F8B614E8B615089584985604B8E5C50895C4D815C498D5A4E907668AFBFCC
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998A8A
999392998E8D998E8D998E8D
998E8D998E8D998988998D8C998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D89767548322A896B5E997B71997A67997A73
997A70997667997A6B997A6E997E78997E74996E68997A6F90474390493F8C3B3395504D
8B433A955950815C4A8A624E8A5C498556488D604F895C4D845C4A885345846353988277
AABFCC998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998988
998D8C998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D371E1AF4C6AD9D7E75997A70997A6B997A73
997A6B956E609A70619E8271997972997263955455965B4E9260598434279A6056944343
812822903E348B504580594B84664F84533D895F518E5C50895C4D89584A895E4F896455
A7AAAD99999D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998A8A999392998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D775F5F4E392F9E837498796E95725E9E877B99756B
99725F8C6955915E51A9887E91574D601B0DD7958790413B8D645A794C447A302581634F
7E3C2F8A403E762D21A34036806B55895A3D885A4D8864538E604E84554A896051895C4D
997F71AAB2B799999D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998A8A999392998988998D8C998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D331A18CE9C8297776C997A6A9065589D8B82997B71
996958834F3A8753456A1814BF9F955E15137D453E8B4A4591544A987D728A3C34804C49
683728633E36521F16602213AF4F3B8D70538D52478E6B5B8E6553895E4C84584D895D4E
8963549996A4A6998C9E9997998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998988998D8C998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D8D7E861E0805E9BB9B9D7D72997A6B936B5F987671997A70
915A497B4B32813125460D06B886799B96859A807A9EA8A9997D7499867F8C63599F9A95
916758817A794726223C26244A160EB1553C936C59996F59936E638A5D4C855A4C895446
89635385878D907E82A59DABAAA497998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D5F463D4D28247D57509D8572987969997262997A69998377997A70
874B407A5845723A33460A107D383A8D62529062579A7C72A06960927763924F43955749
8D59499F957E844D3F725551402C244F0A01BE786498775A9877698B5F4D855A4E85594B
8E5F50847062898890746271ACA9A0998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998A8A999392998E8D998E8D998E8D998E8D998E8D
998E8D998E8D8D7A7E18070332130FDCA1909271609976669969639579619E7C6C996D66
875A4682523DAD9B91987C6D99676293635D8D61598B5851914E4A834845864541833731
833B3A83564889464075413761322442130E7C2C1FB18C6F9E7A688B644D85564B815749
8D635389685856362CDED9E99084869E9997998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998988998D8C998E8D998E8D998E8D998E8D998E8D
998E8D998E8D7D67721D110800000C816E659E7E6F997163996F6993666298876D996B66
8752487B4739A088779E8881997F7599756C997E74997F7599695F906D57946A5C8B6350
8F5E4F81554490484587463C75332F5E26245D232588583C9E746990665085564B815846
8D5B4F8963542E1D1DC2ABA4AAA3A7988C8B998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D886B69957A74936F618F6A589979699E7A6A99796E996B66997A6D997566
8A6050844E438E6151A594849E8781997A7099756C998278996860905E53905E4F906E59
875A4A7E58498A533F8554448559448551448052448C61509267568F614F815547855B49
89604B8A5F53241413D6C2CA9F978A998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D9586869E745C9572669675638D8082A9795E987D72997E7399796F997E74997A70
93615889634F844E42977B6A9D8C83998379996A649588739E7F708C5D50905B4D87523F
876854774B3D7E553F7F4E4283553B7B4B3E7F4C39966D5E8E64558B5D4E825447845648
845F4C8860500F0306D9BBB8B3B1B6998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D937569987C748C614F8C63518D7F799A6B67998776998278997F75997F75997F75
996860936257865647945F53A3938A9982789968649372659879698A5D508A5E4C804A3F
83594B7745387F4F3E7F54458859458353418157458C61528B594B8B5D4E84584A805245
845F4B895F53100506613F38F9F1F0999392998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D996B5595766B8049389E847695696298796999767299827899837C99796C997F75
99766899715E8757488F5E4C9E82799E837D997B6C997E7899756C9065588757498B5D4E
855C4D814D407F4E397B4940885C4D925F549267558A6152855E5089584B85584A85584A
845B49886454261A172815155D453FFFFFFF998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
997E759164528D514483664F928375AF7469997669997A7399827899847D998077997F75
99766D9576639065578D685797756698796E956D639E8D7A996E6C8C6E53865449855B4B
815646895A4278493B8A51408C6555926358986D5F8B6354856152895D4E845D4E805C49
88574B88705F77473651322C383D48837473998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
996056874E3F7C3A328465539081739A7C72997E6E99756B998278997F75997F75997B71
997B6C907164986D5E8F78689D7D72997E6E93675E98766899655B875E4F814E41815243
7C4E3F84533E7B4F3F85594B8C61538E695A98695B8B6354855E4F89594B89574D845B4A
8457458E6F637D4733895D51AFC2CB938988998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D99827A
99686187443F793D318D675BA08675987972998278997A70997A70997F75957B6C9E7F75
996D67907B62996C5D9579689D827B997E6F997B75997A7099655C875C477C55477C4F40
7B4E407651448756448C6256946959936E5F8F665790625385615289544789574B85564B
855B498D6A677F47377F594A9D9BA3B1B0AE998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D91614B
8E5D4E7446348F503DA67E6BA08371997A73997E74997F75997B6C99766C907667997065
966D629A6F65947461946E609D7C71997A70997A6F997A7095685F8C4F457C50437C4F40
7F51437F594A825F4C9263588E695694695A906A5C8F5E50855D4F89594C855346855245
845A4C8D7063813A278E7B6C80554CABCDDA998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D834029
4A22146C3A2F572C25D39D80A28578997A6F997A6B997A70997A70997566937465926A61
895E528F625791725D9F8270997E6D9E7E77997A70997A6B9069608759477E4C4780553C
7B4D418D5C4D8863538E5C5090685895655A8B6451906A59875D4E8A6050855D4E845346
84564F896656793D298D5F4C8A4D45ABC5C9998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998681814234
391E153A1F18492522CA977CA2857895766C9E7E74997A668D695D9C796B8E64559B7260
97685E975A53956B54946B599B806EA3877F997A70997A6B90615781544478493D7F4C3B
7751458854458561518B5C4C94635394695C8755488E6354845D4F80584A845C4D845346
84564F845F4D6331207C37229C5D46B0CADA998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D956D5D8C5B56
2604013617113F1F1AE6A78A987C6B997666987D72997A6B84605474514470493A5A3B34
58312A7E3B27A05F4B843C2A8C4A34C4B19B9E837D997A70906558815044784C387B523B
77453B8D61517D5A4C77574A815749845E537D5C4A97685789615281594B7C5749855749
8E5B4F845B4D57291F66281C8D4835AFD4DC998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D9D92918E5844825045
1C0E101F0C093A1613E2B4959878699470629E7D6D997A6A9371676D483B6D524A2A1D1A
2D13114B1F1469443A893B2A7E493E9678699D807A997D76906450814D417044347C5137
511309AC7A608A5B3F8157497846349E66567C5A4C91624D8A6053855D4E734F417A5A4B
8C5A4F7C5644572820773828934B41AEC6CB938988998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998F8F999392998A8A999392998E8D998E8D998E8D998E8D998E8D3C100BFDAE8C8B6355
3018161D0F152D100BF3BC9C997969997A6A9475669A7A6A9E7E77845F508E5C534C3A35
2B22242C1A1748362E744D428D5A50977D6C9D8B8399847D906B5B8151446E42326C4537
4D20196D4C465D382B1D0304833F2D6C4B3C552B1E975F4B8650359D614B785A4E7A5547
8C564B674739451F18683125B66F5DAFBECA958A89998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998988999291998988998D8C998E8D998E8D998E8D998E8D401B163919144D060093513C
30141A26120E341512E5B7979475669D7D7288584B967B64A9908793796B8D61547D5145
79514174504170463884604A9064599372629D8A82997F75906255815C4B784331724E3B
6F393067524E44333009010550201453342E361E18784431764938885A44764D41765A4B
8C5B4840211F412217522218B45943B7DEE79A8F8E998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998787998D8C998E8D998E8D998E8D998E8D998E8D998E8D1801003A1E16310E0D3C1D18
190508351712361411E2B19298796994796D8D5D5B7A4F41865747A07B67906C5A825349
793F31844D368E503B90513BB48D779F7C6C9D817A997F709062598163547847387B5037
7A563E8D5D4F7B51471F1F24291C1D3B25213D2C2667473B734B3779584C8958457A564B
7A56452D15103415125022179D3827BBE2EA998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D1A0200290C0828120E2E120E
240E0C25100D452421CF9377A9827093796998797288675A6B4438693C355D473F764A3F
4C3129583C325F362C784B3F8B716295756B98796E996D6390725B815E5078443F65311E
77402A9B76518E6051845C4B7E544A654436613D368453427B524284564B7A5A458E604B
67473B1C0B0928110D8D4E3E612017C4DEE6998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998A8A999392998E8D998E8D998E8D998E8D20060324080525100D23100C
1501022D120E442925B37B62B288759E8271997A73997E7493746681554E614545774C49
72453C70473D693F367F4E418C6B5D9D817B9571649A6C67956B5E8563557E514D562D28
441C195A32205E3321AE664B9D6E5B855C467B58487A56488053437651448F5D53825A45
40231A220E0C2F1E1A97493469281A5F4E49FAFBFC998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998988998D8C998E8D998E8D998E8D998E8D2109072E1411260E0B27100C
1A09062A100D442925A66B53AA85739D8170997A73998278997F7599837C997D73997D73
99796C99837C99796C997A6C93715E987D729376688F6D5E946C5D8F70618D6A5C825A51
5034333C23212A1E1A4E251B5D32228A4A3873523E834A357A4735926357805547805244
240E0C27100C30181949110A6C1D10453531E0DDDD998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D200B0A3B23201C0C092A100C
250F0C2C1415422722935D46AF826EA98B79997A6F997E7899837999847D998A8799847E
997F7599837C997B6E997F75997A6C997562997A6A90695B946B5D946A5C947564946761
8566597F554D5D3E383E2C293725214D2A2354392E6E473A5E4439834A47815D49784B3C
220C0B260F0C24110E220A07431612523530E1DEDE998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D250B083E21192A1715250E0B
2D0B073216144023196A4335B57D65A88D7A9E7E6E997A7399827899837C997F75998A87
99847E99847E997B6E997F75997B6C997B7199766290695B947564946B5D946A5C946B60
8B66588962537F5E4F7654477253475E3F3661403775483C79554B7E4F45765143553526
281110260F0C3014111E0E0B2C100D4A271CC3ACB0BBBFBC998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D2108044228242D16132F1310
1D0A062F110E2F130E5B2F2291583CC29C8A9D8271997A73998278998885997F75997F75
998A87998077998077997F75997664997A6F956E60956C5E946A5C947060946B5D946A5C
8B63548B5E4F8B615284615384584A895D4E805C4D7C534685564B855649734738371D18
200B07311617200B0C200C07160103411B15956E67CBCFD2998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D2008043B252339211E2F1613
2B110F250F0C321916492B25663B2AC5886FA98B78997E77997E74998981998A87997F75
99837C997B6E997F75997F75997668957662956E5F946B5D946B5D946A5C906A5C956657
906657855E4F896152896455845E4F84584A855C4D7353468256487252435133292B1310
2B1714180507200C0E1401021E0B0C2D110D7F5A53D1CFCF998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D230B084027233F2723361F1C
2F120F1D0A073918144D2A1F633E2F9D624AAD907F9E8276997A74997E74998981998A87
99847E997F7599796C997F7599766D9375638F685A906759956657996A608B6A578F6253
8F655A85614F896152895D4E856050855D4E805344805A4C7A4E3F66423847241B2E1311
1F0C081E0B0D1905071D0A071D0A0D351511ACA09D8A7B7A998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998A8A958B8B210E0D402622442B273B231F
270E0B2F18153117143F211C79422E915643A6826FA38674997A73997E74997E74998885
99847E99847E997B6E997F759572649E7A6B90695B8F6B5D8D66588F62569066578F5E4F
8B65598B5D4F85584E8A614E855C4D845C4D8050437B55477344365E3A2E321A13301311
1E0E0B210F0C200E0C1D0A0623100D371512FAFAFA938988998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D9989889382821A070649261D3B2623422925
321C192E1613371F1B3C1F1669463A804432AF7A66A48E7B9E7E77997E7499837999847D
99857F99857F997C73957B6C957364997969956457906653956A5E9066538F665A8F6253
85615289615284554B805B4D845749845B4B7C5749734E3F693E2F4B272233161124100D
1F0B071F0C0D1A06070F01021D0708502722E2E8E89A8F8E998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D1D09083C1E14422A28412825
361E1A3114113E22183C2420583C2F622E23A96952AD94809D7D72997A70997E78997F70
997F75997F75997B759375638F685A9470609064559066538F65598F69538F66568F5D4E
856555895D4E895D4E815C4D8453468052436F51426940314B2722412117270F0C22100D
270F0C1C0A0C180507170507301411958080806E6E998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D2B1412331B173F2521492B27
371D15331C1A3419154227233E241E502D278D4D37AF8166AA90809A7A6A9E7E73997A6B
997A6A9576669A7A6E9E7E6F9065579063549066538B594E9064589064559565558B5A4B
8B5F5089584E85604D855C49804F447C524366463852281F3C20172A110D1F0B07200C0D
2B110C1C0A0C1400021A06083A1713F9F8F89A8F8E998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D351E193821203F27233F2420
3E231E2D1415351B163B221D4128253C1F165C2E219A664DAC7D67A07C699F82709A7A69
9A7F6E95766694716299796991695B8C57499064508B5D4E895A4B8964538F60508B5D4E
8557498A574B815646815A47784F3F7242326840303B1D162B110D24100D1D0A07190508
1C07081001030F01023415113A1811E7EEF3998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D472E2A29130F4029253B231F
462D293218122E1311432B27371F1B4529243519146B4635764737A66049AF846F926A59
9B7B6E96746496715C9B7464885F50794C3D8E5644945B448F5E518A5A4B8A52428A6251
85573F8052497C4E3F774C3C6A4C3C572C244F2418321612270F0C1D0B07190607190507
1400020E00021905072E120E94746F897C79998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D7C676E260E0C321B19402622
412723341F192F13144524193B2422482E2A38221F40272152342D703C2E874E397A534C
7A55459256429169558E624F764A3E71412E6C3C2B834B328B4C3B8958418F513F7C4E40
7B4733844A387B4C3C6842376134284B22183A161229100D1F0B071A06071401020F0103
0F00020F000224100D321411EBE7E7988C8B998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D3B242128140F412824
3B272338211D200E0B41231D492E2A462D2949312C422C284C332C53352C553328522E2A
512C20592E276D392A6D4536512F2A573028602E215F311E6632277C47317943306E3C2B
6E3E2F6331236A3D315B2E244C271D351511361A161D0A061E0B071805071300020E0002
0E0002270F0C1C0A0C6F4A43B4B7B9998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D614C55200C0A3B2420
3D26223D2421311D1B3C2522482E2A4B332E422925482D29502A2458312545291E3E2724
381A164727233C16124F2E274427223D211D3E1813401F194019134C1D16532B1C4E271A
50281B451A14471C163F1A153C191425110D220D081A06071A06071905070E00020F0002
270F15270F0B36211FAF99988E7E7D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D8E7D83321819271210
3D24204128253B221F4D342F361E1A523631371F1B472C2852302842252241231D3E2420
341C1948292628111238231D37161335181429100D26120E2E110D3816123717122D120D
30130E2E110D38161229100D2C110D1E0B071E0B071805071905070F00020F0002190507
351B182E12108A7F7E837473998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D644D50240E0B
3D28254128253B231F39241F4A2E2A49312D35221F391F1B542B1F331C193D231E3A211D
2A151B3E251D2E131634171229101626110C25100D1E0B0726110D27110D28110D200B07
1C0608220C082F110E1F0B071C0608200C071E0B0C1805060F00021905071F0E0B2C1514
30141181717081706F998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D8873782B0F0F
331C19442B273B231F3C27233E2A264A2D2937201C331A173A1C172A110D3D231E2E1516
2C15172A120E2B1118210C0C1C0608210C0E1F0C0C190607200C0D1A0607200C0D190607
1E0B0C220F0B1F0B0C1A06070F01021001031001031001031E0B0C1C0A061A0608300E09
887575867A79998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D543C39
1E09082E18154026223F2A263D2925482D2A3720202F130F321B17210E0B2F120E25110E
2C110E1A06071C0709200C0E1D0A0C1905071F0C0D1805071F0B0D1805073215120C0002
210C0E24100C1D0A0C0E00020F00021400021C0A0C1A090B1D0A0C3114102F19134B2C25
B2BAC7988C8B998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
543C391A06052F1F1D381F1B49312D462D2A422A282C1815371D19230D131E0B0B2A110C
1E0B0C220F0C200D0B1D0A0C1905071905071A06081905071A060823100C210B0D31232C
2A1B19220B0F1705061C0A0C1E0D0B1E0C0B1C0A0C351E1A27141331131058302594837B
8D7A76998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D5637351B080733211F371F1B452F2A5135303A2623351B132B16161E0D0B1F0B0C
1A0607200C081F0C0D1906071905071E0B0C1805061E0B0C1805061B0608382929311927
4C393136232524141732201E2715131E0D0A2F1816331A1741282444201A867271897B79
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D9E9392553835230B083A2A293A242150373249312D432A252A13112D1714311E1C
231514210C09200F0C1C090C1D0A0B1905071905072410161C090A210E0B220E103A2422
472A26230E102D16112E1611240E0F2B110D351B183C1F165D392E6B575F998B83998D8C
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D4F2C24260E0B311B184C302B5B413C4E3B3738221F291311311718
35181338221F2818151A080A19050728141A2311152E1C192210173C251F1A0A104F362E
351F202F1C192E1C192B18152F1C1B3B2621301A195E36297D6A697A6365958888998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D4F362F1D060325120E472C28533934504045452A23382525
3A272631191A3427263B272E2F201B2513182E1E2939211E3D2E383B221B301C1C4B312D
42262441221F41241B3A27254B2F275B3A2D321D18A68F888D7471998D8C998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D826D733E24231E0909422C244237416C504B543D3B
533E384632324234384C3739523D3A3B2625412D30361F233E2523432925462D2A412825
5329214E2B254B2D264E353047251E72504C6A5347867472998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998F8F999392998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D4F363E33181725161D3625296D544E
6254574E3B31543E3A54403D583F3B543A3B4E38323E2D2E452F2D3828234D36354E3633
472B2456332C4926228F6C6B5838294F282A8D7C7D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998787998D8C998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D8E7D834C384756393F
6C536060434B614335432A29432F2B6448496140355D433E6245405A403A563D385C392F
573E348F7C7A2E120F69494F938485998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D8E7D88978587826C7755404E4C3746472B2C462826462E2B462926402321391810
381A11887371998D8C998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D998E8D
998E8D998E8D998E8D998E8D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?oooeVISXd4T6=>19emK@>INW<4VH9h19UfK@BIPWP;VGme19Uf
K@BINVL4T75S19A]GPB;Ge44SfIF0hENCa29HE84REU;0h5LAPB4G4l4Q5a618ALC`B[^<8?VHj=19V5
Q@BITY4SVHj=5Oooo`005?oooeVISXd4T6=>19emK@>INW<4VH9h19UfK@BIPWP;VGme19UfK@BINVL4
T75S19A]GPB;Ge44SfIF0hENCa29HE84REU;0h5LAPB4G4l4Q5a618ALC`B[^<8?VHj=19V5Q@BITY4S
VHj=5Oooo`005?oooeVISXd4T6=>19emK@>INW<4VH9h19UfK@BIPWP;VGme19UfK@BINVL4T75S19A]
GPB;Ge44SfIF0hENCa29HE84REU;0h5LAPB4G4l4Q5a618ALC`B[^<8?VHj=19V5Q@BITY4SVHj=5Ooo
o`005?ooo`BISXd4VHZ:19VCTPBISXd4VHZ:0iVCTR>ISXd4VHZ:19VCTQNISXd4TfMA19QiKP>INVX4
VH9m19UfK@BIPWP4VGme19UkK0>ENg04VW]`19YfI`BALF84TFeL195SE0B@IED3Qee>18iTE@R9HE88
REe>0h5LBPB4G4`4Q5a618A/J0B[XZ<?VHj=19V9R0BISH`SVHj=5Oooo`005?ooo`BISXd4VHZ:19VC
TPBISXd4VHZ:0iVCTR>ISXd4VHZ:19VCTQNISXd4TfMA19QiKP>INVX4VH9m19UfK@BIPWP4VGme19Uk
K0>ENg04VW]`19YfI`BALF84TFeL195SE0B@IED3Qee>18iTE@R9HE88REe>0h5LBPB4G4`4Q5a618A/
J0B[XZ<?VHj=19V9R0BISH`SVHj=5Oooo`005?ooo`BISXd4VHZ:19VCTPBISXd4VHZ:0iVCTR>ISXd4
VHZ:19VCTQNISXd4TfMA19QiKP>INVX4VH9m19UfK@BIPWP4VGme19UkK0>ENg04VW]`19YfI`BALF84
TFeL195SE0B@IED3Qee>18iTE@R9HE88REe>0h5LBPB4G4`4Q5a618A/J0B[XZ<?VHj=19V9R0BISH`S
VHj=5Oooo`005?ooo`BISXd4VHZ:19VCTPBISXd4VHZ:0iVCTR>ISXd4VHZ:19VCTQNISXd4TfMA19Qi
KP>INVX4VH9m19UfK@BIPWP4VGme19UkK0>ENg04VW]`19YfI`BALF84TFeL195SE0B@IED3Qee>18iT
E@R9HE88REe>0h5LBPB4G4`4Q5a618A/J0B[XZ<?VHj=19V9R0BISH`SVHj=5Oooo`005?ooo`BISXd8
VHV819VCTPBIRHP3VHf<19V>S@BIRXX4VI>B19V:RPBITi8?VHj=19V9R0BISH`GVHj=19EXD@BNOW<3
VGY`19UnL`BIOgD4VGY`19UoM@BEMf@3RG9V1:1`G@BEJ5`4S6]G18]ZF`B9HU<4RF5C0hAIC0B4G4d8
RV1@18YMCPB:G4T3QEa@18ALC@B4G4X4U9NL19B6QA>ISXd4VHZ:19VCTQnISXdEoooo000Doooo19V>
S@RIRHP4VI>B19V9R0>ISH`4VHj=19V:RPBITi84VHZ:19VCTPnISXd4VHV819V=S1NISXd4UFQA19in
L`>INW04VGic19UoM@BINW04VGme19EgI0>9LVH4X71M19EXG0B<JeL4RfYK18URD`B9HE<3Q5U<18AL
C@R:H504RUe>18YLB@>5G504Q5a=18ALBPBDUi`4U8J54iV>S@BIRXX4VI>B7iV>SAGoool001Coool4
VHj=29V9R0BITi84VHV80iV=S0BISXd4VHZ:19VCTPBIRXX4VI>B3iV>S@BIRHP4VHf<5iV>S@BEJ544
WWic0iUjL0BIOW<4VGme19UjL0BIOgD4UGMT0hUbIPBPL5d4UFQL18a[E`B;JU/4RF9C18UQD`>4FD`4
Q5a=28YPD0B:GDh4RUa90hELD0B4G4d4Q5a:19BGW0BDQXDCVHj=19V:RPBITi8OVHj=5Oooo`005?oo
o`BISXd8VHV819VCTPBIRHP3VHf<19V>S@BIRXX4VI>B19V:RPBITi8?VHj=19V9R0BISH`GVHj=19EX
D@BNOW<3VGY`19UnL`BIOgD4VGY`19UoM@BEMf@3RG9V1:1`G@BEJ5`4S6]G18]ZF`B9HU<4RF5C0hAI
C0B4G4d8RV1@18YMCPB:G4T3QEa@18ALC@B4G4X4U9NL19B6QA>ISXd4VHZ:19VCTQnISXdEoooo000D
oooo29V>S@BIQHD4VI:A2iV>S@BIRHP4VHf<19V9R0BISH`^VHj=19=SCPBHOG83VGY_19UjL0BIOW@4
VG]a19UjJ`BCMF`3PFmU18IVEPBAFUP4Oee918QQDPB8IEX4R6EF0hAIB`B1HDh<Q5a=18ALBP>8H504
P5Q:18ALC@B[^<8GVHj=19V9R0BISH`OVHj=5Oooo`005?ooo`RISXd4VHF519VBT@^ISXd4VHV819V=
S0BIRHP4VHf<;YV>S@BCHdh4V7eb0iUjK`BINW04VGid19UkL@BINV/4TgE/0h5_I@B6IUH4TEYH17mM
B@B8HE84R6EJ18QUEP>4FD/4PF5>38ALC@B4G4X3R61@181HBPB4G4d4ZkS25iV>S@BIRHP4VHf<7iV>
SAGoool001Coool8VHj=19V5Q@BITY4;VHj=19V9R0BISH`4VHV819V=S2jISXd4Tf=>19QmLP>INVl4
VGY`19UnM0BINg44VGY[19=eK0>1KfD4QVIF195JF0AoGDT4R65B18QUFPB8IEH3Q5U;185QCPb4G4d4
Q5a:0hQPD0B0F4X4Q5a=1:^h`QNISXd4VHV819V=S1nISXdEoooo000Doooo29V>S@BIQHD4VI:A2iV>
S@BIRHP4VHf<19V9R0BISH`^VHj=19=SCPBHOG83VGY_19UjL0BIOW@4VG]a19UjJ`BCMF`3PFmU18IV
EPBAFUP4Oee918QQDPB8IEX4R6EF0hAIB`B1HDh<Q5a=18ALBP>8H504P5Q:18ALC@B[^<8GVHj=19V9
R0BISH`OVHj=5Oooo`005?ooo`RISXd4VHV819V=S4VISXd4VFMA19UiKP>INW04VGYd29UjL0BINV/4
VGic0iUiK`BCLF<4U6MN191NEPB=HE04SF1F18YID`>=H5@4NTa418=KC@B3J5T4P5E418QLC@>8Ge04
PEe>18QTE@BU[KPnVHj=5Oooo`005?ooo`RISXd4VHV819V=S4VISXd4VFMA19UiKP>INW04VGYd29Uj
L0BINV/4VGic0iUiK`BCLF<4U6MN191NEPB=HE04SF1F18YID`>=H5@4NTa418=KC@B3J5T4P5E418QL
C@>8Ge04PEe>18QTE@BU[KPnVHj=5Oooo`005?ooo`RISXd4VHV819V=S4VISXd4VFMA19UiKP>INW04
VGYd29UjL0BINV/4VGic0iUiK`BCLF<4U6MN191NEPB=HE04SF1F18YID`>=H5@4NTa418=KC@B3J5T4
P5E418QLC@>8Ge04PEe>18QTE@BU[KPnVHj=5Oooo`005?ooo`RISXd4VHV819V=S4VISXd4VFMA19Ui
KP>INW04VGYd29UjL0BINV/4VGic0iUiK`BCLF<4U6MN191NEPB=HE04SF1F18YID`>=H5@4NTa418=K
C@B3J5T4P5E418QLC@>8Ge04PEe>18QTE@BU[KPnVHj=5Oooo`005?oooeVISXd4VF]E19UjJP>INVl4
VGYZ19UjM0BINW04VGid19UjL0NIOgD4Tg5S199ZG@B?HUH4U6IL18mRE@>?IEH4RUMA18AGB`B9GU<4
Q6IL18AEA0>:G4d4QEa=19IlM@BKVYXKVHj=19V:RPBITi8KVHj=5Oooo`005?oooeVISXd4VF]E19Uj
JP>INVl4VGYZ19UjM0BINW04VGid19UjL0NIOgD4Tg5S199ZG@B?HUH4U6IL18mRE@>?IEH4RUMA18AG
B`B9GU<4Q6IL18AEA0>:G4d4QEa=19IlM@BKVYXKVHj=19V:RPBITi8KVHj=5Oooo`005?oooeVISXd4
VF]E19UjJP>INVl4VGYZ19UjM0BINW04VGid19UjL0NIOgD4Tg5S199ZG@B?HUH4U6IL18mRE@>?IEH4
RUMA18AGB`B9GU<4Q6IL18AEA0>:G4d4QEa=19IlM@BKVYXKVHj=19V:RPBITi8KVHj=5Oooo`005?oo
oeFISXd4SFeT1:ZAO@BINVl3VGYZ19UjJ`BINW<4VGid19UjL0BIOgD3VGU_19UnM0BIMVd4VGY[19=]
F`BBIed4SfII0hmVF0B:FU<4RF5?18AIB`B5HeH4QEe?0hQLC@B0G4d4XIVO19fDTQ^ISXd4VHV819V=
S0NISXd4VHZ:19V?S`BITi88VHj=5Oooo`005?oooeFISXd4SFeT1:ZAO@BINVl3VGYZ19UjJ`BINW<4
VGid19UjL0BIOgD3VGU_19UnM0BIMVd4VGY[19=]F`BBIed4SfII0hmVF0B:FU<4RF5?18AIB`B5HeH4
QEe?0hQLC@B0G4d4XIVO19fDTQ^ISXd4VHV819V=S0NISXd4VHZ:19V?S`BITi88VHj=5Oooo`005?oo
oeFISXd4SFeT1:ZAO@BINVl3VGYZ19UjJ`BINW<4VGid19UjL0BIOgD3VGU_19UnM0BIMVd4VGY[19=]
F`BBIed4SfII0hmVF0B:FU<4RF5?18AIB`B5HeH4QEe?0hQLC@B0G4d4XIVO19fDTQ^ISXd4VHV819V=
S0NISXd4VHZ:19V?S`BITi88VHj=5Oooo`005?oooeFISXd4SFeT1:ZAO@BINVl3VGYZ19UjJ`BINW<4
VGid19UjL0BIOgD3VGU_19UnM0BIMVd4VGY[19=]F`BBIed4SfII0hmVF0B:FU<4RF5?18AIB`B5HeH4
QEe?0hQLC@B0G4d4XIVO19fDTQ^ISXd4VHV819V=S0NISXd4VHZ:19V?S`BITi88VHj=5Oooo`005?oo
oe6ISXd4GdHm1<bOR`BKNV`4VGYc0iUjJ`BINVX4VGY_19V2N0BIMVd4VGi_0iV3OPRINg44VGY[19Ue
I`BEI5X4UF]I0iAVG0B;He04ReU>18]QDPB4F4X4P5a=0heTE@B4F4/4X:Rc19R<RbZISXd4VHV819V7
Q`BISH`8VHj=5Oooo`005?oooe6ISXd4GdHm1<bOR`BKNV`4VGYc0iUjJ`BINVX4VGY_19V2N0BIMVd4
VGi_0iV3OPRINg44VGY[19UeI`BEI5X4UF]I0iAVG0B;He04ReU>18]QDPB4F4X4P5a=0heTE@B4F4/4
X:Rc19R<RbZISXd4VHV819V7Q`BISH`8VHj=5Oooo`005?oooe6ISXd4GdHm1<bOR`BKNV`4VGYc0iUj
J`BINVX4VGY_19V2N0BIMVd4VGi_0iV3OPRINg44VGY[19UeI`BEI5X4UF]I0iAVG0B;He04ReU>18]Q
DPB4F4X4P5a=0heTE@B4F4/4X:Rc19R<RbZISXd4VHV819V7Q`BISH`8VHj=5Oooo`005?oooe6ISXd4
GdHm1<bOR`BKNV`4VGYc0iUjJ`BINVX4VGY_19V2N0BIMVd4VGi_0iV3OPRINg44VGY[19UeI`BEI5X4
UF]I0iAVG0B;He04ReU>18]QDPB4F4X4P5a=0heTE@B4F4/4X:Rc19R<RbZISXd4VHV819V7Q`BISH`8
VHj=5Oooo`005?ooo`RISXd4VHZ:19VCTSfISXd4RGIj12d@2`C`aj`4V7UU19UnM`>IMF`4VGid19Ue
K0BIOW@4VGme19UiJ`>INVl4VG]/19U]K0BENV<4UWES19YaI@BDJUd3T6IL18aNC@B?GTl4Q61A18EI
A`B5G503RF=C18YQD@B/^L=2VHj=5Oooo`005?ooo`RISXd4VHZ:19VCTSfISXd4RGIj12d@2`C`aj`4
V7UU19UnM`>IMF`4VGid19UeK0BIOW@4VGme19UiJ`>INVl4VG]/19U]K0BENV<4UWES19YaI@BDJUd3
T6IL18aNC@B?GTl4Q61A18EIA`B5G503RF=C18YQD@B/^L=2VHj=5Oooo`005?ooo`RISXd4VHZ:19VC
TSfISXd4RGIj12d@2`C`aj`4V7UU19UnM`>IMF`4VGid19UeK0BIOW@4VGme19UiJ`>INVl4VG]/19U]
K0BENV<4UWES19YaI@BDJUd3T6IL18aNC@B?GTl4Q61A18EIA`B5G503RF=C18YQD@B/^L=2VHj=5Ooo
o`005?ooo`RISXd4VHZ:19VCTSfISXd4RGIj12d@2`C`aj`4V7UU19UnM`>IMF`4VGid19UeK0BIOW@4
VGme19UiJ`>INVl4VG]/19U]K0BENV<4UWES19YaI@BDJUd3T6IL18aNC@B?GTl4Q61A18EIA`B5G503
RF=C18YQD@B/^L=2VHj=5Oooo`005?ooo`RISXd8VHV819VCTSFISXd4WI:A13XL5PB:JV@4QfQR19Uj
L0BIOW<3VG]a19UnM0BINg44VGY`19UnM0BIPgT3VGI]19EfH`BJIF84UFYJ18]SE0BDJEX4UFYK0i1Z
E`B5Ge<4See>18]PD0B4GD/4Pea<0h1LC@B8H544XIjQ19jTYcjISXdEoooo000Doooo29V>S@RIRHP4
VI>B=IV>S@BMTY44>Q`F18YZI0B7J684VGY`19UnL`>INg44VGid19UkL@BINW04VGid19V3N@>IMVd4
UGIS19YUHPBEJUX4Rf=D19AYFPBEJU/3T6YG18EOD`B?GDh4Rf1@18AMB`B3G4`3P5a=18QPD@BQWZ44
WZBW?YV>SAGoool001Coool8VHj=29V9R0BITi8eVHj=19fBT@@j71H4RVYT18MXHPBINW04VGic0iUk
L@BIOW@4VG]a19UjL0BIOW@4VH=i0iUfK@BEMV<4VVER19EZFPB;He@4U6UJ19EZF`>@JUL4QEmC18mM
CPB;H504Q5e;18=LC0>0G4d4R61A1:6NX@BNY:LnVHj=5Oooo`005?ooo`RISXd8VHV819VCTSFISXd4
WI:A13XL5PB:JV@4QfQR19UjL0BIOW<3VG]a19UnM0BINg44VGY`19UnM0BIPgT3VGI]19EfH`BJIF84
UFYJ18]SE0BDJEX4UFYK0i1ZE`B5Ge<4See>18]PD0B4GD/4Pea<0h1LC@B8H544XIjQ19jTYcjISXdE
oooo000Doooo29V>S@BIRXX4VHj=19V=S3FISXd4B2PM19Z3N`AnGE84V7UU19UjL`NINW04VGY[19Uj
M0BINW04VGid19UjL0>INg44T5A;19AWG0B@Fdh4T5i@18mMC`B?N5l3Rf5>18]QD0B9F4T4QF1;18iL
D0B9G4d3PEa918eJCPB@MVP4[ko<:YV>S@BIRXX4VI>B39V>SAGoool001Coool8VHj=19V:RPBISXd4
VHf<=IV>S@A8:1d4VX=k17iMDPBHNFD4VGYc1iUjL0BINV/4VGYd19UjL0BIOW@4VGY`0iUkL@B@E4/4
U6ML191KCPB@GU04See?18mhG`>;HDh4Rf5@18UHB@B5H4/4SUa@18ULC@>1G4T4SEY>191fJ0B__l`Z
VHj=19V:RPBITi8<VHj=5Oooo`005?ooo`RISXd4VHZ:19V>S@BISH`eVHj=14PX7@BJPg/4OUeB19Qi
I@BINW<7VGY`19UjJ`BINW@4VGY`19UnM0BINW03VG]a191DB`BDIe`4T5]>191ND0B?GDl4SgQO0h]Q
CPB;HE04REQ918EPB`B>G504REa=0h5LB@B=FTh4T7IX1:noc2ZISXd4VHZ:19VCTPbISXdEoooo000D
oooo29V>S@BIRXX4VHj=19V=S3FISXd4B2PM19Z3N`AnGE84V7UU19UjL`NINW04VGY[19UjM0BINW04
VGid19UjL0>INg44T5A;19AWG0B@Fdh4T5i@18mMC`B?N5l3Rf5>18]QD0B9F4T4QF1;18iLD0B9G4d3
PEa918eJCPB@MVP4[ko<:YV>S@BIRXX4VI>B39V>SAGoool001Coool8VHj=19V9R0BISH`fVHj=0hUf
M@A8<RX4RF]N19UkL@BINVL4VGYc19UjL0>IMVL4VGY[19UjKPBIOWP4VGid19U^J0>INVl4T4M31919
?`B<>c<4UE1=18]3>PBEFE03PEa:18YRCPB:G4T4QEI818ePC`B9G4d3Q5a:18QCA@B4He<4V89g1:Zo
c2JISXd4VHV819V=S0bISXdEoooo000Doooo29V>S@BIRHP4VHf<=YV>S@>9MWD4B38Z18U[GPBINg44
VGYW19UjL`BINW03VGIW19UjJ`BINVh4VGih19UnM0BIKVP3VGY_1917@`B@BCl4S3/c19E@C@B;@cX4
UEU@0h5LBPB:HTh4RUa918EFB0B=H4l4REa=0hALBPB8DdD4Q6=C19R2M`BZ_l`VVHj=19V9R0BISH`<
VHj=5Oooo`005?ooo`RISXd4VHV819V=S3JISXd3RGIe14Pb:PB9Jeh4VG]a19UjI`BINW<4VGY`0iUf
I`BINV/4VGY^19UnN0BIOW@4VFiX0iUjK`B@Ad<4T4To18`k<`BED4d4Rd<j19EID0>1G4X4RV9>18YL
B@B5ETP4SF1?18ULC@>4G4X4R5=518ASD`BHPWL4Z[o<9YV>S@BIRHP4VHf<39V>SAGoool001Cooom6
VHj=0cLN6PCdaZd4WGie19UjL0BINV/4VGYc19UjJ`>EKV04VW1Q19j2L@BING84VG9S19EDE@>FFdh4
TV1I18@d9`BJH5H4U4=3184X8PB@?S@3Re15181IB`B4ITl4Q5<m18UOD@B>G503REa=18UHBPB9GTl4
RFAE1:NZ[@BIVIdfVHj=5Oooo`005?ooodJISXd3=ahJ1?C6[@BMOWD4VGY`19UjJ`BINW<4VGY[0iE^
H0BJL644WX9a19UiLPBILV<4UEAE0iIKCPBBH5T4Q3@W19YPEPBD@d<4PBPR190n=0>;D4D4P5U;18AV
C`B4Dcd4REmA18iLD0>9G4d4REQ:18UNC`B9I5D4YjZ]19VIWCJISXdEoooo000DooooAYV>S@<g7QX4
m<J]19enM@BINW04VGY[19UjL`BINV/3UFiP19Y`H@BNPW44VGUb19UbH`BEE5D3UU]>199PF@B4=2L4
VV1F19A3@`B1:284T3hd0h]@A@B0FD/4Q6I?18AC?@B9Ge44SUa@0hULC@B9F4X4REi?18UTE@BWZZd4
VIVM=YV>SAGoool001Cooom6VHj=0cLN6PCdaZd4WGie19UjL0BINV/4VGYc19UjJ`>EKV04VW1Q19j2
L@BING84VG9S19EDE@>FFdh4TV1I18@d9`BJH5H4U4=3184X8PB@?S@3Re15181IB`B4ITl4Q5<m18UO
D@B>G503REa=18UHBPB9GTl4RFAE1:NZ[@BIVIdfVHj=5Oooo`005?oooa2ISXd4VHZ:0iVCTR^ISXd4
MemO0dhi;`BNPg@4V7U^19EbGPBNQg/4VGE[19UbG`><JED4TEiA1:V8OPBAEdd4H1/=1=NEQ`>@@C/4
SFAJ17U<A0Aj<2D4PF=?17hl;`B:@3h3MRdQ1:=0=PB0JeD4REXm18QJC@B8I5<3SV1>18AEBPB9H544
REa=19UoL@BZ/[L4VIVM<YV>SAGoool001Coool@VHj=19V:RP>ITi8[VHj=17MOG`=>>Bl4WX=d19Qi
KPBELUh4WXMk19UeJ`BILUl3S6UE195ND@BYR7h4TEM=160K3@CGUHL3T44k18eTFPAiC4@4NS0U185S
C`An?2l4RT0n0gH]8@BS@3H4P6]E18UJ?@B8FTd4R6AC0hiPCPB4EDX4RF1A18ULC@BIOg44Z[:g19VI
WC:ISXdEoooo000Doooo49V>S@BIRXX3VI>B:iV>S@AgGel3CST_19j3M0BHNFh4UG9N19j7N`BIMF/4
VG9O0haYE@BAGU44ZHQn195GC@AP6`d4eiF70i11>`B=I5X4NDa417X`9@B1Hdl4OS`_18Y0?P=f;B44
Xd0f181[E@B9FSd4R5Y=18QTD`>>H4h4Q5E:18UPD@B9G4d4VGma1:Zb]`BIVIdbVHj=5Oooo`005?oo
oa2ISXd4VHZ:0iVCTR^ISXd4MemO0dhi;`BNPg@4V7U^19EbGPBNQg/4VGE[19UbG`><JED4TEiA1:V8
OPBAEdd4H1/=1=NEQ`>@@C/4SFAJ17U<A0Aj<2D4PF=?17hl;`B:@3h3MRdQ1:=0=PB0JeD4REXm18QJ
C@B8I5<3SV1>18AEBPB9H544REa=19UoL@BZ/[L4VIVM<YV>SAGoool001Coool8VHj=19V:RPBITi84
VHV80iV=S2^ISXd4<aXH0ljLPPBGMf`4VGYZ191UF0BMRh84VG]a19UYF0>3CcX4Qe=516XH50BoWiD4
GQDC17e5?P>;BTD4TEA:19QmLPB:?3@4P4a916Pg:0AS?SH3DQlF160R4`B_Cc/4SG1C18eBA`B>Je/3
SVEC18UNC0B4F4d4REe>18USE0BIUZ@4YYV<0ijIUbnISXdEoooo000Doooo29V>S@BIRXX4VI>B19V9
R0>ISH`[VHj=13<J60?>W884UgM/19UjJPB@IEP4WH^219UkL@BIJEP3Pdlj18MCA@AZ61@4_inE15hE
4`AmACh3RdY5195DBPBHOG84RS`d181<B@AX=bP4Hchf0e8O5PAP8Q<4[dlk18e`D`B=DTL4SV]K0hiU
D`B9GT`4Q5Q=18UMCPB9He@4VIJT1:JIS0>NVIL_VHj=5Oooo`005?ooo`RISXd4VHZ:19VCTPBIRHP3
VHf<:iV>S@@c6QP3cYb219MgK0BINVX4T6EH19f;PPBINg44VFUH0h=?>PB7DdD4JQPD1;nOU@AN5A<4
ODDn0h]:A@BAE4X4V7eb18Xl=0B0C4T4J3LX16<n=P=B7aH4H28C1:m?>`B=L5<4SE9718i[F`>>IE<4
REi<18AHC@B9GDh4RF=D19VFY0BVVH`3WYVG;iV>SAGoool001Coool8VHj=19V:RPBITi84VHV80iV=
S2^ISXd4<aXH0ljLPPBGMf`4VGYZ191UF0BMRh84VG]a19UYF0>3CcX4Qe=516XH50BoWiD4GQDC17e5
?P>;BTD4TEA:19QmLPB:?3@4P4a916Pg:0AS?SH3DQlF160R4`B_Cc/4SG1C18eBA`B>Je/3SVEC18UN
C0B4F4d4REe>18USE0BIUZ@4YYV<0ijIUbnISXdEoooo000Doooo29V>S@BIRHP4VHf<;YV>S@B=OXH4
7PP50nVkV`BMOG84VGY[19=[G`BHMW44VGY`195JB@=kBc84PC4U14H=1PBhQWT4ViJ519Z0NP>NZ:T4
VGed19V6O`B<HeT4WiZE195WF0B1NWT3AbHR13`V90A:5Ph4/EDl19=/F@BIKeT3TfiS18YMC0B5FT`4
REA618USD`B5Qhd4T7j20jFMZ`BZY9L[VHj=5Oooo`005?ooo`RISXd4VHV819V=S2jISXd4SGj611h8
1@?Y^i/4WGeb19UjJ`BCJel4V7Ia19UjL0BAFTT3Nd/b184a9@A63@H4^8Ii19^FQ@BJP7X3WZRY19Um
M0BIQWl4S6=I19nJU@BAIeP4PGYi0dLV8P@l9R@4BQH>1;5E?0BCK5T4VFmI0i=^H`B:GD`4QEY<18UD
APB9He<4QHN=191nPP>UWJ/4ZZBG:iV>SAGoool001Coool8VHj=19V9R0BISH`^VHj=18enQP@N20D3
jK^K19emLPBINV/4Tf]O19QfL@BINW04TEY90g];<PB1<BD4APd61;R6N@BKUXD4VX1j0ijXZ@BIOG@4
VHIo18aSF@BOVYD4TFMH185jN@=79R84?2HT14XF3PBaEC`4TfaI19U_F@>CKV<4RUe<18EJC0B9E4H4
RF=C18F7S@B@OX83YIf[1:ZTUb^ISXdEoooo000Doooo29V>S@BIRHP4VHf<;YV>S@B=OXH47PP50nVk
V`BMOG84VGY[19=[G`BHMW44VGY`195JB@=kBc84PC4U14H=1PBhQWT4ViJ519Z0NP>NZ:T4VGed19V6
O`B<HeT4WiZE195WF0B1NWT3AbHR13`V90A:5Ph4/EDl19=/F@BIKeT3TfiS18YMC0B5FT`4REA618US
D`B5Qhd4T7j20jFMZ`BZY9L[VHj=5Oooo`005?ooocZISXd4GdHm14dX90AmEe03WHEb19QiJ@BILV84
VGYY19V3M`BINW04Qd]00gYHA@Ab>S<4APX@17dh>PB=HU84T69G0iYlLPBPJF04TWMS199?@`BEEdT4
SEU919nEOP>4CCl4LUEA140/90A?2P44_WQT19QgFP>HMfT4Rem=18EJCPB5FD/4SUm@18A`HPB9R903
M69a1:bYX2^ISXdEoooo000Doooo>YV>S@AOASd4CBPT17eGD0>MQG84V7UY19UbHPBINVT4VH=g19Uj
L0B7Bd03NUQ5178j<`A62Q04OCPj18eRDPB@HUL3VWab1:1YH0BBMf<4TTm319EGB@B=FDT4WiEn0hA=
?`AbEE44@2`T14l:0@BnN6@4V7MJ0iQgJ@B;Gdd4QEY>18EIB`B>Ge04Q71R18V8T0=dHW44[:VP:iV>
SAGoool001CoooljVHj=15m6?@A=:2@4OEM@0if5LPBHNFT4VG9R19UjJ@BIPgL4VGY`18M;@0=jF4D4
LSXc14H:40Am>3X4SF9B191RE`>JO784X6UP199gH`BBCd<4UEM918eIB@BOUGh3Q4do179ED@A0;2@4
C`X11;ihI0BHMeX3V7MY18]OC@B5FTh4QEU;18iOD0B4L684RHR@0gARL@B/ZJ0[VHj=5Oooo`005?oo
oaBISXd3VHZ:19VCTQ^ISXd4SGYn11P70`@b4`l4g:6@0i9aH0BIMVH4VFUS19EiH@BNO6`4VFeV18MJ
AP>2DSd4[I^A19QlK@BIIf84Tf=M18eQF@>;F544TDi:18=8A@B6AD44PcLa18<k>PB3ETP3RDI017E1
=`AQ<R@4@Q<>17`/7`BaS6l3WWYX18]TC@B5ET/4PEM918eSD`B9J5P4ESH/0mkIj@B@Q8H4WYVG9iV>
SAGoool001CooolDVHj=0iV:RPBITi8KVHj=18ejOP@H1`<4<Q<?1=bQT0>BLF04VGIV19UYH`BENF44
WWa/19U]IPB7FTH3PU8m1:fKT@BHO6d4VFMR19=SG@B=HET3ReQA195>BPB3B4D4QTE118<g<@B3>cX4
PeI80hU6@0Ae@CL4HC8T148C3PAl;1l4/Ha_0iijJ0B;I4d4QEI;185GB@B=He<4RFQH15Hf;0?NfNT4
T8B619jIUbNISXdEoooo000Doooo59V>S@>IRXX4VI>B6iV>S@B=NWh460L3138C3`CLXI03TW5P19Uf
IPBIJF<4UGUQ19ilK0BIKFH4QeY60h9B?@B]Vi44V7a]19UWHPBCHed4SF5I0h]HD@BACTX4PdQ518I5
@@B3=c44Pc/j18=FB0>9AT04MD4g164b90A24`h4O2`O1;6<K`>NNVP4RfA=18EFB`B1EdT4SF=C18UX
F0AF=R`3g]WY1924QPBNVILWVHj=5Oooo`005?oooaBISXd3VHZ:19VCTQ^ISXd4SGYn11P70`@b4`l4
g:6@0i9aH0BIMVH4VFUS19EiH@BNO6`4VFeV18MJAP>2DSd4[I^A19QlK@BIIf84Tf=M18eQF@>;F544
TDi:18=8A@B6AD44PcLa18<k>PB3ETP3RDI017E1=`AQ<R@4@Q<>17`/7`BaS6l3WWYX18]TC@B5ET/4
PEM918eSD`B9J5P4ESH/0mkIj@B@Q8H4WYVG9iV>SAGoool001CooolDVHj=0iV9R0BISH`KVHj=17eW
LP@M4@P4000<185^I@>NOVl4VG5S19U_J@BCIV84V8M]19U[IPB7DTP3NdLi1:28M`BNR844VGme19Ue
K0BIOW@3VGme19UYG`B@KEL4U6YL18]SD0B?GTl4PEE40i18A@B7AS`4MC<_15hV90AM8bD4R5Pl0iid
J@B@IU04QEI;185HAPB=Fdl4RF=D12hM7@?2Zj@4ZZ>W19R<RbNISXdEoooo000Doooo59V>S@>IRHP4
VHf<6iV>S@AmIg847A48100030B1KVD3WWi_19UaH`BIKfT4TfIR19R7K@BIJfH4Qe980g]7>@BPR7L4
WXR119UoM@BIMF`4VGid0iUoM@BIJEl4T6eG19AZG0B;He04Sei?185EA0>@B4D4QdHl17Dc;`AN9R@4
GB<U18QH?0>NM6T4T6I@18EFB`B1F4H4SE]?18USE0@^7Ad3`Z^T1:ZSY`BHS8/WVHj=5Oooo`005?oo
oaBISXd3VHV819V=S1^ISXd4OFMb11dA20@000`4PFiU0iinK`BILF<4VFmY19=VHPBHQfd4VF]V18MB
B0=kAcT4X8Qg19j8P@BIOgD4VGE/19UnM0>IOgD4VFUO191]E`BDJU`4Rf=@18mNC`B1ED@3T4Q518M6
?0Ae<bl4GRHT15dS9@B8F3`3WWAY191VD0B5ET/4PEQ618eKC`B9He@4;QdM0l:[Y0BZXjL4V8b;9iV>
SAGoool001CooolDVHj=0iV9R0BISH`KVHj=17eWLP@M4@P4000<185^I@>NOVl4VG5S19U_J@BCIV84
V8M]19U[IPB7DTP3NdLi1:28M`BNR844VGme19UeK0BIOW@3VGme19UYG`B@KEL4U6YL18]SD0B?GTl4
PEE40i18A@B7AS`4MC<_15hV90AM8bD4R5Pl0iidJ@B@IU04QEI;185HAPB=Fdl4RF=D12hM7@?2Zj@4
ZZ>W19R<RbNISXdEoooo000Doooo=YV>S@B8JfT4UGYd19=_H@B?JUP3VGUY19ijJPBINFh4VF]V19Uj
K@BIMFH4RV1@0hA>@`B>HE44YIB419j7P@BINW04VGE/0iV2N0BIJ604T5iC191NC`B@KUT4QeY:17iH
B@>:Dcl4QEA418EIA0B5DD@4P59418aQD0>BIeH4Sf5?185EA`B5FdT4RF1;18YOD`@T51<3e/;:19nG
RR^ISXdEoooo000Doooo=YV>S@B8JfT4UGYd19=_H@B?JUP3VGUY19ijJPBINFh4VF]V19UjK@BIMFH4
RV1@0hA>@`B>HE44YIB419j7P@BINW04VGE/0iV2N0BIJ604T5iC191NC`B@KUT4QeY:17iHB@>:Dcl4
QEA418EIA0B5DD@4P59418aQD0>BIeH4Sf5?185EA`B5FdT4RF1;18YOD`@T51<3e/;:19nGRR^ISXdE
oooo000Doooo=YV>S@B8JfT4UGYd19=_H@B?JUP3VGUY19ijJPBINFh4VF]V19UjK@BIMFH4RV1@0hA>
@`B>HE44YIB419j7P@BINW04VGE/0iV2N0BIJ604T5iC191NC`B@KUT4QeY:17iHB@>:Dcl4QEA418EI
A0B5DD@4P59418aQD0>BIeH4Sf5?185EA`B5FdT4RF1;18YOD`@T51<3e/;:19nGRR^ISXdEoooo000D
oooo=YV>S@B8JfT4UGYd19=_H@B?JUP3VGUY19ijJPBINFh4VF]V19UjK@BIMFH4RV1@0hA>@`B>HE44
YIB419j7P@BINW04VGE/0iV2N0BIJ604T5iC191NC`B@KUT4QeY:17iHB@>:Dcl4QEA418EIA0B5DD@4
P59418aQD0>BIeH4Sf5?185EA`B5FdT4RF1;18YOD`@T51<3e/;:19nGRR^ISXdEoooo000Doooo<YV>
S@BEQXH4WWAL19EbIPBFMF<4SH220jUiGPBHOG84VGic19UiK`BIOW@4VGY`19=QF0>9Hdl4Q4i219Mk
JPBMS8<4VH=i19UZI0>ER7<4WWm`18aMD0B@Fdd4Qe8o18MXE0AgBcd3OUDo17m>@PB3EC/4Nd/n17m<
>@BFKEh3SVAE18]MCPB2E4L4Q5I818AOC0B8H5043`<60mVk^0Bc/KH[VHj=5Oooo`005?oooc:ISXd4
UHJ619idG0BELVH4UWES18f0PP>YNEh4V7eb19UnL`BINFl4VGid19UjL0BCHEP3RF=?18A>@PBGNfX4
WHb319V3N@BIJV@3UHQc19ioL0B<GE04T5]=18MB?`B7J5@4Md/m0giE?`AoCT84PeDk17];?PAoC3T4
UVeN0hiTE@B;GDh4PUA718AFB0B4Gd`4R61@10l31P?I^kP4/k6f:iV>SAGoool001CooolbVHj=19F6
QPBNM5`4UG9V19IeH`B=P883ZGUN19QmLPBIOW<4VGU_19UnM0BINW04Tf5H0hUSC`B4CT84Ug]Z19f<
P`BIPgT4VFYT0iF8L`BNOg04S5e@191KC@B7DSl4QfQD17M;?@=nECl4Odi218=E>`AkBch4Od`i19I]
GP>>I5D4Ree>189DA`B4ETP4Q5m<18QPD0@?0`H3fK^h1;>a]R^ISXdEoooo000Doooo<YV>S@BEQXH4
WWAL19EbIPBFMF<4SH220jUiGPBHOG84VGic19UiK`BIOW@4VGY`19=QF0>9Hdl4Q4i219MkJPBMS8<4
VH=i19UZI0>ER7<4WWm`18aMD0B@Fdd4Qe8o18MXE0AgBcd3OUDo17m>@PB3EC/4Nd/n17m<>@BFKEh3
SVAE18]MCPB2E4L4Q5I818AOC0B8H5043`<60mVk^0Bc/KH[VHj=5Oooo`005?oooc:ISXd4TgEY19Ql
M0B<HDl4S6=A18eoN@>JJfL4VHMf19V2N0bIOgD4VFQP0i=RE`B6ETL4U5mC1:>CRPBIPWP4VFQT0i=b
I@BHNFT4RUe@18YNC0B0BSl4PeU;17M5>0=oCch4OeA518QIA@B3Dd44PEM518aQDP>;FD/4Ree>18AH
BPB0DTD4Q5m;18UOD`@@1@H3HClh1?Wal0BITi8WVHj=5Oooo`005?oooc:ISXd4TgEY19QlM0B<HDl4
S6=A18eoN@>JJfL4VHMf19V2N0bIOgD4VFQP0i=RE`B6ETL4U5mC1:>CRPBIPWP4VFQT0i=bI@BHNFT4
RUe@18YNC0B0BSl4PeU;17M5>0=oCch4OeA518QIA@B3Dd44PEM518aQDP>;FD/4Ree>18AHBPB0DTD4
Q5m;18UOD`@@1@H3HClh1?Wal0BITi8WVHj=5Oooo`005?oooc:ISXd4TgEY19QlM0B<HDl4S6=A18eo
N@>JJfL4VHMf19V2N0bIOgD4VFQP0i=RE`B6ETL4U5mC1:>CRPBIPWP4VFQT0i=bI@BHNFT4RUe@18YN
C0B0BSl4PeU;17M5>0=oCch4OeA518QIA@B3Dd44PEM518aQDP>;FD/4Ree>18AHBPB0DTD4Q5m;18UO
D`@@1@H3HClh1?Wal0BITi8WVHj=5Oooo`005?oooc:ISXd4TgEY19QlM0B<HDl4S6=A18eoN@>JJfL4
VHMf19V2N0bIOgD4VFQP0i=RE`B6ETL4U5mC1:>CRPBIPWP4VFQT0i=bI@BHNFT4RUe@18YNC0B0BSl4
PeU;17M5>0=oCch4OeA518QIA@B3Dd44PEM518aQDP>;FD/4Ree>18AHBPB0DTD4Q5m;18UOD`@@1@H3
HClh1?Wal0BITi8WVHj=5Oooo`005?oooc:ISXd4VF]E19EfJ`B0BCP4WXAf19EYHP>HNFT4VGIb19V2
N0BIPg`4VGU/19UoM@BIMVP3VG5N18MGB0B?GT`4WX9i19j3O@BINf`3VGih19UeK0B@IEP4QeM918]M
CPB5G4d4PDe00gm>>@AkBD04R5a=199OE0BBIeD4RV5B0hEND0B9F4/8QEQ:18AKB@B8I5@49QXG0bPE
5@AMACl4oooo9iV>SAGoool001CooolbVHj=19U[E@BEMV/4P4Th19j4MPBEJF83V7UY19UfLPBIPWP4
VH=l19UiK0BIOgD4VGIX0iUaGPB7EdP4Sei<19j2N@BNPgd4VG]/0iUnN0BIMF`4T6EH18MGB@B;GDh4
QEa=185=@0=oCST4NdU018QLC@BBGe@4TVME18YQDP>5GU04REQ;28EHBPB4FdT4R6AD12HJ5`<X5AD4
GDDo1?ooobNISXdEoooo000Doooo<YV>S@BIJeD4UGI[1819>0BNQ7H4UFUR0iQiJ@BIMW84VH9h19V3
O0BINF`4VGme19UfJ0>ILEh4QeM818mNC0BNPWT4WX=m19UkK0>IOWP4VGE/191UF0B7EdT4Ree>18EL
C@B1CD03Odhi17]9@0B8G4d4TUmD199WE@B:HE83QEi@18UHB`R5F4X4Q5]918QTE0@V6QL3:1DE15e5
?`CooolWVHj=5Oooo`005?ooobjISXd4VGie195TDPB=DD@4PfI?19:3M@B_M6T3VGIY19UjL`BIPWP4
VHAm19V0M`BIOgD4VGI]0iEfH`B@IEL4SFQG19MeIPBHNFh4UFeS0ij=NPBIKV`4S6iC18IDB@B5Fd/4
PEI618UJ@P=hBC/4RU5018aUE@BBHeP4V6eO18]SE0>5HE84REe>18AMCPB0G4T4R5M;18Q`G`AgAcH3
DC8/13PmB0B3M7<WVHj=5Oooo`005?ooobjISXd4VGie195TDPB=DD@4PfI?19:3M@B_M6T3VGIY19Uj
L`BIPWP4VHAm19V0M`BIOgD4VGI]0iEfH`B@IEL4SFQG19MeIPBHNFh4UFeS0ij=NPBIKV`4S6iC18ID
B@B5Fd/4PEI618UJ@P=hBC/4RU5018aUE@BBHeP4V6eO18]SE0>5HE84REe>18AMCPB0G4T4R5M;18Q`
G`AgAcH3DC8/13PmB0B3M7<WVHj=5Oooo`005?ooobjISXd4VGie195TDPB=DD@4PfI?19:3M@B_M6T3
VGIY19UjL`BIPWP4VHAm19V0M`BIOgD4VGI]0iEfH`B@IEL4SFQG19MeIPBHNFh4UFeS0ij=NPBIKV`4
S6iC18IDB@B5Fd/4PEI618UJ@P=hBC/4RU5018aUE@BBHeP4V6eO18]SE0>5HE84REe>18AMCPB0G4T4
R5M;18Q`G`AgAcH3DC8/13PmB0B3M7<WVHj=5Oooo`005?ooobjISXd4VGie195TDPB=DD@4PfI?19:3
M@B_M6T3VGIY19UjL`BIPWP4VHAm19V0M`BIOgD4VGI]0iEfH`B@IEL4SFQG19MeIPBHNFh4UFeS0ij=
NPBIKV`4S6iC18IDB@B5Fd/4PEI618UJ@P=hBC/4RU5018aUE@BBHeP4V6eO18]SE0>5HE84REe>18AM
CPB0G4T4R5M;18Q`G`AgAcH3DC8/13PmB0B3M7<WVHj=5Oooo`005?ooobjISXd4VF1F18M>?`Al>S84
Q6EC1921L`BJO783VGi^19UeJ`BIPWP8VGme19UkL@BINf`3T75T19Q]GPB?N6P4WGeb19UnKPBCIeh3
V7IX19UUF`B7GTl4PDi1185B@`AlCSl4Q5<n0g]??`B5FD/4S65C18iYFPBHJE/4Rf=D0hENC`B9FD/4
REM=18AKBPB4EdD4SVmS17e7<`>9GE44[l;;19>9R2NISXdEoooo000Doooo;YV>S@BIH5H4Qdho17`j
<PB4IE<4T85c19YlLP>IOVh4VGE[19V2N0RIOgD4VG]a19UkK0>@LF@4V6eN18mhJ0BMOG84VGi^19=W
GP>HMVP4VFEK18MNC`B1CT44PE9317a>?`B4Dch3Ndlo18EIB`B<HE<4SVUJ19QYF`B;He@3QEi?18UI
B`B9Edd4Q5]:18AGA@B>Kf<4ODLc0hUMD@B_`//4ThV89iV>SAGoool001Coool^VHj=19UPEPB7CSl4
O3Xb18AUD`B@PG<4VWab0iUnKPBIMF/4VH9h29UoM@BINg44VG]/0i1aI0BHKEh4SgQX19emLPBIOVh4
TfMN0iQfJ0BIIE/4Qei?185>@@B1DT<4O4ho18AC?P=kCcl4QEU;18aQD`B>JEX4V6UK18]SE0>5GTl4
REU;18UGC@B4FdX4Q5M518i_H`AmAc<3REeA1:o2b`BCRHPWVHj=5Oooo`005?ooobjISXd4VF1F18M>
?`Al>S84Q6EC1921L`BJO783VGi^19UeJ`BIPWP8VGme19UkL@BINf`3T75T19Q]GPB?N6P4WGeb19Un
KPBCIeh3V7IX19UUF`B7GTl4PDi1185B@`AlCSl4Q5<n0g]??`B5FD/4S65C18iYFPBHJE/4Rf=D0hEN
C`B9FD/4REM=18AKBPB4EdD4SVmS17e7<`>9GE44[l;;19>9R2NISXdEoooo000Doooo:iV>S@>IPWX4
VFQQ18M4?`Ai?C44SFMK1:26M@BHNG83VH9h29UjL0BIOgD4UG]/19ioM@BIKFL3T7]R19U/G@BENFP4
WH9k19UnK`BINgD3VGY`19UUG0B7G4L4O5E717a?@0AkCT04MU540hMFA0B<HUH4U6UI19=^G`B?IUL4
T69C0hEQDPB9E4L4REM;18EFB`B5FdT4SFYW17m7=`=oFDX4WI^S1;6`[RNISXdEoooo000Doooo:iV>
S@>IPWX4VFQQ18M4?`Ai?C44SFMK1:26M@BHNG83VH9h29UjL0BIOgD4UG]/19ioM@BIKFL3T7]R19U/
G@BENFP4WH9k19UnK`BINgD3VGY`19UUG0B7G4L4O5E717a?@0AkCT04MU540hMFA0B<HUH4U6UI19=^
G`B?IUL4T69C0hEQDPB9E4L4REM;18EFB`B5FdT4SFYW17m7=`=oFDX4WI^S1;6`[RNISXdEoooo000D
oooo:iV>S@>IPWX4VFQQ18M4?`Ai?C44SFMK1:26M@BHNG83VH9h29UjL0BIOgD4UG]/19ioM@BIKFL3
T7]R19U/G@BENFP4WH9k19UnK`BINgD3VGY`19UUG0B7G4L4O5E717a?@0AkCT04MU540hMFA0B<HUH4
U6UI19=^G`B?IUL4T69C0hEQDPB9E4L4REM;18EFB`B5FdT4SFYW17m7=`=oFDX4WI^S1;6`[RNISXdE
oooo000Doooo:iV>S@>IPWX4VFQQ18M4?`Ai?C44SFMK1:26M@BHNG83VH9h29UjL0BIOgD4UG]/19io
M@BIKFL3T7]R19U/G@BENFP4WH9k19UnK`BINgD3VGY`19UUG0B7G4L4O5E717a?@0AkCT04MU540hMF
A0B<HUH4U6UI19=^G`B?IUL4T69C0hEQDPB9E4L4REM;18EFB`B5FdT4SFYW17m7=`=oFDX4WI^S1;6`
[RNISXdEoooo000Doooo:iV>S@>AHD/4SUe>17A6=0B?D3d4YWi[1:23L@BINW<3VGid19UoM@BINf`4
VGI/191fI`BIL6D4UVeR0iY_I@BDM644U6iP19elL@BINW04VGY_0iUjL0BEJ5l4S4m517a@@`AlCd04
Oe5317mIBP>2Gd`4TV=H18iYEPBDJEX4T6YL18mND0>5GDl4REU<18ECAPB5DTD4Q5Y<18e`H`B1>RL3
SW]/181EC0B[cMXWVHj=5Oooo`005?ooob^ISXd3TF5;18iMCPAdAS@4Se0m1:InJ`BPPg44VGYc0iUn
M0BIOgD4VG]/19UfK0B@MVL4VG1U19I]HP>JKfD4U7AQ19A^H0BMO744VGY`19UjK`>INW04UFQO18a?
A@AlD4<4O4m017mA@`AoFDX3PUm<199SF0B>JEH4U6UJ191ZG0B?GU03QEe?18UIC0B5DdH4QE9518AJ
C0B=L6<4PCXW0hikK0B0ED`4ZlgJ9iV>SAGoool001Coool[VHj=0i5QB`B>GDh4M4Hd18m@?@BVOV/4
X8=a19UjL`>IOW@4VGme19UkK0BIMV`4T7IW19U`I@BFKF83VVmU19AdH@BDKV04WGaa19UjL0BINVl3
VGY`19EXG`B<CdD4O51317a?@0AoDD<4OeU:0h9OC0BBHeP4SVUF19AYFPB@JU`4Sei@0hEMC`B9FD`4
QE=618EBA@B4FT`4SG1S184j9`>>Nf`4P5E<1:_=fRNISXdEoooo000Doooo:iV>S@>AHD/4SUe>17A6
=0B?D3d4YWi[1:23L@BINW<3VGid19UoM@BINf`4VGI/191fI`BIL6D4UVeR0iY_I@BDM644U6iP19el
L@BINW04VGY_0iUjL0BEJ5l4S4m517a@@`AlCd04Oe5317mIBP>2Gd`4TV=H18iYEPBDJEX4T6YL18mN
D0>5GDl4REU<18ECAPB5DTD4Q5Y<18e`H`B1>RL3SW]/181EC0B[cMXWVHj=5Oooo`005?ooob^ISXd3
Pd0Y14XR50A/>Rl4Eb`U1=>MP0BRQGP4VGY_0iUjJ`RINW04VGEV19=dI@BBJV44REiB0hmRE`BALUd4
Wh9`19UnK@BNOWL4VGY`0iUjJ`B@JF04QeU717i<A`B0EC`4Nde118eLC@>8He<4SUa@191XF0BEIEX4
RfAA191ZF@>7GDh4RV1@18EMCPB4DdH4Q5I?18UVEPAi?BT3SEm<18Y=A@B[aLTWVHj=5Oooo`005?oo
ob^ISXd3Pd0Y14XR50A/>Rl4Eb`U1=>MP0BRQGP4VGY_0iUjJ`RINW04VGEV19=dI@BBJV44REiB0hmR
E`BALUd4Wh9`19UnK@BNOWL4VGY`0iUjJ`B@JF04QeU717i<A`B0EC`4Nde118eLC@>8He<4SUa@191X
F0BEIEX4RfAA191ZF@>7GDh4RV1@18EMCPB4DdH4Q5I?18UVEPAi?BT3SEm<18Y=A@B[aLTWVHj=5Ooo
o`005?ooob^ISXd3Pd0Y14XR50A/>Rl4Eb`U1=>MP0BRQGP4VGY_0iUjJ`RINW04VGEV19=dI@BBJV44
REiB0hmRE`BALUd4Wh9`19UnK@BNOWL4VGY`0iUjJ`B@JF04QeU717i<A`B0EC`4Nde118eLC@>8He<4
SUa@191XF0BEIEX4RfAA191ZF@>7GDh4RV1@18EMCPB4DdH4Q5I?18UVEPAi?BT3SEm<18Y=A@B[aLTW
VHj=5Oooo`005?ooobNISXd4VHJ10h52=0@i7QD4>QlH14TU8PC:Ug`4XXEh19EfK0>NOW@4VGYV18eY
G@BLNF/4SVAE19]bH0BGJ5h3UeYC19E[E0BDJeT4Vh1^1:>7O`BINW03VGY[191QE`B1E4@4N4Tm17m<
>`AgDDD4R5A50hEQD@B;G4`4U6=C19AYG0B7EDP4SV=D0hAMC`B0F4X4Q5a=18ACAPB4ETl4Q5m=16<a
80=l=b84W5e61;3:fRNISXdEoooo000Doooo9iV>S@BIQX43PD8d13TN5@@j7aP4BBDR1<ZGO0BRQGP4
UGI/0iinM0BINVH4SFUM19aiJ`B>I5D4Vg9P19MXGP>GFU<4UF]D19A[F@BKP6h4XhMo19UjL0>INV/4
T65G185DA0AhBCd4Od`k17MAA@B8E4D3QF5A18]LC0BDHe<4U6UL18MEB0B>He@3Q5e?181HBPB4G4d4
Q5=618AFC`B4Gdd4Hc4P0g`g8PBLGDH4/<[J9iV>SAGoool001CooolWVHj=19V6P@>1@S@4>AhE13XO
60A99B84bYMl1::5N0BEMV`3WWid19UjIPB=JEd4W7U[18iTE@BKLV04UfQN0iMJD`BEJe@4U6]I19^0
KPBSQgl4VGY`0iUjJ`B@HEL4PEA417Q9?@AoC3/4Me5518QDA@>5HE44Rea<19ASD`BDJE`4QeE818iS
E0>4GDl4P5Q:18ALC@B4DdH4Q5I?18AOC@AS<B03O3LR19aMAPB`b]XWVHj=5Oooo`005?ooobNISXd4
VHJ10h52=0@i7QD4>QlH14TU8PC:Ug`4XXEh19EfK0>NOW@4VGYV18eYG@BLNF/4SVAE19]bH0BGJ5h3
UeYC19E[E0BDJeT4Vh1^1:>7O`BINW03VGY[191QE`B1E4@4N4Tm17m<>`AgDDD4R5A50hEQD@B;G4`4
U6=C19AYG0B7EDP4SV=D0hAMC`B0F4X4Q5a=18ACAPB4ETl4Q5m=16<a80=l=b84W5e61;3:fRNISXdE
oooo000Doooo9iV>S@BEKEd3S5]F12H40@@f5a44?alJ1>JWRPBHO6/4VGIV0iQmLPBINV/4Q61D17AA
A0A`BCX4FS/d15Pa:P=n>bL4X5m;18@l:PB<BS@4a;6K19j3O@>INW04T6EH185@A0AhC3P4Ne8k17M5
>`B=HE43OEY<17MGBPB1EdT4Q5iC17eLBPBGJ5L3RF5B185IB`AlEdT4QEM918iKC`B4Fdd4EbTO0fHX
70B=B3D4[mCL9iV>SAGoool001CooolWVHj=19E]G@><FeH49P@113HG4@@o7aX4iZN:19QlJ`BIMVH3
V7eb19UjJ`B4H5@4M5541719>PAJ>c@4F34Z0ghk9`BPGd/4Q3`Z18a:=0C4/I/4WX=m0iUjL0B@IEP4
PE1417Q<>0AkDS/4MdDk18eQD@=mFT`4MeM:185GB@B4GU<4OEa:19MXE`>9HE84PEU;17aGB@B5EdT4
SU]?18AKC@AG:Al3IRPL18e8=@B_e=`WVHj=5Oooo`005?ooobNISXd4UFeM0haKEP@V1044=QLA13lO
6PCVYhX4V7a[19UfIP>HOG84VGY[18APE0AdDD@4L4Tj15Xk=0AH<BX3OS/W1:1OB`B4?2X4S4Xd1<Ba
V`BNPgd3VGY`191UF0B1D4@4N4`h17]B>`AgAC/4SF5A0geJC0AgEdX4PEM918AND`AmG4X4UfQG0hUQ
DPB1FD/4O5M918EGB@B>Fdl4Q5]=15LY7`=V:1`4SDPe1:oDg2NISXdEoooo000Doooo9iV>S@BEKEd3
S5]F12H40@@f5a44?alJ1>JWRPBHO6/4VGIV0iQmLPBINV/4Q61D17AAA0A`BCX4FS/d15Pa:P=n>bL4
X5m;18@l:PB<BS@4a;6K19j3O@>INW04T6EH185@A0AhC3P4Ne8k17M5>`B=HE43OEY<17MGBPB1EdT4
Q5iC17eLBPBGJ5L3RF5B185IB`AlEdT4QEM918iKC`B4Fdd4EbTO0fHX70B=B3D4[mCL9iV>SAGoool0
01CooolSVHj=19fBT@B>F4@3PU1511`>40@O30T4>QHC1>:dU@BHN6T4U71R0iimK@BINVX4Tg5W16e8
>`A]DTX4:QdJ12dC4@=;7a@4JD@j18Tk:PAnBCh4UWQY19f0NP>IOGH4T6A@185=@@A`A3@4O54g154C
2@B/NV03RU/o185GB@AhAS@4WVIF17aJC0BAHTd3RV1C18EMCPAcCd44NUY;18aJC`AlET@4EbPP0gLh
:0BCBd44[/K;19>9R2>ISXdEoooo000Doooo8iV>S@BMTY44SUQ40h9@A@@L3Q047``913XF4`CR]9D4
V7QY19A`HP>NOFd4VGYZ19=aI`A]B3/4KE9:12XM6P@]4a43BalD16U4>PB9>bX4OTTn19IhJ@BMP7X3
VGef191TD0B1CD44L4@d17aA=`AA4`T4[7YP0hYK?`B1EdT4N4Hd19iVEPAlFT`4TF9=0hYPD`B5GDh4
Ldm117YJB`B<FTl4O5I415LX80=g>2P4Td]11:k6b`BCRHPSVHj=5Oooo`005?ooob>ISXd4WI:A18iH
A0>2D4D470h@11l<2@@j5Q<4h[BE19QhJ@BDL683WWe]19UjJPBCLFL4KDPk16eBBP@Z7AX4;A<A0d/O
50AYA3X4RC/Z17i9?PBFN6T4WH1j0iUmMPB@I504PDe11714=0AlDCL4DA<91:ajH0>:Fcl4PEM917Q6
=0BNIUH4O5Y<195RC@>:H5<4QEe>17=?@@AjFT/4S5Y?17aFA0AG:203McPX19=;@@B^a//4ThV88iV>
SAGoool001CooolSVHj=19fBT@B>F4@3PU1511`>40@O30T4>QHC1>:dU@BHN6T4U71R0iimK@BINVX4
Tg5W16e8>`A]DTX4:QdJ12dC4@=;7a@4JD@j18Tk:PAnBCh4UWQY19f0NP>IOGH4T6A@185=@@A`A3@4
O54g154C2@B/NV03RU/o185GB@AhAS@4WVIF17aJC0BAHTd3RV1C18EMCPAcCd44NUY;18aJC`AlET@4
EbPP0gLh:0BCBd44[/K;19>9R2>ISXdEoooo000Doooo19V?S`BITi84VHZ:19VCTQ>ISXd4?10;1?f^
S0>;HeD4<1PF11d?5@@]40/4lkbL19UiJ@BINVX3U7EV19YjJPBNOWL4Q5m@18iLD`A<>SD4:b8T0b`J
5`A8=Rh4M4e218eJD0BGOF`4WH^30iV4O@B@Je/4PE5416i2<PA/ACL4CB0I16e<AP=M>2/47@<418<o
;@A/Bc`4EB/N19MOB`>6D3D4WF5;17QJCPAjEDL4S5I;16M7>@A57aP3J34U1;I_G@B__/X4UHZ98iV>
SAGoool001Coool4VHn?19VCTPBIRXX4VI>B4iV>S@@l40/4oJj<0h]SE@@`61H47@lE12d@2`Cc_9`4
VGUY19UjJP>DMFH4VWYZ19inM`B4Ge04SUaC14`j=@@[8R@3;1XG14Pf;PAdCD84SEY@19MmK0BMRh<3
VHAm191[F`B1DD@4KT8b16a5=`A=81T4KDa60edh:`@M0`@4Pcl]16a;?0AE:ah4Uem;0hI@=@BMHD/4
N5Y>17YEA`B<ET/4IdLi14DO60=X<BD4]VmM1:nnbPBERXTSVHj=5Oooo`005?ooo`BIShl4VI>B19V:
RPBITi8CVHj=13`@2`Cm[X`3Rf=E130H5P@M3aD4;A0;1?>lW0BINFT4VGYZ0iAeIPBJNVX4WWig18AO
D0B>G5<4C3Xe12/R90</6QL4B3H^17A=@PB=FU04Uge/19f;P`>IQ7d4T6]K185AA0A^@S84K4Dg14dP
6@A]C4H3GCP[11d310B3?bd4K4/l15D[7PBGGd/3QU0e19eQB`AhFTh4NUE718aFB`AWAcT4AAlH0fPa
9@BfKed4[kk:19F:RB>ISXdEoooo000Doooo19V?S`BITi84VHZ:19VCTQ>ISXd4?10;1?f^S0>;HeD4
<1PF11d?5@@]40/4lkbL19UiJ@BINVX3U7EV19YjJPBNOWL4Q5m@18iLD`A<>SD4:b8T0b`J5`A8=Rh4
M4e218eJD0BGOF`4WH^30iV4O@B@Je/4PE5416i2<PA/ACL4CB0I16e<AP=M>2/47@<418<o;@A/Bc`4
EB/N19MOB`>6D3D4WF5;17QJCPAjEDL4S5I;16M7>@A57aP3J34U1;I_G@B__/X4UHZ98iV>SAGoool0
01Coool4VHV819VBT@BIRHP4VHf<3iV>S@A06aH4>ATD14d600>CDC`4<1@J12HB3P@d5A84iKNG19Ae
IPBMOG83R5Q;19IkI0BYT8L4TgU[18eQE0AmDDD4NE510gA@@@A`ASP4Q61:191TF@BCLV84WHZ20iUo
M@B@HUD4PEa;17Q3<@AbCS/4KcT`16MBCP=4<c042@45150P50AC=2h4=QhH17Q4<@=fBCP4R5Y417I=
@@AfFT/4S5]8140Q7`A18QL3DR8H1;AI@`Bgg^L4VXn>8iV>SAGoool001Coool4VHV819VBT@BIRHP4
VHf<3iV>S@A06aH4>ATD14d600>CDC`4<1@J12HB3P@d5A84iKNG19AeIPBMOG83R5Q;19IkI0BYT8L4
TgU[18eQE0AmDDD4NE510gA@@@A`ASP4Q61:191TF@BCLV84WHZ20iUoM@B@HUD4PEa;17Q3<@AbCS/4
KcT`16MBCP=4<c042@45150P50AC=2h4=QhH17Q4<@=fBCP4R5Y417I=@@AfFT/4S5]8140Q7`A18QL3
DR8H1;AI@`Bgg^L4VXn>8iV>SAGoool001Coool4VHV819VBT@BIRHP4VHf<3iV>S@A06aH4>ATD14d6
00>CDC`4<1@J12HB3P@d5A84iKNG19AeIPBMOG83R5Q;19IkI0BYT8L4TgU[18eQE0AmDDD4NE510gA@
@@A`ASP4Q61:191TF@BCLV84WHZ20iUoM@B@HUD4PEa;17Q3<@AbCS/4KcT`16MBCP=4<c042@45150P
50AC=2h4=QhH17Q4<@=fBCP4R5Y417I=@@AfFT/4S5]8140Q7`A18QL3DR8H1;AI@`Bgg^L4VXn>8iV>
SAGoool001Coool4VHV819VBT@BIRHP4VHf<3iV>S@A06aH4>ATD14d600>CDC`4<1@J12HB3P@d5A84
iKNG19AeIPBMOG83R5Q;19IkI0BYT8L4TgU[18eQE0AmDDD4NE510gA@@@A`ASP4Q61:191TF@BCLV84
WHZ20iUoM@B@HUD4PEa;17Q3<@AbCS/4KcT`16MBCP=4<c042@45150P50AC=2h4=QhH17Q4<@=fBCP4
R5Y417I=@@AfFT/4S5]8140Q7`A18QL3DR8H1;AI@`Bgg^L4VXn>8iV>SAGoool001Coool4VHN719V=
S1NISXd4604013XN5P@a3Pd3?1dH11T520@e5a84=Q@A1>:aTPBHNFT4U7U]0heMF`AjCd44QUM71:1k
I`B@K5X4PU=917To<@>4CCH4SU0k191A>`BdSGL4Wga/19f1NP>IOg04T69I185SE0AhAcP4Ne0g17YF
?PB=GDl3Ne5711lO90@Y71d4>bDQ13d/9PAWAc/3Ld/g17UHC0B9F4D4NUI;17YFA@@]5A04=1DB0e0R
5`BM>2L4^n;Z9iV>SAGoool001Coool4VHN719V=S1NISXd4604013XN5P@a3Pd3?1dH11T520@e5a84
=Q@A1>:aTPBHNFT4U7U]0heMF`AjCd44QUM71:1kI`B@K5X4PU=917To<@>4CCH4SU0k191A>`BdSGL4
Wga/19f1NP>IOg04T69I185SE0AhAcP4Ne0g17YF?PB=GDl3Ne5711lO90@Y71d4>bDQ13d/9PAWAc/3
Ld/g17UHC0B9F4D4NUI;17YFA@@]5A04=1DB0e0R5`BM>2L4^n;Z9iV>SAGoool001Coool4VHN719V=
S1NISXd4604013XN5P@a3Pd3?1dH11T520@e5a84=Q@A1>:aTPBHNFT4U7U]0heMF`AjCd44QUM71:1k
I`B@K5X4PU=917To<@>4CCH4SU0k191A>`BdSGL4Wga/19f1NP>IOg04T69I185SE0AhAcP4Ne0g17YF
?PB=GDl3Ne5711lO90@Y71d4>bDQ13d/9PAWAc/3Ld/g17UHC0B9F4D4NUI;17YFA@@]5A04=1DB0e0R
5`BM>2L4^n;Z9iV>SAGoool001CooolOVHj=11X200@Y30P4:18>0bhB3P@T3P`49A0=14DT8@C?TgL4
ZH9`19=iJ@>HNG84R6MJ16]4>0AY?3D4GDLo17I:?`A<<BT3F3`b15lf;0AhBcl4Rg5R19EeJ`BHNFh3
VFeS191bF`B1GU04N4@o16Da7PAg@2X4VgIA0hiPD@B4G4/4OUA:16E4=PAQ?CH4Q5=20g]B@PB4ET/4
NUY518iPB`AWAc/470/912PA3@>=CSh4HB0G1<CNiRNISXdEoooo000Doooo7iV>S@@J0P04:@`812PB
3P<^4Ph490h<12D@3@A59244ci=g1:V2L0BCNFT3V7Ub18QWFPA[A3P4JC`e15e7?`AfBSl4C34Y0ePl
<PAO=R`4N4/o18]aHPBEMF/4V7U^0iU]H`B@LU/4PEi@17Q4?`AU<Ah4Md0Z19]fD@>>H544Q5a;17iD
BPAUA3H4HCdf18AC@P=kDT84Q5I;17YJA@B>H4/4IdLk11`;2@@X4@d3SDhn164P5`C4g^HWVHj=5Ooo
o`005?oooanISXd46P8012T<20@X4Ph3;Q8>12@>30@U40d4AB@Q1<nCM`BYPW04TgUY0iQiLPB8IeX4
Jd@h16Tl=@AMAcl4MTXo14`a:@=H?384GcH/17Q;?`B;LF84UGE[19QiKP>IKF<4T79K185ND0AhA3l4
IC4N17M0:PBKMU43SV1A18ALB`AnE4X4ID@f164m=PB4Dd83Ne9218AFB`AjFTD4SV1;16M7>`@L2`T4
:14=0he>?PAQ81L4a=kV9iV>SAGoool001CooolOVHj=11X200@Y30P4:18>0bhB3P@T3P`49A0=14DT
8@C?TgL4ZH9`19=iJ@>HNG84R6MJ16]4>0AY?3D4GDLo17I:?`A<<BT3F3`b15lf;0AhBcl4Rg5R19Ee
J`BHNFh3VFeS191bF`B1GU04N4@o16Da7PAg@2X4VgIA0hiPD@B4G4/4OUA:16E4=PAQ?CH4Q5=20g]B
@PB4ET/4NUY518iPB`AWAc/470/912PA3@>=CSh4HB0G1<CNiRNISXdEoooo000Doooo29V>S@BIRXX4
VI>B3iV>S@@P1P<490P512D@3@<S40`45@4212dB3PA4:BD4/g]R1;:8M@BNPW43VGYc19UnM0BCM6H4
PEE>1655A@AgC4T4LTDl0g17?@AY?cH4Odi118a[G@BMPG/4UG5T0iY/I`BEJeh4QF=E17iAC@AF;BP4
A1`I15Xb80=N<b44[VI;19e^F`B5G4H4NeQ817YFB0>0Dd<4MU5418mMD`B2FTD4@2<J128>30@_7QX3
UdTd16TX6PAOCTT4n__l8iV>SAGoool001Coool8VHj=19V:RPBITi8?VHj=12060`@T20D49A0=0b<@
30@E0@84;A8>14@Y9@BcNf84/XQe19j2L@>INW<4VGid19=dIPB1EDh4HDE517M<B@AbAC`3L4Lm16To
=PAoCT44S6]M19f1N`BELF@3VVaW19E[GPB5HeD4OU5=15H]:0A471T4FS8P0ehc8@B^IT/4WFiK18EL
APAkF4P4NUI80h1C@`AfDD@4SeeC189JA@A08aX48Ph<12lN6P>GBC@4JBPJ15m>B@Cjno`SVHj=5Ooo
o`005?ooo`RISXd4VHZ:19VCTPnISXd480H312@81@@U40d38a0<11D10P@]4Ph4A2TU1;=kHPBbR7D4
WX9a0iUjL`BIOW@4TgAV185ECPAQADD4Mda91795?0=`Acd4JClf17m>@@B<Jed4WH5k19EaI0>JK6L4
UF]N18ESE@AnDDd4ERdX14@L6@AJ<R03GS<Q1:iVB`BMKU/4QEa617]HB0AjETP3P5=317IAA0B?GE<4
PUY5140S6P@R3P`4;ahJ0iM9=0AY:1X4Gdi91?[ko2>ISXdEoooo000Doooo29V>S@BIRXX4VI>B3iV>
S@@P1P<490P512D@3@<S40`45@4212dB3PA4:BD4/g]R1;:8M@BNPW43VGYc19UnM0BCM6H4PEE>1655
A@AgC4T4LTDl0g17?@AY?cH4Odi118a[G@BMPG/4UG5T0iY/I`BEJeh4QF=E17iAC@AF;BP4A1`I15Xb
80=N<b44[VI;19e^F`B5G4H4NeQ817YFB0>0Dd<4MU5418mMD`B2FTD4@2<J128>30@_7QX3UdTd16TX
6PAOCTT4n__l8iV>SAGoool001Coool8VHj=19V9R0BISH`?VHj=12491`@^51449Ph;0bL@30@J2@H4
:Q0=14@Y9@BVJe<4ZXEc19f1L0>INW<4VH9h19UoM@BIPg`8VGec19UiK0>IPg`4VGU/19UjK0BCLEh4
V7eb19=fJ0>?KEh4U6aM18m`H@B=JU`4PUYA150d<`@l8b43:QhJ14hU6`AM<R84RTXh17=B?PB3BSD3
NTLe199SE`B0EDL4P59412@>30@W40`4<1PI0dTA2PA/7A04ACDa1>3MgB>ISXdEoooo000Doooo29V>
S@BIRHP4VHf<3iV>S@@Q2@L4;Q@A12H>2`<W40`46PT612X@3@A4:BD4YV]C1:Z5L`BMPG03VGYc19V2
N0BIOgD4VH=l29UmL`BINF`3VH=l19UiK0BINV`4Tg5N19QmLPBCMVP3SfeN19A/G@B?L644SFYL189J
D@A@=3<4?2<Q0bXN6PA>9A/4GC8R18Y:>0AcDSh4PdXe0gY7=@BBHeL4P5E7181BA0@T3P`49a0<130H
6@=94@X4K1d@14De<@CPgMdSVHj=5Oooo`005?ooo`RISXd4VHV819V=S0nISXd48@T712hD4@@V3P/3
9a0<11X91P@Z40d4A2TU1:I[D`BZQG<4WH5`0iUjL`BIPWP4VGme19V3O0RIOG<4VGU/0iV3O0BINF`4
VGY/19=aGPBHOG84TgIX0hm]GPBDK5d4Sg1Q18eZG0B2FU44D3@c13`S8@<Z7QX4CRDK15db8PB:BSP4
Le8n18=:=@=jAcD4TV=G181EA`B0DT@490h<12L@30@`61T3BA4:16`M40A5=C44h=gM8iV>SAGoool0
01Coool8VHj=19V9R0BISH`?VHj=12491`@^51449Ph;0bL@30@J2@H4:Q0=14@Y9@BVJe<4ZXEc19f1
L0>INW<4VH9h19UoM@BIPg`8VGec19UiK0>IPg`4VGU/19UjK0BCLEh4V7eb19=fJ0>?KEh4U6aM18m`
H@B=JU`4PUYA150d<`@l8b43:QhJ14hU6`AM<R84RTXh17=B?PB3BSD3NTLe199SE`B0EDL4P59412@>
30@W40`4<1PI0dTA2PA/7A04ACDa1>3MgB>ISXdEoooo000Doooo7iV>S@@P2`X4>b<P11`<2@<Z40`4
9@l<12`D5@A29b84Tee61:n2KPBYRgT3VGY_19UnN0BIPgT4VHAm19V:Q`BIQ7h4VGme0iV3O0BINfh4
VGme19UjK0BIMF84VGYZ0i1YF`BDJed4U6YL19AeI0BDIf44QFII17mEC@=M?SP4?R`Y13LU8@A=:R<4
E3T^16i7>P=NA3T4PdY7185MB@AhBc`48P`;12H?30@T4@h38PX714<F4PAB=C04hMkN8iV>SAGoool0
01CooolOVHj=120;2P@k8b0470`90bX@30@U3``4;1@E148W8PBCGDH4[h9^1:V;N@>INVl4VGih19V3
N@BIQ7d4VHZ719V4OPBIOgD3VH=l19UkKPBIOgD4VGY/19UeHPBINVX3T6UK19A[G@BDJU`4U7ET19AW
H@B5IUT4OeE=0edn>0@n;2T4=bDQ14dZ8`AD>Bh4KTLj0ei4>@B3BTL4PEe917Q;?0@R30/49Pl<12@A
3P<R2PL4@aHB158e<0CQg]hSVHj=5Oooo`005?oooanISXd480/:13/S80@L30T3:Q0<12D?30@/51D4
@RLR19=MAPB_PVh4ZH]i0iUjK`BIOWP4VH=i19V4O@BIRXL4VHAn19UoM@>IPg`4VG]^19UoM@BINV`4
VGER19UjJP>@JE/4U6]M19AZG0BDMF@4U6MQ18EVF@AoEDd3GChh13h/:@@g9B44CBXS15@i;PA^AcX3
GT@i18=:A`B1GDT4N4/l128<2`@V3``4914>0b8:1`A35Q84DSD`1>7NgR>ISXdEoooo000Doooo7iV>
S@@P2`X4>b<P11`<2@<Z40`49@l<12`D5@A29b84Tee61:n2KPBYRgT3VGY_19UnN0BIPgT4VHAm19V:
Q`BIQ7h4VGme0iV3O0BINfh4VGme19UjK0BIMF84VGYZ0i1YF`BDJed4U6YL19AeI0BDIf44QFII17mE
C@=M?SP4?R`Y13LU8@A=:R<4E3T^16i7>P=NA3T4PdY7185MB@AhBc`48P`;12H?30@T4@h38PX714<F
4PAB=C04hMkN8iV>SAGoool001CooolOVHj=12D;20@n8AT4:QLE0bD>2`@]2`L4<QHD140S6@AZ@cD4
]GeU1:R=NP>NOVh4VGYc19V2N0BIPg`4VGme19V:Q`NIQ7h4VG]^19UoM@BINf`4VG]a19UfHP>@JE/4
U7ET19A[G@BDJU`4U6]P18]VF0B9HU<3Oei?17IDA`AbDdL4GSlf1650=`AeB3`3NEE;17i?A@AfDD<4
ECDV12PA40@V3``4<1@A0ah>2`@/40d4BRLL1<>//0Bk_k`OVHj=5Oooo`005?oooanISXd49@/813hQ
6@@Z5aD39@h;12d;1`@b5Q@4@2<I16Y3=@BeOFD4Z8ej0iinKPBINW<4VH9h19V3O0BIOgD4VHZ71iV4
OPBINfh4VGme19UkK0BINg44VGIR0i1YF`BDMF@4U6]M19AZG0BDJf04RfIH18URD`=oGTl4MUA7179C
A`AN?cH4HD0g17E8?0=iED/4OTm517IA@`AE=BH4:14@12H?30@`51437Ph;12`@3@A:9a`4`jb`1;^o
_1nISXdEoooo000Doooo7iV>S@@U2`P4?R4I12XG5@<U3P/4;@/7138F50A08aT4JT<e1;EmI@BXSGX3
WWi^19UjL`BIPWP4VH=l19UoM@BIRXL7VHAn19UkKPBIOgD4VG]/19UkL@BIMV83T6UK19AeI0BDJed4
U6YL19A[H0B;IUP4RF9C0gmNC`AfE4L4LU=715ho=PAQ@3L4MDPl0gUEB`AnCdD4MU5315De9P@X4A04
9Pl<130D4@<N3P/4;10=14XW70C3[;04^knl7iV>SAGoool001CooolOVHj=124810A2:2@4;AHC0blC
40@M2PH4;a4>12lC3PAK;b84TEPl1<:LRP>MPW44VGYc19V2N0BIR8D8VGme19V:Q`NIP7L4VGme19Uf
I0BINVl4UFiP0iE/GPBDJU`4U71P19A[G@BDJU`4Rf=D18]NC`>;HE84Q65C18AHBPB9GDh4P5a=17aC
AP>5ET/4QEI917=7>0@g7AP480/7134F5`@P2``380`711H10`A16aD4UFiW1<_?dQnISXdEoooo000D
oooo7iV>S@@Q20@4@RPT12dF4`<_4a047@X612lA3P@_4`h4FblR195H?0C2W8X3WH9a19UjL`BIPWP4
VHR529UoM@BIRXL7VH1g19UoM@BIMV@4VGY_19E^H0>EK5h4U6YL19A`H0BDJed4U6YL18]SE0B;GTl3
Rf5B18AQD`B4F4X4REe>181LC@AlDdH3QEI;18EFB@AcAcP4=adH120;1`@a5QL480/<0b0<1`@F0@<4
@A/E19E^I`C;cm8OVHj=5Oooo`005?oooanISXd48@P4148X90@]5Q<3;a<@11d:1P@_4@h4;a<>15/_
8PBAF3`4`Yb:0if2L@BINW<4VH9h19V8Q@RIOgD4VHZ71iV0M`BIOgD4VGIT19UjK`BEKV03UFaN19AZ
G0BDL604U6]M19AZG0B;He@4Rei?0h]QDPB4HE<4Q5Q:18UMCPB0G4d4O5=60hEFB`B5ETT4LdLh13LM
60@P2`L4<AHG120;30<P30L45P43144K5@BEKVL4bloB7iV>SAGoool001CooolOVHj=124810A2:2@4
;AHC0blC40@M2PH4;a4>12lC3PAK;b84TEPl1<:LRP>MPW44VGYc19V2N0BIR8D8VGme19V:Q`NIP7L4
VGme19UfI0BINVl4UFiP0iE/GPBDJU`4U71P19A[G@BDJU`4Rf=D18]NC`>;HE84Q65C18AHBPB9GDh4
P5a=17aCAP>5ET/4QEI917=7>0@g7AP480/7134F5`@P2``380`711H10`A16aD4UFiW1<_?dQnISXdE
oooo000Doooo7iV>S@@P20@4>bDS13TQ7P<_5Q<4:a4?12D?30@b6AH4BB/U16Hk:PC5R6l3ZH]h19Un
M`BIOW@4VHV119V:Q`BIOgD4VH=l0iUkKPRIOgD4VGIX19EfHPBEKUl7U6]M19AZG0B@JU`4UFIG191V
E`B5GTl3RF5B18UTE@B4GTl4Q5Q:18ELC@AcDdH3PUI8179B@`AA<bT4:a<@12/G50@H1@L480`>0a@1
0P@N2``4;A4=17mJD`CAcllOVHj=5Oooo`005?oooanISXd480P413/U8`@i8Ah3;aHC12/A3`@U3``4
<QTF14T[9@AV>bX4aHQ_0jV;N0BIOWL4VGid19V9P@BIRXL4VGme19V3O0>INfh8VGme19UfJ0BEMV84
UFiO1iA[G@BDJU`4T6YL19EVE`B@IUL4QEi?0hUQDPB9I5D4Q5i?18AHBPB5G4d4Le=60h9FB0AbDT<4
DC<Y12/C40@[5a@460D7120<3P<D0@847P/<12dA3@AoFU<4dLo?7iV>SAGoool001CooolOVHj=1208
10@k9B<4>B4N0blF4`@[4@l49@l<138I5PA9:bD4IS/Z1<F8K`>YRgP4VGig19UnM0BIRH44VHZ719Uo
M@BIPg`3VG]^29UoM@BIMVP4UGIR19E^G`NDJed4U6YL191ZG0BEIUL4T6IG18ENC`>9HE84RFAE18AN
C`B4F4X4QEa=17=CAP>2ETP4LU93154c:@@[4a04:aLD11P51`@P30h3504211h;30@]4@d4OeYC1=7?
canISXdEoooo000Doooo7iV>S@@P20@4>bDS13TQ7P<_5Q<4:a4?12D?30@b6AH4BB/U16Hk:PC5R6l3
ZH]h19UnM`BIOW@4VHV119V:Q`BIOgD4VH=l0iUkKPRIOgD4VGIX19EfHPBEKUl7U6]M19AZG0B@JU`4
UFIG191VE`B5GTl3RF5B18UTE@B4GTl4Q5Q:18ELC@AcDdH3PUI8179B@`AA<bT4:a<@12/G50@H1@L4
80`>0a@10P@N2``4;A4=17mJD`CAcllOVHj=5Oooo`005?oooanISXd48`/8140W8`@o9b<3=QlL12lB
3`@M2PL4>APD14dZ7`AS?Rl4WF9:0jf@O`BNPWH4VGYd19UnM0BIRH44VHZ719V4OP>IOgD4VGU/19Uo
M@BIMVd4TgES18mXFP>@IeT4UFIG19UZH0B;JUL4Sf9C18mUFPB5HDl3RF5B18UMCPB5H504QEe>181C
A0B0FT`3NTho16I2>0A791/4;Q<A11l<20@N2`d46@D70ad:1`@M2Pd4=ADA1:bPW@B:NgXOVHj=5Ooo
o`005?oooanISXd48`/8140W8`@o9b<3=QlL12lB3`@M2PL4>APD14dZ7`AS?Rl4WF9:0jf@O`BNPWH4
VGYd19UnM0BIRH44VHZ719V4OP>IOgD4VGU/19UoM@BIMVd4TgES18mXFP>@IeT4UFIG19UZH0B;JUL4
Sf9C18mUFPB5HDl3RF5B18UMCPB5H504QEe>181CA0B0FT`3NTho16I2>0A791/4;Q<A11l<20@N2`d4
6@D70ad:1`@M2Pd4=ADA1:bPW@B:NgXOVHj=5Oooo`005?oooanISXd48`/8140W8`@o9b<3=QlL12lB
3`@M2PL4>APD14dZ7`AS?Rl4WF9:0jf@O`BNPWH4VGYd19UnM0BIRH44VHZ719V4OP>IOgD4VGU/19Uo
M@BIMVd4TgES18mXFP>@IeT4UFIG19UZH0B;JUL4Sf9C18mUFPB5HDl3RF5B18UMCPB5H504QEe>181C
A0B0FT`3NTho16I2>0A791/4;Q<A11l<20@N2`d46@D70ad:1`@M2Pd4=ADA1:bPW@B:NgXOVHj=5Ooo
o`005?oooanISXd48`/8140W8`@o9b<3=QlL12lB3`@M2PL4>APD14dZ7`AS?Rl4WF9:0jf@O`BNPWH4
VGYd19UnM0BIRH44VHZ719V4OP>IOgD4VGU/19UoM@BIMVd4TgES18mXFP>@IeT4UFIG19UZH0B;JUL4
Sf9C18mUFPB5HDl3RF5B18UMCPB5H504QEe>181CA0B0FT`3NTho16I2>0A791/4;Q<A11l<20@N2`d4
6@D70ad:1`@M2Pd4=ADA1:bPW@B:NgXOVHj=5Oooo`005?oooaNISXd4VHZ:19F;R`@Q3Pd4@2HR14@[
9`<k8al49`h;12lH5@@a5a@4?b4L17U2;PBAET<3YX9_1:>6M0BINW<8VGid19V8Q@NIQ7h4VG]^19Uo
M@BELV@4WWY[191YF`>?Jed4SFIH18mREPB@IUL4Sei?18]UF@B;GDl3QEQ>18YQCPB5G4d4Q5a=181@
@`AkEDL3Ld@f15hj;P@b6Q<4<1<A11h>2`@Q3``480h<0ad:1P@S40d4=aDB1?[jnPBCRHPOVHj=5Ooo
o`005?oooaNISXd4VHZ:19F;R`@Q3Pd4@2HR14@[9`<k8al49`h;12lH5@@a5a@4?b4L17U2;PBAET<3
YX9_1:>6M0BINW<8VGid19V8Q@NIQ7h4VG]^19UoM@BELV@4WWY[191YF`>?Jed4SFIH18mREPB@IUL4
Sei?18]UF@B;GDl3QEQ>18YQCPB5G4d4Q5a=181@@`AkEDL3Ld@f15hj;P@b6Q<4<1<A11h>2`@Q3``4
80h<0ad:1P@S40d4=aDB1?[jnPBCRHPOVHj=5Oooo`005?oooaNISXd4VHZ:19F;R`@Q3Pd4@2HR14@[
9`<k8al49`h;12lH5@@a5a@4?b4L17U2;PBAET<3YX9_1:>6M0BINW<8VGid19V8Q@NIQ7h4VG]^19Uo
M@BELV@4WWY[191YF`>?Jed4SFIH18mREPB@IUL4Sei?18]UF@B;GDl3QEQ>18YQCPB5G4d4Q5a=181@
@`AkEDL3Ld@f15hj;P@b6Q<4<1<A11h>2`@Q3``480h<0ad:1P@S40d4=aDB1?[jnPBCRHPOVHj=5Ooo
o`005?oooaNISXd4VHZ:19F;R`@Q3Pd4@2HR14@[9`<k8al49`h;12lH5@@a5a@4?b4L17U2;PBAET<3
YX9_1:>6M0BINW<8VGid19V8Q@NIQ7h4VG]^19UoM@BELV@4WWY[191YF`>?Jed4SFIH18mREPB@IUL4
Sei?18]UF@B;GDl3QEQ>18YQCPB5G4d4Q5a=181@@`AkEDL3Ld@f15hj;P@b6Q<4<1<A11h>2`@Q3``4
80h<0ad:1P@S40d4=aDB1?[jnPBCRHPOVHj=5Oooo`005?oooaNISXd4VHV819>2PP@J1`H4BBHM13/V
8`=2:BD4<Q`I12hF4`@g7a/4?1lF16U6>PB0A383[gYV1:B>N`BNOWL4VGid19V3N@BIQ7d7VHEo19Ul
L`BENf`4UG=T19UiJ@BEI5L3T6IC19EZGPB@IU<4SfIJ18mRD`B5HE84RF5B0hAEB`B0Fdd4Q5M918AK
B`AlEdT4Ldho0fTn;`A;9b84<aHA12@@3@@O2`L47``=11X61`<?0@847@L8150W8PCRj>P4VXn>7iV>
SAGoool001CooolGVHj=19V9R0BCPX846PL614TV7@@k9R<3@RTU138L6@@^5Q<4=alK13`O5PAYASX4
P4@b0jmjIPBTSW/4WWig19UnM0BIPgT4VHAm1iV5O`BIO7<4UG]/19EcI0BINFT4UFAG0i1VD`BEJUh4
T6IC18mVFPB?HU<4QF5B18UQDP>4ED/4P5]=18AGB@B4Fd/4O5M917=>?`=Y?Rl4BbLR13<F4@@T40d4
7`/711l<3@@J1PL33`4211d720A@9b84h^SX19Z?SQnISXdEoooo000Doooo5iV>S@BIRHP4Th:211X7
1PA99Qd4>bHS0d8Y9@@b71T4;QHC13LO6`@l7aH4JDHj1814<P>_NVH4Y8ik19inM`BIOW@4VH=i19V4
O@NIQGl4VGac19EkK0BELf@4VGUY19ETE`>@IU<4UFYN191VD`B?IUX4Sf9C18EQDPB9HE83Q5E;181K
C@B4EdT4Q5];17aGB@AcCSl3JCh_14/W8P@c5Q44910=11l;1`@O30d46PH70`l10P@M1`P4D2LR1>;X
j0BJShhOVHj=5Oooo`005?oooanISXd47@T813`N50A2:RP3@BPU13HN6P@a5144?R8H13`T80AH?2l4
HRhS0jUYDPB]U804WGeb19UjL0BIOWP4VGm`1iUoM@BINgD4TgES18mXFPBDL604T6AE0i1VD`B?IET4
SfUC18mVEPB?GDh4QFEE1hUMCPB1G4d4Q5=6181B@`A_DD84JD0a0d/W8PA18AL49`l<128@3@@W3``4
70X<11P51`<G1@L4<1@A19F0P0B0KVhSVHj=5Oooo`005?oooanISXd47@T813`N50A2:RP3@BPU13HN
6P@a5144?R8H13`T80AH?2l4HRhS0jUYDPB]U804WGeb19UjL0BIOWP4VGm`1iUoM@BINgD4TgES18mX
FPBDL604T6AE0i1VD`B?IET4SfUC18mVEPB?GDh4QFEE1hUMCPB1G4d4Q5=6181B@`A_DD84JD0a0d/W
8PA18AL49`l<128@3@@W3``470X<11P51`<G1@L4<1@A19F0P0B0KVhSVHj=5Oooo`005?oooanISXd4
7@T813`N50A2:RP3@BPU13HN6P@a5144?R8H13`T80AH?2l4HRhS0jUYDPB]U804WGeb19UjL0BIOWP4
VGm`1iUoM@BINgD4TgES18mXFPBDL604T6AE0i1VD`B?IET4SfUC18mVEPB?GDh4QFEE1hUMCPB1G4d4
Q5=6181B@`A_DD84JD0a0d/W8PA18AL49`l<128@3@@W3``470X<11P51`<G1@L4<1@A19F0P0B0KVhS
VHj=5Oooo`005?oooanISXd47@T813`N50A2:RP3@BPU13HN6P@a5144?R8H13`T80AH?2l4HRhS0jUY
DPB]U804WGeb19UjL0BIOWP4VGm`1iUoM@BINgD4TgES18mXFPBDL604T6AE0i1VD`B?IET4SfUC18mV
EPB?GDh4QFEE1hUMCPB1G4d4Q5=6181B@`A_DD84JD0a0d/W8PA18AL49`l<128@3@@W3``470X<11P5
1`<G1@L4<1@A19F0P0B0KVhSVHj=5Oooo`005?oooanISXd4:a@B13<K5`@o9B43BB/W13LM5@@c71X4
=1TE148W8`@n91h4D2dW0he==`B_PFH4ZY2019YjJPBNOW<4VGY[19UjJP>EMVH4VWY^19inK`B@IEL4
T6=D191VD`>;FDh4T6AH191TE@BEIED4ReY;18]OD0B9F4h3QF1=18ELB@B0Cd@4O59316I6>0AB:1l3
?20G12XA3@@O2`L480`=12/A30@L2P`450020aX620@j5a<4nOSh19Z?SR>ISXdEoooo000Doooo7iV>
S@@[5184<a/G13lU8@=9:bL4=adE13<L6P@d6AD4@RLS13hT7PA@;BL3SDdg1:n1IPBZT804VWYZ19in
L`BINV/4VGYZ0iEfIPBJNVh4WWi_191UE`B@He@4T6IC0h]ICPB@I5P4T6AE19EUE@B;FT/4Rem@18UH
CP>5H4d4QEa9181?A0AlDT<4ITHh158X7`<l81L4:Q4=11l;1`@P30d4:a4<11`:30@D00836PH813XG
4`Cin?P4VXn>8iV>SAGoool001CooolOVHj=12/D4P@c6aL4?bDQ0dT[9`@g7AD4<a`J13@I5@A29b<4
?R@N150]9`>=CCL4[h5V1:Z@P0BJNVX4WWic19UjJ`BINVX3UGIV19YjKPBNOVl4T6EG191SE0B@IU<3
ReU>191TF0B@I5D4UFEE18]JB`B;Ge04REQ>0hEPC@B5G4T4P4m417aB@`AVASP4DRPO0c`P5`@Z4@d4
7`/7120<3@@[4@`470X<11@00P<J1PP4>QLC1?Whn0BJShhSVHj=5Oooo`005?oooanISXd4:a@B13<K
5`@o9B43BB/W13LM5@@c71X4=1TE148W8`@n91h4D2dW0he==`B_PFH4ZY2019YjJPBNOW<4VGY[19Uj
JP>EMVH4VWY^19inK`B@IEL4T6=D191VD`>;FDh4T6AH191TE@BEIED4ReY;18]OD0B9F4h3QF1=18EL
B@B0Cd@4O59316I6>0AB:1l3?20G12XA3@@O2`L480`=12/A30@L2P`450020aX620@j5a<4nOSh19Z?
SR>ISXdEoooo000Doooo7iV>S@@e7QT4>24P13lW8`<o9204?R<N12dD5@@e6aH4>b8M144X9@@l7aH3
G2hQ19YVC@B/OFL4X7aY19n2L0BJNVT4VWm^0iEfIPBDLF84VGUY195YF`B<EdT4T6A@0h]MCPB9FT/4
RFAC18mPD0B;GDh4QEM918YGB`>1ETH4PEY717Q??`Ab@S84J40`13/M5P<[4@d4910=11d:1`@I1@P4
70L811010`@?0@83=1DA13XH4@CWk_<WVHj=5Oooo`005?oooanISXd4=AhI13PQ80@o9b<3?b@P13hS
7P@]51D4=A/F13/R7@A1:2D4?1lF0e`^8@BJITd4[7eW1:1lJ@BOPW04VWYY19YoKP>EMVH4U75R19Ui
J@BAJE/4S5M9191TD0>;GDh4REY;18UTD`B?H504Ree>18EGB@B:Ed/3PEI6185JA`AhCcl4LT8b16Q0
<0@k7AH3:a4=12@@3@@M2PL46@D811`720@@0@<43`420c@E4@@j6144inkc9iV>SAGoool001CooolO
VHj=13DN6@@h8B04?bLS0clT80@n8ah4;A@E13DK5P@k8Qd4@BPU13`O5P=L;R44VVI=1:amI`BPO6T4
Wh9`19YjJ@BJOfh3UGIV19AaHPBINFT4TFUK18aGB@B@I503Ree>18UJB`B9I5<4Sf1@18]MCPB5EdT4
RUM;0h5FAPB1FTL4N4lo1792<PAX@304>adF0b/A3@@T40d47@X711T520@L1`P4404310l10P<d5A44
>QPA1>O^lbNISXdEoooo000Doooo7iV>S@@e7QT4>24P13lW8`<o9204?R<N12dD5@@e6aH4>b8M144X
9@@l7aH3G2hQ19YVC@B/OFL4X7aY19n2L0BJNVT4VWm^0iEfIPBDLF84VGUY195YF`B<EdT4T6A@0h]M
CPB9FT/4RFAC18mPD0B;GDh4QEM918YGB`>1ETH4PEY717Q??`Ab@S84J40`13/M5P<[4@d4910=11d:
1`@I1@P470L811010`@?0@83=1DA13XH4@CWk_<WVHj=5Oooo`005?oooanISXd4AbhZ12TC3`A0:BD3
>b<O14H]:@@b6184;Q<A14<[9`@g7a/4ABTT0cDI50A[ASD4MTLg1:IPB@B_Q6l4TVYI19]kKP>FM6@4
UW5L19]dI0B8Ge04ND`m18iFA0>DFd@4SeiA18YJB`B:DT84RV9A18EG?`B0DTT3O4ho17M<?0AZC3`4
Eb`T14lT60@b5Q839`l<11d;1`@I1PL46@D711@00P@>00846@D70bhB3PBDM6l4RGai9iV>SAGoool0
01CooolOVHj=14L^:P@Y4`l4@2TU0c/S7`A6;BT4<QPB12hC4@A3:bL4=alK14DY90<e6A@4JdHe17I7
=`BVH4T4[hA_199ZF@BKNfh3UWAT19IaG0BKM6@4R5m@17U<?@B>ET@3U5]418mND@B:FT/4RU9218YR
D@B5Ecl4P5990ga>?`AgC3`4JT`l15L/90A?91P4<QHB0bL?30@M2`L46@H711T51`@D00843P0211T5
1`<^4Ph4U7A_18UlNBNISXdEoooo000Doooo7iV>S@A7;RX4:A<?140Y9@<k8al4ARdY138H4P@^4a44
@b/W13LO6`A5:B@3=ATD16]6=@AfAcL4YV191:n4K`BBJUT4Vg]^0iIdI0BFLE`4VgAT18QOD0AiC3d4
SUI40iAKA0B?GU44RUY;18YB@PB:HU44QELo181BB@=lCSl4Md`l16Y<?0AG;2@4Cb@H138F4P<W3``4
7@/711T61`@I1@L4500210h00P@I1@L3;Q8>19AdK`B9O7TWVHj=5Oooo`005?oooanISXd4AbhZ12TC
3`A0:BD3>b<O14H]:@@b6184;Q<A14<[9`@g7a/4ABTT0cDI50A[ASD4MTLg1:IPB@B_Q6l4TVYI19]k
KP>FM6@4UW5L19]dI0B8Ge04ND`m18iFA0>DFd@4SeiA18YJB`B:DT84RV9A18EG?`B0DTT3O4ho17M<
?0AZC3`4Eb`T14lT60@b5Q839`l<11d;1`@I1PL46@D711@00P@>00846@D70bhB3PBDM6l4RGai9iV>
SAGoool001CooolOVHj=17aWKP@V3P`4<Q/I0d0V8PA19b<4=1lI12lC50A591T4>b@R14P^:P<h8Ql4
@2LQ158d;@A`?2h4Qdhi17YCC0AjEDD3TUI2195YE@B>HTl4MTXn1751;PA/?2/3Pd/b18]<>`B9F444
Se4o17a>@0AkAc<4Q4Xh0g]<?0AX@SL4HC@X14/R60@j5Q84:A0=0al;1`@J1PL4504210l10`P?0084
910=0c8D4@C[inL4V8b;9iV>SAGoool001CooolOVHj=17aWKP@V3P`4<Q/I0d0V8PA19b<4=1lI12lC
50A591T4>b@R14P^:P<h8Ql4@2LQ158d;@A`?2h4Qdhi17YCC0AjEDD3TUI2195YE@B>HTl4MTXn1751
;PA/?2/3Pd/b18]<>`B9F444Se4o17a>@0AkAc<4Q4Xh0g]<?0AX@SL4HC@X14/R60@j5Q84:A0=0al;
1`@J1PL4504210l10`P?0084910=0c8D4@C[inL4V8b;9iV>SAGoool001CooolOVHj=17aWKP@V3P`4
<Q/I0d0V8PA19b<4=1lI12lC50A591T4>b@R14P^:P<h8Ql4@2LQ158d;@A`?2h4Qdhi17YCC0AjEDD3
TUI2195YE@B>HTl4MTXn1751;PA/?2/3Pd/b18]<>`B9F444Se4o17a>@0AkAc<4Q4Xh0g]<?0AX@SL4
HC@X14/R60@j5Q84:A0=0al;1`@J1PL4504210l10`P?0084910=0c8D4@C[inL4V8b;9iV>SAGoool0
01CooolOVHj=17aWKP@V3P`4<Q/I0d0V8PA19b<4=1lI12lC50A591T4>b@R14P^:P<h8Ql4@2LQ158d
;@A`?2h4Qdhi17YCC0AjEDD3TUI2195YE@B>HTl4MTXn1751;PA/?2/3Pd/b18]<>`B9F444Se4o17a>
@0AkAc<4Q4Xh0g]<?0AX@SL4HC@X14/R60@j5Q84:A0=0al;1`@J1PL4504210l10`P?0084910=0c8D
4@C[inL4V8b;9iV>SAGoool001CooolSVHj=13/T8@@X50l3@BPT13/W8`@h8Ad480h;144S7@A9;RX4
ARdY0dTa;0A2;2P4C3</15<e;0AE<bP4DRhZ154/80=I;RL4KCTZ16e5=PAA;bX4Ec0X160^8@=O<Ah4
IS8W17a7<@Ai@c04KS`[16hn;`AS<B<3JSda15/^90A<9ad4=ADA13HJ5P@M2PH37P/711P51`@C0088
3P0212L?30@L2P`3KdY31;Bg^B^ISXdEoooo000Doooo8iV>S@@k9244:1@?0d4X90@k9b<4>24M120>
2`A18ad4BBhZ14H]:@=9<B`4@R`X14`c;0AC=B`4EC<X158^:PAA;203FBhW16di:PA]ACH4DBlZ15L`
:0AP;R43Gc4N16Hb9`AlAc44ND<`16hl:`A^?Rl4Hc4S0fXm<@AK;R@4C2LM13DE4@@f6QH47@X60ah;
1`@H1@L44`0220h00P@W3``470X<0fm:@`Bd]kT[VHj=5Oooo`005?ooob>ISXd4>b@Q12PD3`=1:2@4
>bLS13PQ7@@P3P/4@B<M14T^:PA6;BT3BC4/148/:0A<<b`4DcD/15Dc:0AB;RX4DB`P0eT^9`A]>BX4
KDDf154_:PAG<2P4H2hQ0ela7PAV<RL4O4La17U3<0A^?2/4KSh_16<a8`=Z?C44FbhT14`W7@@e5A44
=QXF11d:1P<N2`L460D711<00PP>00849`l<11`:30=_BT<4];Ni:iV>SAGoool001CooolSVHj=165<
E@@P30X3>b@P13dV8P@m9244<AdK13`U8PA8;RX4Bc<^0d8Y9@A8;BT4D2XT15Pa9@A5:Ah4?RLT13PJ
5P=79b<4?1HB14l^9`A49b84?B4M13hH4`=07aT4@1TC14`M5PAC:a`4CRLJ150X6`A56Q@3Aa`F13lJ
5@@l6A@49A4=128=20LJ1PL46@D710h00P@?00849`lE12L?2`@f8Al3[iVH18inOB^ISXdEoooo000D
oooo8iV>S@AQC5D480`:0c/T80@m9R84?B@Q134M6`@l9B84B2hZ14/c;P=2:BD4B2dY150Z90AH<BD4
ABTN13hW90@h6QH3AbLS13`F4PA?;RL4A2LR13dQ7@@n61<3@1lI140I4`A<7AH4Db/L14hW6PA@:1/4
AAXD0dLL5P@o6QD4?1TD12DA3@@R3@P76PH711T51`@>00843`0212L?5@@W3`/4=R4O0jnIV0B>OWd[
VHj=5Oooo`005?ooob>ISXd4HDaE120<2P<k9204?BHR13dT8@@a7A/4?2DR14P^:PA;<bh3@RTU14P]
:@A@:R@4F34U14DY7P@n9b@4>1XF0dLW8`@l5Q84CbhW14@W8P@m8Ad4?QPC0d0O6@A06A<4C1dF15<[
70A>9aX4D2PK14DJ50=771H4?aXE13`I50@U4@d48Pd81aX61`@I1@L43P0210l00P@W3aD49`l;13HQ
7`>_VIP4SWim:iV>SAGoool001CooolSVHj=165<E@@P30X3>b@P13dV8P@m9244<AdK13`U8PA8;RX4
Bc<^0d8Y9@A8;BT4D2XT15Pa9@A5:Ah4?RLT13PJ5P=79b<4?1HB14l^9`A49b84?B4M13hH4`=07aT4
@1TC14`M5PAC:a`4CRLJ150X6`A56Q@3Aa`F13lJ5@@l6A@49A4=128=20LJ1PL46@D710h00P@?0084
9`lE12L?2`@f8Al3[iVH18inOB^ISXdEoooo000Doooo8iV>S@B>OH<4<QPI0bLB40@m9204@BPU13/R
7`A==2l4=QhJ158f<@<g7a/4Ab`X158`:0A29B84@B<M13hT80@d71T3B2TV12PA4P@h8ad4=aHC13DH
50@Y40d39Q8>12hA3@@h5Q84=aLB12dB3@@`4`h4;Q4=0cPF4P@Y40d4;14=21h;1`@H1@L36@D720l0
0P@I1@L4=A/H12hB40B:Ogh3PgAc;iV>SAGoool001CooolSVHj=18imP`@b61T39a8@13dT80A1:2D4
>b8O14dd;`@f7QX4DSHa0cLO6`A7;2P4DS0X148U8PA18ad4?R@P13@L6@=8:BH4:14B13PS7@@g5Q<4
=APD12T@3@<V4Ph4;Q4=13PF4P@g5a84;A8=130C3P@^4@d3>1HB12T@3@@/4@d87P/711P51`<I1@L8
3`0211T51`@e6aP4;Q8@18YoOP>3M7<_VHj=5Oooo`005?ooob>ISXd4SWf3138H6@<W4Q04?B@P144X
9@@k8Ql4CC@_13HN6PAB=S43=alK14L/:0AB<2P4@RDR144S7@@n9204=1`I0dPY9P@X4A84>2<M13LF
4`@e61@4:A0=0bHB3P@^4@d4>1HB13LG4P@]4Pd4<1<>12hA3@<h5Q84:A0=12`A3@PN2`L460D70aT5
1`P?00846@D713DK60@^4Q04RWmn0h=dLbnISXdEoooo000Doooo8iV>S@B>OH<4<QPI0bLB40@m9204
@BPU13/R7`A==2l4=QhJ158f<@<g7a/4Ab`X158`:0A29B84@B<M13hT80@d71T3B2TV12PA4P@h8ad4
=aHC13DH50@Y40d39Q8>12hA3@@h5Q84=aLB12dB3@@`4`h4;Q4=0cPF4P@Y40d4;14=21h;1`@H1@L3
6@D720l00P@I1@L4=A/H12hB40B:Ogh3PgAc;iV>SAGoool001CooolWVHj=16A=D0<T3P/4?BPU144X
9@@k8al4>B@O14X^:PA9<Bd3=B8O13TO6`AD:al4<a`I13dS7P@j8Ad4:QDK0chU7@@^4aH4=1LB12T@
5P@V4@`49A0=0ah;1`@V4@d49a4=12PA3@@P2`L470H8128<20<_4@h47`/711`620@P30L47P/<11P5
1P<?00846@D711l>2`@/5A@4<1@A185aL0B1L6lbVHj=5Oooo`005?ooobNISXd4I4e@0b@>2`@m:2D4
@BPU13/S7`@i91l4BRhZ14Ta;@<e8Ql4>AlK15@[7`@c71T4?B<N13XQ7@@Z5A/3?RDM12hC5P@d5a84
:A0F12HA30@U40d37P/712HA3@@W4@d4:14=120;1`@L1PP48P`80blA3P@O2`L470H8120<1`@N2``4
60D60`l00P@I1@L47`h;12`E50@`5144PG5`185`Kc:ISXdEoooo000Doooo9iV>S@ATCE0390h;13dX
9@A1:2D4>b<O13TT7`A:;RX4BC4]0cDR7`@i7a/4E2/O13<L6@@m8ah4>R4M12XE6`<n9Ad4;Q<F13@G
4P@Y41H49Q4<12D@3@<N2`L49Q4=12LA3@@X4@d480/711`620@R30P3;a4>11l;1`@L1PP480`711h;
30@H1@H33`0211T51`@O3P/4;1DD130D4@B1LG04PG1_<YV>SAGoool001CooolWVHj=16A=D0<T3P/4
?BPU144X9@@k8al4>B@O14X^:PA9<Bd3=B8O13TO6`AD:al4<a`I13dS7P@j8Ad4:QDK0chU7@@^4aH4
=1LB12T@5P@V4@`49A0=0ah;1`@V4@d49a4=12PA3@@P2`L470H8128<20<_4@h47`/711`620@P30L4
7P/<11P51P<?00846@D711l>2`@/5A@4<1@A185aL0B1L6lbVHj=5Oooo`005?ooobNISXd4R7=h0b/?
3`@c71T4A2/W13/S7`@l9b<4?RXV14X]:@<g81`4<aXG13XL5`@Z4@d4?B<N12hE5P@/5AL3:Q8>12/A
60@Q30`470H8124<3P@O30`36@H7120<3@@J1PL480`=11T61`@N2``48Pl;0al;30@J1PL43`423101
0`<N2``470X611X620@`3PT4R7Ee18IjNCJISXdEoooo000Doooo9iV>S@B8LgP3:`l?13<L6@A4:bL4
>b<O13`W8`@n:RH4BRdY0cLP70@c6QL4>Q`G12XA3@@m8ah4;QDF12`E5`<Z4Ph4:a4H124<30@L1PP4
8@`>11l<30<I1PL480`=11X61`@P30d46@H711h;30@R3`/37`/<11X61`@?0@8<40430ah;30@L2PH4
6PH8130>2@B8MGD4QWYi=YV>SAGoool001CooolWVHj=18QcN0<[3`l4<a`I14@[9`@k8al4?2LS13hZ
9PA:;BT3=b0L13<J5`@j71L4:Q4=13dS7P@^5AH4;1DG0bXB3P@[4AP48@`<11`620@Q30h47``<0aT6
1`@P30d46PH7120<3@@I1PL47P/<128?2`<O2``46PH710l10P`@0@<37P/<11`:1P@J1PP4<0h918Qe
M@B6NWTfVHj=5Oooo`005?ooobNISXd4R7=h0b/?3`@c71T4A2/W13/S7`@l9b<4?RXV14X]:@<g81`4
<aXG13XL5`@Z4@d4?B<N12hE5P@/5AL3:Q8>12/A60@Q30`470H8124<3P@O30`36@H7120<3@@J1PL4
80`=11T61`@N2``48Pl;0al;30@J1PL43`4231010`<N2``470X611X620@`3PT4R7Ee18IjNCJISXdE
oooo000Doooo:iV>S@=D?3T47PT812hH5@A09R84?bXV13dY9@A8;BX3=b0P12lC3`@b6aL48@h;12lB
3P@U4@h4;14>0aX61`@L1`T480`>11d:30@I1@L47``=0aP51`@O2`d460D7138E4P@<00848@`>12@@
30<M2P`43P0210l00P@D008470X<11X92`<M2P`4<A@@12lI4`A;;2D4/[[719R<RcJISXdEoooo000D
oooo:iV>S@=D?3T47PT812hH5@A09R84?bXV13dY9@A8;BX3=b0P12lC3`@b6aL48@h;12lB3P@U4@h4
;14>0aX61`@L1`T480`>11d:30@I1@L47``=0aP51`@O2`d460D7138E4P@<00848@`>12@@30<M2P`4
3P0210l00P@D008470X<11X92`<M2P`4<A@@12lI4`A;;2D4/[[719R<RcJISXdEoooo000Doooo:iV>
S@=D?3T47PT812hH5@A09R84?bXV13dY9@A8;BX3=b0P12lC3`@b6aL48@h;12lB3P@U4@h4;14>0aX6
1`@L1`T480`>11d:30@I1@L47``=0aP51`@O2`d460D7138E4P@<00848@`>12@@30<M2P`43P0210l0
0P@D008470X<11X92`<M2P`4<A@@12lI4`A;;2D4/[[719R<RcJISXdEoooo000Doooo;YV>S@AD?3T4
6PH512lO7@@h7a/4BC4]14H]:P=2:RP4;1PE13LM6@@S3A<47P/;12XA30@N2``38Pl<120=2`@M2P`8
6@D711X620<I1@L46PH812<@30@Q2`d4<B</12XK6@@R2`l35`D611`:30@N3@/47P`;11`:30@e7QX3
9a@C134C40AH<2D4U8=k18ejMSZISXdEoooo000Doooo;YV>S@AD?3T46PH512lO7@@h7a/4BC4]14H]
:P=2:RP4;1PE13LM6@@S3A<47P/;12XA30@N2``38Pl<120=2`@M2P`86@D711X620<I1@L46PH812<@
30@Q2`d4<B</12XK6@@R2`l35`D611`:30@N3@/47P`;11`:30@e7QX39a@C134C40AH<2D4U8=k18ej
MSZISXdEoooo000Doooo;YV>S@AD?3T46PH512lO7@@h7a/4BC4]14H]:P=2:RP4;1PE13LM6@@S3A<4
7P/;12XA30@N2``38Pl<120=2`@M2P`86@D711X620<I1@L46PH812<@30@Q2`d4<B</12XK6@@R2`l3
5`D611`:30@N3@/47P`;11`:30@e7QX39a@C134C40AH<2D4U8=k18ejMSZISXdEoooo000Doooo;YV>
S@AD?3T46PH512lO7@@h7a/4BC4]14H]:P=2:RP4;1PE13LM6@@S3A<47P/;12XA30@N2``38Pl<120=
2`@M2P`86@D711X620<I1@L46PH812<@30@Q2`d4<B</12XK6@@R2`l35`D611`:30@N3@/47P`;11`:
30@e7QX39a@C134C40AH<2D4U8=k18ejMSZISXdEoooo000Doooo<YV>S@AF=cD46`P713<Q7`@g7a/4
ABlZ0e4e<0@j9R<4=A/C12/F5P@N3@/47`/<11X61`<P30P47``=11T61`@I1@L47P/<11P51P<N2``4
60D611/620@h:BT4<ATW14`i<@@f8bD391@G138P7P@W5A<47Pd:12lH5P@c6QL3@BPT14@P6PB6LW44
RG]i?YV>SAGoool001CooolbVHj=15Hg=@@K20L4<b4O13LO6`A5;bX3DCD`13XV8`@e6a<4:aHF11h=
2`@O2``46PH70b0<20@O30d46@H711T51`@N2``460D60ah;30@H1@H46`H813PY:@@a6BL4C3Ta13HS
9@<T51L4<R0N12LE4`@N3@X4;aPF13<J5`=1:2@4A20J18IbL@B9NgTnVHj=5Oooo`005?oooc:ISXd4
ESLe11/81`@c8Al4=alK14D_:P=A=C04>RHS13DK4`@[5QH47Pd;11l;30@J1PL380`811l<3@@I1PL4
6@D711h;30@H1@H37P/<11P51P@K1PP4>2TY134I9`A<>C44=R<U0b@D5`@b81h49aDC11h=2P@_61H4
<aXG0d4X90A481X4QW9a18UkNCjISXdEoooo000Doooo<YV>S@AF=cD46`P713<Q7`@g7a/4ABlZ0e4e
<0@j9R<4=A/C12/F5P@N3@/47`/<11X61`<P30P47``=11T61`@I1@L47P/<11P51P<N2``460D611/6
20@h:BT4<ATW14`i<@@f8bD391@G138P7P@W5A<47Pd:12lH5P@c6QL3@BPT14@P6PB6LW44RG]i?YV>
SAGoool001CooolbVHj=19jCTPAE>3D48`/813XZ:@@j9243D3Lb14Ta;@A3:RD4:Q<A12dG50@a7Q`4
8aDD0b4<2@@P3``470T<11d:2`PI1@L3910F11`92P@Q3P/48Ph@13XT8PA7:RH48`h@0bdF4@@^5Q44
90h?12/A3@@e6aP4?1lF0edi;PA[Eel4VH^319V=S3jISXdEoooo000Doooo<YV>S@BNTi84ECPe12<;
20@j:RT4>R@Q0e0g<PA9<Bd4@bXU12XC4@@]5a@4<AhL12<E50<Q30T480l<11`930@M2P/86@D70b@@
5P@L2@X48@h;128>40@j9284AbXV12<>40<]5Q44;QHA12@>3`@[4@d4=A/H13`O5P=M>Bh4JeMO19V;
P`BISH`nVHj=5Oooo`005?oooc:ISXd4WY>B15Dh=@@S2`P4>RXY13XT8@=@=c84BC4]14<Z9@@Z4a44
;ALD134N70@S5A@38@`9120?30@L2@`47@X;21T51`<T41H470T:124>2`@R3Q04>R@R14LZ9P@S3Q03
;AHA12hF4@@T3Pl4:a4=13DK60@l7aH3GCT^16]GG`BIRh<4VHf<?YV>SAGoool001CooolbVHj=19jC
TPAE>3D48`/813XZ:@@j9243D3Lb14Ta;@A3:RD4:Q<A12dG50@a7Q`48aDD0b4<2@@P3``470T<11d:
2`PI1@L3910F11`92P@Q3P/48Ph@13XT8PA7:RH48`h@0bdF4@@^5Q4490h?12/A3@@e6aP4?1lF0edi
;PA[Eel4VH^319V=S3jISXdEoooo000Doooo>YV>S@A?;2@49Ph;134K60=<<2/4Fd4l14hk=`@h8Ql4
:A<A134G60@e61<3>28O12PH5@@J20X46@D712PD6P@S4AD3;Q`I128@5`@l9Al46PX@14lf;P@e7b04
;a`I0bhL6@@[61D4;a`K13/V8@@`6QT4GSHY0geZJ@AjHfD4UHR8@YV>SAGoool001CoooljVHj=14l/
90@V3P/4<A/H0d``:`AK@C`4CS/g13PR7`@Y4a44<ALH13DH4`<h8Ql4:1PE11X82P@I1@L4:1@J12<A
5@<^71T48Q0G13`U7`@J2Q04CcH^13DO80@_71T3;Q`I12/H5@@_71/4>bHQ130J6@AN=RT3OFYY17YS
I@BER8Q2VHj=5Oooo`005?ooocZISXd4Cb`T12H>2`@a6aP3C30[15]1?0A>>cL4>28O12TC4@@a5aP4
=APC0cPR7`@X61D46PP:11T51`@X51X48a4E0bhL6@@R41L4?2DO11X:40A?=Rh4=AlP12lL6@<^71T4
:aPE12lL6`@k9R44<1XI15hf:@=mJVT4NV=U19F8R4:ISXdEoooo000Doooo>YV>S@A?;2@49Ph;134K
60=<<2/4Fd4l14hk=`@h8Ql4:A<A134G60@e61<3>28O12PH5@@J20X46@D712PD6P@S4AD3;Q`I128@
5`@l9Al46PX@14lf;P@e7b04;a`I0bhL6@@[61D4;a`K13/V8@@`6QT4GSHY0geZJ@AjHfD4UHR8@YV>
SAGoool001CooolnVHj=14lf;`@M1P<39A8>14L/:0AC>C@4D41514DZ8`@h9BD4>RLV0c4I6P@d9bH4
>bL^12lP6`@U4aP4;QhY0cTQ7P@m;SP4>b8K130L70A;<Bd4@RHT144R7`=191/4>RLU14/_9`AK>Rd4
<QdH1:J?R0>=M744VHf<AYV>SAGoool001CooolnVHj=14lf;`@M1P<39A8>14L/:0AC>C@4D41514DZ
8`@h9BD4>RLV0c4I6P@d9bH4>bL^12lP6`@U4aP4;QhY0cTQ7P@m;SP4>b8K130L70A;<Bd4@RHT144R
7`=191/4>RLU14/_9`AK>Rd4<QdH1:J?R0>=M744VHf<AYV>SAGoool001CooolnVHj=14lf;`@M1P<3
9A8>14L/:0AC>C@4D41514DZ8`@h9BD4>RLV0c4I6P@d9bH4>bL^12lP6`@U4aP4;QhY0cTQ7P@m;SP4
>b8K130L70A;<Bd4@RHT144R7`=191/4>RLU14/_9`AK>Rd4<QdH1:J?R0>=M744VHf<AYV>SAGoool0
01CooolnVHj=14lf;`@M1P<39A8>14L/:0AC>C@4D41514DZ8`@h9BD4>RLV0c4I6P@d9bH4>bL^12lP
6`@U4aP4;QhY0cTQ7P@m;SP4>b8K130L70A;<Bd4@RHT144R7`=191/4>RLU14/_9`AK>Rd4<QdH1:J?
R0>=M744VHf<AYV>SAGoool001Cooom2VHj=189]L`<n92<47PT9148/90A2=d44K51;15@m>`AC?SP3
AS8b148d>0A<=cT4DSdj13/V9@A1;C03=QlS13hU8`A3:BD4ARdZ144X9@AC:B44CR/U0d/]9PA>=C04
AbDN179@C0AZDdL4QWAbCIV>SAGoool001Cooom2VHj=189]L`<n92<47PT9148/90A2=d44K51;15@m
>`AC?SP3AS8b148d>0A<=cT4DSdj13/V9@A1;C03=QlS13hU8`A3:BD4ARdZ144X9@AC:B44CR/U0d/]
9PA>=C04AbDN179@C0AZDdL4QWAbCIV>SAGoool001Cooom2VHj=189]L`<n92<47PT9148/90A2=d44
K51;15@m>`AC?SP3AS8b148d>0A<=cT4DSdj13/V9@A1;C03=QlS13hU8`A3:BD4ARdZ144X9@AC:B44
CR/U0d/]9PA>=C04AbDN179@C0AZDdL4QWAbCIV>SAGoool001Coool4VHn?19VCTT6ISXd4CcHn13<H
5`@U5Qd4=RDY16eDCPARE5L3CS/a15@n>PAD@3d4F3lk15@j>`A>>383?Rd^14D_;@@h:2<4CCHe14hf
<`A7:b@4ES</0dTV8PB?K6/4F3PY14lX:PB=O7eAVHj=5Oooo`005?ooo`BIShl4VI>B@IV>S@A?=Sh4
<aPG12DF7@@f9BT4KEA>169DE`=>>c44E3hj15A0?@AH?c/4E3Xk14hh<P<n;Bh4ABl]13PX8`A==SD4
CSHc14L[90AF<b`3BBHR18m/J`AH>2T4CbPZ18elOE6ISXdEoooo000Doooo19V?S`BITi91VHj=14lf
?P@c61L49AHM13HU:@A]E4h4HUAG0dhk<@AD?SX4E40m15Po>`AD>S/4CSPb0ch];PA5;bd4>2PS14df
=@A>=S<4Ab/T15Hc;0=99R84Sfa[15Ph:@A?:2X4SGamDIV>SAGoool001Coool4VHn?19VCTT6ISXd4
CcHn13<H5`@U5Qd4=RDY16eDCPARE5L3CS/a15@n>PAD@3d4F3lk15@j>`A>>383?Rd^14D_;@@h:2<4
CCHe14hf<`A7:b@4ES</0dTV8PB?K6/4F3PY14lX:PB=O7eAVHj=5Oooo`005?ooo`BIQhL4VHf<BIV>
S@B>OH<4C3Q715Hi?`A/Df03H4=;1653=@A3:RT4@bl[16A8B@AQ@3D3GD<n1695@0AJ@3X4ESdh15`i
;`AG?S@4Sgaj0bhB3`AYBDl4ThB5FIV>SAGoool001Coool4VHN719V=S4VISXd4SWf314`hA`AF>Cl4
K5=P0f13B`AQ@cD4@bXY14<_:`ATB4T4HD0e0ee3?PARAD04FT0j15Hm>0AL>Bl4Echd18mlNP<^4Pl4
JDU?19>4QEVISXdEoooo000Doooo19V7Q`BISHa9VHj=18imP`A<>4L4ESTo16aCH0=P@d/4HD<e14<Z
:@A3;b/4I4Q91650=@=M@ch4HTE015Y0>PAF?CP4G3T_15Ln=0B?O7X3;Q8?16U9C`BCQ8EIVHj=5Ooo
o`005?ooo`BIQhL4VHf<BIV>S@B>OH<4C3Q715Hi?`A/Df03H4=;1653=@A3:RT4@bl[16A8B@AQ@3D3
GD<n1695@0AJ@3X4ESdh15`i;`AG?S@4Sgaj0bhB3`AYBDl4ThB5FIV>SAGoool001CooomQVHj=0him
R0BGQHL4PVag15E0CPA<=dH4Ab//0dHX9PA6;R/4ARTV140S8@@i6104>1XA18QcL@>ISHaQVHj=5Ooo
o`005?ooof6ISXd3SWf819N5Q`B2K7L4ED1>14`gAPA7:b`3ARPV14H^:`A6:BH4@2<Q13TH40@h6Q44
R7=a0iV=S66ISXdEoooo000DooooHIV>S@>>OHP4UhF7189/M`AE@4h4C3M614L[;0=6:2H4ARh[14HY
9PA08b44>AP@13PJ4@B8Lg43VHf<HIV>SAGoool001CooomQVHj=0himR0BGQHL4PVag15E0CPA<=dH4
Ab//0dHX9PA6;R/4ARTV140S8@@i6104>1XA18QcL@>ISHaQVHj=5Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00Toooo`<0002:oooo002F
oooo00<0003oooooool0Qoooo`00P_ooo`800004oooo100000;oool300000oooo`<00003oooo0P00
08Coool0087oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool00`000?ooooooo`03
oooo00@0003oooooool00029oooo0021oooo00@0003oooooool00002oooo00@0003oooooool00002
oooo100000;oool010000?ooooooo`0008Woool0087oool010000?ooooooo`0000?oool300000ooo
o`800004oooo100008Soool0087oool010000?ooooooo`0000Goool00`000?ooooooo`2Coooo0022
oooo0P0000Goool20000UOooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(22) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
787375787375787375787375787375787375787375787375787375787375787375787375
7873757873757873757873757873757873757873757873757873757873757873756E4A39
7E695F786464786C67785F5B786C67786863786863786863785F5B7864576E5C54745950
6A4D4570554C664E466C52496C52496C52496C52496C4B42634E3F684E48684E3F684E48
91AAB9787375787375787375787375786A6C78787A787375787375787375787375787375
787375787375787375787375
787375786F7178787A787375786F7178787A787375787375787375787375787375787375
787375787375787375786F7178787A787375787375787375787375787375787375724D3B
78656078645B786C6B785F5B786C6778686378645A73645D79645D7960566F5B5270584E
71514871554B674D4471554B6C52496C52496C4E456C4E45634E42684E45684E3F685F61
91969D787375787375787375787375786E70787375787375787375787375787375787375
787375787375787375787375
787375786E70786F7178787A786E70787375787375786F7178787A786F7178787A787375
787375787375787375786E70787375787375787375787375787375787375787375734E3C
7D686278645F78686378686378645F786862736052665C57805C5075544E6B574B6B584F
6C52496C524A674B43684E456D51476D51476D4E456D4E41684E48684E45684E427A8C98
7A7679787375787375787375787375787375786F7178787A787375787375787375787375
787375787375787375787375
787375787375786A6C78787A787375787375787375786E70787375786E70787375787375
787375787375787375787375787375787375787375787375787375787375787375724A39
78696378645F78645F78686378645F78645B72605B615C586B544A734A4E604F406B5249
6B554F6B554C664942635145684E45684E45684E45684E426C5249634B42684E4591AAB9
787375787375787375787375787375787375786E70787375787375787375787375787375
787375787375787375787375
787375787375786E70787375787375787375787375787375787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375784D3B
78655F78645E78646378645F78645F78645B78686378645F725C547454506E4D496F5247
6F524D6B4B496E524A5C413D674D45675A5163483D6C4E456C5148634E456C564D8BA0AF
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
78737578737578737578737578737578737578737578737578737578737578737578513F
78645B78645F78645B78646378645F78686378645F786862786863725C547257506E514A
7455516E524A70564C6A4646664B436C524A67555068483D6D4E45684E457B6F6E7F8B92
787375787375787375787375787375787375787375786F7178787A787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
7873757873757873757873757873757873757873757873757873757873756A524D897363
78645F78645B78645B78646478686378645F78686378645F786863785F5B78645B72584D
7255516E554D6E554D6B4B496A5246664B4268554D684D446C4E45634E45878B967E7F81
787375787375787375787375787375787375787375786E70787375787375787375786F71
78737578787A787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
78737578737578737578737578737578737578737578737578737542342FAB7F707F6A60
78646478645B78645B78645F786C67785F5B78685E786C6B78645F78645F78645B786057
73514D73584D7455506A51456B4B446B5249674B42634E4572564D674B43869BAB787476
787375787375787375787375787375787375787375787375787375787375787375786E70
786F71787375787375787375
787375787375786F7178787A787375787375787375787375787375787375787375787375
787375787375787375787375787375787375787375787375665A60180E0CE8BCA4786557
78686878605B78686378605B78686378686378645B78645F78645A78585A736352745F53
795B567459507055506B4E42704E46665249684B3E684E486D554A6D514790A9B8787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375786E70786F7178787A787375787375787375787375787375787375787375
7873757873757873757873757873757873757873757C77792316146F585388726978645F
78686378645F78686378645F78645F786863786C66785F5B73605379505373594C6A5149
75594F75584F70584B664E48724E456B5147674E42674E45634E456C5249878D957D878C
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375786F71787375787375787375787375787375787375787375787375787375
78737578737578737578737578737578737578737531201B7766607C645B786557786464
78645F78645F78645B78646378645F78686378645F78645F6E413D74534E704B43704D45
704D467066546B51446B51476C4941685244714E486C4E45634E41724D4672655D8FA6B4
787375787375787375787375787375787375787375787375787375787375787375786F71
78787A787375787375787375
787375787375786E70787375787375787375787375787375787375787375787375787375
787375787375787375787375787375787375665A5D251D1A87716678645F786457786464
78645F78605778645A78645E78686778686378575678635E6E3536703F396B332F764747
6B3B36764F49624D416D53466D4E41684A417252486C4E45674E426C463F67564C7C716B
899FAD787375787375787375787375787375787375787375787375787375787375786E70
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375787375787375221717DBAB957E686278645E78645B786464
78645B73584F795C537D6D62786564785C53734146744B436F4F4C642D257B5851774043
6224217238326B4740634E446859486846376D5249714E486C4E456C4B426C52486C554B
8B99A1787C83787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375786F7178787A787375787375787375787375787375787375
7873757873757873757873757873755646492B241F9F8777786560735C4F7D716B78605C
785C4F6A5447704B458A74706F4540441B13B67E757038356E5B555C4744622D27645246
5F312A6E3D3E5B2B23863A34645F4E6D4D376C4E476C564C7153466648426C52496C4E45
7C6E6589959C787C83787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375786F7178787A786E70787375787375787375787375787375787375787375
7873757873757873757873757873751C1213BB8C74816C6678645B6E50497E767378645F
785449603E3167443D501A199E89833F1A1B7457536D434573504C786F68682925614D4E
4F352D4A38373A1B174F2319934A3A73634C724742715E5371564A6A4E43664B456C4E45
6C554C7C859A847E777D7C7E787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375786E70787375787375787375787375787375787375787375787375787375
7873757873757873757873756A626D0B0707E8B7977E696378645B72575078656578645F
6F463B593B2B642B252D110FAC8377807F717965637D8C9078635C786C676A4C477F8383
6F4F466164662D1C1C2A27273D1A16994E3B775C517C6251745E586B4E43664B436C473F
6C554A68767F72676A85819189877E787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
78737578737578737542342F3B242360443EA08C7778655B785C53786459786C6678645E
6538335A4B3E5A363630151C7442476F574B70514C7A6A647E524D6F6153703D38764A42
6C473D808170613B3355474928242143120CA66E607C69527A665F6A4D42664A44684A42
7153496761596F77835A5164909289787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375786F7178787A787375787375787375787375787375
7873757873756A5E640E0A09291816E0A5947B685A7860577854547365547D695F785857
6546396345379088837869607853547254516D54516D4D4A73444363403F693C3B663430
66393A674F456B3937593934462D242C15136F3026967D6680685D6A5142664742634A41
72554A6C584E3F2F2ABDB7C87672737D7C7E787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375786E70787375787375787375787375787375787375
7873757873755B4D5B00060005111B85766C7D685E785C54785C5B72555478725F785757
65433C5C3A32877C717D716E78686378605B78686378686378544F6E58497459506A5146
704E4662473C723E3F673F38592F2E4627284B272B75573E81655F705545664742634B3F
724F486C554C15171ABAA7A289878D787476787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
78737578737566515179645D725B546E594E79645B7D645B786560785758786A60786058
684C4265403A715449857E737D716F78635F78605B786C6778524F6E4D46704D44705C4D
674A415F49416E463969483E694C3E69453E64463E725749775A5170514662463E684D41
6D52446D514A131315CEBBC885857D787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375736B6D7D5946735C57745E526B686E8A645078696378686378645F78686378635F
724D4969514365413A7A6D617E7673786C667854537371617D685E6A4942704A42674539
67574A5B3F3765493965443E694B3860413A6543367C615871554B6B4D4462463E684A41
6852456C524906090DD7B7B396979B787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375725A5178635D6A4D426B51456F6E6E7F5857787268786C67786863786863786863
78524F72514A65463D75514A837F7B786C6778525372615878655C6848426B4E43613D37
674F465B3A3265463A6549406E4E3F67473D674C4172574E6B4B426B4E45674B4263473F
6852446D514A02080C5C413BE3D7D978787A787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
78737578513F73605B5E382E7F726A795A5978655B786564786C67786C6B78635B786863
785F57785C5065463D704E437F736E7D6C6A78645A78686778605B6E504966463E6B4D44
684E4563403A64453560403C6E514777534D755B4F6B5249664E466C4B43684B42684B42
684F436C564D081215201A1C54433FE0DBDD787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
78625D6F4B3E6B403A62524278786F8F605B78655B786464786C67786C6A786762786863
785F5B7360536E50496F594E79665D78655F7358537D756978575A6A584465423E684D44
64493F6D4D3B5B3F356E453C725A507757507A5D546A51496651486C4D44674E45634E41
6C4A446C6155593A2F372C2C2F4D5B827E80787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
784740653B335D302D685E4E76746B7F696378685F78605C786C6778686378686378645F
78645A6E5C537859506E655B7E696378685F72535078655C78504C654D4262403A64463D
60423969483A5F433B6E504772574E715A517A59516A5149664E466C4B426C4A45674D42
684A3F71625B5F392D6D504996B6C4726E70787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375786660
784E4A65363459342D725F5586786C786564786C6778635F78645F78686273645A7D6862
7858576E645379585073655A7E6D6B78685E78646378645F78504C65493C5D463E5F433B
60443B5C48406E4C3F72564F77594F745D5470554C7051486651486C463E6C4A44684A44
684F41725E5E623A2F644F46818B978E9090787375787375787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873757873757873757873756F4737
6C484055382E7044378D726585736778646478686378686278645A78605A6E6057795C57
745852795D57746154745D557E696378645F78645F78645F73534F6A40395D433C5F433B
65473D644E4469524577555071594C75594F705950704E46664E466C4B4368484068473F
684E4572615B642F23716D6263484491B6C3787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375602B1C
321F1754342E472B27C0917984736C78645F78645B78645E78645F786058726058725754
694D4770514C705F507F6C6179695E7D686778645F78645B6E544F66463B5E3F3E644937
60433C7351476C564C724E4871584E76554F6B544771584D674D446D5147684E4568463F
684A486D594D5B302473574A6D3F3C91BAC4787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375786B685F2B22
1B19162D211E3A2525C4947A84736A73605A7D68637864576A544E7A625A6C50477A5C50
75534E764A47765B4A775B4F7B6B5F83726F78645F78645B6E4C496043395A3D37654335
5C47406E4A406954496D4D4376554A77595267473F71554C674E46634B42684E4568463F
684A4868524548291F63322581514197BFD1787375787375787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873757873757873757353476A4443
170B0A2B1B18362220E2A3877A695F78605778696378645B624C4656433B533B33443331
452D29683527865445673429704132A799897D6C6A78645F6E50496040395A4032604738
5C3D3874554B634F475E4B44684B4368504A604D417C594E6C5249634B42604A41694A41
724F48684F453B211D5227207A453697CAD8787375787375787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873757873757C77796C3F30613F3B
040C111B1413341C1AE4B49578655C745C547D695F78645B725C584C3831554845151A1B
23171741221A5B413B7335296A474084776A7E6D6C7868676E4F42603C3752392F614734
3C1511956E596E4D396349415D3B3080584D604D447855466D514A684E4557433B614D44
734E4860493D3C221F6234297F484197C2CC726E70787375787375787375787375787375
787375787375787375787375
78737578787A786F7178787A787375787375787375787375787375291210DB8C71695149
15141715141A281714F4BC9C79645B78645B74605779645A7D6867624B42714E4A2A2C2C
1D222724201D3E3732694A4079544D7A6F627E7674786C6A6E5348603F3950372D543D34
341C1B5F4D4A473229180C0E6F3A2D5A453B4328207F52456B44328153445B4D46614A42
734A444B3C33301C1A582F27A3685996B6C5716D70787375787375787375787375787375
787375787375787375787375
786F7178787A786E707873757873757873757873757873752B181626161547100C7A4839
22161C1E17152E1A18EAB8997460577E696365453E7665558A7A7772645B6D4F495E433D
5D453A58443B593F376E58487656527463587E76747868636E4C45604A405A372C574538
57332E524E4C2F2D2C04090D4C251C4533302A1F1C6D42346343367654435B443E5C4D44
734F412A1E1F31211A45241EA855429CCCDA777274787375787375787375787375787375
787375787375787375787375
786F7178737578737578737578737578737578737578737503000331221C29141535231F
150E112F1C19301A19E4B19178645B74645E6C4A4C5C443B68493F7F64576F564B63423D
5C352D69433372443673463695796A7F6A5F7E6D6C78685E6E4C486051485A3931604534
614A3A73534A5F443F051A232824243027252F2B2861473D614636614F476D4B3F5F4B46
614A3F1813142A1A1846251D92382AA3DAE6787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375030003231411231816281816
1F15142318163D2725CD92778A6D6272655B78656466534C4D3933513533443D3A60413B
392D29483A334D332D65473F786E637966617865607858536E5C4D604D465A36374B2B1F
5E3A2B82674B725249684E446247424B3B324B3936704D4060473D684A46614E3F725244
4B3B35110F10231715884F4054221DB0DCE7787375787375787375787375787375787375
787375787375787375787375
787375787375786F7178787A7873757873757873757873750600021D100F211816201715
150B0D2819163E2C29AC765F9676687D6D62786464786863725F57614545463F43654947
573F3B584540523B386A4B42705F567E6D6C735C53795857735A506451496043443B2725
311C1D4A31244C2F24935845815F52684E3F5F4B41614A4164463D5C453E73504A694E3F
2A1F1B1712132A222094493750241D4E4A48DAD6D8787375787375787375787375787375
787375787375787375787375
787375787375786E707873757873757873757873757873750A0304251817211514221715
1711102818163D2C299E675293776A7E6D63786464786C67786863786C6B786762786762
78635B786C6B78635B78635A725C50786963725F576E59507458506E5D546F5951634A47
332A2F2B24241C201F4327204D30257141345B463A683F32623E327857506A4B4264463D
1310112016142B1D1F4218135A1F17343433DEDCDE787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375060305302423171212261715
211614281B1C3B2B278A59459774658A766A78645F786867786C66786C6A787172786C6A
786762786C6B78625A78686378635A78605478645B6E544D745951745950746157745454
64554D6147434034332B2929292725412B2743362F5F42384C40397144456450415B4037
110E112116142118161F12103D1C1A453734DEDCDD787375787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873750B040633231E211A1A211514
2813112C1C1B39261F5F4136A2715E8B7A6D7D685E786464786C67786C6B786863787172
786C6A786C6A78625A78686378645A78645F7860536E544C746157745951745950745853
6A554B6A5148614E465A47405948414738334D3C3761423B5F4B4664443F5B473D3D2D25
1A1315211614291A191A1514291816412A22B9A2A79A9F9F787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873750A0304372928251A19271817
1B12102A18162A191651302682523BA88B7D7E6D62786464786C67787173786762786863
787172786762786762786863785F5378645F73584F735850745950745D53745850745950
6A51496B4E466B524967524A684B426C4E45634E4560463F694A44694A41573C33261B1A
1911102B1B1D1D13141D1411160C0E3B201C8B6A65B5BDC0787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873750601033127272E2221271A19
2417162116142C1E1C422D2A59392DB37E6A8A756978686778686378716E787172786762
786C6B78625A786863786863785F5773605373585074585074585074595070595075554C
70554C664E466C52496C554B674E46684B42684E4557463F694A4158463D3A2B271D1516
231C1A170F111D1416140C0D1C13152B1916765954C3C5C8787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873750A03043428263528262C2120
271716191210331D1B442C24573B30905B47917E727D6D6678646378686378716E787172
786C6A78676278635B786863785F5B7260536E554D70544D75554C7958546A584C705148
70554F6651466C52496C4E45685147684E4564463D634D446142394B393433211D221717
1C14111A1215180F111B13101C1316301B19B3ADAC7E7B7D787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375786F71736F710A0709352725392B29312422
201413271D1B2C1D1C3825216D40307F4F418D7669837266786464786863786863787173
786C6A786C6A78625A786863735C537D645A6E544C6E58506F554D70524C70554C704E46
6B564F6B4E466849456D5145684E45684E4563433C604A4257393144322C231A18261818
1A15141E16151D15141B1310201716321B19FFFFFF726E70787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375786E70726A6C0503053E2721312726372927
281E1E281C1A2F222034221C5F453B6D3F32976D5E857A6D7D6867786863786C66786C6A
786C69786C6978635E73645A735C5279645B73504970554875585270554870554F705249
6652496C5148674742634F45684A41684D44604A4157423950342C3824232619161F1615
1C13111D1416191011110C0D1C11124A2B27E6EDED777274787375787375787375787375
787375787375787375787375
78737578737578737578737578737578737578737578737503010433211A372B2B372928
2C201E29191836251E3326244D3B32522C2495604E9184757E696378645E78686778685E
7868627868627864637260536E554D745C5370504770544870554F70594970554C704D44
66554B6C4E456C4E45634E4568463F64463D53453C50372E38242331211C2015141E1715
2216141A1315170F10160F112D1B19A396967B7A7C787375787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873750D0608271D1B3527253D2B29
2C1F1A2B1F1F2D1E1B382927352622432C297E493896745E8A796F79645A7D686278645B
78645B73605779645E7D685E6E50497051487055486B4B4571554E71554B76554B6B4A42
6B51486C4945685245684E4164433D60463D4B3C343E24202C201C2316151B13111D1416
271815191215140B0D191011361E1AFDFCFC777274787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375170F0F292021352826352624
33242125191B2D1F1C33252237292833221C502E25875D49916C5D80665A7F6C61796459
79685E736057745C5379645A6F534C6B473F7154476B4D456C4D446C554A7251476B4E45
684A416D4A4464493F644C3F5B423958392F4F372D2A1D1A2316151F16151B1210180F11
1B1011110C0E110C0D301C1A351E19EBF2F7787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375231919191312342927312422
3B2D2B281B182719183A2D2B2F22203A29262D1D1A5E43366340358A534290716271574C
7B675F765F56765C4E7B6056674D445B3D3571493D774D3D7250496D4E446D453B6D5349
684A396446426042395C41385041384128243E241D261A182016141A1311180F11180F11
140C0D100C0D180F112C1A1695807D87898B787375787375787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873755B50590E0708281E1D352725
3828262A201D27181A3D281F3025253E2F2D2D222238292545322E61392E7147375F4643
61493F76483B74584A715246593D3756372B56362B6C43317143396D4C3B73453960443C
603D2F6840356142384F3A344B2F2839211B2E1A182116151C1311180F11140C0D110C0E
110C0D100C0D2318162E1B19F3EEEF787476787375787375787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873757873751911111B1513372928
3128262E23211B14133A26223E2F2D3B2D2B3C2F2D362B2A41332D46332D463129412C2B
422B224A2C285A362B583E343E2B2A472D284E2C244E2F22542F29664131623C2F55362B
57382D4F2E25553831472B263C26202A19172C1E1C1912101C1311170F11140B0D100C0D
100C0D2517151B13156B4C47B7C0C3787375787375787375787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873757873753E35410D0A0A312624
33272533252427201F3628273E2F2D3E312F3729273B2C2A422A26492F27372821322626
2E1E1B3C2927321B18432E2A362625322321341C1936221E361D1A41211C442B203F271F
422820381C1A3A201C341E1B321D1A1F16151F1412180F11191011180F11100B0D100C0D
25171D2517142F2524B9A9A87D7A7C787375787375787375787375787375787375787375
787375787375787375787375
7873757873757873757873757873757873757873757873757873756C646C12090C1C1515
3326243729283124234233312C201E4534312C201E3C2C2A462F2A372625342421332624
2A1F1D3E2B292016183126222F1B192D1C1A231615221816281715311B192F1C19261815
291916281715311B192317152717161A13111C1311170F11180F11100C0D100C0D180F11
32211F281917909091827E80787375787375787375787375787375787375787375787375
787375787375787375787375
78737578737578737578737578737578737578737578737578737578737541353C100C0C
3229283729283124223026233D2C2B3F322F292222312220492B23281E1E332422312321
231A2036272225181B2D1C1924161C2217142117151C13112218162418162317161D1311
1A10111F14112A18161C13111A10111D14111C1315170F10100C0D180F111D1615291C1C
2C1B19837F81838082787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375665A620F0507
271E1E392B29312422322826362B293E2C2A2C211F2B1E1C33201D231615352623271A1C
261A1D25181525171E1E14141A0F121E14161D1415180F101E15161910111E1416180F10
1C13152017141D1315180F10100C0D120C0E120C0E110C0E1C13151B13101910112C1612
897F81898A8B787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
78737578737578737578737578737578737578737578737578737578737578737532282A
0B080A241B1A352725352B293329273E2D2B2C21232718162B1F1D1D15142A1917201716
271716180F111B10121D14161B1214180F111D1416170F101D1416170F102E1C1A0D0B0D
2015162118151B1215100B0D100C0D150C0D1B13151912141C13152C1B18291E1B48312B
B8C7D3787476787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
32282A0805072621212F22203E302E3B2D2B352929231B1A2F211F1D14191C1314251815
1C13151E16141D15141B1315180F11180F11191011180F11191011201715201416292630
2621201E1317160F101A13141C15141C15141B1315302320221A1A2C1A184F3129938E8A
7D7C7F787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
7873753425270807092822222F22203A2E2B4433302D25252D1E19231A1C1A14141D1315
180F111E15111D1416180F11180F111C1315170F101C1315170F101A1011322C2E2C1E2B
4237302B23261D191D2C2524211B1A1A14132A1D1C2E201D3729283B231F8980827F8284
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
7873757D787A312325110A0B2D292A3026254535323B2F2D362926211818251C1A2B2222
1E1A1B1E14131D16151A12141B1314180F11180F1121181D1A12131F1614211719332525
3F2C291E1516271A18281B1820151625171530201E34221C543A30645B6691928E787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
7873757873757873752C1A17150F0F261C1C41302D4D3D3B4037362A21212218182B1C1E
2D1C192F2423221D1C171013180F11241B2020181C2A211F1E171D362924161218493832
2D2124251E1E29201F251D1C292021352A26281F1F55372C7B76786C6871797677787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
7873757873757873757873752C23210D0A0E1A16143C2C2A443532403A403628242E2729
312A2A281D202A282831293129262220191E27212C322522342F3B33251F251E20443330
3526263624223626202F282841302A50392F251E1CA597937D777A787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
78737578737578737578737578737560555E231D1E0F0A0D362B2637353F5E4946433838
433935362D2F3734394235384438362C2324362D312D21243527263728253B2D2B372928
462924402B273D2D284134323A2621634B4A5A5954817E81787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
78737578787A787375787375787375787375787375787375787375787375787375787375
7873757873757873757873757873757873757873752C232E2823231B1F2B2924295A4A46
514D533D35304338374338374639384335384036332F2B2D392F2E2E2927413637413433
3A2B2646322E3A262480686B4A403846393F7D7A7C787375787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
786F71787375787375787375787375787375787375787375787375787375787375787375
7873757873757873757873757873757873757873757873757873756C646C2D2A394B4043
5A525F4739424E40362F292E302A2A5241454D3931493B3A513E3C4639354638364B342D
443831857C7F221D2064565F7A7779787375787375787375787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
7873756C64707970716056633A36433E3A47382F2F392F30393537393032332C2D2E2320
2F28267F777A787375787375787375787375787375787375787375787375787375787375
787375787375787375787375787375787375787375787375787375787375787375787375
787375787375787375787375
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?oooeUhLgD4KTXi17iYG`=hI6@4N6aW17QOF`AhK6L;N6QS17QO
F`AhI5L4KUaD17AID0AZCDD4L5E<0fI>AQ1/DTT4K4]20f=>?`AXCTP4J4ho16Q>B0BAZ[T?N7=e17QZ
K0AhN7XSN7=e5Oooo`005?oooeUhLgD4KTXi17iYG`=hI6@4N6aW17QOF`AhK6L;N6QS17QOF`AhI5L4
KUaD17AID0AZCDD4L5E<0fI>AQ1/DTT4K4]20f=>?`AXCTP4J4ho16Q>B0BAZ[T?N7=e17QZK0AhN7XS
N7=e5Oooo`005?oooeUhLgD4KTXi17iYG`=hI6@4N6aW17QOF`AhK6L;N6QS17QOF`AhI5L4KUaD17AI
D0AZCDD4L5E<0fI>AQ1/DTT4K4]20f=>?`AXCTP4J4ho16Q>B0BAZ[T?N7=e17QZK0AhN7XSN7=e5Ooo
o`005?ooo`AhLgD4N6ma17QhNPAhLgD4N6ma0gQhNR=hLgD4N6ma17QhNQMhLgD4LTdk17QUH0=hI5/4
N6a[17QOF`AhK6L4N6QS17QTFP=cI5d4NFAM17UPEPA_Fe84L5Q>175AB0AaED/3Ide4175EB`Q/DTT8
K4i50f=>@PAXCTD4J4ho16QOH@BAUYd?N7=e17Q^L2MhLgDEoooo000Doooo17QcM@AhKg44N7Qj17Qc
M@AhKg43N7Qj8gQcM@AhKg44N7Qj5gQcM@AbCC/4N6EP0gQTF`AhK6/4N5mK17Q/I`AhJ6<4N6AJ0g=T
G@AiI5d4NF1F16mKDPA`F4h4LE58175EB`=WCD@4LEE;26aBB@Q/CTD3Hdi216Q>A@AXCSl4J5mQ196F
W@mhLgD4N6i`9gQcMAGoool001Coool4N7=e17Q_L@AhN7X4N7=e17Q_L@=hN7XSN7=e17Q_L@AhN7XG
N7=e179=>`AhIF03N6AK17Q/J`AhGe/4N6aW17QXH`AhI5X3LfAM17UTG@AiH5H4Ke]B171HCPAaDDP4
LEE;0fM=A0AaED/8K59926a>A@=SCT84J4i516Q>?`AXGf44TIJM3gQcM@AhKW0WN7=e5Oooo`005?oo
o`AhLgD4N6ma17QhNPAhLgD4N6ma0gQhNR=hLgD4N6ma17QhNQMhLgD4LTdk17QUH0=hI5/4N6a[17QO
F`AhK6L4N6QS17QTFP=cI5d4NFAM17UPEPA_Fe84L5Q>175AB0AaED/3Ide4175EB`Q/DTT8K4i50f=>
@PAXCTD4J4ho16QOH@BAUYd?N7=e17Q^L2MhLgDEoooo000Doooo17QcM@AhKW04N6ma17QhNPAhKW07
N7=e17Q_L@AhN7X4N6ma17QhNPmhLgD4N6i`6gQcM@AcCS`4OFQR0gQTG`QhJ6<4N6AO17QXHPAcH583
IUaG181LD0AeE4h4JeM;16]HC`A/DTT4K59:0fM;@`AXCTD8KE5716e>A@A]CT43J4i816Q>A@AXCT84
NXbH17YfNA=hLgD4N6ma17QhNQmhLgDEoooo000Doooo17QcM@AhKW04N6ma17QhNPAhKW07N7=e17Q_
L@AhN7X4N6ma17QhNPmhLgD4N6i`6gQcM@AcCS`4OFQR0gQTG`QhJ6<4N6AO17QXHPAcH583IUaG181L
D0AeE4h4JeM;16]HC`A/DTT4K59:0fM;@`AXCTD8KE5716e>A@A]CT43J4i816Q>A@AXCT84NXbH17Yf
NA=hLgD4N6ma17QhNQmhLgDEoooo000Doooo17QcM@AhKW04N6ma17QhNPAhKW07N7=e17Q_L@AhN7X4
N6ma17QhNPmhLgD4N6i`6gQcM@AcCS`4OFQR0gQTG`QhJ6<4N6AO17QXHPAcH583IUaG181LD0AeE4h4
JeM;16]HC`A/DTT4K59:0fM;@`AXCTD8KE5716e>A@A]CT43J4i816Q>A@AXCT84NXbH17YfNA=hLgD4
N6ma17QhNQmhLgDEoooo000Doooo17QcM@AhKW04N6ma17QhNPAhKW07N7=e17Q_L@AhN7X4N6ma17Qh
NPmhLgD4N6i`6gQcM@AcCS`4OFQR0gQTG`QhJ6<4N6AO17QXHPAcH583IUaG181LD0AeE4h4JeM;16]H
C`A/DTT4K59:0fM;@`AXCTD8KE5716e>A@A]CT43J4i816Q>A@AXCT84NXbH17YfNA=hLgD4N6ma17Qh
NQmhLgDEoooo000Doooo27QcM@AhJV`4N7Qj2gQcM@AhKW04N7=e17Q^L39hLgD4LTXi17QYH`MhI5l4
N6QS17QTG`AhI5/4LV1K0f5LF0A[E4X4LdY>161?@0A[DTT4JeE?16]EC0=VBD84He5536Q>A@AXCT83
K59916=;@PAXCTD4TJZi5gQcM@AhKW0SN7=e5Oooo`005?ooo`QhLgD4N6Y/17QhNP]hLgD4N6i`17Qc
M@AhKW0bN7=e179:>@AhJF<7N6AO17QXH`AhI5l4N6AK179PF`=QG5P4JeA:17=:CPAPCd04Je9916]E
C`A[ED`3ITU216=AA@aXCTD4J4i20faBB@ASBd84J4i5196Z^AMhLgD4N6i`8gQcMAGoool001Coool8
N7=e17QZK0AhN7X;N7=e17Q^L0AhLgD4N6i`<WQcM@AbBST4N6US1gQTG`AhJ6<4N6AO17QTF`AbH5/3
HEaH16]DBPAcBTh4H4m016]BB@A[EDl4JeE<0fI9@PASDDD<J4i516Q>@P=/DTT4Hd]216Q>A@BAZ[TG
N7=e17Q^L2=hLgDEoooo000Doooo27QcM@AhJV`4N7Qj2gQcM@AhKW04N7=e17Q^L39hLgD4LTXi17QY
H`MhI5l4N6QS17QTG`AhI5/4LV1K0f5LF0A[E4X4LdY>161?@0A[DTT4JeE?16]EC0=VBD84He5536Q>
A@AXCT83K59916=;@PAXCTD4TJZi5gQcM@AhKW0SN7=e5Oooo`005?ooo`QhLgD4N6i`CGQcM@AhCC/4
N6EO0gQTGPAhI6<8N6AO17QTF`AhJ6<3N6AO179LE0AdE504KTe916mBA`A_DTd4Jd]90fiBBPAL@Cd4
Ide516MJD@ASB3d4K4i50faAB0ASCTD4K5I=18^P[cihLgDEoooo000Doooo27QcM@AhKW1=N7=e17Q=
>`AhIEl3N6AN17QTH`QhI5l4N6AK17QXH`=hI5l4LUaD17ADD0A^CDT4Ke9716mBC@A[BdT3KU9:15a1
?@AWCDD4IeYA16=8?@A/CTD3K55816=>A@A/ETd4Rj2_?WQcMAGoool001Coool8N7=e17Q^L4ehLgD4
N4dk17QUG`=hI5h4N6AS27QTG`AhI5/4N6QS0gQTG`AbG5@4M5A@16i=B@A_DTL4Ke9=16];B@=^DTX4
G44m16M=A@AWFU44HdPm16a>A@=/DDP4Hdi516aFC@B;X:lnN7=e5Oooo`005?ooo`QhLgD4N6i`CGQc
M@AhCC/4N6EO0gQTGPAhI6<8N6AO17QTF`AhJ6<3N6AO179LE0AdE504KTe916mBA`A_DTd4Jd]90fiB
BPAL@Cd4Ide516MJD@ASB3d4K4i50faAB0ASCTD4K5I=18^P[cihLgDEoooo000DooooFGQcM@AhDCl4
N6AK0gQTG`AhI5/4N6AS17QTG`AhJ6<4N6AO0gQXHPAhJ6<4LUaD179GD0A^DDX4M5EA16iBBP=`ET`4
JTI616I;@`A/DTX4IeE@16Q8?@=]CTD4J4i517]_KPAoRi8KN7=e17Q_L@AhN7XKN7=e5Oooo`005?oo
oeUhLgD4N54o17QTF`=hI5l4N6AK17QTH`AhI5l4N6QS17QTG`=hJ684N6QS179LE0AbEe04KU5:17AE
D@A^DTX3L5I<16Y6APAVBd<4K59:16MED0AXB3d3KDi516Q>A@AkKfh4Oh^B6gQcM@AhKg44N7Qj6gQc
MAGoool001CooomIN7=e17QA?`AhI5/3N6AO17QTF`AhI6<4N6AO17QXH`AhI5l3N6QR17QXH`AbG5@4
LUM@16iABPAdEE44KU9:0g1FC0AZATH4IT]316aBBPAWEE04J4Pm0fe>A@AXCTD4Nfm^17n;TQ]hLgD4
N6ma17QhNQ]hLgDEoooo000DooooEGQcM@AZDTd4RG=S17QTG`MhI5/4N6AT17QXH`AhI5l4N6QS0gQT
G`AhJ6<4N5mK17QTF`AbF4d4LUEA1fiEC@A[BdT4JU9616I;@PAXEDd4J4e40fa>A@ASCTD4Qh^F17io
PA]hLgD4N6i`2gQcM@AhKg44N7=e17QhNPQhLgDEoooo000DooooEGQcM@AZDTd4RG=S17QTG`MhI5/4
N6AT17QXH`AhI5l4N6QS0gQTG`AhJ6<4N5mK17QTF`AbF4d4LUEA1fiEC@A[BdT4JU9616I;@PAXEDd4
J4e40fa>A@ASCTD4Qh^F17ioPA]hLgD4N6i`2gQcM@AhKg44N7=e17QhNPQhLgDEoooo000DooooEGQc
M@AZDTd4RG=S17QTG`MhI5/4N6AT17QXH`AhI5l4N6QS0gQTG`AhJ6<4N5mK17QTF`AbF4d4LUEA1fiE
C@A[BdT4JU9616I;@PAXEDd4J4e40fa>A@ASCTD4Qh^F17ioPA]hLgD4N6i`2gQcM@AhKg44N7=e17Qh
NPQhLgDEoooo000DooooEGQcM@AZDTd4RG=S17QTG`MhI5/4N6AT17QXH`AhI5l4N6QS0gQTG`AhJ6<4
N5mK17QTF`AbF4d4LUEA1fiEC@A[BdT4JU9616I;@PAXEDd4J4e40fa>A@ASCTD4Qh^F17ioPA]hLgD4
N6i`2gQcM@AhKg44N7=e17QhNPQhLgDEoooo000DooooDGQcM@A2=2l4Zgm`17mZH0AhI6@7N6AK17QT
G`AhK6L4N5mK17QXGP=hK6/8N6AO17QTF`AhH5L4Le5=17=HC@=dEE04JU5516];A0A[DTT4Id]216=>
A@=bETd4Id]318JKZ`AhM7HZN7=e17Q^L0AhKg4<N7=e5Oooo`005?oooe5hLgD4@S@_1:]oL0AoJV04
N6AT1gQTF`AhI5l4N6aW17QOF`AhJ5h3N6a[27QTG`AhI5/4N61G17=AC@AcF4d3M5E@16YAA@A[Bd@4
Je9916M;@PASCTD3LUI=16M;@`B6Vj/4N7Af:WQcM@AhKW04N6ma37QcMAGoool001CooomAN7=e148d
;`B[Og04OfYP17QTI0MhI5/4N6AO17Q/I`AhGe/4N6QN0gQ/J`QhI5l4N6AK17QPE`AcDDd4LeQ=0gAE
D0AZDDD4Jd]416]BB@AWBd84Hdi50g9FC@AWBd<4QY^[17QdMRYhLgD4N6i`17Q_L@ahLgDEoooo000D
ooooDGQcM@A2=2l4Zgm`17mZH0AhI6@7N6AK17QTG`AhK6L4N5mK17QXGP=hK6/8N6AO17QTF`AhH5L4
Le5=17=HC@=dEE04JU5516];A0A[DTT4Id]216=>A@=bETd4Id]318JKZ`AhM7HZN7=e17Q^L0AhKg4<
N7=e5Oooo`005?ooo`QhLgD4N6ma17QhNSehLgD4IUYP11P>30CX_:@4N6EG17QXJ0=hH5/4N6QS17QP
F`QhJ6<4N6AK0gQTG`AhI5X4N5QJ17=SDPAdGe<4NE]F17AID0=`EE04Jdi2171>APAVDTT4J4/n16Q>
B0=]EDX4KE57192Y^49hLgDEoooo000Doooo27QcM@AhKg44N7Qj?GQcM@AVFV0460h<1>RlY0AhIEL4
N6QX0gQPF`AhJ6<4N61K27QXH`AhI5/3N6AO17QTFPAhF5X4Lf=B17AOD`AiFeH4M5U@0g1ED0A[CT84
L4i616IBB@AXBch4J4i80feEBPA]DDL4T:Vh@WQcMAGoool001Coool8N7=e17Q_L@AhN7XmN7=e16IJ
H0@H3P`4j;bT17QUE`AhJ6P3N61K17QXH`AhH5/8N6QS17QTF`=hI5l4N6AJ17QHFPAcHe84M5mC17UK
EPAdFE03L5E@16]>@PA`CTH4IU9916Q;?PAXCTP3KEE:16eAA`B@ZKQ2N7=e5Oooo`005?ooo`QhLgD4
N6ma17QhNSehLgD4IUYP11P>30CX_:@4N6EG17QXJ0=hH5/4N6QS17QPF`QhJ6<4N6AK0gQTG`AhI5X4
N5QJ17=SDPAdGe<4NE]F17AID0=`EE04Jdi2171>APAVDTT4J4/n16Q>B0=]EDX4KE57192Y^49hLgDE
oooo000Doooo27QcM@AhKW04N6ma17QhNSEhLgD4O7Mi12<F50A_F5<4R79Y17QTG`AhJ6<3N6AO17QX
H`QhI5l4N6QS17Q/IP=hGe/4Lf1C17U@D`AcFD`4JU5917EIC`AeF4l3L5Q;16I>B0AbCTD4Je5716M>
@PAWCTD3Hdi516aBB@B7SID4OHN<?WQcMAGoool001Coool8N7=e17Q^L0AhKg44N7Qj=GQcM@AlMgT4
8aHD16mHD`B8LVT4N6AO17QXH`=hI5l4N6QS27QTG`AhJ6<4N6aV0gQOF`AcH5<4NE1C17=IC0AZDDT4
MEU?17EHC`=`F4/4ITi8179>A@A[DDL4Idi216M>A@=SCTD4K59918N=U@AmQh`nN7=e5Oooo`005?oo
o`QhLgD4N6i`17Q_L@AhN7XeN7=e17agN@@S5Q@4KeQC18QbJ@AhI5l4N6QS0gQTG`AhJ6<8N6AO17QX
H`AhK6H3N5mK17=PD`AiD5<4LeU<16YAB@AeFDl4MEQ?0g1HB`AVCTP4LTi516]AA`AWCT84Idi50f=>
A@A/DTT4QhfE17f7S3ihLgDEoooo000Doooo27QcM@AhKW04N6ma17QhNSEhLgD4O7Mi12<F50A_F5<4
R79Y17QTG`AhJ6<3N6AO17QXH`QhI5l4N6QS17Q/IP=hGe/4Lf1C17U@D`AcFD`4JU5917EIC`AeF4l3
L5Q;16I>B0AbCTD4Je5716M>@PAWCTD3Hdi516aBB@B7SID4OHN<?WQcMAGoool001Coool8N7=e17Q_
LCehLgD4<B0K17MVH0AlI5/4N6EG17QTI0MhI5l4N6AK17QTH`AhI5l4N6QS1gQTG`A^@Cd4M5=>171;
@`A`CDD4L4e6171VE0=[DD@4Je5716a9@@AXDT@4LDi816a>A@=SCT44LTe6179UG@B?Y[@ZN7=e17Q_
L@AhN7X<N7=e5Oooo`005?ooo`QhLgD4N6ma?GQcM@@a81/4MfIP17aTF`AhIEL4N6AT1gQTG`AhI5/4
N6AS17QTG`AhJ6<7N6AO16i1?@AdDdh4L4]3171=A@A`CDH4L6ID0f]AA0A[DDL4K4U116QBA0AaCTP4
K4i50f=>@@AbCDH4LVEM18nV]2YhLgD4N6ma17QhNPahLgDEoooo000Doooo27QcM@AhKg4mN7=e134P
6`AgIV04O6AK17QUE`AhI6@7N6AO17QTF`AhI6<4N6AO17QXH`MhI5l4KT4m17ACCPA`Bd<4L4e5171=
APA`IU@3Je5416]AA`A/BD44J594175>B0A/CTD3Hdi1179=APAbIEd4SjJd:WQcM@AhKg44N7Qj37Qc
MAGoool001Coool8N7=e17Q_LCehLgD4<B0K17MVH0AlI5/4N6EG17QTI0MhI5l4N6AK17QTH`AhI5l4
N6QS1gQTG`A^@Cd4M5=>171;@`A`CDD4L4e6171VE0=[DD@4Je5716a9@@AXDT@4LDi816a>A@=SCT44
LTe6179UG@B?Y[@ZN7=e17Q_L@AhN7X<N7=e5Oooo`005?ooo`QhLgD4N6i`>WQcM@=VFUd49AdJ18Ma
IPAhI5l4N6AG17QTI0AhI5l3N61G17QTFPAhI5h4N6QW17QXH`AhEeH3N6=N16he=PA`?cT4Jc<_17I7
A`A[>cH4MTm90f9=@@A]DdH4KDi116Q:@@AbDTP4K4i50fM>@PA/ASl4IeI<17aaJ`B9WjdVN7=e17Q^
L11hLgDEoooo000Doooo27QcM@AhKW0jN7=e0fIJG@@U7AX4Qg5V17QTG`AhI5L4N6AT17QTG`=hH5L4
N6AJ17QTGPAhJ6L4N6QS17QGEP=hHeh4KSDf170o>@A[<bl4MTM716/k=PAfCdT3HTe116eCAPA]CT44
J4Y1179BB0A/CTD3Idi216a6?`AWET`4O75[18VO[BIhLgD4N6i`47QcMAGoool001Coool8N7=e17Q^
L3YhLgD3IUYM12DM6PB7LFH4N6AO17QTE`AhI6@4N6AO0gQPE`AhI5X4N6AN17QXI`AhJ6<4N5MF0gQS
GPA^=CH4L3li16/c;`AfAdL4Jc/f17I?B@=RCD44KE=616e>@@AXBT44LU9816a>A@=WCT84K4Ho16MF
C0AlLF/4RIn]9WQcM@AhKW0@N7=e5Oooo`005?ooodIhLgD38QLG1=^[U@AnJ684N6AN17QTF`AhI6@4
N6AK0g=HC`AiG5<4OFeR17QUI0AhG5<4Ld560gA;@`A_Cd`4I2dU17]HD@Ag@4<4HR@Q178h<P=[Ad04
Hdi416QIB0AXASL4KE99175>B0=/CTD4K4]216aBB0A/ED/4RiVQ17QlPcIhLgDEoooo000DooooAWQc
M@<R5aL4fj^E17iXHPAhI5h4N6AK17QTI0AhI5/3LeQ?17ULD`AmKF84N6ET17QLD`Ac@DH3M4]316m?
C0AT;BD4NeQA17M0@`AR9244LSPb0f]7@0ASCT@4J5U816Q6=`A]DTT4LDi80fa>A@A/Bd84K59816aE
B`B;VJ44N7b3=WQcMAGoool001Cooom6N7=e0b8G5`CKZiD4OVQR17QTGPAhI5/4N6AT17QTF`=cF4l4
NEaC17e]HPAhIF@4N5aC17=1AP=dBd<4Kdm<16@]9@AkF544Md13168T8@Ab>383JdM016=>A0AXFDP4
J4Hg16eBB@AaCTP3K4i516a;@PA/DTP4K5E;18^IX@AhO8<fN7=e5Oooo`005?ooodIhLgD38QLG1=^[
U@AnJ684N6AN17QTF`AhI6@4N6AK0g=HC`AiG5<4OFeR17QUI0AhG5<4Ld560gA;@`A_Cd`4I2dU17]H
D@Ag@4<4HR@Q178h<P=[Ad04Hdi416QIB0AXASL4KE99175>B0=/CTD4K4]216aBB0A/ED/4RiVQ17Ql
PcIhLgDEoooo000Doooo47QcM@AhKg43N7Qj:gQcM@AFATT3:b@O19n7M`AhIF04Lea?17eaJ`AhH5`4
N5a?0fYDA`A`BdD4RWA`16m5@0A46a<4]Wie0g0h=@A^FeD4G4M4168]9`ATDTH4Gc4Z16hm?P=K:b<4
QSXd16AOCPA]CCL4K4i716aFC0=aDdH4ITQ216aBB@A/CTD4O6iU18VEW0AhO8<bN7=e5Oooo`005?oo
oa1hLgD4N6ma0gQhNR]hLgD4ETI90b/T7`BOQgL4N6EP17=LC`AmLF/4N61L17QLC`=ZE4L4L4]518Yd
L0A_AD04A1/C1;InM@=`>3D4KU]E15a7A0AR;BL4I59615la:PA^?Ch3Fb/S18Hj=0ATGdh4KDdg16a>
A`A/ET`3LE=616I8@PA/DTT4K4i517a^I@B9UI`4N7b3<WQcMAGoool001Coool@N7=e17Q_L@=hN7X[
N7=e15I6B@<[91l4WhMg17QUH0AcG4l4OG5[17QPG0AhG4l3JUA7171;A@B:M704KdE014@K4`BfOWD3
L3Pe16iKE@ALAd@4HRdW16ABAPAO<BX4KSdn0e/[8`B6>S@4I5m>16e==`A/CTL4K5I<0g5CAPAVB484
K59916a>A@AlKVD4RIFL17QlPc9hLgDEoooo000Doooo47QcM@AhKg43N7Qj:gQcM@AFATT3:b@O19n7
M`AhIF04Lea?17eaJ`AhH5`4N5a?0fYDA`A`BdD4RWA`16m5@0A46a<4]Wie0g0h=@A^FeD4G4M4168]
9`ATDTH4Gc4Z16hm?P=K:b<4QSXd16AOCPA]CCL4K4i716aFC0=aDdH4ITQ216aBB@A/CTD4O6iU18VE
W0AhO8<bN7=e5Oooo`005?ooo`QhLgD4N6ma17QhNPAhKW0^N7=e11`B4`>kS7@4PFaV17QTF`A^D4T4
OWIc17QTG`AhE4T3H3ha16M4?@A@6QT4WXV313lJ6`AdEe<3KD=517=@C0AhKfP4J2TU165=CPA?=Bd4
BSPg0cXK5`A?8aT4TdXj17=SC0AbAd84LEiC0g5FBPAZCT<4IT]516a>A@A/ED`4O8FJ18AnM`=mO7h_
N7=e5Oooo`005?ooo`QhLgD4N6ma17QhNPAhKW0^N7=e11`B4`>kS7@4PFaV17QTF`A^D4T4OWIc17QT
G`AhE4T3H3ha16M4?@A@6QT4WXV313lJ6`AdEe<3KD=517=@C0AhKfP4J2TU165=CPA?=Bd4BSPg0cXK
5`A?8aT4TdXj17=SC0AbAd84LEiC0g5FBPAZCT<4IT]516a>A@A/ED`4O8FJ18AnM`=mO7h_N7=e5Ooo
o`005?ooo`QhLgD4N6ma17QhNPAhKW0^N7=e11`B4`>kS7@4PFaV17QTF`A^D4T4OWIc17QTG`AhE4T3
H3ha16M4?@A@6QT4WXV313lJ6`AdEe<3KD=517=@C0AhKfP4J2TU165=CPA?=Bd4BSPg0cXK5`A?8aT4
TdXj17=SC0AbAd84LEiC0g5FBPAZCT<4IT]516a>A@A/ED`4O8FJ18AnM`=mO7h_N7=e5Oooo`005?oo
o`QhLgD4N6ma17QhNPAhKW0^N7=e11`B4`>kS7@4PFaV17QTF`A^D4T4OWIc17QTG`AhE4T3H3ha16M4
?@A@6QT4WXV313lJ6`AdEe<3KD=517=@C0AhKfP4J2TU165=CPA?=Bd4BSPg0cXK5`A?8aT4TdXj17=S
C0AbAd84LEiC0g5FBPAZCT<4IT]516a>A@A/ED`4O8FJ18AnM`=mO7h_N7=e5Oooo`005?ooo`QhLgD4
N6i`<WQcM@AZHVd42`L70nRgU`AnJF<4N6AK179GD0AhIFD4N6AO16m6>`=I>b/4I2/U12dA3`B/PgL4
P7ma17UUH`=mS904N6=L17Q/I`AZC4L4Oh>316m?APAQI6H3;A`L12XW9`@m6QH4VDhk17MLD@AlHU43
M5iH16]>@`AVBd<4K4Lo16aEBPAXMWl4LVMZ0hF1T@B9Qgh[N7=e5Oooo`005?ooo`QhLgD4N6i`<WQc
M@AZHVd42`L70nRgU`AnJF<4N6AK179GD0AhIFD4N6AO16m6>`=I>b/4I2/U12dA3`B/PgL4P7ma17UU
H`=mS904N6=L17Q/I`AZC4L4Oh>316m?APAQI6H3;A`L12XW9`@m6QH4VDhk17MLD@AlHU43M5iH16]>
@`AVBd<4K4Lo16aEBPAXMWl4LVMZ0hF1T@B9Qgh[N7=e5Oooo`005?ooo`QhLgD4N6i`<WQcM@AZHVd4
2`L70nRgU`AnJF<4N6AK179GD0AhIFD4N6AO16m6>`=I>b/4I2/U12dA3`B/PgL4P7ma17UUH`=mS904
N6=L17Q/I`AZC4L4Oh>316m?APAQI6H3;A`L12XW9`@m6QH4VDhk17MLD@AlHU43M5iH16]>@`AVBd<4
K4Lo16aEBPAXMWl4LVMZ0hF1T@B9Qgh[N7=e5Oooo`005?ooo`QhLgD4N6i`<WQcM@AZHVd42`L70nRg
U`AnJF<4N6AK179GD0AhIFD4N6AO16m6>`=I>b/4I2/U12dA3`B/PgL4P7ma17UUH`=mS904N6=L17Q/
I`AZC4L4Oh>316m?APAQI6H3;A`L12XW9`@m6QH4VDhk17MLD@AlHU43M5iH16]>@`AVBd<4K4Lo16aE
BPAXMWl4LVMZ0hF1T@B9Qgh[N7=e5Oooo`005?ooocYhLgD4@S@_13/T8`APA3h3X8ag17QUF`AhG5<4
N6AI17Q/IPAhI5h4ICPc0eY;?PAJ=SH4<1DL17A2A`A_Ed/4L55<0gYZI0AnDTd4Kf5C170m>0AfBT84
K4Lm1821L0=Q>c<4EDM912PT8@A34P`4YViP17aYDP=jIUl4JTe216I:A0AXBT84LE=916MQF@A_Mh<3
FU5T192BRB]hLgDEoooo000Doooo>WQcM@A2=2l4>b@S1614?P>PS7L4N6EK17QLD`AhI5T4N6aV17QT
GPAU>3<3FT/n15Xf=P@`5A`4M49716mGB`A`DD`3NVYT17iBC@A_HE<4L3dh17I:@PA/Acd4P85`0f4k
<`AEAdT4:2@Q14<B30BVKV04O6UB0gYVG`AZCD84ITY416Q:@PAaDdT4If5I16mgP`=JDF@4T9:9:gQc
MAGoool001CoooljN7=e148d;`@k92<4H4@n0j2<M`AhIE/4N5aC17QTF@AhK6H4N6AN16Dh<`=JBch4
FSHf130E70Ad@TL4KeM;171AC0=jJV@4OU9=16mQD`A`?CP4MTY216a7?@B0PG03HC/c15E7B@@X9244
@a8<1:I^H0AlJE83NVIO16Y=@PAVBT@4J4Y2175CB@AWHET4KgN30eYAI0B@TXT[N7=e5Oooo`005?oo
oaAhLgD3N6ma17QhNQ]hLgD4JUiT10h:2@@Y61H4h:FD0g]XFPAhH5L4N5AD17=UE0AmJEl4N5QG16E6
>@=SACL4T8R317QYH0AhDe@4LUAA16eDD@=]CDX4LdA316=0?`AY?3/4IS@`16Hi>PAWCdD3JcTg15Ti
=0A6;B@4;1DC16l`9PBFOFH3P6QM16YA@PAVAd84HdY1179EBPA/F4h4?blZ0kfgb0AfLW<4OGan9gQc
MAGoool001CooolDN7=e0gQ_L@AhN7XKN7=e16YNI0@>2PT4:APF1>2UU0=kJ5X4N61G17QDE0AcIE@4
OFUO17QHE`AUAST3HdDg1928P`AhJF04N5=D179DD@A]E543KDe:17=4@`AS@3l4JC`k16Hd<0AV>CX4
Idm50f/i=`AI>C@4ARdT12`E4`A_<2H4UWeV0h1XG@AZDD84ITM216=:@@AbEDX4K5Q>13l_:P>m]lP4
MW9c17elORMhLgDEoooo000Doooo57QcM@=hKg44N7Qj6gQcM@AZGV@43PX912TH5PCPYI@3NfQJ17QP
E`AhE5@4LfED17eYG`AhF5L4IDHi0f=5=`B@R8<4N6UP17QCE0AbE544KEAA0fe=BPAcA4<4Hd0o16Tl
>`AV=304ISTj16M?A@=[>CL4FCTd14H]90@/5A<4Kc0V19ImIP>0J5d4JU5216I7@PASBT44LUE:16aH
CP@o;bX3_KO817IbL`AmO7hWN7=e5Oooo`005?oooaAhLgD3N6ma17QhNQ]hLgD4JUiT10h:2@@Y61H4
h:FD0g]XFPAhH5L4N5AD17=UE0AmJEl4N5QG16E6>@=SACL4T8R317QYH0AhDe@4LUAA16eDD@=]CDX4
LdA316=0?`AY?3/4IS@`16Hi>PAWCdD3JcTg15Ti=0A6;B@4;1DC16l`9PBFOFH3P6QM16YA@PAVAd84
HdY1179EBPA/F4h4?blZ0kfgb0AfLW<4OGan9gQcMAGoool001CooolDN7=e0gQ^L1mhLgD4FdeK1006
00@54A/4QGI/0geXGPAhG5@4N5aK179EE0AhLUl4N5MG16E3?0=L>S84Qgaa17eaKPAhJ6<4N61K1gQX
H`AhE4l4KUQ917AID0AZDDH4L4i61697?0=b?Sl4Iclh15T_;PA69bP4BbL[17EG?P>1IEl4L5E516I7
@PASBcl4LTm816aEC0@E5aX3^ZNR18V7S@AhM7HWN7=e5Oooo`005?oooaAhLgD3N6i`7gQcM@AKCE/4
00H010DA6`B5MV`3OFQN17QLE0AhG5/4LUED17QbG`AhEeL4ID<l0e`j<PB7O744OG5^17QXH`AhH5/7
N6QS17QDC`A^F4T4M5U@16YAAPA`CTH4HTLl0g8n?`AW?cP4FBl^14HW:0A;9b/4MELn0h5UG`A`EDD4
ITM216=;?`AbCdP4K5E<11DG6P>jYj84RHN=17QdMRMhLgDEoooo000Doooo57QcM@=hKW0ON7=e15]=
F`@01P041A4K18EfK0=mJ5h4N5aD17QLF`AbEE@4N79O17QGE`AU@c`3G3Xb18MlL@AmLFh4N6QS17QP
F`MhJ6<4N5A?16iHB@AdFE04JU56171>APARAc`3LSho16Lo>0AI;bh4ARLX14/W:`AeEch3PFEO171E
A@AVAd84Hd/o179?B0A/ED`45ALJ0kZWXPB9Qhd4N7Af9gQcMAGoool001CooolDN7=e0gQ^L1mhLgD4
FdeK100600@54A/4QGI/0geXGPAhG5@4N5aK179EE0AhLUl4N5MG16E3?0=L>S84Qgaa17eaKPAhJ6<4
N61K1gQXH`AhE4l4KUQ917AID0AZDDH4L4i61697?0=b?Sl4Iclh15T_;PA69bP4BbL[17EG?P>1IEl4
L5E516I7@PASBcl4LTm816aEC0@E5aX3^ZNR18V7S@AhM7HWN7=e5Oooo`005?ooocIhLgD4IU5A17UT
G@AbFe@4KUU>0gUTF`AmI5/4N6EP17QGF0AhJV04N61H16Q<@P=U@3X4LEA918EnL`AmLFl4N6=O17QP
F`=hK6L4N59?16i=APA`CD@4L5a=16M:@@AOBD43KTHi16U8?PAYC3h4JDDn16A6?PAbEdT3MeYA171A
APARASh4J4e116eBA0A]DDX44a<E0ljkb0B5QGd[N7=e5Oooo`005?ooocIhLgD4IU5A17UTG@AbFe@4
KUU>0gUTF`AmI5/4N6EP17QGF0AhJV04N61H16Q<@P=U@3X4LEA918EnL`AmLFl4N6=O17QPF`=hK6L4
N59?16i=APA`CD@4L5a=16M:@@AOBD43KTHi16U8?PAYC3h4JDDn16A6?PAbEdT3MeYA171AAPARASh4
J4e116eBA0A]DDX44a<E0ljkb0B5QGd[N7=e5Oooo`005?ooocIhLgD4IU5A17UTG@AbFe@4KUU>0gUT
F`AmI5/4N6EP17QGF0AhJV04N61H16Q<@P=U@3X4LEA918EnL`AmLFl4N6=O17QPF`=hK6L4N59?16i=
APA`CD@4L5a=16M:@@AOBD43KTHi16U8?PAYC3h4JDDn16A6?PAbEdT3MeYA171AAPARASh4J4e116eB
A0A]DDX44a<E0ljkb0B5QGd[N7=e5Oooo`005?ooocIhLgD4IU5A17UTG@AbFe@4KUU>0gUTF`AmI5/4
N6EP17QGF0AhJV04N61H16Q<@P=U@3X4LEA918EnL`AmLFl4N6=O17QPF`=hK6L4N59?16i=APA`CD@4
L5a=16M:@@AOBD43KTHi16U8?PAYC3h4JDDn16A6?PAbEdT3MeYA171AAPARASh4J4e116eBA0A]DDX4
4a<E0ljkb0B5QGd[N7=e5Oooo`005?oooc9hLgD4Lf]]17eIAPAcG5L4M5iB16]XKP>:I504N6US17QX
H`AhI5l4N6QS17QSG`AbCDT3JE5316E1>PAjKF44OWIc17Q/IPAhE5<3Lg5Q17eXGPAZBD84L4Y216M5
>@AWEdX4Fclg0fE9>@AUA3h4JD/h1611>PAU@cH4O65H0g5EB`A[CD@4HTHn16Q:@@AXDTD4K59910H9
3@?G]k<4UYNK:gQcMAGoool001CooolbN7=e17=[K@AmFDH4LeaG17ANDPA[J6h3RVA@17QYH`AhJ6<4
N6AO17QXH`AhHel4LTe90fUA@`AU@CX4NVeQ17ifL`AhK6H4N5AC0g=aH@AmJ5h4JTU2171:@PAWACT4
IeM:15/o=`=UBCT4ID@n16U;>0AP@CX4ID<f17aQF0=aED/4Jde41696?PAXBT44J59516aBB@@62@d3
ekNc19JGVb]hLgDEoooo000Doooo<WQcM@AcJfd4OEU617=LE`AdGU84JfQ^0hYTD0AhJF<4N6QS17QT
G`AhJ6<4N6=O179=B@=YDD<4ID4j17Y]H@AnMW<4N6aV17QDD`=cLF44OFQN16Y9@PA`BT84IdDi16MG
BPAK?cL3IDTi16E4?PAYBcP4H44j16E3=PAlHEP3LEE;16]=A0ARASh4J4Y116QBA@A/DTT41PT=0mNg
/`BFUi/[N7=e5Oooo`005?oooc9hLgD4Lf]]17eIAPAcG5L4M5iB16]XKP>:I504N6US17QXH`AhI5l4
N6QS17QSG`AbCDT3JE5316E1>PAjKF44OWIc17Q/IPAhE5<3Lg5Q17eXGPAZBD84L4Y216M5>@AWEdX4
Fclg0fE9>@AUA3h4JD/h1611>PAU@cH4O65H0g5EB`A[CD@4HTHn16Q:@@AXDTD4K59910H93@?G]k<4
UYNK:gQcMAGoool001CooolbN7=e179JD@AhHed4JTe216]AA@A_KVh3OeQG17QbJ0AhK6L<N6QS17QB
C`=bDDX4IDHm17EABPB3Og/4N6aW17QBD`=bHEP4N6EL16Q8@PA[CT<4HCdg16M?APAK>S83IDHj16E9
@0A^CSl4IdLm16M<@@AbEdh3Jd]216]>A@AWBd84HdLo16QBA0A]DDX40PP<0ea1>`CSemT4N7Qj9gQc
MAGoool001CooolbN7=e179JD@AhHed4JTe216]AA@A_KVh3OeQG17QbJ0AhK6L<N6QS17QBC`=bDDX4
IDHm17EABPB3Og/4N6aW17QBD`=bHEP4N6EL16Q8@PA[CT<4HCdg16M?APAK>S83IDHj16E9@0A^CSl4
IdLm16M<@@AbEdh3Jd]216]>A@AWBd84HdLo16QBA0A]DDX40PP<0ea1>`CSemT4N7Qj9gQcMAGoool0
01CooolbN7=e179JD@AhHed4JTe216]AA@A_KVh3OeQG17QbJ0AhK6L<N6QS17QBC`=bDDX4IDHm17EA
BPB3Og/4N6aW17QBD`=bHEP4N6EL16Q8@PA[CT<4HCdg16M?APAK>S83IDHj16E9@0A^CSl4IdLm16M<
@@AbEdh3Jd]216]>A@AWBd84HdLo16QBA0A]DDX40PP<0ea1>`CSemT4N7Qj9gQcMAGoool001Cooolb
N7=e179JD@AhHed4JTe216]AA@A_KVh3OeQG17QbJ0AhK6L<N6QS17QBC`=bDDX4IDHm17EABPB3Og/4
N6aW17QBD`=bHEP4N6EL16Q8@PA[CT<4HCdg16M?APAK>S83IDHj16E9@0A^CSl4IdLm16M<@@AbEdh3
Jd]216]>A@AWBd84HdLo16QBA0A]DDX40PP<0ea1>`CSemT4N7Qj9gQcMAGoool001CooolbN7=e17QA
?`AcH5/4GSP^17mbJPAiFUT3N6EK17QUI0AhK6L4N6a[17QSF`AhJ6<4N5mG0gQLD0AUASd4L4i317mc
KPAmK6X4N6AJ0gQXI`AhH5/4KU1916I6?PA[CD@4J4i516=0>P=TACD4H40l16iAA`AgDdd4ME]?16]B
B@=VCTH4K4]326Q;@PAXCd<4K5I=10PB5@<P6Q`4E4<o1>3KgBMhLgDEoooo000Doooo<WQcM@AhDCl4
Lf1K15hh;PAoLVX4NEYI0gQUF`AhIF@4N6aW17Q/J`AhHe/4N6QS17QOE`=hG504IDHm171>@`AoLfh4
OFaZ17QTFP=hJ6L4N61K16i@B@AVASh4Jde416Q>A@AS@3X3I4De1610?0A^DDL4Me==17EKC`A[DTT3
ITi616a;@`QXBd84J4m316aFC@@84QD381XL15A3?`CPfmdWN7=e5Oooo`005?oooc9hLgD4N54o17=P
F`AN>2h4Og9Z17UJF@=hIE/4N6ET17Q/I`AhK6/4N6=K17QXH`AhGeL3N5a@16E6?@A`CT<4Og=^17e/
JPAhI5X3N6QW17QPF`A^D4T4ITHn16]=A0AXCTD4Hd0j0fA5=@AP@3`4KU5717MCC@AeFdl4Je990fI>
APA/Bd<8J4]216Q?@`A/ETd4218E0b0J70AD@cl4h=_M9gQcMAGoool001Coool^N7=e17QRG@A_Bch4
Jd0j169B@PAhN6l4Sf1K0gQUF`AhI6@4N6aW17Q/JPAhIf84N6QS17QOF`=cH5<4KU1916mICPAiIUd4
N6EO17=HD`=mMFT4N5MJ16YHA0AU@Sh4J4e416A9?`A]CC/3Fcle16i5?0AbFU04MeM@17YME0AZDDT3
IU5816a=A0AWCTD4Hdi116a:A0A/HED4FCX_0cL/;0@_CE/4PWj09gQcMAGoool001Coool^N7=e17QR
G@A_Bch4Jd0j169B@PAhN6l4Sf1K0gQUF`AhI6@4N6aW17Q/JPAhIf84N6QS17QOF`=cH5<4KU1916mI
CPAiIUd4N6EO17=HD`=mMFT4N5MJ16YHA0AU@Sh4J4e416A9?`A]CC/3Fcle16i5?0AbFU04MeM@17YM
E0AZDDT3IU5816a=A0AWCTD4Hdi116a:A0A/HED4FCX_0cL/;0@_CE/4PWj09gQcMAGoool001Coool^
N7=e17QRG@A_Bch4Jd0j169B@PAhN6l4Sf1K0gQUF`AhI6@4N6aW17Q/JPAhIf84N6QS17QOF`=cH5<4
KU1916mICPAiIUd4N6EO17=HD`=mMFT4N5MJ16YHA0AU@Sh4J4e416A9?`A]CC/3Fcle16i5?0AbFU04
MeM@17YME0AZDDT3IU5816a=A0AWCTD4Hdi116a:A0A/HED4FCX_0cL/;0@_CE/4PWj09gQcMAGoool0
01Coool^N7=e17QRG@A_Bch4Jd0j169B@PAhN6l4Sf1K0gQUF`AhI6@4N6aW17Q/JPAhIf84N6QS17QO
F`=cH5<4KU1916mICPAiIUd4N6EO17=HD`=mMFT4N5MJ16YHA0AU@Sh4J4e416A9?`A]CC/3Fcle16i5
?0AbFU04MeM@17YME0AZDDT3IU5816a=A0AWCTD4Hdi116a:A0A/HED4FCX_0cL/;0@_CE/4PWj09gQc
MAGoool001Coool^N7=e17Q7@0AU>c<4GC0]16QNCPAfM6/4OfUS0gQXG`AhH5`4N6aW27QXH`AhI5l4
N6AJ0fiLD`AhFE04KVEK17iYH`AhJ5l4LU=@0gQUG0AhD4`4IDe21690>PATASd4H48i16U8>P=O@c/4
KU17179GCPAaFU44NUUA16YAB@=VCTH4K4]216a:A@AWCD84J4Xo175RF`AO>Bd3KE1919Jfa0AbKW0W
N7=e5Oooo`005?ooobihLgD4N4M016Dk<`AM<2d4J5i>17IdJ`AoJF<3N6QO17QPG0AhK6L8N6QS17QT
G`AhI5X3KUaC17QID0A^IE/4OVUS17QXG`AbDe03N6EL17Q@C0AUCD84HT0j16A6?@AP@ST4JDPj0em3
>`A^D4L4LUM>175JD@AjFE44JU590fI>APA/Bd84K4Y516M=@PAXBSl4LF9K15li;@=]D4T4U[K4179^
L2MhLgDEoooo000Doooo;WQcM@AhAd04IC/c15d`;@AXGTh4MWA[17mYH`=hJ5l4N61L17Q/I`QhJ6<4
N6AO17QTFP=^G5<4N5U@16iUF`AnJF<4N6QO179CD0=hIE`4N51<16E=@PAR@3X4I4Hm1612>@AYB3X3
Gd<k16i@A`AbEdh4LEYA17YID@AZDDT3ITi616a;@PA/BTD4Ide216Q:?`AaHU/4GcT]0fe@B@BF]/@4
LVi`9gQcMAGoool001Coool^N7=e17Q7@0AU>c<4GC0]16QNCPAfM6/4OfUS0gQXG`AhH5`4N6aW27QX
H`AhI5l4N6AJ0fiLD`AhFE04KVEK17iYH`AhJ5l4LU=@0gQUG0AhD4`4IDe21690>PATASd4H48i16U8
>P=O@c/4KU17179GCPAaFU44NUUA16YAB@=VCTH4K4]216a:A@AWCD84J4Xo175RF`AO>Bd3KE1919Jf
a0AbKW0WN7=e5Oooo`005?ooob]hLgD3N6IP17Q>BPAU=S@4FC@]179OE@B6N6`4N6ET0gQ/I`AhHel4
N6AO17QXHPAcI5X4OFQR17QHE`=^I5<4NEQ@17=UFPAnKF/4N6QN17QTH`=hI5l4N51<16E9?0AMASh4
Gd<k1614>`ALB403KT`o179FC`AgFDl4M5eD171EC0A`DDP3IU5816a6?PA/BT@4J4Y416Q?@@AbGUh4
HSX_0fA?APB1RiL4SY2@9gQcMAGoool001Coool[N7=e0gQVH0AhCTX4ICHd15Td;@AbGeD4QWQ/17QU
I0=hK6L4N6=O17QTG`AhJ684LfAJ17eXHPAhF5L3KVAC17UHD0AcIEX4OVe[17QXGPAhI6<3N6AO17Q@
C0AUBC`4GDHn15m3>`APA3/4G4Q00fi<?`AbETl4MeU?17AME0A`ED`4L5580fIAB0A/ASh4K4Y416Q:
A0AXCd44LUiN168j;`=TCdH4PH^G18j@T2MhLgDEoooo000Doooo:gQcM@=hIV04N4i:16Df=0AI=2d4
LUmE18IhK0AhIF@3N6aW17QSG`AhI5l4N6QR17=TFPAmJ684N5QG0fiTD`AiF504LfEJ17i]J`AhJ5h4
N6AS0gQTG`AhD4`4IDTl15e6?PAO@c/4H4@k15a8@0=^C3l4LUI?17MIC`AdGE@4L5E<171AB0=VDDP4
K4Hn16a:A0AXBT@4J4m1179NGPAR>Rl3I4m6186;U`B>T90WN7=e5Oooo`005?ooob]hLgD3N6IP17Q>
BPAU=S@4FC@]179OE@B6N6`4N6ET0gQ/I`AhHel4N6AO17QXHPAcI5X4OFQR17QHE`=^I5<4NEQ@17=U
FPAnKF/4N6QN17QTH`=hI5l4N51<16E9?0AMASh4Gd<k1614>`ALB403KT`o179FC`AgFDl4M5eD171E
C0A`DDP3IU5816a6?PA/BT@4J4Y416Q?@@AbGUh4HSX_0fA?APB1RiL4SY2@9gQcMAGoool001Coool[
N7=e0fm7=`A/B404ECP^1714=`B=LVD4QG=W17QTI0=hJ6<4N6QR17QTFPAhH5X4KV1G17ULE`AdF583
NEeG17AQE0AdGED4OVUS2gQTG`AcDdl4JT0i15e3?0AO@c/4IDLm16A>A0=YDTD4MeE@175IC0AeFDl4
L5U@171>AP=VCTH4K4]316Q8@0AXAcl4J4i5179QF`AT;b<3LFeR16=8A0BA]/<WN7=e5Oooo`005?oo
ob]hLgD3KdLg16a8@0AE>2h4L4@g18ebI@B5LfL4N6AT0gQXH`AhJ684N6AJ17QPFPA^H5L4NEaG17AH
DP=iGEL4M65D17AME@AnJF<;N6AO17=CC`AZ@3T4GD<l15m3>`AUAcd4I4i40fUBA@AgEE04LEU<17EI
C`A`FE04L4i60fI>APA/Bd<4J4Q016Q7?`AXCTD4LV5K16@_8`=aKF84HdQ4196f`bMhLgDEoooo000D
oooo:gQcM@=_AcL4K4Q015Dh;PA`A3L4SG9U18EcI`AhI6@3N6QS17QXHPAhI5X4N61J16iPE`AiG5L4
M5QB0gUME`AdHE@4M5eE17iYH`]hI5l4Le=?16Y0>@AM@c`4Gd<k16E7?@ATCT@3JE9517MED0AaFD`4
MEU?171ID0A`CTH3ITi616a;@`AXB404J4Lo16Q>A@AbHE/4I2lS0g5]HPASB4@4TKK39gQcMAGoool0
01Coool[N7=e0fm7=`A/B404ECP^1714=`B=LVD4QG=W17QTI0=hJ6<4N6QR17QTFPAhH5X4KV1G17UL
E`AdF583NEeG17AQE0AdGED4OVUS2gQTG`AcDdl4JT0i15e3?0AO@c/4IDLm16A>A0=YDTD4MeE@175I
C0AeFDl4L5U@171>AP=VCTH4K4]316Q8@0AXAcl4J4i5179QF`AT;b<3LFeR16=8A0BA]/<WN7=e5Ooo
o`005?ooob]hLgD3H2/L138O5`AD=2h4Ab/W1<2AN@B4Lf`4N6AO0gQTF`AhI5h4N6AO17QPF0AbH5P4
LUMD16U=A`=`DD`4L5m@17m/H@AiJEh4OFQW17QTG`=hI5/4KUA?16I6>`AN?ch4I4Tg1613?0AcDDL3
K5I<179>B0AaF4h4MUE?16]DA`AaF4d3Ide416eAA`AXCTD4J4Ho16Q:B0A]FDd4Fc0T0g=GBPA]?c`4
TK[49gQcMAGoool001Coool[N7=e0f0[70@b7aL4E3@^14L[9`C0TGT4Q7=/17QTG`=hI5/4N6AN17QT
G`AhH5P4LV1H179GE0AYCDL3L55<171OD0AoK644NFUN17eXI`AhI5l3N6AK16iDC`AVAS/4GSln16A9
=`AP@c`4Le570faFC0AbCTP4LEQ>17IEC`A[E4L4LEQ=0fM=A0A]DDL4J4i516Q6?`AXBTP4KEU=15/`
90=cEdX4KCll196ja2MhLgDEoooo000Doooo:gQcM@=P:a`4<QlG15@d;PA7:bL4`95i18AcK0AhI5l3
N6AK17QTGPAhI5l4N61H179PF0AbEe@4JDe70g1AC0A`Ge04OfaQ17UYGPAmJ6L4N6AO0gQTF`A^E4l4
ITHk15ho?PATBCL4H4<l17=AA`=/ET`4LTi8175HCPAfEDl4JeA7175HC@=WCD@4KE5716Q>A@AXASl4
J4Y816eIC@AK<2@3LeM:16do?0BA^/@WN7=e5Oooo`005?ooobMhLgD4N6]X0el[8P@K6AH4;B4N13XU
9@C4U7X4Q7=Z17=PFP=mJ6<4N6AG16YDCPAjHUX4K51717YLD0AeDdh3MTY717IKBPAgFdl4Nf]O18=b
K`AhI5l3N6AK16i<B@AP@cT4FSdg16E3=@ALAd04KTY00fUDB@A]CD<4MUE:17MIDPAWAcl4LEE<0fM>
APASBd84J4i516Q6?`AXBTP4J59514PY7`=S<RD4PE5119NodBMhLgDEoooo000Doooo9gQcM@AhJfP3
Gb/R11/I5P@]8Ah4>RDU1<BDNPB4LfX4Lf1J0geXH`AhI5L4JUA>17YRFPA/D4L4NUa@17ECCP=fBTL4
MU]:17MKC`AkJel4Pg9_17QTG`=hI5/4KTa91613>@AJ?CL4ID<e15a7@0A^BT03JEA916e=@`AfEDX4
MeUB16M7?`AaED`3Idi616=;@PAXCTD4J4Ho16Q:B0AXDTD4B2TO0f<b9@B1DD44UkoA9gQcMAGoool0
01CooolWN7=e17Q[J0=O:b846aTF12dQ7P@j9BD4a9Aj18AcJPAcH5X3OFQS17QTE`AZE4h4NV9J16a@
A`AjG504ME=>0gI:A`AfFdX4Me]?17][G`B3LVl4N6AO0gQTF`A^C4T4H4<i15Xm=`AU@cD4G4M016i:
@0=YE4T4KDe317IEBPAgFE84IdLo175EC0=WCTH4Hd]216Q>A@AXASl4J4Y816QBA@A8:Al3Hc8U185A
@@BG_m4WN7=e5Oooo`005?ooobMhLgD4N6]X0el[8P@K6AH4;B4N13XU9@C4U7X4Q7=Z17=PFP=mJ6<4
N6AG16YDCPAjHUX4K51717YLD0AeDdh3MTY717IKBPAgFdl4Nf]O18=bK`AhI5l3N6AK16i<B@AP@cT4
FSdg16E3=@ALAd04KTY00fUDB@A]CD<4MUE:17MIDPAWAcl4LEE<0fM>APASBd84J4i516Q6?`AXBTP4
J59514PY7`=S<RD4PE5119NodBMhLgDEoooo000Doooo9gQcM@AcDdL3JTA311L;2P@[6aP4=R8P1>:S
Q`AjJEl4N61G0gQYH`AhI5/4HTa615I3>`AC>c<4A3<a14D]:@=X=BL4QUA516Ld:@A`@C84YiV917e/
JP=hI5l4KU191610>@AJ@384H4Lh15`m>0AdED/3Hdm715i;A0AXBd<4J51:161=@@AlFDh3K59916=;
@PAPBT44JDY1179?B0AXCdD4>b4M0e8W80AjACH4Ul[H9gQcMAGoool001CooolWN7=e17=CA`=ZA4<4
5`/:12/K60@f8R04hZ>717YYG`AhH5L3N6US17QTF`ARC4H4ET<k15<k<`A4<c44ABdY0fPe9`B6E4D4
Ic@Y1711<PBWVHT4OFaZ0gQTG`A^D4T4H40i15Y0<PAPAcP4G3dh17AEB`=SCdL4GT]416Q;@`AXD4X4
H4e117aICP=/DTT4Hd]2161:@@AYBT44LTm816Q?A@@k8Ad3DRLP17Y5=PBGb]PWN7=e5Oooo`005?oo
obMhLgD4Le=70fY4@`@G2`X4:a/H13HR80CRXhL4NVUO17QPE`=hJF<4N6AK169<APAF@c/4Dc/c14@c
<@A5;BT3J3DW18IDA@AW=2T4L44b1:NIR@AmK6X3N6AO16i@B@AP@3T4FT0b1617>0AL?CP4M5E;0f=?
A`ANBd@4J4]316Q@BPAPCD44O5U>0faBB@ASBd84H4Y116U:@@AbCdP4J4m513/Q7@=B9b04NTDf19O:
f2MhLgDEoooo000Doooo9gQcM@AcDdL3JTA311L;2P@[6aP4=R8P1>:SQ`AjJEl4N61G0gQYH`AhI5/4
HTa615I3>`AC>c<4A3<a14D]:@=X=BL4QUA516Ld:@A`@C84YiV917e/JP=hI5l4KU191610>@AJ@384
H4Lh15`m>0AdED/3Hdm715i;A0AXBd<4J51:161=@@AlFDh3K59916=;@PAPBT44JDY1179?B0AXCdD4
>b4M0e8W80AjACH4Ul[H9gQcMAGoool001CooolSN7=e17agN@A/?c03HClk10@<4@@K51<4=1`J1>Bd
U@AhIE`4M5aD0geYG`AhI5/4LUaH14`h<@AEB4D45AXK12<G5`=18QX4Fd4k17<e:@AZAd04Q7MZ17i]
K0=hJ6L4KTm2160l=`AB>Bl4HDLd13`E4@BEKUT3KTdi16=9@@AM>c04P5Q=161=A0AhEDH3KE5:16Q>
A@AG@c/4HDe417=>B0APBCd4?28O0f8d:@AoB444Ul;<179^L2=hLgDEoooo000Doooo8gQcM@AlMgT4
K3l`0f4o>`@431446a@C13@L6PCT]9D4N6EL17ALE0=mJEl4N6AK179LF0A<>344EDQ511DJ6`@S5aL3
@B8J15]1>`Ac=BT4JTM018AgJPAnKF`3N6QW16i?@PAP?3L4DST_1657=0@l5A44UFiI0fi=>@ASBD44
GC/`181HC@APCD@4N5E60feABPAXCTD4Ed<k165=A0AcCTP4H4Tm13`R7`=R=2T4OdQ119O2c0AbKW0S
N7=e5Oooo`005?ooob=hLgD4O7Mi16`o<0=Q?c/410`A11/D4`@d71X4i;BE17QUG0AdG5@3OFUO17QT
F`AbG5P4C3Pa15E8A@@E6Q/48aLG0d4R6PAK@C/4LcDY16Y7@0B4MfX4OVe/0gQXI`A^Cd84H3`g158i
;`AQAc@4?1DA19E^F@=^CCT4HdU115dk<0B0F4d4H4e417QEAP=]DDX4J4i515M3>`AQCD@4Ldi81619
?@@l8Ql3HS@Y17m8@@BG`/`4LVi`8gQcMAGoool001CooolSN7=e17agN@A/?c03HClk10@<4@@K51<4
=1`J1>BdU@AhIE`4M5aD0geYG`AhI5/4LUaH14`h<@AEB4D45AXK12<G5`=18QX4Fd4k17<e:@AZAd04
Q7MZ17i]K0=hJ6L4KTm2160l=`AB>Bl4HDLd13`E4@BEKUT3KTdi16=9@@AM>c04P5Q=161=A0AhEDH3
KE5:16Q>A@AG@c/4HDe417=>B0APBCd4?28O0f8d:@AoB444Ul;<179^L2=hLgDEoooo000Doooo17Qc
M@AhN7X4N6ma17QhNQ=hLgD4:A8@1=^<L@=YDDT45A@G11DD6P@X5a@4m;bL17UTF`AhI5/3M61G17UT
FPAmJ6L4HT]2175>BP@Z;2`47B8W0b@P7@@n=c84JDY017UDC@AjKf84OWId0gQ/JPA^DdP4H3li150g
;@AD?C@4=1`K15m=BP=7<RT460`>16lj;@AJAC/4@bPP17mBA@=[A384PE=415]=APAQBT84LdY414/l
<`@`71X3F2lW1:=XF@BF]/D4LFe`8gQcMAGoool001Coool4N7=e17QhNPAhKg44N7Qj4gQcM@@Y4Q04
fhaa0fUAB@@E51L45A@J12PG50Cd_9`4NFAK17QTF`=dH5L4NFAJ17eXI`ARBd84LDi:12X/;0@M8RL3
920M13hg<PAYBT04NEA=17Y_HPAnMW@3N6aZ16iCB0AP?cT4D3L]15@m=0@d71/4Gde:0dLb:@@H30h4
KcX]15Y5>`A3:204Oe950f]4<PB1Dd@4Fde6165:@PAcBT@4Bc`c130L6P=H;bL4XfQI19Jfa@AaKG0S
N7=e5Oooo`005?ooo`AhLgD4N7Qj17Q_L@AhN7XCN7=e12TB40CKS743JE5911DD5`@E51X4:1LD1?Bl
W0AiI5/4N6AK0gAPE`AiI5X4OFQW169;@PAaCTX4:R`/11dR9`<T81d4?SLb16U:@0AiE4d4NVmR17if
M0=hK6X4KU=8160o>@A@=bd4E3dd13@L6`AOCDX3Ac8Y11P<3PA_>Rd4FTDk14<X80AoDTD3Jd@b185C
A0AKCDH4HDY217=:A0A;?3<4<1`J0eP_9`BSJ5T4U[K5175]L2=hLgDEoooo000Doooo17QcM@AhN7X4
N6ma17QhNQ=hLgD4:A8@1=^<L@=YDDT45A@G11DD6P@X5a@4m;bL17UTF`AhI5/3M61G17UTFPAmJ6L4
HT]2175>BP@Z;2`47B8W0b@P7@@n=c84JDY017UDC@AjKf84OWId0gQ/JPA^DdP4H3li150g;@AD?C@4
=1`K15m=BP=7<RT460`>16lj;@AJAC/4@bPP17mBA@=[A384PE=415]=APAQBT84LdY414/l<`@`71X3
F2lW1:=XF@BF]/D4LFe`8gQcMAGoool001Coool4N6ma17QhNPAhKW0CN7=e12/H5P@V5QD4Aa0<0gY8
>@@R5Q`47QLE12hJ60CZ^9T4M61G17iYH`=UACh4MVEE18YjM`AbI5/4KDm915i3?@AMACX3F4@k15To
=`A^F4P4MUIB17ASF0AnMW@3N6QS16i<A@APBT04FSL/15M5>0AG<bh4DTi<0bl];0@42@d4C2DL14Dc
<0@Z7a`4KD8d0f=3=PAfE4<4Fd@n15a=A0AcCd44:QhO134Q6P=591h4Z5E219c<fPAgLW@SN7=e5Ooo
o`005?ooo`AhKg44N7Qj17Q^L1=hLgD4:aPF12HF5@A740`3NTPi128F70@N5aD4;QXH1>ZhV@AdH5L4
OVUS0fE5?PAfIED4RWYg179TF`A]CdT4GT<m15e5>P=HA3/4FClg16iHB0AfEU84M6=H17ifM0=hJ6<4
KTa5161:@0AJ=b`4EdDh15Lc;PABCT`3;bd/10@93@A<9A`4AC<`12XO70A]@S@3Hd<f17ID@`AKA3h4
G4e417=?@@@Z7Ql4<B4J0dDT7PBXED84W<cJ17MbM2=hLgDEoooo000Doooo17Q_L@AhN7X4N6i`4gQc
M@@[61H49QHE14L@30=jB3T48QHL11hG5@@^6QP4j[RI17APE`AnJF<3IDDn17IUE@B:NWL4LVAK16e?
B@AN@cd4GDDj0eQ4>`AI?cL4KUQ817IFDPAdHeP4OWId0gQXH`A^C4D4H4Y015Xg;0AGACP4Ec<^159>
C0<_;B`410T=14`U70A5<c04:QlL16e2=0=S@cH4MUA315]4?PALCD@4Ldm112XN7`@a8AX3AB@N1:QE
@PBLc=X4Mg9d8gQcMAGoool001Coool4N6ma17QhNPAhKW0CN7=e12/H5P@V5QD4Aa0<0gY8>@@R5Q`4
7QLE12hJ60CZ^9T4M61G17iYH`=UACh4MVEE18YjM`AbI5/4KDm915i3?@AMACX3F4@k15To=`A^F4P4
MUIB17ASF0AnMW@3N6QS16i<A@APBT04FSL/15M5>0AG<bh4DTi<0bl];0@42@d4C2DL14Dc<0@Z7a`4
KD8d0f=3=PAfE4<4Fd@n15a=A0AcCd44:QhO134Q6P=591h4Z5E219c<fPAgLW@SN7=e5Oooo`005?oo
o`AhKg4KN7=e10<00`@a8Q`4:A@E0cDS7`@E3Q44;a`I130J6@CT/I44N6AK17ATGP=/BT`4G4@k16Q9
?`AoI5L4KeI;16=2?@AL=Bd3JD<c1794=PAcASH4UGUZ17mZG`AnKF`3N6QN16i<B0APDDP4FSTa1615
=0AQBSX4Le=:0em4?`@56R<4:2@T130W9@@_:bP4HDLm0f56=PAQCdL4KD/o15m;APAQBSl461<D12XJ
60=69Ad4TSPZ1:?JiRMhLgDEoooo000Doooo17Q_LA]hLgD40`03134R70@Y51D3=B<O11D>4@@_71T4
<1XI1>BaT@AhI5/4M6AN0fa:C0ALA3/4J4To17mTE`A_ET/4Hd8m15`e;@=Y@c<4LT@f17=6=PBENFX4
OfYO17i]K0=hJ5h4KTa8161AB0AJ>C44H4Dd165:>PAcDdX3Gd@o10DJ8`@X92@4<2LU12l[:0AQAcd3
HDHf165?A`A]Bcl4Gd]6165:?`@H4a@4:QXH0dHU7@BB>2X4Xm[V9gQcMAGoool001Coool4N6ma6gQc
M@@300<4<B8L12TD5@<e8al45@hA12lL6@@`6QT4i;6A17QTF`AdI5h3K4Y<15a4>`AXBCl4OfAG16mF
B`AS@Sd4G3D]0fU3<`AbA3H4LdHf19EiJPAoJUl4OVe/0gQXGPA^C4P4H55815Xi<@APAC@4HDXj17=C
BP=OA3l41AXS12PT90@`9bD4;b/X1657?@=QASH4HDm716e;?`AOBdH4HDXo11PC50@Z6QP3ARDM198h
:PBSf^HWN7=e5Oooo`005?oooamhLgD40`0312<D4@@S61H3:1PF11lE50@S61H4?BLU1<fBM`B:KF84
LVEK0gQUI0AVDd`4CCTc154e<`A4?CX4H44k13T]:@=8>S<4CC<]16E7?`AhKV<4NFIQ17QUH0=hF5<4
KUa=161=APAJ=SL4Bb/O15hj:`B2Id/3LU9916Q>A0ARAd84Bc/b14/i=PA`CD03H4Lm16Q:APAQCSl4
LU9414/k=@@A3a048aLE0hQ?@0AD8Qd4/=cW9gQcMAGoool001CooolON7=e10<00`@S51448aPF0bPH
5P@O5A@48aPF13dW9@C=TWL4RVeR179UF`=hIF@4IU=<14di<`AA=C<4A3dj1611>`@i;BT3B3Xc14dc
;@AUAcl4N6iS17UVH@AhIF03N5QC16iLC@APCDH4FSHg14/[7`AN>R/4PVM;0g9BB@AXCT@4HTM214/k
<PA;>CH4L4e00f17?@AXBTH4HDho179BA0A;>cD44@l@12<G5@>8Cd04E28M1;3LibMhLgDEoooo000D
oooo7gQcM@@300<48a@A12<H5P<X61H47aDD12<H5P@m9bD4cI9g18Y]HPAbIE/3N6ET16ICC0A=>C<4
DCDc14@m>PAP@C/4>BdY0dPj<`A=<bd4IDLo17Q^H`AiIV44N6EP0gQHD`A^G4d4H4e615Xf=`A;:al4
GSX[189WB`=bDTT4J4i41697@PA;>c84BcTf171=@0=PAcd4J4Y6165>?`AbDT@4Bc/e114?40@S5aD3
R4m015@R7@B`g>LWN7=e5Oooo`005?oooamhLgD40`0312<D4@@S61H3:1PF11lE50@S61H4?BLU1<fB
M`B:KF84LVEK0gQUI0AVDd`4CCTc154e<`A4?CX4H44k13T]:@=8>S<4CC<]16E7?`AhKV<4NFIQ17QU
H0=hF5<4KUa=161=APAJ=SL4Bb/O15hj:`B2Id/3LU9916Q>A0ARAd84Bc/b14/i=PA`CD03H4Lm16Q:
APAQCSl4LU9414/k=@@A3a048aLE0hQ?@0AD8Qd4/=cW9gQcMAGoool001Coool8N7=e17Q_L@AhN7X?
N7=e10H00P@M40l48APF0b0G5@@E2`d4:1TF13h/:@B/MUl4UWIX17e]HP=hI6@4N6QS179OE`AQADD4
ASm316E9A`AG?c/3F4E0158k>0AZBd84L5mF17i]K0AcG5<3NEQG17=JD0ATDDT4H4=413/W9@@a71d4
BS4T0d`_90BCF4D4PEmB16Q>?`AOBd44HDY10fA6?@ALACh4Le1:16U>?`@Z7a/45a8C12XR80>DBCL4
D2@M14i:B0CJe]PSN7=e5Oooo`005?ooo`QhLgD4N6ma17QhNPmhLgD41P0211d@3`@Q61H381LE11D;
3@@X6AH4?R`Y1:afG`BFMVP4OFeR0gQTI0AhJ6<4LUmG1655A@A6?d<4IDU715Lo>`=HAD04DS/h16Y;
@PA`GeH4OVe/17=LD`=iF5L4LeY@16AAB@AP@d@4>bLU134L7@A:<B@3C2lT19=HA@B1Ge84J4ho15m;
@@AQBT43I4Hm15a5?PAcD4X4JDho12XO6`@G4Q<4:R8P0iA9=`A@91d4CTY81=[Ff2=hLgDEoooo000D
oooo27QcM@AhKg44N7Qj3gQcM@@600847A0?124H5P<P5aD45@/=12PI5P@n;2T4[7IO19IfJ0AmKF83
N6AT17QXH`AbGeL4HDE514Ho@`AUBDL4Eclk0eQ5@0AB>cP4JT]2171OEPAnKF`4LeaC0gUHE`AcFU04
I5591613A0@k9bD4<A`M14Xa90=<;b@4TeQ5185ODPAXCSl4Gd]1165:@@=TASd4G4Dn17=@BPAYCSl4
:QlK11LB4`@Z8R03U4Tg150T7@A>BTP4f]KH8gQcMAGoool001Coool8N7=e17Q_L@AhN7X?N7=e10H0
0P@M40l48APF0b0G5@@E2`d4:1TF13h/:@B/MUl4UWIX17e]HP=hI6@4N6QS179OE`AQADD4ASm316E9
A`AG?c/3F4E0158k>0AZBd84L5mF17i]K0AcG5<3NEQG17=JD0ATDDT4H4=413/W9@@a71d4BS4T0d`_
90BCF4D4PEmB16Q>?`AOBd44HDY10fA6?@ALACh4Le1:16U>?`@Z7a/45a8C12XR80>DBCL4D2@M14i:
B0CJe]PSN7=e5Oooo`005?ooo`QhLgD4N6i`4gQcM@@:0`@49APG124E50<R5aD45a4@12PH5P@m;2T4
WVMB19=gJPAnKF<3N6AT17Q/I`AhJ6<4N6a[27QWHPAhHe/3N6a[17QSF`AhHeX4LUa@17QYH`AbGeL3
KUU@17AHD0A^GE@4KeUA16=:A`@c:Rl4:b@T0a`P7`A39b04CC0U1751=0AKASX4J3lb0f8n<PAhEe04
JT]216A6?@@C414481HD12/M7`=261<4FQlG13@d<`CNg=hSN7=e5Oooo`005?ooo`QhLgD4N6i`4gQc
M@@:0`@49APG124E50<R5aD45a4@12PH5P@m;2T4WVMB19=gJPAnKF<3N6AT17Q/I`AhJ6<4N6a[27QW
HPAhHe/3N6a[17QSF`AhHeX4LUa@17QYH`AbGeL3KUU@17AHD0A^GE@4KeUA16=:A`@c:Rl4:b@T0a`P
7`A39b04CC0U1751=0AKASX4J3lb0f8n<PAhEe04JT]216A6?@@C414481HD12/M7`=261<4FQlG13@d
<`CNg=hSN7=e5Oooo`005?ooo`QhLgD4N6i`4gQcM@@:0`@49APG124E50<R5aD45a4@12PH5P@m;2T4
WVMB19=gJPAnKF<3N6AT17Q/I`AhJ6<4N6a[27QWHPAhHe/3N6a[17QSF`AhHeX4LUa@17QYH`AbGeL3
KUU@17AHD0A^GE@4KeUA16=:A`@c:Rl4:b@T0a`P7`A39b04CC0U1751=0AKASX4J3lb0f8n<PAhEe04
JT]216A6?@@C414481HD12/M7`=261<4FQlG13@d<`CNg=hSN7=e5Oooo`005?ooo`QhLgD4N6i`4gQc
M@@:0`@49APG124E50<R5aD45a4@12PH5P@m;2T4WVMB19=gJPAnKF<3N6AT17Q/I`AhJ6<4N6a[27QW
HPAhHe/3N6a[17QSF`AhHeX4LUa@17QYH`AbGeL3KUU@17AHD0A^GE@4KeUA16=:A`@c:Rl4:b@T0a`P
7`A39b04CC0U1751=0AKASX4J3lb0f8n<PAhEe04JT]216A6?@@C414481HD12/M7`=261<4FQlG13@d
<`CNg=hSN7=e5Oooo`005?oooamhLgD41P<5130T8`@G4Q839QLE124F50@X6a`4>b/W18YIA@BGM6D4
RWIZ0gQTG`AhJ6L4N6aV17Q/JPAhLG84N6aZ17QWHP=hK6/4N69J17QXH`AhHeX4N61D17QTF`=^E4d4
M5UA17AID0AdHEL4M5AD16AEC@AQAd<3@3@c12/Y:@@Y9bD4@B/W14<f;`AO@SP3C40i1754A@ATD444
Fd0g114>4@@Q5Q@48APF0alB40@m71X4ACLd1=kLgB=hLgDEoooo000Doooo7gQcM@@60`D4<2@S11LB
4P<V5aD48AHD12PK70@k:bL4RUU519MdI@B:MVX3N6AO17QXI`AhK6H4N6aZ17QaLPAhK6X4N6MR0gQ/
J`AhHUX4N6QS17QSFPAhH5@4N6AK0fiDC@AdFE44M5U@17AQE`AdE5@4I5E=1657@`=0=3<4:bTY12TW
9@A1:bL4@cH_15m2>0=<@3T4LDA516A@@@AK@3L44@hA124F50@Q61H37a8@13dL6PA5=c@4g]cM8gQc
MAGoool001CooolON7=e10H31@@`92<45a8B0bHG5@@Q5Q@4:1/L13/[9`B:FDD4UgAU18YfJP=hI5l4
N6QW17Q/IPAhK6X4N75b17Q/JPAhIf83N6a[17QRFPAhJ6<4N6=J17QPE0AhI5/3KUA=17AID@AdFE04
M65G17ADE0ATEDd4HDM30d0d<`@[:BT4:BLU144[9`A3=Rl4Gd8h0da0>@AaA4D4I51115]0=`@A3Q44
8AHD124H5P<O4Q04?A`J14Dg=0CNg=dSN7=e5Oooo`005?oooamhLgD41P<5130T8`@G4Q839QLE124F
50@X6a`4>b/W18YIA@BGM6D4RWIZ0gQTG`AhJ6L4N6aV17Q/JPAhLG84N6aZ17QWHP=hK6/4N69J17QX
H`AhHeX4N61D17QTF`=^E4d4M5UA17AID0AdHEL4M5AD16AEC@AQAd<3@3@c12/Y:@@Y9bD4@B/W14<f
;`AO@SP3C40i1754A@ATD444Fd0g114>4@@Q5Q@48APF0alB40@m71X4ACLd1=kLgB=hLgDEoooo000D
oooo7gQcM@@;10H4<b<N124J6P<Q5A@4:1<A12`L6`@i9Ql4Gd4f1:9aGPB;NVd3OFQN17QTI0AhK6L4
N6a[17QXH`AhLG87N6aZ17QRFPAhJ6<4N6AJ17QTG`AhH5<3KUA<17AQE`AdFE44M5U@17AHD`AZED/4
JU580f5>APAJAd04FDQ114Lh<`A=?3L4HD8k0em;APATA3l4FdLm13d]9@@J4aD48AHD12TJ6@<J5A@4
:APF144Z8PBiXZL4VYnO7gQcMAGoool001CooolON7=e10/41P@c8ah48AXJ0b4E50@X4a44;1`K13TV
7`AO@CH4XW5N18]jK@=mJ5h4N6AT17Q/I`AhK6/4N6QS17QaLPMhK6X4N69J17QXH`AhI5X4N6AO17QP
D`=^E4`4M65G17AID@AdFE04M5QC16YEB`AZDDP3HDi615Y7@0AIB444AcPc14dl=`AQ@S/3Gd]616A4
?`AKAcd4?BdU11XC5@@Q5Q@4:AXI0aXE50@Y61H4@BXR1;VRY`BJWilON7=e5Oooo`005?oooamhLgD4
2`@613<S7P@Q6QX38ADD12PC4@@/71/4>BHO15m1=PBRLEh4RgY]0geXGPAhI6@4N6aW17Q/J`AhJ6<4
N75b1gQ/JPAhHUX4N6QS17QTFPAhI5l4N61C0fiDC0AdHEL4M5UA17AID0AdF5<4JUE;16YAB0=QCTH4
FTM015U8@@A7>3<4CC`g1652>`=OBdH4I4@o15]7?@@m;BD46Q<E124F50@Y6QT36QDD12TH5PA1:R84
^J:W19ZOWamhLgDEoooo000Doooo7gQcM@@:0`@4=bTX12DJ6@<W61L46a8@12XH5P@Z6AH4DC0V189B
>`BXRgd3OVeR17QTI0AhK6L4N75c17QWHPAhJ6<4N75b1gQWHPAhJ6<4N5mC17QTG`AcF4l3LeQ@17AI
D0AdGE<4M5Q@17AID0AZDDT4Jdi60f]BB@AWDTX4J4]216a>A@ASCTD4H4Ho0fU:A0AYBT44Ec`c12HK
6P@I4A04:a/M11dC50<M51445P`>13/P70B;JVD4]Kg07gQcMAGoool001CooolON7=e10X310@g:BP4
9AXI0bLH5`@K4Q04:QPF12XI5PAA<2H4PU8k1:R;O@=nKF84N6AT17Q/I`AhLG<4N6MR17QXH`AhLG87
N6MR17QXH`AhGe<4N6AO17=HC`=cF504M5U@17AMD`AdF504M5U@16YAB@A[CTH3Je9916MBBPAXBd84
K4i516=>A@APASl3JDY416U:@@AG?3<49Q/J11TA40@[6ad47A<D0adD4@@F30h4>b0L18]ZI@Be_L0O
N7=e5Oooo`005?oooamhLgD42P<413LY:0@U6QT39aPG11/B40@Z61H4:QTF154`9PB2DS/4Z8]m0gi]
HPAhI6@4N6aW17QaL`AhIf84N6QS17QaLPMhIf84N6QS17QOD`AhI5l4LeQ?0g=HD0AdFE04M5eC17AH
D0AdFE04JU5916]>AP=[DTT4Ie9:16Q;@PA/CTD4Hdi51616?`=YBT@4JDY115Ll<`@V6aX46A4@12/K
7@@M4a@37A@A11H<3P@k81`4RfYU1;Fm`1mhLgDEoooo000Doooo7gQcM@@:0`@4=bTX12DJ6@<W61L4
6a8@12XH5P@Z6AH4DC0V189B>`BXRgd3OVeR17QTI0AhK6L4N75c17QWHPAhJ6<4N75b1gQWHPAhJ6<4
N5mC17QTG`AcF4l3LeQ@17AID0AdGE<4M5Q@17AID0AZDDT4Jdi60f]BB@AWDTX4J4]216a>A@ASCTD4
H4Ho0fU:A0AYBT44Ec`c12HK6P@I4A04:a/M11dC50<M51445P`>13/P70B;JVD4]Kg07gQcMAGoool0
01CooolON7=e10H10`@a9bL4;R8Q0bLJ6@@T5aH48AHD12`N70A2;BX4FCT]1;=nJP>:MFT4N6QW17QX
H`AhLFh4N75b17QWHPAhK6/3N69J27QXH`AhGeL4Lf1C17=HD0MdF504M5U@171ID0AeED`4L5E<16I>
AP=/DTT4K5E;16M>APAXBd84J4i515M6?`=YBT44F4Hm13X[9`@M5AH48a`J11L?4@@M51H350`=11`C
5@@[6AH4MUUD1<?5b1mhLgDEoooo000Doooo7gQcM@@60@<4<BLW12hR8@<W6QT491LF124F50@/7Q`4
@RdZ15Ti;@BcOVX3RWEY17QXI`AhJ6<4N75^17QaLPAhIf84N6a[0gQRFPQhJ6<4N5mG17=PD`AcF507
M5Q@17AID0A`FE04MEE<171EC0AVCTH3K59916aEB`AWCTH4J4]216Q>A@AGASl3JDY115Q6?@@j:bL4
7ADF12<L6P@G3a447A@F0a@<3@@L4aD4:aTF17IIE0C3aLPON7=e5Oooo`005?oooamhLgD41P43134W
9`@^8R439aXI12@G5P@Q5Q@4;1hL148]:PAI>Bd4/giZ0hYeJ@AhJ6L4N6QS17QaKPAhLG84N6MR17Q/
J`=hHUX8N6QS17QOE`AcH5<4LeQ@1gAHD0AdFE04L5U@17EEC0A`ED`4ITi60faBB@A/ED/4Idi616Q;
@PAXCTD4EdHo0fU:@@AHASd4>R/W11dE5P@S71X45`lA11dD5P<D30d471<E12/I5PAfFE@4`lG87gQc
MAGoool001CooolON7=e10H10`@a9bL4;R8Q0bLJ6@@T5aH48AHD12`N70A2;BX4FCT]1;=nJP>:MFT4
N6QW17QXH`AhLFh4N75b17QWHPAhK6/3N69J27QXH`AhGeL4Lf1C17=HD0MdF504M5U@171ID0AeED`4
L5E<16I>AP=/DTT4K5E;16M>APAXBd84J4i515M6?`=YBT44F4Hm13X[9`@M5AH48a`J11L?4@@M51H3
50`=11`C5@@[6AH4MUUD1<?5b1mhLgDEoooo000Doooo7gQcM@@:0`@4=2PV13DX9P</8B049aLF11TB
40@c7A/4A2`T15Lk<0B@FdL3TGib17e]IPAhI6<4N6QS17QaKPAhLG84N6aZ0gQWHPAhHe/4N6QS17QO
F`AbH5<4KUE=0g1DC@AeED`4NEQD16YHC0A`DDP4L5E?16IAAP=/DTT4K4i516QAA`AXCTD4I4Hm16==
A0=Q@ST4BcTd13<Q7@@R5aL471@A11XB5@@H3a436a<@11`C5P@`6aT4/jf/17ikOAmhLgDEoooo000D
oooo7gQcM@@:0`@4=2PV13DX9P</8B049aLF11TB40@c7A/4A2`T15Lk<0B@FdL3TGib17e]IPAhI6<4
N6QS17QaKPAhLG84N6aZ0gQWHPAhHe/4N6QS17QOF`AbH5<4KUE=0g1DC@AeED`4NEQD16YHC0A`DDP4
L5E?16IAAP=/DTT4K4i516QAA`AXCTD4I4Hm16==A0=Q@ST4BcTd13<Q7@@R5aL471@A11XB5@@H3a43
6a<@11`C5P@`6aT4/jf/17ikOAmhLgDEoooo000Doooo7gQcM@@:0`@4=2PV13DX9P</8B049aLF11TB
40@c7A/4A2`T15Lk<0B@FdL3TGib17e]IPAhI6<4N6QS17QaKPAhLG84N6aZ0gQWHPAhHe/4N6QS17QO
F`AbH5<4KUE=0g1DC@AeED`4NEQD16YHC0A`DDP4L5E?16IAAP=/DTT4K4i516QAA`AXCTD4I4Hm16==
A0=Q@ST4BcTd13<Q7@@R5aL471@A11XB5@@H3a436a<@11`C5P@`6aT4/jf/17ikOAmhLgDEoooo000D
oooo7gQcM@@:0`@4=2PV13DX9P</8B049aLF11TB40@c7A/4A2`T15Lk<0B@FdL3TGib17e]IPAhI6<4
N6QS17QaKPAhLG84N6aZ0gQWHPAhHe/4N6QS17QOF`AbH5<4KUE=0g1DC@AeED`4NEQD16YHC0A`DDP4
L5E?16IAAP=/DTT4K4i516QAA`AXCTD4I4Hm16==A0=Q@ST4BcTd13<Q7@@R5aL471@A11XB5@@H3a43
6a<@11`C5P@`6aT4/jf/17ikOAmhLgDEoooo000Doooo5gQcM@AhKg44Lfma10X72@@e9bD4>B/Y0c4T
8P@P51<49adK12`M70@h9B44KD0`17m?@@>=MVT4Pg9V17QTI0QhJ6<4N75c1gQ/JPAhHUX4N6QS17=L
D`AmI5X4KUA<0fiHD0A_EDd4L59<171EC0A`CTH4JeI?16]>AP=XBDD4KE5526Q>A@AS@c`4H4Y20eLi
<@A4<R`48aXH12HH60@J5A@47QHE11dE50<K4a0481LF138K6@Coool4LVi`7gQcMAGoool001CooolG
N7=e17Q_L@AcKg442PL913DW9@@i:bT3<B@R120D4`@W7A/4;1dL13PU8@A]@304Odm10hefJ@B3LVH4
N6AT27QXH`AhLG<7N6aZ17QRFPAhJ6<4LeaC17eTFPA^E4`3KUQ@16mEC@A`DT`4L5E<171>APA[ETl4
Jdi60fQ9A@A]DDD8J4i516=3?0APBT83EcTa14@b;0@S6QP49QPH11XE50@N5QD47ADD0a/C40@P5aH4
<Q/I1?ooo`AbKW0ON7=e5Oooo`005?oooaMhLgD4N6ma17=_L@@:1`T4=BLU13T[:@<a928481@C12LM
6`@/7A`4>2DQ16e0<0AoCd43SGIY18=bIPAhI6@8N6QS17QaL`MhK6X4N69J17QXH`AcG5<4OFAJ16iD
C0=^F504KeE=171BC0A`ED`4L4i616]FC`A[CTH3J4U516eAA@QXCTD4Hd<l161:@P=G>C44A38/12<J
60@V61P46QDD11hF5@@M5A@36a<@120G5P@b6aT4oooo179^L1mhLgDEoooo000Doooo5gQcM@AhKg44
Lfma10X72@@e9bD4>B/Y0c4T8P@P51<49adK12`M70@h9B44KD0`17m?@@>=MVT4Pg9V17QTI0QhJ6<4
N75c1gQ/JPAhHUX4N6QS17=LD`AmI5X4KUA<0fiHD0A_EDd4L59<171EC0A`CTH4JeI?16]>AP=XBDD4
KE5526Q>A@AS@c`4H4Y20eLi<@A4<R`48aXH12HH60@J5A@47QHE11dE50<K4a0481LF138K6@Coool4
LVi`7gQcMAGoool001CooolGN7=e17Q^L0AbJV`41@<513hW8@@a9bH3=bTW12PN7P@X71X4;b8P13@R
70AOAC/4KClb0iM]GPB5NVd4OFQW17QXH`AhK6H4N6aZ1gQ/J@AhHeh4LfAJ17=LDPAiI5/4Le190g1E
B0AeF584L5E8171EC`A`DTT4IU9916aAB0=WAd84Hdm516Q:@@AXCD@4H4Y115M2>@=@=2`4>2@S12HI
5P@O5QD471<A11dD5P@I41434@`=11`A4PA::bL4i^g]17MbM1mhLgDEoooo000Doooo5gQcM@AhKW04
LVY/10D31@@n9b44<BLV0cLY9`@X7Qh4:1`J12lR80@d8Q`4GdDk16do<P>GKEh4QGY]17eXI`AhJ6<4
N6aV17Q/JPMhK6T4N6=N17=TFPAcG584NFAK17=@B@=`EDP4MEQB171EB0A`EDl4L59916IBB@A/DDP3
IdM216=?A@AXBT44J4e4161:@@AG@ST3D3@/13PT8`@V6AH47aHE11`C4@@M51H46A0A0a4<3@@L4A84
BR/W1>K]k@AgLW@ON7=e5Oooo`005?oooaMhLgD4N6i`179ZK0@50`D4?RLQ134W9P<g:BL4:1hN12PL
6P@_8R04=28L15m5>`A]?c83UfeN18EjK@AmJ6L4N6QS17Q/IPAhK6X7N6aY17QSGPAcI5X4LeaB17UT
F`AcD4T3L5E817EHDPA`EDP4L5E?171BB@AVDTT4K5580fM7@PASCdD4J4Y116Q=A0APBT44Ed8i0e0d
;0@h92<49QTF11lF5@@L4a447A@F11T@4@<A30d4714B14X[9`CVkNd4Mg9d7gQcMAGoool001CooolO
N7=e10<110@c8AX4=b/[0cLY:0@/81h4:ATH13HU7P@c9R@4CC/b158/90>EH4h4THAe17iYH`AhI5h4
N6QW17QXGPMhJ684N6AS179PD`A^EDd4M5aC171@A`=`E4P4L5E?171IB@A`ED`4L4e416IEB`M/CTD4
Hdi516Q6?`ATASd4DdDl150g;P<h92<4<B4L120E50@N5aD48QHD11XC5@@G3a035PlA12dK6@BSUYH4
NgYl8gQcMAGoool001CooolON7=e10<110@c8AX4=b/[0cLY:0@/81h4:ATH13HU7P@c9R@4CC/b158/
90>EH4h4THAe17iYH`AhI5h4N6QW17QXGPMhJ684N6AS179PD`A^EDd4M5aC171@A`=`E4P4L5E?171I
B@A`ED`4L4e416IEB`M/CTD4Hdi516Q6?`ATASd4DdDl150g;P<h92<4<B4L120E50@N5aD48QHD11XC
5@@G3a035PlA12dK6@BSUYH4NgYl8gQcMAGoool001CooolON7=e10<110@c8AX4=b/[0cLY:0@/81h4
:ATH13HU7P@c9R@4CC/b158/90>EH4h4THAe17iYH`AhI5h4N6QW17QXGPMhJ684N6AS179PD`A^EDd4
M5aC171@A`=`E4P4L5E?171IB@A`ED`4L4e416IEB`M/CTD4Hdi516Q6?`ATASd4DdDl150g;P<h92<4
<B4L120E50@N5aD48QHD11XC5@@G3a035PlA12dK6@BSUYH4NgYl8gQcMAGoool001CooolON7=e10<1
10@c8AX4=b/[0cLY:0@/81h4:ATH13HU7P@c9R@4CC/b158/90>EH4h4THAe17iYH`AhI5h4N6QW17QX
GPMhJ684N6AS179PD`A^EDd4M5aC171@A`=`E4P4L5E?171IB@A`ED`4L4e416IEB`M/CTD4Hdi516Q6
?`ATASd4DdDl150g;P<h92<4<B4L120E50@N5aD48QHD11XC5@@G3a035PlA12dK6@BSUYH4NgYl8gQc
MAGoool001CooolON7=e10d620@W7A/4=BLU0cd[:@@/7aX4:alO12dN6`@h:BL4=BHR14</:@=nBCP4
UWAN18YiK`AiI5X4OFQR27QTF`=cH5L4NFAN17eXGPA^D4T4L558171EB0=[BdD4LEE>175EB`AfED/4
JdY216]AB0A/BDD3J59516Q>@@AT@cd4H4Hm14/l=0@n9203;20L12<F5@@K4a447A@F12LH5@@I4QD4
50/=0aT@4@@f7QX4oOcl17MbM2=hLgDEoooo000Doooo7gQcM@@=1PP49adK13DW9@<m:bT4;1lJ12/O
7`@]7Q/4>2TW13DV8PA3;2T3OTTh19IdGPB:NFl4NFAJ17eXHPQhI5/3Lf1G17UTGPAmJ5h4KU19171A
B0A`EDP3Jd]5175ECPAaED/4MUE;16]:@PA[DDP4K4U50fQBA@AXCT44I4<m1616?@A;?3@4?R@P0b`P
70@S5QD46a<A11dD5P@W61D46A8E11@;3@<I4144=QhJ1?glo0AgLW@SN7=e5Oooo`005?oooamhLgD4
3@H812LM6`@e9bD3?B/Y12`O6P@[7al4;AhK13PY9`@e9R84@b`Y0gi9>0BFM5h4RWU_17UTFPAmJ688
N6AK0g=PE`AiI5h4OFQN16i@B@A`DDP4L5E80f];A@AaEDh4LEE;17IEB`A[BT84Je5816a9A@=XDTD4
J4i116A3?@APASd4Bc`d13hT80</81`48aHE11/C4@@M51H49aPE11TB5@@D2`d36A0A13HN6PCmo?`4
Mg9d8gQcMAGoool001CooolON7=e10d620@W7A/4=BLU0cd[:@@/7aX4:alO12dN6`@h:BL4=BHR14</
:@=nBCP4UWAN18YiK`AiI5X4OFQR27QTF`=cH5L4NFAN17eXGPA^D4T4L558171EB0=[BdD4LEE>175E
B`AfED/4JdY216]AB0A/BDD3J59516Q>@@AT@cd4H4Hm14/l=0@n9203;20L12<F5@@K4a447A@F12LH
5@@I4QD450/=0aT@4@@f7QX4oOcl17MbM2=hLgDEoooo000Doooo7gQcM@@G3`l4:B0Q13DX9P<e9R@4
<b@Q12DI6`@]7a`4<bDR13LY:0@c8Q`3D2hU18MMB@BAK5d4P6IJ17m/H@AiI5T4NFQN0g=PE`AdG5<4
NFAJ16mCC0A[Acl4LEA70f]=A@A/CD@4K5E:179AA`A[CTD4J4Y116e:A0=TBCl4I4`o15]2>@AH>Bl4
CcL]12XM6P<S5QD47aHE11/B40@H3a446a0A114<3P@A30d3<1`J13DN6@C[l_LWN7=e5Oooo`005?oo
oamhLgD45`l?12TP8@@e:2H3=BHT13<T8@@U6A/4;AlL13<U8P@g:BP4<b8L0e0^9@B7GDT4TFaM181V
FPAoK644NFAI17UXGP=cH5L4M5aC17UTFPA_Dd`4JdLo175DA`=[CDD4K4e416aEBPAbDDL4Jdi516Q:
@@A]BT@3I4To16A<?`AK@ST4F3T_14lg;@@Z7AX38aHE11lF5@@K4Q0460lA11/@4@@A30h44@`=0c0L
6P@e7QT4jo;g9gQcMAGoool001CooolON7=e11L?3`@Y8244=BPV0cDV90@c92449ATK12dO70@c9B84
=bTX13<R70=@;RD4Qee9195/G@B0IUX4OfaQ17UTF@AiJ5h3Lf1G17ALD`AiI5X4Ke=<16]7?`AaE4L3
Jde516a=A0A/EDX4LU5716]>A@AXBT44KDY40fA9?`ATC3l4Fd8i15Pi;`A?=bd4:QdJ0b<F5@@O5QD4
6a8@11P?4@@K41444@`>114<3@<`71X4=AhI1>_bmbMhLgDEoooo000Doooo7gQcM@@G3`l4:B0Q13DX
9P<e9R@4<b@Q12DI6`@]7a`4<bDR13LY:0@c8Q`3D2hU18MMB@BAK5d4P6IJ17m/H@AiI5T4NFQN0g=P
E`AdG5<4NFAJ16mCC0A[Acl4LEA70f]=A@A/CD@4K5E:179AA`A[CTD4J4Y116e:A0=TBCl4I4`o15]2
>@AH>Bl4CcL]12XM6P<S5QD47aHE11/B40@H3a446a0A114<3P@A30d3<1`J13DN6@C[l_LWN7=e5Ooo
o`005?oooamhLgD48aTI11TC4P@d:BL3<B@R13/]:`@X6aP49aTH13X]:`@_8R04>RTV0bdM6PAN@cH4
Hd0e18YC@PB@LF84LEM<17]WG`=fGeH4MUa>17]PEPAWCD@4Fcde1759?@=gCCd4LU1916e>A0A]AC/4
KE=916Q:>@ATAT83H48i15a1>0A@@CP4@BPT13hT7@@V6QP381HD11XC4@PH3a4450`=110<3@@H3a43
;1XF19F0O@B7RH/WN7=e5Oooo`005?oooamhLgD48aTI11TC4P@d:BL3<B@R13/]:`@X6aP49aTH13X]
:`@_8R04>RTV0bdM6PAN@cH4Hd0e18YC@PB@LF84LEM<17]WG`=fGeH4MUa>17]PEPAWCD@4Fcde1759
?@=gCCd4LU1916e>A0A]AC/4KE=916Q:>@ATAT83H48i15a1>0A@@CP4@BPT13hT7@@V6QP381HD11XC
4@PH3a4450`=110<3@@H3a43;1XF19F0O@B7RH/WN7=e5Oooo`005?oooamhLgD48aTI11TC4P@d:BL3
<B@R13/]:`@X6aP49aTH13X]:`@_8R04>RTV0bdM6PAN@cH4Hd0e18YC@PB@LF84LEM<17]WG`=fGeH4
MUa>17]PEPAWCD@4Fcde1759?@=gCCd4LU1916e>A0A]AC/4KE=916Q:>@ATAT83H48i15a1>0A@@CP4
@BPT13hT7@@V6QP381HD11XC4@PH3a4450`=110<3@@H3a43;1XF19F0O@B7RH/WN7=e5Oooo`005?oo
oamhLgD48aTI11TC4P@d:BL3<B@R13/]:`@X6aP49aTH13X]:`@_8R04>RTV0bdM6PAN@cH4Hd0e18YC
@PB@LF84LEM<17]WG`=fGeH4MUa>17]PEPAWCD@4Fcde1759?@=gCCd4LU1916e>A0A]AC/4KE=916Q:
>@ATAT83H48i15a1>0A@@CP4@BPT13hT7@@V6QP381HD11XC4@PH3a4450`=110<3@@H3a43;1XF19F0
O@B7RH/WN7=e5Oooo`005?oooamhLgD4Fe1I10h720@X7Qd3=BLU13PX9P@Z81d49aPJ13dX7`@`9BD4
?Rl]0bdR8P@h:BD4AC8^164i;PAaAcL4GdI31659?`=fB3/4M5Q:175BAPAI?CL4ESL[15Hf:`=/@c44
LD<i16e<>`AcACT4H4@l160m;`AX@3D3HD8h14lj=0A;;bP4>B4K12hJ60@Q5QD371<A11P?4@@D30d4
4@`>114<3@@@30d48aPF0bhK6@Cck^l4N7Af9gQcMAGoool001CooolON7=e15]@F@@>1`P4:1hM0cDW
9@@h:2H4:R0M12LH6P@m:1l4<2DU13h_;@<]8R84>2TU14Db;PAQ>Bh4LDLg15m6@`AQBCl3MTPk17AH
BPAaDTH4FCdg15Hg:`AF=R/3K4<a1753>@A]C3/4LdDi1614?0AP?Bl4J40e0f52>0A?>S@4BblX13TQ
6`@^6QP48AHE0a`C4@@H3a4450`=114<3P@A30d440`=12<H5P<^6aT4lnk_17QdMRMhLgDEoooo000D
oooo7gQcM@AKD5T43PL812PN7@<e9bD4>2PV12XP7@@W61X4?BPO130U9@@n;bd3;B8R13PY9@A5<Rh4
HCT^1757=`AOAT<4HDTo0gI8>`AdF4X4LE9615Tm=`AF=b/4ESH[0fa3<@Aa@cT4KD`k17=5>@APA3`4
H3d_16Q0=@=Q@SP4CcXd14/_:0@i8A/4;QXH124F5@<L4a4460lA11@<3@@A30h44@`=110<3@@S61H3
;Q/I1??^k`AhM7HWN7=e5Oooo`005?oooamhLgD4Fe1I10h720@X7Qd3=BLU13PX9P@Z81d49aPJ13dX
7`@`9BD4?Rl]0bdR8P@h:BD4AC8^164i;PAaAcL4GdI31659?`=fB3/4M5Q:175BAPAI?CL4ESL[15Hf
:`=/@c44LD<i16e<>`AcACT4H4@l160m;`AX@3D3HD8h14lj=0A;;bP4>B4K12hJ60@Q5QD371<A11P?
4@@D30d44@`>114<3@@@30d48aPF0bhK6@Cck^l4N7Af9gQcMAGoool001CooolSN7=e11TA4@@K5A<3
=bTX134X9P@^8b446a@C13XV8P@n;bd4>bd[0c`_;@@f:bX4@C<]14Hc;@A6<BT4@B`[148[8P=:;2P4
FSH[15Pn=0@n:bX4AbdX14h/90=>;b84E2lY16I1<@AR?2l4ECH[15Lh;@A?;RD3ECPa14L[9P@l9R04
:QTG12`N70@I4Q0371<A11L?4@@D2`d840`=12DG5@@K4aD3Jda71;O0`b]hLgDEoooo000Doooo8gQc
M@@I4A446aDC0cLY:0@a:2H4;R<Q11/D4`@j9R84?Rl]13/]:`<l;bd4=R/Z144c;@A6<bd4AS4Y144/
:`A2:b83BR`X15Xf:`AH?S@4?R/Z14L]:0A>;2@3CRlR15@_:@AV@C44HS`_15Df:`AG>2d4CbhU0eDh
<@A7:bH4?2HP12XI5`@/7Q`46A8@0a`C4@@G3a4450/=210<3@@U5aD46a<E0f]<A`Bg`<<[N7=e5Ooo
o`005?ooob=hLgD46A4A11/E4`<g:BP4<BPV12hS8@@K51<4>RHR13h_;@@k;B/3?2l]13H[:PA1<bd4
AS<]14Ha:@A1;2/4@R/R0dX/:0AJ=R/4F3hd13h[:PA7;BP4CR`T0dh_8PAD;bT4IT4a168l;`AE=R/4
EcP]14l^9@=E>344Ab/V13`V80@Z6AL4;1hL11TB40<L4a445`lA11@;3@P@30d49ALE11/C5@=[C4L4
]l33:gQcMAGoool001CooolSN7=e13he@@@=2PX3<BHT13<W9@@c9B@49b0O13HX9`@n;bd4?S4_0cLY
9`@k;2X4@RXV14T_9`@g:244<RHV12hN6`<l:BL4<Q/H14<^:P@f9RD4<R<Q13@L6@<f8Qh4=QdJ144Q
70A4:b04?bLO148X80@h71X3>R0L13@N6`@b7AX47aHE11lD4P@H3a436A0A11P?4@@@2`d440`=12DG
7@@U5a@4;bDT0kVYZ0AmNW`[N7=e5Oooo`005?ooob=hLgD4?SE110d:2P<a9R@4<bLU13<U90@W81l4
=RPW13h_;@@n<Bl3=bTW13//:PA2:RH4BBlW13LX8@@b9RH4;QhK0c`Y9`@b6aP4@bhZ13HV9@@b8b44
=1`I0cHR7P@f7AX4@B4L14@[80@o9al4@RPP13PL6P<j81`4=1hK138M6P@O5QD47a@B11P?4@<I4144
60lA110;3@@@30d49ALM12DG50@_9B@3^JVX17ejO2]hLgDEoooo000Doooo8gQcM@@n=D443@X:0c4V
90@c9bD4<bDT12LP7`@f:2L4?Rl]13ha;`<g:BL4>b`Z148Z9PA9;bL4=bPQ138V9P@^7Q/3?2TW138K
60A3;RX4=RHU138S8@@d71T3=R8N13HM6PA18A`4A2/P13lW7`A2:204>1`J0cXP70@d7Q/4<QdJ11lF
5@@O518460lA0aT@4@@H3a4440/=110<3@@U5ad49ALD12lU90>iZJP4OGYl:gQcMAGoool001CooolS
N7=e13he@@@=2PX3<BHT13<W9@@c9B@49b0O13HX9`@n;bd4?S4_0cLY9`@k;2X4@RXV14T_9`@g:244
<RHV12hN6`<l:BL4<Q/H14<^:P@f9RD4<R<Q13@L6@<f8Qh4=QdJ144Q70A4:b04?bLO148X80@h71X3
>R0L13@N6`@b7AX47aHE11lD4P@H3a436A0A11P?4@@@2`d440`=12DG7@@U5a@4;bDT0kVYZ0AmNW`[
N7=e5Oooo`005?ooob=hLgD4K6A/118930<L5AD4<bHT13LY:0@a92<4@S<a12`P7PA5=343;20N13`/
:PA6;bX4=bHU13@T8@@c9R@4:QlM0ch[:@@P5QP4<BHR12lK6@@]71X48aHE0b8H5P@X5aD4<A/I12lL
6@@V61D4:ATF12PG5@<a6aT48aLE12LG5P@J4a4471<A11L?4@<H3a4840`=11P?4@@b8Al4:1TG192@
T@>2OX0_N7=e5Oooo`005?ooob=hLgD4K6A/118930<L5AD4<bHT13LY:0@a92<4@S<a12`P7PA5=343
;20N13`/:PA6;bX4=bHU13@T8@@c9R@4:QlM0ch[:@@P5QP4<BHR12lK6@@]71X48aHE0b8H5P@X5aD4
<A/I12lL6@@V61D4:ATF12PG5@<a6aT48aLE12LG5P@J4a4471<A11L?4@<H3a4840`=11P?4@@b8Al4
:1TG192@T@>2OX0_N7=e5Oooo`005?ooob=hLgD4K6A/118930<L5AD4<bHT13LY:0@a92<4@S<a12`P
7PA5=343;20N13`/:PA6;bX4=bHU13@T8@@c9R@4:QlM0ch[:@@P5QP4<BHR12lK6@@]71X48aHE0b8H
5P@X5aD4<A/I12lL6@@V61D4:ATF12PG5@<a6aT48aLE12LG5P@J4a4471<A11L?4@<H3a4840`=11P?
4@@b8Al4:1TG192@T@>2OX0_N7=e5Oooo`005?ooob=hLgD4K6A/118930<L5AD4<bHT13LY:0@a92<4
@S<a12`P7PA5=343;20N13`/:PA6;bX4=bHU13@T8@@c9R@4:QlM0ch[:@@P5QP4<BHR12lK6@@]71X4
8aHE0b8H5P@X5aD4<A/I12lL6@@V61D4:ATF12PG5@<a6aT48aLE12LG5P@J4a4471<A11L?4@<H3a48
40`=11P?4@@b8Al4:1TG192@T@>2OX0_N7=e5Oooo`005?ooobMhLgD4@CDl0a0<30@b:BP4=bTX134T
8P@`9R<4?B`[13lb;`<Y8R84<B8P14T[8`@X7Qh4<b@R134S8@@S6R03=RLR12DH6`@]71T491HL128G
50@Q5aD371<A128H5P@T61H48aLF11dC4@@J41447a@A0bXH5P@L4a446Q0A11dD4@@L4aD45`l@0a0<
3@@H3a447AHE12TL70@/6aT4Pgn118>0PS9hLgDEoooo000Doooo9gQcM@A1=C`340`<138Y:0@g:BP4
<B@R130V8`@m;2/4?c8_0bTR8P@a8R04BB/S12PN7P@c9284<B<Q12<J80<f9b849APK12dL6@@T5Q`4
8QLD124G5@<L4a448QPF12@H5P@S5aH47A<A11X@4@@O5143:QPF11`C4@@J41447A@A11`C5@@G3a03
40`=11P?4@@M5QD4:A`L12`K6@B3Oh44Ph22<WQcMAGoool001CooolWN7=e144e?0<@30`4<RTX13LY
:0@a9284<2HS13d/:`@o<Rl3:B8R134R80A9:b<4:1hN13<T8P@a8b448aXP0cHW8P@U61/4;A`I12@F
70@R5a@48ALE0a`C4@@R61H491PF12<G5P@M4a446Q0A11lD4@<Z61H471<A11X@4@@M514471<E11L?
40<@30d460lA11dF5@@Y71`4;1/I18=oP@B3P88bN7=e5Oooo`005?ooobMhLgD4@CDl0a0<30@b:BP4
=bTX134T8P@`9R<4?B`[13lb;`<Y8R84<B8P14T[8`@X7Qh4<b@R134S8@@S6R03=RLR12DH6`@]71T4
91HL128G50@Q5aD371<A128H5P@T61H48aLF11dC4@@J41447a@A0bXH5P@L4a446Q0A11dD4@@L4aD4
5`l@0a0<3@@H3a447AHE12TL70@/6aT4Pgn118>0PS9hLgDEoooo000Doooo9gQcM@AVFV833`D712LN
7P@i:bT4<B@R138X9P@f:bT4?R`Z0b`Q7`@[7Q`4<b0M12<F5@@e9R<49aXL12HJ7@<U61D49ALN11hD
50@J3a847Q@F11dD5@<H3a047QDF11T@4@@N51H460l@11`C5@@P5a@37A<E11P?40@@30d84P`>114<
3P<L4aD46a<@11T@4@@/5Q84RGn118V:RcIhLgDEoooo000Doooo9gQcM@AVFV833`D712LN7P@i:bT4
<B@R138X9P@f:bT4?R`Z0b`Q7`@[7Q`4<b0M12<F5@@e9R<49aXL12HJ7@<U61D49ALN11hD50@J3a84
7Q@F11dD5@<H3a047QDF11T@4@@N51H460l@11`C5@@P5a@37A<E11P?40@@30d84P`>114<3P<L4aD4
6a<@11T@4@@/5Q84RGn118V:RcIhLgDEoooo000Doooo9gQcM@AVFV833`D712LN7P@i:bT4<B@R138X
9P@f:bT4?R`Z0b`Q7`@[7Q`4<b0M12<F5@@e9R<49aXL12HJ7@<U61D49ALN11hD50@J3a847Q@F11dD
5@<H3a047QDF11T@4@@N51H460l@11`C5@@P5a@37A<E11P?40@@30d84P`>114<3P<L4aD46a<@11T@
4@@/5Q84RGn118V:RcIhLgDEoooo000Doooo9gQcM@AVFV833`D712LN7P@i:bT4<B@R138X9P@f:bT4
?R`Z0b`Q7`@[7Q`4<b0M12<F5@@e9R<49aXL12HJ7@<U61D49ALN11hD50@J3a847Q@F11dD5@<H3a04
7QDF11T@4@@N51H460l@11`C5@@P5a@37A<E11P?40@@30d84P`>114<3P<L4aD46a<@11T@4@@/5Q84
RGn118V:RcIhLgDEoooo000Doooo:gQcM@<b:2X42`P:12@K6P@e9bD4=B/Y13<Y9`@n;B/3;24S12LH
5P@[7ad47ADD12XI5`@P5aH49aLF0aP?4@@K41847A@F11/B50@H3a447A@F0aL?40@M51H45`l@12hL
6P@=2`d481DF124H5@<K4QD440/=110<3@@E30d46a<E11TB50<L4aD4;1/H12TN6`A8<B/4^<OC17Qd
MSIhLgDEoooo000Doooo:gQcM@<b:2X42`P:12@K6P@e9bD4=B/Y13<Y9`@n;B/3;24S12LH5P@[7ad4
7ADD12XI5`@P5aH49aLF0aP?4@@K41847A@F11/B50@H3a447A@F0aL?40@M51H45`l@12hL6P@=2`d4
81DF124H5@<K4QD440/=110<3@@E30d46a<E11TB50<L4aD4;1/H12TN6`A8<B/4^<OC17QdMSIhLgDE
oooo000Doooo:gQcM@<b:2X42`P:12@K6P@e9bD4=B/Y13<Y9`@n;B/3;24S12LH5P@[7ad47ADD12XI
5`@P5aH49aLF0aP?4@@K41847A@F11/B50@H3a447A@F0aL?40@M51H45`l@12hL6P@=2`d481DF124H
5@<K4QD440/=110<3@@E30d46a<E11TB50<L4aD4;1/H12TN6`A8<B/4^<OC17QdMSIhLgDEoooo000D
oooo;WQcM@@b:2X420D712HQ8@@_8R04?S0^13/]:`<e:BT48a/J12lQ7`@M51T471<D12DH5@@L4aD3
7QHD11dE50@K4aD860lA11T@4@<H3a446A0A120G5@@P51H4:BH`12HQ80@N4aL35Pl@11XC50PL5A@4
6a<E130S80<R6QX4;1XH14la:@BCSXX4OGao>WQcMAGoool001Coool^N7=e138X:P@81@L49R4Q12lR
80@n<2h4>bd[0cDY:@@S6aX4;b4O11dD6@@L4a@49APE11`C5@<N5Q@47ADD11/C5@PH3a446A0A0aP?
4@@I414481LE120D5P@Y9S049R4P11hC5`<F3a046Q<D21`E50@K4aD4<2<P0b8J6P@/6QP4Cc4Y19>>
RPAmO7ljN7=e5Oooo`005?ooobihLgD4<RPZ10P51`@V8B44;b8P13h`;P@k;B/3=BTY12<K6P@_8Al4
7A@I11`C50@U61D471<E0ahF50@M5A@46a<E21P?4@@I414360lA11T@4@@P5aD481@F12TV<0@V8B04
7Q<G0aH?40@J4a@871DD11/C5@@`8b038QXJ12`J60A?<BT4Thj:17elOcYhLgDEoooo000Doooo;WQc
M@@b:2X420D712HQ8@@_8R04?S0^13/]:`<e:BT48a/J12lQ7`@M51T471<D12DH5@@L4aD37QHD11dE
50@K4aD860lA11T@4@<H3a446A0A120G5@@P51H4:BH`12HQ80@N4aL35Pl@11XC50PL5A@46a<E130S
80<R6QX4;1XH14la:@BCSXX4OGao>WQcMAGoool001CooolbN7=e13@U9`@81`T4:28R12lR80@j;R/3
A3<`12dU9@@]7QT48aXL11XD50@M4aD460lA0ahE4@@M51H860lA11`C5@@G3a0371<E11L?40@J4144
<R`^12`N:`A2=c04:b<V0adI7@@/9B@48A/J11XD4`@Z7A`4;R0M0cLY:0@k8al4RH2217n2Q3ihLgDE
oooo000Doooo<WQcM@@d9BL420L912PR8P@_8R04>Rh[0d@c<0@]9BD4;AhI12<J70@J51@47A<E11P?
4@<N5A447A@F21P?4@@L4aD45`l@0a`C5@@G3a046Q0A138/;P@/7R/4@SL`12/S9P<M6Ad4;2DT124K
6P@J51<4:QdL12hP7@<g:BP4>b<O18V0PPAoPX@nN7=e5Oooo`005?oooc9hLgD4=2DW10P72@@X8R84
;b8P13X^:`=4<c04;BDU12dN6@@S6Q`46Q@D11dC5@@H3a437QDA11dD5PPH3a4471<E11L?40<L4aD4
5`l@11X@4@@b;2h4;1h[148g<0@[8bH37ATM12`U90@Q6aX46Q@C12XM70@^81d3=bTX13/S7`B9P884
Oh:4?WQcMAGoool001CooolbN7=e13@U9`@81`T4:28R12lR80@j;R/3A3<`12dU9@@]7QT48aXL11XD
50@M4aD460lA0ahE4@@M51H860lA11`C5@@G3a0371<E11L?40@J4144<R`^12`N:`A2=c04:b<V0adI
7@@/9B@48A/J11XD4`@Z7A`4;R0M0cLY:0@k8al4RH2217n2Q3ihLgDEoooo000Doooo<WQcM@AmN7X4
<B<U114:2`@]:BX4<2HU0dDe<P@k;bd4=RTV124H60@U71X4:b8R11hJ6`<N51<47AHE11XB50@K4a@8
60lA0b4H7@@J4Q<47aHD124G6@@c9BD4?b`Y11hE5P<W6QP4:1/H120E5P@U5aD4<20N13@R70=D>S04
I5]V196BST9hLgDEoooo000Doooo<WQcM@AmN7X4<B<U114:2`@]:BX4<2HU0dDe<P@k;bd4=RTV124H
60@U71X4:b8R11hJ6`<N51<47AHE11XB50@K4a@860lA0b4H7@@J4Q<47aHD124G6@@c9BD4?b`Y11hE
5P<W6QP4:1/H120E5P@U5aD4<20N13@R70=D>S04I5]V196BST9hLgDEoooo000Doooo<WQcM@AmN7X4
<B<U114:2`@]:BX4<2HU0dDe<P@k;bd4=RTV124H60@U71X4:b8R11hJ6`<N51<47AHE11XB50@K4a@8
60lA0b4H7@@J4Q<47aHD124G6@@c9BD4?b`Y11hE5P<W6QP4:1/H120E5P@U5aD4<20N13@R70=D>S04
I5]V196BST9hLgDEoooo000Doooo<WQcM@AmN7X4<B<U114:2`@]:BX4<2HU0dDe<P@k;bd4=RTV124H
60@U71X4:b8R11hJ6`<N51<47AHE11XB50@K4a@860lA0b4H7@@J4Q<47aHD124G6@@c9BD4?b`Y11hE
5P<W6QP4:1/H120E5P@U5aD4<20N13@R70=D>S04I5]V196BST9hLgDEoooo000Doooo>WQcM@@/6QL4
5@l?12HL70=1<2d4CCdk140g=P@Z8B448QPH12/L7P@]71T3;b@S128M70@G41<460lA12@K80@P61`3
:R4O11hG7@@f:B@45Q8H14Th<P@]8B@49AhN0bTP7`@U7A`4:B0Q13DZ9P@X7al4ECL/0g]fN0A/J744
NGIg@WQcMAGoool001CoooljN7=e12`J5`@E3`l49Q`L0d4`;@A=?C/4@3Lf12XQ8@@R61P4:a`N12dL
6@<_92<48QdL11L@4`@H3a4491/P120H70<Z8Al47QLM13HY90@F4QP4BCPb12dQ90@U7Qh3:B0O12DM
70@Y8244=BXV12PO7`AE=b`3NgIh16aXL@AiMWM2N7=e5Oooo`005?ooocYhLgD4;1XG11D?3`@V71`3
@C0]14dm>`A0=cH4:R4Q128H60@[71h4;A`I0blT8`@R7A`45a0C11P?4@@T6b0481PL0bXQ7`@N5ad4
=RTT11HB60A9>384;B4T12DN7P<Y81l49AdL12TP8@@e:RH4:1lO15Dg;0=kMWP4K6Qa17UfMd9hLgDE
oooo000Doooo>WQcM@@/6QL45@l?12HL70=1<2d4CCdk140g=P@Z8B448QPH12/L7P@]71T3;b@S128M
70@G41<460lA12@K80@P61`3:R4O11hG7@@f:B@45Q8H14Th<P@]8B@49AhN0bTP7`@U7A`4:B0Q13DZ
9P@X7al4ECL/0g]fN0A/J744NGIg@WQcMAGoool001CooolnN7=e12`S8@@=2Ph36QHD13`/:PA4=C84
@3Y013HX90@^9bT4<BXZ0bPM80@Z:2P4<BTa12TV8P@P6Ah49b4/0c8U8P@d;c/4<bDO12DN80A4<c04
=BHV13HT8P<f9R04;bPX144`:PA@>Bl49AhL1:FGT`=mMgY:N7=e5Oooo`005?ooocihLgD4;2<Q10d:
3P<J5Q@4?2`Z14@e<PA0>T04=RPT12hW:@@a:RX3:1dP12XX:0@a:C44:BHR120I7P@W8B`3<RDR13@_
>`@c9Al49AhP14@c<0@e9RH4=R@R0cHV80@_:2P4@C0Z150i;`@U7Q`4YINC0gegNTYhLgDEoooo000D
oooo?WQcM@@/8b443@X>0aXF50@l;2X4A3Db140j@0@f:2@4;RLY134Z:P<X7B04:RPX134Y<@@Y9R84
81TN12LQ;0<b9B84=2lk13<U7`@U7R04A3<`13DV9P@f9283=RHP12lX:0A1<2X4D3T_12DN70BUUi<3
OGMjBWQcMAGoool001CooolnN7=e12`S8@@=2Ph36QHD13`/:PA4=C84@3Y013HX90@^9bT4<BXZ0bPM
80@Z:2P4<BTa12TV8P@P6Ah49b4/0c8U8P@d;c/4<bDO12DN80A4<c04=BHV13HT8P<f9R04;bPX144`
:PA@>Bl49AhL1:FGT`=mMgY:N7=e5Oooo`005?oood9hLgD4H5EN0b<M7P@?2Pd4=R/V13Le?`ANBDH4
@cPh14<i=@<f;Bl4=c@i148e>0A4>3H4;2<T13H]<@<]8B@4=BLV13LX9@@k;B/4=bTX14HY90A0:bL3
?BdX144d<P@j9R44Hd]:15YIE0B1OX5=N7=e5Oooo`005?oood9hLgD4H5EN0b<M7P@?2Pd4=R/V13Le
?`ANBDH4@cPh14<i=@<f;Bl4=c@i148e>0A4>3H4;2<T13H]<@<]8B@4=BLV13LX9@@k;B/4=bTX14HY
90A0:bL3?BdX144d<P@j9R44Hd]:15YIE0B1OX5=N7=e5Oooo`005?oood9hLgD4H5EN0b<M7P@?2Pd4
=R/V13Le?`ANBDH4@cPh14<i=@<f;Bl4=c@i148e>0A4>3H4;2<T13H]<@<]8B@4=BLV13LX9@@k;B/4
=bTX14HY90A0:bL3?BdX144d<P@j9R44Hd]:15YIE0B1OX5=N7=e5Oooo`005?ooo`AhLgD4N7Qj@GQc
M@@/8bh4:2<S11/O:`@Y92T4FTY6155=D`<m=C08@cPg14Hi>0A3=CP4@3Hc0bl[;@@i;bh4;RTW144f
=`A1=3<4>R/V14Hb;P<j9R@4P6Q[14Y0>0A6>Cl4OGYlDGQcMAGoool001Coool4N7=e17QhNT5hLgD4
;2<^12PS8`@K7b/4:B@Y15Y:APAACE<3?CD`24<h=`A6>CP4@cDh140f<`<_:bd4>Bl^12hY9`A1=SL4
@C@c13X[9PA6<Rh3>RHT181XJ`A:@3P4ASTo17ejO55hLgDEoooo000Doooo17QcM@AhN7Y1N7=e12`S
;P@X8b<46al[12TT:@AJBTH4DDeC0cde<0Q3>3L4ASTh14<e>0A0=S<3;b/]13T_;P@^:BL4@CHg144d
<`@j:bH4AS8^0cXV90B0J6/4BT0h14Hi?`AmNWaAN7=e5Oooo`005?ooo`AhLgD4N7Qj@GQcM@@/8bh4
:2<S11/O:`@Y92T4FTY6155=D`<m=C08@cPg14Hi>0A3=CP4@3Hc0bl[;@@i;bh4;RTW144f=`A1=3<4
>R/V14Hb;P<j9R@4P6Q[14Y0>0A6>Cl4OGYlDGQcMAGoool001Coool4N6maCGQcM@A/I6`4;BXi14]0
@`AJDUl3AcU214i0=P@_:Bh4<2XZ1591A@A=>C43BC/j154n?0A6>CD4ASPf14/d;@A4>344QGao0b8M
80ATEUl4NWMiFGQcMAGoool001Coool4N6maCGQcM@A/I6`4;BXi14]0@`AJDUl3AcU214i0=P@_:Bh4
<2XZ1591A@A=>C43BC/j154n?0A6>CD4ASPf14/d;@A4>344QGao0b8M80ATEUl4NWMiFGQcMAGoool0
01Coool4N6maCGQcM@A/I6`4;BXi14]0@`AJDUl3AcU214i0=P@_:Bh4<2XZ1591A@A=>C43BC/j154n
?0A6>CD4ASPf14/d;@A4>344QGao0b8M80ATEUl4NWMiFGQcMAGoool001Coool4N6maCGQcM@A/I6`4
;BXi14]0@`AJDUl3AcU214i0=P@_:Bh4<2XZ1591A@A=>C43BC/j154n?0A6>CD4ASPf14/d;@A4>344
QGao0b8M80ATEUl4NWMiFGQcMAGoool001CooomQN7=e0faTL0AiL744H5IS13Xf@`@n>TL4>2l_0cT_
<0@i=CL4>C0b13</;@@^8b04;bPV17mgNVAhLgDEoooo000DooooHGQcM@=/I704NG1a161FH`@j=T<4
?SY713P_;`<i;c04>CDg13T`<P@c;2d4;R<P12lX9PAoMgYTN7=e5Oooo`005?ooof5hLgD3K6A`17U`
L@APEV<4>SI313hjA`@h;bl3>Bl`13Te=`@i<384<b`]12hS80@_:2H4OgMjI7QcMAGoool001CooomQ
N7=e0faTL0AiL744H5IS13Xf@`@n>TL4>2l_0cT_<0@i=CL4>C0b13</;@@^8b04;bPV17mgNVAhLgDE
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo002Foooo0`0008Ooool009Woool00`000?ooooooo`24oooo001noooo100000;oool400000ooo
o`@00002oooo0`0000?oool300000oooo`800021oooo001noooo00<0003oooooool00oooo`030000
oooooooo00?oool010000?ooooooo`0000;oool00`000?ooooooo`03oooo00@0003oooooool00026
oooo001ooooo00<0003oooooool00oooo`030000oooooooo00;oool010000?ooooooo`0000;oool4
00000_ooo`040000oooooooo0000Q_ooo`00P?ooo`030000oooooooo00?oool00`000?ooooooo`02
oooo0`0000?oool200001?ooo`@00025oooo001noooo00@0003oooooool00002oooo00@0003ooooo
ool00005oooo00<0003oooooool0T?ooo`00Ooooo`800004oooo0P0000Goool20000T_ooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B71513D
806E617B6A677B736A7B665E7B736A7B6E667B6E667B6E667B665E7B6A5A716256775E52
6D5247735A4D6852466E56496E56496E56496E56496E4E4365523F6A52486A523F6A5248
93AEBB7B7B7B7B7B7B7B7B7B7B7B7B7B72727B80807B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B75757B7E7E7B7B7B7B75757B7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B75757B7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B775641
7D6C657B6A5E7B736D7B665E7B736A7B6E667B695B74665B78665B7862546F5C516D594C
6E524670574A664F4371584B6E56496E56496E51446E51446552446A52466A523F6A6869
93A0A77B7B7B7B7B7B7B7B7B7B7B7B7B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B77787B77777B7E7E7B77787B7C7C7B7B7B7B75757B7E7E7B75757B7E7E7B7B7B
7B7B7B7B7B7B7B7B7B7B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B74543F
7E6D637B6A627B6D667B6E667B6A627B6C63746353625F597C5D5074534C6A57486C5B4E
6E574B6E594C6B51466A52456C53466C53466C51446C52406852476A52456A5244839AA6
8385877B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B75757B7E7E7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B72727B80807B7B7B7B7B7B7B7B7B7B77787B7C7C7B77787B7C7C7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B77513D
7D6E687B6A647B6A627B6D657B69617B6A5C7767606D6660755F507B5355675645715649
71574F71574D6A4A426553446A52456A52456A52456A524470574B6750446A524593AEBB
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B5641
7B6C627B6A5F7B6A657B6A627B6A627B6A5F7B70697B6D6577655A775E5571564E755A4C
755B526F514B745B4F6347406C4E456C5F55674D40705245705447655144705C4F8FA7B4
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B5843
7B6A5E7B6A647B6A5E7B6A657B6A627B70687B6A627B6C637B6E6677655A796358735C4F
775B5573594D735B4D6C4C486A53476E55496B5A526A4D406C524568524581797785969D
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B75757B7E7E7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B684F4787705C
7B6A647B6A5E7B6A5C7B6A677B70687B6A627B6E667B6D657B70687B665E7B6A5F775F51
795D54735B4F735B4F6F504B6E56466A4E4368564B684F4270524567524589939C808889
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B77787B7C7C7B7B7B7B7B7B7B7575
7B78787B7E7E7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B352C259B7563857364
7B6A677B6A5F7B6A617B6A647B736A7B665E7B6D5F7B716C7B69617B69617B6A5C7B675A
745650745C4F7758526D56456C4E436C56496B5044675245735C4F6B52478BA4B17D7E7E
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7778
7B79797B7C7C7B7B7B7B7B7B
7B7B7B7B7B7B7B75757B7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B625A5F100906DEB49F7D6C5C
7B706C7B67607B70687B67607B6D657B6E667B6D627B6A647B695B7B5A5A74614F725C4F
785C53775E51715B526A52437352476A574A684E3E6852476D56496C524591ACB97B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B77787B77777B7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B81808019100C796254A88B7A7B6A62
7B6D667B69617B6D657B69617B6A627B6D657B71697B665E746555785454745E4E6D564A
765C50745B4E715B496851477251446C53466B51436C524667524570574A898D927E888B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B75757B7B7B7B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B22171178685E9D80737D6C5C7B6A67
7B6A627B6A627B6A5C7B6A657B6A627B70687B6A627B6961713F3B774C4871443D71463F
7346407363506C52436C52466E4B406854427152476E5245655240734E446F60558DA3AD
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7575
7B7E7E7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B625A5A3F352EA5887B7B69617B6A5A7B6A67
7B6A627B65577B675A7B675D7B6D687B6D657B58567B615C713735713F366A312A774743
6C3C33774C4562493E6C53446C5240684D417354486E52456B5244704A406B5B4D7B6C62
8799A27B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7778
7B7C7C7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B17110EC29A82806D607B6A5F7B6A5C7B6A67
7B6A5C745D50785D527E72647B6C687B5F52743F4072443A6C4D465D2D2176615579524E
62261F6F342C6C443A674D426A5A486A4A366D55477152476E52456E4F446E55486E584B
8D9B9F7B81857B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B75757B7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B4D4142342A20B797817D6C65745F517E766E7B6761
7B5F506B55446D4A4089706D6F3D3935120A9F7168713F3874645B6D65606F342C624C3E
583427684743512D217D362D645A486D4E35705047705A4D755A486A4D446E574A6E5245
79695D878F917B81857B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B75757B7E7E7B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B140E0DB38B718B78707B6A5E7155498079737B6961
7B5A4B613F2F66423942131189827A574A4691827B7763657B6D6B7D7D766D3D336F6F6C
64554E544947371D16412013824433726249734B43756354755B4C6E55466A50456E5144
6E594C79869E807F7A7E81817B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B686470060402E3B393806E647B6A5C7761577D6F6B7B6A62
6F4639543A275D281F290D08AE7D6F847666785F597E89887B66597B6D616B4B437E8080
6F4D406D6A66442F27413D373A1B1488463374594C7C655179655A6F55476850466E4A3F
6E56496877796D64617C7C8B8788817B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B352C252718165D4137BA9D847D6C5F7B5F547B65587B70657B6A5F
673D346455456D534C564742916161755F5271534C78655D7C49436C574B6C3730733F36
683C317A79675F392E5A4646342A243E0E069766587E6A517C6B606D5242684D43684E43
71584B6B64587B828C615C6D91968B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B75757B7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B685F640505031F120FE5AF9B8776647B65597B5756746B597E70637B5A59
67493B6044338F88807D71687B5E5C77635B7567607760597B5A526B5248734E466D4A3D
6D4D456C55477138366038314B2A1E34130E6D2B208C755D80695D6D5542684B43654C40
7356496E5A4D31261FAAA8B27D7C797E81817B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B5D56642E2C1C52413CA68C7A7E6D5F7B62567B665F775B587D75617B615B
674C406140358B7F717E736D7B6E667B67607B6D657B6E667B5752715A4A775E526D5648
735247624C3C6F453F664B3B603F37573D355D3A3A7C604180665C715845684B43654F3F
7353486E594C161A1BB4A59F878A8D7D7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B6E5850816A5D77675E7364557A695C7E6A5E7B6C657B615E7B74687B675E
6D55486B493F715447827B6E7E76707B6B647B67607B736A7B5D54715649714E42715D4B
664D3F5B4B406B473767473A674B3A67453A64483A755D4B7B605573554662483E684E40
6D54436C54490D1010C9BAC98B8F8A7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B746F707E5E48745F56725C4B66666B8969557D6E687B70697B6D657B70687B6B64
77524E6F57486B483D7F70618077727B71697B565474705E7E6C5E6B4D43714F43664436
6656485E4036684A3766473E6C4F3763453966453480635775584B6C4F4363493E6A4D41
6A554670574B010608CAAEA99398967B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B775E507D675D6B50436A524475736D875C577B756A7B736A7B6E667B6E667B6E66
7B5D54775C4E694F3F76544984807A7B736A7B5D59776C607D6C626D4F486F554764453B
6C55485E3C32664739664B3F6F50416C4B407155487960546C4E436C51446B4F44674B40
6A55436D5449000607513932CDC5C77B7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B584374655B5A372980766981605F7D6C5F7B6F687B736A7B74717B6B617B6E66
7B665C7B6556674D4173554680796E7E706A7B695B7B706B7B676071574B674A3E6C4F43
68524565463B684B3663433A6F52467A58507B63546F594C6855496E5247685044684F44
6A5344705C5022221A311E1A463934C2C3C37B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B645A6F4637663730614D3E767C738D685F7B6F5F7B6A677B736A7B716C7B6C647B6E66
7B665E74655571574D7565567F70647D6C62745A527E76687B58596B574166433B684E42
62493D6D4E38583F336B453A755F517B5E527C63556D564A6855486E4F436B5144675240
704C427064555E3F334B3A35617E88A19FA07B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B4A42673B325F322C6A62507D7A6D8770687B70667B67617B736A7B6E667B6E667B6961
7B695B7162557D5E52736A5D806E687B7066775E597D6F647B574F67534462433B62483C
5F433766483861463C765A4C7960537560547C5F536D564A6852466E4E436E4C456B4E44
6A4C4071655D5F3B2B6D51479ABBC77777787B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B695F
7B5449673E365A3B2D7364568B7F6F7D6C687B736A7B6B647B6A627B6C637466587E6C60
7B5A577165547A5B5074685A80716D7B6D5F7B69647B6A627B5550674B3C5F483D61463A
63473B5F4D42715341755C50795D5079625573584C7153476855486E493E6E4C42684D42
68534073625F673F326855497B8791888D8C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B6F4834
634136453025613F318B7567897B6B7B6A677B6D657B6C637B695B7B655A7165577A5D57
725A5178615777685977665A8070657B6A627B6A647B6A62745C526B483C5F483D61463A
66493D6850446E55467A5952755D4E765C50715E527355496853476E5146684E43684B40
6A504673645D622E1E716D5F67463E93B1B97B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B612C1A
271910462F273C2622B38C7586786F7B6A647B6A5C7B6A5F7B6A627B675E77696079635D
6F564D73534C6D5D4C7E6C5E7A6C5E7E6D697B6A627B6A5C71575067483B5D3F3E644A36
60443A725246705B4D745247705A4C77574F6C544570584B664F436C53466851446A4A3F
6A4D486D5A4B5A35227058466C3E3993BDC67B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B6F6A633327
29211A2F221B352321C3947986786B74655A7E6D657B6A5B68554B735E5261493D6B5144
684B456C4542735A47755A4C78695B84756F7B6A627B6A5F71524D63483A5C4135664533
5D493F6E4C3F655447664D41725649755D52664C4071594C6B53476750446A52456A4A3F
6A4D486A554544271C592B1E7A4C3A97C0CE7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7455446B4641
0E06041E15112D1E1ADBA3857C6F617B65597D6E647B6A5C69554A56463B4C3A2F392F2C
342622532D1E744C3B5A2D216035279B8C7B7E706A7B6A6271574B63453A5C4332604C37
5A3F3675594B6B574B6953487051446A50495D4C3F7A5C4E6E5649654E435F4C40654C40
7153486A53453D241C54281D7C443499C9D77B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B818080734735634139
070E0F19120F311A15E4B3947D6D607763587E6E617B6A5E77655F5541376A56501D1F1C
1F14113A1E144F3D376B36287656498F86758076717B7370715A49634238513A2E5D4531
33100A87634F684A335A443A4E35287353465F4F427858456C534868514458453A624F43
7450485F493B37201C5E3527814D449CCBD47777787B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B78787B7E7E7B75757B7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B1B0A07B772596B5449
19171613131823140FEDBA997A695C7B6A5E77665A78675B7E6D6969574975564C3B3831
453B364833265743347B5744825E527F7364807A757B716C715748634339553B2C574034
3C221C61534D3A2F270D07075A31254E413533211869483B5B3D2A784E3C5B4E44624E42
744D43483D30291B164E2C239D6A599ABEC97576767B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B77777B80807B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B1D100D180E0C390A055B392C
15101416130F2B1813ECB99877665A806E6865433C715F4F897A75776D62755D55695048
654B3E624D41674B3F79614D7D5F5679695C807C777B6E667151486350435C3D2E5A4B38
603B2F62585046372F0407094723173E2F2B251C186A41306745367C5B4760483E5F4F43
745341231B1A281D15402219A14F3B99C5D17879797B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B79797B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B0100003021182814112F211C
0E0A0B2C1A142F1814E4AF8F7D695C77695F7258556351436044386E57495E4B3E4F3832
482C235539295F3A2D633D2D8872637E6F6180736E7B6C5E7151486356495C3D31634633
624D39725849634B42293130553E334732294433297852427050396453486D503F655247
624D4014120F2517134222198E3626A1D7E27B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B0200001E100B1B1410211511
1B120F1E1511382723CA9377897062776C5F7D6C686E5E55604F435F423C46413D6A4941
4E392E5B473A593C31745347877D6D8170697D6C657B5A55715F4F6353485C393845281B
5132237861457154476A5242694D4359473857463D775744604C3F6A4D48625040715443
483C320A0B0A1B14109156435D271CADDCE77B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B75757B7E7E7B7B7B7B7B7B7B7B7B7B7B7B0702001B0D0A1D15111B1410
0F07072316113B2B26A6745B9275667E71647B6A677B7068776A5F6D59555F5D597E665D
6C5D5470635B6B5B547E6557776B5E807470746255785F5774615269574C69504A4C3A30
3721203F2B1E39251B7C4D3B7B5D4F68523F634F41624D4164473C59453A7151496E5040
231C16110E0D28221D9248334C22183E3E3BBEBEBF7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B77787B7C7C7B7B7B7B7B7B7B7B7B7B7B7B0704032117141D130F1F1410
140E0B2415113A2B269D6750947A698073657B6A677B736A7B6E667B74717B716C7B716C
7B6B617B74717B6B617B6B617765567D6E64776659735E52775B507362567561556D534E
483F3D4C3B34312C2640261C3B271C59352A483D3257382A55382A76574F714F4364483B
0E0D0D1A120F271A1A38120C4A19102F322FDFDEDF7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B07050433262214110D211410
1D130F261919392A2484584290736289796A7B6A617B6D687B71697B716C7B76747B736E
7B6F697B74717B695E7B6E667B6B617B67597B6A5E715A4F775F54775E52776558775956
695B4F6750464E4139443B3443382F50342A4B3A2E6C473A5B4B40774948625140564236
0D0C0C1D130F1C1411180F0B341A153F3631DDDCDD7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B0B05032F20181E18161E130F
24100B291A1636241A593E31996D5A8A7B6C7E6D607B6A677B736A7B74717B6E667B7674
7B736E7B736E7B695E7B6E667B695B7B69617B655671574C776558775F54775E52775C53
6D584B6E5347675246604D426551455A453B614B406E4C41674F486A4940604A3C3A2B20
15100F1D130F28181417130F2415113C271CAD96999299987B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B070301332925221916251613
160F0B231511231511492C21774C339F86768071647B6A677B736A7B78777B6F697B6E66
7B76747B6C647B6C647B6E667B66567B6A61745D50745E52775E52775F53775C51775E52
6D564A6C52466C56496B594C6A50446E51446752455F4A3F654D43654D40513D311C1816
110D0A26191917101016100B0F0707341C1682645EAFB9BB7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B0703012F26232C221E251A16
2216121F1410291D19402E2852382BAA7B678976677B6D697B6D657B746E7B76747B6F69
7B74717B695E7B6E667B6E667B665C746556745D51775C51775C51775E52715E5274584C
71584C6852466E56496E584B6B52466A5044685245584A3F6E4D415C483C352923181210
221A16120B0B1710100F0707171010261611705750C0C6C87B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B0905033228253428242B211E
251612140F0B2E1A16422A1F5A3C2C915A428E7C6E7E71677B6A657B6D657B746E7B7674
7B736E7B6F697B6B617B6E667B665E776757735C5071594F74584C7A5B546D5B4C735347
73574F6855466E56496E514468534668514464473B674E4262433743362F2B1E171D1411
15100B150F10130B0B16100B1810112D1914CAC5C49495967B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B75757473730707063125213629252E231F
1B110E251C182B1C1832231D683F2D7E51418B78698476687B6A677B70687B70687B7877
7B736E7B736E7B695E7B6E667461547E675A71574C735C51755B4F73574D715A4C735246
6C5B506C5346684B446C53446852456A524567483D604E42533B30443329211913221513
16130F1B14101A130F17100B1C14112F1915FFFFFF7777787B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B77787776760304033C251C2F2522342824
281F1C261B172C211C3221185C453A663E2F906A59847A6A7E6D697B6D657B71697B716C
7B70697B70697B675E746658745E517A695C74564B715847745B50715847735A4F73574B
6856496E55486B4C436753456A4C406A4E425F4C405343374C332830211E1E1411191310
150F0B181010130B0B0A0707150C0C492A24E9EFEF7879797B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B050403312016332A27352925
291F1A251613342319312521493A2F4B281F8C5C498E8473806E647B6A5F7B6D687B6C5E
7B6C607B6C607B6964776757735C50775F53715145715647735750735C4B735A4E734F43
68574A6E51446E51446552456A4A3F64483C5045394C352930201E291E161A120F191410
1F130F161010120B0B120B0B2D1915C9BCBA999C9D7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B110C0B271E1A3226223B2925
2B1E16291F1B291C183427232F231D3B29257447348D6E5686776A78675B7E6D637B6A5C
7B6A5E74655978675D7E6D5F71554A7152467158476C4E4470584D70584A77574A6C4D42
6C54476E4B4468544568524064453B5F483C4A3E3238221C261D161C130F150F0B171010
231410150F100E0707140C0C321B16F9F9F97879797B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B18130F28201E342824322420
2F231E201717281C182F231E352925312018482A1F7857438666577C62547E6C5E786558
786A5D7465597761557A66596F574C6A4A3F7055466C4F446E4E426E55487253466C5144
684C406C4C42624A3D624B3D56423750372B483428241A141B120F191310160F0B130B0C
150C0C0A07070A07072F1A15361E15EDF2F67B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B322B2C1F18143328242E231F
3A2E29281B15261714392C282C201C362823281B17533F3253392E764939856A5A6B5447
75635B715D54715B4C786255644D42533B30664538704A386F50466C50436C44386C5346
684C3664483F5F43375A41354E41353D2620361F171F15131B130F15100B120B0B130B0B
0F07070A0707140C0C281711AE9D9AA5AAAB7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B67636814100C251D1A312521
332622251E1922161738251A2E24213D2F2B2D24213528223F2F2A58362B6240304E3E3B
4E4037623F30665040634C3E4B362F4B32254D3225603F2B663E326548356E45355B4438
56392A5F3B2F5B3F33483831422C23311D162716131B1310150F0B120B0B0F07070B0808
0B07070A07071F15112D1915F6F1F17D7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B211D1D1D1714362A25
2F28242D221F17110E35241E3C2F2C3A2E293B302C392E2A43362D45352C403127392927
3A261C4027224D2F244C372D3426243C2924462920472C1D492B235A3D2C57382A493125
4F3529472C204A352C3E282035231B231612261B18130F0A16100B120B0B0E07070A0707
0B070723151018101076554EC9D1D27B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B4D4852140F0B2F2420
2F252130242028201D382A263D2F2B3D322D3328243629253D2621452B2234241C2E2421
271B163526232A1813382A252F24202C201C2C18132B1E182B1914351B1637241A342219
3623192D1714301A1629181429191418130F18100C110B0B130C0B130B0B0A07070A0707
231519231510302622D2C3C08E91927B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B737074211D1B1F1916
3024203529252F232041342F291F1A40312D271E1A382B264631283327232E231F2F2421
281E1A3E2B271D14152C241E2918142818141E130F1B15112214102C19142A1914201410
2215102014102B19141E1410211410150F0B17100B120B0B130B0B0A07070A0707140C0C
31201B271713B2B1B0A19FA07B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B4B4349150E0B
3229253529252E231F2A231E392C2841342F2823202D201C43281D221B182D211D2C211C
1D171B2F241D1F15162A19141F13181B140F1B141016100B1D14101D14101C1410160F0B
130B0C19110C241511150F0B130B0C17100B171010120B0B0A0707130B0B1B14102A1C19
2B1915A6A3A3A6A5A57B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B6E6A6E17110E
271F1C3629252E231F322824342B26382A26271F1A261B172C1D181C130F31241E221718
21171821151020141917100F130B0C181110181010120B0B191111130B0B181110120B0B
1710101C1510181010120B0B0A07070B08080B08080B070718101018100B140C0C26120C
A69B9CAAABAB7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B4B4847
1E1A18241B18312521322A262F28243C2D292B2121241612281D1918120F2416111A1410
211410120B0B140C0C171010160F0F130B0B181010120B0B181111120B0B2D1A15080707
1A11111D1510160F100A07070A07070F07071810101610101810102B19142E20185C3C2E
CED8E07D7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
4B48471B16142824212B201B3C2F2B3A2D29352A27211B172C201C1A121617100F211410
1710101A130F1A1310171010130B0B130B0B140C0C130B0B140C0C1C14101A1111282833
2B26241D1115110B0B1610101A14101A131017101030221D241A172B1814523227ADABAA
90979B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B4F49481C18162D26222C201C332B2741332E2F27242D1E1622191817120F181010
120B0B19110C181010120B0B130B0B181010120B0B181010120B0B140C0C302C2D2B1D29
43362D332927241D1E362B27251D1917120F291C192C1E19362A2541261EAAA1A1979FA1
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7E7E7E494342201611312C293127244335303A2F2B382C27201815241A172E2421
211D191D120E1A1410160F0F171010130B0B130B0B1D151A160F0F1B14101B12132C221E
3A2A23160F101D15111F16111710101F140F2C1E1A3221185C3C2E7F747EA5ABAA7B7C7C
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B473E3A231E1A231B183B2D284C3E39433C382E2623211815261919
2818142F2420221E1A140E0F130B0B21191D1E171A2A221D1C161A392B241511154C3B32
2D2223271F1C2D231F271E1A2D22203E31272C211F603D2D9D9799868B938183827B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B47454139353A27211C382B263D312C3C3A3F3C2F2A3B3230
3F37332A202128282738303A3C352F281F2128232C3225223A3440362720261F1D45342E
34252237231F37241B3028254532295A3D2E281E19B9B0AD9093987B7C7C7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B6B676B474945211B1E382E2833343D5C4C47453E3D
433C373A3331423F414B3C3A453A332C242239302F2D21222F242031241F392D29352925
452820442C244230274A3A333E261E624C4C787F7D9D9FA27B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B78787B7E7E7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B47454A5B5A564E4F5A352F355B4D48
605A634D433E4B3D39443A36473B374B3C3D4D3F393A34324A3B373A332B493D3A4D3D39
41332A4637303526228570766F6E69716F739093927B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B79797B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7370744B4D54736D6A
76757C5D555C6C645B4C47503A363A51454D493A31463C384E3F3A443A35453936453228
3E352C9A93965757588983878589877B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7370787F7D796B686F57595E66666A635F5A655E5D656665656262615F5F5F5A57
61615F9995987B7C7C7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B7B
7B7B7B7B7B7B7B7B7B7B7B7B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?oooeUkNg/4LE4m181^H@=kJVL4Ng=Z17]VGPAkLfX;NfiV17]V
GPAkJUX4LF9F17MNDPA]DTL4LeY=0fQBAQ1^ETT4KTi30fEB?`AZDTP4JU8o16YBB0BC[[/?Ng]k17]b
LPAkP80SNg]k5Oooo`005?oooeUkNg/4LE4m181^H@=kJVL4Ng=Z17]VGPAkLfX;NfiV17]VGPAkJUX4
LF9F17MNDPA]DTL4LeY=0fQBAQ1^ETT4KTi30fEB?`AZDTP4JU8o16YBB0BC[[/?Ng]k17]bLPAkP80S
Ng]k5Oooo`005?oooeUkNg/4LE4m181^H@=kJVL4Ng=Z17]VGPAkLfX;NfiV17]VGPAkJUX4LF9F17MN
DPA]DTL4LeY=0fQBAQ1^ETT4KTi30fEB?`AZDTP4JU8o16YBB0BC[[/?Ng]k17]bLPAkP80SNg]k5Ooo
o`005?ooo`AkNg/4NgEe17]nOPAkNg/4NgEe0g]nOR=kNg/4NgEe17]nOQMkNg/4MeI117e/I@=kJUh4
Ng=]17]VGPAkLfX4NfiV17]YF`=dIU/4N6IK17QRE0A_G544KEU<16iBAPA`EdX3ITm3175HB`Q^ETT8
KU540fEBA0AZDTH4JU8o16YXJ@BCX:L?Ng]k17]gN0AkO7`SNg]k5Oooo`005?ooo`AkNg/4NgEe17]n
OPAkNg/4NgEe0g]nOR=kNg/4NgEe17]nOQMkNg/4MeI117e/I@=kJUh4Ng=]17]VGPAkLfX4NfiV17]Y
F`=dIU/4N6IK17QRE0A_G544KEU<16iBAPA`EdX3ITm3175HB`Q^ETT8KU540fEBA0AZDTH4JU8o16YX
J@BCX:L?Ng]k17]gN0AkO7`SNg]k5Oooo`005?ooo`AkNg/4NgEe17]nOPAkNg/4NgEe0g]nOR=kNg/4
NgEe17]nOQMkNg/4MeI117e/I@=kJUh4Ng=]17]VGPAkLfX4NfiV17]YF`=dIU/4N6IK17QRE0A_G544
KEU<16iBAPA`EdX3ITm3175HB`Q^ETT8KU540fEBA0AZDTH4JU8o16YXJ@BCX:L?Ng]k17]gN0AkO7`S
Ng]k5Oooo`005?ooo`AkNg/4NgEe17]nOPAkNg/4NgEe0g]nOR=kNg/4NgEe17]nOQMkNg/4MeI117e/
I@=kJUh4Ng=]17]VGPAkLfX4NfiV17]YF`=dIU/4N6IK17QRE0A_G544KEU<16iBAPA`EdX3ITm3175H
B`Q^ETT8KU540fEBA0AZDTH4JU8o16YXJ@BCX:L?Ng]k17]gN0AkO7`SNg]k5Oooo`005?ooo`AkNg/4
NgMh17]gM`AkOWh4NgMh0g]lO0AkNg/4NgEe17]nOPAkMGD4Ngin3g]kN`AkMgP4Ngal5g]kN`AdE3l4
OVeS0g]ZHPAkKFH4NfiV17]ZHPAkK6<4M6=C0f9OF@AlGE04M5=<16YGB0A/Fdh4KUM;16iIC0=[DDH4
JU9526aCAPA/DD@4K5900fQBA`AZDTD4JU9418>JYPB3QHLCNg]k17]eM@AkOWhONg]k5Oooo`005?oo
o`AkNg/4NgMh17]gM`AkOWh4NgMh0g]lO0AkNg/4NgEe17]nOPAkMGD4Ngin3g]kN`AkMgP4Ngal5g]k
N`AdE3l4OVeS0g]ZHPAkKFH4NfiV17]ZHPAkK6<4M6=C0f9OF@AlGE04M5=<16YGB0A/Fdh4KUM;16iI
C0=[DDH4JU9526aCAPA/DD@4K5900fQBA`AZDTD4JU9418>JYPB3QHLCNg]k17]eM@AkOWhONg]k5Ooo
o`005?ooo`AkNg/4NgMh17]gM`AkOWh4NgMh0g]lO0AkNg/4NgEe17]nOPAkMGD4Ngin3g]kN`AkMgP4
Ngal5g]kN`AdE3l4OVeS0g]ZHPAkKFH4NfiV17]ZHPAkK6<4M6=C0f9OF@AlGE04M5=<16YGB0A/Fdh4
KUM;16iIC0=[DDH4JU9526aCAPA/DD@4K5900fQBA`AZDTD4JU9418>JYPB3QHLCNg]k17]eM@AkOWhO
Ng]k5Oooo`005?ooo`AkNg/4NgMh17]gM`AkOWh4NgMh0g]lO0AkNg/4NgEe17]nOPAkMGD4Ngin3g]k
N`AkMgP4Ngal5g]kN`AdE3l4OVeS0g]ZHPAkKFH4NfiV17]ZHPAkK6<4M6=C0f9OF@AlGE04M5=<16YG
B0A/Fdh4KUM;16iIC0=[DDH4JU9526aCAPA/DD@4K5900fQBA`AZDTD4JU9418>JYPB3QHLCNg]k17]e
M@AkOWhONg]k5Oooo`005?ooo`QkNg/4Ng9b17^0P0]kNg/4NgMh17]lO0AkMgP4Ngal;W]kN`AgDCd4
OFiX0g]ZI0AkJV84NfeU17]YH@AkJU`4MfMP0feVH0AeGe04Ne=E16MFA@AaETT4LEM?175GC@=ZBT84
IE=436YBA@AZDT@3L5M;16M@A0AZDTD4Tjjk5g]kN`AkMgP4Ngal7g]kNaGoool001Coool8Ng]k17]b
LPAkP80;Ng]k17]gN0AkO7`4NgMh17]lO2ikNg/4Me4m17e^J0=kJV@4NfYR17]]I@AkJF44NfYL17MW
H0=]IV04MEm@17]CE@AWETD4LEI9175GC`AaEdd3JTY216ECA0aZDTD4JU940g1GB`AWD4@4JU9519>^
^aMkNg/4NgMh17]lO1mkNg/Eoooo000Doooo27]kN`AkLW84Nh202g]kN`AkMgP4Ngal17]gN0AkO7`^
Ng]k17MA?@AmKVP3NfYT17]ZHPAkKFD4NfUQ17]ZG0AgIf03KFIP17EOD0AkDeD4IeI5175FB@AaEdl4
LEM=0fY:@PAUDd@<JU9516YBA0=`Ed/4Ie1416YBA@BC[[/GNg]k17]gN0AkO7`ONg]k5Oooo`005?oo
o`QkNg/4Ng9b17^0P0]kNg/4NgMh17]lO0AkMgP4Ngal;W]kN`AgDCd4OFiX0g]ZI0AkJV84NfeU17]Y
H@AkJU`4MfMP0feVH0AeGe04Ne=E16MFA@AaETT4LEM?175GC@=ZBT84IE=436YBA@AZDT@3L5M;16M@
A0AZDTD4Tjjk5g]kN`AkMgP4Ngal7g]kNaGoool001Coool8Ng]k17]gN0AkO7a9Ng]k17]F@@AkK683
NfYO17]ZI@QkJV84NfYO17]`J@=kKFD4MfEJ17MNE@AaETh4MEY<17EKDPA_DD/3M5]?16=7@0A/CTD4
K5mE16M=@0A`DTD3L5A716EAA0A`G4l4SjNd?W]kNaGoool001Coool8Ng]k17]gN0AkO7a9Ng]k17]F
@@AkK683NfYO17]ZI@QkJV84NfYO17]`J@=kKFD4MfEJ17MNE@AaETh4MEY<17EKDPA_DD/3M5]?16=7
@0A/CTD4K5mE16M=@0A`DTD3L5A716EAA0A`G4l4SjNd?W]kNaGoool001Coool8Ng]k17]gN0AkO7a9
Ng]k17]F@@AkK683NfYO17]ZI@QkJV84NfYO17]`J@=kKFD4MfEJ17MNE@AaETh4MEY<17EKDPA_DD/3
M5]?16=7@0A/CTD4K5mE16M=@0A`DTD3L5A716EAA0A`G4l4SjNd?W]kNaGoool001Coool8Ng]k17]g
N0AkO7a9Ng]k17]F@@AkK683NfYO17]ZI@QkJV84NfYO17]`J@=kKFD4MfEJ17MNE@AaETh4MEY<17EK
DPA_DD/3M5]?16=7@0A/CTD4K5mE16M=@0A`DTD3L5A716EAA0A`G4l4SjNd?W]kNaGoool001CooomI
Ng]k17]H@`AkJUh3NfYT17]ZGPAkJVD4NfYR17]`J0AkJV83NfaS17]^IPAgIEX4NF=H17=LC`AgFeD4
LeU=0g=KC@A/C4P4JU=716iEB@A[FU84JTe00faBA@AXDTD4PGUg18FFWA]kNg/4NgEe17]nOQ]kNg/E
oooo000DooooFG]kN`AkF4<4NfYN0g]ZI0AkJUh4NfYU17]ZHPAkL6P4NfYR0g]/H`AkKVH4MfEJ17US
F0AcG4l4Me]E17=IC@=cFdd4K4a816YCA`A^EDT4JeYB16Y=@0=/DTD4J595185iM`B5UYdKNg]k17]e
M@AkOWhKNg]k5Oooo`005?oooeUkNg/4NeQ317]ZGP=kJV@4NfYN17]ZI@AkJV84Ng1X17]ZHP=kK6<4
NfiV17MUFPAiHeP4Lea?17MKE@AcFDd3Le]=16a<B0AZDdL4KUE916]JDPAZCD03K59516QBA@B1NGL4
QIJM6g]kN`AkMGD4Ngin6g]kNaGoool001CooomENg]k16Q?A`B7L5`4NfYT0g]ZGPAkJU`4NfYW17]`
J0AkJV84NfiV0g]]I@AkL6P4NfIN17]ZG`AgGe44NEeD1g=KC`A_D4/4KUI616Y>@`AXET/4J4m20g1B
A@AWDTD4RI>L1828RA]kNg/4NgMh17]lO0MkNg/4NgEe17]hN0AkOWh8Ng]k5Oooo`005?oooeEkNg/4
J4m718M`G0AkJV@3NfYN17]ZG0AkJVL4Ng1X17]ZHPAkKVH3NfeU17]`J0AkIUh4NfYO17MOD@AiGE@7
Le]?16m@B`A^ETH4JTi316QFB`AXCd83L59516MBA@B9Ti`4P8R96g]kN`AkMgP4Ngal1g]kN`AkMGD4
NgQh17]nOPQkNg/Eoooo000DooooEG]kN`AXCdL4Qg1L17]ZI0=kJUh4NfYL17]ZI`AkL6P4NfYR17]^
IP=kKFD4Ng1X17]VGPAkJUl4MemA17UME0McFdl4Ke1;16iFAPAZCT<4J5I;16Q?@P=`DTD4Ie9518VC
W0B0R8TKNg]k17]gN0AkO7`7Ng]k17]eM@AkN7P4Ngin27]kNaGoool001CooomENg]k16Q?A`B7L5`4
NfYT0g]ZGPAkJU`4NfYW17]`J0AkJV84NfiV0g]]I@AkL6P4NfIN17]ZG`AgGe44NEeD1g=KC`A_D4/4
KUI616Y>@`AXET/4J4m20g1BA@AWDTD4RI>L1828RA]kNg/4NgMh17]lO0MkNg/4NgEe17]hN0AkOWh8
Ng]k5Oooo`005?oooe5kNg/4=B`U19]eH`B5Lf@4NfYW0g]ZG`AkJV44NfYT17]cJPAkIUh4NfeO0g]a
K0QkJF44NfYL17]WFPAdEU04M5a?0gMHDPA]ETD4K4i316aFB@A[D4@4Ie950g=LC`A[DTL4RjBa17en
ORYkNg/4NgMh17]iN@AkO7`8Ng]k5Oooo`005?oooe5kNg/4=B`U19]eH`B5Lf@4NfYW0g]ZG`AkJV44
NfYT17]cJPAkIUh4NfeO0g]aK0QkJF44NfYL17]WFPAdEU04M5a?0gMHDPA]ETD4K4i316aFB@A[D4@4
Ie950g=LC`A[DTL4RjBa17enORYkNg/4NgMh17]iN@AkO7`8Ng]k5Oooo`005?oooe5kNg/4=B`U19]e
H`B5Lf@4NfYW0g]ZG`AkJV44NfYT17]cJPAkIUh4NfeO0g]aK0QkJF44NfYL17]WFPAdEU04M5a?0gMH
DPA]ETD4K4i316aFB@A[D4@4Ie950g=LC`A[DTL4RjBa17enORYkNg/4NgMh17]iN@AkO7`8Ng]k5Ooo
o`005?oooe5kNg/4=B`U19]eH`B5Lf@4NfYW0g]ZG`AkJV44NfYT17]cJPAkIUh4NfeO0g]aK0QkJF44
NfYL17]WFPAdEU04M5a?0gMHDPA]ETD4K4i316aFB@A[D4@4Ie950g=LC`A[DTL4RjBa17enORYkNg/4
NgMh17]iN@AkO7`8Ng]k5Oooo`005?ooo`QkNg/4NgEe17]nOSekNg/4HUYO11091PCN]9l4OFaL17]`
K0=kIf04Ng1X17]WH0AkKFD4NfiV17]]HP=kJV@4NfUK17]JFPAdHDl4LUa?17QLD`AgGU43LE]B16YB
@`AcDTL4JUM:16Q>?PAXDTL3KEI916aBA@BA[;U2Ng]k5Oooo`005?ooo`QkNg/4NgEe17]nOSekNg/4
HUYO11091PCN]9l4OFaL17]`K0=kIf04Ng1X17]WH0AkKFD4NfiV17]]HP=kJV@4NfUK17]JFPAdHDl4
LUa?17QLD`AgGU43LE]B16YB@`AcDTL4JUM:16Q>?PAXDTL3KEI916aBA@BA[;U2Ng]k5Oooo`005?oo
o`QkNg/4NgEe17]nOSekNg/4HUYO11091PCN]9l4OFaL17]`K0=kIf04Ng1X17]WH0AkKFD4NfiV17]]
HP=kJV@4NfUK17]JFPAdHDl4LUa?17QLD`AgGU43LE]B16YB@`AcDTL4JUM:16Q>?PAXDTL3KEI916aB
A@BA[;U2Ng]k5Oooo`005?ooo`QkNg/4NgEe17]nOSekNg/4HUYO11091PCN]9l4OFaL17]`K0=kIf04
Ng1X17]WH0AkKFD4NfiV17]]HP=kJV@4NfUK17]JFPAdHDl4LUa?17QLD`AgGU43LE]B16YB@`AcDTL4
JUM:16Q>?PAXDTL3KEI916aBA@BA[;U2Ng]k5Oooo`005?ooo`QkNg/4NgMh17]gM`AkOWheNg]k1860
P0@I40`4NF9D1:R;NPAkJV84NfeV0g]YH@AkKFD4NfUQ17]ZHPAkKFD4Ng5Y0g]VGPAdIED4N5AD17AN
CPA]ETX4MUa@17AKCP=aFdT4J557179AA0A/DdH4Je5316aBAP=WDTD4L5M:18V=TPAnR8/nNg]k5Ooo
o`005?ooo`QkNg/4NgMh17]gM`AkOWheNg]k1860P0@I40`4NF9D1:R;NPAkJV84NfeV0g]YH@AkKFD4
NfUQ17]ZHPAkKFD4Ng5Y0g]VGPAdIED4N5AD17ANCPA]ETX4MUa@17AKCP=aFdT4J557179AA0A/DdH4
Je5316aBAP=WDTD4L5M:18V=TPAnR8/nNg]k5Oooo`005?ooo`QkNg/4NgMh17]gM`AkOWheNg]k1860
P0@I40`4NF9D1:R;NPAkJV84NfeV0g]YH@AkKFD4NfUQ17]ZHPAkKFD4Ng5Y0g]VGPAdIED4N5AD17AN
CPA]ETX4MUa@17AKCP=aFdT4J557179AA0A/DdH4Je5316aBAP=WDTD4L5M:18V=TPAnR8/nNg]k5Ooo
o`005?ooo`QkNg/4NgMh17]gM`AkOWheNg]k1860P0@I40`4NF9D1:R;NPAkJV84NfeV0g]YH@AkKFD4
NfUQ17]ZHPAkKFD4Ng5Y0g]VGPAdIED4N5AD17ANCPA]ETX4MUa@17AKCP=aFdT4J557179AA0A/DdH4
Je5316aBAP=WDTD4L5M:18V=TPAnR8/nNg]k5Oooo`005?ooo`QkNg/4NgEe17]kN`AkO7`eNg]k128G
4@AhJ5h4WH1c17e/G0AkJVL7NfYR17]ZG0AkJVD4NfYR17]`J0AkJV83NfUQ174o>`AgC4P4LD@m1756
?`AcAT04Lf=@0faB@`A/DTH4KT]016QD@PAaDTL4KU950fEB@0AcCT@4Kf1E18fS[BYkNg/4NgEe17]n
OPakNg/Eoooo000Doooo27]kN`AkMGD4Ng]k17]lO3EkNg/48QLA17QXGPBMP7<4OFaL17]ZI`MkJV84
NfYL17]ZI@AkJV84Ng1X17]ZHP=kJF44LClk17M<B0AaA3d4LDHo17=6@0AcHe03K59316aBAPA^Bd04
J5A2175BA`A^DTD3IE9017=>A0A_H5D4SJ>]:W]kN`AkMGD4Ngin37]kNaGoool001Coool8Ng]k17]e
M@AkNg/4Ngal=G]kN`@R5a44N6QN19f0L`AmK5`4NfYW1g]ZHPAkJU`4NfYU17]ZHPAkL6P4NfYR0g]Y
H@Aa?c/4Mda81754?@AaASl4LdI017=SD0=/DT<4K59616i;@0AXE484LE9716iBA@=UDT04Ldi416mP
E@B=XjdZNg]k17]eM@AkOWh<Ng]k5Oooo`005?ooo`QkNg/4NgEe17]kN`AkO7`eNg]k128G4@AhJ5h4
WH1c17e/G0AkJVL7NfYR17]ZG0AkJVD4NfYR17]`J0AkJV83NfUQ174o>`AgC4P4LD@m1756?`AcAT04
Lf=@0faB@`A/DTH4KT]016QD@PAaDTL4KU950fEB@0AcCT@4Kf1E18fS[BYkNg/4NgEe17]nOPakNg/E
oooo000Doooo27]kN`AkMgP4Ngal=W]kN`=RFUX4?cD^1:F8N`AkJF44NfYJ17]ZI`AkJV83NfEG17]W
FPAkIed4NfeX17]]I@AkF5H3Nf5L174g=@Aa?cH4JS4Z17M7@`A/?3<4Mda50f99?PA/Dd@4K59016Q=
@@AcE4P4KU950f]BA0A`BT04Je]=17]/HPB7VJ8VNg]k17]gN0AkO7`<Ng]k5Oooo`005?ooo`QkNg/4
NgMh17]lO3IkNg/3HUYJ13le;PBUR7/4NfUQ17]ZFPAkJVL4NfYR0g]UE`AkIeX4NfMM17]]J0AkKFD4
NeQF0g]QG0Aa=cD4LClf16Xa:PAgAd<4K3`c17M<A@=RBCh4K5=416aB@0AXCD44LeA816iBA@=[DT@4
L4Y016]KC@AkK684QiVR9W]kN`AkMgP4Ngal37]kNaGoool001Coool8Ng]k17]gN0AkO7`fNg]k0f9J
FP@o=Bh4YHQk17]YH@AkJUX4NfYW17]ZHP=kIEL4NfMJ17]WG@AkKFP4NfeU17]HEP=kHE`4LCLe174o
=PAZ<BX4MdM316`l<`AgC4D3HTTn16aCA0A/DT04J4e117=DB0A^DTD3Je94171:@0A[Fdd4NfaR18NI
XRIkNg/4NgMh17]lO0akNg/Eoooo000DooooAW]kN`<G4@h4`YZ2181]H0AkJUl4NfYL17]ZI`AkJU`3
M5e@17QMDPAnLV@4NfaX17]ODPAd?d03LT@j16a=APAM;B44MV5E17UBCPAR9Ql4Kc@/0fa4>PAWCD84
JUY816Y:=PA]EDL4LE970fiBA@A^Cd@4KUE816iHB`B=Vil4Nh65=W]kNaGoool001Cooom6Ng]k0aLA
3PC2VX84P6eP17]ZG`AkJU`4NfYW17]ZG0=dGE04N5eB17ibI0AkK6P4NemB17@o@0=bA3X4K4e615d]
8@AfHED4NE9>168V7`A_=2`3K4@j16M=@PAZFTP4JTXf16eEA`AaDTL3KU9516i?A0A^EDP4KUQ;18fK
W`AkPHDfNg]k5Oooo`005?ooodIkNg/35a4>1<:JPPB0KF04NfYO17]ZG0AkJVL4NfYL0gAMD0AhGE84
OW9T17]/J0AkGe84M3m00g94>PA/CDH4GBdQ17IQE@AiDTh4HRHO16ld;0=/A3X4Ide216YJB0AZBSH4
KEE7175BA`=^DTD4KTm416iEB0A^F4/4SI^O17^1QCIkNg/Eoooo000DooooAW]kN`<G4@h4`YZ2181]
H0AkJUl4NfYL17]ZI`AkJU`3M5e@17QMDPAnLV@4NfaX17]ODPAd?d03LT@j16a=APAM;B44MV5E17UB
CPAR9Ql4Kc@/0fa4>PAWCD84JUY816Y:=PA]EDL4LE970fiBA@A^Cd@4KUE816iHB`B=Vil4Nh65=W]k
NaGoool001Coool@Ng]k17]eM@=kOWh[Ng]k14e1@P<d:R04]iN117e/I@AdGe44OWI^17]WH@AkGe03
JeE416e:@0B9L6d4Kcdi13DB2PBOLFP3LClh17ATF`A]IF04Kc@/169<?PAH=2L4J4M30e4]8@Am=Rd4
I5Y816e>=@A`D4L4L5Y=0gEJB0AZCD@4KUM:16iBA@AiJEd4QhnA17^1QC9kNg/Eoooo000Doooo47]k
N`AkMGD3Ngin:g]kN`A=@D83=2XP1;NGP@AmK6D4M5mA17ifKPAkIf44Nem@0f]EA0A]BT04RG1]16lm
>@@e4PX4Wg5X0g4o>0AdI5/4KFEP16ld;0ARC3h4F3@W16Q7@`=A;B44OCH]16AJB0A]CSD4L517171J
C@=eFTP4JTe416iGBPA^DTD4NFUM18N?T@AkPHDbNg]k5Oooo`005?oooa1kNg/4NgEe0g]nOR]kNg/4
CD520c@Z80BgUh44OFaU17AOD@AnMVh4NfMQ17]OD0=[ED@4KDY018U`K@A_?CT4=A8:19maJ0=a?cP4
M6AK16eUH0A_=2`4HT`n15Pd9`AXAd<3DBdQ17df;@ATFTP4KDhe171@A`A`FTd3MEY816Y=A0A^EdX4
KU9517UYG@B7Si44Nh65<W]kNaGoool001Coool@Ng]k17]eM@=kOWh[Ng]k14e1@P<d:R04]iN117e/
I@AdGe44OWI^17]WH@AkGe03JeE416e:@0B9L6d4Kcdi13DB2PBOLFP3LClh17ATF`A]IF04Kc@/169<
?PAH=2L4J4M30e4]8@Am=Rd4I5Y816e>=@A`D4L4L5Y=0gEJB0AZCD@4KUM:16iBA@AiJEd4QhnA17^1
QC9kNg/Eoooo000Doooo27]kN`AkMGD4Ngin17]gN0=kO7`[Ng]k11@>3@>cRg44RgQ`17]ZGPAaEDT4
P7Uc17]YH@AkFT/3HCl_16I2>@A24a44RH9j15M:APBAPW/3Mf=U17]]J`AmOGH4KCdc16m_K0ATEDh4
E4U70cLM5PA181<4PT@c179RB@AcBd<4MF=D0gEKC0A^EDH4JU1516iAA0A^FD`4NHJN181oNP=nPH4_
Ng]k5Oooo`005?ooo`QkNg/4NgEe17]nOPAkMgP3Ngal:g]kN`@D3Pd3/h]a18]hL0AkJUh4LEE9181i
L`AkJF44NeY;0f4o;`AV@ST4@Q<A18V2NPAGBTH4TH9k0gMSI@AkKF/4OGef16dm<`A_Kf`4I5E>15A9
A`<g7AH4@B0C1894<`AbHTT4Ld]317ESE0=eFd`4KUE616Y@A@A^DD@4KUU<17V6WPB0OgX3OX61;g]k
NaGoool001Coool8Ng]k17]eM@AkOWh4NgMh0g]lO2]kNg/450h=0k>;L@B;N704NfYN175EB@B0NG<4
NfUQ17]JB`=Q?bl4IT8i148C4@B9PWX4EdY61962N`=gHfD4Nfe[17emMPA]?C<4Kfm/16AECPADBDL3
=adF144P4`B2A3<4LV9917=;@`AeHe@3ME]<16iEAPAZD4D4KU5416iIC0AiQYh4P7mj0gj1PBmkNg/E
oooo000Doooo27]kN`AkMGD4Ngin17]gN0=kO7`[Ng]k11@>3@>cRg44RgQ`17]ZGPAaEDT4P7Uc17]Y
H@AkFT/3HCl_16I2>@A24a44RH9j15M:APBAPW/3Mf=U17]]J`AmOGH4KCdc16m_K0ATEDh4E4U70cLM
5PA181<4PT@c179RB@AcBd<4MF=D0gEKC0A^EDH4JU1516iAA0A^FD`4NHJN181oNP=nPH4_Ng]k5Ooo
o`005?ooo`QkNg/4NgMh17]lO2ikNg/4J6A`10H40P?S/i<4P6iT17]ZG0AgHEL4OFm[17]ZHPA_AST3
E3XW15dX7`@Y3@P4[We_18AfIPAhGeT3OXV817]VF@AkKF44Jd]317j0P0A_CD04KFYV0d@_9`A1?CL4
>Q/D18Q6<`AdFD`4O6EA0gUUFPA_EDL4J51616i:?`A^ETT4J7Mi16eTH@=lO8/4QhR1:g]kNaGoool0
01Coool8Ng]k17]gN0AkO7`^Ng]k16QTL0@61083hk>C181^I0AkJU`4Mf5G17e_J`AkJV84KdHi0e@j
9`AM:1l4:@d81:imK`B4MVH4N5mI0gj9R0AkIUT4NfeQ16];@`AnP804Kde016eZIP=4;bL4@Cdg13XK
50B8AS<4M5U<17aUD@=iIEX4KeE716Q@APA^BSl4KUI916QgN@A]I643O7b;18N8PB]kNg/Eoooo000D
oooo27]kN`AkMgP4Ngal;W]kN`AXI7041P@20n>cT`B0KV@4NfYL17MQE`AmKf/4NfYR16m6>@=D>RL4
GBPO12T=20B^OFl4Q7IV17QOF@=nRHP4NfII17]]H@A[Bd<4OX2016m=@0A]JVH3A2lW144m=`@j6a@4
R4Hc17AIC0AlIE43NFEJ16mEA`AXD4H4KTXo16iFB@AXMgT4KFAQ0galR`B7R84[Ng]k5Oooo`005?oo
o`QkNg/4NgMh17]lO2ikNg/4J6A`10H40P?S/i<4P6iT17]ZG0AgHEL4OFm[17]ZHPA_AST3E3XW15dX
7`@Y3@P4[We_18AfIPAhGeT3OXV817]VF@AkKF44Jd]317j0P0A_CD04KFYV0d@_9`A1?CL4>Q/D18Q6
<`AdFD`4O6EA0gUUFPA_EDL4J51616i:?`A^ETT4J7Mi16eTH@=lO8/4QhR1:g]kNaGoool001Cooolj
Ng]k13D/9@@W61H4GD4g0kZMQ0AmK5l4NemD17]UF0AkL6D4NfYO16Lm=0=TEDD4KE=<15I7@PBAHF44
MEmB175CC0=hIEd4O4U316aGB`A/=c04Lclf16Pl<@AjNFL3GcT^15Y6AP@d:R@4?Ph619MVF0AnJU43
O6]P16eB@PAXCD<4J4i3175HB`A[I5P4Nh:<0f5LK@BAUX/[Ng]k5Oooo`005?ooocYkNg/4=B`U12LH
5PAM@CL3^Yf417e/G`AkGe@4NfEH17]`I@AkJUl4Icdd0fAEA@A]Dd`4ETM2195QH@AeGe84LE=<0gQU
G@AlBD<4K5M;16`g<0Ac?cH4J3`a17YiI`=O>Bh4FTI613@Z90@n3PH4UfIH17iZD@=lJf04KE9216Q=
@`AXCT<4LEQ;16]TF0AkPX`3HEa]196FRb]kNg/Eoooo000Doooo>W]kN`@e;2D49aPF15e1=`>jWH@4
OFaO17]OE0AkIEP4Ng1U17]ZG`AW?C@3I5E516eCC0AFAd84TF5Q17EODPAaDd`3N6EM17a9@`A/Ed/4
K3L`17<o=PAX?344NWUW0eli;PAJATH4=2XT13h>1PBGIUP4OVYA0ga[H0A]DT84J4e316Q>@`AaF4/4
JfAH17^2S0=QG6d4TIJ;:g]kNaGoool001CooolDNg]k0g]eM@AkOWhKNg]k16QOI0@51@<47a8?1>F_
V`>7MV@4NfEI17]GEPAdJeT4OW1S17]JF@AWBC/3H4@c18n8P0AmLFP4NeiL17MSF`AeIf03Mf1I17]J
DPA[DTP4Ldi616e:?@A]CDD4K5E70g4h=PAP>344BbXN13@C3PA]:b04S7EM0h1YG@A]ED84J4]316E<
@0AcETT4KUY=134V7`>ZZ;84OGai17j1PBMkNg/Eoooo000Doooo57]kN`=kMGD4Ngin6g]kN`AXGf@4
1@D311lB3`CU[i/3QgIT17]UF@AkEeH4M6]I17i`H`AkFUT4IdTk0f14<`B?R804OG5X17]NG0AgHe/4
MFMP0gMPF@AkFU84Je9817=>APA]BSd4KDe516aEA`=a>3H4H3Pa14/Z7P@d4`h4KB/P18aeG@>0JEd4
KEE216Q;@`AUC404LeI916iJC@@a9Ql3ZZRb17elN@AnPH4WNg]k5Oooo`005?oooaAkNg/3NgEe17]n
OQ]kNg/4J5mT10D50`@O4Pl4iJnK0hMfI0AkIET4NeMF17A[F@AnL6<4NeYI16M9>`=PA3<4ShR017ea
J0AkGU`4Mf=K17EWH0=gH5T4NeYB16]BB0AcCTH4KDXm16e=A@A/EDL3LCPf160h<@A;:Qh4=1<>16d[
80B<MEd3P6UM16eE@PAXBd<4IDa017=FB@A^FTd4<BHO0jZX/PAmO7T4OX619g]kNaGoool001CooolD
Ng]k0g]eM@AkOWhKNg]k16QOI0@51@<47a8?1>F_V`>7MV@4NfEI17]GEPAdJeT4OW1S17]JF@AWBC/3
H4@c18n8P0AmLFP4NeiL17MSF`AeIf03Mf1I17]JDPA[DTP4Ldi616e:?@A]CDD4K5E70g4h=PAP>344
BbXN13@C3PA]:b04S7EM0h1YG@A]ED84J4]316E<@0AcETT4KUY=134V7`>ZZ;84OGai17j1PBMkNg/E
oooo000Doooo57]kN`=kMgP4Ngal6g]kN`AMEV@4;R`L1591?0BVS7X3OVeO17]REPAkIUl4Me]H17ee
H@AkHE/4Ida00f50=@B;Og44OW=]17]^IPAkIf04NfeU0g]^IPAkEe84LEY:17MNDPA]ETP4Le97169<
?0=_ACl4IT/k160o=`AG?CD4GCXj17aP@@>0IU`4LEQ516Q;@`AUCcl4Le=816iIC0@F6Q/3]:FO18N:
S@AmOWhWNg]k5Oooo`005?oooaAkNg/3NgMh17]lO1]kNg/4GEIT12h/70AB@C`4YXaj0gi]G`AkHUH4
NfIO17MKF0AmMF44Nf5K16M<@0=Q@3D4Rgma17icK@AkKVH4NfMP17]]I@=kKVH4NeMB175JBPAgGU84
KEI817=BA`ARC3`3KdDo16I;>`AP?cL4Ecde15dj>PAlH443P6IL175HA@AXBd<4IDlo17=CB0A^FD`4
5QXK0kBUW`B7RXd4OGin9g]kNaGoool001CooolDNg]k0g]gN0AkO7`KNg]k15eFI0@^;1`4DT4l1:J<
NP=nKEl4Nf9F17]VG`AgFeP4OGEQ17]QF`AWC403HD0e18]oL@AnLfd4NfiV17]WH0AkKFD3NfiV17]G
DPAaFTX4MeiB16eFB0AcDTL4HT`l0fm5?`AVBc/4H3lg15Lm=@AM>SX4O6110h1VG0AaF4D4J4]316E?
?`AcDdP4KUU<11HJ6`>dYIl4QhZ=17enORMkNg/Eoooo000Doooo57]kN`=kMgP4Ngal6g]kN`AMEV@4
;R`L1591?0BVS7X3OVeO17]REPAkIUl4Me]H17eeH@AkHE/4Ida00f50=@B;Og44OW=]17]^IPAkIf04
NfeU0g]^IPAkEe84LEY:17MNDPA]ETP4Le97169<?0=_ACl4IT/k160o=`AG?CD4GCXj17aP@@>0IU`4
LEQ516Q;@`AUCcl4Le=816iIC0@F6Q/3]:FO18N:S@AmOWhWNg]k5Oooo`005?ooocIkNg/4KUQ@185Z
G@AgIeh4LfAE0gYYG0AnJUh4NfaU17]QGPAkM6P4NfMN16eEB0=[BCl4LEA7189kKPAnMW04Nf]T17]W
H0=kLfX4NeeD175FB@AaCT84LEe;16I=?`AKBd03JdLg16M7>PAWBcX4IdDj16A8>PAeGD/3Nf1E17=E
APARB3h4J4i016eD@`A/E4T43A0@0lVjb@B;ShX[Ng]k5Oooo`005?ooocIkNg/4KUQ@185ZG@AgIeh4
LfAE0gYYG0AnJUh4NfaU17]QGPAkM6P4NfMN16eEB0=[BCl4LEA7189kKPAnMW04Nf]T17]WH0=kLfX4
NeeD175FB@AaCT84LEe;16I=?`AKBd03JdLg16M7>PAWBcX4IdDj16A8>PAeGD/3Nf1E17=EAPARB3h4
J4i016eD@`A/E4T43A0@0lVjb@B;ShX[Ng]k5Oooo`005?ooocIkNg/4KUQ@185ZG@AgIeh4LfAE0gYY
G0AnJUh4NfaU17]QGPAkM6P4NfMN16eEB0=[BCl4LEA7189kKPAnMW04Nf]T17]WH0=kLfX4NeeD175F
B@AaCT84LEe;16I=?`AKBd03JdLg16M7>PAWBcX4IdDj16A8>PAeGD/3Nf1E17=EAPARB3h4J4i016eD
@`A/E4T43A0@0lVjb@B;ShX[Ng]k5Oooo`005?ooocIkNg/4KUQ@185ZG@AgIeh4LfAE0gYYG0AnJUh4
NfaU17]QGPAkM6P4NfMN16eEB0=[BCl4LEA7189kKPAnMW04Nf]T17]WH0=kLfX4NeeD175FB@AaCT84
LEe;16I=?`AKBd03JdLg16M7>PAWBcX4IdDj16A8>PAeGD/3Nf1E17=EAPARB3h4J4i016eD@`A/E4T4
3A0@0lVjb@B;ShX[Ng]k5Oooo`005?oooc9kNg/4M6m`17iNB0AdGeH4LUa;16IVJ`>9JED4OFiX17]`
J@AkKFD4Ng1X17][I0AgDTh3KeM816]8?@AoL644P7Mb17]aJ@AkEU@3M71N17i/GPA[CD<4LDm316I4
=PAVETP4GT0f0fQ:=`AVAch4K4lg16=5>@AVAC@4P6=G0gEHB`A/Cd<4HdTn16Y=@@AZEDH4L5M;1046
20?:[ZT4TiRF:g]kNaGoool001CooolbNg]k17A_L0AnGTP4M5mF179LB`AVIV/3RFUE17e^J0AkL6T4
NfeU17]`J0AkJf@4Me9>0fmGB0A[B3d4Og1Q181gLPAkLFT4NeID0gA`GPAnK5h4Jde3175?@`AVA3H4
IUI815i0=P=XBSL4ITLn16a?=`ASACT4ITDd181SE`=eF4/4K4m316=9?PAZCD44JUE6171GB`@11PP3
bZjY19>HUR]kNg/Eoooo000Doooo<W]kN`AdKg04OUi817AOEPAbG4/4IVI[0hUYE@AmKVP4Ng1Y17]]
I@AkL6P4Nf]T17MBCP=_EdP4JdPm17m`H@B0Mg84Ng5Y17]FE0=dL5h4OVaN16]=@`AaCd<4IT@f16IF
B0AN@3H3J4Xg16I7?PA/CcL4HdDi16I5=0B0HeL3MEQ;16a?@`ASBCh4JTe116YEAPA`Ed/40@H80lZ^
Z@BCV9H[Ng]k5Oooo`005?oooc9kNg/4M6m`17iNB0AdGeH4LUa;16IVJ`>9JED4OFiX17]`J@AkKFD4
Ng1X17][I0AgDTh3KeM816]8?@AoL644P7Mb17]aJ@AkEU@3M71N17i/GPA[CD<4LDm316I4=PAVETP4
GT0f0fQ:=`AVAch4K4lg16=5>@AVAC@4P6=G0gEHB`A/Cd<4HdTn16Y=@@AZEDH4L5M;104620?:[ZT4
TiRF:g]kNaGoool001CooolbNg]k17MND0AmIed4Je1316YBA0AeLfd3QeaG17]eJPAkLfX<NfiV17]M
E0=gG4h4JDlo17IDB@B4P7X4Ng=Z17]MF@=gK604OFaR16e?B0A_EDL4I4Dk16aEB0AN?383ITLi16I;
?`A_D444K4]0175EB0AiH5@3K4i316aAA0A[Cd@4Id]016YE@`A]E4T400H70e4i<PC=aLL4Ngin9g]k
NaGoool001CooolbNg]k17MND0AmIed4Je1316YBA0AeLfd3QeaG17]eJPAkLfX<NfiV17]ME0=gG4h4
JDlo17IDB@B4P7X4Ng=Z17]MF@=gK604OFaR16e?B0A_EDL4I4Dk16aEB0AN?383ITLi16I;?`A_D444
K4]0175EB0AiH5@3K4i316aAA0A[Cd@4Id]016YE@`A]E4T400H70e4i<PC=aLL4Ngin9g]kNaGoool0
01CooolbNg]k17MND0AmIed4Je1316YBA0AeLfd3QeaG17]eJPAkLfX<NfiV17]ME0=gG4h4JDlo17ID
B@B4P7X4Ng=Z17]MF@=gK604OFaR16e?B0A_EDL4I4Dk16aEB0AN?383ITLi16I;?`A_D444K4]0175E
B0AiH5@3K4i316aAA0A[Cd@4Id]016YE@`A]E4T400H70e4i<PC=aLL4Ngin9g]kNaGoool001Cooolb
Ng]k17MND0AmIed4Je1316YBA0AeLfd3QeaG17]eJPAkLfX<NfiV17]ME0=gG4h4JDlo17IDB@B4P7X4
Ng=Z17]MF@=gK604OFaR16e?B0A_EDL4I4Dk16aEB0AN?383ITLi16I;?`A_D444K4]0175EB0AiH5@3
K4i316aAA0A[Cd@4Id]016YE@`A]E4T400H70e4i<PC=aLL4Ngin9g]kNaGoool001CooolbNg]k17]H
@`AdIE/4FSLY181fJ@B1H5l3OFaO17]_J0AkLfX4NgAa17][H@AkKVH4NfIL0g]UEPAWCD44LeE6181i
KPAnL6X4NfUK0g]`J`AkIf04LEM;16M:?PA/Cd<4J59516E6>`=XBcH4Hd<j16mBAPAjF504Nf=D16mI
C0=XEDT4KU9716Q@A0AXCd@4JU=4171LD0@R8QX3<AhJ14Hi=0C2`l<WNg]k5Oooo`005?oooc9kNg/4
NeQ317AUF`AJ=bT4P7IY185PG`=mK5l4NfmX17]cJPAkM744Nf]Q17]^IPAkIU`3NfEF16M=@@AcEDH4
P7U^17i`JPAkJE/3Ng1[17]WH0AaEd/4IdXn16a?@`AXDTD4IDHk0fQ;=PAS@cX4Ke9617YHD0AkHe@4
KeU<0fQEB@A^DTL4J51416Q?A0AZDd@4L5a@128R6P<a7QX4ASTd1<;3`bMkNg/Eoooo000Doooo<W]k
N`AkF4<4M6EK15Xg:@B0MVT4PF1O0ge/G`AkKfP4Ng=Z17]dL@AkJf44NfiV17]VG0=kIEH4Ide117=E
APB0NFh4OW1Z17]YF`=kL6/4NfMP175GB`AWBSh4K4m316QBA@AUAS/3J4/f16=3>PA_DTH4NUQ@17]S
E0A_FD`3J5E916iBA`AXD4@4J4m416YCA0A`G5048R8J0c4N6PA6>C@4`/?39g]kNaGoool001Coool^
Ng]k17]TFPA_ASL4ISL`165=?PAfO7<4SFQO0g]_G`AkJVL4Ng=Z17]aK0AkK6@4NfiV17]VGP=dIED4
LEM=17EUEPAoL6@4OFaR17AJDP=nMVP4NeQI16]G@@AV@c/4J4i21699?@A]CSP3F3lc16]5>PAeGe44
NeiB17aSE@A]ETX3J5E816i?@`A[DD@4Ie90171<@PA`I5D4GSlc0d/j=@AQOXP4XInP9g]kNaGoool0
01Coool^Ng]k17]TFPA_ASL4ISL`165=?PAfO7<4SFQO0g]_G`AkJVL4Ng=Z17]aK0AkK6@4NfiV17]V
GP=dIED4LEM=17EUEPAoL6@4OFaR17AJDP=nMVP4NeQI16]G@@AV@c/4J4i21699?@A]CSP3F3lc16]5
>PAeGe44NeiB17aSE@A]ETX3J5E816i?@`A[DD@4Ie90171<@PA`I5D4GSlc0d/j=@AQOXP4XInP9g]k
NaGoool001Coool^Ng]k17]TFPA_ASL4ISL`165=?PAfO7<4SFQO0g]_G`AkJVL4Ng=Z17]aK0AkK6@4
NfiV17]VGP=dIED4LEM=17EUEPAoL6@4OFaR17AJDP=nMVP4NeQI16]G@@AV@c/4J4i21699?@A]CSP3
F3lc16]5>PAeGe44NeiB17aSE@A]ETX3J5E816i?@`A[DD@4Ie90171<@PA`I5D4GSlc0d/j=@AQOXP4
XInP9g]kNaGoool001Coool^Ng]k17]TFPA_ASL4ISL`165=?PAfO7<4SFQO0g]_G`AkJVL4Ng=Z17]a
K0AkK6@4NfiV17]VGP=dIED4LEM=17EUEPAoL6@4OFaR17AJDP=nMVP4NeQI16]G@@AV@c/4J4i21699
?@A]CSP3F3lc16]5>PAeGe44NeiB17aSE@A]ETX3J5E816i?@`A[DD@4Ie90171<@PA`I5D4GSlc0d/j
=@AQOXP4XInP9g]kNaGoool001Coool^Ng]k17]:@PAW>c84Gc8/16YRD0AmNVd4Qg1X0g]`IPAkIf44
Ng=Z27]^IPAkJF44NfUK0g5RE@AmGU84LfYM181^J0AkL6H4MeiI0ge_I0AkEdl4Ie=41693>`ARB3`4
Gd<g16I8>0=QAS`4MUY<17UPD`AeH5@4O5mC16eFBP=XDTH4KTi316i<A@A[CT@4JTa0175UG@AO>b/3
KE5719Zka`AgMgPWNg]k5Oooo`005?ooobikNg/4NdY216Lk<PAO<R`4JV9@17ejK@B7L6P3Ng1V17]W
H@AkLfX8NfiV17]YH@AkJE/3LF9E17eNDPAcJUd4P6iX17]`IPAgGUT3OFmT17]GC`AWDd@4HT<k1698
?0AO@cL4ITPh0f56?0AfFT`4NF1C17EPE0AlGe<4KEI:0fQBAPA^CT<4KTa516]>A0AZC404LFEM15lk
:`=]DDL4V[_717MgN2MkNg/Eoooo000Doooo;W]kN`AkBT84Ic/b15lb;0AZHU04OGY]18M`J0=kL6H4
NfMQ17]cJPQkKVH4NfUQ17]YF`=aHUD4OEiB17=ZG@B0KVP4Ng1V17MNF@=mKf@4NeM?16MCA0AR@c/4
HTPl15m3=`AVB3P3HDHl17IJC0AiH5<4MF1D17aOD`A]ETX3J59616i>@`A^C4D4Jdi416Y<@0AaIEd4
Gc/[0feAA`BJ^lL4MgMh9g]kNaGoool001Coool^Ng]k17]:@PAW>c84Gc8/16YRD0AmNVd4Qg1X0g]`
IPAkIf44Ng=Z27]^IPAkJF44NfUK0g5RE@AmGU84LfYM181^J0AkL6H4MeiI0ge_I0AkEdl4Ie=41693
>`ARB3`4Gd<g16I8>0=QAS`4MUY<17UPD`AeH5@4O5mC16eFBP=XDTH4KTi316i<A@A[CT@4JTa0175U
G@AO>b/3KE5719Zka`AgMgPWNg]k5Oooo`005?ooob]kNg/3NfUO17]DB@AW?SH4FS/]17=TEPB;Ofl4
OFaX0g]cJPAkJf@4NfYR17]/H`AdIUP4OVaP17]JE`=aIE@4NU]@17AXFPB0LFd4NfeO17]YI0=kJV84
NeE@16M;?0AOB3d4HDHj16=7>`AOCD83LE=117ELD0AiGE04NF9E17=HC0AaDdL3J5E816i9?PA^C484
J4e216QC@0AcHUl4Iclb0fQEB@AkQi44R8f<9g]kNaGoool001Coool[Ng]k0g]YG`AkE4T4Ichf15Xk
;@AcI5H4Rgm_17e/J0=kLfX4Nf]T17]ZHPAkK6<4M6IH17i/H0AkFUL3LFED17YKD0AdJ5X4P75]17]]
G`AkJF@3NfYR17]ED0AWBc`4GdPm1656>PASAc/4Gde20g5C@@AeG504NEe@17URE@AcF4`4LE=70fQE
B0A^BCh4KTa216Q=@PAXDd04Lf9O16Lo<P=XEDT4NhNA18R=S2MkNg/Eoooo000Doooo:g]kN`=kJEl4
NeA916Ln=PAJ>bd4LfAF18]oK`AmK6P3Ng=Z17][I0AkJV84NfaS17AVF0AnK604NeYG0g5UE0AjFe04
M6QJ181aK@AkKEl4NfUT0g]ZHPAkEE04Id/l15m8?@AQASX4HdLk15m=@P=aDd44MEa@17UMD0AiHUD4
LeQ<175CA`=XEDP4KTTn16i<@PAXCD84J5=017=RG`AW?c83J5E917^7T@B8SH`WNg]k5Oooo`005?oo
ob]kNg/3NfUO17]DB@AW?SH4FS/]17=TEPB;Ofl4OFaX0g]cJPAkJf@4NfYR17]/H`AdIUP4OVaP17]J
E`=aIE@4NU]@17AXFPB0LFd4NfeO17]YI0=kJV84NeE@16M;?0AOB3d4HDHj16=7>`AOCD83LE=117EL
D0AiGE04NF9E17=HC0AaDdL3J5E816i9?PA^C484J4e216QC@0AcHUl4Iclb0fQEB@AkQi44R8f<9g]k
NaGoool001Coool[Ng]k0fm8=0AS@CH4AC0U164o<@B;MFL4RG][17]ZI`=kKFD4NfaS17]YF`AkIEX4
LFEG17YME`AbFU43N65G17MXF@AgIUX4P71U17]ZHPAkJV@3NfYR17ALDPA[B3`4GdPm1656>PAVBCd4
J5140fiEAPAjFE84MEe>17ILD0AaGU84LeE90fQCA`A^DDH4J4i316Q;@0AZD4H4LfAM168^7P=aKEl4
IdHn19>a^BMkNg/Eoooo000Doooo:g]kN`=_B3@4Hd4f14D`9@AQ?c44RgEW18UkJ`AkJVL3NfeU17]/
H`AkJE/4NfEJ175UE`AjGEL4LUYA0gQQE`AgJ5T4MfIJ181`I@AkJV84NfYT0g]ZHPAdG584JdPl15m8
?@AQASX4ITTm16Q@A0=^EDH4NUUB17EMCPAfG504LEiB17=EB@=XDdL4KU5616Q>@`AXBd04JU1617=T
G@AR;Qh3LFeO16M6?PBC/KTWNg]k5Oooo`005?ooob]kNg/3KdPd16=1=PA5<2D4HCla18]eI`B9Nf/4
NfYW0g]]I@AkK6<4NfUK17]UFPAaIEL4NUeG179JD@=hHEL4MfQI17MVFPB0L6D4NfYR17]ZI0=kJV84
M5aB16]8?0AOB3d4HDHj16I9?@AXD4@3KUE617YIDPAeGDh4MUa@175NDPAcEDT3J5=716iAAPAXCT<4
J4]016Y@APAcI5d4HRhN0g5]G`AWASh4Tk6i9g]kNaGoool001Coool[Ng]k0fm8=0AS@CH4AC0U164o
<@B;MFL4RG][17]ZI`=kKFD4NfaS17]YF`AkIEX4LFEG17YME`AbFU43N65G17MXF@AgIUX4P71U17]Z
HPAkJV@3NfYR17ALDPA[B3`4GdPm1656>PAVBCd4J5140fiEAPAjFE84MEe>17ILD0AaGU84LeE90fQC
A`A^DDH4J4i316Q;@0AZD4H4LfAM168^7P=aKEl4IdHn19>a^BMkNg/Eoooo000Doooo:g]kN`=Q;1X4
9aT@14H_9`@l9R84/hae18IhK`AkJV@3NfYL17]ZG`AkJV84NfMN17MYH0AiHed4KeI=0g=CC0A]GD`4
OVaN17Y/GPAnKFT4NfYR0g]ZG0AaEe04IdPk15do?PATBSH4H4@j179BAP=`Fdd4M597171JC0AgEdl4
K5A5171HB`=VCd<4K5=616QAA0AZBSl4JTe816eJB`AJ=B83L5Q616`n>@BC_LHWNg]k5Oooo`005?oo
ob]kNg/3HB`J12LI40A6;bL4?2HR1;><M@B6N6l4NfYT0g]ZG0AkJUl4NfYR17]WGPAgJF04NF=M16mF
C@=cDd`4KEe<17i/GPAjK5h4OVeY17]ZHP=kJU`4LEM@16M8>`AM?ch4I4Xf1614>PAbDTH3L5]=17AB
A`A`FT`4MeM?16aDA@A`F4/3ITm316aCAPAXDD@4JTXo16Y=B0A]FT/4FSDR0g1HAPA/?ST4Tkg69g]k
NaGoool001Coool[Ng]k0f4/6P@W6A04ARlW13`V8PBcS7D4QWQ_17]ZI0=kJU`4NfYO17]ZHPAkIeh4
MfUP17USG@A_ETd3Le=<16eMC0AnK5h4NVaN17i]J@AkJV83NfYL175GD0AWB3/4GCln16A:=PAPA3X4
LU960g1KC@AdDTL4L5Y<17MGC`A/E4D4L5Q;0fI?@`A/DdH4J55416Y:?`AZCDP4KEY;15Xe8P=`F4H4
K3hi19>maRMkNg/Eoooo000Doooo9g]kN`AkKfX3Hc<W12TQ6P@_8Q/4=B<Q1<>DN@B6N6/4M6EJ0gi]
I@AkJU/4J5E;17=NDPAQBCd4Je5416Q;A@=/AD84LeY717EJC0AhJE/4Q7E_17]ZHP=kJUl4LE9=16=8
>PAL@CD4ITDc15e9?`A^C3l3IEA716I=@@AbETT4MEeB16I<@0AaFD`3Je=716M@A0AZDTD4JTXo16Y=
B0AZEDD4A2LL0eT[7PAjC3X4Ul3>9g]kNaGoool001CooolWNg]k17]_JP=S<bL4:B4J12lR6`@e8b44
`iAi18IhJ`AdIEX3OVeU17]ZF`AXED/4LeiB1659?@A[DD@4J4]50fa5@PAcFTL4MEY<17QYF`B4MFl4
NfYR0g]ZG`AaDTd4HdPj15a1=@AVAC<4GDTo16i<?`=UE4L4ITe1179FB@AeGE84ITa0175IC0=[DdL4
Ie1416YBA@AZBSl4JTe816YEA@A49a`3FB/N17Y<>PBG`<hWNg]k5Oooo`005?ooobMkNg/4NfmZ0f<c
9`@Y8AX4;b8K13DS8@C3U7T4QWQ[17AUFP=nKFD4NfYK16QEB`AcGU84HDTm16]AA0AXBdD3K4E217=J
A`AeFT`4N6UK18AeK`AkJV83NfYO175BC@ASB3X4G44e16I5<`AMBCl4KT`o0fEDA`AVCD44LUI917EM
DPAVC404LEU<0f]CA`AWD4@4JU9516Y:?`AZCDP4JUE514@W70=I:ah4NT`j19O0cRMkNg/Eoooo000D
oooo9g]kN`AkKfX3Hc<W12TQ6P@_8Q/4=B<Q1<>DN@B6N6/4M6EJ0gi]I@AkJU/4J5E;17=NDPAQBCd4
Je5416Q;A@=/AD84LeY717EJC0AhJE/4Q7E_17]ZHP=kJUl4LE9=16=8>PAL@CD4ITDc15e9?`A^C3l3
IEA716I=@@AbETT4MEeB16I<@0AaFD`3Je=716M@A0AZDTD4JTXo16Y=B0AZEDD4A2LL0eT[7PAjC3X4
Ul3>9g]kNaGoool001CooolWNg]k17AEA0=[AT443PH411hE4@@]7QX4fj>517a_H@AkIET3OFiT17]Z
G0AYEDX4ETHk14`j;`@i;b`4=2HR0e<]7PAdC3/4FRdQ160e9`BKS7/4OW1Z0g]ZHPAaEd/4HdDj15a3
<PAPC3L4FSlf17EIB`=[Ed/4JE=8171AA0AZD4T4GD`o17YLCP=^ETT4IDi315m<@0AUC404LE=816YC
A@@m91`3E2PM17a4=0BIbMLWNg]k5Oooo`005?ooobMkNg/4M5E40f]6@@@>1P@47QDA12dN6PCKXhD4
O6mQ17]UF@=mKV@4NfYL16UEBPAFAS/4C3X_13T_;0@d9R83DbdN17A<>`AJ;B44H3DW19^<N`AnL6X3
NfYR175GB`ASACX4G4<b161<=`AJ?cH4MEU;0f]GB`AYDdP4L55416Y@B@AMC3l4NUa>0fiFB@AUCT<4
Gda016E<@0AaDdP4JU=513dT70=D:1d4O4@d19W9ebMkNg/Eoooo000Doooo9g]kN`AdED@3JdI110h6
10@N5A44;AhJ1=^SQ@AlKf44NfEI0ge^I0AkJU`4JEE:15I6>`A<>Rl4>Bl/13@V8P=C;Ah4M4`k15X]
8@AP=BL4Vhak17i`JP=kJV84LEM;16=5>PAL@c84H4`g15Xo=PAeFD/3JeM;16UCB0A`DD@4JU1915e<
?`AjG4h3KUI916E>@`AOC404IDa0175CB0AZDdD4?B@L0e@X7@AlA3@4VLWG9g]kNaGoool001CooolW
Ng]k17AEA0=[AT443PH411hE4@@]7QX4fj>517a_H@AkIET3OFiT17]ZG0AYEDX4ETHk14`j;`@i;b`4
=2HR0e<]7PAdC3/4FRdQ160e9`BKS7/4OW1Z0g]ZHPAaEd/4HdDj15a3<PAPC3L4FSlf17EIB`=[Ed/4
JE=8171AA0AZD4T4GD`o17YLCP=^ETT4IDi315m<@0AUC404LE=816YCA@@m91`3E2PM17a4=0BIbMLW
Ng]k5Oooo`005?ooob=kNg/4PH2017=7=@=S@CT41`h?11TB3`@a6QD4i;>D17e]H0AgHeP3OViQ17]Z
GPAgIEl4ED4g16YFD0@M7a`47a@A0cXN50A??CL4JcHX17IFB@B?QWD4P7Ia0g]cL0AaFTT4Hd8h154j
;PAMAC44<a0:18MSC`=XBS<4FT@j14he:0AcDdH4Gdm217QHA@=/DdP4J55415Q5>PARCd<4M51815m9
>`@g81`3GSDW185=A0BLbm@4MgMh8g]kNaGoool001CooolSNg]k1860P0AcAcD3Hd4i10L>3`@I4Pl4
<AXE1>BcU0AmKF04Mf=H0gi^H@AkJUh4MfEO15E1=`AZEU047AlL11lD4@<j7Q@4Ccdg16/f:0AfETT4
ShIe181fL@=kLg04LEY916=2>0AA>Rh4GDDa13<@2PB7Hdl3J4Xc15Y4>PA>=BP4Le=615m?@PAhF4D3
K5=816QAA0AHACX4HTm317A@B0AOBC/4=b0L0ehe9`B1CD@4W<_D17MgN2=kNg/Eoooo000Doooo8g]k
N`B1P804LdLe0f=1>@@73Pl46A8?134J5@CT/i@4OFeP17MSF0=nKV44NfYN17MUG`AE@CL4JUI@11dO
70@O5143>QhD14lm=`A[=RP4MUI918n6M@B0MW43Ng=`175JB@AS@SP4DCX^15e5<@@c40X4Qf=?0fQ:
<`AJA3X4CSDX17=CAPAOCd84N5Q50faCB0AXDD@4F4Dj169?@`AdD4P4GdTk13LP70=N=BL4PDe419c;
e0AgMgPSNg]k5Oooo`005?ooob=kNg/4PH2017=7=@=S@CT41`h?11TB3`@a6QD4i;>D17e]H0AgHeP3
OViQ17]ZGPAgIEl4ED4g16YFD0@M7a`47a@A0cXN50A??CL4JcHX17IFB@B?QWD4P7Ia0g]cL0AaFTT4
Hd8h154j;PAMAC44<a0:18MSC`=XBS<4FT@j14he:0AcDdH4Gdm217QHA@=/DdP4J55415Q5>PARCd<4
M51815m9>`@g81`3GSDW185=A0BLbm@4MgMh8g]kNaGoool001Coool4NgQh17]nOPAkMGD4Ngin4g]k
N`@K2PL4]g9I0f]DB@@I5aH44a<H12<D3`C]^YT4NVUL17]ZGP=gIUX4N6MK17i]J@AYEdT4MEI<13/h
<@A5>cH3B3<V15M3=0AkEd@4PUiB17mcI0B0NWD3Ng5/175GB0AS@cT4EC//15M0=0@l8Q`4HE==0cX_
9`@=1`L4FS4U14i1=@@c8AP4JDPk0e/m:PAhCS`4Fdi4169>@PAdCD<4B3d`12TK5P=>;2<4WFYI19Zn
b@AeMWHSNg]k5Oooo`005?ooo`AkN7P4Ngin17]eM@AkOWhCNg]k11/:1`BgLUT3JeA911TG5P@C4aP4
8a@?1>fjV@AjJE`4NfYN0gMVFPAhIe/4OVeY16UGB@AeET`4>cPa14Dk=P=8<bH4Ed<d17]GA0B2GU84
Og=T181jM@=kLF`4LEM816=3>@AE>b`4Ed0d13`R70AQDdd3>RlW10d71`AJ<BD4CT4e13<Q60AYB3/3
FcdZ17Q>?0AKCT@4HTi217A=@`A8?C04:A/F0dh/8`BMJUT4V[k917EfMR=kNg/Eoooo000Doooo17]h
N0AkOWh4NgEe17]nOQ=kNg/46`X71;MbF@=[E4T46ALF11<C60@S50l4kKZI17YYG0AkJUh3MfIJ17QW
F`AnKFT4JEM917EFC0@k>344AC/f0dPc9PAG@c@4NeM4189NDPAoLf@4P7Ye0g]aK0AaEdP4Hd<i15Dk
;0AG@3@4?28L165CC@<j;bL43@L715Xa9@A>@CD4<b4H16U8>`=K?BX4N4hl15]>A0ARCT84M4e314Pm
<0@Y6aH3CR`S19eZF@BJ_/T4MGIf8g]kNaGoool001Coool4NgQh17]nOPAkMGD4Ngin4g]kN`@K2PL4
]g9I0f]DB@@I5aH44a<H12<D3`C]^YT4NVUL17]ZGP=gIUX4N6MK17i]J@AYEdT4MEI<13/h<@A5>cH3
B3<V15M3=0AkEd@4PUiB17mcI0B0NWD3Ng5/175GB0AS@cT4EC//15M0=0@l8Q`4HE==0cX_9`@=1`L4
FS4U14i1=@@c8AP4JDPk0e/m:PAhCS`4Fdi4169>@PAdCD<4B3d`12TK5P=>;2<4WFYI19Znb@AeMWHS
Ng]k5Oooo`005?ooo`AkMgL4Nh2017]gN0AkO7`?Ng]k11d@3@@H3P`4>@X50e/i;0@E41@45Q<?12/H
4`C/^IP4MfIJ181^J0=U@c`4LEm?18UjM@AgKF84MEeE16U@B0AUBch3HTe116M;?`AiHDd4OEmF17UY
G0B0O7L3NfiV175AB0ASD4<4G3d^15Y;>0AP>bl4HUQ@0dHg;`@41`T4Ab<G13h_:`@U71P4JT4`0fM5
=PAlFdL4H4Pn15m?@`AdDd448a/J12PM5@=08QT4XDlk19W5d@AhNGTSNg]k5Oooo`005?ooo`AkMgL4
Nh2017]gN0AkO7`?Ng]k11d@3@@H3P`4>@X50e/i;0@E41@45Q<?12/H4`C/^IP4MfIJ181^J0=U@c`4
LEm?18UjM@AgKF84MEeE16U@B0AUBch3HTe116M;?`AiHDd4OEmF17UYG0B0O7L3NfiV175AB0ASD4<4
G3d^15Y;>0AP>bl4HUQ@0dHg;`@41`T4Ab<G13h_:`@U71P4JT4`0fM5=PAlFdL4H4Pn15m?@`AdDd44
8a/J12PM5@=08QT4XDlk19W5d@AhNGTSNg]k5Oooo`005?ooo`AkMgL4Nh2017]gN0AkO7`?Ng]k11d@
3@@H3P`4>@X50e/i;0@E41@45Q<?12/H4`C/^IP4MfIJ181^J0=U@c`4LEm?18UjM@AgKF84MEeE16U@
B0AUBch3HTe116M;?`AiHDd4OEmF17UYG0B0O7L3NfiV175AB0ASD4<4G3d^15Y;>0AP>bl4HUQ@0dHg
;`@41`T4Ab<G13h_:`@U71P4JT4`0fM5=PAlFdL4H4Pn15m?@`AdDd448a/J12PM5@=08QT4XDlk19W5
d@AhNGTSNg]k5Oooo`005?ooo`AkMgL4Nh2017]gN0AkO7`?Ng]k11d@3@@H3P`4>@X50e/i;0@E41@4
5Q<?12/H4`C/^IP4MfIJ181^J0=U@c`4LEm?18UjM@AgKF84MEeE16U@B0AUBch3HTe116M;?`AiHDd4
OEmF17UYG0B0O7L3NfiV175AB0ASD4<4G3d^15Y;>0AP>bl4HUQ@0dHg;`@41`T4Ab<G13h_:`@U71P4
JT4`0fM5=PAlFdL4H4Pn15m?@`AdDd448a/J12PM5@=08QT4XDlk19W5d@AhNGTSNg]k5Oooo`005?oo
o`AkNGT4Ngal5g]kN`@10004<24H12PD4@<_8A`43PX;12`J50@_61@4i:n?17eYG0AgJEl3LUQE16=A
@`APA3P4KUM915i;?PA?>384B2`S0eDi:@AO>Rd4Hcd]18QbH`AnKf44P7=^0g]/GPAaDDP4HeI915`m
<@ASAS<4HTdi179HB@=SBd84:C4`15Dn<`A7<RT4A3<Y17QB@P=`D3T4I5=816e@?`AUDTL4HTe011@B
3`@U5a<3@R8I18hf9PBQen8WNg]k5Oooo`005?ooo`AkNGT4Ngal5g]kN`@10004<24H12PD4@<_8A`4
3PX;12`J50@_61@4i:n?17eYG0AgJEl3LUQE16=A@`APA3P4KUM915i;?PA?>384B2`S0eDi:@AO>Rd4
Hcd]18QbH`AnKf44P7=^0g]/GPAaDDP4HeI915`m<@ASAS<4HTdi179HB@=SBd84:C4`15Dn<`A7<RT4
A3<Y17QB@P=`D3T4I5=816e@?`AUDTL4HTe011@B3`@U5a<3@R8I18hf9PBQen8WNg]k5Oooo`005?oo
o`AkNGT4Ngal5g]kN`@10004<24H12PD4@<_8A`43PX;12`J50@_61@4i:n?17eYG0AgJEl3LUQE16=A
@`APA3P4KUM915i;?PA?>384B2`S0eDi:@AO>Rd4Hcd]18QbH`AnKf44P7=^0g]/GPAaDDP4HeI915`m
<@ASAS<4HTdi179HB@=SBd84:C4`15Dn<`A7<RT4A3<Y17QB@P=`D3T4I5=816e@?`AUDTL4HTe011@B
3`@U5a<3@R8I18hf9PBQen8WNg]k5Oooo`005?oooamkNg/40P0011h@2`@K51038ADA11/B3`@N5A44
>2LS1<ZCM`B9L684MfaO0ge/J0A^GUD4H4m315m2?0A6@Cd4JTU114hi;P=KAcX4FC`a17ACA`B7OFd4
PG1Y17e/I@=kFUD4LEm?16=CB0AL>CP4ABPK154b8`AhHDD3LEA716YB@PAYCD<4FDLh15M6?@AgEd@3
H4`o16Y=B0ARD404LEA314Pl<P@:2`X46a@@0i5F@`AM9a`4[McW9g]kNaGoool001CooolONg]k1080
00@N40/46a@@0b4E4@@K4Pl47QDA13PW8`C:TgL4RG1R17M/G`=mK6P4KUiE161?@`AO@S`4AT4m16Y9
@@A>>Bh3FdLj15Tl<@AdDdL4Qge]185`J@AmK6D3NeYE175OC`ASDdP4G3Th14DX6`AA<R<4N6550g5D
A`AZDT84JDe315U7>0AGASd4MeM40f1<?`AZCDP4HU10175D@`A8?3842P/:11/D40>AET<4GBLL1:gL
ibMkNg/Eoooo000Doooo7g]kN`@200047Q0;11/D40<Q5A446a8?11hE4@@h9b<4bY=g18U`HPAgK5l3
OFaX16iNE@APCd<4Gd8l14I1?@AZBD44CST^0e]7>PAI?344M5=718MmK@B1L6T4OFaU0g]JE@AaGdl4
He=815`i>0A5:1/4DC8S17QQA@=aE4L4JU9216U=@`AIAcP4EdHm17MGA0=PC3l4JTe8169@@0AaE4<4
B3`b10X;2P@K5103TEI315dW70B]g>LWNg]k5Oooo`005?oooamkNg/40P0011h@2`@K51038ADA11/B
3`@N5A44>2LS1<ZCM`B9L684MfaO0ge/J0A^GUD4H4m315m2?0A6@Cd4JTU114hi;P=KAcX4FC`a17AC
A`B7OFd4PG1Y17e/I@=kFUD4LEm?16=CB0AL>CP4ABPK154b8`AhHDD3LEA716YB@PAYCD<4FDLh15M6
?@AgEd@3H4`o16Y=B0ARD404LEA314Pl<P@:2`X46a@@0i5F@`AM9a`4[McW9g]kNaGoool001Coool8
Ng]k17]eM@AkOWh?Ng]k10L200@K3@X47ADA0a/D40@?1`L48aHA13/[9PBVM5/4TWEV17iaI0=kJVL4
Ng1X17MZG`A]FED4GeeI17iVG@A/GE@3L6=K16]KE0AnIEL4Mf]N181dL0AdHUD3N5mG17AQDPAYEd`4
JE1:14`j<0@g8B04?b/N0cTU6`AlCC/4Nee?16QB?`ASCd44HTe10fA7?0AIACX4LE5916i@@0@S71H4
4@h=12PR7@>BB3<4C28H13hn>`Bn_[lSNg]k5Oooo`005?ooo`QkNg/4NgEe17]nOPmkNg/41`8011/=
2P@M5A436a@@10l71`@S5Q44>b/V1:IdF`BBMFH4OW5T0g]ZI`AkL6P4MfYO16eIE@AOGET4OVIM16aM
E0=`He/4Je]D17iUE`AgJeh4P7A`17ARE@=hGeL4M65B16UGC0AYD4X4C3X`13LQ80@o:ah3>BDK17a=
>`AkGDl4J58o16=?@@ARCD43I4Ll15U5>PAaDDT4KU1012<L5P@A3Pd4:28M0i98<`A<8QP4?Shk1;jn
_b=kNg/Eoooo000Doooo27]kN`AkMGD4Ngin3g]kN`@70P046`d:11dE4@<K51043`L712<F4@@k:bH4
YWAK199eIPAnLF@3NfYW17]`J0AgJUl4KEUE15mMF@AnIUd4K5eD0g1SF`A[Fe@4OVEG17M[GPB0M704
M69E0gQOE`AdHE84JEM<16U@BPA<>S04=b4P13l[7P<i9A/4O4dk17]MC`AXDSl4Hdm1169=@@=TAc`4
FDDj175AB@A^D4048a`F114>3@@X8Qd3TTPc14`R60@n?S/4_[jo8g]kNaGoool001Coool8Ng]k17]e
M@AkOWh?Ng]k10L200@K3@X47ADA0a/D40@?1`L48aHA13/[9PBVM5/4TWEV17iaI0=kJVL4Ng1X17MZ
G`A]FED4GeeI17iVG@A/GE@3L6=K16]KE0AnIEL4Mf]N181dL0AdHUD3N5mG17AQDPAYEd`4JE1:14`j
<0@g8B04?b/N0cTU6`AlCC/4Nee?16QB?`ASCd44HTe10fA7?0AIACX4LE5916i@@0@S71H44@h=12PR
7@>BB3<4C28H13hn>`Bn_[lSNg]k5Oooo`005?ooo`QkNg/4NgMh17]lO0mkNg/41`@3124G50@M4`l3
7a@@11@>2`@T5A44>R/V19eWD0BDNVT4P7=U0g]ZI`AkLfX4NfiV17]dL@QkLF`4Nf]Q0g]dL@QkJf44
MfEF17e^I0AgIUT3LeiB17MKD0AcHUH4MF5E16eCCPA8?cd4C3/d0c4/9PA09Q`4>bLL15Te:PA8?C84
EcPZ0eDh:PAfEdl4LDm316A8>`@>3@d46Q8?12LJ6P<h4P`4BQT@12lb;`COg]lSNg]k5Oooo`005?oo
o`QkNg/4NgMh17]lO0mkNg/41`@3124G50@M4`l37a@@11@>2`@T5A44>R/V19eWD0BDNVT4P7=U0g]Z
I`AkLfX4NfiV17]dL@QkLF`4Nf]Q0g]dL@QkJf44MfEF17e^I0AgIUT3LeiB17MKD0AcHUH4MF5E16eC
CPA8?cd4C3/d0c4/9PA09Q`4>bLL15Te:PA8?C84EcPZ0eDh:PAfEdl4LDm316A8>`@>3@d46Q8?12LJ
6P<h4P`4BQT@12lb;`COg]lSNg]k5Oooo`005?ooo`QkNg/4NgMh17]lO0mkNg/41`@3124G50@M4`l3
7a@@11@>2`@T5A44>R/V19eWD0BDNVT4P7=U0g]ZI`AkLfX4NfiV17]dL@QkLF`4Nf]Q0g]dL@QkJf44
MfEF17e^I0AgIUT3LeiB17MKD0AcHUH4MF5E16eCCPA8?cd4C3/d0c4/9PA09Q`4>bLL15Te:PA8?C84
EcPZ0eDh:PAfEdl4LDm316A8>`@>3@d46Q8?12LJ6P<h4P`4BQT@12lb;`COg]lSNg]k5Oooo`005?oo
o`QkNg/4NgMh17]lO0mkNg/41`@3124G50@M4`l37a@@11@>2`@T5A44>R/V19eWD0BDNVT4P7=U0g]Z
I`AkLfX4NfiV17]dL@QkLF`4Nf]Q0g]dL@QkJf44MfEF17e^I0AgIUT3LeiB17MKD0AcHUH4MF5E16eC
CPA8?cd4C3/d0c4/9PA09Q`4>bLL15Te:PA8?C84EcPZ0eDh:PAfEdl4LDm316A8>`@>3@d46Q8?12LJ
6P<h4P`4BQT@12lb;`COg]lSNg]k5Oooo`005?oooamkNg/41`D413<V8P@D4@d38A@@11dC3`@V6AT4
>BXT18AH@PB@Lf84RGUZ0g]ZH@AkKFP4Ng5Y17]aK0AkMW@4Ng=^17]_J@=kM744NfUN17]^IPAkJf44
NfMI17]ZGP=aFTl4MemD17MNDPAgIEP4MeUF16UKC`AWD4H3CT4i14@k=0A3>2l4D3@Z14/j;PA/AcX3
Fd]017M9B0ARDD04ET8f10d<30@M4`l471@A0aP?2`@d6QD4?cHa1=gLgB=kNg/Eoooo000Doooo7g]k
N`@71@@4<bHR11@A3@<Q51047A<?12HI6@@i:R@4Q5Q2191cHPB9NFX3NfYQ17]]J0AkLFT4Ng5/17]f
M0AkLfh4NfmY0g]dL@AkJEh4NfiV17][H@AkIeT4NfYN0g5JC`AgGe@4MeiB17MUF0AgFEH4JE]?16M@
AP=>@CT4A3/d14<h;`A@=2X4BcX^16a7>P=KBd04MdU8169A@0AF@SH43@`<11dC3`@L514360l;13@J
5@@o=S44gMcM8g]kNaGoool001CooolONg]k10L510@c9R84514=0b4D40@M4`l49QTI13TZ90B4F484
T7=R18UiJP=kJV44NfeX17]aJ@AkLF`4NgId17]cKPAkKfT3NgAa17]YGPAkKVH4Nf]Q17]WF@AkJUh3
LEY?17MOE0AgGU84MfEH17MIEPAYFdl4Ie160di1>@A4>c@4@cP_150d:PA;>Rh4K4Lj0e];@0AgBDP4
HU5015I2=P@=30`47A<?11`D4@<H3`/4=1XE13lf<@CMg=dSNg]k5Oooo`005?oooamkNg/41`D413<V
8P@D4@d38A@@11dC3`@V6AT4>BXT18AH@PB@Lf84RGUZ0g]ZH@AkKFP4Ng5Y17]aK0AkMW@4Ng=^17]_
J@=kM744NfUN17]^IPAkJf44NfMI17]ZGP=aFTl4MemD17MNDPAgIEP4MeUF16UKC`AWD4H3CT4i14@k
=0A3>2l4D3@Z14/j;PA/AcX3Fd]017M9B0ARDD04ET8f10d<30@M4`l471@A0aP?2`@d6QD4?cHa1=gL
gB=kNg/Eoooo000Doooo7g]kN`@;1@<4;b0H11hH5P<N4`l4910;12TJ5P@f91X4FCha19U]FPB:Nf`3
OVeP17]ZI`AkLfX4NgAa17]^IPAkMW@7Ng=^17]YGPAkKVH4NfUK17]YH@AkIEH3LEM<17MUF0AgGe@4
MeiB17MLD`A]F4/4KU=70fMBAPAPCD84IE5515Y5>`AQBd04KTa10fM?B0AZBD04H4Xl13X[80@E40l4
7A<?12PH50<G4`l491DA13`W70B]UYT4TYVH7g]kNaGoool001CooolONg]k10/50`@_81P47QPF0ahC
3`@T40/4:AXF13HT6PAI?S44VFeJ18YkK0=nKF04NfYW17]cJPAkM744NfiV17]fM0MkLfh4NfUN17]^
IPAkJE/4NfUQ17]UEP=aEd`4MfEH17MOE0AgGU84MeaC16eHB`A^DdL3Ie96161=@PAUDDD4FTDk165;
@0A^C443Idm816Y9@0APBS`4>R/P11D@3`@M4`l4:1PD0aLC3`@T5A44?2LL1:fFV@BBVIPONg]k5Ooo
o`005?oooamkNg/42`D312lP60@N61H37Q<?12@@2`@Y6QH4=R@J15Tn<@BIKEX4RW]/0gi]H0AkJVL4
Ng=Z17]dL@AkKVH4NgId1g]cKPAkJEh4NfiV17]YF`AkJF44NfEF0g5GC0AgIEP4MemD17MNDPAgG5<4
KEQ;16iCA`=WDTH4H4e216EAA@AJAC/4HD]016i<@@=WCdP4JTU0161:?0@j:b045A0?11dC3`@X61@3
5a<?12@E4@@l9a`4[IJI19:IV1mkNg/Eoooo000Doooo7g]kN`@70`44<bTU128I5P<U5Q<45Pl;22<E
4@A9;244Md`c19n6MP>0LF@4NfYW17]cJPAkN7L4NfmY17]^IPAkMW@7NfaT17]^IPAkIUH4NfYQ17AM
D0=dGU84MeiB17MOD`AgG544MeiB16eFBPA/DTH3K5I916]IC0AZD4@4KU5416MBA@AOBSl3IDe316E=
@0AA?C4471PF114=2P@V6AT45a0@0aH@2`@?1`L4=1`F189TGPB_^K/ONg]k5Oooo`005?oooamkNg/4
1`<113<Y9@@R6AH39AHC11H?2`PS5A44BB`Q17M<<`BOQWH3P75T17]ZI`AkLfX4NgQg17]_J@AkKVH4
NgId1g]/I0AkKVH4NfIF17]ZH@AdGE03M5iB17MNDPAgGe<4MeaA17MNDPA]ETX4K5960faFB@A[FD`4
JU1416iAA0AWDTD4GdXo0fE=@`AUCD04DCda11`H5P@A3@X49QTI11L@40<F40/43`L713@L5PB2I5h4
[kVk7g]kNaGoool001CooolONg]k10L30@@c:BD48QTF0bDF4`@F3`/88aDA14T/8@AgC3<4WhIf0h1a
I0AkJVL4Ng=Z17]hM`AkKfT4NfiV17]fM0MkK6@4NfiV17]VEPAkJV44M5e@0gANDPAgGU84MemC17ML
D@AgGU84KEI:16aBAP=/ETT4JeU<16Y@A0A^DD@4Ie9515m:?`=UCD<4IDe0154m<@@L61H44@d:12HI
6@@G41035Q0;10l71`@d71H4PVAN1:ni^amkNg/Eoooo000Doooo7g]kN`@70`44<bTU128I5P<U5Q<4
5Pl;22<E4@A9;244Md`c19n6MP>0LF@4NfYW17]cJPAkN7L4NfmY17]^IPAkMW@7NfaT17]^IPAkIUH4
NfYQ17AMD0=dGU84MeiB17MOD`AgG544MeiB16eFBPA/DTH3K5I916]IC0AZD4@4KU5416MBA@AOBSl3
IDe316E=@0AA?C4471PF114=2P@V6AT45a0@0aH@2`@?1`L4=1`F189TGPB_^K/ONg]k5Oooo`005?oo
oamkNg/41`<112lV8`@/8Qh39AXF128F4P@O5104:AdI140^:0AB>2/4ZW]W0hUfI`AkKFT4NfeU17]d
KPAkMW@4NfmY17]dL@=kJEh8NfiV17]VG0AdIEH4M5eA1gMLD@AgGU84LEiB17AHC0AaF4`4J5960fiF
B@A^F4/4Je9616Y@A0AXDTD4F4Xo0fi=@@ALB3`4=BTS11PB40@R6QH44P/;11L@40<?1`L45a0@12HF
4@A`Ee04`<K87g]kNaGoool001CooolONg]k10L30@@_9R<4;28N0bDJ5P@R5Q847a@@12TM6@A0;RP4
DSP[1:YkI`>9MVL4NfeY17]]I@AkM6h4NgId17]_J@AkM743NfUN27]^IPAkIU`4M6EF17AMD@MgG544
MeiB175NDPAdF4`4LEQ<16QBAP=^ETT4KUQ;16]BAPAZD4@4J59515Q:?`=^CD44G4Pl13DY8`@H4Q04
8QXF118;2`@G41033`L711L@40@V5Q44L5M@1<36b1mkNg/Eoooo000Doooo7g]kN`@70`44;bHS12`R
7P<U6QH48QHB11lD40@Y7AT4@2hX158h:`BZNfL3RGIW17]]J@AkKFD4NgA^17]fM0AkKfT4NgAa0g]Y
GPQkKVH4NfIL17AUEPAdGE47MeaA17MNDPAaGU84M5Q<175HC0AXDTH3KUI916iHB`A[DTH4JU1416QB
A@AHBSl3KTe115a8?0@e:B<4618@128J5P@B2`/45a0@0`l71`@G41049QHA171GD0C0a/PONg]k5Ooo
o`005?oooamkNg/41`<112lV8`@/8Qh39AXF128F4P@O5104:AdI140^:0AB>2/4ZW]W0hUfI`AkKFT4
NfeU17]dKPAkMW@4NfmY17]dL@=kJEh8NfiV17]VG0AdIEH4M5eA1gMLD@AgGU84LEiB17AHC0AaF4`4
J5960fiFB@A^F4/4Je9616Y@A0AXDTD4F4Xo0fi=@@ALB3`4=BTS11PB40@R6QH44P/;11L@40<?1`L4
5a0@12HF4@A`Ee04`<K87g]kNaGoool001CooolONg]k10T50`@b:2D4=2PT0b/Q7P@U5Q8450l;12hJ
5PA2:Ql4FS`/195J@P>>O6h4OW5W17]ZI@AkKFD4NgA^17]fM0AkLfh3NfmY17][H@AkKVH4NfIN17MW
E`AcG503LEU?17AHC0AjFe@4KE]<17=CA`AcEdl4J5E60fiFB@A^DD@4J5=616QAA0ATAc/4Idi20f93
=`A3=Rl4:ahG11dD4@@E40/45@l@11<;2`<F40/4610A12dI50C:aL@4U9FF7g]kNaGoool001CooolO
Ng]k10T50`@b:2D4=2PT0b/Q7P@U5Q8450l;12hJ5PA2:Ql4FS`/195J@P>>O6h4OW5W17]ZI@AkKFD4
NgA^17]fM0AkLfh3NfmY17][H@AkKVH4NfIN17MWE`AcG503LEU?17AHC0AjFe@4KE]<17=CA`AcEdl4
J5E60fiFB@A^DD@4J5=616QAA0ATAc/4Idi20f93=`A3=Rl4:ahG11dD4@@E40/45@l@11<;2`<F40/4
610A12dI50C:aL@4U9FF7g]kNaGoool001CooolONg]k10T50`@b:2D4=2PT0b/Q7P@U5Q8450l;12hJ
5PA2:Ql4FS`/195J@P>>O6h4OW5W17]ZI@AkKFD4NgA^17]fM0AkLfh3NfmY17][H@AkKVH4NfIN17MW
E`AcG503LEU?17AHC0AjFe@4KE]<17=CA`AcEdl4J5E60fiFB@A^DD@4J5=616QAA0ATAc/4Idi20f93
=`A3=Rl4:ahG11dD4@@E40/45@l@11<;2`<F40/4610A12dI50C:aL@4U9FF7g]kNaGoool001CooolO
Ng]k10T50`@b:2D4=2PT0b/Q7P@U5Q8450l;12hJ5PA2:Ql4FS`/195J@P>>O6h4OW5W17]ZI@AkKFD4
NgA^17]fM0AkLfh3NfmY17][H@AkKVH4NfIN17MWE`AcG503LEU?17AHC0AjFe@4KE]<17=CA`AcEdl4
J5E60fiFB@A^DD@4J5=616QAA0ATAc/4Idi20f93=`A3=Rl4:ahG11dD4@@E40/45@l@11<;2`<F40/4
610A12dI50C:aL@4U9FF7g]kNaGoool001CooolGNg]k17]eM@AdLg<41`L6134U8@@f:BD3;R<O11/A
3P@U71P4:a`H138S7@AX?bd4OU510h]hJ@B4MVP4NfYW27]`J0AkN7L7Ng=^17]YGPAkKVH4M65D17iW
FPAaEd`3LeaA17EKC`AcEdd4LEY<17=BAPA/Fe04K5=60fQ;A0A/Dd@4J59516YBA@AWB3d4H4i20e<k
<0A4<bT48ATC128E4`@F4`l46a@@11XC3`<G40/471@A12lI5@Coool4MgMh7g]kNaGoool001CooolG
Ng]k17]eM@AdLg<41`L6134U8@@f:BD3;R<O11/A3P@U71P4:a`H138S7@AX?bd4OU510h]hJ@B4MVP4
NfYW27]`J0AkN7L7Ng=^17]YGPAkKVH4M65D17iWFPAaEd`3LeaA17EKC`AcEdd4LEY<17=BAPA/Fe04
K5=60fQ;A0A/Dd@4J59516YBA@AWB3d4H4i20e<k<0A4<bT48ATC128E4`@F4`l46a@@11XC3`<G40/4
71@A12lI5@Coool4MgMh7g]kNaGoool001CooolGNg]k17]eM@AdLg<41`L6134U8@@f:BD3;R<O11/A
3P@U71P4:a`H138S7@AX?bd4OU510h]hJ@B4MVP4NfYW27]`J0AkN7L7Ng=^17]YGPAkKVH4M65D17iW
FPAaEd`3LeaA17EKC`AcEdd4LEY<17=BAPA/Fe04K5=60fQ;A0A/Dd@4J59516YBA@AWB3d4H4i20e<k
<0A4<bT48ATC128E4`@F4`l46a@@11XC3`<G40/471@A12lI5@Coool4MgMh7g]kNaGoool001CooolG
Ng]k17]eM@AdLg<41`L6134U8@@f:BD3;R<O11/A3P@U71P4:a`H138S7@AX?bd4OU510h]hJ@B4MVP4
NfYW27]`J0AkN7L7Ng=^17]YGPAkKVH4M65D17iWFPAaEd`3LeaA17EKC`AcEdd4LEY<17=BAPA/Fe04
K5=60fQ;A0A/Dd@4J59516YBA@AWB3d4H4i20e<k<0A4<bT48ATC128E4`@F4`l46a@@11XC3`<G40/4
71@A12lI5@Coool4MgMh7g]kNaGoool001CooolGNg]k17]gN0AgMWH40`@313`U70@_9B83=2PT12PO
70@V6aL4;24L138Q60ALACX4ISh_0i1ZF@B4NVX4OVeY17]]I@AkLFT4Ng5/1g]`J@AkIeh4M6IH17AN
D@AjJE`4M5I;0g5HA`AdFe04LEQ717=JC`AcEd/4J5I916iEB0=[C4<4Ie=516Y<@0AZCT84Gda015=3
=`=<<bP4<24N11hD4@@I4a045@l;11P@40@C2`/32PL711D<30A9:R@4jNo_17QiNAmkNg/Eoooo000D
oooo5g]kN`AkMgP4MgIf10<40`@l9A`4;bDR0c@X90@X7a`49Q/G12`Q70@b8AP4G4Dj16Hn;`>@JUT4
Q7YZ17i]J@AkKFD4Ng5Y17]aK0MkL6T4NfMN17AVF0AdGU44NVUL17AFB`=aF4L4M5]@175HA`AcFTl4
LeM;16QFB@A^EDP3Jda316MCA@AZC404JTi215m<@0AC@cL3C3<X130Q7P@N51446A<@11D?2`@H4104
4`/;0`X71`@E30`4BBXT1>W_k`AhNGTONg]k5Oooo`005?oooaMkNg/4NgMh17MfMP@310<4?2DL12lU
8P<d:2@4:1lL12HK5`@/8A`4<R4H15a5>PAV?Rl3T6YI18AjJPAnKFT4NfeU17]aJ@AkLF`7Ng1Y17]W
GPAdIUP4M5iA17YYG0AdET/3LEQ717AKD0AaF4L4LeY?17=GB`AXETT4KUE80f]<@`AWDdD4JTa016Y>
@PAOC404Dd<g0d`c:0@`8Ah47Q@A11TC40@E3`/4610@11<;2`<:1`L45@`<14TZ90CYknl4N7Ui7g]k
NaGoool001CooolONg]k10D40`@a81H4<bXW0cDY9@@Y7aX49AHC13@S6@@a9B44BCX_14/X7`><G4T4
SXAc181^I0AkJUl4NfeX17]/GPMkK604NfUT17MWE`AcG504MemC175AA@=aETL4LeM@17=LB`AcFTh4
Ldm316QGBPM^DD@4IE9516Y:?`ATB3`4D4Di14`e:@<`81h4:AhF11XB3`@I51047a<?11H@40LB2`/4
;ATE1<Vl^PBIW9dSNg]k5Oooo`005?oooamkNg/41@@3134P5P@c:RL3=BTU12TO6P@U5Q<4=2<I134U
8@A9>Rl4BbPO0haLB@B>Q7<4P6iT17]ZG`AkKFP4NfaN1g]/H0AkJF@4MfMG17=LD0AgGe<4LE550g5F
A`AcEe04Lea;17=JCPAcCd<4J5M:1fiAA0AUDTD4JTXo16A8?0A@ACT4C3DY0c0P7P@Y7QH46Q8?11TD
40@O4`l45Q0@1a8;2`@]6AD4bKbj19VLWB=kNg/Eoooo000Doooo7g]kN`@510<4<B0F13<Z9`<e:BD4
:AlJ12DF4`@d8aT4<BDQ14Tj;`A;:1l3S5a918j4L`B0KV@4NfYO17]]J0AkK5h7NfaP17]YI0AgIeL4
Lea@17MOD`AaDDD3LEI717=GD0AcG4/4LeY>17=?@`AXEdX7KU5416EBA@AZBSl4I4Pl1515>@A<=BT3
<20N12TN5P@J4Pl46A@@11lC3`@F41074P/;12dI5@C9_;X4VIbM8g]kNaGoool001CooolONg]k10D4
0`@a81H4<bXW0cDY9@@Y7aX49AHC13@S6@@a9B44BCX_14/X7`><G4T4SXAc181^I0AkJUl4NfeX17]/
GPMkK604NfUT17MWE`AcG504MemC175AA@=aETL4LeM@17=LB`AcFTh4Ldm316QGBPM^DD@4IE9516Y:
?`ATB3`4D4Di14`e:@<`81h4:AhF11XB3`@I51047a<?11H@40LB2`/4;ATE1<Vl^PBIW9dSNg]k5Ooo
o`005?oooamkNg/44@`;12LN6P@b9R83>bTU12/N5P@Y7a/4:A`H13@W8`@_8ad4>bTU0gA7=0B=KUH4
QWMZ17QWF`AnKF<4NfYL17]ZGP=dIET4N6MM17i]G`AaEDX4LE96175HA`=/CT@4L5Q=171HBPAgEdX4
K4e216aDA`A^Bd@3J5A516QB@0ATAC/4GdPl14Xn<P@h8Q`39QdF11`C3`@E3`/45a0@12<D40@E3a04
3PL70a@<30@b6aH4nOWi17QiNB=kNg/Eoooo000Doooo7g]kN`@A30/49ahJ138V8P<k:BD4:ahF12TO
6`@Y71P4=2LS12lS7@@k:BD3M4Ld18e^EPB6MfX4N6MK17i]H`AkJU`4NfYN0gAUF@AhIed4OVeO175E
BPAaDTH4LEQ70fa>A0A`F4d4L5Q:17MGBPA/CD84K5A716i;A0=XE4D4J59016A5>`AOB3`4BShb13PR
70<V7AH471<?11D?2`@G41048a@@11D?40@>1`L350`<138K5PCinOT4N7Ui8g]kNaGoool001CooolO
Ng]k114<2`@W7QX4<RHR0c/Y9@@[7QH4:AlK12TL60@d9b<4;b<M13/Y9@=dAc@4SFiF18IgJPAhIe/4
OVeS17]ZG0AkJUh3M6EI17QWG@AnKEl4LEE:175BAPAaF4L3K4i4171HC@A`F4X4MeM:16a=@PA/E4L4
KT]40fQDA@AXDT04I4Dk15m8?0A:?S84>28L0bHM5P@L4`l45@l;11L@40@S51045@l@10h71`<D30`4
<Q/F1?Win@AhNGTSNg]k5Oooo`005?oooamkNg/44@`;12LN6P@b9R83>bTU12/N5P@Y7a/4:A`H13@W
8`@_8ad4>bTU0gA7=0B=KUH4QWMZ17QWF`AnKF<4NfYL17]ZGP=dIET4N6MM17i]G`AaEDX4LE96175H
A`=/CT@4L5Q=171HBPAgEdX4K4e216aDA`A^Bd@3J5A516QB@0ATAC/4GdPl14Xn<P@h8Q`39QdF11`C
3`@E3`/45a0@12<D40@E3a043PL70a@<30@b6aH4nOWi17QiNB=kNg/Eoooo000Doooo7g]kN`@H4`l4
:20N13@X90<b9204;b<N120G5`@X71P4;b<N13DY9@@a81P3B2XO17QG@`B6IUL4O69D17i/GPAhIEP4
N6YM0gAUF@AgHED4NVII16mGC0AZBSl4L5E60fa?A0A^CT84KUE8179CAPA/DD@4J4a016a<@P=RBSd4
HT/m15I2=`A@=b/4B3@X12@J50<K4Pl46A<@11H?2`@C2``45@`<20X71`<_6QD4=QhE1>gbmRMkNg/E
oooo000Doooo7g]kN`@H4`l4:20N13@X90<b9204;b<N120G5`@X71P4;b<N13DY9@@a81P3B2XO17QG
@`B6IUL4O69D17i/GPAhIEP4N6YM0gAUF@AgHED4NVII16mGC0AZBSl4L5E60fa?A0A^CT84KUE8179C
APA/DD@4J4a016a<@P=RBSd4HT/m15I2=`A@=b/4B3@X12@J50<K4Pl46A<@11H?2`@C2``45@`<20X7
1`<_6QD4=QhE1>gbmRMkNg/Eoooo000Doooo7g]kN`@H4`l4:20N13@X90<b9204;b<N120G5`@X71P4
;b<N13DY9@@a81P3B2XO17QG@`B6IUL4O69D17i/GPAhIEP4N6YM0gAUF@AgHED4NVII16mGC0AZBSl4
L5E60fa?A0A^CT84KUE8179CAPA/DD@4J4a016a<@P=RBSd4HT/m15I2=`A@=b/4B3@X12@J50<K4Pl4
6A<@11H?2`@C2``45@`<20X71`<_6QD4=QhE1>gbmRMkNg/Eoooo000Doooo7g]kN`@H4`l4:20N13@X
90<b9204;b<N120G5`@X71P4;b<N13DY9@@a81P3B2XO17QG@`B6IUL4O69D17i/GPAhIEP4N6YM0gAU
F@AgHED4NVII16mGC0AZBSl4L5E60fa?A0A^CT84KUE8179CAPA/DD@4J4a016a<@P=RBSd4HT/m15I2
=`A@=b/4B3@X12@J50<K4Pl46A<@11H?2`@C2``45@`<20X71`<_6QD4=QhE1>gbmRMkNg/Eoooo000D
oooo7g]kN`@b:b`47aPD13<X90<^8al4>RhY12PK5@@V5a@4>B`X12`P70@f:2<3:1/G15<o<PAC>Bh4
MTTi18EZFPA[E4L4MF=K0g5ME0AaFd`4N69E16A=@PAC>c04ITDh0g1:>0A_D4H4K51316a4>0A/DdH4
J4`f16A8?`=O@cL4FT4e14i1=@@m9R04=QlG11lE4`<K4`l45A0;118;2`@C2`/43`L710X71`@D30`3
:1LA1:jMVPBUZZ/WNg]k5Oooo`005?oooamkNg/4<R//11lH50@c:2@3;R<O13X^:@@X6aD49QLD13T/
:0@/81`4=RPS0bPK5`AC?c84DcT^17I9>@B5JUX4JeA717ESF`=aGE@4LE]<17QRE@ATCD84Dc/`16I5
>0=`BSP4Ke1616a@@`A/A3P4K5=616Q<=PATB3l3Gd<g15Y1=@A>@CD4?BHP13HO5`@O5A<36a<?11D@
2`@B2`/44`/;10l71`@:1`L450`<0bPG4@B^WIX4YJZ[9g]kNaGoool001CooolONg]k138[;0@O61@4
<bPT0bhS7`@j;RT4:1/E12HG50@i;2P4;20L13HX8`<X6aL4Dclb15<i;PAfBCT4QFYJ16]DA`AeHe/3
LEeD175KC0AhHUD4I4e215<k<0AVACP3L4Xh16m@APA/D4<4K4@h16aCAPAXC3H4I4Po0em3=`AJ@CD4
CT4e13dV80@f7aL47aDC0a/C3`@E40/44P/;11<;2`@?1`L42PL711@<30<X5a44[YfJ1:FZZbMkNg/E
oooo000Doooo7g]kN`@b:b`47aPD13<X90<^8al4>RhY12PK5@@V5a@4>B`X12`P70@f:2<3:1/G15<o
<PAC>Bh4MTTi18EZFPA[E4L4MF=K0g5ME0AaFd`4N69E16A=@PAC>c04ITDh0g1:>0A_D4H4K51316a4
>0A/DdH4J4`f16A8?`=O@cL4FT4e14i1=@@m9R04=QlG11lE4`<K4`l45A0;118;2`@C2`/43`L710X7
1`@D30`3:1LA1:jMVPBUZZ/WNg]k5Oooo`005?oooamkNg/4If=X11@@30@U7AX3<BDQ13<V8P@U7QT4
8QHG13PU6P@^9244?Bl[0bdT8@@e:284?blZ15Pf:`AR@304CShk14i0=`=R?c04IU1016=<?PA;=Rl4
Bc8U14db9@=P?b/4IShb16E8=@A^ACD4Fd@h15Hi:PAO>bl3Fclc14Ph<@A2;2<4<AdF12LF4`@K4a03
5@l;118;2`@?1`L42`P810/71`@:1`L47aDA0bdI5@CflO44OGin9g]kNaGoool001CooolONg]k16MS
J0@D40`49AdJ0c4U8@@c9R849AhI128F5`@h9AX4;R@Q13d_:`<]9244=BPR13l_:PAH=R/4HT0`14hn
>`A>@3L3HSl`16I@@0ASC3h4BcH_14/b9@A=<RD3H3l[16Hn<PAUB3D4KTDe15]4>0AF>BX4Gc/_0e/o
<`A8>344@R`S134M5P@W5Q<46a<@0aD?2`@B2`/43`L710/820@;1`L42PL711lE4@<]6AD4m_7a17en
ORMkNg/Eoooo000Doooo7g]kN`AWHfP4510<12DM6P<a9B44<bHR12DN6@@R5QL4>2DJ12hT8@@m;b/3
;B@Q13DX8P@o;bX4F3H[1690<0A>?S/4CT0g0f8o<0AVD404Hd`n14/f;`A;<RD4CC8U0f0o:`AV?S84
IDPe16i5=@AKA3P4ESTZ15lk;`=K?c<4B3Pa148/8`@a7AH49aHC11/C40<E3`/44P/;10l71`@;20P4
2`L710X71`@O5A43;ATE1?Kal@AmOWhWNg]k5Oooo`005?oooamkNg/4If=X11@@30@U7AX3<BDQ13<V
8P@U7QT48QHG13PU6P@^9244?Bl[0bdT8@@e:284?blZ15Pf:`AR@304CShk14i0=`=R?c04IU1016=<
?PA;=Rl4Bc8U14db9@=P?b/4IShb16E8=@A^ACD4Fd@h15Hi:PAO>bl3Fclc14Ph<@A2;2<4<AdF12LF
4`@K4a035@l;118;2`@?1`L42`P810/71`@:1`L47aDA0bdI5@CflO44OGin9g]kNaGoool001CooolS
Ng]k124M7@@M5a@3=RXU12lX90@]8Ql45a4>13DT7P@l;b`4>RhY0c/`;0@i;RX4@cH]14De;0A0<BL4
>BTW13XV70=09b84CBlT14`g;@@d9R@4?2TT14HY80=7;1d4BB/S15Xm;0AG>2X4BC4U14le:@A7;203
BSD/13hX80@e8a/48aHB12HK60@C3`X35Q0;118;2`@>1`L42PL710/71`@S5A04610@0gIECPC9dM8[
Ng]k5Oooo`005?ooob=kNg/48AdM11dG50<f:RD4;bPT12dR7`@G4@h4=B@N13`_;0@j;RT3>c0/13T^
:PA3=Rd4ACD/140a9`@i:BL4>RHL0d0W8PA=;b@4C3L]13@V90@l:B@4ARTP0dL/7@A9:b<4FSd/15Lh
:PA9<BD4CcDY14L/80=:=B`4?RPP13DS6`@S5Q849Q/H11<?2P<F40/44P/;10h71`@:1`L42`L712<E
40@H4103MUE>1<WAdR]kNg/Eoooo000Doooo8g]kN`@Q7Ad47ALD0cHZ9@@_:2@4;B8O11LA3P@e91h4
?2l/13X^:@<k<2`4>BhZ14<f;@A5=B`4@34W13TY9`@j9Q`3@2LR14d_90A<=bd4=2HT13`Y90A6:B03
Ab`M14T[8`AJ?B`4EcPZ14Ta9@A?=BT4Ab`P0dXe;0@n:204=B<K12<F4P@V6aP44`l:0aH@2`@B2`/4
3PL710X71`@;1`L48aD@11P@40=fEDh4bM7B:g]kNaGoool001CooolSNg]k14e8DP@D3`/3;b@P12lU
8@@`9204:20M13PZ9P@m;b/4?C8]0c<X90@f:BD4?BHQ14D[8P@d91`4;R@Q12LK5P<e9R<4:QPC13PZ
9@@_9204;20L12`H4`<[7QP4:aTD13DK5P@g91X4=28I13HS6@@]5a@3<1XF12TH50@Y6A@461<?11P@
30@A2`/34``;11<;2`P:1`L48aDI12<E40@`9R83d/?018jATR]kNg/Eoooo000Doooo8g]kN`A=B584
50l;0blT80@_9B44<2@P12PP7@@h:RH4?Bl[13db;@<c:2@4=RTU13dV8@A5:b84=2@L12hT8@@W6aH3
=BHS12XH4`@h:RD4;b@P12`P70@/61<3:ahH12/I50@e6aH4=b@J13@R6@@f8aT4;ALD0c0J5P@Y61@4
:ATD11PC3`@H40`44@/;0a<<2`@C2`/82PL712<E6@@S5A04<2HR0m;3`0B>TI8[Ng]k5Oooo`005?oo
ob=kNg/4CDQB11@?2`<_9204;bDQ130T80@X81d4>2XV13d_:`@m<Rd3<bPT13HY9@@m9R44AB/R13@T
70@^92449a/F0cDV8`@Z61<4>2XU12lT80@/81`4;1PC0b/N60@[6A@4=A/F13LT6P@d8QT4=R<I12dG
50<`6QH4:APD12TI50@H4`l4610<114;2`<C30/44`/;20X71`@S5AT48aD@130V8P?B`l04SY6B:g]k
NaGoool001CooolSNg]k14e8DP@D3`/3;b@P12lU8@@`9204:20M13PZ9P@m;b/4?C8]0c<X90@f:BD4
?BHQ14D[8P@d91`4;R@Q12LK5P<e9R<4:QPC13PZ9@@_9204;20L12`H4`<[7QP4:aTD13DK5P@g91X4
=28I13HS6@@]5a@3<1XF12TH50@Y6A@461<?11P@30@A2`/34``;11<;2`P:1`L48aDI12<E40@`9R83
d/?018jATR]kNg/Eoooo000Doooo8g]kN`AcL7@48AdK0alI5P@`9204=BTU12lS80A1=2l4:AlJ140a
;@<W7QX4>2/V14Ha:0@c9b<4;R<O12lT8@@X7QX3?R/W11dD5@@/91h4:APD12PH50@N4`l36aDA128D
40@/6A@4:QTD120D40@R5A0481@@0b/I50@N51048A@@11D?2`@G40/44P/;0a<;2`P:1`L450`<134P
6`@W5a<4/[6`0j6OX2mkNg/Eoooo000Doooo8g]kN`AcL7@48AdK0alI5P@`9204=BTU12lS80A1=2l4
:AlJ140a;@<W7QX4>2/V14Ha:0@c9b<4;R<O12lT8@@X7QX3?R/W11dD5@@/91h4:APD12PH50@N4`l3
6aDA128D40@/6A@4:QTD120D40@R5A0481@@0b/I50@N51048A@@11D?2`@G40/44P/;0a<;2`P:1`L4
50`<134P6`@W5a<4/[6`0j6OX2mkNg/Eoooo000Doooo8g]kN`AcL7@48AdK0alI5P@`9204=BTU12lS
80A1=2l4:AlJ140a;@<W7QX4>2/V14Ha:0@c9b<4;R<O12lT8@@X7QX3?R/W11dD5@@/91h4:APD12PH
50@N4`l36aDA128D40@/6A@4:QTD120D40@R5A0481@@0b/I50@N51048A@@11D?2`@G40/44P/;0a<;
2`P:1`L450`<134P6`@W5a<4/[6`0j6OX2mkNg/Eoooo000Doooo8g]kN`AcL7@48AdK0alI5P@`9204
=BTU12lS80A1=2l4:AlJ140a;@<W7QX4>2/V14Ha:0@c9b<4;R<O12lT8@@X7QX3?R/W11dD5@@/91h4
:APD12PH50@N4`l36aDA128D40@/6A@4:QTD120D40@R5A0481@@0b/I50@N51048A@@11D?2`@G40/4
4P/;0a<;2`P:1`L450`<134P6`@W5a<4/[6`0j6OX2mkNg/Eoooo000Doooo9g]kN`A;@dT35@h;138Y
9@@e:BD4;R<O12XS7P@i;2P4@C@_0bPS80@]81`4@bPM128K60@]8Ad4;24L11dG6`<_91d47aDF12XI
50@O4aP46a@?11/D40<F40/87A@@11`D40@F3`/44`/<11TA30<T5A445@l;11<;30@G40/45a0@118;
2`<:1`L44`/;11/D40@Z71T4:aTE1:JSX`BVYJDbNg]k5Oooo`005?ooobMkNg/4Bd=90aD>2`@b:BD4
=BTU12hS7`@Z8ah4>B`X144d;`<X8b04;B0L14<X7@@R6aP4;B4M12`Q70@M5a/3;b@M11lE5P@Z6A@4
7a<H11/D3`@K51035Q0;21dD40@L51045Pl;11<;30@I4@`391DA11D?2`@C2``45a0;11L@40@B2`/3
2PL711<;2`@K5104:Q`I12/I5@BVXj<4YZFU<W]kNaGoool001CooolWNg]k14]3B@<E3P/4<RTU13DY
9@@^8al4:R<N13T/:0A1=2l3:2<P12dP70A3:1d48Q/H12dQ7@@/8A`47ALK0blT7@@O5AH4:QTD11lC
60@K50l46a@@0aH@2`PM510471@@11H?2`@C2``46A4<0b@E4@@E3`/44`/<11L@2`@G41044P/;0`X7
1`@C2`/46a@@12XL6@@[6AD4YZ>S1:JUYC9kNg/Eoooo000Doooo9g]kN`A;@dT35@h;138Y9@@e:BD4
;R<O12XS7P@i;2P4@C@_0bPS80@]81`4@bPM128K60@]8Ad4;24L11dG6`<_91d47aDF12XI50@O4aP4
6a@?11/D40<F40/87A@@11`D40@F3`/44`/<11TA30<T5A445@l;11<;30@G40/45a0@118;2`<:1`L4
4`/;11/D40@Z71T4:aTE1:JSX`BVYJDbNg]k5Oooo`005?ooobMkNg/4KVY^0aLA3P@W7a`4=RTU12hS
7`@b:2@4=2/V13PZ9P<W7aX49Q/G12`M60@L4`l4<B@N128G60@Q5aP38AD@120D6@@G40l44`/<11PA
40@H41034P/;11TA4@@C2`/4614@118;2`@G410471D@0aP@40@B2`/42PL720/820@;1`L3610@11P@
2`@D30`49Q8<1:JKW0BZZj/fNg]k5Oooo`005?ooobMkNg/4KVY^0aLA3P@W7a`4=RTU12hS7`@b:2@4
=2/V13PZ9P<W7aX49Q/G12`M60@L4`l4<B@N128G60@Q5aP38AD@120D6@@G40l44`/<11PA40@H4103
4P/;11TA4@@C2`/4614@118;2`@G410471D@0aP@40@B2`/42PL720/820@;1`L3610@11P@2`@D30`4
9Q8<1:JKW0BZZj/fNg]k5Oooo`005?ooobMkNg/4KVY^0aLA3P@W7a`4=RTU12hS7`@b:2@4=2/V13PZ
9P<W7aX49Q/G12`M60@L4`l4<B@N128G60@Q5aP38AD@120D6@@G40l44`/<11PA40@H41034P/;11TA
4@@C2`/4614@118;2`@G410471D@0aP@40@B2`/42PL720/820@;1`L3610@11P@2`@D30`49Q8<1:JK
W0BZZj/fNg]k5Oooo`005?ooobMkNg/4KVY^0aLA3P@W7a`4=RTU12hS7`@b:2@4=2/V13PZ9P<W7aX4
9Q/G12`M60@L4`l4<B@N128G60@Q5aP38AD@120D6@@G40l44`/<11PA40@H41034P/;11TA4@@C2`/4
614@118;2`@G410471D@0aP@40@B2`/42PL720/820@;1`L3610@11P@2`@D30`49Q8<1:JKW0BZZj/f
Ng]k5Oooo`005?ooob]kNg/3BdQ711hJ60@T6aP4<BDQ138Z9P@_:2@4?2dY0b/Q8@@T5Q84:1dI11PB
3`@T5Q446Q@@124D40<B2`/450`<11L@40@F3`l44`/;11P@40<B2`/4614A118;2`@]6QD420L711XA
4@@M5A035Pl@20X71`@?1`L4610@11H@40<H4104:aTD12hP60AL?2h4c]SP17enOSIkNg/Eoooo000D
oooo:g]kN`=;B4L47QXH12@K60@a9B44<RXV12lX90@l;BT3:b4Q12@F4P@X7AT4618?12@F4@@J5104
8A@@0a8;2`@D30`45a0@11H?3`@C2`/4610@0a8;2`@H4A444P/;12dJ5@@81`L46Q4A11dE40<F3a08
2PL710l71`@H41045Q0@0aP@40@[6A@4;R0H15`l;PC>f>04OGin=W]kNaGoool001Coool[Ng]k0d]8
A`@N6QP491/H134U8@@b:RH4;bPT13`]:@<[8B4491HB12PM6@@H4Pl491HA11XD40@Q51034P/;11@<
30@G41045Pl?11<;2`@H41034P/;11PA4@@B2`/4;AXE10P71`@J4A447AD@0aH?40P:1`L43`L711P@
40@F4103610@12/I50@^81P4G3`^1<kHh0AmOWhfNg]k5Oooo`005?ooobikNg/4BdQ711/F50@X9244
:b0K13`_:`@j;BT3=BXW124K5`@/81`46Q8F11L@3`@Q51045a0@0aXC3`@J4a045a0@21<;2`@D30`3
4`/;11@<30@L51046Q4A12PX<`@[9R@47A4E0a4;2`@F41046Q@@11XC40@G4104<28M0b@J5`@[61@4
DS8W1:f[ZPB@Ui/jNg]k5Oooo`005?ooobikNg/4BdQ711/F50@X9244:b0K13`_:`@j;BT3=BXW124K
5`@/81`46Q8F11L@3`@Q51045a0@0aXC3`@J4a045a0@21<;2`@D30`34`/;11@<30@L51046Q4A12PX
<`@[9R@47A4E0a4;2`@F41046Q@@11XC40@G4104<28M0b@J5`@[61@4DS8W1:f[ZPB@Ui/jNg]k5Ooo
o`005?ooobikNg/4BdQ711/F50@X9244:b0K13`_:`@j;BT3=BXW124K5`@/81`46Q8F11L@3`@Q5104
5a0@0aXC3`@J4a045a0@21<;2`@D30`34`/;11@<30@L51046Q4A12PX<`@[9R@47A4E0a4;2`@F4104
6Q@@11XC40@G4104<28M0b@J5`@[61@4DS8W1:f[ZPB@Ui/jNg]k5Oooo`005?ooobikNg/4BdQ711/F
50@X9244:b0K13`_:`@j;BT3=BXW124K5`@/81`46Q8F11L@3`@Q51045a0@0aXC3`@J4a045a0@21<;
2`@D30`34`/;11@<30@L51046Q4A12PX<`@[9R@47A4E0a4;2`@F41046Q@@11XC40@G4104<28M0b@J
5`@[61@4DS8W1:f[ZPB@Ui/jNg]k5Oooo`005?oooc9kNg/4CdU811`H5P@]9R84;20L13<[9`=1<bh4
;bLT12dN5P@R6AP45a8?11P@40@B2`/36A4<11P@40@B2`/44`/;11P@40@B2`/3610@118;2`@D30`4
<2`]12/M:@A3=Rd4<bTW0b@M7P@f:bL49AdI11LB3`@Y71T4;1hI0cHZ9@A19Qh4ZZ6Q19NOXCikNg/E
oooo000Doooo<W]kN`A?BDP471PF12dV8P@/81`4<b/W0d4c;P@_9b@4;AhF128I60@G4Pl4610@118;
2`<I4@`4610@118;2`@C2`/4610@118;2`<H41044P/;11@<30@`;2d4:adY14<f;@@c:BL391dN13H[
9`@U7AT45a8?12TL6@@/7QT3=RXU144V7PBZXJ44UinQ?W]kNaGoool001CooolbNg]k14m9B0@L61H4
;BHR12`P70@c:bL3@C<^12lW90@]7QH48QTH11LB3`@H41044P/;0aTA30@H41044P/;11<;2`@H4104
4P/;0aP@40@B2`/450`<130/;@@[7BT4@cH]13<Y9`<T7Ah4=R/W12DM6@@G4Pl4:A`I12`N6@<f:RD4
@BHN1:ZQX@BGWj4nNg]k5Oooo`005?oooc9kNg/4CdU811`H5P@]9R84;20L13<[9`=1<bh4;bLT12dN
5P@R6AP45a8?11P@40@B2`/36A4<11P@40@B2`/44`/;11P@40@B2`/3610@118;2`@D30`4<2`]12/M
:@A3=Rd4<bTW0b@M7P@f:bL49AdI11LB3`@Y71T4;1hI0cHZ9@A19Qh4ZZ6Q19NOXCikNg/Eoooo000D
oooo<W]kN`AnOWh4BD=2120F4@@a;2T4<BLT0d<e<0@j;b/4>2`W120H5@@T6QL4;R@Q124M6@<M4Ph4
6Q@@11H?3`@G41084`/;0adE6P@F3`l46a@@11/B4`@/8Qh4>RXS11H?40<M5A447aHA11L@40@O50l4
;1hJ138Q60=L?2h4OgAn1:F[ZPAkO7`nNg]k5Oooo`005?oooc9kNg/4OWin14U3@P@P5Q44<B`Y134W
90=3=C04>Rl[13P/9`@P61D491XG12hT8@@Q7AT37A8>11XD40@F3`l45a0@21<;2`<M5AX45Pl?11/D
40@K4Q<4;28N13XZ8`@F3a037ADA11lF4@@G41047a@?12`N6P@b8AP3G3`^17mdOPBUZjX4Ngal?W]k
NaGoool001CooolbNg]k17inOPA9@d8481HA134/:@@a9b@3@cD`13X_:`@h;2L481PE12@J5`@^9244
8AdI0adB3P@J51045Pl?11L@40PC2`/37ADJ11H?3`@K51046a8C12`R7P@j:R<45Pl@0adE4@@O5Q44
5a0@11lD3`@/7QX4<R4H0e`l;PAoM7h4YJ^Z17]lO3ikNg/Eoooo000Doooo<W]kN`AnOWh4BD=2120F
4@@a;2T4<BLT0d<e<0@j;b/4>2`W120H5@@T6QL4;R@Q124M6@<M4Ph46Q@@11H?3`@G41084`/;0adE
6P@F3`l46a@@11/B4`@/8Qh4>RXS11H?40<M5A447aHA11L@40@O50l4;1hJ138Q60=L?2h4OgAn1:F[
ZPAkO7`nNg]k5Oooo`005?ooocYkNg/4Achj12<N6P@S6aP3>bdX14`n>@A3?3P4;RHS124H5@@V6AT4
:1PD0blT80@R7QX450h?11<;2`@Q6Ad47QLJ0bXR7@@L5QX4>B/T11DA5@A<>c84;B8S12LO70<]8al4
9ahJ12dR80@n<BL4;24O160m;@>MUiT4QX^C1863PT9kNg/Eoooo000Doooo>W]kN`A7?SX48ahJ12<K
60<k;BP4C3hi14<l>0@^9R<48APE12HI6@@X61@3;b@P128N6P@D3Pl44`/;124I7@@N5aX3:R8M11`F
6P@i:b@45A4E14`k<P@]8R<49alL0bdS7`@W7QX4;B8P13ha9`@/8Al4H3d]0ifGV@B6Ri<4PH>2@W]k
NaGoool001CoooljNg]k14Ln>P@S7QX48a/H0c/]:0A<?ST4@c`h12hV8`@Q61D49QTI12PH50<_9204
8QhJ11@>3`@C2`/48ATM11hG6P<Z8Qd471HJ13T[90@E4AD4C3/b12dR8`@W7a`3;B<O12LN6P@]8R04
?S4W12`Q7`AP?Bd3WINI18J;T`B1Ph92Ng]k5Oooo`005?ooocYkNg/4Achj12<N6P@S6aP3>bdX14`n
>@A3?3P4;RHS124H5@@V6AT4:1PD0blT80@R7QX450h?11<;2`@Q6Ad47QLJ0bXR7@@L5QX4>B/T11DA
5@A<>c84;B8S12LO70<]8al49ahJ12dR80@n<BL4;24O160m;@>MUiT4QX^C1863PT9kNg/Eoooo000D
oooo?W]kN`A7AD44>CDj0bLQ70@h:bH4?C4/13`j?`@l;bX4>c8`13lg<`<Z8244:2PW13P`>P@l=Bl4
:1lQ12PS;0<b9B84>SA013HW80@V7ad4AC@^13@U8P@g8al3=b@K130X9@A5<RT4FSd^12PN6@Bi/:d3
T9>H17]lO4IkNg/Eoooo000Doooo?W]kN`A7AD44>CDj0bLQ70@h:bH4?C4/13`j?`@l;bX4>c8`13lg
<`<Z8244:2PW13P`>P@l=Bl4:1lQ12PS;0<b9B84>SA013HW80@V7ad4AC@^13@U8P@g8al3=b@K130X
9@A5<RT4FSd^12PN6@Bi/:d3T9>H17]lO4IkNg/Eoooo000Doooo?W]kN`A7AD44>CDj0bLQ70@h:bH4
?C4/13`j?`@l;bX4>c8`13lg<`<Z8244:2PW13P`>P@l=Bl4:1lQ12PS;0<b9B84>SA013HW80@V7ad4
AC@^13@U8P@g8al3=b@K130X9@A5<RT4FSd^12PN6@Bi/:d3T9>H17]lO4IkNg/Eoooo000Doooo?W]k
N`A7AD44>CDj0bLQ70@h:bH4?C4/13`j?`@l;bX4>c8`13lg<`<Z8244:2PW13P`>P@l=Bl4:1lQ12PS
;0<b9B84>SA013HW80@V7ad4AC@^13@U8P@g8al3=b@K130X9@A5<RT4FSd^12PN6@Bi/:d3T9>H17]l
O4IkNg/Eoooo000Doooo@W]kN`A[If/3AdU5124K7P@h;RP4<c@m15a<A`A5?Sd4@c`g0cXc<@A2?d44
Bc`j14Dj<`@/9284>C0_0bdQ8P@_9204<B@O13T]:@@e:BD4ABPP14@/90=2<2L4BSXc13hV7PARC4`4
N7mm19fOXTekNg/Eoooo000Doooo@W]kN`A[If/3AdU5124K7P@h;RP4<c@m15a<A`A5?Sd4@c`g0cXc
<@A2?d44Bc`j14Dj<`@/9284>C0_0bdQ8P@_9204<B@O13T]:@@e:BD4ABPP14@/90=2<2L4BSXc13hV
7PARC4`4N7mm19fOXTekNg/Eoooo000Doooo@W]kN`A[If/3AdU5124K7P@h;RP4<c@m15a<A`A5?Sd4
@c`g0cXc<@A2?d44Bc`j14Dj<`@/9284>C0_0bdQ8P@_9204<B@O13T]:@@e:BD4ABPP14@/90=2<2L4
BSXc13hV7PARC4`4N7mm19fOXTekNg/Eoooo000Doooo17]hN0AkOWi1Ng]k14M5BPAKFUH4CTmJ13D_
=@AKCDP4H5YS0de3?PA;?CT4A3Xf14Lk=`A;?3d4CCli0cXd<PA:>cL4>S<[14Tm>PA=?CT4@C<Z14Hg
<0<e9R84QG1f16m^J@AaKg<4T9>BDG]kNaGoool001Coool4NgQh17]nOT5kNg/4AdE:15]JEPA>CeX4
=Ble15]=B0APFV<3CD<n14/m>@A4>SH4Ac/g14/l?@A=?cT3>S@b14Xk=`@j<b/4BCdj14dm>@A1<bX4
ASL`0cDV8PB5L7H4KfiY175_L`B@Ti9ANg]k5Oooo`005?ooo`AkN7P4Ngin@G]kN`A7ADX4FeYF14i?
FP@e;cD4Fde8161JH`==@ch4Bcdi14@j=PA7>cL4Bc`m14do>@<j=384BS/g13Xc:`A9?CX4CCdi144c
:PA6=c03=BHR18E`MPA_KVT4LFmc192CTU5kNg/Eoooo000Doooo17]hN0AkOWi1Ng]k14M5BPAKFUH4
CTmJ13D_=@AKCDP4H5YS0de3?PA;?CT4A3Xf14Lk=`A;?3d4CCli0cXd<PA:>cL4>S<[14Tm>PA=?CT4
@C<Z14Hg<0<e9R84QG1f16m^J@AaKg<4T9>BDG]kNaGoool001Coool4NgUi17]lO4UkNg/4Lg1d14]=
E0AcKFX4MWEl0eeEG0A/I5/4C4M@13Xf>PAAADd4BCXa0dHl>0A>?cX4A3Xe14Di=PA5<RP4?SD/19ZC
UP=GEeP4RH>718F9QeUkNg/Eoooo000Doooo17]iN@AkO7a9Ng]k17=`M0A;CE@4LfeZ17IeO0=MEE`4
K6AK14a7D0@j=SX4DDE=14Tj<@=6?3P4CSlj14@j=@A5>CH4AC8X13he;0BJTiH3EeMH18V3Q`B5RHMI
Ng]k5Oooo`005?ooo`AkNGT4NgalBG]kN`AcL7@4BdeD17=]JPAfMG`3GEEL16aTF`A<Ae04>SHj1555
C@A9>S43AS`h14ho>PA4>SD4ACTf14Db:0@n=B`4VY>F0eMGF0B9PhL4QHV7FG]kNaGoool001Coool4
NgUi17]lO4UkNg/4Lg1d14]=E0AcKFX4MWEl0eeEG0A/I5/4C4M@13Xf>PAAADd4BCXa0dHl>0A>?cX4
A3Xe14Di=PA5<RP4?SD/19ZCUP=GEeP4RH>718F9QeUkNg/Eoooo000DooooHG]kN`=cL7P4Ogei16]X
K`AGFEh4IVIZ16=OFP=UGUd4IFIU16ERHPAQGel4GeYG165QG`BIUIP3NgalHG]kNaGoool001CooomQ
Ng]k0g=`N0AoOGT4JfQ_15MIGPAVIVX4HemJ0fENG@AUIVD4IF9R165OG`AOFUL4HF5O19VEV0=kO7aQ
Ng]k5Oooo`005?ooof5kNg/3Lg1h17mmN@A[J6l4EeUN16IVJPASGeX3IEiM16EVI@AUHV84HEmO15mJ
E`AQHEl4VIFH0g]lO65kNg/Eoooo000DooooHG]kN`=cL7P4Ogei16]XK`AGFEh4IVIZ16=OFP=UGUd4
IFIU16ERHPAQGel4GeYG165QG`BIUIP3NgalHG]kNaGoool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool009Koool30000Qoooo`00VOooo`030000
oooooooo08Coool0083oool300000_ooo`800004oooo100000;oool300000oooo`<00003oooo0P00
087oool0087oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`00
00Goool010000?ooooooo`0008Koool007koool500001?ooo`040000oooooooo00000_ooo`030000
oooooooo00@00002oooo00@0003oooooool00026oooo001noooo00@0003oooooool00003oooo0P00
00Coool300000oooo`800004oooo100008Goool007ooool00`000?ooo`000003oooo00<0003ooooo
ool01Oooo`030000oooooooo093oool0083oool200000oooo`<00004oooo0P0009;oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(68) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A6D513D
7D6E61776A6677726A77655E77726A776E66776E66776E6677655E776A596D6256735E52
6A52476F594D6552466B55496B55496B55496B55496B4E4262513E67514867513E675148
90ADBA777A7A777A7A777A7A777A7A777171777F7F777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777373777C7C777A7A777373777C7C777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777373777C7C777A7A777A7A777A7A777A7A777A7A777A7A745641
7B6C67776A5D77726C77655E77726A776E66776759706356726356725F5169584D675449
674F446A5548614D426D574A6B55496B55496B4F436B4F4362514467514767513E676B6E
90A4AE777A7A777A7A777A7A777A7A777878777D7D777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777878777676777C7C777878777D7D777A7A777373777C7C777373777C7C777A7A
777A7A777A7A777A7A777878777D7D777A7A777A7A777A7A777A7A777A7A777A7A70523E
7A6B60776A62776B66776E66776A627769617061515B5D57735A4E6E4E4964524567594C
6B584C6B5A4D695247675145665144665144664F4366513F64514667514567514486A0AE
868C8E777A7A777A7A777A7A777A7A777A7A777373777C7C777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777171777F7F777A7A777A7A777A7A777878777D7D777878777D7D777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A74513D
7B6E68776A64776A62776B6377675F776A5B7468607069637963537C5759685848705549
70554E70554D6847416251436751456751456751456751446E574C65504467514590ADBA
777A7A777A7A777A7A777A7A777A7A777A7A777878777D7D777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777878777D7D777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A775641
776C61776A5D776A63776A62776A62776A6077706B776E6674665D7360566D584F745C4F
745F546D524C745E516449426C4C456C5F57654F426E51456E5346624F436E5E508DA9B6
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A775843
776A5D776A64776A5D776A63776A62777068776A62776961776E6674665D78675B715F51
735C56715A4F6F5B4D694D486857486B5547695951674F42665145645145807D7C859BA4
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777373777C7C777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A61483E7F6652
776A64776A5D776A5B776A66777068776A62776E66776E6677706877655E776A60746053
785E54715C4E715C506D504C6D5546684E42645448644D406E514565514585949F7D8A8C
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777878777D7D777A7A777A7A777373
777575777C7C777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A29221C896754857665
776A66776A60776A63776A6477726A77655E776B5C776F6977675F77675F776A5B776859
705551705B4E7357516A5644674E42675549695044655145705E506955488BA7B47B8080
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777878
777B7B777D7D777A7A777A7A
777A7A777A7A777373777C7C777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A5B535A0A0504D5AB997B6C5E
77706D776860777068776860776B63776E66776E65776A64776759775657705B4B6B5549
72584E735D4F6C5C516452436F524868574B644E3D645146695447664F438CAAB7777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777878777676777C7C777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A7F8181100B087B6551BFA088776A62
776B6677675F776B6377675F776A62776B63776F6777655E706353725351705D4C6A564A
725B4E6E594C6C59476550456E4F43675144694F426C51476551456E574B85898D7A8284
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777373777A7A777D7D777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A170F0A746357B695877B6C5E776A66
776A62776A62776A5B776A63776A62777068776A6277675F6D39377342416C3B376C3C39
6F3E3B6F5C4C674F42674F446B493E6453416D51466B514562513F704C4269594E859BA3
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777373
777C7C777A7A777A7A777A7A
777A7A777A7A777878777D7D777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A5B53544D423BBB9A8C77675F776A59776A66
776A6277635577655677655A776B65776B63775453775B586D34346C3E34642E26724441
673B327248425E433A664F4266513F644D417053486B51456951446E4940695B4D756459
7F8D92777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777878
777D7D777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A0E0B0AAB87707D6B5C776A5D776A5B776A66
776A5B705B4E725A4F7A7062776C68775D4F70393B6B3B32634840532B1F6E6657765E56
5E271F693029674036654A406758486749356955446D51466B51456B50446B55486B574A
8A979B777E80777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777373777C7C777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A42383937291EC9A38A7B6C67705D507A746E776863
775D4E66504067443C826968693433270C0788625B6C433A74685E757A757639315D4437
4F3325604F48462E22723129605544694C346E4E466E594D735C49684F446B574B6B5145
7261557F8483777E80777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777373777C7C777878777D7D777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A0D0A09AA866C8F7E76776A5D6D53477D767177675F
775A4B5D3B2C613E35350F0D747770646F69A5A59E79797D7C81827B837E6B473A748783
6F6B67585455341E17371E12713F2F6F5E47704B44736355735B4D6D56476850456B4F43
6B594C72839E777A797A7E7E777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777878777D7D777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A615F6D020201DFAF907D6E63776A5B7464597B726D776A62
6943364C362454241D240C08AD7869836B5A72544D7A807E77625277685866453D78797A
694639706A63523A2F514C44391D16793F2F6E534878655077675B6D56496550476B4A3E
6B5447647372645D557071817F827E777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A29221C180E0D573A2ECDAB8E7B6C5F775D51776054776D62776A5D
643D3366594A78675E6F6D61A57A787462566C514B715E55753D39634A42642E2A6C342D
602F27716E5E5833295A42433A2D273B0E06885D527B6850796A606A5241654C42644E42
6D5A4C696256808790635F728C9288777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777373777C7C777A7A777A7A777A7A777A7A777A7A
777A7A777A7A6159600102011A100DEAB5A18D7F6B776357775556706A5A7A7063775657
64473A5A413089837C7B736B77625F746A60757269796C647C685B6C5D4F755A4E6E5A47
6E5A4E6C584871353560352F4B261B38130E6B291E816B567C665B6A5341654B42624B3F
7054476B584B251E1996949B7E7F7A7A7E7E777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777878777D7D777A7A777A7A777A7A777A7A777A7A
777A7A777A7A5A56654B44308D6759BF9D857A6B5C77625677685F745C587B726177645C
645041604238897E717A6F68776E66776860776B63776E667755526D5649735D516A5648
6F52485E4D3C69484061523E604A3F614C426949477E66447A64586C5744654B4262503E
7054486B594C151C1DAFA29D7F85877B8080777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A6F584B826A58746B6471675976675B7A6A5D776C6777646177786B776861
6B564A6A4C416D51447B74677A746D776C6477686077726A7760546D584A6C4B406C5A48
614C3C54493E654536624438624838624338604738745F4C7961576F53465E463D644C3F
695342665347090E0FC3B6CA8B9290777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A706D6D7A5B46705D536B55435D60668267567B6E6877706B776E66777068776C64
74524F6E584A6A4A3F7D6E607D736F776F67775251706A597A695A664C426C4E43614134
6152465C3E3566483663483E6A51386146396345337E625673574A674D425E483D674D41
6755476E574C000508C1A7A08B928D777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A745C4B7B6458664D42644F4274736B885B5577726A77726A776E66776E66776E66
776054745F4F675141725347807C7677726A77605B7470637B6C656B504A6D564963483E
6C574A5C3C32634639634A3F6C50426C4C4275594C7A6458674E42674F43695044654B40
6755426953470006074A342DB8B2B5777C7C777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A7758437063595232247B74678262627B6C5F77726877726A777573776C62776E66
77655C776659644F436F56477B796D7A6D6777675977706A7768606D584B62493C674D42
64514562473C684E376144396C5145795A527A66586D5A4D65564A6B5548645044645044
6754456E5E52322C1F3E231C3E312CA6A9A9777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
775F54693D2E5D2D285B4539717D75856A5F77725F776A6677726A777069776B61776E66
77655E7063536D584D746A5B7E74687B6C6170564F7A716377545466523D624138644C41
5D473B694C35533C316543397461527960537963556A564A6553476B4D42694F4365513F
6E4B416E62545D413557433D85A4ADB8B9BA777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
77474064372F5C312C6763517E7C6D88706877706977686377726A776E66776E6677675F
7767596D62537B5E52716A5D7D6E6877706974625E7B726777584E6454435E433B5D473B
5A42366146375E463D785E507A6456736255795F536A564A6552466B4E426B4B45694C44
674B406D655D5B392A694F4498BBC8747878777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A77655A
775244644236563D2D7067568B80717B6C6877726A776C64776A627769617063547A695C
7756556D605176584E7065587D706B776B5C776761776A6277535064483B5C463B5E463A
61483C5D4F436F5643745D51765D507761556F574B6C51456553476B483D6B4B41644D41
64543F70635E66413368574C72808B7E8483777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A69432E
58382D37281F53392D867567877C6D776A66776B637769617767597763576D6355765A55
6B564D725F5573685A73695C7D7065776A62776A64776A62705E52664A3C5C483D5E463A
63493D6850446D5547795953735D4F725B4E6C5D516F564A6554486B5247645144644B40
674E4770625D5D2A1C6D695B65423990A7AB777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A5D2918
1D140E3A2923352320A68671837770776A64776A5B776A5D776A62776861746A63786762
6E58506F514B67574778665976695C7A6B68776A62776A5B6D554E624539583D3D604835
5D43386F51456E5B4D7151466A584A72554E6750436A5448614D42665144644F4367493E
674D486958485535226A5644663B3790BCC7777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A776D66613428
2F261F31231C322220C1947983776A7063577A6B63776A5C61504768574A543F355B4439
59413B603E3C6C554470554871635680726D776A62776A606D514D5F473A594134634531
5B493F6A4C3F5E51445D4A3F6B5447705D51614D406D594C69544865504467514567493E
674D486755453E241A4E251B70463593BECA777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A70503F66423C
08050316110F281C19D6A183796E607763577B6E63776A5B68564C53443A44362C2F2B29
28201E4226196444344D261C512B208D7E6E7A6D67776A626D584B5F463A5943325D4D38
553E3572584B6D5A4D6E574A725245674D4757493C755A4D6B5549624E425A4B3F5E4B3F
6C54486754453C241C54291E7B433396C5D4777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A7F8181724835603F37
090F101C1310311915E4B3937B6F627364587A6E61776A5D74666156453A765F5822231F
1E1310361C13463A366336297C5F5095907D7D77737776736D5C4C5F42394C382D58412F
2B0D097A584760452E503D34412E23664D415A4E41745643665146644F435644395F4E42
724E485A473A311E1A5935288050479CCFD9747878777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777575777C7C777373777C7C777A7A777A7A777A7A777A7A777A7A100604965743665348
1A191814141922140FE8B89876675B776A5D7366597265597A6B68685B4C73584D423E34
624E4363432F694B38885F488664567D72637D78747770696D55455F4238553B2C574034
40271F615752302B27090506492A21453C32271C15573D344D36266D4736584C425F4F43
724D42433B2F231915462A2196695898C1CB717575777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777676777F7F777878777D7D777A7A777A7A777A7A777A7A1209080F0907310904432C23
0D0C1113110E2B1813EDB9987366597D6E685F3E39695648827570746E6575635D6C5650
674D406552456F52467E66527E6259776B5D7D7B76776E666D4F485F5044593F2F584E39
6340316C5E53543D3207080A462217392C29231B1868402F6845367E5F4A5F493F5D4E42
7254411D1918231A133C21189B4A3792BBC8747777777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777B7B777D7D777A7A777A7A777A7A777A7A777A7A777A7A0000003022182A15122D211C
0C090A2C1914311814E4AD8E7B675B73675C725F5A645849563D335D483B4D3D323D2D28
37241D432F234E31265334277A695B786E607D726E77695A6D4F455F5648593D32614433
5F4D396F5949634D4340413B775240583B2E53382B895A4779563C635448695040665448
5F4D4011110F2316124021188A34259BD2DD777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A0200001D0F0B1913101F1410
1C120F1E1511372823C79477826D60746C5F7B6C686F625A695C4F65494444413F6F4D45
5B4134674F406142357D5B4D8F877682746E7B6C677756536D5D4F5F54485938383D2419
462C206E59406C53446751416A4E44604D3C5E4E43795C485D4D40674D4A5F4E406C5342
433930080A0919130F975B46632B1FA8DBE6777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777373777C7C777A7A777A7A777A7A777A7A0703011C0D0A1E15111B1410
0E07072215103B2A26A271598971627A7062776A66777068746D637064606E716A8D7A6E
7671677D786F7A716A8977677870627D757070625372605570635267574D6C564E564739
3A252436271D2B1E1767413472584C64513E6350415F4D4160453B5443386C4F476D4E40
1D18140E0D0C2A231E914733462016323533A3A4A4777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777878777D7D777A7A777A7A777A7A777A7A0504032018151E14101F1410
150F0B2516113A2A269C664F9178687D7265776A6677726A776E6677757377736F77736F
776C62777573776C62776C627466597B6E63746557715E5273584E7162557463566F5752
544B48634B4240352E3E261C2E2118462B2339342C4831264A312671544D74514460473A
0B0C0C19110E261A1A32100B3D160F2B302EDEDEDF777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A07060536272315110E211410
1E141027191A392A24805641876E5E827668776A5F776B65776F6777706977747177726E
77706A77757377695E776E66776C6277685A776A5D6D5A4F736054735D51736457735955
675C4E66534755483D55483C5646395A3B2E503C2E744B3C6453467A4C4B5C4F3F4E4035
0B0C0C1D130F1B1410170F0A2F1A153B3531DBDBDC777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A0905032D1F171E181520130F
250F0B2A1915362419543B2F8F67568578687A6B5F776A6677726A777573776E66777471
77726E77726E77695E776E6677675977675F7763566D554A736457736054735D51735B51
6A57496D5145665246614E436B5549644E426C554875524669514A6B4A405F4B3B35271E
120F0E1D130F29181419130F24151139251BA28B8E878D8C777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A050301322926221A17261613
160F0B22151121141044291F6E462F957E6E7D7062776A6677726A77777677706A776E66
777471776B61776B61776E66776556776A5F705B4E705E52735D51735C51735B4F735D51
6A564A675246675549695A4D6750446B4F436551455A493E5E4D425E4D3F483B30161615
0E0C09241819170F10150F0B0F0707311B167B5F5AA7B2B2777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A0704012F26232C221E261A17
2417132014102A1D19402F294D382CA07664827163776B68776B6377716B77747177706A
77757377695E776E66776E6677655C706356705B50735B4F735B4F735D516C5D516E574B
6C574B6552466B55496B574A69524667504464514556493E6D4D415B473B31272115100F
231A16130B0B160F0F0F07071810102716116C554FBAC3C6777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A0706043128253428242D221F
261612140F0B2D1A1542291E5C3B2B90573F8776687A7064776A63776B6377716B777471
77726E77706A776C62776E6677655E746858715C516C594E6E574B7659536A594B6F5145
6F554E6553466B55496B4F43645144644F4360453A654C415F42363B332D241B151C1311
150F0B140E0F140B0B17100B1911112E1914DCD8D7A3A7A8777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777373706F6F0506052F24203529252D231F
1B110E261C182C1D1930231E643E2D7B5141867668807466776A66777068777068777776
77726E77726E77695E776E66705F517A65566D554A715B4F745C506F584D6C594B6F5246
675B5067544664494366514364514567514565483D5D4F434D3A2F4132281F1913211513
17130F1C14101B141018100B1C14112F1915FFFFFF747878777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A7778787479790204033C251C2F2521342824
2B211E281C182D211C3321185A463A5E3D2F8764547E75667A6B68776B63776F67777069
776D64776D6477645B706354705B4D76675B70554B6C57456E594E6C57456F594E6F584C
6555496B5347694D42655445674B3F674C415A4B3F4D42364631262A1E1C1A131017120F
150F0B171010130B0B0A0707150C0C492A24ECF0F1747777777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A050504312016322A27352925
281E1A241612342219312521473A2F45261E8256458780707D6E63776A5D776B6577695A
77695C77695C776761746858715C51735C516C4D426C53456F55506F5B4C6F594F6F4D42
6555486B4F436B4F4362514567493E60473B4B43374632272A1D1C241B1519110E181310
201410171010130B0B130B0B301A15E7DCD8AFB7B8777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A110F0D28201C3126223A2925
2B1E15291F1B281C183226232D211C3627246C45338267507D70637265597A6B60776A5B
776A5D70635772655A7A6B5C6D53496C4F446C5745674E436A574B6A5748725548674C41
6753466B494364534564513F60443A5A473B453D3133201B221B151A120E130E0B171010
221410150F100F0707140C0C321B16F6F7F7747777777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A16130E28211E342824312420
2D231E201617271B172F221D35292531201743271D6C513F795E51735A4E786659726054
72675A706357735F5376635669554A64493E6A5244674D436B4C416B52466E5144674F43
644B3F664B415D493B5C483B4E403647342941302520181318110E17120F160F0B130B0C
150C0B0A07070B0707301B163A1F15EFF3F5777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A383337241B193228242D231F
3B2E2A2B1D15271713392D282B201C352824261B174B3C3045322A643F32786152624E42
6B5C56695750695649715E525E493E49362C5A3F33664533684D43664E42664135664F43
644B3460473D5A4236553F334A3F3338241F301D151B14111B120F160F0B130B0B130B0B
0F07070B0707150C0C281611C0B4B2BBC3C6777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A6A6B6E18150F241D1A2F2420
322521231D1920161737241A2D23203E302C2F25223527223B2D2951342A553A2C3F3634
3E38315035285746385643383D2F2A402D22452E23553A285B392E5B4230674332554236
4C342754352C533B3041352F3A28212C1A1423151219120F150F0B120B0B0F07070B0707
0B07070B07072016112E1A15F8F3F47B8080777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A2321251F1A17372A26
2F28242E231F17110E33241D3C302D3B2E2A3C312C3B312C46392F45362C3B3128332625
3422193A231F432A214230282C222135262240271F41291B40272150392A4C34283E2D23
473227402A1F41322A37251E3020191F1412241B18130F0A160F0B130B0B0F07070B0707
0C07072515111911117E5C55D7DDDE777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A53515A18130F2F2420
2E24203023202A221E3C2C283E302C3D322D32272333282439231F42282033221A2B2220
241A163125222616123127232B221F291F1B271612251C172517142D18142E20182C1E17
2E201826151229171423161224171316120F16100B110A0B140B0B130B0B0B07070B0707
25151A251510332723E6D9D598A1A2777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A727476282826221C19
3024203529252F2420423530281E1A3C2F2B251C19362A254732283228242B231F2D2421
281E1A402C281D14152A241E2716132617131D120F1A141020130F2A18142819141D130F
1F13101E130F2918141D13101F1410140F0B170F0B130B0B140B0B0B07070B0707150C0C
33201B281813CCCCCBB8B9BA777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A4E484E18100D
3329253529252D231F28211C372B274335302924212C201C3F261C1F19162B201B2B201C
1C161B2C221D1E15162A19141E12171A140F1A1310160F0B1D14101C14101B1410150F0B
130B0B18100B231510150F0B130B0B17100B181010130B0B0B0707140B0B1E15102E1E1A
2E1A15C0BFC0C0C2C2777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A6F70721B1814
28211E3529252D231F332824342B27352925251D19251A162A1C181A120F2F231E221717
21171821140F1F1318160F0F120B0B17100F171010130B0B191011130B0B181010130B0B
1810101D1510181010120B0B0B07070C08070B07080B070718101019100B140C0C24110C
BBB1B2C2C6C6777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A585B5A
2B2724251D192F2420312A262E28243C2D292B2222251612281C1818120F23151119130F
201410110B0B130B0C17100F171010140B0B181010130B0B191111130B0B2E1A15090707
1A11111D1510160F100A07070B07071007071911111810101A11112C19143322196D4432
DEE6EB7B8080777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
585B5A2A221F2B27232A1F1B3C2F2B3B2D29352B28221D182D211D1B1217170F0F211410
170F101A13101C1410181010130B0B130B0B140C0C130B0B140C0C1C14101A11112A2B37
312C2B1F1317120B0B1710101D15101D141019101132231E281C182C1914553328C0C2C4
9BAAB1777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A5E5E5E2A24213229252B201C30292540332E312926301F16231A1718130F181010
120B0B19100B171010130B0B130B0B181010130B0B181010130B0B150C0C322E2F2C1E2A
44362C3A2D2A2B22223F312C2B201B19130F2A1D192D1E19372A26472820C2BBBBA6B5B9
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A7A7C7C5456552A1E18352F2B3429254335303A302B392F2A211916251B17332622
26201B20130F1B1410170F10181010140B0B130B0B1E151A170F0F1D14101A12122A201C
382922130D0E18120F1B1410140E0E1E130F2D1E1A332118613E2E928691B2BFC0777D7D
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A5555522D2A24221B18382B274B3D39453F3B322A26231916241819
26171331242125201C150E0F130B0B22191E21181D2D241E1E171B3D2D271712174F3D34
30232429211E3326212C201C32252246372B302521684130B5B1B597A5AE828986777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A55595658555E322A25362A25372D2939383F40342F463B37
4A423C2E23242828293E36424B423B3124252B252F3526243F3846392A2228201E47352E
33252238241F38241B32282548352A61402F2C1E18C8C4C29BA8AF777D7D777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A6D6E705E66622F282D3B312B32343C5B4C48464141
423D383C36344B474852413D463A322C24223D332F2E22212D221D2E221C392D29352925
45271F472C24453329503E3641271E604C4E8B9C9FB1B9BD777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777575777C7C777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A55595C7F857F7274803E373F5A4C49
69626E574B49503F3B443A35463C3850404155453F413A3757453E443A3150423F56443F
46382F453B3332262386757F88919090999E9BA4A2777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777B7B777D7D777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A7274765C64668F8E87
888D9169666F7F7D775F5D6B403E474F4752453A32433B374B3E39413A35433936402F26
393229A9A4A87C8286A4A6A989928E777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A7274787E817B6D717569716F82868480827A838181838A8A838888818686828583
858D8EAAABAF777D7D777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A777A7A
777A7A777A7A777A7A777A7A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?oooeUgNWX4KE4m17e^H@=gJVH4Mg9Z17MUGPAgLVX;MfiV17MU
GPAgJUT4KF9F17=NDPAZDTL4KeU=0fEBAQ1[EDT4Jdi20f9A?PAWDDP4Ie4n16MAB0B@[KX?MgYj17Ma
L@AgOglSMgYj5Oooo`005?oooeUgNWX4KE4m17e^H@=gJVH4Mg9Z17MUGPAgLVX;MfiV17MUGPAgJUT4
KF9F17=NDPAZDTL4KeU=0fEBAQ1[EDT4Jdi20f9A?PAWDDP4Ie4n16MAB0B@[KX?MgYj17MaL@AgOglS
MgYj5Oooo`005?oooeUgNWX4KE4m17e^H@=gJVH4Mg9Z17MUGPAgLVX;MfiV17MUGPAgJUT4KF9F17=N
DPAZDTL4KeU=0fEBAQ1[EDT4Jdi20f9A?PAWDDP4Ie4n16MAB0B@[KX?MgYj17MaL@AgOglSMgYj5Ooo
o`005?ooo`AgNWX4Mg=c17MlO0AgNWX4Mg=c0gMlO2=gNWX4Mg=c17MlO1MgNWX4M5I117]/I`=gJUd4
Mg9/17MUGPAgLVX4MfiV17MWF@=`HeH4LV=F179OD@AYF4d4IeA916M?A0AZEDP3HDe216eGBPQ[EDT8
Jdm30f9AA0AWDDL4Ie4n16M[KPB@Y:h?MgYj17MhN0AgOGdSMgYj5Oooo`005?ooo`AgNWX4Mg=c17Ml
O0AgNWX4Mg=c0gMlO2=gNWX4Mg=c17MlO1MgNWX4M5I117]/I`=gJUd4Mg9/17MUGPAgLVX4MfiV17MW
F@=`HeH4LV=F179OD@AYF4d4IeA916M?A0AZEDP3HDe216eGBPQ[EDT8Jdm30f9AA0AWDDL4Ie4n16M[
KPB@Y:h?MgYj17MhN0AgOGdSMgYj5Oooo`005?ooo`AgNWX4Mg=c17MlO0AgNWX4Mg=c0gMlO2=gNWX4
Mg=c17MlO1MgNWX4M5I117]/I`=gJUd4Mg9/17MUGPAgLVX4MfiV17MWF@=`HeH4LV=F179OD@AYF4d4
IeA916M?A0AZEDP3HDe216eGBPQ[EDT8Jdm30f9AA0AWDDL4Ie4n16M[KPB@Y:h?MgYj17MhN0AgOGdS
MgYj5Oooo`005?ooo`AgNWX4Mg=c17MlO0AgNWX4Mg=c0gMlO2=gNWX4Mg=c17MlO1MgNWX4M5I117]/
I`=gJUd4Mg9/17MUGPAgLVX4MfiV17MWF@=`HeH4LV=F179OD@AYF4d4IeA916M?A0AZEDP3HDe216eG
BPQ[EDT8Jdm30f9AA0AWDDL4Ie4n16M[KPB@Y:h?MgYj17MhN0AgOGdSMgYj5Oooo`005?ooo`AgNWX4
MgQh17MfMPAgO7`4MgQh0gMmO@AgNWX4Mg=c17MlO0AgLg<4Mgal3gMjNPAgN7P4Mgem5gMjNPA`DSh4
NV]P0gMZHPAgJfH4MfiV17MZHPAgJF44L65A0e]ME`AcFTh4KTi916ABA@AWFD`4JeQ<16]JC@=YDTL4
Ie5526IAA0AVCd<4IU4o0fAAAPAWDDD4Ie5418JP[PB6S8hCMgYj17McL`AgO7`OMgYj5Oooo`005?oo
o`AgNWX4MgQh17MfMPAgO7`4MgQh0gMmO@AgNWX4Mg=c17MlO0AgLg<4Mgal3gMjNPAgN7P4Mgem5gMj
NPA`DSh4NV]P0gMZHPAgJfH4MfiV17MZHPAgJF44L65A0e]ME`AcFTh4KTi916ABA@AWFD`4JeQ<16]J
C@=YDTL4Ie5526IAA0AVCd<4IU4o0fAAAPAWDDD4Ie5418JP[PB6S8hCMgYj17McL`AgO7`OMgYj5Ooo
o`005?ooo`AgNWX4MgQh17MfMPAgO7`4MgQh0gMmO@AgNWX4Mg=c17MlO0AgLg<4Mgal3gMjNPAgN7P4
Mgem5gMjNPA`DSh4NV]P0gMZHPAgJfH4MfiV17MZHPAgJF44L65A0e]ME`AcFTh4KTi916ABA@AWFD`4
JeQ<16]JC@=YDTL4Ie5526IAA0AVCd<4IU4o0fAAAPAWDDD4Ie5418JP[PB6S8hCMgYj17McL`AgO7`O
MgYj5Oooo`005?ooo`AgNWX4MgQh17MfMPAgO7`4MgQh0gMmO@AgNWX4Mg=c17MlO0AgLg<4Mgal3gMj
NPAgN7P4Mgem5gMjNPA`DSh4NV]P0gMZHPAgJfH4MfiV17MZHPAgJF44L65A0e]ME`AcFTh4KTi916AB
A@AWFD`4JeQ<16]JC@=YDTL4Ie5526IAA0AVCd<4IU4o0fAAAPAWDDD4Ie5418JP[PB6S8hCMgYj17Mc
L`AgO7`OMgYj5Oooo`005?ooo`QgNWX4Mg5a17MoO`]gNWX4MgQh17MmO@AgN7P4Mgem;WMjNPAdDCd4
NfiX0gMZI0AgJV84Mf]S17MWG`AgJU/4M6QP0g1YH`AiHe<4O5MI16QHB0A`EDT4L5E>171EC@=XAd44
HU5336MAA@AWDD@3KUM<16E@A0AWDDD4T:fj5gMjNPAgN7P4Mgem7gMjNQGoool001Coool8MgYj17Ma
L@AgOgl;MgYj17MhN0AgOGd4MgQh17MmOBigNWX4M54m17]^J0=gJV@4MfYR17M[H`AgIel4MfYK17AX
H0=`JF<4NF=C17aGF@AXF4P4L5E9171ECPA`EDd3J4M1169A@`aWDDD4Ie540fiGC0AUD4@4Ie55192]
^QMgNWX4MgQh17MmOAmgNWXEoooo000Doooo27MjNPAgLG44Mgmo2gMjNPAgN7P4Mgem17MhN0AgOGd^
MgYj17AA?@AkKVP3MfYT17MZHPAgJf<4MfMO17MZF`AdJ603L6US17USD`AlEeT4J5Q8171EB@A`EDh4
L5E=0fQ7@@ARDD<<Ie5516MAA0=^Ed`4IE1416MAA@B@[KXGMgYj17MhN0AgOGdOMgYj5Oooo`005?oo
o`QgNWX4Mg5a17MoO`]gNWX4MgQh17MmO@AgN7P4Mgem;WMjNPAdDCd4NfiX0gMZI0AgJV84Mf]S17MW
G`AgJU/4M6QP0g1YH`AiHe<4O5MI16QHB0A`EDT4L5E>171EC@=XAd44HU5336MAA@AWDD@3KUM<16E@
A0AWDDD4T:fj5gMjNPAgN7P4Mgem7gMjNQGoool001Coool8MgYj17MhN0AgOGe9MgYj17MF@@AgK643
MfYM17MZH`QgJV84MfYP17M`J`=gKVH4M6IM17=PEPA]F4l4M5a?17AOE0A]DT`3M5iA16A9@PA/C4D4
K5mG16E?@PA^DDD3KU=6169?@`A^GU04SJVf?WMjNQGoool001Coool8MgYj17MhN0AgOGe9MgYj17MF
@@AgK643MfYM17MZH`QgJV84MfYP17M`J`=gKVH4M6IM17=PEPA]F4l4M5a?17AOE0A]DT`3M5iA16A9
@PA/C4D4K5mG16E?@PA^DDD3KU=6169?@`A^GU04SJVf?WMjNQGoool001Coool8MgYj17MhN0AgOGe9
MgYj17MF@@AgK643MfYM17MZH`QgJV84MfYP17M`J`=gKVH4M6IM17=PEPA]F4l4M5a?17AOE0A]DT`3
M5iA16A9@PA/C4D4K5mG16E?@PA^DDD3KU=6169?@`A^GU04SJVf?WMjNQGoool001Coool8MgYj17Mh
N0AgOGe9MgYj17MF@@AgK643MfYM17MZH`QgJV84MfYP17M`J`=gKVH4M6IM17=PEPA]F4l4M5a?17AO
E0A]DT`3M5iA16A9@PA/C4D4K5mG16E?@PA^DDD3KU=6169?@`A^GU04SJVf?WMjNQGoool001CooomI
MgYj17MH@`AgJUd3MfYT17MZG@AgJV<4MfYR17M`J0AgJV83MfUQ17M^IPAdIUd4N6MK175OD@AcG5H4
LEY?0fmKC@AYCDP4J5M816]EA`AYFE44Idm20fIAA@ATDDD4P7el18FKY1]gNWX4Mg=c17MlO1]gNWXE
oooo000DooooFGMjNPAgF4<4MfYM0gMZI0AgJUd4MfYS17MZHPAgL6P4MfYR0gMYH@AgKVH4M6IM17QW
F`AaGe44LeaF175JC`=_Fdd4JDe816QGB0A[EDL4JEUA16M?@P=VDDD4I555181mO0B5Vj@KMgYj17Mc
L`AgO7`KMgYj5Oooo`005?oooeUgNWX4MeQ317MZG@=gJV@4MfYM17MZH`AgJV84Mg1X17MZHP=gJF44
MfiV17AVG@AhIe/4LEmA17=LEPAaFTl3Ke]=16U=B0AXEdP4JeE716UID@AWCd83IU5516AAA@B0OG`4
QI^T6gMjNPAgLg<4Mgal6gMjNQGoool001CooomEMgYj1658?PAoIU84MfYT0gMZG@AgJU/4MfYV17M`
J0AgJV87MfiV17M`J0AgIEh4MfYP17APD`AhGU@4LEa>0g5LD0A]D4`4KEE616Q>@PATE4P4I4e00fiA
A@AUDDD4QIBO17f:S1]gNWX4MgQh17MmO@MgNWX4Mg=c17MeM@AgO7`8MgYj5Oooo`005?oooeEgNWX4
HDPn17mVDPAgJV@3MfYM17MZF`AgJVH4Mg1X17MZHPMgKVH4Mg1X17MUGPAgJV04M61C17QNE0AaG4h3
LEa@16e@C0A]EDH4J4i216ADB0ATCD03KU5516EAA@B5U9l4OHZ<6gMjNPAgN7P4Mgem1gMjNPAgLg<4
MgEe17MlO0QgNWXEoooo000DooooEGMjNPAQB3h4OfIB17MZI0=gJUd4MfYK17MZIPAgL6P4MfYR1gM^
IPAgL6P4MfEN17MZH0AdH5<4N5iD175LCP=aG504KE1<16eEAPAXCT84I5A816A=@0=^DDD4IE5518FD
W`AmRX`KMgYj17MhN0AgOGd7MgYj17McL`AgMGD4Mgal27MjNQGoool001CooomEMgYj1658?PAoIU84
MfYT0gMZG@AgJU/4MfYV17M`J0AgJV87MfiV17M`J0AgIEh4MfYP17APD`AhGU@4LEa>0g5LD0A]D4`4
KEE616Q>@PATE4P4I4e00fiAA@AUDDD4QIBO17f:S1]gNWX4MgQh17MmO@MgNWX4Mg=c17MeM@AgO7`8
MgYj5Oooo`005?oooe5gNWX4:B8L18UWE0B5MVD4MfYV0gMZH0AgJV<4MfYT17MbJPAgIEh4Mf]L0gM_
J@QgIel4MfYK17MXF@A`EE44L5]>0g=GD@AZET@4Idi216MEB@AYD4@4IE550g1ND0AYEDP4RjNd17^0
P2YgNWX4MgQh17MkN`AgOGd8MgYj5Oooo`005?oooe5gNWX4:B8L18UWE0B5MVD4MfYV0gMZH0AgJV<4
MfYT17MbJPAgIEh4Mf]L0gM_J@QgIel4MfYK17MXF@A`EE44L5]>0g=GD@AZET@4Idi216MEB@AYD4@4
IE550g1ND0AYEDP4RjNd17^0P2YgNWX4MgQh17MkN`AgOGd8MgYj5Oooo`005?oooe5gNWX4:B8L18UW
E0B5MVD4MfYV0gMZH0AgJV<4MfYT17MbJPAgIEh4Mf]L0gM_J@QgIel4MfYK17MXF@A`EE44L5]>0g=G
D@AZET@4Idi216MEB@AYD4@4IE550g1ND0AYEDP4RjNd17^0P2YgNWX4MgQh17MkN`AgOGd8MgYj5Ooo
o`005?oooe5gNWX4:B8L18UWE0B5MVD4MfYV0gMZH0AgJV<4MfYT17MbJPAgIEh4Mf]L0gM_J@QgIel4
MfYK17MXF@A`EE44L5]>0g=GD@AZET@4Idi216MEB@AYD4@4IE550g1ND0AYEDP4RjNd17^0P2YgNWX4
MgQh17MkN`AgOGd8MgYj5Oooo`005?ooo`QgNWX4Mg=c17MlO3egNWX4Fe=J10X510CEZiT4NfaN17M`
K@=gJ604Mg1X17MXH0AgJf<4MfiV17M^I@=gJV@4MfMI17MFE`A`Fd/4JeE9179HCPAcGDl3K5aA16AB
@`A_DTP4J5M;16A>?@ATDDH3JEA716I?@`B<Z[M2MgYj5Oooo`005?ooo`QgNWX4Mg=c17MlO3egNWX4
Fe=J10X510CEZiT4NfaN17M`K@=gJ604Mg1X17MXH0AgJf<4MfiV17M^I@=gJV@4MfMI17MFE`A`Fd/4
JeE9179HCPAcGDl3K5aA16AB@`A_DTP4J5M;16A>?@ATDDH3JEA716I?@`B<Z[M2MgYj5Oooo`005?oo
o`QgNWX4Mg=c17MlO3egNWX4Fe=J10X510CEZiT4NfaN17M`K@=gJ604Mg1X17MXH0AgJf<4MfiV17M^
I@=gJV@4MfMI17MFE`A`Fd/4JeE9179HCPAcGDl3K5aA16AB@`A_DTP4J5M;16A>?@ATDDH3JEA716I?
@`B<Z[M2MgYj5Oooo`005?ooo`QgNWX4Mg=c17MlO3egNWX4Fe=J10X510CEZiT4NfaN17M`K@=gJ604
Mg1X17MXH0AgJf<4MfiV17M^I@=gJV@4MfMI17MFE`A`Fd/4JeE9179HCPAcGDl3K5aA16AB@`A_DTP4
J5M;16A>?@ATDDH3JEA716I?@`B<Z[M2MgYj5Oooo`005?ooo`QgNWX4MgQh17MfMPAgO7`eMgYj17n1
P@@@2`P4NfEA1;nPR0AgJV84Mf]V0gMWG`AgJf<4MfMO17MZHPAgJf<4MfmW0gMUGPA`He<4LU=A171M
C0AZETX4LU]>16iIC0=/FDL4IE1516i?@`AWDD@4JDm216aAA`=UDDD4KUM;18F9S@AjPX@nMgYj5Ooo
o`005?ooo`QgNWX4MgQh17MfMPAgO7`eMgYj17n1P@@@2`P4NfEA1;nPR0AgJV84Mf]V0gMWG`AgJf<4
MfMO17MZHPAgJf<4MfmW0gMUGPA`He<4LU=A171MC0AZETX4LU]>16iIC0=/FDL4IE1516i?@`AWDD@4
JDm216aAA`=UDDD4KUM;18F9S@AjPX@nMgYj5Oooo`005?ooo`QgNWX4MgQh17MfMPAgO7`eMgYj17n1
P@@@2`P4NfEA1;nPR0AgJV84Mf]V0gMWG`AgJf<4MfMO17MZHPAgJf<4MfmW0gMUGPA`He<4LU=A171M
C0AZETX4LU]>16iIC0=/FDL4IE1516i?@`AWDD@4JDm216aAA`=UDDD4KUM;18F9S@AjPX@nMgYj5Ooo
o`005?ooo`QgNWX4MgQh17MfMPAgO7`eMgYj17n1P@@@2`P4NfEA1;nPR0AgJV84Mf]V0gMWG`AgJf<4
MfMO17MZHPAgJf<4MfmW0gMUGPA`He<4LU=A171MC0AZETX4LU]>16iIC0=/FDL4IE1516i?@`AWDD@4
JDm216aAA`=UDDD4KUM;18F9S@AjPX@nMgYj5Oooo`005?ooo`QgNWX4Mg=c17MjNPAgOGdeMgYj11L?
2PAdHeL4]YF717]/GPAgJVH7MfYR17MZF`AgJV<4MfYR17M`J0AgJV83MfMO16di=`Ac@T44K3/g16`l
>@A_?S/4Kea<0fM?@PAWCd@4JdTn16AC@@A]DDH4Je550f9A?`A`C484JEU>18FKXbYgNWX4Mg=c17Ml
O0agNWXEoooo000Doooo27MjNPAgLg<4MgYj17MmOCEgNWX45`l:17ASE`BfUHL4NfaN17MZIPMgJV84
MfYK17MZH`AgJV84Mg1X17MZHP=gIel4KCTg17=2@@A/>cL4K3`i16ln>`A_G4`3Idm216M?A0A[BCh4
I5=116eAAPA[DDD3HU4o171<@PAYFDh4QI^S:WMjNPAgLg<4Mgal37MjNQGoool001Coool8MgYj17Mc
L`AgNWX4Mgem=GMjNP@G3`X4M6=G1;JEQ`AkK5h4MfYV1gMZHPAgJU/4MfYS17MZHPAgL6P4MfYR0gMW
G`A]>CL4Ld9116`k=`A/?3T4Kchk16mLC0=WCd84Idm416]9?PATDd44KE5616]AA@=RDCl4L4a216UI
CPB5Vj<ZMgYj17McL`AgO7`<MgYj5Oooo`005?ooo`QgNWX4Mg=c17MjNPAgOGdeMgYj11L?2PAdHeL4
]YF717]/GPAgJVH7MfYR17MZF`AgJV<4MfYR17M`J0AgJV83MfMO16di=`Ac@T44K3/g16`l>@A_?S/4
Kea<0fM?@PAWCd@4JdTn16AC@@A]DDH4Je550f9A?`A`C484JEU>18FKXbYgNWX4Mg=c17MlO0agNWXE
oooo000Doooo27MjNPAgN7P4Mgem=WMjNP=KDe@4CD8k1;^JS0AgIel4MfYI17MZIPAgJV83Mf=E17MU
EPAgIEX4Mf]U17M[H`AgE5<3Me]H16dd=0A/?S@4I2hV1794@@AW>c84LTQ20ei3>PAVCd84IU4o16A=
@@A`DdP4Je550fUAA0A^BD04JE]=17ETF@AoSI8VMgYj17MhN0AgOGd<MgYj5Oooo`005?ooo`QgNWX4
MgQh17MmOCIgNWX3Fe=D14e2>`BkVX`4MfMO17MZF@AgJVH4MfYR0gMSE@AgIEH4MfEJ17M[I@AgJf<4
MeAC0gMKF0A]=3@4K3hd16@^9PAbA444Ic/b1798@P=N@cX4ITm216IA?`ATCD44L5=816]AA@=YDD@4
KTU016UKC@AeI5T4OhfB9WMjNPAgN7P4Mgem37MjNQGoool001Coool8MgYj17MhN0AgOGdfMgYj0e]C
E0A=@S/4^iZ<17MWG`AgJUT4MfYV17MZHP=gHeD4MfEF17MUFPAgJfD4Mf]S17MDD`=gFeP4KC@d16`n
=0AT;RH4LTA116Lk<PAbB483GT<j16I?@PAVDCl4I4e1171CB0A[DDD3JE5416i9@0AYFdd4MFAI17n=
TRIgNWX4MgQh17MmO@agNWXEoooo000DooooAWMjNP<>2`X4ZhM`17e[G0AgJUd4MfYK17MZIPAgJU/3
L5]>179JC`AjL684MfaX17MMC`A`>C/3Jc/b16=8@0AC:al4KVIG17INEPAN9al4JC0Y0fM0=PAUBT04
IeQ816M9=@AYED@4KE560f]AA@A[D4@4JeE816]GBPB:Ui/4Mgj0=WMjNQGoool001Cooom6MgYj0`h;
2PB[Qg04OF]L17MZG@AgJU/4MfYV17MZF`=`Fdh4LUY?17Y`HPAgK6P4Mee?170i>`=[>c84HdQ015<[
7`A^IUL4MUiF15hW7`AY<2T3Id0f16E:@0AWF4P4IdTe16UEA0A]DDH3Je5516]@A0A[EDP4JeM:18ZG
V`AgOX0fMgYj5Oooo`005?ooodIgNWX33P/:1:^7L0AmJe`4MfYM17MZF`AgJVH4MfYK0g1KCPAbFTl4
NW1R17M/J0AgGDl4L3Tk0f/k<PASB404Db/O16iVE`AfGUH4GRLO16T`:@=W@3H4IDY016MHB0AWBCD4
JEE416eAAP=[DDD4Je1416]EB0A[EdX4RYNK17MnP3IgNWXEoooo000DooooAWMjNP<>2`X4ZhM`17e[
G0AgJUd4MfYK17MZIPAgJU/3L5]>179JC`AjL684MfaX17MMC`A`>C/3Jc/b16=8@0AC:al4KVIG17IN
EPAN9al4JC0Y0fM0=PAUBT04IeQ816M9=@AYED@4KE560f]AA@A[D4@4JeE816]GBPB:Ui/4Mgj0=WMj
NQGoool001Coool@MgYj17McL`=gO7`[MgYj148h>@<g:Ah4bJ>:17]/I`A`GE04NWA^17MXH`AgGDh3
IU1016M4?0B2JFP4JC@c12L<1`B8HU/3K4<j17AXGPAeNWD4MSTa15e4=`A?<bD4H4m80dH^8PAb<BT4
H5E416U<=0A^CTH4KUU=0g=LB@AXCd@4JeM;16]AA@AbHED4OhB317MnP39gNWXEoooo000Doooo47Mj
NPAgLg<3Mgal:gMjNPA2>3T3=bTN1<VSRPAkK6L4L5e@17YdKPAgJ6<4Mee>0fI@@0AWA3`4PVUX16Td
<`@W30L4R69K0fa3>PAdJ5h4MGYe17Hi<@AMA3L4Cc<U161?B0=6;R84LS4Y161EA0AYC3@4KTi616iI
C@=cG4T4J4m416]GB`A[DDD4LV5E17n4P`AgOX0bMgYj5Oooo`005?oooa1gNWX4Mg=c0gMlO2]gNWX4
@SPi0cLY7PC9XhX4NfaW171MD0AjM6h4MfQS17MMCP=VD404Id@l189YJ0AY=3<49``718QRF`=/@cX4
M6QN17EjM@Af>C44GD@g14lc9@APCdP3ARhR178a:@APED@4JD`d16i>APA^FDd3Lea916Q?A0A[Ed/4
Je55179QE@AoQ8<4Mgj0<WMjNQGoool001Coool@MgYj17McL`=gO7`[MgYj148h>@<g:Ah4bJ>:17]/
I`A`GE04NWA^17MXH`AgGDh3IU1016M4?0B2JFP4JC@c12L<1`B8HU/3K4<j17AXGPAeNWD4MSTa15e4
=`A?<bD4H4m80dH^8PAb<BT4H5E416U<=0A^CTH4KUU=0g=LB@AXCd@4JeM;16]AA@AbHED4OhB317Mn
P39gNWXEoooo000Doooo27MjNPAgLg<4Mgal17MhN0=gOGd[MgYj10d:2@>ZQV`4Sgif17MZG@A]DdL4
OGIa17MWG`AgFT/3GC//164n=@@e3`d4M7M`16A_J@BUYIh3NGUm17b1PPAkPgh4JdLj17B7P`A_JfL4
F5AE0c@N5`@g7Q84LCl_16mNA`A`Bd@4Lf=E0g=KC@A]ETL4J51516]?@`A[FD`4LX>N17MjN@=jOWh_
MgYj5Oooo`005?ooo`QgNWX4Mg=c17MlO0AgN7P3Mgem:gMjNP@=2PT3ZXI/18mnMPAgJUd4KE=717ef
L@AgIel4MeY;0edk;0AQ?SD4=@l=17AgL0ATKfT4YJFN0gUiO@AlPH84Nh=n16]7>PAdQh<4Kf]W15QD
E@<d7QL4=ahB174o;`A_GTL4L4]417=SE@=cFdd4KEI716Q@A@A[Cd<4JeU<17:3WPAgNWT3NWin;gMj
NQGoool001Coool8MgYj17McL`AgO7`4MgQh0gMmOB]gNWX43@X90jZ6K0B?OWH4MfYM16eCA`AmMW44
MfMO17MJB`=M>b`4HChe13D?3@AdMg04I6mY1:FUWP=iNGd4O86217^3OPA[AcX4M8N316m[I`AHE5D3
=1hG13LN4PAa?bl4Kei7171;A0AcHeD3Le]=16eFA`AXD4D4Jdm316]IC0AbPih4MgYi0gYnORmgNWXE
oooo000Doooo27MjNPAgLg<4Mgal17MhN0=gOGd[MgYj10d:2@>ZQV`4Sgif17MZG@A]DdL4OGIa17MW
G`AgFT/3GC//164n=@@e3`d4M7M`16A_J@BUYIh3NGUm17b1PPAkPgh4JdLj17B7P`A_JfL4F5AE0c@N
5`@g7Q84LCl_16mNA`A`Bd@4Lf=E0g=KC@A]ETL4J51516]?@`A[FD`4LX>N17MjN@=jOWh_MgYj5Ooo
o`005?ooo`QgNWX4MgQh17MmOBigNWX4HEm]10820@?O[i04OFiS17MZF`AdI5T4Ng9]17MZHPAY@cH3
C3HT15@T7@@T30P4[GQY18=[FPAbE4d3NX1n17MRDPAgJ5P4ITDm17QiNPAYAST4L6YS0e8j;`AAC4@4
>AdF17To;`A^DdP4N6E@0gMWF`A]ETT4IE1716]:?PA[E4L4I7=b16AME@=`LH44Oh9n:gMjNQGoool0
01Coool8MgYj17MhN0AgOGd^MgYj165OK@@20P43gjn@17e^H`AgJU/4M6AI17]bK@AgJV84JD<f0d`f
90AD91d490`81:ehJ@B3JeX4LUA=0gZ0OPAgHU84MfQH16I5?@AhNGX4JDHi171ZH`=B>Rl4DDa413TM
5PAi?bl4KU=817QUD0=gIe/4KEI916E@A`A[BSh4JeA716AcLPATGED3L76117n2OR]gNWXEoooo000D
oooo27MjNPAgN7P4Mgem;WMjNPAQGfd40P810mn_T0AmKV<4MfYK17ATF@AkLVd4MfYR16U3=P=<=R@4
E2@M12@<20B]N6T4Pf]J179DC@=jP7h4Mf9B17MXF0AVACd4N7Uj16U6>@A`JV<3DSX_155<A0@i7AH4
NCl_16iCB0AhIE03MfMK16eFB@AUD4L4JdXn16]DA`ATLg84I5eE0g1aP@AoPWh[MgYj5Oooo`005?oo
o`QgNWX4MgQh17MmOBigNWX4HEm]10820@?O[i04OFiS17MZF`AdI5T4Ng9]17MZHPAY@cH3C3HT15@T
7@@T30P4[GQY18=[FPAbE4d3NX1n17MRDPAgJ5P4ITDm17QiNPAYAST4L6YS0e8j;`AAC4@4>AdF17To
;`A^DdP4N6E@0gMWF`A]ETT4IE1716]:?PA[E4L4I7=b16AME@=`LH44Oh9n:gMjNQGoool001Cooolj
MgYj12TR70@H3Pd4EcX^0lf[SPAkK5l4MeeA17MPE0AgKF84MfYM16@m<`=VFDX4N6MN16m]H@BUNWP4
M69F16aAB`=aGUD4MCdi16=:@PAT;RX4K3@]160_9`AaKUh3F3<Y15Y2@`@j;BL4>`h618QMDPAkJ503
NFYP16YB@@AUC484I4i216eJC0AYHUH4P8N@0f=OLPB<TXP[MgYj5Oooo`005?ooocYgNWX4:B8L11P>
3@AG>Rh3cJ^>17]/G`AgGE44Mf1D17M]HPAgJUd4I3dc0fIIBPAhIeh4KfeQ1:EjN0AdHUH4K55;0g5N
E@Ae?CT4HdY216@^:PA/=2d4H2lW175^GP=H<bT4FT9313X]9`@k3PH4R5eB17]XD0=iJV04JU9116E<
@PATCT84KEY<16UREPB0Qi03Hemb18bBR2]gNWXEoooo000Doooo>WMjNP@Y8Q`460h=15Lj;P?=Zhh4
NfaO17MMD@AgH5@4MfeR17MZG@AT?C<3IUU:17QWGPA_KF44YGYh17AREPA/DD/3LEiE17Dm>@ASBT84
I2hZ16`d;@AP;bL4LFiN0ePc:@AJ@T<4>RdW13/>1PB8GE84NfQ@0gUZH0AZDT44IDa216A>@PA]FT`4
JF9F1827T0=SGg84S9:8:gMjNQGoool001CooolDMgYj0gMcL`AgO7`KMgYj165IH0@10P446Q0=1>Ze
X@>=Of/4Mf=G17MEEPA`JUX4NW1S17MFE`ATAcX3FT4`18V3O0AkLf/4Mf9O17AZH0AeLVT3NFaT17aX
F`A/GDl4MEY>16iJA`A^FTh4K5Q80g4e=@AP=Bl4BbHK13PC3PA[:Ah4PF]F0gaVF`AZDd44ID]2169;
?`A`E4L4JeQ;12DN6@>FU9/4OWmj17YnORMgNWXEoooo000Doooo57MjNP=gLg<4Mgal6gMjNPAQFF04
0@8111X@3@CZ]J43SGm[17MSE`AgEEH4L6YJ17Y`H`AgEUL4I4Lj0eY1<0B9Pg`4Ng=[17MRG`AdJV04
MG9Y0gU/I0AlJ5/4K5e?17EJCPA^FTL4KUY>16aHB0=a=CD4H3D_14/V6`@h4`h4JbTN185[EP=lIU/4
JU=116E;@PARBcl4L5A716]HB`@U7QT3UYBK17ioNPAjOWhWMgYj5Oooo`005?oooaAgNWX3Mg=c17Ml
O1]gNWX4HEUP10420@@J40d4j[FQ0heoJ`AgHeL4MeEF171ZFPAjL6<4MeIG16A7>P=J@C04RH=l17]c
J`AgHUl4M6YP17EbJ@=iK6@4O6QK16aMC`AeFTh4KUY716iJCPA/F4P3LCDe160e;`A;9Q/4>1<>16/Y
7PB1JeH3O6IK16YC@@AUBd84HT/o171DA`A[F4/49AhI0iJDV`AnOgX4NWin9gMjNQGoool001CooolD
MgYj0gMcL`AgO7`KMgYj165IH0@10P446Q0=1>ZeX@>=Of/4Mf=G17MEEPA`JUX4NW1S17MFE`ATAcX3
FT4`18V3O0AkLf/4Mf9O17AZH0AeLVT3NFaT17aXF`A/GDl4MEY>16iJA`A^FTh4K5Q80g4e=@AP=Bl4
BbHK13PC3PA[:Ah4PF]F0gaVF`AZDd44ID]2169;?`A`E4L4JeQ;12DN6@>FU9/4OWmj17YnORMgNWXE
oooo000Doooo57MjNP=gN7P4Mgem6gMjNPAJEVD4Bd@`18eWF@BoWHD3NV]L17MREPAgJ5l4M5aH17]b
H@AgI5`4I5110f12>0B9OW44NVmX17M^IPAgJ604Mf]S0gM^IPAgEE84KEI917=MD@AZETP4Ke9815i=
?0=YB404HE8n161:?`AQC484JDU717iVA0=jI5P4K5M416E;@PARD3h4L5A816]IC0@E71d3[j:M17n5
Q`AkP80WMgYj5Oooo`005?oooaAgNWX3MgQh17MmOA]gNWX4FUIU14]4<0B=IeT4_if50gY[G0AgHUH4
MfQO17ALF0AkLV44MfAL16A@@@=P@SP4RGia17Y_J0AgKVH4MfQP17M[H`=gKVH4MeEB16eFB@AcGE44
JUI816mBB0ANCC`3JDQ0165B?PAPBSl4HDa216U9A`AnIT@3NVAH16aGA0AUBd84HU0n171DB0A[FD`4
5A`M0jnRW@AoQHL4Nh209gMjNQGoool001CooolDMgYj0gMhN0AgOGdKMgYj15YFI@A;A304SFMI1;nM
Q@=jJe`4Mf9F17MXG`AdG5P4Ng9Q17MTG0ATD443H48h18UnL@AjKfP4MfiV17MXH0AgJf<3MfiV17ME
DPA]ETT4LeeA16YFB0A_DTP4GTdl0fU8@0AQDSh4H4Xo165<@PAYBDL4OVI40gYTF0A/Ed@4ID]2169@
?PA`E4P4JeU<11DL7@>_XYd4OhF717^0P2MgNWXEoooo000Doooo57MjNP=gN7P4Mgem6gMjNPAJEVD4
Bd@`18eWF@BoWHD3NV]L17MREPAgJ5l4M5aH17]bH@AgI5`4I5110f12>0B9OW44NVmX17M^IPAgJ604
Mf]S0gM^IPAgEE84KEI917=MD@AZETP4Ke9815i=?0=YB404HE8n161:?`AQC484JDU717iVA0=jI5P4
K5M416E;@PARD3h4L5A816]IC0@E71d3[j:M17n5Q`AkP80WMgYj5Oooo`005?ooocIgNWX4KeQ;189Z
F0AdJf@4LFMI0gIWF`AjJUd4MfaW17MTH@AgN6/4MfQQ16]FBP=ZC444KE5417]dI`AjM6d4MfaT17MX
H0=gLVX4Mf1D16eHBPA/Bd04K5Y8165<?0ADBCh3IDDf1694>0ARB3P4HT<h1617>0AdGd`3NF5G16mC
APANASd4I4`o16UC@PAVDdL42@h?0l>fbPB;TY0[MgYj5Oooo`005?ooocIgNWX4KeQ;189ZF0AdJf@4
LFMI0gIWF`AjJUd4MfaW17MTH@AgN6/4MfQQ16]FBP=ZC444KE5417]dI`AjM6d4MfaT17MXH0=gLVX4
Mf1D16eHBPA/Bd04K5Y8165<?0ADBCh3IDDf1694>0ARB3P4HT<h1617>0AdGd`3NF5G16mCAPANASd4
I4`o16UC@PAVDdL42@h?0l>fbPB;TY0[MgYj5Oooo`005?ooocIgNWX4KeQ;189ZF0AdJf@4LFMI0gIW
F`AjJUd4MfaW17MTH@AgN6/4MfQQ16]FBP=ZC444KE5417]dI`AjM6d4MfaT17MXH0=gLVX4Mf1D16eH
BPA/Bd04K5Y8165<?0ADBCh3IDDf1694>0ARB3P4HT<h1617>0AdGd`3NF5G16mCAPANASd4I4`o16UC
@PAVDdL42@h?0l>fbPB;TY0[MgYj5Oooo`005?ooocIgNWX4KeQ;189ZF0AdJf@4LFMI0gIWF`AjJUd4
MfaW17MTH@AgN6/4MfQQ16]FBP=ZC444KE5417]dI`AjM6d4MfaT17MXH0=gLVX4Mf1D16eHBPA/Bd04
K5Y8165<?0ADBCh3IDDf1694>0ARB3P4HT<h1617>0AdGd`3NF5G16mCAPANASd4I4`o16UC@PAVDdL4
2@h?0l>fbPB;TY0[MgYj5Oooo`005?oooc9gNWX4L6e]17YKAPA`GE<4JeE315ePIP>2IeH4NfiX17M`
J`AgKVH4Mg1X17M/I0AdDTl3KUQ:16Y:?`AmKV04OG=_17M_I`AgDU43L6YI17YYFPAVC484K4i31651
=0AQDTH4G3he0fI8=PASB3h4JU4h1656>@ASAC<4OV9F0g=GBPAWCD84GTPm16M=@@AWEDL4KUM<1005
20?1Yj04Ri:=:gMjNQGoool001CooolbMgYj171]K@AjFdH4L5eC16]E@`AMH6H3PVMF17]^J0AgL6/4
MfiV17M`J0AgK6@4M59?0fiHBPAZBSl4OFiP17ecK`AgKfL4Me9A0g1ZF@AjJEX4ITa216a>@`AQ@C@4
HE9615`n=@=VB3H4HdPn16YA>0AQAST4HdDc17iREP=cEdX4Ide215i8?@AWCD44IeE716iGC0@01@P3
`JNP18^BSB]gNWXEoooo000Doooo<WMjNPA`KFd4NU]6171MD`A[ED<4GF1V0h9WEPAkKVP4Mg1[17M^
IPAgL6P4MfaT17ABC`=^F4X4JTXo17e^H0AmLfl4MfmW17MBD@=`JUT4NVUJ16I<@PA/CT<4HD4d165B
APAL?SD3ITPf16=8?PAZDCP4HDHi16=5<`AnHUH3LeM:16M=@PANB3d4Ide116MEA`A^Ed`400D80l6W
X0B;TXd[MgYj5Oooo`005?oooc9gNWX4L6e]17YKAPA`GE<4JeE315ePIP>2IeH4NfiX17M`J`AgKVH4
Mg1X17M/I0AdDTl3KUQ:16Y:?`AmKV04OG=_17M_I`AgDU43L6YI17YYFPAVC484K4i31651=0AQDTH4
G3he0fI8=PASB3h4JU4h1656>@ASAC<4OV9F0g=GBPAWCD84GTPm16M=@@AWEDL4KUM<100520?1Yj04
Ri:=:gMjNQGoool001CooolbMgYj17ALB`AkI5P4ITe216A?@PAdLf/3R5]E27MbJPagKVH4Mf1D0gAO
C`AWDD44LU=7181lMPAgLVX4Mf1K0gA`H`AkK6D4Je1:16eFB@ASB3h4K5M:15`l<P=SAST4HdXo16a@
@PA/C484MEU<17YTF0=WCT84Idm316U@A0AUBd04IeE216UCA`@01PL3BS@]1;Rb]@AgO7`WMgYj5Ooo
o`005?oooc9gNWX4M5a;17]TF0AVCD84I4m217AcJ`>8FeD8Mg9Z37M^IPAgH5@3M5m?16MA@@AbDdL4
P7af17MbJPAgH5/3M71S17]/I@A[D4X4KEI916=8?PA/EdX4G3`b0f=6>@ASBSl4K51216a<@PAeFD`4
NVAH0fM>@PAWCd<4JE1416E;@0AWED84JE=710061`=:=2d4^;:e17MlO2MgNWXEoooo000Doooo<WMj
NPAdG4/4NfAH16I=@PATCd84M7=[0hQKE@QgLVX<MfiV17MPE0=dGdl4Ie51179CA`B0O7H4Mg9Z17MP
F`=dL6<4NfaU16]@BPA]ETT4HdPn16aGBPAL?383HdHi16=:?`A/D484K4a217EIC0AjI5P3Idi216M?
@`AYD4@4ID]016ME@PAYDdL400H70dXd;@Bh/[D4Mgal9gMjNQGoool001CooolbMgYj17ALB`AkI5P4
ITe216A?@PAdLf/3R5]E27MbJPagKVH4Mf1D0gAOC`AWDD44LU=7181lMPAgLVX4Mf1K0gA`H`AkK6D4
Je1:16eFB@ASB3h4K5M:15`l<P=SAST4HdXo16a@@PA/C484MEU<17YTF0=WCT84Idm316U@A0AUBd04
IeE216UCA`@01PL3BS@]1;Rb]@AgO7`WMgYj5Oooo`005?oooc9gNWX4MeQ3171SF@AB<R@4NgAW189R
HP=kK5l4Mg9X17MbJPAgMG<4MfaR17M^IPAgIE`3MfII16A?@`A_ETL4NgU]17Y]I`AgIeT3Mg1Z17MX
H0A]F4/4HTTl16M=@PATDDD4HTLl0fQ>=`AQA3T4K55517UJDPAjIUP4KEY=0fEFBPA[EDP8I51416MD
A@A^GU84<R`O0chS70@n<B`4YZVY9gMjNQGoool001CooolbMgYj17MH@`A`HeT4DS8T17]dI`B2HV83
NfaO17MbJ0AgLVX4MgEc17M/HPAgKVH4MfEL0gMVF@ATCd<4KeI717]iK@AjKFL4MfMI0gM`JPAgJ604
KEQ;1699?0AWCD84I5551697?0=XCSL4HD@i16aAA@AiFU84NVIH16eJC@=UETX4JeE826A@A0AWE4D4
KUiB138/7`<n8a`4?S4/1:JYZBMgNWXEoooo000Doooo<WMjNPAgF4<4L6=I158b90AkM6L4PV9R0g]/
G`AgLVP4Mg9Z17MeL`AgK684MfiV17MUG0=gIUT4I4m316mFA`AkNFd4NVeW17MWF@=gL6X4MfQP16eH
B`ARBC`4Ide216AAA@ARAc`3J4hg1654>@A/DDD4NEYB17YVF0A]FTd3IEI:16]EB0QTD4@4IeA516iN
DP@b;1l3?R<L13ha;0BVZJTWMgYj5Oooo`005?ooobigNWX4MemD16Tm;PAM;BP4FdDi175mM@B5JUl3
Mg9O17MZIPAgLVX4Mg1Y17M[H@AgKVH4MfEN0g1SD`A]F4d4M6YK17idJ0AkK644L5I?0gYaH`AgE5@4
IU8m1691>0ATC444GDLk16U<=@=C?344ID<i17AQDPAiH5<4NF=E16YFBP=UDdL4Jde216U?@`AUDCl4
KT]116iRE0AM@CD3Ed<m18FT[@Bh^KXWMgYj5Oooo`005?ooobigNWX4MemD16Tm;PAM;BP4FdDi175m
M@B5JUl3Mg9O17MZIPAgLVX4Mg1Y17M[H@AgKVH4MfEN0g1SD`A]F4d4M6YK17idJ0AkK644L5I?0gYa
H`AgE5@4IU8m1691>0ATC444GDLk16U<=@=C?344ID<i17AQDPAiH5<4NF=E16YFBP=UDdL4Jde216U?
@`AUDCl4KT]116iRE0AM@CD3Ed<m18FT[@Bh^KXWMgYj5Oooo`005?ooobigNWX4MemD16Tm;PAM;BP4
FdDi175mM@B5JUl3Mg9O17MZIPAgLVX4Mg1Y17M[H@AgKVH4MfEN0g1SD`A]F4d4M6YK17idJ0AkK644
L5I?0gYaH`AgE5@4IU8m1691>0ATC444GDLk16U<=@=C?344ID<i17AQDPAiH5<4NF=E16YFBP=UDdL4
Jde216U?@`AUDCl4KT]116iRE0AM@CD3Ed<m18FT[@Bh^KXWMgYj5Oooo`005?ooobigNWX4MemD16Tm
;PAM;BP4FdDi175mM@B5JUl3Mg9O17MZIPAgLVX4Mg1Y17M[H@AgKVH4MfEN0g1SD`A]F4d4M6YK17id
J0AkK644L5I?0gYaH`AgE5@4IU8m1691>0ATC444GDLk16U<=@=C?344ID<i17AQDPAiH5<4NF=E16YF
BP=UDdL4Jde216U?@`AUDCl4KT]116iRE0AM@CD3Ed<m18FT[@Bh^KXWMgYj5Oooo`005?ooobigNWX4
MdM016@g;`AL<B`4If=A17ilK@B8L6P3Mg1Y17MXH`AgLVX8MfiV17MWG`AgIeT3KF9C17]NDPAaJUd4
OFiX17M`J@AdHUh3Ng9W17MHCPATE4<4GT<k15e7>`AJ@SH4HDHg0ei6?@AhGU04NVAF17=RE@AiGe<4
JUI:0fEBAPA[CT84Jd]516U<A0AWBd04KFEM15/i:P=YCd@4V;_817AhN2MgNWXEoooo000Doooo;WMj
NPAgAd04I3L_15`a;0AWHe44OWa]18Q`J0=gL6T4MfQS17MbJPQgKVH4MfMO17MWF@=]HU<4NeiB175Z
G@AmKVP4Mg1Y17ARGP=kLVL4MeQ>16AD@`AN@c/4GDLk15Y2=PAQASL3GTHm17QND0AjI5H4Lf9E17UO
D`AZETX3IE9616]>@PA[BdD4JDa416M;@0A]IEd4FcTZ0fU?A0BH^lP4M7Qh9gMjNQGoool001Coool^
MgYj17M7@0AT=bl4G34/16MSD@AnO6d4R71X0gM`J@AgJ6<4Mg9Z27M^IPAgIel4MfMI0feRD`AkGU84
LFYM17e^J0AgL6T4M69N0g]bI`AgF4h4I5A315i3>`AMAc/4FT8f1656=`=NASd4N5i@17YTEPAcHUD4
NEmC16YFBP=UDTH4Jdi216];A@AYC4@4Id]016eUG@AK>BX3JDm419Rkb0AdN7PWMgYj5Oooo`005?oo
obigNWX4MdM016@g;`AL<B`4If=A17ilK@B8L6P3Mg1Y17MXH`AgLVX8MfiV17MWG`AgIeT3KF9C17]N
DPAaJUd4OFiX17M`J@AdHUh3Ng9W17MHCPATE4<4GT<k15e7>`AJ@SH4HDHg0ei6?@AhGU04NVAF17=R
E@AiGe<4JUI:0fEBAPA[CT84Jd]516U<A0AWBd04KFEM15/i:P=YCd@4V;_817AhN2MgNWXEoooo000D
oooo:gMjNP=gIEX4Me9416A2=PAF?Bd4L6MF18^0L@AkK6P3Mg9Z17M/I0AgJV84MfUQ171SE0AjJE`4
MeIE0fePD@AfF4h4L6EH17e`J`AgJe`4MfMQ0gMZHPAgDe04I4Pk15a6>`ANASX4HDPl15e?@`=_ET<4
M5eA17IMD0AgHED4KeM;16aAA@=UDdL4JdPm16];@@ATCD44I5@o171SGPAV@C<3J5M<17:0R`AnQ8<W
MgYj5Oooo`005?ooob]gNWX3MfEJ17MBA0AT@SH4ESd]171WEPB;P744NfaX0gMbJPAgK6@4MfYR17MY
H@A`He@4NVUL17MFE@=]H544MUQ>171UF0AmL6/4Mf]L17MWH@=gJV84Me=@16A8>`ALAS/4GTHj1658
?0AMCd<3KeI317AMD@AfGE04Mf5E16mGB`A/DDD3IE=716]8?@A[Bd44I4e116AD?`A`Heh4IT4c0fQG
C0AbP8/4OXB39gMjNQGoool001Coool[MgYj0gMUFPAgDT@4I48f15Hm;@A`IeH4Rh1a17]/J0=gLVX4
MfaT17MZHPAgJF44L6=D17YYG0AgEUD3KF1A17IHCPA`IEP4OG1[17M[G0AgIf43MfYR17MCD0ATB3/4
G4Hk15i6>PAQB3`4GDm30fmF@`AdGE44MUe@17MQE@A_Ed/4K5550fECA`A[B3d4Jd]116A=@@ATE3l4
L6=N16I1<`=XEd`4LX2;17j4PbMgNWXEoooo000Doooo:gMjNP=gIEX4Me9416A2=PAF?Bd4L6MF18^0
L@AkK6P3Mg9Z17M/I0AgJV84MfUQ171SE0AjJE`4MeIE0fePD@AfF4h4L6EH17e`J`AgJe`4MfMQ0gMZ
HPAgDe04I4Pk15a6>`ANASX4HDPl15e?@`=_ET<4M5eA17IMD0AgHED4KeM;16aAA@=UDdL4JdPm16];
@@ATCD44I5@o171SGPAV@C<3J5M<17:0R`AnQ8<WMgYj5Oooo`005?ooob]gNWX3JD<^15Ph;@@g:1l4
DcT]18IeI`B7O6d4MfYV0gM[H`AgJF44MfMI17MSE`A]HeD4MUYE16]FC@=bGeD4LfQJ17=YG0AmL6D4
MfYR17MZI0=gJV84L5iB16I:?0ALB3d4GTHj16=9?@AXD4@3KEE717UID`AcGDl4LU]>16aMD@A_ETX3
IEA816]BA`ATDD@4I4]016M>A`A`HUd4GBXL0feYF`AU@ST4T:N[9gMjNQGoool001Coool[MgYj0fU3
;PAH>2d4=bPO15<i;@B6MFL4Qga]17MZIP=gJf<4MfUQ17MWF@AgHeL4KF=E17IJE@A[ETd3LUmE17=X
FPAcJE`4OG1U17MZHPAgJV@3MfYR171NDPAVBS`4G4Pm15i6>PASBCd4J5140feEA`AiFE<4Lee?179K
CPA/GE44KeI:0fEDB0A[DTL4I55416A;@0AWCTL4L69M15dZ70=]JE/4ID8i192WZbMgNWXEoooo000D
oooo:gMjNP=Y@bh4F3P]13LX7`AC>Bd4QWEW18MlK@AgJVH3Mf]S17MYH@AgIeT4Mf=G16eSE@AfFUD4
JeI=0g9OE@AcJ5X4LfUL17e`I@AgJV84MfYT0gMZHPA`GU84ITXl15a8?@ANASX4HdTm16Q@A0=]EDL4
NEUC17=MC`AbFdh4K5eA16mFBP=UE4P4Je9716AAA0ATBd04Idi7171RG@AM:Q`3KFUK16E2>@B@Yj/W
MgYj5Oooo`005?ooob]gNWX3JD<^15Ph;@@g:1l4DcT]18IeI`B7O6d4MfYV0gM[H`AgJF44MfMI17MS
E`A]HeD4MUYE16]FC@=bGeD4LfQJ17=YG0AmL6D4MfYR17MZI0=gJV84L5iB16I:?0ALB3d4GTHj16=9
?@AXD4@3KEE717UID`AcGDl4LU]>16aMD@A_ETX3IEA816]BA`ATDD@4I4]016M>A`A`HUd4GBXL0feY
F`AU@ST4T:N[9gMjNQGoool001Coool[MgYj0edY60@M50h4>RTS13DS80BVQW44PgM`17MZI0=gJU/4
MfYM17MZHPAgJ644M6YS17QWHPA^F503Ke5;16MGA`AhIUT4MVUL17Y[J0AgJV83MfYK16eECPARACT4
F3dm1618=@AM@cP4Ke550fiKC@AaDDH4JUQ:179ECPAWD4<4JUA80f5=@PAVDD@4I4m316M9?PAWCDP4
JEQ815De8P=ZET@4IS/g192labMgNWXEoooo000Doooo:gMjNP=M:AP47A@>13XY8`@e8b04YXIa18=g
L0AgJV@3MfYK17MZG@AgJV84MfQQ17AZH`AhIf84KUQ@0fmAB`AWEdL4N6II17IYG0AjJfP4MfYR0gMZ
F`A]EDh4HTDi15Pm?@APB3D4GD<h16mAA@=^Fdd4LE5616YHBPAbEDh4Ie1316YDB0=QCD84IU5416A?
@`AWBCh4Ide816UHB0AE=B83JUI416Hk=`B@_<LWMgYj5Oooo`005?ooob]gNWX3GBTH11dD3P@j:B<4
=B<P1:J6L@B3Mg04MfYT0gMZF`AgJUd4MfYR17MXH@AdJV<4N6MR16iHD0=_DD/4IeM717QVF@AfJE`4
NV]X17MZHP=gJU/4KEE>1695>@AH?Cd4H4Pe15e3>0A_DDD3KU]=175AAPAZF4X4LUE>16M@@`AZE4P3
HDe216IAA0ATCd<4IdTn16M=B0AYF4P4ECDR0fYFA0AV>cL4T;c79gMjNQGoool001CooolWMgYj17M]
IP=Q=2P4;bHO134S70@b8R04`IAi18=gJPA`HeL3NV]S17MZG0AQD4L4J5M:15@o=@AKA3T4FD4k0f0n
?0A/ED@4L5E8175SEPB0LVd4MfYR0gMZH0A]DDd4GdLj15U1=0ASAC44FdTo16Y<?`=NDD@4GDXo16]D
A`A`GE44HDe016eIC0=YE4P4IE1416MAA@AWBCh4Ide816MEA@@n91X3CRDK1716=@BC_/XWMgYj5Ooo
o`005?ooobMgNWX4MfeV0f4d:0@_9Ql4<B<L138R80C1U7T4PgMZ171SE`=jJf<4MfYL165@A`AXEdX4
E3le15]4>@AI@C/3H3hl16aEA0A`EDP4LF=F181bK@AgJV83MfYP16eAC@AOAcX4FD4d16=5<@AKBCl4
JT`o0eiAA0AMBSl4JeA7171MD@AQCD04KEU<0fUDB0AUD4@4Ie5516M9?PAWCDP4IeE513hT6P=>9A/4
L4He19>nbRMgNWXEoooo000Doooo9gMjNPAgKFH3HC@X12lV7`@a8a`4<R8P1<6DN@B3MfX4L6=G0gY[
H`AgJU`4HE1716QGBPAD?cD4Fd@i15U1>`=P?S`4K5E4171EB0AaHeH4P79]17MZHP=gJV04KE5=15m7
>PAI@C@4HdDa15]9?`AZC3l3GU5415e:?`A[E4L4L5eA165=@0A]FD`3JEA816E@A0AWDDD4IdTn16M=
B0AWEDD4?R@J0dhU6`A`ASD4Tkk:9gMjNQGoool001CooolWMgYj17M]IP=Q=2P4;bHO134S70@b8R04
`IAi18=gJPA`HeL3NV]S17MZG0AQD4L4J5M:15@o=@AKA3T4FD4k0f0n?0A/ED@4L5E8175SEPB0LVd4
MfYR0gMZH0A]DDd4GdLj15U1=0ASAC44FdTo16Y<?`=NDD@4GDXo16]DA`A`GE44HDe016eIC0=YE4P4
IE1416MAA@AWBCh4Ide816MEA@@n91X3CRDK1716=@BC_/XWMgYj5Oooo`005?ooobMgNWX4L50o0fI2
?0@81@<45Q4?12PL6@CFXH<4NFiP17MSE`=kKV<4MfYK16QFC0ACA3X4A3H/12l[:@@X81h3@RHI16A4
=0A=9Q`4DB/P18enKPAjKFL3MfYR16eHB`AOASX4FD<b15e=>0AE?SD4LUQ;0feJC@A^EdX4LU9516M=
A`AGBC`4MEY=0f]EB@ARCT84FT/o15i;?`A/E4P4IeA513`T70=D:Ah4Nd<c19K5e2MgNWXEoooo000D
oooo9gMjNPA`D3l3IT8l10P50`@F4@l4:1`I1=JQP`AiKV04Mf=G0g]^H`AgJU/4J5I<15=4>PA4=R`4
;b/Y12PP7P=29QT4I4@d14dV70AA:b04SGi^17Y]I`=gJV84KEQ;15m6>PAI@c84GDdh15Dn=@AbF4/3
KEY=16iGBPAbDTD4Ide715M9?0AeFTd3JeE9169>@PAJBcl4GT/o16aDB0AWE4D4?2@L0e@Y7PAk@c<4
U/GD9gMjNQGoool001CooolWMgYj171@?`=V@S`420D311HA3`@X71T4eZ6317U^H0AgHeL3NfiS17MZ
F`AXET`4Dd@j14@f;0@_:bT4:20N0d8V6@ATA3@4CBHL154[80B=OVh4NVeW0gMZHPA]F4/4GdHj15U3
<PAMCCP4EChe179HB`=]FTd4KUM:179BA@AWCDL4EdTl17EJC@=[EDT4HTi215Y;?`ANBcl4K5A816MD
A@@l91`3E2TN17]3<`BFaM@WMgYj5Oooo`005?ooobMgNWX4L50o0fI2?0@81@<45Q4?12PL6@CFXH<4
NFiP17MSE`=kKV<4MfYK16QFC0ACA3X4A3H/12l[:@@X81h3@RHI16A4=0A=9Q`4DB/P18enKPAjKFL3
MfYR16eHB`AOASX4FD<b15e=>0AE?SD4LUQ;0feJC@A^EdX4LU9516M=A`AGBC`4MEY=0f]EB@ARCT84
FT/o15i;?`A/E4P4IeA513`T70=D:Ah4Nd<c19K5e2MgNWXEoooo000Doooo8gMjNPAoPH44LTPe0f0o
=`@93a0471<@134I5@CT/i<4NfmR17=TF0=jKV44MfYM17AVH@AFACX4MUmH128S7`@N4a03=Q`C14Hj
=PAS=RT4O5m@19F@O@AmMg<3MgIc16eLC0AO@ST4C3P]15Q1;`@[3@T4NUQ70f15;PA@?C@4@BhS16I=
@@AJCT44M5I30fIAAPATCd<4ET@i15m>@PAbCTP4FTLj134N6P=I=BP4P51719c?f@AdN7PSMgYj5Ooo
o`005?ooob=gNWX4Oh611798=@=P?cL42@l@11`C40@a6AD4i;>C17]_HPAcI5P3NViQ17MZG@AdIV44
ETDj17IOF0@R8al47Q<@0cHL4`A6>SH4HcHY17aOD0BET7d4OGMc0gMfL`A]G4`4Gd8i14`h;@AH@Bl4
:`d917YHA`=PABh4D3dd144^8`AVCD44FTi117AF@`=VDDH4I4m315I4>@AOCT84LTi815Y7>P@a7QX3
FCDX181@A`BLcmT4M7Qh8gMjNQGoool001CooolSMgYj17n1P@AbB3D3H3lg10T?40@L4a04<ATE1>Bc
T`AkKf84LfAH0gY^H@AgJUd4M6IQ15I5>PAfGeP48R<O11hC40<f71<4ASXf16<f:@AlGe04UI1m17eg
L`=gMW<4KEa<15m2>@A<>2d4F44_12/=2@AjF4L3H4D^150m=0A1;R<4ITe115Y>@@AdET<3IU5616A?
@`AFA3T4Gdi2179>B0AJAcX4<AhJ0eTe:0B0D4L4W<oI17AhN2=gNWXEoooo000Doooo8gMjNPAoPH44
LTPe0f0o=`@93a0471<@134I5@CT/i<4NfmR17=TF0=jKV44MfYM17AVH@AFACX4MUmH128S7`@N4a03
=Q`C14Hj=PAS=RT4O5m@19F@O@AmMg<3MgIc16eLC0AO@ST4C3P]15Q1;`@[3@T4NUQ70f15;PA@?C@4
@BhS16I=@@AJCT44M5I30fIAAPATCd<4ET@i15m>@PAbCTP4FTLj134N6P=I=BP4P51719c?f@AdN7PS
MgYj5Oooo`005?ooo`AgMGD4Mgal17McL`AgO7`CMgYj110610BFEd<3IU=811XI60@D51T48Q@?1>Rh
V0AfIe/4MfYM0g=VF@AbIET4NV]X16QKC0AcF4d4@Shd169>@`=S@bl4JD/h18QOB0B6I5H4OG9S17eh
M0=gL6T4KEE515m2>0AE>b`4Ed0d140W7`AQEe83<2/W10T51PA9:R44AC`b12LL5@AG?C@3CCHV16e7
=PAHC484Gdm3179=@PA3>bl48aTE0dHZ8@BFJEP4V<7;175eMB=gNWXEoooo000Doooo17MeM@AgO7`4
Mg=c17MlO1=gNWX440H419IG@`=VDdP46QTH11@D6@@R50l4j;RH17IWF`AgJUd3LfII179UF@AjJfP4
J5]<17=HC@A2?S@4HTi30f=3;`AYBcP4R5m818ITEPAmLV<4OGQd0gM`J@A]EDD4Gd8h15Dk;0AG@3@4
@2LO165GDP<`:bL42@D614TZ8@A5?3849a`E15Lm=0===RH4KDLf15Q<@PAOCd<4LTe214<k;`@S6AD3
ARXQ19IYF0BH`L/4LGEe8gMjNQGoool001Coool4MgEe17MlO0AgLg<4Mgal4gMjNP@@1P@4UUM30fIC
B0@J6AP451@I128D3`CX^9P4MVMK17MZG@=cIUT4LVEI17Y[J0AXFd`4LeQ=148n=0ARCT<3Hd<_16U;
>0B8GdP4QVAF17ebH`AmN7@3Mg1Y16eEA@AO@SP4EC//15M0=0A09al4HEMB0c0[9`@91@H4BBXQ14Dl
<P@W71D4Ecdd0ddf9PA]AcH4F4a215m?@`AbCD84@c/_12<I5@=6:R44UVUH19S1b`AaMGDSMgYj5Ooo
o`005?ooo`AgMGD4Mgal17McL`AgO7`CMgYj110610BFEd<3IU=811XI60@D51T48Q@?1>RhV0AfIe/4
MfYM0g=VF@AbIET4NV]X16QKC0AcF4d4@Shd169>@`=S@bl4JD/h18QOB0B6I5H4OG9S17ehM0=gL6T4
KEE515m2>0AE>b`4Ed0d140W7`AQEe83<2/W10T51PA9:R44AC`b12LL5@AG?C@3CCHV16e7=PAHC484
Gdm3179=@PA3>bl48aTE0dHZ8@BFJEP4V<7;175eMB=gNWXEoooo000Doooo17MfMPAgOgl4MgQh17Mm
O@mgNWX44PT810l91`@a2@@3@b`S10d<4@@C4@h4:aPC1>fiV0AcIUT4OFiX0eln>@AYETP4PWE`17A^
I@AeHed4K5I@16M=@0=UDTD4Ke9617iVDPAnHUT4Mf]M17ekMP=gKVH4KDm815m@A0AI?bl4F4hi16=0
<@A/GU<3E3db10L82PA68QL4>B`Y12<K60AX@2l3J4Df17iOBPAOBCl4GDi2179D@@@M6AP48aXC0c`Q
60BKBSL4T[_817AgMb=gNWXEoooo000Doooo17MfMPAgOgl4MgQh17MmO@mgNWX44PT810l91`@a2@@3
@b`S10d<4@@C4@h4:aPC1>fiV0AcIUT4OFiX0eln>@AYETP4PWE`17A^I@AeHed4K5I@16M=@0=UDTD4
Ke9617iVDPAnHUT4Mf]M17ekMP=gKVH4KDm815m@A0AI?bl4F4hi16=0<@A/GU<3E3db10L82PA68QL4
>B`Y12<K60AX@2l3J4Df17iOBPAOBCl4GDi2179D@@@M6AP48aXC0c`Q60BKBSL4T[_817AgMb=gNWXE
oooo000Doooo17MfMPAgOgl4MgQh17MmO@mgNWX44PT810l91`@a2@@3@b`S10d<4@@C4@h4:aPC1>fi
V0AcIUT4OFiX0eln>@AYETP4PWE`17A^I@AeHed4K5I@16M=@0=UDTD4Ke9617iVDPAnHUT4Mf]M17ek
MP=gKVH4KDm815m@A0AI?bl4F4hi16=0<@A/GU<3E3db10L82PA68QL4>B`Y12<K60AX@2l3J4Df17iO
BPAOBCl4GDi2179D@@@M6AP48aXC0c`Q60BKBSL4T[_817AgMb=gNWXEoooo000Doooo17MfMPAgOgl4
MgQh17MmO@mgNWX44PT810l91`@a2@@3@b`S10d<4@@C4@h4:aPC1>fiV0AcIUT4OFiX0eln>@AYETP4
PWE`17A^I@AeHed4K5I@16M=@0=UDTD4Ke9617iVDPAnHUT4Mf]M17ekMP=gKVH4KDm815m@A0AI?bl4
F4hi16=0<@A/GU<3E3db10L82PA68QL4>B`Y12<K60AX@2l3J4Df17iOBPAOBCl4GDi2179D@@@M6AP4
8aXC0c`Q60BKBSL4T[_817AgMb=gNWXEoooo000Doooo17MkN`AgOGdGMgYj100000@`8QP4:QDB0bdQ
70@<2@X4;1TD134H50CT[Hh4NfMK17=WG0=bGeX4I5Q915Hm<`AMB3/4CCdb13d]:0@g91d3@blS14ha
9PAC=2L4NVUK17Q^H0AmLVh3MfUJ16e?A@AOETP4FCdb1654<`AOCCT4KeU90f==@`A0@C/4Me9015Pk
;PAC>2/4REY70gUF?0ASE4P4JE1016IDB0AOCD044A4?12<F4P=08AP4RS@U19_BgBMgNWXEoooo000D
oooo17MkN`AgOGdGMgYj100000@`8QP4:QDB0bdQ70@<2@X4;1TD134H50CT[Hh4NfMK17=WG0=bGeX4
I5Q915Hm<`AMB3/4CCdb13d]:0@g91d3@blS14ha9PAC=2L4NVUK17Q^H0AmLVh3MfUJ16e?A@AOETP4
FCdb1654<`AOCCT4KeU90f==@`A0@C/4Me9015Pk;PAC>2/4REY70gUF?0ASE4P4JE1016IDB0AOCD04
4A4?12<F4P=08AP4RS@U19_BgBMgNWXEoooo000Doooo17MkN`AgOGdGMgYj100000@`8QP4:QDB0bdQ
70@<2@X4;1TD134H50CT[Hh4NfMK17=WG0=bGeX4I5Q915Hm<`AMB3/4CCdb13d]:0@g91d3@blS14ha
9PAC=2L4NVUK17Q^H0AmLVh3MfUJ16e?A@AOETP4FCdb1654<`AOCCT4KeU90f==@`A0@C/4Me9015Pk
;PAC>2/4REY70gUF?0ASE4P4JE1016IDB0AOCD044A4?12<F4P=08AP4RS@U19_BgBMgNWXEoooo000D
oooo7gMjNP@200047@l;11TC40<O5104718?11hE4@@g:2<4aiAg189]H0AdK5l3NfaX16mRFPAYG4l4
IDU414A1?`A_CDD4Fd4d0fM?@0AQ@SD4OE]=18n7MPB2M6h4NfaW0gMFD`A]GDl4GeA815Th>0@m91T4
AR`P16iI@0=/Dd@4Ie5116Y>A0APCC`4GTi317ULB0=MCD04Ide:15m>@0A/Dd84@cT`10P:2@@I4`l3
Ue]616<[7`BXfnHWMgYj5Oooo`005?oooamgNWX40P0011d?2`@I4a037a@@11`B3`@N5A44=bPS1<ND
M`B2KF04M6aO0g]/J0A_HUX4JEa?16E9A0A4@Cl4Kde515]1=0=WCd04HD8e17eKC@B?QgH4PWA^17]/
I`=gEU<4KEe?15mDB0AI>3P4?B@I14H/80A^FD03K5=416MA@@AZCT@4H4dl15i>@`AiG4P3GDe016M=
BPAOCT04K5=214<i<0@82PT46A<?0iMKAPAS:al4Z=_V9gMjNQGoool001CooolOMgYj108000@M3`/4
6A<@0alD40@L4Pl47QDA13LX8`C7U7L4PVeP17A/G`=kK6P4Kf9J16ULC`AUBD@4A44o16m=A@AK@C@3
Idm01652=@AmFdd4ShMf189dKPAkK6L3MeIC16eMC`AOE4P4FCPh13dT6@A6;204KUU00faCA0AWDD44
JTi4161=?0ANCT<4NEa80ee=@0AWCDX4Gdi016aC@PA3>C0420X911TC3`>GFdH4Hb/O1:SKiRMgNWXE
oooo000Doooo7gMjNP@200047@l;11TC40<O5104718?11hE4@@g:2<4aiAg189]H0AdK5l3NfaX16mR
FPAYG4l4IDU414A1?`A_CDD4Fd4d0fM?@0AQ@SD4OE]=18n7MPB2M6h4NfaW0gMFD`A]GDl4GeA815Th
>0@m91T4AR`P16iI@0=/Dd@4Ie5116Y>A0APCC`4GTi317ULB0=MCD04Ide:15m>@0A/Dd84@cT`10P:
2@@I4`l3Ue]616<[7`BXfnHWMgYj5Oooo`005?ooo`QgNWX4Mg=c17MlO0mgNWX41`<111`=2P@N5A43
6a@@10h71`@R5A04>bXV1:9aF@B9LF84NW1R0gMZIPAgL6P4M6eS171TH0A^LFX4SGY^17IaI`=mN6l4
NW5Z18UgI`AhL684OGE`171RD`=bH5D4L6=B16MGC@A/ETh4ETLi13XU90@f9ad3:ahG16M1=0AbF4`4
I54n16=@@@AOCD43H4Dk15A3>0A/CdL4KDi011dH50@>3@`4:R<N0i57<`A681H4<SDc1:>TY2=gNWXE
oooo000Doooo27MjNPAgLg<4Mgal3gMjNP@70`4470d:11hE4@<K51043PL7128E40@k:RH4XW5I18Ua
HPAjL683MfYV17M`J0AdKF<4L6AP16iaJPB=NVh4MW5W0gehK`AjLFX4RGMW17Q`HPAmMG04L69C0g9P
E@A`He84IeM=16aFCPAFAcT4>RDT13HW7@<[7QL4Id4d179HC0ATDCh4He1115m=@@=PAC/4E4<h16a?
A`A]CT047APD10h=30@Z8ah3TDLc14HP5P@b=C<4XjBT8gMjNQGoool001Coool8MgYj17McL`AgO7`?
MgYj10L30@@L3@X47QDA0a/D40@>1`L48QD@13/Z9PBRLET4RG5R17Y`HP=gJVH4Mg1X17A]H`A`I604
KW5Z18ejKPAfLFL3OGQ_17YaJPB9MfL4N71R17eeL0A`HU<3LV1E171SDPAWEdd4K5I>15I7>@@j9B@4
=RLM0b/N5`AW@C@4LUQ<16AA?PASD444Gde10f15>`AD@cP4K4m716e>@0@M61@43Pd<12XS7P>AAc<4
AR0F138e<`BSY:@SMgYj5Oooo`005?ooo`QgNWX4Mg=c17MlO0mgNWX41`<111`=2P@N5A436a@@10h7
1`@R5A04>bXV1:9aF@B9LF84NW1R0gMZIPAgL6P4M6eS171TH0A^LFX4SGY^17IaI`=mN6l4NW5Z18Ug
I`AhL684OGE`171RD`=bH5D4L6=B16MGC@A/ETh4ETLi13XU90@f9ad3:ahG16M1=0AbF4`4I54n16=@
@@AOCD43H4Dk15A3>0A/CdL4KDi011dH50@>3@`4:R<N0i57<`A681H4<SDc1:>TY2=gNWXEoooo000D
oooo27MjNPAgN7P4Mgem3gMjNP@510<481PE11hD40<O51045@l;12DF4@@j:RH4W6I?195hJ0AmLVD3
MfYV17MbJPAgKVH4MgEc27McK`AgK683MgEc27M/HPAdIUT4NfiS17AUE`=aGU84LeQ>175RE@AdHeH4
KeMB15A;B0ASBd83@3D^13hV70@^8AP4AR/S13Td;0A8<BH3BS4V175DC@AdDD@4H4Lj10/<30@I4@h4
9QXJ0c8@2`@m5Pl4:c0^1=kNgb=gNWXEoooo000Doooo27MjNPAgN7P4Mgem3gMjNP@510<481PE11hD
40<O51045@l;12DF4@@j:RH4W6I?195hJ0AmLVD3MfYV17MbJPAgKVH4MgEc27McK`AgK683MgEc27M/
HPAdIUT4NfiS17AUE`=aGU84LeQ>175RE@AdHeH4KeMB15A;B0ASBd83@3D^13hV70@^8AP4AR/S13Td
;0A8<BH3BS4V175DC@AdDD@4H4Lj10/<30@I4@h49QXJ0c8@2`@m5Pl4:c0^1=kNgb=gNWXEoooo000D
oooo27MjNPAgN7P4Mgem3gMjNP@510<481PE11hD40<O51045@l;12DF4@@j:RH4W6I?195hJ0AmLVD3
MfYV17MbJPAgKVH4MgEc27McK`AgK683MgEc27M/HPAdIUT4NfiS17AUE`=aGU84LeQ>175RE@AdHeH4
KeMB15A;B0ASBd83@3D^13hV70@^8AP4AR/S13Td;0A8<BH3BS4V175DC@AdDD@4H4Lj10/<30@I4@h4
9QXJ0c8@2`@m5Pl4:c0^1=kNgb=gNWXEoooo000Doooo27MjNPAgN7P4Mgem3gMjNP@510<481PE11hD
40<O51045@l;12DF4@@j:RH4W6I?195hJ0AmLVD3MfYV17MbJPAgKVH4MgEc27McK`AgK683MgEc27M/
HPAdIUT4NfiS17AUE`=aGU84LeQ>175RE@AdHeH4KeMB15A;B0ASBd83@3D^13hV70@^8AP4AR/S13Td
;0A8<BH3BS4V175DC@AdDD@4H4Lj10/<30@I4@h49QXJ0c8@2`@m5Pl4:c0^1=kNgb=gNWXEoooo000D
oooo7gMjNP@71PD4=RLS11DA3P<Q51047Q@@12LI6P@i:R@4P5I118M^GPB2MVP3MfYO17M[I@AgKfL4
Mg1Y17MdL@AgLVh4Mg1Z0gMeL`AgJEh4MfiV17M/HPAgJ5X4MfYM0feJC`AcH5@4LeeA17=TE`AcFED4
Iea>16ICA`=EB3d4EDPl15I6>@AJ>bh4D3`^17A;?0=TDdH4NTa;15a??`A>@3D42``<11dC3`@K5103
5`l:12lJ5@@k=C44fm_L8gMjNQGoool001CooolOMgYj10L61@@f9b<45A4>0b4D40@N51049aTJ13TZ
90B0ET44QfiN189fJ0=gJUl4Mf]U17M_I`AgL6T4MgAa17MbKPAgL6X3MgEc17MYGPAgKVH4MfaR17MX
FPAgJUd3KEY?17=PE0AcGE44LfAG17=IE@AWG4h4IU=70eE8?@AEB3`4ETHi15Xk;PA@?2h4M4/l0fAC
APAjC4/4G4lo14i0=@@;30`47A<?11/D40<G3`X4;aXE13/e<@CKfm`SMgYj5Oooo`005?oooamgNWX4
1`H513HW8`@E4@h38A@@11hD40@W6AX4>BXT181F@@B7KUh4PWIX0gMZG`AgJfD4MfmW17M`J@AgM744
Mg9^17M`JP=gMG<4MfUN17M^IPAgK684MfQJ17MZG@=]FTl4Lf1D17=MD@AcI5L4LeUE16MLCPAVDdL3
EDPm15E8?0AFAST4FS/^150l;PAdBc`3I5=617Y<B`ALCcl4CT0e10/<30@M4`l46a@@0aL?2P@_6QD4
>cDa1=_Kg2=gNWXEoooo000Doooo7gMjNP@71PD4=RLS11DA3P<Q51047Q@@12LI6P@i:R@4P5I118M^
GPB2MVP3MfYO17M[I@AgKfL4Mg1Y17MdL@AgLVh4Mg1Z0gMeL`AgJEh4MfiV17M/HPAgJ5X4MfYM0feJ
C`AcH5@4LeeA17=TE`AcFED4Iea>16ICA`=EB3d4EDPl15I6>@AJ>bh4D3`^17A;?0=TDdH4NTa;15a?
?`A>@3D42``<11dC3`@K51035`l:12lJ5@@k=C44fm_L8gMjNQGoool001CooolOMgYj10T50`@]7aL4
7QPE0b0C3`@U3`/4:QTE13HT6@AD>bl4SfMF18EhJ0=jJel4MfYV17MbJPAgMG<4MfiV17MdL@MgLVh4
MfUN17M^IPAgIeT4MfMO17MSEP=]EDX4LfAG17=PE0AcGE44Le]A16YGB@A]DDD3IU96165>@`A[EDT4
I4i216aEB0AeDTH3JE5:16]:@0AOBc/4=BLN118?3P@M4`l4:APD0aTC3`@T5A44>BDK1::;SPB7SH`O
MgYj5Oooo`005?oooamgNWX42@D312dO5`@N61D381<?12D?2`@Z6AD4=R@I15@k;`B?IeH4QGQX0gY[
G`AgJVH4Mg9Z17MeL`AgKVH4MgAa1gMbKPAgJEh4MfiV17MWF@AgIel4Mf=F0feEBPAcI5L4Lf1D17=M
D@AcFe44JUM916eAA@=VDTH4HDi316]EB@ATCT84K5E817EBAP=YDDX4JdY015m;>`@e9ah44Pl>11dC
3`@Y61@36A<?12@E4@@i9A/4XX^>18N=S1mgNWXEoooo000Doooo7gMjNP@91@<4;AlG11hH5@<P4`l4
9@l;12XI5@@f91T4E3/_18mWEPB5N6P3NV]O17MZIPAgLVX4MgEc17M^IPAgM747Mg9^17MYGPAgKVH4
MfMI17MWG`AgHeH3KEE:17=TE`AcH5@4LeeA17=KD@AZEdT4KE550fIBAPAQCT<4JeE916A>@PA/EDP4
ME960fUABPA[BT04Gd/k13DW7P@B3`h47A<?12TH50<I4`l491DA13TU6`BRRhh4Qhf<7gMjNQGoool0
01CooolOMgYj10D30@@b:BH48QXG0bHF4`@F3`/48QDA124D40A4:Al4KTH_19EnKP=mL684MfYV17Mb
JPAgMgH4Mg1Z17M^IPAgM747Mf]Q17M^IPAgIEH4MfYO171KCP=`GU84LeeA17=LD@AcFdl4LeeA16YF
BPAWDTH3IeE916UJC@AWD4@4Jdm316EAA@AJBCh3GTe215i=?`A8>c045QHE10h<2@@T61T45`l@0aD?
2`@?1`L4<A/F17]OFPBW/[8OMgYj5Oooo`005?oooamgNWX41@<1138Y9P@R6QL39QHC11H?2`@R5A44
8A@@14@Y7`A^ARl4UGi^0ge`HPAgJVH4Mg9Z17MgMPAgL6X4MfiV17MdL@MgJf44MfiV17MUEPAgJUl4
L5]>0g1NDPAcGE44LeaA17=KC`AcGE44JUI:16MBAP=WEDT4JEY=16M@A0A[Cd<4IE5515Y9?P=NCD84
GTdo14Pk<0@F5QD43P`912@H6@@G3a035@l;10l71`@a6aH4NemJ1:Nb/QmgNWXEoooo000Doooo7gMj
NP@50`44<RTV128J5`<V5Q<45Pl;128E4@@Q5104A2TO16i6;`BEOVh3OG1R17MZIPAgLVX4MgMf17M`
JPAgKVH4MgAa1gM[H@AgKVH4MfEF17MZG`A`Fdh3L5iB17=MD@AcG544Le]?17=MD@AZETX4Ie960fME
B@AYFTd4Ie1416]?@`AUDDD4FTTn0ei=@PANCCl4B3/`11HF5@@>30T491PI11L?40<E3`/43`L7134K
5PAkGeX4Yk:b7gMjNQGoool001CooolOMgYj10D30@@b:BH48QXG0bHF4`@F3`/48QDA124D40A4:Al4
KTH_19EnKP=mL684MfYV17MbJPAgMgH4Mg1Z17M^IPAgM747Mf]Q17M^IPAgIEH4MfYO171KCP=`GU84
LeeA17=LD@AcFdl4LeeA16YFBPAWDTH3IeE916UJC@AWD4@4Jdm316EAA@AJBCh3GTe215i=?`A8>c04
5QHE10h<2@@T61T45`l@0aD?2`@?1`L4<A/F17]OFPBW/[8OMgYj5Oooo`005?oooamgNWX41`@112lV
8`@/8Qh39QXG12@G4`@P5104:QdI140_:@A=>2`4X7IT0h9aH`AgJfP4Mf]S17MaJ`AgM744Mg1Z17Me
L`=gJEh8MfiV17MUG0A`HeH4L5]@1g=KC`AcGE44K5eA16iGB`A/Ed/4IE960f]EB@A[EdX4JE9616M@
A0ATDDD4ETTn0fe=@@AKAc/4<BLQ11D@3`@S6QH44`/;11H?3`<?1`L4610@12LF4@A/EDl4^/?67gMj
NQGoool001CooolOMgYj10L40@@_9R<4;28N0bHJ5`@T5a<481@@12XM6@A0;bT4CCP/1:1fI0>2LF<4
Mf]X17M[H`AgLF/4MgAa17M`JPAgMG<3MfUN27M^IPAgIE`4L6=F171KD0McFdl4LeeA16aMD@A^Ed/4
K5M;16EBAP=[EDT4JeM:16UBAPAWD4@4I55515I9?P=]CD44FdLk134W8@@E40l48aXF11<;2`@F3`l3
3`L711P@40@W5Q44K5E?1;[3aQmgNWXEoooo000Doooo7gMjNP@71044;bHS12`R7P<V6QL491LC120D
40@Z7AT4@2lY14dh;0BPMV@3PW5S17M[J0AgJf<4Mg5[17MdL@AgL6X4MgEc0gMYGPQgKVH4MfEL171S
EPA`Fe07Le]?17=MD@A/GE44KUM;16aGB`AUDTH3JeE916]GBPAYDTH4Ie1416AAA@AFBCh3KDe115]7
>`@a9b445A0?12<J5P@C2`/45Pl?0`l71`@H41049aHA16aEC`Bj`lHOMgYj5Oooo`005?oooamgNWX4
1`@112lV8`@/8Qh39QXG12@G4`@P5104:QdI140_:@A=>2`4X7IT0h9aH`AgJfP4Mf]S17MaJ`AgM744
Mg1Z17MeL`=gJEh8MfiV17MUG0A`HeH4L5]@1g=KC`AcGE44K5eA16iGB`A/Ed/4IE960f]EB@A[EdX4
JE9616M@A0ATDDD4ETTn0fe=@@AKAc/4<BLQ11D@3`@S6QH44`/;11H?3`<?1`L4610@12LF4@A/EDl4
^/?67gMjNQGoool001CooolOMgYj10L610@a:2D4=2PT0bdR7`@V5Q8450l;12dJ5@A2:Ah4G3/[191G
?`>7MVP4NW1T17MZH`AgJf<4Mg5[17MdL@AgLVh3Mg1Z17M/HPAgKVH4MfEN17AXF0AaG543K5U>16iG
B`AfFE<4JUU;16mAA@A_EDh4IE=60f]EB@A[Cd<4I55416A?@`APACX4IDa10em2=P@k<bd491/E11`C
4@@E3`/450h?11@;2`<G40/46A4A12hI50CLf=L4XjNX7gMjNQGoool001CooolOMgYj10L610@a:2D4
=2PT0bdR7`@V5Q8450l;12dJ5@A2:Ah4G3/[191G?`>7MVP4NW1T17MZH`AgJf<4Mg5[17MdL@AgLVh3
Mg1Z17M/HPAgKVH4MfEN17AXF0AaG543K5U>16iGB`AfFE<4JUU;16mAA@A_EDh4IE=60f]EB@A[Cd<4
I55416A?@`APACX4IDa10em2=P@k<bd491/E11`C4@@E3`/450h?11@;2`<G40/46A4A12hI50CLf=L4
XjNX7gMjNQGoool001CooolOMgYj10L610@a:2D4=2PT0bdR7`@V5Q8450l;12dJ5@A2:Ah4G3/[191G
?`>7MVP4NW1T17MZH`AgJf<4Mg5[17MdL@AgLVh3Mg1Z17M/HPAgKVH4MfEN17AXF0AaG543K5U>16iG
B`AfFE<4JUU;16mAA@A_EDh4IE=60f]EB@A[Cd<4I55416A?@`APACX4IDa10em2=P@k<bd491/E11`C
4@@E3`/450h?11@;2`<G40/46A4A12hI50CLf=L4XjNX7gMjNQGoool001CooolOMgYj10L610@a:2D4
=2PT0bdR7`@V5Q8450l;12dJ5@A2:Ah4G3/[191G?`>7MVP4NW1T17MZH`AgJf<4Mg5[17MdL@AgLVh3
Mg1Z17M/HPAgKVH4MfEN17AXF0AaG543K5U>16iGB`AfFE<4JUU;16mAA@A_EDh4IE=60f]EB@A[Cd<4
I55416A?@`APACX4IDa10em2=P@k<bd491/E11`C4@@E3`/450h?11@;2`<G40/46A4A12hI50CLf=L4
XjNX7gMjNQGoool001CooolGMgYj17McL`A`Kfl41@H512lT80@e:BD3;B<O11/A3P@V71P4;1dI130S
7PAT?Rd4Ne510hIfJ0B0M6H4MfYV27M`J0AgMgH7Mg9^17MYGPAgKVH4L5mA17YUEPA]EDX3LE]?17AL
D0A_F4d4K5U;16mBAPAWFe04IeA60fA9@`AVDD<4I55516MAA@AUB3d4GDm30ddj;`A1<RP47aTC124E
4`@G4`l471@@11/D40<H40/471@A12lI5@Coool4M7Qh7gMjNQGoool001CooolGMgYj17McL`A`Kfl4
1@H512lT80@e:BD3;B<O11/A3P@V71P4;1dI130S7PAT?Rd4Ne510hIfJ0B0M6H4MfYV27M`J0AgMgH7
Mg9^17MYGPAgKVH4L5mA17YUEPA]EDX3LE]?17ALD0A_F4d4K5U;16mBAPAWFe04IeA60fA9@`AVDD<4
I55516MAA@AUB3d4GDm30ddj;`A1<RP47aTC124E4`@G4`l471@@11/D40<H40/471@A12lI5@Coool4
M7Qh7gMjNQGoool001CooolGMgYj17McL`A`Kfl41@H512lT80@e:BD3;B<O11/A3P@V71P4;1dI130S
7PAT?Rd4Ne510hIfJ0B0M6H4MfYV27M`J0AgMgH7Mg9^17MYGPAgKVH4L5mA17YUEPA]EDX3LE]?17AL
D0A_F4d4K5U;16mBAPAWFe04IeA60fA9@`AVDD<4I55516MAA@AUB3d4GDm30ddj;`A1<RP47aTC124E
4`@G4`l471@@11/D40<H40/471@A12lI5@Coool4M7Qh7gMjNQGoool001CooolGMgYj17McL`A`Kfl4
1@H512lT80@e:BD3;B<O11/A3P@V71P4;1dI130S7PAT?Rd4Ne510hIfJ0B0M6H4MfYV27M`J0AgMgH7
Mg9^17MYGPAgKVH4L5mA17YUEPA]EDX3LE]?17ALD0A_F4d4K5U;16mBAPAWFe04IeA60fA9@`AVDD<4
I55516MAA@AUB3d4GDm30ddj;`A1<RP47aTC124E4`@G4`l471@@11/D40<H40/471@A12lI5@Coool4
M7Qh7gMjNQGoool001CooolGMgYj17MhN0AdNGT40P@313`U70@_9B43=2PT12/Q7P@X71P4;B4L13<Q
60AJASX4GSd_0hMTE0AnMFH4NV]X17M[H`AgKfL4Mg1Y1gM]I0AgI5/4L6=D171KC@AfIe/4L5E;0faG
A@A^FDh4K5M516mICPA_F4`4IEE916]CA`=YCD84IEA516M;?`AWC444FT/o14e2=P=6<BH4:QhL11XC
40@G4Pl45@l;11L@40@C2`/32PL711D<30A9:R@4k?3a17AgMamgNWXEoooo000Doooo5gMjNPAgN7P4
M7Ui10840`@l9A`4;bDQ0c@X90@[8Ah4:1`H12dQ70@c8AP4FTHj15hm;`>7I5@4OWEV17Y[J0AgJf<4
MfmW17M`J@MgKF@4MfAK171SE0A`Fdd4MVMK171EB`=/EdD4KUU>16aGA@A_FDh4KeQ<16EEB@A[DdL3
JDe216EDA@AWBcl4Ida115Y;?`A=@SH3AS4V12XN70@J4a045a8?11D?2`@G41044`/;0`X71`@E30`4
BBXT1>c`l@AdMgLOMgYj5Oooo`005?oooaMgNWX4MgQh17AiN@@210<4?2DL12lU8@<d:2@4:b4N12PL
60@]8A`4<b4H15Y6>PAN?Bl3QfAD17ieIPAjJfP4Mf]S17M_I`AgL6T7MfeT17MTF`A`He@4L5]=17IW
F`A`ED/3K5M516iICPA/EdD4KeU>16mHC0AUEDT4Je=70fU=@PAUE4D4Id/o16M<@@AJBcl4CD8f0dHa
9P@Z7Q`46Q<@11LB3`@E3`/45a0@11<;2`<:1`L45@`<14TZ90C/l?44M7Mg7gMjNQGoool001CooolO
MgYj10D510@a81H4<RXW0cDY9@@X7QX491HB13@R6@@a9B44AcX_14DV7P>2ETD4Qh1`17e^H`AgJUd4
Mf]U17MYFPMgJE`4MfMQ17AXF0AaG544LeaA16a=@P=/DdD4KeE@16mKC0A_FDl4Kde216EEB0M[Cd<4
HU5516M9?PAPAc/4Bd<g14Hb9`<Z7A`491/E11TA3P@H4a0481@@11L@40LC2`/4<1XE1>OLf0B_]kPS
MgYj5Oooo`005?oooamgNWX41@D4134P5P@b:RL3=BTU12PN6P@T5Q84=28I134U8@A7>Rl4ABHN0h9F
A@B7P704OFiS17MZG@AgJfD4MfUJ1gMYG0AgIf44M6QH175LD@AcG544K4e20faCA@A_EE04Ke]<16mI
C`A_CD84IEE81f]?@`ARDDD4IdTn1617>`A;@cL4AS8W0bXM70@T6aD46A4>11PC40@P51045a0@1a<;
2`@`6QD4imcH1:ng^2=gNWXEoooo000Doooo7gMjNP@51@@4<B0F138Z9`<e:BD4:1hJ12@F4P@d8QT4
<BDQ14Lj;`A59Qh3PUI518N0L0AmKV<4MfYM17M[I@AgJEX7MfUL17MWH@AdJ5P4LEaA17=LD@A/CD83
K5=516mED0A_Fd`4KeU?16m=@PAUEDP7Jdm3169AA@AWBCh4H4Lk14]3=`A6<RL3:QdL12@K5@@I4@h4
61<@120D40@G41074`/;130J5@CWg=P4[kNh8gMjNQGoool001CooolOMgYj10D510@a81H4<RXW0cDY
9@@X7QX491HB13@R6@@a9B44AcX_14DV7P>2ETD4Qh1`17e^H`AgJUd4Mf]U17MYFPMgJE`4MfMQ17AX
F0AaG544LeaA16a=@P=/DdD4KeE@16mKC0A_FDl4Kde216EEB0M[Cd<4HU5516M9?PAPAc/4Bd<g14Hb
9`<Z7A`491/E11TA3P@H4a0481@@11L@40LC2`/4<1XE1>OLf0B_]kPSMgYj5Oooo`005?oooamgNWX4
4@l=12PP70@a9R83>RTU12/N5@@Y7a/4:1`H138V8`@]8A`4=RLT0fa5<`B2Ie04OG1S179UF@AjJf04
MfYK17MZG@=`HeL4LVEJ17Y[G0A]DdT4K4m416aGA@=WCT<4JUM;16YGB0AbEDP4Ida116MCAPA[BD<3
I5=516AA?`APA3X4FTLk14Dm<@@c81/38Q/E11XB3P@C3P/45a0@128D40@E3a043`L70a@<30@b6aH4
m_Og17AgMb=gNWXEoooo000Doooo7gMjNP@A3`d4:20L134V8P<j:BD4:ahE12TO6`@X71P4<RHS12dQ
70@f9b@3K4Dc189WD0AmL6<4LVEI17Y[H0AgJU/4MfYM0g1SE`AbIEX4NV]L16eCB@A/Cd@4K5M50fM>
@`AZEd/4JUM8179EB0AWC444Ie=616]9@`=TDdD4I54o1614>PAJAc/4ACda13<P6`<R6aD46Q8>11<>
2`@G41048Q@@11D?40@?1`L350`<138K5PCfmoL4M7Mg8gMjNQGoool001CooolOMgYj114?3@@X81`4
<BHR0cXY9@@[7QD4:AlK12PL60@b9R<4;B4L13HW90=/AC<4PVM@17e`H`AbIET4NV]P17MZF`AgJUd3
L6=G179UFPAjJe`4KE=916a?A0A/EdD3Idi316YGB`AZEdP4LUE816M<@@AWDdH4JdU30fACA@ATDCl4
H4@j15Y7>`A5?C44<b0K0b8K5@@J4Ph44`h;11L@40@R51045@l@10l71`<D30`4<Q/F1?Kgm`AdMgLS
MgYj5Oooo`005?oooamgNWX44@l=12PP70@a9R83>RTU12/N5@@Y7a/4:1`H138V8`@]8A`4=RLT0fa5
<`B2Ie04OG1S179UF@AjJf04MfYK17MZG@=`HeL4LVEJ17Y[G0A]DdT4K4m416aGA@=WCT<4JUM;16YG
B0AbEDP4Ida116MCAPA[BD<3I5=516AA?`APA3X4FTLk14Dm<@@c81/38Q/E11XB3P@C3P/45a0@128D
40@E3a043`L70a@<30@b6aH4m_Og17AgMb=gNWXEoooo000Doooo7gMjNP@F4`h4:24N13@X90<a9204
;B<N120F5`@W6aL4;b8M13DY9@@a81L3@bLM16aA?`AiGU44LeY>17QVF@AbH5@4LVMJ0g1SE`AcGe<4
MV=F16UEBPATBCh4JU940fM=@`A[C444Je9616iAA0AWCd<4I4/o16I;@@=MBC/4G4Pk14i0=PA7=2T4
@C0U120H4`<H4@h45a8?11H?2`@C2``45@`;10X71`@;1`L3<1/F13XO5@C_loDWMgYj5Oooo`005?oo
oamgNWX45Q<>12PQ7P@d:2@3<B@P12dS7P@P5QL49a/G12lR7@@e:BD4<B0G0d<W7@A/DCl4NEiA17=J
CPAhIUT4LV1D179WFP=`HeL4LemC17ISEPAYEDX4I4Tn16YBA0=WCD<4Jda116]BAPA^DD@4Idm316A;
?`AVBd43GDTk15a8>`A>@3H4Ac@Y144`9@@P61<3614>11LB3`@F3`/44`/<11D<2`@:1`L42`L70c0K
5P@j7aD4ko?e9gMjNQGoool001CooolOMgYj11HC3P@X8Ah4=2PT0c4T80@]8ah481HG12LK5`@_8Qd4
=BTU134P5`=39ad4K54o17UND@AcFTh4N6II179PE0AbIeX3L6=G17=OD`AfHeH4JEE:16A9?PAZDT@3
Ide316]<@@A[DTH4KU5416M?@`ATBcl4IT]10ee9>`ALB3/4CT0f14Ld:@A1<2D481PC0aPA3P@G4Pl4
5Pl;11<;30@E30/42PL710/71`<`6aH4>QlE1>ocmBMgNWXEoooo000Doooo7gMjNP@F4`h4:24N13@X
90<a9204;B<N120F5`@W6aL4;b8M13DY9@@a81L3@bLM16aA?`AiGU44LeY>17QVF@AbH5@4LVMJ0g1S
E`AcGe<4MV=F16UEBPATBCh4JU940fM=@`A[C444Je9616iAA0AWCd<4I4/o16I;@@=MBC/4G4Pk14i0
=PA7=2T4@C0U120H4`<H4@h45a8?11H?2`@C2``45@`;10X71`@;1`L3<1/F13XO5@C_loDWMgYj5Ooo
o`005?oooamgNWX4>3<g12@K6@@b:2@3;B<O13/^:P@[7AD49aLC13T]:0@[81`4=BPT0bHK5`A;?304
AC8Z16@o<PAhHE84HTi216]LEP=YEe04JEI9175NDPANBCh4BCH/15Xo<`=VAC<4J4e316I>@PAV@CD4
ITm316A;=0APAcd3FT8f15Do<`A:?c<4>2@O130M5@@K51436a8?11H?2`PC2`/43`L710/71`@E30`3
:1HA1<2d/PBk`lHWMgYj5Oooo`005?oooamgNWX4>3<g12@K6@@b:2@3;B<O13/^:P@[7AD49aLC13T]
:0@[81`4=BPT0bHK5`A;?304AC8Z16@o<PAhHE84HTi216]LEP=YEe04JEI9175NDPANBCh4BCH/15Xo
<`=VAC<4J4e316I>@PAV@CD4ITm316A;=0APAcd3FT8f15Do<`A:?c<4>2@O130M5@@K51436a8?11H?
2`PC2`/43`L710/71`@E30`3:1HA1<2d/PBk`lHWMgYj5Oooo`005?oooamgNWX4>3<g12@K6@@b:2@3
;B<O13/^:P@[7AD49aLC13T]:0@[81`4=BPT0bHK5`A;?304AC8Z16@o<PAhHE84HTi216]LEP=YEe04
JEI9175NDPANBCh4BCH/15Xo<`=VAC<4J4e316I>@PAV@CD4ITm316A;=0APAcd3FT8f15Do<`A:?c<4
>2@O130M5@@K51436a8?11H?2`PC2`/43`L710/71`@E30`3:1HA1<2d/PBk`lHWMgYj5Oooo`005?oo
oamgNWX4>3<g12@K6@@b:2@3;B<O13/^:P@[7AD49aLC13T]:0@[81`4=BPT0bHK5`A;?304AC8Z16@o
<PAhHE84HTi216]LEP=YEe04JEI9175NDPANBCh4BCH/15Xo<`=VAC<4J4e316I>@PAV@CD4ITm316A;
=0APAcd3FT8f15Do<`A:?c<4>2@O130M5@@K51436a8?11H?2`PC2`/43`L710/71`@E30`3:1HA1<2d
/PBk`lHWMgYj5Oooo`005?oooamgNWX4JV]^11PE3`@T7AX3;b@P138U8@@S7AT481HG13LT6P@]8b04
?S0/0blU8P@e9b84>bdY154d:PAE>R`4?cHd13hh<@=@=BP4EdHh15I3>0@m;bX4@2dR14D^8`=E>RP4
FcT^15]2<0AW@c84ED8f14`d9`AD=B`3Dc/`144e;`@j:244;1XD12<E4P@I4Pl35@l;118;2`@?1`L<
2`L7120F4@<^6QD4n??d17^0P2MgNWXEoooo000Doooo7gMjNPAZJfh461D?12@M6P<_9204<RDQ12<M
6@@P5QL4=b@J12dS80@n<2`3;bDR13DW8P@k;BT4DC@Z15Dj;0@o=S@4?SPa0e0e:0AGASP4ET<h13d_
:PA0;B84ABhS0eDj:0AK>Bh4Fd8`16M3<PAE@SH4C3@W15@e;0=C>c04@CD_13XX8@@/6Q@48aDB11TB
3`<E3`/44P/;10l71``;1`L481HA0bhJ5@Chlo@4Nh209gMjNQGoool001CooolOMgYj16Y[KP@H5@l4
91dJ0blT80@b9B448adI120F5`@g91X4;B<P13h`;0<_9B84=BLR13/]:@AA=2X4ECX/13lf=0@n>343
D3DX15M6>0AF@cP4?BlZ140]8PA5;R<3ECXX15/i;PAK@S04Id<b15E2=PA<=2L4E3D/0e<k<0A1=Bl4
>RPQ12`J50@S5A846A8?0aD?2`@B2`/43`L730/71`@P5Q43;QXE1?Scm0AkP80WMgYj5Oooo`005?oo
oamgNWX4JV]^11PE3`@T7AX3;b@P138U8@@S7AT481HG13LT6P@]8b04?S0/0blU8P@e9b84>bdY154d
:PAE>R`4?cHd13hh<@=@=BP4EdHh15I3>0@m;bX4@2dR14D^8`=E>RP4FcT^15]2<0AW@c84ED8f14`d
9`AD=B`3Dc/`144e;`@j:244;1XD12<E4P@I4Pl35@l;118;2`@?1`L<2`L7120F4@<^6QD4n??d17^0
P2MgNWXEoooo000Doooo8gMjNP@S8BD47aXG0cLZ9P@_:2@4;R<O11LA3P@c91d4?30]13/^:P<l<B`4
>c4/14Hi;`A5=R`4>c4X13<V9@@d8QT3>R<O14<Z8@A2<2P4;28Q13DV8PA09al3@BTK140W8@A@>BX4
C3@X13h]8`A7<RL4@2XO0d4b:P@g9Ah4<20I11lD4P@T6aP44`l:0aH?2`@C2`/43`L710/71`@<1`L4
9ADA11TA4@=nG5D4emgN:gMjNQGoool001CooolSMgYj12<Q9@@O6QL3=bXV12lX90@^8al45a4>13<T
7@@l<2d4>bhZ0c`a;0@k<B`4AST_14Df;0@k<BP4<bHU13@R6@<j8al4@bXQ148`:0@/8R44=BHR140W
7`=1:A/4@2LQ150i:PA<=2P4?RdS14Lb9`A0:Ql3@C8Z13LU7P@`81T47a@B12@K60@C3`X35Pl;11<;
2`@?1`L42`L710`71`@U5A446A4A0giLE@CGgMh[MgYj5Oooo`005?ooob=gNWX48b4U11lJ5`<g:RH4
;bPT12hS7`@G4@h4<b@M13``;@@k;RX3?34/13/a;0A6>Bl4ACH/13/a:0@c9RD4=28I0cXS7`A3:R44
@S0X12`R8@@e9R84@2LO0d4Y6`A09b44D3TZ14`d:0@n;B<4Ac8W140Z7`=1<RX4=bDN130P6@@O5184
91/H11<?2P<F3`/44`/;10l71`@;1`L430L712DE4@@I4A43OUaE1=OMgR]gNWXEoooo000Doooo8gMj
NPACDEX461<?0blT80@^9204<2<P12XR7P@l;2P4?S0/13db;@<b9b<4<bPT13TS7`A2:204<b8J12/R
80@T6QH3<BDR12HF4P@a9b<4:b8O12TO6`@W5Q839A`G12DG50@]61@4;R0H12`N5`@^81P49QDB0bTG
50@S5Q8491LC11HB3`@F40/44@X;0a@;2`@C2`/82`L712DE6P@U5A04<bLS0nKIe@BHXJ8[MgYj5Ooo
o`005?ooob=gNWX4De5J11PC3`<_9204;R@P130S80@Z8Qh4?2`X13h`;0@m<Rd3<RLS13<X90@i8al4
@RPP13<R6P@[8R0491XF0c4U8P@V5Q84<BLS12/R7`@Y7a/49aHB0bDL5`@U5a@4;APD12hP60@/7QL4
;R0H12HE4P<Y5a@48aHB12@G4`@F4Pl45Q0;114:2`<D2`/44`/;20/71`@U5AX49AD@13<W8`?VfMD4
V:6R:gMjNQGoool001CooolSMgYj15=AFP@H4`l3;b@P12hT80@`8b04:R8N13`/:0@n<2`4?C8]0c8W
8`@c:2@4>B<O148X80@c8QX4:b8P12@J5P<a9B849QHB134W8`@[8Ql4:AlK12LF4P<U71L49ALD12dH
50@^81P4;1hG12hP60@V5A83:ALD12<F4P@T5a<45Q8?11H@2`@A2P/350/;11<;2`P;1`L49ADJ12DE
40@c9b<3i]WE19RQXR]gNWXEoooo000Doooo8gMjNPACDEX461<?0blT80@^9204<2<P12XR7P@l;2P4
?S0/13db;@<b9b<4<bPT13TS7`A2:204<b8J12/R80@T6QH3<BDR12HF4P@a9b<4:b8O12TO6`@W5Q83
9A`G12DG50@]61@4;R0H12`N5`@^81P49QDB0bTG50@S5Q8491LC11HB3`@F40/44@X;0a@;2`@C2`/8
2`L712DE6P@U5A04<bLS0nKIe@BHXJ8[MgYj5Oooo`005?ooob=gNWX4LWAf12PX9P<R71T4<2@P13DY
9@@_9204@SD`12PN6P@l;b/39A`I13HZ9@A7<RP4<RPT12/S7`@]9244:1hJ0d0/:0@M51D4:R@N12LF
4`@V5a<47A8?0aXD40@P4`l4:QPD12PI50@M4`l47a<@11hC3`<Y61@47A<@11lD40@D3`/45`l;11<;
2`<D2`/82`L711D<30@c81/4:1PC1<c<b`>h^KX_MgYj5Oooo`005?ooob=gNWX4LWAf12PX9P<R71T4
<2@P13DY9@@_9204@SD`12PN6P@l;b/39A`I13HZ9@A7<RP4<RPT12/S7`@]9244:1hJ0d0/:0@M51D4
:R@N12LF4`@V5a<47A8?0aXD40@P4`l4:QPD12PI50@M4`l47a<@11hC3`<Y61@47A<@11lD40@D3`/4
5`l;11<;2`<D2`/82`L711D<30@c81/4:1PC1<c<b`>h^KX_MgYj5Oooo`005?ooob=gNWX4LWAf12PX
9P<R71T4<2@P13DY9@@_9204@SD`12PN6P@l;b/39A`I13HZ9@A7<RP4<RPT12/S7`@]9244:1hJ0d0/
:0@M51D4:R@N12LF4`@V5a<47A8?0aXD40@P4`l4:QPD12PI50@M4`l47a<@11hC3`<Y61@47A<@11lD
40@D3`/45`l;11<;2`<D2`/82`L711D<30@c81/4:1PC1<c<b`>h^KX_MgYj5Oooo`005?ooob=gNWX4
LWAf12PX9P<R71T4<2@P13DY9@@_9204@SD`12PN6P@l;b/39A`I13HZ9@A7<RP4<RPT12/S7`@]9244
:1hJ0d0/:0@M51D4:R@N12LF4`@V5a<47A8?0aXD40@P4`l4:QPD12PI50@M4`l47a<@11hC3`<Y61@4
7A<@11lD40@D3`/45`l;11<;2`<D2`/82`L711D<30@c81/4:1PC1<c<b`>h^KX_MgYj5Oooo`005?oo
obMgNWX4CTQ>0aP@3@@c:BD4=BTU12dS7`@X8A`4=b/W14<e<0<Y9244;20L13lV70@O6AH4:b0K12/P
70@L5Q/3;28M11hE5P@Z6A@47Q8G11XD3`@J4a035Pl;11dD40@L51046a@@11D?2`@C2`/4610;0b<E
40@E3`/44`/;11L@2`@H41044`/;0`/71`@D2`/47QD@12hN6P@^6QD4`;o01<32`S9gNWXEoooo000D
oooo9gMjNPA>B4h3610=13<Y9@@e:BD4;B<O12PQ70@g:bL4@cD`0bTT8@@/81`4?bHL11lI5P@[81/4
:b0L11`F6`</8Qd47QDF12XI50@N4QL46Q@?11XC40<F3`/47A@@11`D40@K51045@l;11<;2`@H40/3
8aD@11D?2`@C2`/45a0;11P@40@C2`/32`L711@;2`@N5A04;QhJ12hJ5@C0_l04`<;2<WMjNQGoool0
01CooolWMgYj14i8CP<H40d4<bTU13DY9@@]8al4:24L13L[9`A3=C03:B@Q12`P70@o9Q`47aTF12/P
6`@[81`471HK0b`R7@@N5AH4:QTD11hB5`@J50l46Q<@0aH?2`@M510471@@11/D40@E3`/44`/;11P@
2`<S5A045@l;11<;2`@G40/4610@11<;2`<;1`L450/;11hE40@^7QX4;QXE1<2o`0C0`/8bMgYj5Ooo
o`005?ooobMgNWX4CTQ>0aP@3@@c:BD4=BTU12dS7`@X8A`4=b/W14<e<0<Y9244;20L13lV70@O6AH4
:b0K12/P70@L5Q/3;28M11hE5P@Z6A@47Q8G11XD3`@J4a035Pl;11dD40@L51046a@@11D?2`@C2`/4
610;0b<E40@E3`/44`/;11L@2`@H41044`/;0`/71`@D2`/47QD@12hN6P@^6QD4`;o01<32`S9gNWXE
oooo000Doooo9gMjNPA_L7836aPD12PQ7P@e:BD4;B<O13<X90@d:bL4=BTU0bDM6@@U6QH4:Q`H11XB
3`@_8ah48QLG124G60<Q50l47a<H11H?3`@B2`/45a0?11L@40<C2`/46A0A11<;2`@H41044`/;11P@
40@M5A03610@118;2`@;1`L430P710/720@;1`L3610@11T@2`@D30`4914<1;^a/PC2a/HfMgYj5Ooo
o`005?ooobMgNWX4Kg1b0a/H50@X8Ah4=BTU12dS7`@c:2@4=2/W13DY9@<U7AT49AXF12XL60@J4Pl4
;b<N128G5`@Q5aP38A@?11lC60@F3`l44P/;11L@3`@G41034`/;11T@4@@C2`/4610@11<;2`@H4104
7AD@0aP@40@B2`/42`L710`81`@;1`P42`L70aP@40@I40/450`<12@A30Bk/K84`/K6=WMjNQGoool0
01CooolWMgYj16m`LP<K61@4:24N13DY9@@]8al4<bPT13@[9`@e:BD39AdI12DJ5P@Z71P46Q8?12lS
7P@R5aL48ALH0b4D3`@O4aP45Pl?118;2`@G40l45a0@0a<;2`@I41444`/;11P@40@C2`/4610@11dE
40<H41044P/;10/71`@<20L42`L810/71`<H41046A0;11@<30@T4@`4^k6b1<;6aSIgNWXEoooo000D
oooo9gMjNPA_L7836aPD12PQ7P@e:BD4;B<O13<X90@d:bL4=BTU0bDM6@@U6QH4:Q`H11XB3`@_8ah4
8QLG124G60<Q50l47a<H11H?3`@B2`/45a0?11L@40<C2`/46A0A11<;2`@H41044`/;11P@40@M5A03
610@118;2`@;1`L430P710/720@;1`L3610@11T@2`@D30`4914<1;^a/PC2a/HfMgYj5Oooo`005?oo
ob]gNWX3F5]J12/W90@U7AT4;b@P134Z9P@^:2@4?2dY0b/R8P@U5Q84:1`H11PB3`@S5A446A<?120D
40<A2`/44`/<11L@3`@G410450/;11P@40<C2`/46A4A11<;2`@^6QD42@L711XA4@@M5A035Pl@10X7
1`@;1`L440L711TA4@@H41036Q4A12`I50@c8QT4KD@b1=kVj`AkP80fMgYj5Oooo`005?ooob]gNWX3
F5]J12/W90@U7AT4;b@P134Z9P@^:2@4?2dY0b/R8P@U5Q84:1`H11PB3`@S5A446A<?120D40<A2`/4
4`/<11L@3`@G410450/;11P@40<C2`/46A4A11<;2`@^6QD42@L711XA4@@M5A035Pl@10X71`@;1`L4
40L711TA4@@H41036Q4A12`I50@c8QT4KD@b1=kVj`AkP80fMgYj5Oooo`005?ooob]gNWX3F5]J12/W
90@U7AT4;b@P134Z9P@^:2@4?2dY0b/R8P@U5Q84:1`H11PB3`@S5A446A<?120D40<A2`/44`/<11L@
3`@G410450/;11P@40<C2`/46A4A11<;2`@^6QD42@L711XA4@@M5A035Pl@10X71`@;1`L440L711TA
4@@H41036Q4A12`I50@c8QT4KD@b1=kVj`AkP80fMgYj5Oooo`005?ooobigNWX4F5]J12XR7`@[9b<4
:QlK13`_:`@k;BT3=B/X128M60@]8Ad46a8G11L?3`@Q51045`l@0aXC40@L5104610@21<;2`@D30`3
4`/;11@<30@L51046Q4A12X[=`@a;2/47a<G0a8;2`@G41047AD@11dD40@I4144<R<N0bPL60@/6A@4
EC<X1<32a0BKZ[4jMgYj5Oooo`005?ooobigNWX4F5]J12XR7`@[9b<4:QlK13`_:`@k;BT3=B/X128M
60@]8Ad46a8G11L?3`@Q51045`l@0aXC40@L5104610@21<;2`@D30`34`/;11@<30@L51046Q4A12X[
=`@a;2/47a<G0a8;2`@G41047AD@11dD40@I4144<R<N0bPL60@/6A@4EC<X1<32a0BKZ[4jMgYj5Ooo
o`005?ooobigNWX4F5]J12XR7`@[9b<4:QlK13`_:`@k;BT3=B/X128M60@]8Ad46a8G11L?3`@Q5104
5`l@0aXC40@L5104610@21<;2`@D30`34`/;11@<30@L51046Q4A12X[=`@a;2/47a<G0a8;2`@G4104
7AD@11dD40@I4144<R<N0bPL60@/6A@4EC<X1<32a0BKZ[4jMgYj5Oooo`005?ooobigNWX4F5]J12XR
7`@[9b<4:QlK13`_:`@k;BT3=B/X128M60@]8Ad46a8G11L?3`@Q51045`l@0aXC40@L5104610@21<;
2`@D30`34`/;11@<30@L51046Q4A12X[=`@a;2/47a<G0a8;2`@G41047AD@11dD40@I4144<R<N0bPL
60@/6A@4EC<X1<32a0BKZ[4jMgYj5Oooo`005?oooc9gNWX4GUiN12XT8@@b:BD4:b0L130Y9@=0<bh4
<BTV130O5P@S6QL461<?11P@40@B2`/36A0;11L@40PC2`/4610@11<;2`<H41044`/;11D<30@b;Rl4
;1hZ14@f;0@j;BX3:b8R13la;0@[81/46A<?12XM6@@]7QT3=bXV14LX80C2^k/4Y[Fi?WMjNQGoool0
01CooolbMgYj15iNGP@Z9244<RTU12/P70@`:BD3@3<^134Y9P@`7aH48aXG11PC3`@H41044P/;0aT@
2`@G41084`/;11P@40@C2`/3610@11<;2`@E30`4<Rh_12`N:PA4=R`4>RdZ0b/R8P@o<B`4:b0K11TC
3`@Z7AT4;AhI0cLZ9PA7:204`[^k1:Je^CigNWXEoooo000Doooo<WMjNPANGUh4:R@Q138Y9@@[81`4
<2TU0d0c;P@a:BH4<1lF12<J5`@H4`l4610@118;2`<I40/45a0@21<;2`@H41044`/;0aP@40@C2`/4
5@`<138^;`@/7RX4A3H/13X]:P<[8R84?c4/12/P6`@I4`l4:QdI12dN6@<g:RH4AbPP1<:k^`BV]KTn
MgYj5Oooo`005?oooc9gNWX4GUiN12XT8@@b:BD4:b0L130Y9@=0<bh4<BTV130O5P@S6QL461<?11P@
40@B2`/36A0;11L@40PC2`/4610@11<;2`<H41044`/;11D<30@b;Rl4;1hZ14@f;0@j;BX3:b8R13la
;0@[81/46A<?12XM6@@]7QT3=bXV14LX80C2^k/4Y[Fi?WMjNQGoool001CooolbMgYj17YlO0ADEUD4
:QhH13D_:`@d:BD3@cD`13X`:`@i;bX48ATF12DK5`@c9R849R0K0b0C3`@K51045`l@11P@40@D2`/4
4`/;0ahE6P@G3`l47A@@11XB4P@Z81`4>2TR11<=3P<H4Pl46a@@11@>3P@N4`l4;AhJ13<Q60=Q?Rh4
TXJA1;:o`0AgOGdnMgYj5Oooo`005?oooc9gNWX4NWal15AFE@@Z7QP4=Bl[13@Y9@=3=C04>S0[13T_
:P@Q6AH49A/G13<V8P@V81/381<?11/D40@G3a04610@11@;2`@C2`/37QDJ11L?3`@M51046Q8B12XP
70@h:B844`d>0aPB3`@K510450h>11hC3`@]7QX4<b4H0f4n;PBBQY44/[o017MmOCigNWXEoooo000D
oooo<WMjNPAjO7`4E5IE12XN60@e;b/4=2TU0d<e<0@j<2/4>BlZ124I5P@U6aL4<bHR12HP6`<P4`l4
6a@@11L?40@H410450/;11<;2`<N5AX45`l?11dD40@J4Q84:R0L13PY8P@C3@h3618?11/D40@D3Ph4
7Q<?12dN6P@c8AP3HCh^19:6T@Bb_l04Mgem?WMjNQGoool001CooolbMgYj17YlO0ADEUD4:QhH13D_
:`@d:BD3@cD`13X`:`@i;bX48ATF12DK5`@c9R849R0K0b0C3`@K51045`l@11P@40@D2`/44`/;0ahE
6P@G3`l47A@@11XB4P@Z81`4>2TR11<=3P<H4Pl46a@@11@>3P@N4`l4;AhJ13<Q60=Q?Rh4TXJA1;:o
`0AgOGdnMgYj5Oooo`005?ooocYgNWX4EEEB12dZ90@R6aP3>2/W14/m>@A5?c/4<RXV12<I5P@T61T4
9QLC0c4T8@@U81`45@h?11<;2`@R6Ah48APM0bdT7P@N5a/4?BdW11LB5`A??C@4<2<T12TQ7P<c9R44
;20L138U8PA6=b/4<2DQ16Q1<0>e/KD4UjF^18:9QT9gNWXEoooo000Doooo>WMjNPAEEE84;BXT128K
60<h:bL4Bcdi14Do>`@b:RH48aTF12@H6@@V5a<3<B@Q12DP70@E3Pl44`/;128I7P@Q61d3;B@N11hG
6`@m;BL45a8G14lm=0@`8b@4:B4N0c<V8@@/81`4<RDR14Hg:`@`9B44J44`0kFa]@BGYJh4PXV6@WMj
NQGoool001CoooljMgYj15EEDP@]:R@48Q/H0cP[9`A;?CT4AClk138Z9P@S6AH491PI12HG4`<a9244
9B0L11D>3`@C2`/48QTN124H7@<]91h47QLK13d]9`@G4QL4Ccdd130S90@Y8Ah3<bHQ12`P70@b9B84
ASL[130U8@AX@C03]K6e19NU[PB2RHI2MgYj5Oooo`005?ooocYgNWX4EEEB12dZ90@R6aP3>2/W14/m
>@A5?c/4<RXV12<I5P@T61T49QLC0c4T8@@U81`45@h?11<;2`@R6Ah48APM0bdT7P@N5a/4?BdW11LB
5`A??C@4<2<T12TQ7P<c9R44;20L138U8PA6=b/4<2DQ16Q1<0>e/KD4UjF^18:9QT9gNWXEoooo000D
oooo?WMjNPAEFEH4F5EN0c8Z9@@f:RD4=bdY13Th?`A0=2l4AS/g14Y2?0<^8b@4:2PY13hf@PA;@S/4
<B@U12/U;`<e9R@4?cQ613TZ8P@X81h4AcD^13<U8P@h91l3>2@K138X9@A8=BX4HD0_12`N60C8a<83
VjR_17MmODIgNWXEoooo000Doooo?WMjNPAEFEH4F5EN0c8Z9@@f:RD4=bdY13Th?`A0=2l4AS/g14Y2
?0<^8b@4:2PY13hf@PA;@S/4<B@U12/U;`<e9R@4?cQ613TZ8P@X81h4AcD^13<U8P@h91l3>2@K138X
9@A8=BX4HD0_12`N60C8a<83VjR_17MmODIgNWXEoooo000Doooo?WMjNPAEFEH4F5EN0c8Z9@@f:RD4
=bdY13Th?`A0=2l4AS/g14Y2?0<^8b@4:2PY13hf@PA;@S/4<B@U12/U;`<e9R@4?cQ613TZ8P@X81h4
AcD^13<U8P@h91l3>2@K138X9@A8=BX4HD0_12`N60C8a<83VjR_17MmODIgNWXEoooo000Doooo?WMj
NPAEFEH4F5EN0c8Z9@@f:RD4=bdY13Th?`A0=2l4AS/g14Y2?0<^8b@4:2PY13hf@PA;@S/4<B@U12/U
;`<e9R@4?cQ613TZ8P@X81h4AcD^13<U8P@h91l3>2@K138X9@A8=BX4HD0_12`N60C8a<83VjR_17Mm
ODIgNWXEoooo000Doooo@WMjNPA]KW03GVIR12lX;@@k<B/4<S@l15]<B0A6@D44@Sdh0c`f=0A;AdP4
DT4m14Hj<P@/9284?C<_0bhR8@@]8Qd4;R8L13T]:@@e:BD4ABLO14L/90=5<bT4D3hf144W7PAPC4h4
RibO1;6i_DegNWXEoooo000Doooo@WMjNPA]KW03GVIR12lX;@@k<B/4<S@l15]<B0A6@D44@Sdh0c`f
=0A;AdP4DT4m14Hj<P@/9284?C<_0bhR8@@]8Qd4;R8L13T]:@@e:BD4ABLO14L/90=5<bT4D3hf144W
7PAPC4h4RibO1;6i_DegNWXEoooo000Doooo@WMjNPA]KW03GVIR12lX;@@k<B/4<S@l15]<B0A6@D44
@Sdh0c`f=0A;AdP4DT4m14Hj<P@/9284?C<_0bhR8@@]8Qd4;R8L13T]:@@e:BD4ABLO14L/90=5<bT4
D3hf144W7PAPC4h4RibO1;6i_DegNWXEoooo000Doooo17MeM@AgO7a1MgYj15EIG0AoQGl4LWB013hg
?`AJC4T4JF9^0eM;B@A@?c/4A3Xe14Hl>0A@@444EDDo0d4j=`AGACh4A3Xa1512?`AFA3l4ASP_14Dk
<`<b9R<4QWEo18RAT0B@VIh4VjBRDGMjNQGoool001Coool4MgEe17MlO45gNWX4EEUL17n5O`AbM804
?SLo15Y<B@AYHVh3Ed]9150o>`A4>SD4AS`h1510@@AEACl3@CXg15M5?PA4>S44D48o15I4?`A6>2l4
AC/c0c8V8`B6MGl4R96@192IWPBKY:9AMgYj5Oooo`005?ooo`AgMGD4Mgal@GMjNPAEFE`4OhEo179d
P0@n=cl4FTa916URKP=GBdT4D3lk14@j=@A6?3P4D41115E5?`=1>SL4EdDn14@j<@A@@Sl4ET@o14Hh
;`A5>c<3<RHS18IeO`B8TI04T9VN19^TXU5gNWXEoooo000Doooo17MeM@AgO7a1MgYj15EIG0AoQGl4
LWB013hg?`AJC4T4JF9^0eM;B@A@?c/4A3Xe14Hl>0A@@444EDDo0d4j=`AGACh4A3Xa1512?`AFA3l4
ASP_14Dk<`<b9R<4QWEo18RAT0B@VIh4VjBRDGMjNQGoool001Coool4Mg]k17MmODUgNWX4LWAf15aT
IPB?SXL4R8fA0fUVK`AoOGL4Gee[140nA`A?Ae84ACXb0d<k=`A;?ST4@CXe14<i=PA0;bH4>C8Y1:VT
Z0=lPXH4Y:JY18VBSUUgNWXEoooo000Doooo17MkN`AgOGe9MgYj179dMPALI6H4Shj718R=T@=YIVl4
Ogeg15mMJ`A0?TL4CdMB14Dj<P=3>cL4Bchi144j=@A3>CH4@2lV13Tb:@BYY:P3O8:61:BVZ@B9TXiI
MgYj5Oooo`005?ooo`AgNg/4MgemBGMjNPAbM7H4G6AV18n>Q`B8SI43JFI_17mmM`AOGF/4@3i714m7
DPA5>S83@c/g14/n>@A1>SD4@cTf140_9P@i<RT4ZJBX0gb2QPBTYZT4RI:>FGMjNQGoool001Coool4
Mg]k17MmODUgNWX4LWAf15aTIPB?SXL4R8fA0fUVK`AoOGL4Gee[140nA`A?Ae84ACXb0d<k=`A;?ST4
@CXe14<i=PA0;bH4>C8Y1:VTZ0=lPXH4Y:JY18VBSUUgNWXEoooo000DooooHGMjNP=bM7P4OX5k16ea
M@AYLFl4PXJ41822NP>3PH44PhZ:18>8R0B1QXH4PXF318F=SPBZZjl3MgemHGMjNQGoool001CooomQ
MgYj0g9dN0AnPG/4KG5e16UaK`B2QX@4P89j0h>1P@B3RXX4PhR81866QPB2QH<4QHf>1:Z[[`=gOGeQ
MgYj5Oooo`005?ooof5gNWX3LWAh17j1N`A]LGD4JG5_18:6Q0B0PWX3Ph6118>:RPB3R8P4PHJ618:5
P`B5SHh4ZZ^_0gMmOF5gNWXEoooo000DooooHGMjNP=bM7P4OX5k16eaM@AYLFl4PXJ41822NP>3PH44
PhZ:18>8R0B1QXH4PXF318F=SPBZZjl3MgemHGMjNQGoool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool009Koool30000Qoooo`00VOooo`030000
oooooooo08Coool007koool300001?ooo`800004oooo100000;oool300000oooo`<00003oooo0P00
087oool007koool010000?ooooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`00
00;oool00`000?ooooooo`03oooo00@0003oooooool00026oooo001noooo00@0003oooooool00002
oooo00@0003oooooool00002oooo00@0003oooooool00002oooo100000;oool010000?ooooooo`00
08Koool007koool300001?ooo`800004oooo0`0000?oool200001?ooo`@00025oooo001ooooo00<0
003oooooool00_ooo`040000oooooooo00001Oooo`030000oooooooo093oool007ooool300000ooo
o`800005oooo0P0009;oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C73533F
826F627C6B687C746B7C67607C746B7C6F687C6F687C6F687C67607C6B5B736357785F54
6F5348745A4E6A53476F564A6F564A6F564A6F564A6F4F4367523F6B52496B523F6B5249
93ADBA7C7C7C7C7C7C7C7C7C7C7C7C7C73747C81817C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C74757C7D7D7C7C7C7C74757C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C74757C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7B5945
816F6A7C6B5F7C746C7C67607C746B7C6F687C6859746153756153755D4F6C564C685247
684E436C5448634D4270574B6F564A6F564A6F50446F50446752466B52486B523F6B7075
93AAB67C7C7C7C7C7C7C7C7C7C7C7C7C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7B7C7C78787C7D7D7C7B7C7C80807C7C7C7C74757C7D7D7C74757C7D7D7C7C7C
7C7C7C7C7C7C7C7C7C7C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C74533F
7D6C607C6B647C6C687C6F687C6B647C68617460515B5D5873594E714B47674F436B584C
6F5A4E6F5D506F55496B52466850446850446850446852406752466B52466B52468FA8B9
8F95987C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C74757C7D7D7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C73747C81817C7C7C7C7C7C7C7C7C7C7B7C7C80807C7B7C7C80807C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7B533F
816F6B7C6B677C6B647C6C647C68607C6B5C7B6B637C6D69846859845C5F715C4C78564A
78544F78544E6E46416750446B52466B52466B52466B524673594F6A52466B524693ADBA
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C5945
7C6F637C6B5C7C6B647C6B647C6B647C6B637C736E7C726A7B6A6278655A735D527B6054
7B635873554E7B63556D4C45734B4673615B6A514573524673534667504473605392ACB9
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C5A45
7C6B5F7C6B677C6B5F7C6B647C6B647C736B7C6B647C68617C6F687B6A62806C60776555
785E59775D52745D4E6F4F4A6E5B4B6F56476F5A536B51456852466752468782838BA0AC
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C74757C7D7D7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C6342387F604B
7C6B677C6B5F7C6B5C7C6B687C736B7C6B647C6F687C726A7C736B7C67607C6B637B6256
806256775E50775E5273524E7356476E4F43675347674D3F7352466A52468997A3828E92
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7B7C7C80807C7C7C7C7C7C7C7475
7C75757C7D7D7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C241A157E5C488B7A68
7C6B687C6B637C6B667C6B677C746B7C67607C6C5C7C70697C68607C68607C6B5C7C6B5B
745753745B507857536F57456B4F426B564A6F52466A52467460536F584B91ABB8818484
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7B7C
7C7F807C80807C7C7C7C7C7C
7C7C7C7C7C7C7C74757C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C5B4F57090201CAA495816F61
7C736F7C6B637C736B7C6B637C6C647C6F687C72697C6B677C68597C55567457496D5046
75564C785E50705E5367534474534A6E594C674F3D6752466C5347684D428EA9B67C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7B7C7C78787C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C8584850E0604846952D5B3977C6B64
7C6C687C68607C6C647C68607C6B647C6C647C70687C6760746454755451745E4D6F574B
755B4F71584C7058466A50457050446B50446F50437352486A524673594C89878A7D7F80
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C74757C7C7C7C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C100805786054CEAA9B816F617C6B68
7C6B647C6B647C6B5C7C6B647C6B647C736B7C6B647C6860733535783B3D703433703535
74373774574A6B4D426B4D446F483E6753407052466F5246675240744B4169544885959B
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7475
7C7D7D7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C5B4F5166514BD0AC9D7C68607C6B5B7C6B68
7C6B647C64557C64557C64597C6C657C6C647C52527C5756733334703D34672C2475433F
6B3B3275443F623E38684C41685240674E427453496F52466F5246734A426F5D4F765E52
7F84867C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7B7C
7C80807C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0B0606987760826C5A7C6B5C7C6B5C7C6B68
7C6B5C745C4E75594E7D70637C6F6B7C5D4E7435376D342C64443C522B1E6E6C5B7A6A60
622820692D266B3D346A473F6B57496B4A356C56437052466F52466F52466F56496F574B
8D96987C7E7F7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C74757C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C403133442B1FD9B093816F6A745D517D74707C6B66
7C5D4E6B4E3E6841388463656C2D2E20060378555070473E7B6D6385908C823E38603D32
4E34255F564E4230236D2E266450406C4B33734E47735A4F79604C6E51466F594C6F5246
725B4F7F7B787C7E7F7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C74757C7D7D7C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0D0707A3836898857E7C6B5F7354478275707C6860
7C5B4D613A2B633A332E0A0A656E697B938CBAC7C083909784959A818B8872534481A09C
838282636063371F19301C11653A2B715B46744D46796556795D507359496E52466F5044
6F5A4D7282A077777A7D7E7E7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C635D6D050101D7AC8D826F637C6B5C7B695D8176717C6B64
6C41354C342252221A260A06AD7364876251754B447D79767C604D7C65526B413A7A7477
6C42357C6B62684738675C533A1F176D392B6E4E457B65507C6A5D73594D6A52496F4A3F
6F534767716D62584D6C697A7F7F7E7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C241A150D0605583629DDB899816F627C5D517C5E537C6D617C6B5C
6A3F34705E51897B718F9281BA928E7B675C70514B72584F76333164403B6427256D2A25
60251F6F65575B3026613F4148312B3A0D067E564D7F67507D6B616F53426A4C42674F43
705C4F6F62558D8D966C65798E92877C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C74757C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C63565E000000160D0CE9BCA89788737C64587C5457746B5D7D73657C5558
6A463C5C3F2F897F798176717C68657B73687F7E75837970847767756A587F6657776A52
776958725B4B78333569332E53231842120E6A271C7B63507E645A6F54426A4C43674B40
7453476F574B1F161389848786847D7D7E7E7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C60596A745F46C98D76D6AE917D6C5C7C63577C6D627B5E5A8171627C695E
6A544468463B8D7F727D6D667C6F687C6B637C6C647C6F687C545473554A785E536F574A
74534A624E3D694C41635A43695647715C4E795855856C487C63567057456A4C4367523F
7455496F5A4D1B1E1FA9A09B7F83848184847C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C795A488A6B577B716C776D5F79685B7D6B5F7C6F6A7C69667C7E717C6B66
725A4F725145704F437B6F627D746D7C6F677C6B637C746B7C6557735D4C704A3F705946
634C3C54483E65453564423664453664413664473678624F7E645B74544762453D674B40
6C53426853470B0C0DBCB4CB9197997C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C746C6D7D5B46745D526D503E5C5C6384685A816F6B7C736E7C726A7C736B7C6F67
7B5353765A4E724D42826E6082726D7C70687C51527467577D68596B4C43705044633F34
634F45623E356B483567493F6F533966493967463483615679574B6B4D4262483D6B4E42
6B564873594F020507B4A0988A8E877C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7B5B488164576B4D43674E427B746A905B557C716B7C746B7C6F687C6F687C6F68
7C65577B65526E5543755347837A757C746B7C655F7B7569816F6972524F73594D694D42
735B4D623D33674639674A40705144734D457F5E5281695D6B4F436B50446F52466A4D42
6B56426C5347030607432F28A6A1A47C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C5A45746459532F217E74678A6567816F627C766B7C746B7C78777C6E667C6F68
7C675F7C6A5D6A52467459497E7B6D7D6D657C68597C736C7C6B63735B4D66493C6B4D42
67524667493F6E523966453A7051457E5C55816B5D735D506A594D6F584B675246675246
6B55487360554C36244F271E3729258F92927C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C5D516C37285C24215E4036727E78856E627C76627C6B687C746B7C70697C6B617C6F68
7C6760746454735B507B7062857A6E816F6374554E7D6E617C52536B4F3B663F37674B40
60453A6C4B34543B3065413A7863557E64567D65566F574B6A54486F4D426F50446A5240
734B407362556543396A4D47AECAD1CFD3D47C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C46406A342F61312D6B6553867F6F90736B7C736E7C6B667C746B7C6F687C6F687C6860
7C6859736354815F54776B5E826F6B7C736E7B686481766C7C5B506A564562443D60473B
5C413561443863473F80645581695B7965587D62566F574B6A53476F4F436F4B466F4B46
6B4B4270655F5F382A6C4F439CBDC97B7B7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C6457
7C53426A46385A412F746A58918373816F6B7C746B7C6F677C6B647C68617461537D685A
7C5555735E5179584E74645882706C7C6C5C7C68617C6B647C54536A473C61453B63473B
66493D625246745A467860527A5E517C625674574B7051456A54486F483D6F4B40674E40
67554074655F6E43366E5B4F707B867C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C6C402B
56302630201A4B342A8675698C7F707C6B687C6C647C68617C68597C6456736455795955
6D554C755F55786A5D786E608273667C6B647C6B677C6B647462546B4E3E614A3F63473B
674A3D6E51457356487E5A56795E51755B4F705E5374594D6A564A6F5549675447674D42
6B4E4874625F60281A7067596A3F3693A0A17C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C612817
1A100B34242031201F9C816E8778727C6B677C6B5C7C6B5C7C6B647C6B667B6E69806C68
765D5574514B6853447A635679695C7D6C687C6B647C6B5C73544E6643395B3C3D644835
604338715145735D4F7452466C574975544F6B4E426C5246634D426850446750446B4A3F
6B4E496C57475837226A564368393593BDC87C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C6C6569362C
3F2C2437241D332220BE947987786A7464567D6C647C6B5E634E4566514450382D523A2F
5138345B39396D5243715246725E5383716D7C6B647C6B6373535065493B5E4333674630
5F4A406D4D405E4F435B493E6A5347715E52634E41705A4D6F564A6A52466B52466B4A3F
6B4E496B56463F221A4A20186C403194BDC77C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C744E3C6B4039
060302110E0C241A18CDA0837D70627C6458816F637C6B5C715A4F57453B43342B2A2727
1F1A1A351F15593D2E4720184822198571627D6D657C6B64735B4D65483B5E4333605039
573F3675594C765E51795B4E7B55486B4C4758463C765A4D6F564A674F435C4B405E4B40
6D55496B554642251D592A1F7E433498C3D37C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C8584857A4B38653F37
1211121E1410321815DFB29381726578665A7D6F627C6B5F7B6A6661493F8868622E2622
1F120F331A124037345F372A876A599E9A86827B767C7B7973615165443B4F382D583F2E
280A07704F405E402B4C382F3A281F5E483C5C4E407656436850456750445A4439634E42
754E495C4539321D1A59352883544BA1D4DF7B7B7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C75757C7D7D7C74757C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0A01017B402F6B5449
241C1916141A21130FDDB79779685B7C6B5F78675B7564597D6C68716051795C50554539
8560508152387F543C96674C8F6B5B8273648279747C70697355456542395C3D2D5D4135
4A2B23645C572A29270403043B231D3F38301E161148342E4530226941315B4B41635044
754E42453B2E221814412820916A599CC5CE7777787C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C78787C81817C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C0C04030903032807032F201B
08080E110F0D2C1712E8B99978675B826F6B623B38694E4384726E7B72697F6B66785E59
71514470574A7C5A4F896C5886675D7C6E60827C787C6F687350496552475E42315E523B
6D45347B65576944350B090B442116372A27231A1867402F6E463785644F664B41624E42
7555421D17172017123B1F1795453490B3C07878797C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7F807C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0500003222182D16132B211C
0B07092C1813331814DFAC8D81685B78685C7A67606D605053382E533B30443228322420
2B1C1737271D432920492B217261567A706282746F7C68597350456557485E3E33664433
634E39715B4A6A51456152479A654E6C4333663E2E9B624D855C406756496C52416D574B
634E4213100F2215123F20188732249ACEDA7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0801001C0E0A17110F1D130F
1D120E1E1510362824C19478846D5F7B6F62816F6B7968607A6B5D73524C4A424379514B
6F493A7858476D483A8A64549C927F8A7A74816F6A7C5554735D5065564A5E383A3C2218
40251C69533C6D53436B52407251466E55426A574B80624C6050436B4E4D634E426D5342
45382E07080817110F9D614B6C2F21A6DBE57C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C74757C7D7D7C7C7C7C7C7C7C7C7C7C7C7C0E04021E0D0A1F14101B1310
0D06062114103C2A259C6F58876E607D70637C6B687C736B7B71697C706C85857CA18E80
88857B918D85908881998A788078698277737463547562557466546E5A4F765E53675443
43292931241C20161358372E70554A67523F6A5242634E4264453B5441366D4F47734E42
1D16130E0B0B2C231E8E4632461E15292C2B8E8D8D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7B7C7C80807C7C7C7C7C7C7C7C7C7C7C7C0905042118161E1410201310
160E0A2615113A2A2599654E9378688274667C6B687C746B7C6F687C78777C77757C7775
7C6E667C78777C6E667C6F667B6A5D816F637B6758775F5478584E7763577B6659795C57
695955805C50533E363F251D241B1537221D2E2B273F2A22432C2272524C7B5346644739
0C0B0B18100E26191A2C0E0A34120D2B2F2EDBDFE07C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0E07063B282517110E201310
1F130F28191A392A257C5540836B5C8475677C6B607C6C657C70687C70697C75717C7470
7C736E7C78777C6A607C6F687C6F667C6B5E7C6B5F735B50786256785E53786457785A57
6E5E506E584A6451436C55466C5343684232593E2F804E3F725B4D804F4F5D4F404E4135
0D0C0C1D120F1B1310150E0A2B1915393532D6DBDC7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0F05032D1E1620181521130F
250F0B2B181537231850382D8963538576677D6C607C6B687C746B7C78777C6F687C7571
7C74707C74707C6A607C6F687C68597C68607C645773544B786457786256785E53785B51
6F57497351456E5347695145785B4D75574A7E605181594B71534D724D42664C3B37251C
130D0D1D120F2B18141B130F2314103723199780838284847C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C090301332927241A17281613
150E0A2014101F130F41271E67412B8F78698270637C6B687C746B7C79787C736E7C6F68
7C75717C6B617C6B617C6F687C67577C6B60745C4E745F54785E53785C51785B50785E53
6F574B6B53476B564A6F5D506B52466F50446A52465C4A3F5E4E425E4E40473B30141414
0C0A09231719160F0F140E0A0E06062E1915755A55A2ADAC7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0E04023025232E221F271B17
2717132214102B1D19412F2B4B372D987262846E617C6C687C6C647C716A7C75717C736E
7C78777C6A607C6F687C6F687C675F746457745C51785B50785B50785E53705E5371574B
70574B6A53476F564A6F574B6F53476B52466752465A4A3F734E4262473B322520150E0E
251A17120A0B150E0F0E0606170F1026151167544EB6C2C57C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0C0706332927362925302320
271613130E0A2D181543271D603B2B91553D8673647D70647C6B647C6C647C716A7C7571
7C74707C736E7C6E667C6F687C67607B6B5A775F53705A5071574B7958536F584B745145
74544F6A54476F564A6F50446750446750446445396A4B4063413539302B2318141C1210
140E0A140D0F130A0B170F0B1910112F1914E9EBEBB3BABC7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7475746D6E0905052F23203528252F221F
1B100D271C182E1E1A2F231E613E2D7B51428676698374677C6B687C736B7C736B7C7978
7C74707C74707C6A607C6F687460527D645573544B775B507B5E52745A4E705A4B745347
6B5D516B56476748446850446752466B52466A4A3F6050444D3A2F443228221812211412
17120F1C14101C140F18100B1D14102F1914F9FFFF7B7B7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7B7C7B7E7F0705043E241B302421352824
2F231F2A1D192E211D3521185A463B5B3C2F8360517F72647D6C687C6C647C70687C7069
7C6C627C6C627C645A74615374594C79685B74574D70574571584C705745745A4F745A4E
6A564A6F54486F4E436A55466B4B406B4B405C4B404D4135462F25281B1B18100F16110F
140E0A170F10120A0B090606130A0B4A2A25EAF2F27878797C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C0E0606332017332A27372926
281D1A25151235221833252246392F42231C7B5142867E6E826F637C6B5C7C6C657C6859
7C685A7C685A7C68617B6B5A775F53785C51704B41705145745451745B4E745A51744D42
6A54486F50446F50446752466B4A3F64473B4C4136462F25281A1A22191418100D18120F
21130F170F10120A0B130A0B331A16FFFAF6C5D2D37C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C1B12112B211E3125233C2825
2E1D152B1F1C291C183226232C1F1B3326246643327B614B7C6B5F7564597D6C607C6B5C
7C6B5F7464587564597D6C5C73544A704E437057456B4F446C574B6C57487554486B4C41
6B53466F48446753466752406444395C473B483D32331E1A21191419100D120D0A160F10
221310150E100E0606140B0B311A15EEF4F47878797C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C1C140F2B211F362925312420
2D221F201518271A172F221D3729263320173F241B624B3C73574C7354497A6356755E53
7565597464587860547961556C544B67493E6C51446B4D446F4B406F51457050446B5044
674B40684B4060483A5D463A4E3E35453227402D231F161216100D16110F150E0B130A0B
130A0B090606090606321B163E1F15EBF3F47C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C493E452D1F1D3428242F221F
3D2F2B2F1E152917133B2D292C201C352824251A1745392E3C2D2656372C71594C61493E
6A575369534F695347725C515F473D473229553A30634030694C41684E42683F34684C41
674B3464473C5C4135573E324C3E3238221E2D1A141A11101B110E150F0B120A0B130A0B
0F06070A0607150B0B281611D1CBCBD0DDE17C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C777678231C14261D1A302320
322421221C192015173623192F232040312D332723352723392B294D32294C3528352E2F
34302C442D224F3E314E3D323629253B2920412B204E372655352B573D2C664131554035
49302650312952382E40332E3725202A171222131118110F140E0A110A0B0E06070A0607
0A06070A0607201511301A15F5F6F68184847C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C30282E251C1A392B27
30292530232018110E31231D3E312E3D2F2B3F322E40332F4B3B3147382E3A3128302424
321F17351F1D3C251F3C2B25291F1F3123213D241E3F261A3B241F4A3528463127392920
4430253D281E3C2F2834221D2F1E171D1311221A18120E0A160F0B120A0B0F06070A0607
0B06072615111A101187635CE1EAEB7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C635C66221713302420
2F232031231F2F2320402F2A40312D3F322E33272332262338211E43251E3420182B201F
2318152F24222315122C242128201F281E1A241411211916211413271512271C15271B15
291D162112112414121F131120141214100E140E0A10090A130A0B130A0B0A06070A0607
26151B261510372925F4EEEAA5B2B47C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7A797B3A343229201D
312420372926302420443631281D1A3B2D2A251B183629254A342A3329252A22202D2422
2A1E1A422C281F141529231E2615122515121C110E19130F1F120F2917142718141C110F
1C110F1C110F2817141C120F1E130F140E0A170F0B120A0B130A0B0A06070A0607150B0B
34201B2A1813E3E6E6CFD3D47C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C5B4F57211210
3629263729262F221F261F1B372A274637322C26222D201C3E241A1F17152A1E1A2B1F1B
1B151B29211C1D14152A18131E111719130F19120F160F0B1C13101B131019130F140E0A
110A0B160F0B211310140E0A110A0B160F0B170F10120A0B0A0607130A0B1F151132201B
301A15D8DBDCD8DFE07C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C797879271F1B
2B231F3528252F221F362925352B27342724251B18251815281B1719100E2F221D211617
21161720130E1E1117150E0E10090A160F0F170F10120A0B180F10120A0B170F10120A0B
170F101E1510180F10110A0B0906070A06070A06070A06061810101A100B140B0B230F0B
CFC7C8D9E1E17C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C706F70
3F3431291E1A302320312A262F28243E2E2A2E2224261512281B1818120E21141017110E
1F130F10090A120A0B160F0F170F0F130A0B180F10120A0B181010120A0B301A15090606
1910101D1410160E100906060A06071006071A10111A10101A10112E19143A241A7E4C37
EAF3F58184847C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
706F703E2E2C3029262A1F1B3E2E2A3D2E2A382B28241E192E221D1D1117170F0F201310
170F101A130F1D1410181010130A0B130A0B140B0B130A0B140B0B1D14101910102D2D3C
383131211318120A0A170F0F1F15101F151019101135241E2D1D192E1914593429D2D9DD
AABEC87C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7876763E312E3A2C282C201C2F272440332E372B27331F16251A1719130E180F10
110A0B180F0B170F10120A0B130A0B181010130A0B181010130A0B140B0B332F312E1E2B
47352B43322D34272649373032231D1B130F2C1D192F1E19392B274F2B22D9D5D5B8CBD0
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7D7D7D6B6A6B3A271F3C312D382A264535303D302C3E312D231917271B17392824
2C231E2314101C1410170F0F181010130A0B130A0B1E151A170F0F1D1410191011281E1A
372720100B0C140F0C18110E110C0D1D110E2D1E1A35211869402FA699A5BFD2D67C8080
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C6F6D6C3D352E241B183729254C3D394A423E392E2A261A17231718
25151234252129221E160E0F130A0B23191E23191F2F251F20171C42302A1A1218533F37
3324262E231F3A292431221E382824503D2F362824714633CDCBD0ACBFC98A918C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C6F6E6E7E758340332E362925342926393740483A3653433F
564C453326282A292B463B4B5D4F473A292A302732382726463D4C3E2D252D211F49362F
3625223C241F3C241B3529264E372C6A4231331F18D5D7D7AABDC77C80807C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7877787F858141353D40332E33333C5C4E4B4B4547
453E3A433A37564F4F5B46404B3B323025224235303223222C201B2C1F193B2E2A372926
47271E4C2D244C352B5A423947271F614C50A4B8C1C6D3D87C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C75757C7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C6F6E70A8AFA99C99A74B3F4A5E4D4C
766B7A66545659433E483A35493C39594447624B454D403D664E46514137584844624A45
4E3E34483F373326248A7B88A6B4B8B2C3C8AAB6B47C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7F807C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7A797B787C7AAEB0A6
9FA7A77D79839997947874874B4655514A59453A34443B384B3D3A443A374639373F2D24
383027B9B5BAA7AEB4C1C8CA939D987C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7A797C858880787B7D838A83A3A79FA2A59BA7A4A6A7AEB0A7ADAFA6ADAEA9AFB0
AEB8BDBCC1C77C80807C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?oooeUlO7`4Le<o189_HP=lJfP4O7A[17aWH0AlM6/;O6mX17aW
H0AlJe/4Lf=G17QOE0A_DdP4M5Y>0fYCAa1_ETX4Kdm30fMB?`A[DTT4Je8o16]BB@BC[KX?O7al17ac
M0AlPH4SO7al5Oooo`005?oooeUlO7`4Le<o189_HP=lJfP4O7A[17aWH0AlM6/;O6mX17aWH0AlJe/4
Lf=G17QOE0A_DdP4M5Y>0fYCAa1_ETX4Kdm30fMB?`A[DTT4Je8o16]BB@BC[KX?O7al17acM0AlPH4S
O7al5Oooo`005?oooeUlO7`4Le<o189_HP=lJfP4O7A[17aWH0AlM6/;O6mX17aWH0AlJe/4Lf=G17QO
E0A_DdP4M5Y>0fYCAa1_ETX4Kdm30fMB?`A[DTT4Je8o16]BB@BC[KX?O7al17acM0AlPH4SO7al5Ooo
o`005?ooo`AlO7`4O7Ae17amO@AlO7`4O7Ae0gamOB=lO7`4O7Ae17amOAMlO7`4NeU5185_JP=lJel4
O7A/17aWH0AlM6/4O6mX17aXF@=dHE<4MF5C17EMC`A/ET`4J59716Q>@`A/E4P3Hde2171GB`Q_ETX8
Ke140fMBAPA[DTP4Je8o16]`M@BCZ[H?O7al17akO0AlP80SO7al5Oooo`005?ooo`AlO7`4O7Ae17am
O@AlO7`4O7Ae0gamOB=lO7`4O7Ae17amOAMlO7`4NeU5185_JP=lJel4O7A/17aWH0AlM6/4O6mX17aX
F@=dHE<4MF5C17EMC`A/ET`4J59716Q>@`A/E4P3Hde2171GB`Q_ETX8Ke140fMBAPA[DTP4Je8o16]`
M@BCZ[H?O7al17akO0AlP80SO7al5Oooo`005?ooo`AlO7`4O7Ae17amO@AlO7`4O7Ae0gamOB=lO7`4
O7Ae17amOAMlO7`4NeU5185_JP=lJel4O7A/17aWH0AlM6/4O6mX17aXF@=dHE<4MF5C17EMC`A/ET`4
J59716Q>@`A/E4P3Hde2171GB`Q_ETX8Ke140fMBAPA[DTP4Je8o16]`M@BCZ[H?O7al17akO0AlP80S
O7al5Oooo`005?ooo`AlO7`4O7Ae17amO@AlO7`4O7Ae0gamOB=lO7`4O7Ae17amOAMlO7`4NeU5185_
JP=lJel4O7A/17aWH0AlM6/4O6mX17aXF@=dHE<4MF5C17EMC`A/ET`4J59716Q>@`A/E4P3Hde2171G
B`Q_ETX8Ke140fMBAPA[DTP4Je8o16]`M@BCZ[H?O7al17akO0AlP80SO7al5Oooo`005?ooo`AlO7`4
O7]l17ahN0AlOGd4O7]l0gb0P0AlO7`4O7Ae17amO@AlM7D4O7em3galO0AlNg`4O8205galO0AdDcl4
OFaP0ga[I0AlK6P4O6mX17a[I0AlJ644M61A0e]MF0AcFDh4LD]716M?@`A[F4`4KeY>16mMD0=_EDT4
Je9636Q@A0AXDT03Ie9626]BAPB?Z;T4SiFH4galO0AlM7D4O7em7galO1Goool001Coool4O7al17ak
O0AlN7P4O7em17akO0=lP804O7al17adM@AlOGd4O7Ae17amO@mlO7`4O7]l17b0P1MlO7`4M5<o17e/
H0=lJf@4O6aX17a_J0AlJf@4O6QQ17APD@=KGEP4LeU>175;A`AWCd<4JeQ<16mJCPA_GE03KeE916]B
APaXD4@4J5900fMBAPQ[DTH4SjRi18nEV1=lO7`4O7Ae17amOAmlO7`Eoooo000Doooo17alO0AlNg`4
O7Qh17amO@AlNg`3O82017alO0AlM7D4O7em17adM@AlOGd?O7al17akO0AlP80GO7al17AC?`AmK603
O6]T17a/J0AlKfP4O6]T17aXH@AdH543FeeH17=ICPAaBdL4Idm316]HC0A_FTh4Kee@0fmEB@A[DTH<
J51416QB@0=WDTH8Je9618nX^@B?UIPCO7al17adM@AlOGdOO7al5Oooo`005?ooo`AlO7`4O7]l17ah
N0AlOGd4O7]l0gb0P0AlO7`4O7Ae17amO@AlM7D4O7em3galO0AlNg`4O8205galO0AdDcl4OFaP0ga[
I0AlK6P4O6mX17a[I0AlJ644M61A0e]MF0AcFDh4LD]716M?@`A[F4`4KeY>16mMD0=_EDT4Je9636Q@
A0AXDT03Ie9626]BAPB?Z;T4SiFH4galO0AlM7D4O7em7galO1Goool001Coool8O7al17acM0AlPH4;
O7al17akO0AlP804O7]l17b0P2ilO7`4Ne<o185_J`=lJfL4O6]T17a/I0AlJ604O6]L17][H`=lKFT4
Q6QI18ALG`AaG4`4N5I:17QDC`AhE4h3KTI116M@A11[DTH3LeU?16YBAPA[DTH4Tjfj5galO0AlNg`4
O8207galO1Goool001Coool8O7al17acM0AlPH4;O7al17akO0AlP804O7]l17b0P2ilO7`4Ne<o185_
J`=lJfL4O6]T17a/I0AlJ604O6]L17][H`=lKFT4Q6QI18ALG`AaG4`4N5I:17QDC`AhE4h3KTI116M@
A11[DTH3LeU?16YBAPA[DTH4Tjfj5galO0AlNg`4O8207galO1Goool001Coool8O7al17acM0AlPH4;
O7al17akO0AlP804O7]l17b0P2ilO7`4Ne<o185_J`=lJfL4O6]T17a/I0AlJ604O6]L17][H`=lKFT4
Q6QI18ALG`AaG4`4N5I:17QDC`AhE4h3KTI116M@A11[DTH3LeU?16YBAPA[DTH4Tjfj5galO0AlNg`4
O8207galO1Goool001Coool8O7al17acM0AlPH4;O7al17akO0AlP804O7]l17b0P2ilO7`4Ne<o185_
J`=lJfL4O6]T17a/I0AlJ604O6]L17][H`=lKFT4Q6QI18ALG`AaG4`4N5I:17QDC`AhE4h3KTI116M@
A11[DTH3LeU?16YBAPA[DTH4Tjfj5galO0AlNg`4O8207galO1Goool001Coool8O7al17akO0AlP819
O7al17aIA@AlKf<3O6]L37a[I0AlJf<4O7=^0gabJPAkJV84N6EJ17=MDPAkH5@4Nf=H17=ECP=kHeD4
KDa517=;APAcHE/4JU5517=BAP=cDdH4Ie1417=PD`BB[;TnO7al5Oooo`005?ooo`QlO7`4O7]l17b0
P4UlO7`4O5U517a_H`=lJe`<O6]T17a[H`AlLfh3O79Z17]ZHPAhIEX4LeeB17]PE0AkHeP4LeE>0g]S
E@A]C4D4Ld]617=QF`AZDDD4Le960g=CAPAWD4@4Lf1C19:/^CilO7`Eoooo000Doooo27alO0AlNg`4
O820BGalO0AlFDD4O6mS0ga[G0alJf@4O6]S17acKP=lLVX4NfYR17QUFPAcGE84Nf1D17]SF0AcEDh3
Nf=E16e<A@AcBdH4Lf5K16YAA@AcDTH3Le=616M@A0AcH5<4TZbi?WalO1Goool001Coool8O7al17ak
O0AlP819O7al17aIA@AlKf<3O6]L37a[I0AlJf<4O7=^0gabJPAkJV84N6EJ17=MDPAkH5@4Nf=H17=E
CP=kHeD4KDa517=;APAcHE/4JU5517=BAP=cDdH4Ie1417=PD`BB[;TnO7al5Oooo`005?oooeUlO7`4
O5Y517a[G`=lJfL4O6]O27a[I0AlLf/4O6]T0gaXH@AlKfP4NfYR181/H0AgIED4N5iI17MMDP=dGDh4
Kdm:16iKB`A_ETL4KeYC16]AA@=XDTH4Ie9618N2P`B;X:`KO7al17adM@AlOGdKO7al5Oooo`005?oo
oeUlO7`4O5Y517a[G`=lJfL4O6]O27a[I0AlLf/4O6]T0gaXH@AlKfP4NfYR181/H0AgIED4N5iI17MM
DP=dGDh4Kdm:16iKB`A_ETL4KeYC16]AA@=XDTH4Ie9618N2P`B;X:`KO7al17adM@AlOGdKO7al5Ooo
o`005?oooeUlO7`4O5Y517a[G`=lJfL4O6]O27a[I0AlLf/4O6]T0gaXH@AlKfP4NfYR181/H0AgIED4
N5iI17MMDP=dGDh4Kdm:16iKB`A_ETL4KeYC16]AA@=XDTH4Ie9618N2P`B;X:`KO7al17adM@AlOGdK
O7al5Oooo`005?oooeElO7`4Hd8h17mPB`AlJfL3O6]O17a[G0AlJfP4O7=[17a[I0AlKfP3O79Z17ac
J`AlIf04O6]S17]REPB0HUH4Mei@0gMNDPAcDTh4LeI716i?@`AWDdL4Iddo0g=BAPAZDTH4RINS18:>
TQ]lO7`4O7]l17b0P0MlO7`4O7Ae17aeM@AlOGd8O7al5Oooo`005?oooeElO7`4Hd8h17mPB`AlJfL3
O6]O17a[G0AlJfP4O7=[17a[I0AlKfP3O79Z17acJ`AlIf04O6]S17]REPB0HUH4Mei@0gMNDPAcDTh4
LeI716i?@`AWDdL4Iddo0g=BAPAZDTH4RINS18:>TQ]lO7`4O7]l17b0P0MlO7`4O7Ae17aeM@AlOGd8
O7al5Oooo`005?oooeElO7`4Hd8h17mPB`AlJfL3O6]O17a[G0AlJfP4O7=[17a[I0AlKfP3O79Z17ac
J`AlIf04O6]S17]REPB0HUH4Mei@0gMNDPAcDTh4LeI716i?@`AWDdL4Iddo0g=BAPAZDTH4RINS18:>
TQ]lO7`4O7]l17b0P0MlO7`4O7Ae17aeM@AlOGd8O7al5Oooo`005?oooeElO7`4Hd8h17mPB`AlJfL3
O6]O17a[G0AlJfP4O7=[17a[I0AlKfP3O79Z17acJ`AlIf04O6]S17]REPB0HUH4Mei@0gMNDPAcDTh4
LeI716i?@`AWDdL4Iddo0g=BAPAZDTH4RINS18:>TQ]lO7`4O7]l17b0P0MlO7`4O7Ae17aeM@AlOGd8
O7al5Oooo`005?oooe5lO7`491XE17iLB0B;NVP4O6]X0ga[H`AlJfH4O6]W17adJ`AlIf04O6aL0ga`
J@QlJ604O6]L17a[F`AdEe<4M5]@0gQGD`A_EdD4Jdm216]FBPA_DTH4JU960gAPD`A_F4/4TJ^h1864
Q2YlO7`4O7]l17aoP0AlP808O7al5Oooo`005?oooe5lO7`491XE17iLB0B;NVP4O6]X0ga[H`AlJfH4
O6]W17adJ`AlIf04O6aL0ga`J@QlJ604O6]L17a[F`AdEe<4M5]@0gQGD`A_EdD4Jdm216]FBPA_DTH4
JU960gAPD`A_F4/4TJ^h1864Q2YlO7`4O7]l17aoP0AlP808O7al5Oooo`005?oooe5lO7`491XE17iL
B0B;NVP4O6]X0ga[H`AlJfH4O6]W17adJ`AlIf04O6aL0ga`J@QlJ604O6]L17a[F`AdEe<4M5]@0gQG
D`A_EdD4Jdm216]FBPA_DTH4JU960gAPD`A_F4/4TJ^h1864Q2YlO7`4O7]l17aoP0AlP808O7al5Ooo
o`005?oooe5lO7`491XE17iLB0B;NVP4O6]X0ga[H`AlJfH4O6]W17adJ`AlIf04O6aL0ga`J@QlJ604
O6]L17a[F`AdEe<4M5]@0gQGD`A_EdD4Jdm216]FBPA_DTH4JU960gAPD`A_F4/4TJ^h1864Q2YlO7`4
O7]l17aoP0AlP808O7al5Oooo`005?ooo`QlO7`4O7Ae17amOCelO7`4FdmG10T20@C:Y9D4PFmQ17ac
K`=lJf<4O7=[17a[H`AlK6@4O6mX17abJ@=lJfL4O6QI17aEEPAdEdT4KE1617EFC0AhGU03L5iC16MC
A0AdDdX4KUU<16M??@AWDTH3K5=716Q=@PB>ZKI2O7al5Oooo`005?ooo`QlO7`4O7Ae17amOCelO7`4
FdmG10T20@C:Y9D4PFmQ17acK`=lJf<4O7=[17a[H`AlK6@4O6mX17abJ@=lJfL4O6QI17aEEPAdEdT4
KE1617EFC0AhGU03L5iC16MCA0AdDdX4KUU<16M??@AWDTH3K5=716Q=@PB>ZKI2O7al5Oooo`005?oo
o`QlO7`4O7Ae17amOCelO7`4FdmG10T20@C:Y9D4PFmQ17acK`=lJf<4O7=[17a[H`AlK6@4O6mX17ab
J@=lJfL4O6QI17aEEPAdEdT4KE1617EFC0AhGU03L5iC16MCA0AdDdX4KUU<16M??@AWDTH3K5=716Q=
@PB>ZKI2O7al5Oooo`005?ooo`QlO7`4O7Ae17amOCelO7`4FdmG10T20@C:Y9D4PFmQ17acK`=lJf<4
O7=[17a[H`AlK6@4O6mX17abJ@=lJfL4O6QI17aEEPAdEdT4KE1617EFC0AhGU03L5iC16MCA0AdDdX4
KUU<16M??@AWDTH3K5=716Q=@PB>ZKI2O7al5Oooo`005?ooo`QlO7`4O7]l17ahN0AlOGdeO7al18F4
Q@@>1P@4Q6UB1=FcU`AlJf@4O6aX0gaXH0AlK6@4O6QP17a[I0AlK6@4O71X0gaWH0AdI5@4MEAA17AN
C@A_Ed/4ME]?175HC0=`F4H4JU15171@A0A[D4@4Ke1317=BB0=ZDTH4LeU<18V7RPAmOh0nO7al5Ooo
o`005?ooo`QlO7`4O7]l17ahN0AlOGdeO7al18F4Q@@>1P@4Q6UB1=FcU`AlJf@4O6aX0gaXH0AlK6@4
O6QP17a[I0AlK6@4O71X0gaWH0AdI5@4MEAA17ANC@A_Ed/4ME]?175HC0=`F4H4JU15171@A0A[D4@4
Ke1317=BB0=ZDTH4LeU<18V7RPAmOh0nO7al5Oooo`005?ooo`QlO7`4O7]l17ahN0AlOGdeO7al18F4
Q@@>1P@4Q6UB1=FcU`AlJf@4O6aX0gaXH0AlK6@4O6QP17a[I0AlK6@4O71X0gaWH0AdI5@4MEAA17AN
C@A_Ed/4ME]?175HC0=`F4H4JU15171@A0A[D4@4Ke1317=BB0=ZDTH4LeU<18V7RPAmOh0nO7al5Ooo
o`005?ooo`QlO7`4O7]l17ahN0AlOGdeO7al18F4Q@@>1P@4Q6UB1=FcU`AlJf@4O6aX0gaXH0AlK6@4
O6QP17a[I0AlK6@4O71X0gaWH0AdI5@4MEAA17ANC@A_Ed/4ME]?175HC0=`F4H4JU15171@A0A[D4@4
Ke1317=BB0=ZDTH4LeU<18V7RPAmOh0nO7al5Oooo`005?ooo`QlO7`4O7Ae17alO0AlP80eO7al1108
1@AhH5@4cZZK185_H@AlJfP7O6]T17a[G0QlJf@4O7=[17a[I0=lJ604LcDe17Pk?@A`=3<4L3De17@g
=`AdEdX3Jde216]=A0A_B3h4Ie=0171BAPA_DTH3Ie9017A;@@AYE4P4QIFK:WalO0AlM7D4O7em37al
O1Goool001Coool8O7al17adM@AlO7`4O820=GalO0@@20D4N61D1<jZV`B1Kf44O6]X1ga[I0AlJe`8
O6]T17acJ`AlJf@3O6QP17<e=@Ah>cd4L3@c170e=@Ad=cL4M5M:0f]=@PA[CD@4KdPn16MC@0A`DTH4
Ke960fMB@0AdBd44JEA818FEVbYlO7`4O7Ae17amO@alO7`Eoooo000Doooo27alO0AlM7D4O7al17b0
P3ElO7`440P517QPE0C>ZY/4PFmQ17a[J0MlJf@4O6]L27a[I0AlLf/4O6]T0gaXH0Ac=CD4N3/m170d
<`A`=CD4M3Lg17AGBP=[CD84Jde416m8?PAWDd04L59616mBAP=WDT04M4]116UDB0B5UI/ZO7al17ad
M@AlOGd<O7al5Oooo`005?ooo`QlO7`4O7Ae17alO0AlP80eO7al11081@AhH5@4cZZK185_H@AlJfP7
O6]T17a[G0QlJf@4O7=[17a[I0=lJ604LcDe17Pk?@A`=3<4L3De17@g=`AdEdX3Jde216]=A0A_B3h4
Ie=0171BAPA_DTH3Ie9017A;@@AYE4P4QIFK:WalO0AlM7D4O7em37alO1Goool001Coool8O7al17ak
O0AlP80fO7al0e]?D@AVDD/4d:bM17aXH0AlJe/4O6]X17a[I0MlI5D4O6AI17a/I@AlK6@4O59B0gaG
EPAc<c@4L3dd16L/90Ae@cl4Jc/b17E4?`=R?SP4J4a116QB@0AWCT84M5=91fmBAPAcBT84Kee?17IN
DPAoQ8HVO7al17akO0AlP80<O7al5Oooo`005?ooo`QlO7`4O7]l17b0P3IlO7`3FdmA16IAB`C@[9d4
O6QP17a[F`AlJfP4O6]T1gaTE@AlI5T4O6aU17a/I0AlDU83O5MF17<c=0A`?C@4Ib`T17E3?`A[>c84
MD@o0f8n>0AXC444J59016M>@PAdDdT7Ke9617=:@PA_GDl4MUiB17n4QRIlO7`4O7]l17b0P0alO7`E
oooo000Doooo27alO0AlNg`4O820=WalO0=KCe44IU5;1=2/W@AlJ604O6]K17a[J0AlJf@7O6AE17aT
F@AlK6D4O6aT17aBDP=lEeH4Lc<d170m=0AW;2@4MD<o16/k<PAeA3l3HShh16Q<@@AXDT04Idi217AC
B@M_DTH4LdY216mMC`AfGU84OhB69WalO0AlNg`4O82037alO1Goool001Cooom6O7al0`/61PBHMf04
PVaJ27a[G0AlJfP4O6]L0gALCPAeFDh4OG1S17a_J`AlGDh4M3Dg0fdd;0ATA3`4DR/N16i/F`AjJV04
HRPP16T]9P=[?C@4JTLo16]GB@A[BSD4K5I3171BAPM_DTH4KeI916mGB`B=UYP4O7io=WalO1Goool0
01Cooom6O7al0`/61PBHMf04PVaJ27a[G0AlJfP4O6]L0gALCPAeFDh4OG1S17a_J`AlGDh4M3Dg0fdd
;0ATA3`4DR/N16i/F`AjJV04HRPP16T]9P=[?C@4JTLo16]GB@A[BSD4K5I3171BAPM_DTH4KeI916mG
B`B=UYP4O7io=WalO1Goool001Cooom6O7al0`/61PBHMf04PVaJ27a[G0AlJfP4O6]L0gALCPAeFDh4
OG1S17a_J`AlGDh4M3Dg0fdd;0ATA3`4DR/N16i/F`AjJV04HRPP16T]9P=[?C@4JTLo16]GB@A[BSD4
K5I3171BAPM_DTH4KeI916mGB`B=UYP4O7io=WalO1Goool001Cooom6O7al0`/61PBHMf04PVaJ27a[
G0AlJfP4O6]L0gALCPAeFDh4OG1S17a_J`AlGDh4M3Dg0fdd;0ATA3`4DR/N16i/F`AjJV04HRPP16T]
9P=[?C@4JTLo16]GB@A[BSD4K5I3171BAPM_DTH4KeI916mGB`B=UYP4O7io=WalO1Goool001Coool@
O7al17adM@=lOGd[O7al140a<`=4:al4fK2C185_JPAdGE44OGA`17a[IPAlGDh3Jdhn16Q1>0B4HfD4
K2d^12060`AhEE03L4Ln17]]H`B5T8`4PShh160m<PA>=2D4GeI>0d8`8`A];RH4I51016a;<`AcCTL4
LeY?0gUPC0A^DDH4KeU<16mBAPAbFdl4Og]h17anOc9lO7`Eoooo000Doooo47alO0AlM7D3O7em:gal
O0A0<C<3A2/O1=V`T`B1KfX4M5eA17edL0AlJfH4O5e>0f]>?PAX@CP4Q6=U16`];P@P1P<4N5E@0g17
?PAkKF<4QI2<188n>0AP?C84CS@U15mFCP=2<2<4KBhV16A@@0A/Bc<4Ldi717=JC`=iH4`4KU5616mI
C0A_DTH4LU]?17mkN0AlOWlbO7al5Oooo`005?oooa1lO7`4O7Ae0gamOB]lO7`4@34c0d@[7`CI/9<4
PFmZ17AMD@AmM704O6]V17aMCP=[CSh4J44h18ASI@A/;Bh480H317QED0=`Ach4NfeS18F@S0B2?SP4
H3db14hd9@AOETh3@S0S16d^9PATD404K4/c17=>A`AcFTl3NF1<16iAAPA_FD`4Ke96179KC`AoNgP4
O7io<WalO1Goool001Coool@O7al17adM@=lOGd[O7al140a<`=4:al4fK2C185_JPAdGE44OGA`17a[
IPAlGDh3Jdhn16Q1>0B4HfD4K2d^12060`AhEE03L4Ln17]]H`B5T8`4PShh160m<PA>=2D4GeI>0d8`
8`A];RH4I51016a;<`AcCTL4LeY?0gUPC0A^DDH4KeU<16mBAPAbFdl4Og]h17anOc9lO7`Eoooo000D
oooo27alO0AlM7D4O7em17akO0=lP80[O7al10d71`>SPfP4V8En17a[G`AcE4L4PWE`17aXH0AlFdd3
HCX[16<j<`@^2PX4IFiY17^CS0Bjal03Pi2G18BEVPB1RhP4LU=4186PW0B3PX84Hf1S0cLO6@@`7144
ICX[175KAPAdCDH4NFEF0gUMD0AcFDT4KU9616m@A0A_FTd4LX:P17MgNP=mOWh_O7al5Oooo`005?oo
o`QlO7`4O7Ae17amO@AlNg`3O820:galO0@=1`L3Xh=X19R5OPAlJel4LeA7189eL0AlJ604O5]=0f4j
:`AS>S<4;PX:16E^J@AkTh`4^/O00h>@U`B4UIX4PH^8179CA0B1X9`4Ph:216=PH`<g7aT4<1`A16Dj
:`AaFdH4M4e617UUEP=iGE04LeU916iBAPA_D4@4KeY=17:2X0AgMgX3OGin;galO1Goool001Coool8
O7al17adM@AlOGd4O7]l0gb0P2]lO7`43@L70j>3J0BHQGh4O6]O17=DA`B2MG04O6QP17aKC@=Q>R/4
HcXc12h:2PAUKVT4Ni><1;[7`0>3T9L4Q9FJ186;R0AbDd@4PJ2L18>2PPASH6<3=alI130L4@AU>R/4
LE]617A=APAiIEH3NEe@17=IB@A^DTH4Ke1416mJC@AbPZ04MgMj0genORmlO7`Eoooo000Doooo27al
O0AlM7D4O7em17akO0=lP80[O7al10d71`>SPfP4V8En17a[G`AcE4L4PWE`17aXH0AlFdd3HCX[16<j
<`@^2PX4IFiY17^CS0Bjal03Pi2G18BEVPB1RhP4LU=4186PW0B3PX84Hf1S0cLO6@@`7144ICX[175K
APAdCDH4NFEF0gUMD0AcFDT4KU9616m@A0A_FTd4LX:P17MgNP=mOWh_O7al5Oooo`005?ooo`QlO7`4
O7]l17b0P2ilO7`4Hee]10D10@?G[8d4PVmS17a[G0AkJEd4PGIa17a[I0A/@CD3C3@R158R6P@V2PH4
[G=T18MRD@AeBd@3OGUf17aPC@AlIE84Jd4j17YdM`A/@SD4O6]R0fQ7>0AWG5<4>QlG16di:`A^CTD4
NfE@0gaZG@AcFDd4JU9916m:?`A_DdL4Ig5]169HC@=/JGX4Ogmn:galO1Goool001Coool8O7al17ak
O0AlP80^O7al16=MK@@50@43ejb=189_H`AlJe`4NfUM185fL@AlJf@4K44e0d`d8PAB8QX49PX61:ec
I0B7HU44MD]40geiMPAlH4d4O6EB16]1>PAjM7L4K48e17a[HP=XAcP4IeaC13XO5`A]>B/4KTi517]U
D0=lJUd4LeU=16YBB@A_BSl4Ke=716MaK@ARF4d3K6Uj17moOR]lO7`Eoooo000Doooo27alO0AlNg`4
O820;WalO0ASGFd41@410mN/S@B2Kf<4O6]L17]YG@B1MW44O6]T16a1=@=<=284DR8J12H:1PB]Lf@4
Qf9A17E;A0=mNGH4O61=17aUDPA[@CX4NWAg16a2=@AlJf83J4Lh16MLD`@j7aL4KCT[16i>A@AkIE03
O6YM17=IC@AZDTT4KdXo16mCA`AWLFd4HUQ=0faYNPAoOgh[O7al5Oooo`005?ooo`QlO7`4O7]l17b0
P2ilO7`4Hee]10D10@?G[8d4PVmS17a[G0AkJEd4PGIa17a[I0A/@CD3C3@R158R6P@V2PH4[G=T18MR
D@AeBd@3OGUf17aPC@AlIE84Jd4j17YdM`A/@SD4O6]R0fQ7>0AWG5<4>QlG16di:`A^CTD4NfE@0gaZ
G@AcFDd4JU9916m:?`A_DdL4Ig5]169HC@=/JGX4Ogmn:galO1Goool001CoooljO7al12@J5@@=1PD4
F3HY0mfhV@B1Kf84O5eA17aND`AlKF44O6]L16Xo=0=`GU44RG]a18nBP@BjTXh4NfML171AB`=bF4l4
MS<a16A0>`AT9bD4KBXU160U7`A_IEL3Fc0V164o@@A8<B/4>Pd617iFC@AoIe03OF]Q16mC@PAZC484
Idm3171LC`A_HUD4SHfF0faUN@B>TXL[O7al5Oooo`005?ooocYlO7`491XE10d61@AH=RT3gKRI185_
HPAlGE44O5iC17a]H@AlJe`4JSld0g1ND@B9Ng44Si:11;ZBSPAkIe`4L55;0g9HC`Af<c44I40k16@W
9@A]:RD4H2DO16mUE`=K<2H4HCm114Pa:`@j3@H4OUI=17mWD0=mJf44Ke=216Y<@PAWCd<4L5a?16mR
E@B=SIH3K6Ei18jBQb]lO7`Eoooo000Doooo>WalO0@T6QD43@H515Pf:@?M^9T4PFmR17aMD@AlGU<4
O6eQ17a[G0AZ?c@3L5iA18UkL@B?TX44^Y:>17]WG0A`DD/3LUQ?17Hc<@AT@3/4I2LU16dZ9@AP9Al4
KfEG0e/`9PAQ?d44B34[13X=1PAnETd4OfM@0ge[H@A_Dd84JTa216M?@`A`G4l4Kf9E18f=UP=/IGT4
SY:7:galO1Goool001CooolDO7al0gadM@AlOGdKO7al16=FGP@000045Pd<1>VlZ0>GR7<4O6AH17aD
E`AdJed4OG=U17aEF0AZAS`3G3l_18UoN@B1MW44O6QU17]cJ0AoOWD3PgU`18AgI`AeJUP4OfIG17MZ
DPAgJEP4LU];0gPc=@AY<bh4Db<H148B3PAZ9a`4Nf=@0giTFPA_E484JTa316M;@0AdDdL4KeM;11lF
4`>9Q8L4QXAm17enORMlO7`Eoooo000Doooo57alO0=lM7D4O7em6galO0ASEUh4000011H=30CY_:P3
UhQc17aTF0AlE5L4M6]M17ecI@AlEEP4JTHl0e`o;`B9OgT4PGIa17aXI@AkLfP4Ogie0h=iL0B4MfL4
MFYH17mVE`AgJU84MfUH179KB`=h<cD4JC<^15<S60A24Ph4JRLL17]SD0=nI5X4KeA216Y<@`AWBd04
M5=716mGB`@O5Q<3RHB718J4O@AmOWhWO7al5Oooo`005?oooaAlO7`3O7Ae17amOA]lO7`4HeIN1000
00@F3@`4jKbX0iN8L`AlI5P4O5AG17A[G@AmLfD4O5EH16Y6?0=L?bl4RGmi185fL@AlJ6D4Ng=X17mn
M@>3NG04Q7MW17EZF0AoIUL4MfYB17MYF0AbFd/3N3<e16Tc;PAC8aP4@Q8>16XW70AkHe03OVAJ16mD
@PAZC4<4Id]017ACA`A_Ed/47aHC0hV4Q`B6Q7d4OGin9galO1Goool001CooolDO7al0gadM@AlOGdK
O7al16=FGP@000045Pd<1>VlZ0>GR7<4O6AH17aDE`AdJed4OG=U17aEF0AZAS`3G3l_18UoN@B1MW44
O6QU17]cJ0AoOWD3PgU`18AgI`AeJUP4OfIG17MZDPAgJEP4LU];0gPc=@AY<bh4Db<H148B3PAZ9a`4
Nf=@0giTFPA_E484JTa316M;@0AdDdL4KeM;11lF4`>9Q8L4QXAm17enORMlO7`Eoooo000Doooo57al
O0=lNg`4O8206galO0APFFX4M5m61<V=MPCF[Y43OFaL17aSE`AlKF84NeiJ185aHPAlJEh4JUA40fQ6
>`B=Og84OFeV17a_J0AlJf<4O6aT0ga_J0AlE5@4LeE:17QND`A_EdX4M5=:169>?@=YC444HeY316UF
A`AaG4h4NEQE18E/B0=lHeH4L5M516Y<@`AWDSl4M5E916mJC@@K7Ql3ZJ2K17n3Q0B1Q8@WO7al5Ooo
o`005?oooaAlO7`3O7]l17b0P1]lO7`4H5UZ17AOAPC9SGH4eZjA0ge/G0AlHeL4O6eR17]NFPB1LF84
O6UN16YDA0=XAS/4SGmb17e]IPAlKfP4O6]S17a/I0=lKfP4O5AD17=EBPAhGU<4KeM:17ACBPARCSd3
JDa116=J@`AYETL4LEa>17UHE@B5K4P3O6=F171GA@AZC4<4Ie8o17AEB@A_FTd46ahO0jVPV`AoPh@4
PHB49galO1Goool001CooolDO7al0gakO0AlP80KO7al161IJPAdGdH4bHef1=J^T@=mK5`4O6=G17a]
HPAkGUX4PG5R17aYGPAZE4@3J4Hk18eoLPAmKFH4O6mX17a[H`AlK6@3O6mX17aDE0AcEDX4N5iC16mG
BPAdDdX4HThm0fU<@@ASFT<4JEI7175LCPAiF5D4QFa80gaSEPA`EdD4JTa316MB?`AdEDT4KeY=11/N
7`>YX9/4Oh>41864Q2MlO7`Eoooo000Doooo57alO0=lNg`4O8206galO0APFFX4M5m61<V=MPCF[Y43
OFaL17aSE`AlKF84NeiJ185aHPAlJEh4JUA40fQ6>`B=Og84OFeV17a_J0AlJf<4O6aT0ga_J0AlE5@4
LeE:17QND`A_EdX4M5=:169>?@=YC444HeY316UFA`AaG4h4NEQE18E/B0=lHeH4L5M516Y<@`AWDSl4
M5E916mJC@@K7Ql3ZJ2K17n3Q0B1Q8@WO7al5Oooo`005?ooocIlO7`4NEY818Y[E`AkLF`4MfeO0gUX
F`AmJel4O6mZ17aYIPAlOW44O6]V179JC`=bDDD4L4m317]_HPAmM6d4O6mW17a[H`=lM6/4O6EG17=M
C0A`BSl4L5U616=<?0ADB3h3IDDe16A2=PATACH4I44f16A7=PAhHTl3OVAK17ADA`ARACd4Id]016aC
@PAXDdL42``=0kbdb`BAUiT[O7al5Oooo`005?ooocIlO7`4NEY818Y[E`AkLF`4MfeO0gUXF`AmJel4
O6mZ17aYIPAlOW44O6]V179JC`=bDDD4L4m317]_HPAmM6d4O6mW17a[H`=lM6/4O6EG17=MC0A`BSl4
L5U616=<?0ADB3h3IDDe16A2=PATACH4I44f16A7=PAhHTl3OVAK17ADA`ARACd4Id]016aC@PAXDdL4
2``=0kbdb`BAUiT[O7al5Oooo`005?ooocIlO7`4NEY818Y[E`AkLF`4MfeO0gUXF`AmJel4O6mZ17aY
IPAlOW44O6]V179JC`=bDDD4L4m317]_HPAmM6d4O6mW17a[H`=lM6/4O6EG17=MC0A`BSl4L5U616=<
?0ADB3h3IDDe16A2=PATACH4I44f16A7=PAhHTl3OVAK17ADA`ARACd4Id]016aC@PAXDdL42``=0kbd
b`BAUiT[O7al5Oooo`005?ooocIlO7`4NEY818Y[E`AkLF`4MfeO0gUXF`AmJel4O6mZ17aYIPAlOW44
O6]V179JC`=bDDD4L4m317]_HPAmM6d4O6mW17a[H`=lM6/4O6EG17=MC0A`BSl4L5U616=<?0ADB3h3
IDDe16A2=PATACH4I44f16A7=PAhHTl3OVAK17ADA`ARACd4Id]016aC@PAXDdL42``=0kbdb`BAUiT[
O7al5Oooo`005?oooc9lO7`4M6a]17eKAPAdGE84KE0n15aLH`>4J5X4PFm[17acKPAlLVX4O7=[17a_
I`AkDe<3MUY>179=@PB2KV04PW9]17a`J0AlDE83M6MG17eXF@A[C4<4L51416<o=0ASCdD4HShe0f]8
=@AWBCl4Ke<i16I9>@AWAS@4Pf5F0gUGB`A[CD84HTPm16]>@PA[ETP4LeU?10851`>dX9P4RXj7:gal
O1Goool001CooolbO7al17A/K@AmFdH4M5eB16e@?PALG6<3Q6QJ185_J`AlLfh4O79Z17acJ`AlKfL4
Ne=C0gIJCPAbCD84PViP189bK@AlL6P4O55B0gAWE`AmJ5T4Jda3171@A0AS?c@4Hdm5168n=@=[B3D4
IdTo16mC>@AVBCT4IdHd18=QEP=iEd/4Jde21698?@A[CT84JeI817=IC`@21@L3]:2H18Z>Qb]lO7`E
oooo000Doooo<WalO0AdK6d4OE]617AMDPA]D3h4G5aS0hAXFPB1Kf/4O7=^17abJPAlLf/4O6mW17]C
D`=fFTh4LTe2189^H0B2LVd4O71X17aADP=dIeL4OFQI16]<@`A`D4@4Hcld16=?A@AR?SD3JdPe16M9
?`A_DcT4ITTi16M6=0B3HEH3NEM;16]=@PARB3d4Jdi216]FB0AcFDl40PD70kBPV0B:SXL[O7al5Ooo
o`005?oooc9lO7`4M6a]17eKAPAdGE84KE0n15aLH`>4J5X4PFm[17acKPAlLVX4O7=[17a_I`AkDe<3
MUY>179=@PB2KV04PW9]17a`J0AlDE83M6MG17eXF@A[C4<4L51416<o=0ASCdD4HShe0f]8=@AWBCl4
Ke<i16I9>@AWAS@4Pf5F0gUGB`A[CD84HTPm16]>@PA[ETP4LeU?10851`>dX9P4RXj7:galO1Goool0
01CooolbO7al17]KB0B1I5L4Jde316M>@PAkM6X3T5]E17aaJ`AlM6/<O6mX17aUE`=kIE84KUE317EC
A`B3NWD4O7A[17aUG`=kMFT4PFmY179BC`AcFDd4JDe217=KC@AR?C<3IdHi16M:@0A`DD@4Lde517mN
DPB1JEd3Jdm316]@A0A_DTH4JTe216]F@PA/DdL40`H70d<_:0BVXJ@4O7em9galO1Goool001Cooolb
O7al17]KB0B1I5L4Jde316M>@PAkM6X3T5]E17aaJ`AlM6/<O6mX17aUE`=kIE84KUE317ECA`B3NWD4
O7A[17aUG`=kMFT4PFmY179BC`AcFDd4JDe217=KC@AR?C<3IdHi16M:@0A`DD@4Lde517mNDPB1JEd3
Jdm316]@A0A_DTH4JTe216]F@PA/DdL40`H70d<_:0BVXJ@4O7em9galO1Goool001CooolbO7al17]K
B0B1I5L4Jde316M>@PAkM6X3T5]E17aaJ`AlM6/<O6mX17aUE`=kIE84KUE317ECA`B3NWD4O7A[17aU
G`=kMFT4PFmY179BC`AcFDd4JDe217=KC@AR?C<3IdHi16M:@0A`DD@4Lde517mNDPB1JEd3Jdm316]@
A0A_DTH4JTe216]F@PA/DdL40`H70d<_:0BVXJ@4O7em9galO1Goool001CooolbO7al17]KB0B1I5L4
Jde316M>@PAkM6X3T5]E17aaJ`AlM6/<O6mX17aUE`=kIE84KUE317ECA`B3NWD4O7A[17aUG`=kMFT4
PFmY179BC`AcFDd4JDe217=KC@AR?C<3IdHi16M:@0A`DD@4Lde517mNDPB1JEd3Jdm316]@A0A_DTH4
JTe216]F@PA/DdL40`H70d<_:0BVXJ@4O7em9galO1Goool001CooolbO7al17aJA@AdI5T4DblQ17id
I`B:IFL3PFmR17afJ`AlM6/4O7Qg17a^IPAlKfP4O6MO0gaZG@AZDTH4M5U917ikK@AmKFD4O6QI0gac
K0AlJf<4Le]=16I9?0A[CD84Ie9616M9?`=^DST4ITDj171AA@AnG5D4PF]M17=MD0=ZFDd4KeQ;26MB
APA[EDP4Lf1E14`f90=?9ah4=bTU18nBTRMlO7`Eoooo000Doooo<WalO0AlFTD4M6AI15<_8@AnM6L4
RVEW0h5_HPAlMV/4O7A[17ahM`AlKVH4O6mX17aWG`=lJUd4JU9617AIB@AnNfd4OFeU17aXF@=lLf`4
O6]S17=KC@AVBC`4Jde216MBAPAWBCl3KU8i16I5>PA`DDD4OUaE185[G@AcGE03JUU=16mHB`QWDTH4
JeE817=PE@A<=R@3CbLN13LY9@B?TY8WO7al5Oooo`005?oooc9lO7`4O5Y517ATF@AC;b44OWAW18YU
I`>1Kf84O7I[17adJ`AlN7L4O6iV17a_J0AlIel3O6YM16YBAPAdFDT4OW]]17e]I@AlJ5T3O7=/17a[
H`AcFdd4ITTl16]=@PAWDTH4IdTo0fiB>@AVACX4L55517iLE@B1Jed4Lee@0fYIC@A_F4/8Ie9616]E
B0AcH5D4C3HT0dlW7P@g:BD4Si:B9galO1Goool001Coool^O7al17aMD@A/=bP4G2@Q15i0=PAbOWP4
QFiR0gafHPAlJfP4O7A[17a`J@AlJf44O6mX17aWH0=dI5@4Le]@17]`HPB5NVh4PFmS17AECP=mKV44
O59C16]?>`AV?cL4Id]01615>PA/Bc@3E3/`16E1>PAhHeD4OVAF17eUEPA_Ed/3JUA816m=@PA_D4@4
JU9017=;@0AcHUD4ID<i0fY=A`B^b]44cm?D9galO1Goool001Coool^O7al17aMD@A/=bP4G2@Q15i0
=PAbOWP4QFiR0gafHPAlJfP4O7A[17a`J@AlJf44O6mX17aWH0=dI5@4Le]@17]`HPB5NVh4PFmS17AE
CP=mKV44O59C16]?>`AV?cL4Id]01615>PA/Bc@3E3/`16E1>PAhHeD4OVAF17eUEPA_Ed/3JUA816m=
@PA_D4@4JU9017=;@0AcHUD4ID<i0fY=A`B^b]44cm?D9galO1Goool001Coool^O7al17aMD@A/=bP4
G2@Q15i0=PAbOWP4QFiR0gafHPAlJfP4O7A[17a`J@AlJf44O6mX17aWH0=dI5@4Le]@17]`HPB5NVh4
PFmS17AECP=mKV44O59C16]?>`AV?cL4Id]01615>PA/Bc@3E3/`16E1>PAhHeD4OVAF17eUEPA_Ed/3
JUA816m=@PA_D4@4JU9017=;@0AcHUD4ID<i0fY=A`B^b]44cm?D9galO1Goool001Coool^O7al17aM
D@A/=bP4G2@Q15i0=PAbOWP4QFiR0gafHPAlJfP4O7A[17a`J@AlJf44O6mX17aWH0=dI5@4Le]@17]`
HPB5NVh4PFmS17AECP=mKV44O59C16]?>`AV?cL4Id]01615>PA/Bc@3E3/`16E1>PAhHeD4OVAF17eU
EPA_Ed/3JUA816m=@PA_D4@4JU9017=;@0AcHUD4ID<i0fY=A`B^b]44cm?D9galO1Goool001Coool^
O7al17a6@0AZ=2l4HC4]16]UD`B6Ofl4T7=[0gacKPAlJfH4O7A[27a_J0AlJ604O6QI0g=SE0B1Ge@4
Mf]N189_J`AlLfh4NfQT0h5fK0AlFe04JUI51694?@APAc/4G44e1654>0=SAcl4P6AE185YF`AiIEP4
OF9F16mGB`=ZDdL4Kdm326m;APA[Bd84L6EO15lh:P=/Cd<4W;g917]kO2MlO7`Eoooo000Doooo;Wal
O0AlAT04JS@_164a;@A[IE<4QWm_191cJ`=lLfh4O6]V17adJ`QlKfP4O6QP17aXF@=cHe@4PEmD17M[
GPB2Kf/4O7=^17]XI0>1MV`4O5]@16YFA@ARA3d4H4Lk15a1=@AQA3P3HdLo181TE@B1JE/4NFEH17eR
EPA_Ed/3JU=716m?@`Q_BdH4Jd]2171UG`AO>2X3K4m319bmb@AkNg`WO7al5Oooo`005?ooobilO7`4
O4I016Xd;`AQ<Bd4JfEC18IoK`B@Lf/3O7=^17a[IPAlM6/8O6mX17aXH0AlJ5T3Lf=D185OE0AgJeh4
PVm[17acKPAkJ6@3PGI/17aKD0AZETD4HT@m1617>`AL@CD4HD@h0f=7?`B0I5D4PFUK17UUF0AmHUH4
KeM;0fYCA`A_Cd<8Kd]616];@PA`IEl4GcPZ0fa?@`BL_LT4Ng]l9galO1Goool001Coool^O7al17a6
@0AZ=2l4HC4]16]UD`B6Ofl4T7=[0gacKPAlJfH4O7A[27a_J0AlJ604O6QI0g=SE0B1Ge@4Mf]N189_
J`AlLfh4NfQT0h5fK0AlFe04JUI51694?@APAc/4G44e1654>0=SAcl4P6AE185YF`AiIEP4OF9F16mG
B`=ZDdL4Kdm326m;APA[Bd84L6EO15lh:P=/Cd<4W;g917]kO2MlO7`Eoooo000Doooo:galO0=lI5L4
O5=216Y6>0AJ@Bl4M6YH1963L`B1Kf/3O7A[17a_I`AlJf@4O6QQ17AQD`AmJ5X4O5EE0g=ND@AiF4h4
M6AH189`K0AlK5`4O6QQ0ga[I0AlE5<4JTLl1655>`ASAc/4ITTm169BAP=dFTH4N61B17YND@AlHUH4
M5M;171AA@=ZE4P4KdPm16m;@0AWCT04IeE017AUG`A^@cH3KU]?171kQPAlOGdWO7al5Oooo`005?oo
ob]lO7`3O6AG17aC@PAZASP4FT4_17AZF0BAPg<4PFm[0gadJ`AlKfL4O6]T17aXH@AdHE<4OFQJ17aE
E@=cGU44NEQ>17ATF0B2L6`4O6aL17aXH@=lJf@4O5AC16Y7?0AQAC/4HdLk16I9?@ARDTH3M5Y617QP
DPAjGU44O69F17AGB`A`DDD3JUA816m8?@A_Bd04Idi016ME@0AdIEl4KT<f0fiKC`A`NhH4O7em9gal
O1Goool001Coool[O7al0gaTE`AlDd84JTHh15Y1;`AdJUP4TH=c185_J`=lM6/4O6mW17a[I0AlJ644
M65C17eXFPAlEED3LeiA17UHCPAdI5P4PW1/17a/G0AlJ643O6]T17aDD`AZAc`4HDDk16=7>`AVBCd4
HU960gAJAPAhH584NUiA17aREPAdEd/4L5550fYDB0A_B3d4Kd]016M>@0AWED04M6EO16i3=P=^Fdl4
L7^617amOBMlO7`Eoooo000Doooo:galO0=lI5L4O5=216Y6>0AJ@Bl4M6YH1963L`B1Kf/3O7A[17a_
I`AlJf@4O6QQ17AQD`AmJ5X4O5EE0g=ND@AiF4h4M6AH189`K0AlK5`4O6QQ0ga[I0AlE5<4JTLl1655
>`ASAc/4ITTm169BAP=dFTH4N61B17YND@AlHUH4M5M;171AA@=ZE4P4KdPm16m;@0AWCT04IeE017AU
G`A^@cH3KU]?171kQPAlOGdWO7al5Oooo`005?ooob]lO7`3K40[15H`9P@`81X4Bc@Z18IeJ@B<Og04
O6]X0ga/I0AlJ644O6QI17aTEPAcI5D4NEUE16eEC0=eGeD4N6YM17Q^H0B2LfH4O6]T17a[I`=lJf@4
M69D16]>?PAQBSl4HdLk16M:?@A^DDD3LeI817iJEPAiGU44ME]?171ND`AdFDd3JUI:16mEB@AWE4L4
Ide216]>B0AdHUl4H2PJ0g1WF@AZ?cH4Tj2Q9galO1Goool001Coool[O7al0fa0:`AF<2H4<20J14/d
:PB6MFT4S7m`17a[J0=lK6@4O6QQ17aXF@AlI5H4LfAE17UIE@A]ED`3MEmE17QZG@AhKV04PW=V17a[
I0AlJfL3O6]T17ARE0A[CSh4HDXo16=7>`AWBSd4KU550g=FB0AnFUH4NEiA17EKC`A`GU<4M5U=0fYF
BPA_EDT4IeA716M=@PA[CTP4M69O160X6P=`IeT4JSlf19>PXBMlO7`Eoooo000Doooo:galO0=/@2/4
ES0V130P6PA;=2X4QWEY18aoL0AlJfP3O6aT17aXH@AlJ5T4O6AF17=TE@AiFED4KEE<0gEOE@AhJUd4
N6iP189cIPAlJf@4O6]W0ga[I0AdHU@4Jdhn165:?`ASAc/4IdXm16iAA@=cETP4OUYF17UND@AeFdl4
L5iC17AIC@=ZETX4KeE916MDA`AWCD84Jdi817ARG`AP:1X3L6MI16Xo=PBCX:4WO7al5Oooo`005?oo
ob]lO7`3K40[15H`9P@`81X4Bc@Z18IeJ@B<Og04O6]X0ga/I0AlJ644O6QI17aTEPAcI5D4NEUE16eE
C0=eGeD4N6YM17Q^H0B2LfH4O6]T17a[I`=lJf@4M69D16]>?PAQBSl4HdLk16M:?@A^DDD3LeI817iJ
EPAiGU44ME]?171ND`AdFDd3JUI:16mEB@AWE4L4Ide216]>B0AdHUl4H2PJ0g1WF@AZ?cH4Tj2Q9gal
O1Goool001Coool[O7al0f4X5`@J40/4=2@P134P7`BLPFh4QgQb17a[I`MlJe`4O6]T17a[IPAkKVT4
P6aX17IME@=dDD/4J5=417YSEPAiJE`4OFaX17a[I0=lJe`4LeA>16I3>@AK?3d4I4Pe1613>0AaDDD3
Lee?17ABAPA/EdT4MEA?16]>@PA/DTH3Hde216Q@A0AWD4@4JdXo16]>B@A/EdL4F3LR0fYF@`AX>CD4
Tkg89galO1Goool001Coool[O7al0f4X5`@J40/4=2@P134P7`BLPFh4QgQb17a[I`MlJe`4O6]T17a[
IPAkKVT4P6aX17IME@=dDD/4J5=417YSEPAiJE`4OFaX17a[I0=lJe`4LeA>16I3>@AK?3d4I4Pe1613
>0AaDDD3Lee?17ABAPA/EdT4MEA?16]>@PA/DTH3Hde216Q@A0AWD4@4JdXo16]>B@A/EdL4F3LR0fYF
@`AX>CD4Tkg89galO1Goool001Coool[O7al0f4X5`@J40/4=2@P134P7`BLPFh4QgQb17a[I`MlJe`4
O6]T17a[IPAkKVT4P6aX17IME@=dDD/4J5=417YSEPAiJE`4OFaX17a[I0=lJe`4LeA>16I3>@AK?3d4
I4Pe1613>0AaDDD3Lee?17ABAPA/EdT4MEA?16]>@PA/DTH3Hde216Q@A0AWD4@4JdXo16]>B@A/EdL4
F3LR0fYF@`AX>CD4Tkg89galO1Goool001CooolWO7al17a/I@=Y=R`4?b`T13LT7@@c8R04_YAi18Mh
JPAdI5H3OFaT17a[GPASCTD4IU54150h;@AB>Rl4DCPd0e/i>@A]DT<4LE96179ND`B3LFd4O6]T0ga[
H`AcDe04IDTk15i3<`AWAS04GdY016e=@0=NCd<4FdTn16YCA`AaGU84Hdi1171JC@=_ETX4JU9616]B
APA[BSl4Jdi916]FAP@o8QX3BR0H16a0<@BD_LLWO7al5Oooo`005?ooobMlO7`4O6aU0fTf;0@o;2@4
=b@M13<R80BnU7T4QgQZ17ATEP=mK6@4O6]N16=>A@AVDD@4D3P]158j;`AA>3@3FcTi16eB@`AaDTH4
LUiC18=aK@AlJf@3O6]S17=CD0AUBC/4GT<c16M6<0AOBT04KDe00ei?@`AKBCh4JU=7175NDPASCT44
L5Y=0fmFBPAZDTH4Je9616]:?`A[CTT4JeI613lR6P=:81P4K40a19BmabMlO7`Eoooo000Doooo9gal
O0AlK6D3JCH/13l/90@g91d4<b8P1;jDN@B7N6X4M6AF0ge/I0AlJeh4Hdi516IAA0A@>2d4DSX_154h
=0=K>CT4KE93175BAPAbGU<4Pg5]17a[I0=lJf<4Le=@16E9>`AN@c<4IdH`15m:@0A]CD03GTm315]9
?PAZDdL4LEiB16=>@@A`FTd3KeI:16YBAPA[DTH4JdXo16]>B@A[ETH4?b8J0dXP60A/@344U;g79gal
O1Goool001CooolWO7al17a/I@=Y=R`4?b`T13LT7@@c8R04_YAi18MhJPAdI5H3OFaT17a[GPASCTD4
IU54150h;@AB>Rl4DCPd0e/i>@A]DT<4LE96179ND`B3LFd4O6]T0ga[H`AcDe04IDTk15i3<`AWAS04
GdY016e=@0=NCd<4FdTn16YCA`AaGU84Hdi1171JC@=_ETX4JU9616]BAPA[BSl4Jdi916]FAP@o8QX3
BR0H16a0<@BD_LLWO7al5Oooo`005?ooobMlO7`4M4hl0f]0>@@60`844@h<12@J60C=X8<4OG1R17aT
F0>1Kf<4O6]L175JC`AGAC/4@c@[12XW9`@O6QX3=AlE15Tm;PA781P4B28I18EaHPAmKFD3O6]T17=K
C@AUB3/4GT<c161@>@AG?cH4MEU<0gIND@AiFdh4NeE816]<A`AHAS`4MUY=0fmFBPAWCd<4G4]015i;
@0A]EDT4JeE6148U7@=I:Ql4OT<d19S3dbMlO7`Eoooo000Doooo9galO0AdCS`3Jd0i10H30P@A3P`4
91XH1<fPP`AmL684O6AH0h5_H`AlJe`4LEY?15M5>`A3=2/4:RLW11lJ6P<e7aD4FCd^14LP60A88QT4
QG5R17e]I@=lJf@4Le]=16E8>`AN@c<4H50i15Lo=PAeFD`3MUiA17UKCPAkEDP4Jda715Q6?0AfFTd3
KeI:16M?@`ALBd04GT]016eEB@A[EDH4@RDM0eTZ7`An@c@4V<?C9galO1Goool001CooolWO7al17A>
?0=[@3T41P<2114>30@T6QP4cJ2317e`HPAlI5P3PFmS17a[G0AaFTl4EdDk14<d:`@Z9bL47aXJ0cDO
5@AI?Bh4Ab0H14PR6@B5LF84OFeU0ga[I0AcFdd4IDPk15i3<`APD3T4Eclf17EIC0=fGU44NE]>17]E
B0A[C4L4F4Hl17IJC@=_ETX4Idm315a;@0ANBd04KEE916]EAPA29Ad3FBXO17i3=0BH`m<WO7al5Ooo
o`005?ooobMlO7`4M4hl0f]0>@@60`844@h<12@J60C=X8<4OG1R17aTF0>1Kf<4O6]L175JC`AGAC/4
@c@[12XW9`@O6QX3=AlE15Tm;PA781P4B28I18EaHPAmKFD3O6]T17=KC@AUB3/4GT<c161@>@AG?cH4
MEU<0gIND@AiFdh4NeE816]<A`AHAS`4MUY=0fmFBPAWCd<4G4]015i;@0A]EDT4JeE6148U7@=I:Ql4
OT<d19S3dbMlO7`Eoooo000Doooo8galO0B5Q8D4NT/h0fDo=`@B4A847Q@@138H5@CO/Y<4PG9U17QV
FP=mKf84O6]O17]ZIPAQBCl4R6QR12hV8P@O4Pl3<aXB140g=0AO=bX4QfYI19jJQPB2NgH3O7]i17=Q
D@AUA3/4CcP]15Po;P@X2PL4L4m00ei0:`A<>2l4>RPO15i8?0ALCT04MUI30fQ@A@AWD4@4FT@i16=>
@PAeCTT4G4Di138M6P=I=BP4PeA;1:7Dg`AkNg`SO7al5Oooo`005?ooob=lO7`4QHB517Y;>0=U?cL4
4Q4B11hD40@b61D4gk:C185bI@AhIUX3OFmR17a[G`AkJVH4HDTo18QXHP@^9R847a8?0c<J4PA0=c@4
GcLZ18MZF@BNVXH4PW]f0gakN@AcHE44ID@k14lh;@AH?bh4:0X7171?@0=N@2/4C3P_13XX7`ANB3`4
G4i017IF@`=XD4D4Ie1415Y4>@ASCT84MDi915a5>@@b7AX3FCDX18=DB`BQe=l4Ng]l8galO1Goool0
01CooolSO7al18F4Q@AjBcP3IClg118A4P@N5104<QPE1=nbT`B1LVD4N6IJ0ge_HPAlJel4NfYV1659
?`B8J684;RHR11lB3`<c6Q84@3Ld15lg:PB7JUT4WYZ6189kMP=lNgT4Lf5A16E4>`A?>2d4F3l^12P:
1`A`Cd03GT0[14`h;`@j:1l4GTPl15a>@0AfET<3J51516M@A0AJA3T4Hdi217E>B@ALACT4<QdJ0eTe
:0B3E4/4XMCO17]kO2=lO7`Eoooo000Doooo8galO0B5Q8D4NT/h0fDo=`@B4A847Q@@138H5@CO/Y<4
PG9U17QVFP=mKf84O6]O17]ZIPAQBCl4R6QR12hV8P@O4Pl3<aXB140g=0AO=bX4QfYI19jJQPB2NgH3
O7]i17=QD@AUA3/4CcP]15Po;P@X2PL4L4m00ei0:`A<>2l4>RPO15i8?0ALCT04MUI30fQ@A@AWD4@4
FT@i16=>@PAeCTT4G4Di138M6P=I=BP4PeA;1:7Dg`AkNg`SO7al5Oooo`005?ooo`AlMGD4O7em17ad
M@AlOGdCO7al10X10@Ak@2l3JeA912@L6@@F51X48A<?1=fgU`AiJ5/4O6]O0gQWF`AeI5T4OFaX175P
D@AiG504EDDi18EPD0>1DSP4Oe@l19IWC0B?Je/4PW=T189iM0=lL6T4LeE516E2>@AL?Bd4GD4e14X[
8`ATG5L3:RTW10@310@k8ad4?cP`11hF4@A8=2h3AC0R16U1<@AKBd44He1417E>@PA5>bh48QPD0d4X
80BAJUT4W<G>17MgN2=lO7`Eoooo000Doooo17aeM@AlOGd4O7Ae17amOA=lO7`42P4117]0;`=[E4T4
91`I11HD6P@Q4`l4gKNG17UXF`AlJel3N6MK17ETF@AmK6P4LF1A17ULD0AEACT4QF1@0h5B>0AoE3`4
UVM<18m[F`B2Lf@4PWUd0ga`J@AcEDD4ID8i15`m;@AM@CD4BR/S16ALE`<Z:BL410<413/S7@@o>304
7QHA14Pd;P=5<284JD4a15];@@ASD4@4MDi214Dk;P@R61@3@BPP195ZF@BLaLh4MgMh8galO1Goool0
01Coool4O7Ee17amO@AlM7D4O7em4galO0@:0@44Nd0_0f]DB@@T71T45Q@J124C3`CM]iL4NFQK17a[
G`=hIe/4MFAI17e/J0AaH544NEa@15E5>@B5H503PE8h17mD?0BFId`4Sf]K189cI0B2NG@3O71Y17=E
A@AU@ST4G3d]15e1=@A::b<4I5aG0bXY9`@40`@4>b<M13lh<0@N5Q44B3@^0dD`8PAY@C44Fd]116=@
A0AeCT84AC/^128H50=1:204TFYI19c5cPAgMgPSO7al5Oooo`005?ooo`AlMGD4O7em17adM@AlOGdC
O7al10X10@Ak@2l3JeA912@L6@@F51X48A<?1=fgU`AiJ5/4O6]O0gQWF`AeI5T4OFaX175PD@AiG504
EDDi18EPD0>1DSP4Oe@l19IWC0B?Je/4PW=T189iM0=lL6T4LeE516E2>@AL?Bd4GD4e14X[8`ATG5L3
:RTW10@310@k8ad4?cP`11hF4@A8=2h3AC0R16U1<@AKBd44He1417E>@PA5>bh48QPD0d4X80BAJUT4
W<G>17MgN2=lO7`Eoooo000Doooo17ahN0AlPH44O7]l17b0P0mlO7`430@310T30`@X1`<3;b0K10P8
3P@A3`d4;1LB1>RiV@AhIe/4PVm[0f8k>0AYCT<4Q79^17]bJ@AoJfH4N5iI175AA0=`EdX4O5Y?18U/
F0B6Ied4O6iP189lN0=lKfP4Le1916EBA`AN@S44GU8k16e5=0AkIEL3JD@e10/92`A48AH4=bXW12<J
60AW@2l3KTHg18ETC`AVBd44HTi217EE@P@M5aL481LB0c/O5`BEAC@4T;?017QhNB=lO7`Eoooo000D
oooo17ahN0AlPH44O7]l17b0P0mlO7`430@310T30`@X1`<3;b0K10P83P@A3`d4;1LB1>RiV@AhIe/4
PVm[0f8k>0AYCT<4Q79^17]bJ@AoJfH4N5iI175AA0=`EdX4O5Y?18U/F0B6Ied4O6iP189lN0=lKfP4
Le1916EBA`AN@S44GU8k16e5=0AkIEL3JD@e10/92`A48AH4=bXW12<J60AW@2l3KTHg18ETC`AVBd44
HTi217EE@P@M5aL481LB0c/O5`BEAC@4T;?017QhNB=lO7`Eoooo000Doooo17ahN0AlPH44O7]l17b0
P0mlO7`430@310T30`@X1`<3;b0K10P83P@A3`d4;1LB1>RiV@AhIe/4PVm[0f8k>0AYCT<4Q79^17]b
J@AoJfH4N5iI175AA0=`EdX4O5Y?18U/F0B6Ied4O6iP189lN0=lKfP4Le1916EBA`AN@S44GU8k16e5
=0AkIEL3JD@e10/92`A48AH4=bXW12<J60AW@2l3KTHg18ETC`AVBd44HTi217EE@P@M5aL481LB0c/O
5`BEAC@4T;?017QhNB=lO7`Eoooo000Doooo17ahN0AlPH44O7]l17b0P0mlO7`430@310T30`@X1`<3
;b0K10P83P@A3`d4;1LB1>RiV@AhIe/4PVm[0f8k>0AYCT<4Q79^17]bJ@AoJfH4N5iI175AA0=`EdX4
O5Y?18U/F0B6Ied4O6iP189lN0=lKfP4Le1916EBA`AN@S44GU8k16e5=0AkIEL3JD@e10/92`A48AH4
=bXW12<J60AW@2l3KTHg18ETC`AVBd44HTi217EE@P@M5aL481LB0c/O5`BEAC@4T;?017QhNB=lO7`E
oooo000Doooo17aoP0AlP80GO7al10D000@b8QP4;AHC0b/Q70@;1`T4;1PC13<H50CO[8d4PFQK17QX
G0=jIf04KF1@15<h;PAC>c04A38X138T80@[71L3=bLM14<Y80A9:b44LV5F17Y`HPB2M6l3O6QI17=@
A@AUEdP4GShc16I4<`ASCST4LE]:0fYAA@AQDTL4VVE>16a3<`AV?Rh4Vf9=0hEL@0AWETT4K59116eG
B`ASCT844a0?128E4P<o81P4Qc8T19[>fRMlO7`Eoooo000Doooo17aoP0AlP80GO7al10D000@b8QP4
;AHC0b/Q70@;1`T4;1PC13<H50CO[8d4PFQK17QXG0=jIf04KF1@15<h;PAC>c04A38X138T80@[71L3
=bLM14<Y80A9:b44LV5F17Y`HPB2M6l3O6QI17=@A@AUEdP4GShc16I4<`ASCST4LE]:0fYAA@AQDTL4
VVE>16a3<`AV?Rh4Vf9=0hEL@0AWETT4K59116eGB`ASCT844a0?128E4P<o81P4Qc8T19[>fRMlO7`E
oooo000Doooo17aoP0AlP80GO7al10D000@b8QP4;AHC0b/Q70@;1`T4;1PC13<H50CO[8d4PFQK17QX
G0=jIf04KF1@15<h;PAC>c04A38X138T80@[71L3=bLM14<Y80A9:b44LV5F17Y`HPB2M6l3O6QI17=@
A@AUEdP4GShc16I4<`ASCST4LE]:0fYAA@AQDTL4VVE>16a3<`AV?Rh4Vf9=0hEL@0AWETT4K59116eG
B`ASCT844a0?128E4P<o81P4Qc8T19[>fRMlO7`Eoooo000Doooo7galO0@80@0470h:11LA3`<M4`l4
7A8>11hE40@f:2@4`IAh18A]G`AkKf83PFm[17UXH0AjJed4Le9<14Y2@`AiDD/4KdTj0gQHA`A]B3X4
RVAD19bBO`B:NW@4PFmZ0gaEE0AcGE04IEI:15hh>P@l8QP4@2DL16UC?0=]Dd<4Je90179AAPA^ED84
JUM;181RC0=PD4<4Jdi=16=>@PA]Dd84ACP^10L820@G4@l3WF5;16`_8@BVfnDWO7al5Oooo`005?oo
oamlO7`4204011`>2P@G4@l37A<?11dB3P@N5A04=RPT1<6DN0B4KEl4NfmR0h5_J`AiJ604NV]M17=B
C0A:@T<4NE5;16m9>P=hF4L4KDPj18YTE0BLTWl4RWYd185_JP=lEE@4Lee@16EFBPAN>3X4?28H140U
70AYDc`3KE=316]B@0AbDDH4KUE216YGB`B0HT`3H51316]>C@ASCT84KE=214Dh;P@720P45a4?0ieQ
B`A/;b44Y]_U9galO1Goool001CooolOO7al10P100@L3PX45a4?0adC3`@M4Ph47QD@13HX90C1U7P4
Q6eO17]_HP>1Kf/4NFQP17Y[G@AcDT`4BT9317UAB`A_BCX3N5Q716e8>PB:I5@4W99o18YjM0B1KfX3
O5ED17=MD0AUETX4GSPj13`R60A09A`4JE<l0feC@`A[DT04LU5616iE@PAZEd/4P69<0f1@@`A[CTd4
Hdi216eC@PA5>2h41`P811LA3`>MHD/4K2lQ1:KKiBMlO7`Eoooo000Doooo7galO0@80@0470h:11LA
3`<M4`l47A8>11hE40@f:2@4`IAh18A]G`AkKf83PFm[17UXH0AjJed4Le9<14Y2@`AiDD/4KdTj0gQH
A`A]B3X4RVAD19bBO`B:NW@4PFmZ0gaEE0AcGE04IEI:15hh>P@l8QP4@2DL16UC?0=]Dd<4Je90179A
APA^ED84JUM;181RC0=PD4<4Jdi=16=>@PA]Dd84ACP^10L820@G4@l3WF5;16`_8@BVfnDWO7al5Ooo
o`005?ooo`QlO7`4O7Ae17amO@mlO7`43P@211h=2P@O51036a<@10d61P@Q5104?2XU19a_F0B7KV04
OG1S0ga[J0AlLf/4Ng5Y17a`K0B5QG`4XHj018R5N`>ASHD4T8R119V:N0B0N6T4PWMc17ASE0=eHUD4
M6ID16iJC`AfGU<4IeA314<Y:@@a91`381HC15Pg;PA`EDX4Ie8o16YB@PASCT83I4Dk15A1=PA]CdL4
Ldi211dF4`@>2`/4;2<N0hi6<PA67QD4:B`[18j=SB=lO7`Eoooo000Doooo27alO0AlM7D4O7em3gal
O0@>10847Pd:11lD40<K4a043@H6124D40@l:RD4W6mH18M^H0AmL6<3O6]X17acJ`AkLFT4O71/18F5
O0BQSX04R8Ek0i6=Q@B@R844VHYh181hJ@B2Mg<4M6=D0gERE@AdIU@4KUY?17IND`AWE4<4@bTY134T
70<P5Q<4F3L^171EBPAWDSl4JU9216=>@P=TAC/4E44f16e?A`AcCT847AHC10h;2`@/8ah3STHb14HN
5@@Y;2/4SXf=8galO1Goool001Coool8O7al17adM@AlOGd?O7al10h40P@N3@X47a@@0a/C40@=1PH4
8A@@13`Z9@BLKeP4QfiP17e`H`=lJfP4O7=[17]aJ@AlL6`4QHEl1:6>P0B8QG/3THf51928P@BIRWP4
P7QY189gL`AdHe@3MF9E17AVE0A^FTl4MUiC16MD@`A3:BT4<B@L0b0F4`AH=bh4L5E:16MB?`AZDT84
Hdi20fA5>`AD@CH4KDm717=>@P@M5Q<43P/;12`S7P>>AS84AQhE12T/:`B>SHdSO7al5Oooo`005?oo
o`QlO7`4O7Ae17amO@mlO7`43P@211h=2P@O51036a<@10d61P@Q5104?2XU19a_F0B7KV04OG1S0ga[
J0AlLf/4Ng5Y17a`K0B5QG`4XHj018R5N`>ASHD4T8R119V:N0B0N6T4PWMc17ASE0=eHUD4M6ID16iJ
C`AfGU<4IeA314<Y:@@a91`381HC15Pg;PA`EDX4Ie8o16YB@PASCT83I4Dk15A1=PA]CdL4Ldi211dF
4`@>2`/4;2<N0hi6<PA67QD4:B`[18j=SB=lO7`Eoooo000Doooo27alO0AlNg`4O8203galO0@91@@4
8APF11hD40<P4a045Ph:12HE4@@j:RD4VFE>19=hJ0B2M6H3O6]X17adJ`AlKfP4O7Qg27agM@AlKVH3
O7Qg17a^IPAlKfH4NfYM185_H`AkIeP3MemD17QHCPAgHeL4NfII17ULE`AYFED4P5a@0e<n=P@o9Ad4
91/E13LR7@@^:bL4?bXR0d</8PAbDT`4Ne=616A7>@@<2`/4610>12HI6P</3PX4=18=12/_;PCKgn0S
O7al5Oooo`005?ooo`QlO7`4O7]l17b0P0mlO7`42@D4124H5P@N510381<@11H>2P@V5A44>RXU19UU
CPBCN6P4PWAV0ga[J0AlM6/4O6mX17ahM`QlMgD4O6iV0gahM`AlKVH4O6mV17]ZG@B1Kf<4NfMH0gMO
E0AhF4h4Mf=G17]VF@AiG5L4JEUE181LD0=C?SH4?bDM12@K5@@g8Qd4;R/W13lZ8P=3;284LU9<17]C
APATAcT430/;11P@3P@V6AX3;0h:13@B3@@[;bh4fmoP8galO1Goool001Coool8O7al17akO0AlP80?
O7al10T510@Q61H47Q@@0b0C40@F3PX49QDA13XZ9@BIIDh4TgQX189dIP=lJfP4O7A[17a_J0AlN7L8
O7Me17a^IP=lN7L4O6iV17a_IPAkJUd4PFmS17]WF0=gGe@4N5Q>17MSE`AkIUT4NEaG16UIE@B0G503
Dchf13lU7@@T6aD4=b8M12h[9`@o:R83@b`R179BC0AkDdH4I4Li10`;2`@H40h49QTJ0b`>2P@d4Pd4
:bl^1=_Oh2=lO7`Eoooo000Doooo27alO0AlNg`4O8203galO0@91@@48APF11hD40<P4a045Ph:12HE
4@@j:RD4VFE>19=hJ0B2M6H3O6]X17adJ`AlKfP4O7Qg27agM@AlKVH3O7Qg17a^IPAlKfH4NfYM185_
H`AkIeP3MemD17QHCPAgHeL4NfII17ULE`AYFED4P5a@0e<n=P@o9Ad491/E13LR7@@^:bL4?bXR0d</
8PAbDT`4Ne=616A7>@@<2`/4610>12HI6P</3PX4=18=12/_;PCKgn0SO7al5Oooo`005?oooamlO7`4
3PL613/X9@@G4@h381<@11lC3`@X6AX4>BXU17aE@0B3Je`4Q7EW0ga[H0AlK6D4O71X17a`J@AlMG44
O7A`17acKP=lN7L4O6YP17a_J0AlKfH4O6]N17a[G`=cFe04N69F17QND`AhI5L4N5YG16iND0A^F4X3
I55316aEAPA/Dd<4J48b15Tn;`B0CSl3LU]=181?C`AMCd04CT4e10d<30@M4Pl46a<@0aD>2P@[6AD4
>CDb1=KKg2=lO7`Eoooo000Doooo7galO0@>1`H4>bPU11LA3P<P4a047a<?12PI6P@i:RD4O5E018=[
G0B4MFL3O6]P17a/I@AlL6P4O71Y17aeL@AlM704O7=^0gahM`AlJV04O6mX17a_IPAlJeh4O6]O0g=K
D0AhHUH4N5iC17QTE`AhFUL4KUi@16iHBP=TDD<4K5E616aC@`AX@S84FCh_181>?`=bFdd4P4m?15e?
@0A>@CD43@`<11dB3`@K4a035@h:12/I5@@i=C84e]_L8galO1Goool001CooolOO7al10h71P@k:2D4
5a4>0b0C40@O4`l4:1TJ13TZ9@AlED04Pf]L18AeI`=lJf04O6aU17a`J0AlL6T4O7Ea17adL0AlLfh3
O7Qg17aZH0AlKfP4O6mV17a[GPAlJel3Le]@17QREPAhGU<4N6AG17QJE`A^GU04KUQ:0fAA@`A/EDH4
K5=316Q2<PAI?Rl4P4ho0g9KC@B0Cdl4GDm014i1=@@=30`47A8?11/C40<E3PX4:aTE13Te<PCFfm`S
O7al5Oooo`005?oooamlO7`43PL613/X9@@G4@h381<@11lC3`@X6AX4>BXU17aE@0B3Je`4Q7EW0ga[
H0AlK6D4O71X17a`J@AlMG44O7A`17acKP=lN7L4O6YP17a_J0AlKfH4O6]N17a[G`=cFe04N69F17QN
D`AhI5L4N5YG16iND0A^F4X3I55316aEAPA/Dd<4J48b15Tn;`B0CSl3LU]=181?C`AMCd04CT4e10d<
30@M4Pl46a<@0aD>2P@[6AD4>CDb1=KKg2=lO7`Eoooo000Doooo7galO0@?1@<4;AhF120H5@<Q4`l4
9@l;12/H5@@g8aP4D3P]18USD`B5MVL3OFaP17a[J0AlM6/4O7Qg17a_J0AlMG47O7A`17aZH0AlKfP4
O6QI17aXH0AlI5L3LeA;17QTE`AhHUH4N5iC17QKD@A_EdT4Le550fiCA`AYDDD4N5]=17EGBPAnH544
PEU;0g5CC@AbCD84IT`k13LU70@C3@d47A8?12/H50<K4`l48a@@13LS6@BGP8<4PXB47galO1Goool0
01CooolOO7al10l50`@]7QH481PE0b4C3`@U3`/4:aPE13LS60A@>2d4RF=C18EfI`=mK604O6]X17ad
J`AlN7L4O6mX17aeL@MlM704O6YP17a_J0AlJ5T4O6QP17aTE`=cE4/4N6AG17QREPAhGU<4N5]A16mG
B@AcDDD3KU=716UAA@AhFdd4MEM:17iPD@B1FD/3LE==179=@PAVC3/4=bDL11<=3@@M4Pl4:aPD0a/C
3`@S5104=b<I19N0P`B2Q8@OO7al5Oooo`005?oooamlO7`43`D312dN5P@P61D38A<?12D?2`@[61D4
=b<H150h;@B9He<4QGIW0ge/H0AlJfP4O7A[17ahM`AlKfP4O7Ea1gadL0AlJV04O6mX17aXF@AlJ604
O6AG0g=DB`AhI5L4N69F17QND`AhFe44KeM917=AA@=^DdL4JE5517QKC@AeEdX4OV1A185IB`=aDdd4
LTe216I<>`@g9A`44`d=11dB3`@[61@36a<?12<D40@g8aT4Uh2318:4Q1mlO7`Eoooo000Doooo7gal
O0@90`44<bTW12@J5`<X5Q<45@h:120D40@O4`l4@BLN16M1:`B?N6T3PW1S17a[J0AlM6/4O7Uh17ac
KPAlKfP4O7Ea1ga[H@AlKfP4O6MG17a[H0AdG4h3M5mD17QND`AhG544N5]@17QND`A_Ed/4Je=70f]F
BPA_GE04Je9616m@A0AZDTH4G4Xo0ei>@PANCT04Ac/`11@D50@<2PT48aLI11H?3`<D3PX43PH612hI
5@AeFUD4XZf/7galO1Goool001CooolOO7al10T30@@c:BL491XG0bPF4`@E3PX481@@11lC3`A19ah4
Id4[18mhJ@>2L6<4O6]X17adJ`AlNGP4O7=^17a_J0AlMG47O6]Q17a_J0AlIeL4O6]P17ALCP=dGe@4
N5iC17QLD@AhFe04N5iC16mGB`A[DdL3JeI:16mMD0A[DTH4Ke1416YBAPALBSl3GTi215i>@0A7>c04
51@D10`:2@@S5aT45Pl?0a@>2P@>1PH4;QTE17EJE@BR[J`OO7al5Oooo`005?oooamlO7`42@<113<Y
9`@T6QL3:1HC11D>2P@P51047a<?144W7PAW@B/4SgQY0h9`H`AlJfP4O7A[17aiN0AlLfh4O6mX17ae
L@MlJf44O6mX17aWE`AlJf04M5a>0gAOE0AhGU<4N5aA17QKD0AhGU<4KeM;16]CA`=[ETX4Kee@16]B
APA_D4@4JU9615a:?`=NCT84GTi014Lk<0@D51@430X912<G6@@F3`l350h:10h61P@^6AD4MEYE1::]
[1mlO7`Eoooo000Doooo7galO0@90`44<bTW12@J5`<X5Q<45@h:120D40@O4`l4@BLN16M1:`B?N6T3
PW1S17a[J0AlM6/4O7Uh17acKPAlKfP4O7Ea1ga[H@AlKfP4O6MG17a[H0AdG4h3M5mD17QND`AhG544
N5]@17QND`A_Ed/4Je=70f]FBPA_GE04Je9616m@A0AZDTH4G4Xo0ei>@PANCT04Ac/`11@D50@<2PT4
8aLI11H?3`<D3PX43PH612hI5@AeFUD4XZf/7galO1Goool001CooolOO7al10h40P@`9B<4;R8O0bLK
5`@W5a<48Q@@12/M6@A1;b/4BcL]19QbHP>4KV44O6aX17a/I0AlLFX4O7Ea17acKPAlN7L3O6YP27a_
J0AlIel4M6AG17ALD@MhFe04N5iC171ND`AaEd/4L5M;16YCA`=_ETX4KeM;16mCA`A[DTH4Ie9615Y:
?`=cCT84HTLk138U80@E3Ph49AXG118:2`@E3Pl33PH611L?40@V5A44IeA>1;K2aAmlO7`Eoooo000D
oooo7galO0@>1084<2DS12hR7`<W6aL49aLC128D40@[7AT4@Bl[14/g;@BHLV83Q6iQ17a/J0AlK6@4
O75Z17aeL@AlLfh4O7Qg0gaZH0QlKfP4O6MO17ATE`AdG547N5]@17QND`A`GU<4LEM;171GB`AZDdL3
KeI:16mGB`A_DdL4Je9616MBAPAJBSl3Ldi21697>`@b9B045@h>12DJ5`@B2P/45@h?0`h61P@G3a04
9QDA16MDCPBf`/DOO7al5Oooo`005?oooamlO7`43P@2130U8`@^8Ql39a/G12LG4`@R5104:adI144_
:`A;=bd4V79R0hA^H@AlK6P4O6aT17aaJPAlMG44O7=^17ahM`=lJV08O6mX17aWG`AdI5L4M5aA1gQK
D0AhGU<4L5iC175GB`A`Ed/4JU=70fmFBPA_Ed/4Ke=716]BAPAWDTH4FTXo0g=>@PARAc/4<RDP11D>
3P@U6QL44PX;11D>3`<>1PH45`l@12HE4@AWE4h4]/;57galO1Goool001CooolOO7al10h40P@`9B<4
;R8O0bLK5`@W5a<48Q@@12/M6@A1;b/4BcL]19QbHP>4KV44O6aX17a/I0AlLFX4O7Ea17acKPAlN7L3
O6YP27a_J0AlIel4M6AG17ALD@MhFe04N5iC171ND`AaEd/4L5M;16YCA`=_ETX4KeM;16mCA`A[DTH4
Ie9615Y:?`=cCT84HTLk138U80@E3Ph49AXG118:2`@E3Pl33PH611L?40@V5A44IeA>1;K2aAmlO7`E
oooo000Doooo7galO0@<1`H4<bTW13HY9@<`8b049aHC11<>2P@]61D4@bLM160k:`BAECd3QW=T17e`
I0AlJf@4O6aT17aaJPAlMG44O7A`0gacKPAlKVH4O6mX17aWH0AkJeX4MemC0g1JD0AaEd/4NEQC16mH
B`AdDDD4M5A?16YDA`=_ETX4Ke1426M@A0ATACT4JT]00f=1=@@i<2/48aPD11`B40@D3PX450d?11<:
2`<G3`/46A0A12lI50CYjn/4/kZl7galO1Goool001CooolOO7al10`71P@c:BL4=RTU0c0S80@W5Q<4
4`h:12dH5@A39ad4H3/[195E?@>6Lf@4OG1T17a[I0AlK6@4O75Z17aeL@AlM703O7=^17a^IPAlKfP4
O6MP17][FPAgGe<3L5Y@175GB`AiF5<4KeQ;17AAA@AdE4l4JUA70fmFBPA_D4@8Ie1416A5>@AZBd03
Hd4e13T`:`@S61@4718@11@>2P@D3@l44`X;0aL?2`@I4144;aTD1>W[j`Bc^[`OO7al5Oooo`005?oo
oamlO7`430L613<Y9`@f:BD3<2<P12LF4`@C3PX4;APE14<W7@AP>b/4TEDm0hIcI0AmL6@4O6]T17a/
I0AlLFX4O7Ea17adL0=lLfh4O6iV17a_J0AlIf04Nf]J17MOD`=`FU04LEM;17UHD`A_F4/4M55517AD
C`AZE4L3KeI:16m@A0QWD4@4I4Di16Y;@0=S@CD4>C0[12<H50@L4Q0450h:11@=3`@C2P/35`l;11T@
4@@_6A@4jN_[1;>j_1mlO7`Eoooo000Doooo7galO0@<1`H4<bTW13HY9@<`8b049aHC11<>2P@]61D4
@bLM160k:`BAECd3QW=T17e`I0AlJf@4O6aT17aaJPAlMG44O7A`0gacKPAlKVH4O6mX17aWH0AkJeX4
MemC0g1JD0AaEd/4NEQC16mHB`AdDDD4M5A?16YDA`=_ETX4Ke1426M@A0ATACT4JT]00f=1=@@i<2/4
8aPD11`B40@D3PX450d?11<:2`<G3`/46A0A12lI50CYjn/4/kZl7galO1Goool001CooolGO7al17ad
M@AdKFh42@D512lS80@e:2D3;b8O11/@3@@W71P4;QhJ12lS7PAQ?Rd4Ne520hIfJ@B3M6L4O6]X27ac
J`AlNGP7O7A`17aZH0AlKfP4M61B17eTE@AcE4/3Me]@17]NDPAdFTh4L5Y;17ACA`A[GE44JeI70fM8
A0AXD4@4Ie9616]BAPAZBSl4H5140ddj;`A4<RP48QPB124D4P@G4Pl471@@11`D3`<H40/47A@@12lI
50Ciool4Ng]l7galO1Goool001CooolGO7al17adM@AdKFh42@D512lS80@e:2D3;b8O11/@3@@W71P4
;QhJ12lS7PAQ?Rd4Ne520hIfJ@B3M6L4O6]X27acJ`AlNGP7O7A`17aZH0AlKfP4M61B17eTE@AcE4/3
Me]@17]NDPAdFTh4L5Y;17ACA`A[GE44JeI70fM8A0AXD4@4Ie9616]BAPAZBSl4H5140ddj;`A4<RP4
8QPB124D4P@G4Pl471@@11`D3`<H40/47A@@12lI50Ciool4Ng]l7galO1Goool001CooolGO7al17ad
M@AdKFh42@D512lS80@e:2D3;b8O11/@3@@W71P4;QhJ12lS7PAQ?Rd4Ne520hIfJ@B3M6L4O6]X27ac
J`AlNGP7O7A`17aZH0AlKfP4M61B17eTE@AcE4/3Me]@17]NDPAdFTh4L5Y;17ACA`A[GE44JeI70fM8
A0AXD4@4Ie9616]BAPAZBSl4H5140ddj;`A4<RP48QPB124D4P@G4Pl471@@11`D3`<H40/47A@@12lI
50Ciool4Ng]l7galO1Goool001CooolGO7al17adM@AdKFh42@D512lS80@e:2D3;b8O11/@3@@W71P4
;QhJ12lS7PAQ?Rd4Ne520hIfJ@B3M6L4O6]X27acJ`AlNGP7O7A`17aZH0AlKfP4M61B17eTE@AcE4/3
Me]@17]NDPAdFTh4L5Y;17ACA`A[GE44JeI70fM8A0AXD4@4Ie9616]BAPAZBSl4H5140ddj;`A4<RP4
8QPB124D4P@G4Pl471@@11`D3`<H40/47A@@12lI50Ciool4Ng]l7galO1Goool001CooolGO7al17ak
O0AkOWl41`D413hT6`@`9243=BPT12lS7`@Z7AT4;R4M13DQ60AJAS/4Fc`_0h=PD@AoLV@4OFaX17a/
I0AlL6P4O71Y1ga/HPAlI5X4M65C17AIC0AiJ5/4M5M=0g1GA@AaF4`4L5M517AJC`AdFTh4JUI:16mD
B0=_CT<4JUE626];@0ALBd04CD4e0dH_9@@X6a/4610?11HA3`@D3PX45`l@118:2`<91PH44`X;14XZ
9@CZl_84N7Qi7galO1Goool001CooolGO7al17akO0AkOWl41`D413hT6`@`9243=BPT12lS7`@Z7AT4
;R4M13DQ60AJAS/4Fc`_0h=PD@AoLV@4OFaX17a/I0AlL6P4O71Y1ga/HPAlI5X4M65C17AIC0AiJ5/4
M5M=0g1GA@AaF4`4L5M517AJC`AdFTh4JUI:16mDB0=_CT<4JUE626];@0ALBd04CD4e0dH_9@@X6a/4
610?11HA3`@D3PX45`l@118:2`<91PH44`X;14XZ9@CZl_84N7Qi7galO1Goool001CooolGO7al17ak
O0AkOWl41`D413hT6`@`9243=BPT12lS7`@Z7AT4;R4M13DQ60AJAS/4Fc`_0h=PD@AoLV@4OFaX17a/
I0AlL6P4O71Y1ga/HPAlI5X4M65C17AIC0AiJ5/4M5M=0g1GA@AaF4`4L5M517AJC`AdFTh4JUI:16mD
B0=_CT<4JUE626];@0ALBd04CD4e0dH_9@@X6a/4610?11HA3`@D3PX45`l@118:2`<91PH44`X;14XZ
9@CZl_84N7Qi7galO1Goool001CooolOO7al10h61P@c81L4<bXW0cLY9P@X7AX49ADB13DR60@c9B84
AST_148S70=kDD84QWi^189_H`AlJe`4O6aU17aXF@MlJ5X4O6QQ17][FPAgGe<4N5aA171;@@=`DDD4
M5AA17AKCPAdFU44M4e216YDB0M_D4@4Ie9616]:?`ATAc/4C44f14H_9@<X6QX48QTD11P@3@@H4Pl4
8A<?11L?40@B2P/34`X;13<J5PCon_H4aM;C8galO1Goool001CooolOO7al10h61P@c81L4<bXW0cLY
9P@X7AX49ADB13DR60@c9B84AST_148S70=kDD84QWi^189_H`AlJe`4O6aU17aXF@MlJ5X4O6QQ17][
FPAgGe<4N5aA171;@@=`DDD4M5AA17AKCPAdFU44M4e216YDB0M_D4@4Ie9616]:?`ATAc/4C44f14H_
9@<X6QX48QTD11P@3@@H4Pl48A<?11L?40@B2P/34`X;13<J5PCon_H4aM;C8galO1Goool001CooolO
O7al10h61P@c81L4<bXW0cLY9P@X7AX49ADB13DR60@c9B84AST_148S70=kDD84QWi^189_H`AlJe`4
O6aU17aXF@MlJ5X4O6QQ17][FPAgGe<4N5aA171;@@=`DDD4M5AA17AKCPAdFU44M4e216YDB0M_D4@4
Ie9616]:?`ATAc/4C44f14H_9@<X6QX48QTD11P@3@@H4Pl48A<?11L?40@B2P/34`X;13<J5PCon_H4
aM;C8galO1Goool001CooolOO7al10h61P@c81L4<bXW0cLY9P@X7AX49ADB13DR60@c9B84AST_148S
70=kDD84QWi^189_H`AlJe`4O6aU17aXF@MlJ5X4O6QQ17][FPAgGe<4N5aA171;@@=`DDD4M5AA17AK
CPAdFU44M4e216YDB0M_D4@4Ie9616]:?`ATAc/4C44f14H_9@<X6QX48QTD11P@3@@H4Pl48A<?11L?
40@B2P/34`X;13<J5PCon_H4aM;C8galO1Goool001CooolOO7al11/B4@@[8Ah4<BDS0c`X9@@^7AD4
:alL12TL60@b9R<4;1lK13<V90=V@c84Nf5;17a[G`AeI5T4OFaP17a[G0AlJel3M6AH17ETF@AmK5`4
LeA:171>@`A`EdD3Jdm416aGB`A/EdP4MEA816]<@@A[DdH4KdQ40fMCAPAWDT04I4@i15a7>`A8?C84
<ahJ0b4I50@I40d44Pd:11H?40@R4a045@h@10h61P<D2`/4<AXE1>kdm0AhN7TSO7al5Oooo`005?oo
oamlO7`46a8A12/Q7P@a9B<3?2PU12hM5@@[7a`4:A`H138V8`@/7a/4<bHT0fI3<PAkHD/4O6]O17ET
F@AmK604O6]L17a[G`=dI5P4MFAI17e/G0AcE4X4L4i3171GA@=[Cd@4K5M;16aGB0AeE4P4Jda116]C
APA_B4@3Ie=616MB@0ATA3T4G4Lk14Pm<P@c7QX38ATD11T@3@@B3@X45Pl@128C40@E3Q043PH60a@;
2`@a6QD4k_Cd17QhNB=lO7`Eoooo000Doooo7galO0@K4Q44:b4N134U8`<l:2D4;QdE12/O70@Y71P4
<RHS12`O6`@c9R@3IT<b17]QB`AlJel4MFAI17e/H0AlJe`4O6]O0gATF0AeI5T4OFaL17=DBPA`CT<4
L5M50f]?A0A/Ed/4K5M817EDB0A[C444Je=616m8A0=WDdH4Ie9016A4>@ALAc/4B3db13<N6P<Q6A@4
6A0=118=2P@F3a048Q<@11D>40@>1PH350/;134J5@C^m?@4N7Qi8galO1Goool001CooolOO7al11/B
4@@[8Ah4<BDS0c`X9@@^7AD4:alL12TL60@b9R<4;1lK13<V90=V@c84Nf5;17a[G`AeI5T4OFaP17a[
G0AlJel3M6AH17ETF@AmK5`4LeA:171>@`A`EdD3Jdm416aGB`A/EdP4MEA816]<@@A[DdH4KdQ40fMC
APAWDT04I4@i15a7>`A8?C84<ahJ0b4I50@I40d44Pd:11H?40@R4a045@h@10h61P<D2`/4<AXE1>kd
m0AhN7TSO7al5Oooo`005?oooamlO7`471@?12/Q7`@f:BD3<B@P12dR7`@P5AP49aXG12lR7@@g:BH4
<b0G0clT6`ARBc`4LeM<17=DB@AjHeH4MEiC17EUF@=dI5P4N61D17UQE@A/E4/4IdTn16aAA0=[CD@4
Kd]016mAA@A`D4@4Je1416M;@0AXBd03H4Pj15e6>PA>?SD4AC8W140]8`@O5Q835Q0=11HA3`@E3P/8
4`X;20T61P<b6aH4?QlE1>_cm2MlO7`Eoooo000Doooo7galO0@L50l4:b4O13HY9@<a9204;B8O120E
60@W6QL4;b8M13LY9P@c81L3?b@K169;?0AcEd`4LeA917YSEPAeGU<4MFEI0gATF0AhH5@4NF5E16aD
B`AWBCh4K5540f]=A0A_Bd04Ke55171@A0A[D4@4Id]016Q;@0=PB3X4GDHj14hn=@A5<RL4@2dS11lF
4P<F40d45Q4?11D>2`PC2P/82@H60c8K5P@n7aD4jo?d9galO1Goool001CooolOO7al11`D3`@[8Al4
=RTU0c4T80@]8Ql481DH12LJ5`@_8Qd4=bTV13<P5`<o91/4HT/l17=GC0AcE4T4NV=F17END`AeIET3
M6AH17QPE0AiHED4K5A;16M9?PA/DD@3Jde416m;@0A_DDD4L51416]@A0AWBd04J4]00f18>PAMASX4
CShe14Db9`A0;B<47aHB0aH@3@@F4@l45@h;21<:2`P91PH3<Q/F13hO5@C[lo@WO7al5Oooo`005?oo
oamlO7`471@?12/Q7`@f:BD3<B@P12dR7`@P5AP49aXG12lR7@@g:BH4<b0G0clT6`ARBc`4LeM<17=D
B@AjHeH4MEiC17EUF@=dI5P4N61D17UQE@A/E4/4IdTn16aAA0=[CD@4Kd]016mAA@A`D4@4Je1416M;
@0AXBd03H4Pj15e6>PA>?SD4AC8W140]8`@O5Q835Q0=11HA3`@E3P/84`X;20T61P<b6aH4?QlE1>_c
m2MlO7`Eoooo000Doooo7galO0A9?TD4;AlM13@X90<_8Ql4?Bl[12lN5@@Y5a<4>bdY12`P70@e:2@3
9AXG14Di;P@l;BH4ESL/175IC0AQBCh4JUMC0fUCC`AYDdL4LUaA15m7?@A7<RT4ECX`0f=0<0AYC444
J4i216Po=0AXC444Id/d16A7?0=L@CD4Echb14`n<P@h8Qh4;AXD11XA40<K4@h45@l;118:2`@C2P/4
3`H710X61`@E2`/3:1HA1=7;b`C@gN4WO7al5Oooo`005?oooamlO7`4BCi512dO7@@d:2@3;b8O13d_
:`@_7QD4:ALC13/]:@@/81`4=BPT0bDJ5`A5>Bh4?2dV15Hg;0AaFD`4HDTn16YGD`=YDdl4JE=7179L
D@AOAcd4Ac8Y15Dj<0=S@304JDa116Q>@PAX?c@4J4a116M;=0ATAc`3G44e15Ln<PA<?S84>28N12dJ
50@J4A036a4>11D?2`@B2P/44`X;10l61`@:1PL45@/;0bPF4@CAbl/4d=gQ9galO1Goool001CooolO
O7al14TnA@@]7ad4=2PT0blR7`@m;b/4;ahE12TG4`@k;BT4;20L13DX90<U6QL4ACT^13`]9PAF=b`4
LEU<1659?PAZEe<3JE=?16UCA`AbG544GdLm14Lb:@AE>S03Hd0`16U<@@AXCT84J3ld16Q<@@AWBc@4
I4Ll0ea1=@AG?S84C3hb13PR7P@]6Q@46Q4@0a/A3P@E3`/44PX;11<:2`@?1PL42PH711D;2`<X5Q44
dL_;1=3MhBMlO7`Eoooo000Doooo7galO0A9?TD4;AlM13@X90<_8Ql4?Bl[12lN5@@Y5a<4>bdY12`P
70@e:2@39AXG14Di;P@l;BH4ESL/175IC0AQBCh4JUMC0fUCC`AYDdL4LUaA15m7?@A7<RT4ECX`0f=0
<0AYC444J4i216Po=0AXC444Id/d16A7?0=L@CD4Echb14`n<P@h8Qh4;AXD11XA40<K4@h45@l;118:
2`@C2P/43`H710X61`@E2`/3:1HA1=7;b`C@gN4WO7al5Oooo`005?oooamlO7`4MgIh12<L50@V7AX3
<2<P138T8@@R71T481DG13HS6@@_8b04@34]0c<W8`@e9b<4>B/Y14db:@A<=BP4=Bh_13@`;0=4;B84
Ccha14hm<P@f:BD4>bTP144[80=>=bH4ECD[15Lm;0AV@C44ED0e14T`9PA@<BT3DSP^140c;P@g9B04
:QLB128C4@@H4@l350h:114:2`@>1PL<2PH7120E4@<`6QD4mOKf1864Q2MlO7`Eoooo000Doooo7gal
O0AgMWP48a`D12HM6P<`8b04<R@Q128L6@@P5AL4=R<I12lS80A0<Bd3<bLS13DW8`@i:bT4CC8Y14`e
:0@e;Rl4=30/0d@]8PA??S44CSdb13HY9@@k:B04@B/P0dhg9PAE=B/4Ecd/16I1<@AE@3D4BC0V150a
:@=B>2h4@3<^13LU80@Z5a848Q<A11PA3`<D3PX44@X;10h61``:1PL481DA0c0J5@Cem_H4PHB49gal
O1Goool001CooolOO7al17MfN0@S71@49QdJ0c0S80@b92448Q`I120E5`@f8aT4;b<P140a;@<c9b<4
=BLS13T[:@A=<RT4C3DX13D^;`@d<2`3A2dR14ln<@A>?C84=RTU13/Y80A1:b03CSLV15De:`AG?B`4
IT4a15E0=@A9<2H4D34Y0e8h;PA0<bh4=bDP12XG4P@R4a44614?0a@>2P@A2P/43PH730X61`@P5A43
<1XE1?GfmPB1Q8@WO7al5Oooo`005?oooamlO7`4MgIh12<L50@V7AX3<2<P138T8@@R71T481DG13HS
6@@_8b04@34]0c<W8`@e9b<4>B/Y14db:@A<=BP4=Bh_13@`;0=4;B84Ccha14hm<P@f:BD4>bTP144[
80=>=bH4ECD[15Lm;0AV@C44ED0e14T`9PA@<BT3DSP^140c;P@g9B04:QLB128C4@@H4@l350h:114:
2`@>1PL<2PH7120E4@<`6QD4mOKf1864Q2MlO7`Eoooo000Doooo8galO0@`:2h49A`J0cT[9`@`:BD4
<2<P11PA3P@a8ad4?S4^13d_:`<o<Rh4@3<_14/k<@A7>2h4>S4X130T90@b7aL3=AlM13`U7`@l:bD4
:AlO134S8@@m91h3?bHJ13/T7`A:=BP4AS4W13TY80A4<2D4?BPN0c`_:0@d8Qd4;ahG11dC4@@R6QP4
4Ph:0aH?2`@B2P/43`H710X61`@;1PL49QDA11X@4@>7He`4hN[[:galO1Goool001CooolSO7al130X
;P@U71X3>B/W130Y9@@`8b04614>134S7@@n<Bh4?Bl[0clb;PA0<bl4Bc/a14Lh;P@j<BP4<2@T138O
5`<e7ad4?2DO13`[9@@Y7al4<B<Q13dT7P<o9QX4>b@O14Xe:0A6<BL4>BTP14@`9@@m:1h3?2lX13@R
7@@_7QL47A<A128J60@B3PX35Pl;118:2`@?1PL42PH710/61`@V5A446Q0A0hMSG0CQj^/[O7al5Ooo
o`005?ooob=lO7`4<2P^12DL6P<i:bL4<2TU130S80@H4@h4<B<M13ha;P@m;b/3?c8^140c;`A;>c44
AcP^13Xa:0@`92@4<QlG0cDO7@@l9Al4?2/U12TO7`@a8b44?B@N0clV6P@k91l4BSDX14Ha9`@i:B04
A30U13dX7P<l;bP4=28M12lN5`@M4a448QXH118>2P<F3`/44PX;10l61`@:1PL42`H712HE4@@J4143
Qf=L1>7Zjb]lO7`Eoooo000Doooo8galO0ASG6H48QLC0c0T80@_8b04<B<O12lS80A0;bX4@34]13lb
;P<c9b<4<RHS13PQ7PA39Ah4=20H12/P7`@S61D3;b@R12<E4P@/9244:20O12PN6P@T51438ATF124D
4`@W5A849a`E12LK5@@Y7AH48A8A0b@D4P@O4a4481@B11@@3P@D3PX440T:1a<:2`P:1PL49QDK12HE
40@g:BD3m>kZ1:Fb]2]lO7`Eoooo000Doooo8galO0ASG6H48QLC0c0T80@_8b04<B<O12lS80A0;bX4
@34]13lb;P<c9b<4<RHS13PQ7PA39Ah4=20H12/P7`@S61D3;b@R12<E4P@/9244:20O12PN6P@T5143
8ATF124D4`@W5A849a`E12LK5@@Y7AH48A8A0b@D4P@O4a4481@B11@@3P@D3PX440T:1a<:2`P:1PL4
9QDK12HE40@g:BD3m>kZ1:Fb]2]lO7`Eoooo000Doooo8galO0ASG6H48QLC0c0T80@_8b04<B<O12lS
80A0;bX4@34]13lb;P<c9b<4<RHS13PQ7PA39Ah4=20H12/P7`@S61D3;b@R12<E4P@/9244:20O12PN
6P@T51438ATF124D4`@W5A849a`E12LK5@@Y7AH48A8A0b@D4P@O4a4481@B11@@3P@D3PX440T:1a<:
2`P:1PL49QDK12HE40@g:BD3m>kZ1:Fb]2]lO7`Eoooo000Doooo8galO0ASG6H48QLC0c0T80@_8b04
<B<O12lS80A0;bX4@34]13lb;P<c9b<4<RHS13PQ7PA39Ah4=20H12/P7`@S61D3;b@R12<E4P@/9244
:20O12PN6P@T51438ATF124D4`@W5A849a`E12LK5@@Y7AH48A8A0b@D4P@O4a4481@B11@@3P@D3PX4
40T:1a<:2`P:1PL49QDK12HE40@g:BD3m>kZ1:Fb]2]lO7`Eoooo000Doooo8galO0AjNG/4>S@b0bTP
7@@a9204=bTV130T80A4=S44:1dJ13/]:P<U6aP4=RTU14Xd:P@c:BD4:R8P12dT8P@Z7QX3@R`X11lD
5@@Y8ah49QDB12DE4P@L4@h36A<?11lB3`@Y5a@49aPD31`A3`<X5a@4718?11hC3`@D3PX45`l;118:
2`<C2P/82PH711D;2`@d81/4:QPC1>?ViP??dm@_O7al5Oooo`005?ooob=lO7`4NWUk13Xd<P<Y81d4
<B@P13LY9P@`9204A3Ha12PM6P@k;BX39A/H13HY9@A:=2X4<bTU12XR80@]9284:QhJ0d8/:0@O51D4
:B<N12HE4P@U5A84714>0aTC3`@O4Pl4:ALD12LH50`L4@l3:1LD11`B3`@N4`l450h:11L?2`@B2P/3
4`X;20X61`@E2`/4=20K12XH4`CSi^H3cm?D;galO1Goool001CooolSO7al17YiN`@j=383:B0M134T
80@g:BH4<2@P14@f<@@X7AX4>bdZ0bDK60@f:BD4BS@Z13<Y9@@Z8R04;B@R12XN6P=2;2P47a@E12TS
7P@V5A849ADB11`A3P<I4`l47a8?12TG50@W61@<714?0bPG50@L4Pl47Q<?11@>2P@G3`/44PX;0a<:
2`P:1PL45@/;13@P6`@Z61<4hnKV0loCe2mlO7`Eoooo000Doooo8galO0AjNG/4>S@b0bTP7@@a9204
=bTV130T80A4=S44:1dJ13/]:P<U6aP4=RTU14Xd:P@c:BD4:R8P12dT8P@Z7QX3@R`X11lD5@@Y8ah4
9QDB12DE4P@L4@h36A<?11lB3`@Y5a@49aPD31`A3`<X5a@4718?11hC3`@D3PX45`l;118:2`<C2P/8
2PH711D;2`@d81/4:QPC1>?ViP??dm@_O7al5Oooo`005?ooobMlO7`4FdmG0b4B40@f:BH4=bTV12lR
7`@V7a/4=bXW14Hg<P</9R84;B0L13hT6P@O5aD4:QhJ12/O6`@K5A/3:B4L11dD5@@Z61<47Q4G11TC
3`@I4Pl35Pl;11`C40@K4a046A<?11@>2P@A2P/45Pl;0b4C40@D3PX44@X;11H?2`@G3a044PX;0`X6
1`@C2P/47aDA138P6`@`6QD4f=_L1=SOh39lO7`Eoooo000Doooo9galO0AKCeL38A8@13HY9P@g:BH4
;b8O12HO6`@g:RL4ASLb0b`V8P@]81`4?R@J11lG5@@Z7QX4:alK11/E6`<Y8A`47A@E12XH4`@N4AL4
6A<?11TB3`<F3`/471<@11/C40@I4`l450h:114:2`@F3`/38A<@11@>2P@A2P/45Pl;11L?40@B2P/3
2PH711<:2`@O5A44<R0K130J5@CHfm`4f=oP<WalO1Goool001CooolWO7al15]?E`<Q4Q04=RTV13LY
9P@_8Ql49QlK13LZ9`A6=c83;2HR12dP70@n91X47aLE12XN6P@[7a/46aDK0bTQ70@M51D4:QPC11hA
5`@I4`l46A8?0aH?2`@L4a046a<@11TC3`@D3PX44@X;11H?2`<Q4a0450h:114:2`@F3`/45`l@118:
2`<:1PL44`X;11lE4@@b81/4<1XE1=SKg0CHgn0bO7al5Oooo`005?ooobMlO7`4FdmG0b4B40@f:BH4
=bTV12lR7`@V7a/4=bXW14Hg<P</9R84;B0L13hT6P@O5aD4:QhJ12/O6`@K5A/3:B4L11dD5@@Z61<4
7Q4G11TC3`@I4Pl35Pl;11`C40@K4a046A<?11@>2P@A2P/45Pl;0b4C40@D3PX44@X;11H?2`@G3a04
4PX;0`X61`@C2P/47aDA138P6`@`6QD4f=_L1=SOh39lO7`Eoooo000Doooo9galO0AiN7T39alK12/S
7`@e:2D4;b8O13HY9@@e:bL4=2LT0bDK60@U61D4:1/G11T@3P@_8Qd88AHG0b0C3P@N4AL45@h>1109
2P@F3`l45`l@0a8:2`@H3a044PX;11L?40@B2P/45`l@11hE40<H3a044@X;10T61`P:1PL42PH60aP@
40@J40/450/;12<?2`C?alP4fN7Q=WalO1Goool001CooolWO7al17UhN@<W7a/4:b<O13DX9@@_8Ql4
=RTU13D[9`@d9b@39A/H12DH5@@X6aL46A0>12lR7@PQ5QL381<>11hA5`@E3Ph440T:11H?3`@G3a03
4PX;11P?40@B2P/45`l@118:2`@G3a047QD@0aP?40@A2P/42@H720X61`@:1PH3610@11X@2`@D2`/4
8`l;1<o7b0CIhN4fO7al5Oooo`005?ooobMlO7`4NGQi0bLO6`@[8al4=BPU12lR7`@f:BD4=B/W13@W
90<U6aP49APE12PK5`@I40h4;b8M224F5`<P4`h47Q4G11D>3P@@2@X45Pl?11L?40<B2P/460l@118:
2`@G3a044PX;11L?40@N5A0360l@114:2`@91PL82PH710X61P<H41046Q0;11@;2`@S3`/4clO81=WQ
hCIlO7`Eoooo000Doooo9galO0AiN7T39alK12/S7`@e:2D4;b8O13HY9@@e:bL4=2LT0bDK60@U61D4
:1/G11T@3P@_8Qd88AHG0b0C3P@N4AL45@h>11092P@F3`l45`l@0a8:2`@H3a044PX;11L?40@B2P/4
5`l@11hE40<H3a044@X;10T61`P:1PL42PH60aP@40@J40/450/;12<?2`C?alP4fN7Q=WalO1Goool0
01Coool[O7al0g1_L0@o=344:AhJ130S80@a:RH4;bPT13h^:P<^8R@49QDB12PK60@H4Ph48A@@11LA
3P@O4`l340T:118:2`@F3`l45`l?11<:2`@H3a034PX;11P@40@B2P/4<1XE10T61P@I41047A@@0aH>
40@91PH42PH711061`@J41446Q0@0aX@4@@^6A@4>R@J17i<=`CZloD4PHB4=WalO1Goool001Coool[
O7al0g1_L0@o=344:AhJ130S80@a:RH4;bPT13h^:P<^8R@49QDB12PK60@H4Ph48A@@11LA3P@O4`l3
40T:118:2`@F3`l45`l?11<:2`@H3a034PX;11P@40@B2P/4<1XE10T61P@I41047A@@0aH>40@91PH4
2PH711061`@J41446Q0@0aX@4@@^6A@4>R@J17i<=`CZloD4PHB4=WalO1Goool001Coool[O7al0g1_
L0@o=344:AhJ130S80@a:RH4;bPT13h^:P<^8R@49QDB12PK60@H4Ph48A@@11LA3P@O4`l340T:118:
2`@F3`l45`l?11<:2`@H3a034PX;11P@40@B2P/4<1XE10T61P@I41047A@@0aH>40@91PH42PH71106
1`@J41446Q0@0aX@4@@^6A@4>R@J17i<=`CZloD4PHB4=WalO1Goool001Coool^O7al171_L0@n;R`4
<2TV12XO6`@n;RX4?BhZ0cP[:0@T7QT4;R8M11dA5`@G3`l481<@11L?40<J4`l47A@@11P@40PC2P/4
50/;0a<:2`@D2`/47A@@11T@40@];C`4>34a124C60<B2PX45`l?21lE40@I4144=B@N0bdM6@@^6A@4
FC@Y1=;Ig@BZ_/PjO7al5Oooo`005?ooobilO7`4L6m`13h^;0@`:BH4:QlK13h^:P@m;RX3>2/X12@N
6@@^8Qd47A4G11L?3`@P4a045`l@0aXC3`@M5104610@21<:2`@D2`/34`X;11@;2`@M51046A0@12d]
?0@h<C448A<H0a8:2P@G3`l87aD@11T@4@@e91h3;AdI12hI50AI=2T4d]WM1:Znb3YlO7`Eoooo000D
oooo;WalO0A`Kg04?Rh/130Y9P@Z7a/4?RhZ13d^:P<h:bP491hI12hR7@@M4AL45`l?120C40@G3a03
6Q<?11dD40@H41084`X;11@;2`<C2P/450/;11dD40@I4104;Bdl13Pa<@@Q4aP34PX:11L?3`PO5A04
6A0A13DT7P<]7AT4;QTD15Td:@CBfMd4Z[k8>WalO1Goool001Coool^O7al171_L0@n;R`4<2TV12XO
6`@n;RX4?BhZ0cP[:0@T7QT4;R8M11dA5`@G3`l481<@11L?40<J4`l47A@@11P@40PC2P/450/;0a<:
2`@D2`/47A@@11T@40@];C`4>34a124C60<B2PX45`l?21lE40@I4144=B@N0bdM6@@^6A@4FC@Y1=;I
g@BZ_/PjO7al5Oooo`005?oooc9lO7`4N7If13ha;P@j;2P4;20L12lW90=0<bh4=b/W13<O5P@U6QL4
6A<>11P?40@A2P/360l;11L?40@B2P/44`X;11P@40@C2P/3610@11<:2`@D2`/4<bla12hN:`A7=B/4
@c8]0c@W9PA9=c04<R<M11/C3`@/7AT4;ahI0cT[9`A?:b84fMGE1;S;d3ilO7`Eoooo000Doooo<Wal
O0AhMWH4?S4^13X/:0@/81`4;bLT0d0c;P@g:bL4<alF12DJ5`@I4`h460l@114:2`<H3`/45`l@118:
2`@C2P/4610@11<:2`<H41044`X;11@;2`@c;c44;Qh[14Le:`A3<Rd3=2LV14Tg<0@b8ad46a<?12`M
6@@_7QT3>B/W14l[8PCIeMD4^<_@?WalO1Goool001CooolbO7al17QfMP@n<Bh4>R`X12`P70@_9b@3
@3<^13L[9`@c7aH49AXG11TC3P@H3a044@X;0aP?2`@G3a044PX;11<:2`@H41044`X;0aP@40@C2P/4
50/;13<_<@@^7R/4AcD[14<b;@<d9bH4BCL`138S7@@K4`l4;1dI12lN6@<i:bL4Cb/R1=WEe@Bhbm0n
O7al5Oooo`005?oooc9lO7`4N7If13ha;P@j;2P4;20L12lW90=0<bh4=b/W13<O5P@U6QL46A<>11P?
40@A2P/360l;11L?40@B2P/44`X;11P@40@C2P/3610@11<:2`@D2`/4<bla12hN:`A7=B/4@c8]0c@W
9PA9=c04<R<M11/C3`@/7AT4;ahI0cT[9`A?:b84fMGE1;S;d3ilO7`Eoooo000Doooo<WalO0AmOGd4
JfY[13XW7`@l<Bd4>2XV0dDe<0@m<2`4?S4]12<I5`@W6aL4>BPT12`S7P<S510471@@11L?3`@H4108
4`X;0ahE6P@G3`l47A@@11T@4@@X7QX4=bLP110;30<D3``4614>114<3@@M4@h4;AhJ13DQ60=Y@2l4
YYVU1;oBePAlP80nO7al5Oooo`005?oooc9lO7`4OGem16]ZJ`@j9al4?34]13PZ9P=5=C04?C0/13ha
;@@S6AL49a/G13TX90@/8ah38a@@11`D40@G3`l4610@21<:2`<N5AX45`l?11dD40@I4144:1hJ13LW
80@@2``350l<11PA3P@A30d47A4>12dN6P@e8AP3JD0_1:JIY@Bod]H4O820?WalO1Goool001Cooolb
O7al17emO@A[JV/4>RLO13`a;@@h:RH3ACD`13d`;0@n<Bd48aTG12LK5`@i:2@4;2<N0b<D40@L5104
5`l?11P@40PC2P/37QDJ11L?3`@M51046A0A12PN6P@g9b0440/<0a@?30@H4@h44@`=11dA3P@]7QX4
=B4H0fU0;`BVVJD4_m;F17b0P3ilO7`Eoooo000Doooo<WalO0AmOGd4JfY[13XW7`@l<Bd4>2XV0dDe
<0@m<2`4?S4]12<I5`@W6aL4>BPT12`S7P<S510471@@11L?3`@H41084`X;0ahE6P@G3`l47A@@11T@
4@@X7QX4=bLP110;30<D3``4614>114<3@@M4@h4;AhJ13DQ60=Y@2l4YYVU1;oBePAlP80nO7al5Ooo
o`005?ooocYlO7`4Kfe/13de;P@T6aP3=bTU14`m>@A:@Sh4>BhZ12HJ5`@S5aP49ADB0c@U8@@Y8Qh4
5Ph?11<:2`@S6Ah48aTO0blU7`@P5a`4@S0Z11XB60AC?cL4<b@V12hS7`<j:B@4<B8N13PX90A@?Bl4
=RPT1756<`?=bm04[;o918ZAS49lO7`Eoooo000Doooo>WalO0A_KF`4?CD^12@K60<g:BD4C3di14Y2
?P@i;RX49QXG12<G60@U5A83=2DQ12TR7P@F3Pl44`X;12<I7P@S6Al3;bDO120G70A2<2X46Q8H15<o
=`@c92H4;R<O0cXY90@a8Qh4>2PT150m;`@f:2@4LDHc0lg;d0B/_lT4RY6<@WalO1Goool001Cooolj
O7al16m]K0@m=Bh491/H0cLY9@A<?CT4BT8n13T^:P@V6QL48aLH12DE4P<d9B44:B8N11H>3`@C2P/4
8aTN12<I7`<_9Al481LL148`:P@J4QP4Dclg13<T9P@^8al3>RTT134R7P@h:2@4D3d_13HX90AaAS<3
cL_@1:bob@B:THa2O7al5Oooo`005?ooocYlO7`4Kfe/13de;P@T6aP3=bTU14`m>@A:@Sh4>BhZ12HJ
5`@S5aP49ADB0c@U8@@Y8Qh45Ph?11<:2`@S6Ah48aTO0blU7`@P5a`4@S0Z11XB60AC?cL4<b@V12hS
7`<j:B@4<B8N13PX90A@?Bl4=RPT1756<`?=bm04[;o918ZAS49lO7`Eoooo000Doooo?WalO0A_KVh4
OWF30d0c;P@f:BD4=2TV13Tg@0A8>SH4Dd<o15I<A@<c9RP4:RT[14HkB`AMCdL4>RTZ130W<P<h9bH4
ASe<13h]9@@]8Al4BCH_13HU8P@l91l3?2@K13DY9PA>=b`4JT8a13<O60CEemL3Z[g717b0P4IlO7`E
oooo000Doooo?WalO0A_KVh4OWF30d0c;P@f:BD4=2TV13Tg@0A8>SH4Dd<o15I<A@<c9RP4:RT[14Hk
B`AMCdL4>RTZ130W<P<h9bH4ASe<13h]9@@]8Al4BCH_13HU8P@l91l3?2@K13DY9PA>=b`4JT8a13<O
60CEemL3Z[g717b0P4IlO7`Eoooo000Doooo?WalO0A_KVh4OWF30d0c;P@f:BD4=2TV13Tg@0A8>SH4
Dd<o15I<A@<c9RP4:RT[14HkB`AMCdL4>RTZ130W<P<h9bH4ASe<13h]9@@]8Al4BCH_13HU8P@l91l3
?2@K13DY9PA>=b`4JT8a13<O60CEemL3Z[g717b0P4IlO7`Eoooo000Doooo?WalO0A_KVh4OWF30d0c
;P@f:BD4=2TV13Tg@0A8>SH4Dd<o15I<A@<c9RP4:RT[14HkB`AMCdL4>RTZ130W<P<h9bH4ASe<13h]
9@@]8Al4BCH_13HU8P@l91l3?2@K13DY9PA>=b`4JT8a13<O60CEemL3Z[g717b0P4IlO7`Eoooo000D
oooo@WalO0AhMgP3OhF1144e?@A0<bh4<c<l15a>B`A;ADL4AChj0d<j=`AFCdl4FdI014/k<P@`9B84
@SD`0c8S8P@/81/4;1lI13/^:P@g:BH4AbLN14`]90=<=B/4FT8i14LW7`AQC504Y;S11<KCf4elO7`E
oooo000Doooo@WalO0AhMgP3OhF1144e?@A0<bh4<c<l15a>B`A;ADL4AChj0d<j=`AFCdl4FdI014/k
<P@`9B84@SD`0c8S8P@/81/4;1lI13/^:P@g:BH4AbLN14`]90=<=B/4FT8i14LW7`AQC504Y;S11<KC
f4elO7`Eoooo000Doooo@WalO0AhMgP3OhF1144e?@A0<bh4<c<l15a>B`A;ADL4AChj0d<j=`AFCdl4
FdI014/k<P@`9B84@SD`0c8S8P@/81/4;1lI13/^:P@g:BH4AbLN14`]90=<=B/4FT8i14LW7`AQC504
Y;S11<KCf4elO7`Eoooo000Doooo17aeM@AlOGe1O7al16m^L0BX[jT4W9VW14/oBPANCD`4MV]j0fID
EPAI@ch4B3Xe14Tl>@AIA4L4HT]50de0?@AVCTH4DD4g15Q8A0ARBTD4CShd14Po=`<c9R@4RW^81:Jd
^0Bb`lP4Z[JdDGalO1Goool001Coool4O7Ee17amOD5lO7`4Kfi`1:R_Z@BLVJL4Bcm:15i=C0AfJgX3
IUAF15U3?PA8>SD4BC`i15U4A`ARBdD3CD0m16I>APAA@CL4F4Q4169:A@A>?S@4B3lg0c<V90B:NhP4
Y[Bh1;;3b0BZ][AAO7al5Oooo`005?ooo`AlMGD4O7em@GalO0A_KW04Z:nY19bIY`A;?dX4GTe<17I[
NP=VE5H4FD<n14Pj=@A9?3T4FDA7169;A@==@3d4ITi61551=`AHB4@4HTY514hn=0A8?cL3<bHT18Yk
R0BV];P4//?81:Zf]55lO7`Eoooo000Doooo17aeM@AlOGe1O7al16m^L0BX[jT4W9VW14/oBPANCD`4
MV]j0fIDEPAI@ch4B3Xe14Tl>@AIA4L4HT]50de0?@AVCTH4DD4g15Q8A0ARBTD4CShd14Po=`<c9R@4
RW^81:Jd^0Bb`lP4Z[JdDGalO1Goool001Coool4O7n017b0P4UlO7`4NWUk17QlNPB^/:H4WjNW0gei
P`BIUi@4N7B714]6E@AABUT4ACXd0d@k>0A;?CX4A3Xg14Hi=`@o;B@4>30W1;Ve^P>W[[@4`LS:19>M
V5UlO7`Eoooo000Doooo17aoP0AlP819O7al17YiN`AhO7X4[[2V19nWY`=mNH<4VIND17QdQ`A;AUD4
DDYI14Dj=0=4>cP4Bcdj14@j=`A6>CL4?bdT13P`9`Bi]KX3Yjjd1<78bPBCWIQIO7al5Oooo`005?oo
o`AlOh04O820BGalO0AjNG/4N7aj1:j`YPBOYjL3OGV319VGU0AhM8L4BdIE155:F@A5>S@3A3/h14/m
>PA4>SL4ASTg13l]90@h<2L4^KFj0jN^]0C1b<X4TifHFGalO1Goool001Coool4O7n017b0P4UlO7`4
NWUk17QlNPB^/:H4WjNW0geiP`BIUi@4N7B714]6E@AABUT4ACXd0d@k>0A;?CX4A3Xg14Hi=`@o;B@4
>30W1;Ve^P>W[[@4`LS:19>MV5UlO7`Eoooo000DooooHGalO0=jNG`4QHR017QkO@B3RX<4XjNO1::U
V`>WY:H4Yjj`1:N][`BV[Jh4ZJn`1:jh_@Bl`LL3O820HGalO1Goool001CooomQO7al0gYiO0B5R804
N7]m18>:P`BSYil4XZFK0jNTYPBW[[04Yjf_1:J][PBY[k04[[Rm1;c1a`=lP81QO7al5Oooo`005?oo
of5lO7`3NWUl18F8P0AhNgd4PhZ31:>WW`BRYI/3YjBV1:N^/0BW[Jl4YZf^1:V_/0B^^;d4_<770gb0
P65lO7`Eoooo000DooooHGalO0=jNG`4QHR017QkO@B3RX<4XjNO1::UV`>WY:H4Yjj`1:N][`BV[Jh4
ZJn`1:jh_@Bl`LL3O820HGalO1Goool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool009Koool30000Qoooo`00VOooo`030000oooooooo08Coool0
07koool300001?ooo`800004oooo100000;oool300000oooo`<00003oooo0P00087oool0083oool0
1@000?ooooooooooo`000002oooo00@0003oooooool00002oooo00@0003oooooool00005oooo00@0
003oooooool00026oooo001ooooo0`0000;oool010000?ooooooo`0000;oool010000?ooooooo`00
00;oool400000_ooo`040000oooooooo0000Q_ooo`00O_ooo`040000oooooooo00000_ooo`040000
oooooooo00000oooo`<00003oooo0P0000Coool40000QOooo`00O_ooo`040000oooooooo00000_oo
o`040000oooooooo00001Oooo`030000oooooooo093oool007ooool300000oooo`800005oooo0P00
09;oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(112) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
747376747376747376747376747376747376747376747376747376747376747376747376
7473767473767473767473767473767473767473767473767473767473767473766C4E3D
78675D746462746B6674605B746B6674676274676274676274605B7464576C5D53705950
684E456C544A644E44685147685147685147685147684A41604D3D644D45644D3D644D45
869EAD747376747376747376747376746B6E74777A747376747376747376747376747376
747376747376747376747376
747376746B6D747375747376746B6D747375747376747376747376747376747376747376
747376747376747376746B6D747375747376747376747376747376747376747376745544
79686674645A746B6574605B746B667467627460536B584B6B584B6B5548634D455E4A41
5E473E624D445B473E685046685147685147684A40684A40604D43644D45644D3D646C73
86A0AF74737674737674737674737674737674787A747376747376747376747376747376
747376747376747376747376
747376747376746F7274737574737674787A747376746B6D747375746B6D747375747376
74737674737674737674737674787A7473767473767473767473767473767473766B4E3D
73635974645E74636274676274645E745F5A6B584C5255536650496743415E463E635147
68554B68584E695147644D435F4A405F4A405F4A405F4D3D604D43644D43644D4388A1B4
888F96747376747376747376747376747376746B6D747375747376747376747376747376
747376747376747376747376
747376747376746B6E74777A74737674737674737674737674787A74737674787A747376
747376747376747376747376747376747376747376747376747376747376747376744E3D
79676674646274645E74635E74605B74645674645F7B69678065587E5A5E6E594C725147
724D4A724D4A69403E604A40644D43644D43644D43644D436D544C654D43644D43869EAD
74737674737674737674737674737674737674737674787A747376747376747376747376
747376747376747376747376
74737674737674737674787A747376747376747376747376747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376745544
74685D74645674645E74645E74645E74645F746C6A746C6674655F7061576C5950755C53
7560566D514B7560536A4A446D45436D5B58654E446D4D436D4D43604A406D5B50879FAE
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376745543
74645A74646274645A74645E74645E746C6674645E745F5A74676274655F79695F716253
70595671594F6C584A684B4869584A68504269544F644E445F4D43604D437F7C818397A7
747376747376747376747376747376747376747376746B6D747375747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473767473767473767473767473767473767473767473767473767473765A3830725240
74646274645A746456746462746C6674645E746762746C66746C6674605B74645F745D54
795D5371594C71594F6D4E4B6D5144694A41604D4260473B6D4D43654D437E8D9B78858C
74737674737674737674737674737674737674737674737674787A747376747376746B6D
746A6D747375747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473767473767473767473767473767473767473767473767473761C120E664938837464
74646274645F746463746462746B6674605B74635674676174605B74605B746456746456
6B51506B544C70514F685141634A3E635147694D43654D436C5B5069554A879FAE797C7F
747376747376747376747376747376747376747376747376747376747376747376747376
74787A74787A747376747376
747376747376746B6D747375747376747376747376747376747376747376747376747376
74737674737674737674737674737674737674737674737652464F080202AD8E8679685E
746C6A74645F746C6674645F74635E746762746C67746462746053744D4F6B4C4262453E
6B4D4570584C68594F5E4E416C4E47695449604A3A604D43644D425F473E8199A8747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376746F72747375747376747376747376747376747376747376747376
7473767473767473767473767473767473767473767D7B7E0A040280654CD5B69A74645E
74636274605B74635E74605B74645E74635E74676274605B6B5C506B4E4C6B5849685148
6C544A675147685141644B41674A40634A40694A416D4D45654D436D54497E797D737173
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376746B6D74737674787A747376747376747376747376747376747376747376
7473767473767473767473767473767473767473760903016F564BD1AFA379685E746462
74645E74645E74645674645E74645E746C6674645E74605B6C2F31703035682B2C682B2E
6C2D316C4C4363473E63474068433A604D3C684D43684D43604D3D6C453C5F483E778287
747376747376747376747376747376747376747376747376747376747376747376746B6D
747375747376747376747376
74737674737674737674787A747376747376747376747376747376747376747376747376
747376747376747376747376747376747376524648735955D0AEA274605B746457746462
74645E745C4F745C4F745C5274635E74635E744A4C744C4F6C30316839305E28216C3D3A
63372F6C3C3A5C36335F453C5F4D3D60493F6C4D45684D43694D436D463F69574C6B5146
726F70747376747376747376747376747376747376747376747376747376747376747376
74787A747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376747376747376070403755D4A786352746456746456746462
7464566B55496B504873675D7468667455496B2F30622B25593C3548291D626959716D63
5C28215F282263362E65413A64504564463364503E684D43684D43684D43685045685046
82878B747274747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376746B6D747375747376747376747376747376747376747376
74737674737674737674737674737637282A492B1FD3AC927968666B554C736B69746463
7455496346395E393277565B6324281703025C434168473E75696186989781403B58332B
44322353574F382F235D28225C46396445316D49446D544C725C4A694E43685449684D43
674E44726865747274747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376746B6D74737574737674787A747376747376747376747376747376747376
7473767473767473767473767473760B07068D745E92807C74645A6C4E43786A6874605B
7456495B34285B342E2308084D5D5A83A9A4BDD6D27F99A47E9CA67987876C594A80AAA8
888E9364646A34201B251A115032266852416C4944725E5372584E6D5547694D43684A40
6854496776966A6A72737275747376747376747376747376747376747376747376747376
747376747376747376747376
74737674737674737674787A747376747376747376747376747376747376747376747376
7473767473767473767473765A5365070202BB998178675D74645674655B79706D74645E
633B31452F1F481E18240B079C65597E51426B3E37736966745744745A47633A336F656B
63392D7B645A734F3F71655B36201957302663443E705E4B7564596D554B644E4768463D
684C42606661574C405C586B727175747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473767473767473761C120E020000512E21D8B49879685E74554C74544C746359746456
643C326E5C528C847C9FAA96BD9D9A75635C684A47674B456A2728593132591F1F62201C
561A1661544A532A225E393C4E322D350E07674943755D4B74645C684E3F64473E604A41
68584C695A4F8986906A627781837D747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376746B6D747375747376747376747376747376747376
7473767473765A4C56000000120D0BD2B2A2928573745C53744D536B645A736B61744D53
64413A53392B7C716E79706E7465637472677A7F777F7B747E7B6B726D5A7B6A5A737057
736E5C6D5849722F32662F2C53201646130E60231B695345745A54684E3F64474160463D
6C4C42685046160F0E6D696A7F7D77737275747376747376747376747376747376747376
747376747376747376747376
74737674737674737674737674737674737674787A747376747376747376747376747376
7473767473765B55678F7058EFA58AD8AF93736356745D5374695E74595779675D74655A
64534364443C82756A73635D74676274645F74635E746762744D506C4D4670584F685148
6C4E475C4B3B5F4A3F5B5B43665B4B7565567D605D7E6948705A4F685141644741604D3D
6C51456854491E202193908E727678797C7F747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
74737674737675554283644F746D6C71695E6F605673645A74686674656374796E746463
6C564E6D4F4568483E6E6157736B6574686274645F746B667461546C594A68443B685040
5B47384C433A5B3F335C3C325C3F325C3C325C4232715E4C765F596C4E445C403A60453D
644D3F5F4D420B0D0DA3A1BD878E96747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473766B63657354436B554C624635525059776057796766746C6A746C66746C66746862
744E5071554D6D4B417A655A786664746762744A4C6B5B4E735F5263473F684B415B3930
5B46405D3A3365423361463D694F376146376142317A5A5172504663473E5C433A64493F
6450456D544C040709978B857B7E77747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376745442795B4F63473F5E473E756B6288544F746765746B66746762746762746762
7461547462506952426C4D42786E6B746B6674615C7471677968666C4E4E6D554B644C42
6D574B5D3A3161413761453D684C426D49457C5C537B665C634A41634A40694D4365493F
64503F644D42080808372823838288747375747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473767455436B5C534C2A1D746B5F835F6479685E747066746B66747072746863746762
74605B74655B644F466C554774726573635D746053746C6674645F6C56495F443963473E
604D4360473D694F38614237684B417658537A675C6D584E64554B68554A604D43604D43
6451466D5B535D3E29572A1F2B201D6A6E71747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
745348632D21521A1A57363067757377685E74705E746462746B6674676174635B746762
74605B6B5C506C564D756D627E746C79685D6B4D49736259744A4C6346365F3A3360453C
583F366445304D362D5B3C37715E51765F53745F52685148644E4468473E694A40654D3D
6D463C6D5A4F61413972524BC3DCE5D0D7DC747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
74403D642F2C5C2E2C645F4F7F7769886B66746C6B746463746B6674676274676274605B
7460536C5D50795950716459786766746C6B74656479706A74564D6452425C413B584238
553C33583E355D433D7B62557B6659725F55745C52685148644E44684A41684643694543
64463F685E5A59352864483E90ADBB747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376745A4F
744E3C64463754402E6C6454877B6E796866746B6674686274645E745F5A6B584C735F52
744D4F6C544C6F51496B5C5278676574635674605A74645E744E506441395C40385D4339
61463B5D4F456C5745715B4F71584D755B526C5147684A41644E4468433A68463C60493C
60513D6C5E5A69413769574E626C786D6C6E747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376633926
4A261E2419143B2D26786C6382776B74646274635E745F5A746053745C4F6C5C4F6F504F
624D456B584F70645A70695D786B6074645E74646274645E6B5D50634C3D5C463D5D4339
61453B694C426D504576545372584D6C544A68584F6C554B64514768514760514660493F
6449456C5A5A582518685D5165392F868A8A747376747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473767473767473767473765B2517
150E0A291F1C291D1D8271647D6F6C74646274645674645674645E746463746867796967
7159546C4A475E493D6F574E6F5F5673636274645E7464566C4D495F3E3654373A5C4233
593F35684B416D574C6C4D436250436C4D4A63463D624A405B473E5F4A40604A4064463D
6449456450425136225F4F3E5F343286ABBA747376747376747376747376747376747376
747376747376747376747376
74737674737674737674737674737674737674737674737674737674737674635D64362D
48302837251E2F201FA986717D6F636B5C4F73635E74645A5A463E58453A432D25422C24
422D2A4D313262493D67493F66524A78676574645E74645F6C4E4D5F453959403161422D
59453D64483D54483E4F423A5F4C4267584D5B4B3E685449695147654D43644D4364463D
6449456450433A20193E1B165E372A86ABB4747376747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473767473767473766B4636633A33
0404030B0C0C1F1917B1907974685C745C5379675D7464566D564D5240383C2F27212324
1415172419114533263A1A14391913705B5173635D74645E6C56495F4539594031594C37
503C336C5348725B4F77584D765146644542513F386B5349685147604A4155463D54463D
63514564514341251E55291F743E318BAEC1747376747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473767473767D7B7E7548385F3A33
1914142016122F1815C5A188796C6170605773675D74645A7465636149408C6964342924
1F12102D191234313152342A846B5B9797857874717475766C5E515F42394A342C50382C
2209075C40365338254130282D211A4E3E3555493C6C503F5F4A40604A405640365D493F
6C4945553F362E1B1950322879524B95C4D3747376747376747376747376747376747376
747376747376747376747376
746A6D747375746B6D747375747376747376747376747376747376040000542419634E45
291F1B18151B1F1410BFA48B6F605674645A7060566B5C537363626D5E5172594E5C473A
986B59925B3F87563D96674C89685A7A6A5E786F6D7467616C4E405F3E375A3A2C593E33
4D2E265E5956212527010405291B1933312C14120F34282636271D5A382A55453C5D4C42
6C493F40372B1F171336251E7F615490B6C16F6F71747376747376747376747376747376
747376747376747376747376
746F7274777A74737674787A7473767473767473767473760601010401011E0704171413
03060C0F0F0D2A1813CFA98F7060567867665A34345D413A776664746C677A6A68775E5B
6E4E446F554B7D5B528569587F635B75685C7873707467626C4B475F4E455941325A4F39
6B46347D6455724636100C0D3D20163026242119185D3B2D6843357E604E61483F5D493F
6C513F1A15161C1511351E17813C2E809BAA6F6E71747376747376747376747376747376
747376747376747376747376
74787A74787A7473767473767473767473767473767473760A03023122192D181427201C
0A090A291813321815C59B827960567060567566606A6152473028412B2334251D231A18
1C1512261D1732201A38221B5F514B6F675C786B69745F526C4B405F5145593B33613F32
5D4937685646654E43775C4EAE71577547366E402F9E624E855B40615146644D3F6A5448
5D493F14110F2015123A1F18772F228AB7C5747376747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473760E04021B0F0B14110F1A1310
1D120F1D1511322724AA887077635974685E7968667565607E706474544F483F4377504C
764C3D7D5B4A6E493C896456988F7F837471796866744D506C554D5F5248593539351E18
341F195A4635634D3E644D3C6D4E437056436C5A4D7A614C594C4264494B5D493F634D3F
40342B08090914110F945F4A6B312393C5D3747376747376747376747376747376747376
747376747376747376747376
747376747376746B6D7473757473767473767473767473761408051F0F0B1F15111B1410
0D07081F141038282488635177625773675D746462746C66746C677B73718D8E85A49588
8C8E8596969196928E9A90807B7468786F6D6B5D506B5D4F6B615069554C735E536D5A48
452C2C281F1A131010402B26624C44604D3D654D3F5D493F5C3F384D3C326348426D493F
1A14120E0B0B2C231F7E4130401C141E22226A6A6C747376747376747376747376747376
747376747376747376747376
74737674737674737674787A7473767473767473767473760D08072019171E15111F1410
16100C241612362824895C49866E61786B60746462746B66746762747072747173747173
74686374707274686374686374655B79675D746053715950705149715C53756156765A57
725F5B8E65595E433B3A241D1715112319172022212F231D36251D674B47764F445C4236
0D0C0C17110F241819240D0A27100C282B2BC3CACF747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376140A093C292518130F1F1410
1F141027191B3628256D4E3C726054776A6074645A74635E746762746761746B69746C6A
746C6A74707274635B74676274686374645B74645A6C564D705D5370584F705C52705553
69594C695648685345775B4B785A486B4535593D2F7E4D3E745C4F7A4C4E54483D453D33
0F0D0D1D1310191410140F0B251916333230BEC5CB747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473761408052A1D15211815211410
24100C2A181534221846332975574B786A5F73635A746462746B66747072746762746B69
746C6A746C6A74635B74676274605374605B745C536C4D46705C52705D5370584F70544B
6851446D4A41694E44664E4378594D79594D82625580594D6E4F4B6D4A3F61483834221A
130E0D1D13102A18151B14102115113121187E6C6F706F72747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473760D0604302827231A18271713
15100C1D14111C131039241C5738267A685C78675D746462746B66747071746C6A746762
746B6974635B74635B74676274605374645A6B55496B595070584F70544B70544C70584F
685148634E4463514769584E644D43684A40654D4355463D54493F54493D3F372D101313
0B0B09211719151010130F0B0D0708281815644F4C8D9899747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473761408052F24222D221F271C18
2718142215112A1D1A3C2E2B41342C82655A77625874636274635E746761746B69746C6A
74707274635B74676274676274605B6B5C536B554C70544C70544C70584F68584F675147
685147644E44685147685046694E44644D43604D4356463D6D493F5E42382E221E150E0E
261A17130C0C140F0F0E08081710112416125A4D48A0AFB5747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376100A093028273528252F2320
271714130F0B2918153F251C5C3829834D3878655A73675D74645E74635E746761746B69
746C6A746C6A74686374676274605B74645771595068554C6751476F514E6851476C4A41
6C4D4A644E44685147684A40604A40604A405C3F3665453C5D3C33322B281E16131B1210
130F0B130E0F130C0C17100C1911122D1915E1E6EBB2BBC1747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376746B6D6B63650D07072C221F3227242D221F
1A110E271C192D1F1B2B221E573A2C6F4B3F786C63786B60746462746C66746C66747071
746C6A746C6A74635B7467626B594C735C4F6C4D4671544C75594F6C554A6854476C4E44
63584D6351446043405F4A40604D43644D4365463D594C4246372E413026211813201513
1813101C15111C151018110C1C15112D1915DCE7EC747376747376747376747376747376
747376747376747376747376
74737674737674737674737674737674737674737674787B0C08073A231A2F2320322724
3024202A1E1A2C211D3321185142384E382D72544973665B73636274635E746762746761
74625A74625A745B536B584C6B51456F60566B51496851416751476851416C544A6C554B
645147684E44694B4165514364463D64453C55463D463C33402B2323191A16101015110F
130F0B160F10110B0C090708120B0C462825D2DCE16F6E71747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376140A09311F17302826342825
271D1A23151232211831242140352D3A201B69473C78716578675D74645674635E745F52
745F52745F5274605A74645771595070544B68433B684A416C4D4D6C544B6C544D6C473E
644D44684A40684A40604D4364463D5C4238463C32402B232318181E181317110E171310
211410171011130C0C130C0C331B16FFFFFFC7D8DD747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473762117152C22202E2422382724
2D1D152B201C261C192E2422281E1A2D2322573D2F6953426E5E546B5C53736359746456
74645A6B5C536B5C527363566C4E4668473E685141634A406250466250446C4D4463473E
634D43684340604D43604D3D5C40365542384339302E1C191E181317110E110E0B150F10
2014101510100E0808130C0C2E1A16CFDBDF6F6E71747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473762016112A211F3528252E2320
2A221F1E1618251A172C211C342825311F17362119504036604A436648406F574E6B544C
6B5B526B5C5370594F6F584F634D465E443B62494063474068453C684940674A40634A40
60463D5F463C584236543F364539333B2D2438281F1C161114100E15110F15100C120B0C
120B0B0907080A0808301B163D2016D1DBE0747376747376747376747376747376747376
747376747376747376747376
74737674737674737674737674737674737674737674737651444E3222213227242D221F
3B2E2A301F16281813392B282A1F1C322724231A1839332B2D2622412B255F4B42563F38
5D4C4A5D49485D494166534B5740383D2C2547332A56382A5F453C5F493F5F39305F453C
6046305C4238553C3350392F46392F33201D2718131711101A110F15100C120B0C120B0C
0F08080A0808150C0C251611CDCDD3D0E0EA747376747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473767676782A2218251D1A2C221F
2E2320201C191E16183222192D221F3D2F2C332724322622332827422E273C2D23272528
25272532231A3F322840332B2A212031231C38261E413022472E274B35275B3C2D4C3B31
3E2A22442A2549322A382F2C30211E2515111F131117110F130F0B110B0C0E08080A0808
0A08080B08081F16122F1A16DBE0E5797C7F747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376362C35281F1E372A27
2F28252F232018120F2D221D3A2F2E3B2E2A3C312D3F332F493B3043372D342F28292222
2C1B152D1B1A301F1C312420221B1C29201F35221D37231931201D3D2F253A2B242E251E
3B2C2235251C322A252D1F1B2A1C161A13111F1A18120F0B15100C130C0C0F08080B0808
0B08082616121A111282625DD6E0E5747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376685F69291B172F2320
2C221F2E221F302420402F2B3D2F2C3C312D3025222D2321331E1C3D211C311D17281F1D
1F18152A23211F151225211F241F1D241D191F14111B17161B13121F13111E18141F1914
211A151A11101E12111911101B131212110E130F0B0F0A0B120B0C120B0C0A08080B0808
26161C261612372925EBEBECA2B1B7747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376757476443D3C2D2320
2E23203428252F2320413430271D1A352A27231A173226234633293029252622202A2321
291E1B3F2B281F151626221E2315122314121B110E1713101C120F26171424171419110F
19110F19110F2417141B13101C1310130F0B16100C130C0C130C0C0A08080A0808150C0C
32201B2A1913E4E9EED0D7DC747376747376747376747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473767473767473765E5059271513
3528253428252D221F221E1A3329264436322B26232A1F1C3721191C1514261D19281E1A
19151A241F1B1B14152817131C111717131017131015100C1A1410191410171310130F0B
100B0B150F0B1E1410130F0B100B0B150F0C171011130C0C0A0808130C0C20161233211C
2F1A16DBE1E6DBE6EB747376747376747376747376747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473767473767473767575772F2621
2C24203227242D221F352825322A262F2522231A17231815241A1717110E2B201C201617
2016171F130E1C1117140F0F0F0B0B150F0F160F10120B0C171011110B0C160F10120B0C
1710111D1511171011110B0C0A08080A08080A08080A08081811111A120D130C0C200F0B
CEC9CEDAE5EA747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
7473767473767473767473767473767473767473767473767473767473767473767A7A7C
4B3E3C291F1B2C221F2E28252C27243A2C292D2224251613261B1817120F1E141016110E
1D130F100B0B100B0B150F0F171010130C0C171010130C0C181111130C0C2F1A160A0808
1811111C15101610100A08080A08081008081A11121A12121A11122D19153C251B834F39
E0E9ED797C7F747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7A7A7C4C3836322B27281E1A3A2C293B2C29362B28241F1A2C221E1D13181610101F1410
1610101A14101D1611181111120B0C120B0C130C0C120B0C130C0C1C15101811112D2D3D
3A343522151A120B0C17101020161220161219121234241F2E1F1A2D1915563329CFDBE5
A7BFCF747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473768483864C3A373C2D2A2A1F1C2A25223C312D372B28332017261A171A140F171010
110B0C17100B160F10120B0C120B0C181111130C0C181111130C0C130C0C322E312D1E2A
44322946342E392A294D393335251F1B14102C1D1A2D1E1A372A274F2C23DAD9DEB7CED7
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376737375757678442E263E312D372A2741322E3A2F2B3D312E241B18271B183A2925
2F251F2416111C1511171010181111130C0C120B0C1D151B1710101D1611181111241D18
32251E0D0B0C100E0C14100D0E0C0C1B110E2B1D1A332118663E2DAA9DACBAD1DB74787A
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473767473767473767B7B7E463E37231B18312623473A3748413E3C302D271C18211618
2314123325212B241F161010120B0C22191F241B202F262021191D42302B1C141A503D37
3325273024203C2B2533241F3A2925523F31382925704634D1D1DBAEC6D5838B88747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473767473767473767473767B7A7D968B9D4839353226232E242234343D493C39594743
5B514A34282A29282B483E4F65564F3F2D2D302832372827483D4E3E2E272E221F46342D
3424213B231F3B231A3528254C362C694130361F19CDD5DBA7C0CF74787A747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473767473767473767473767473767676789197954D3F493F332F303039554948494448
423C3A433B385A51525C464048382F30242242352E312321281E19281D17382C29342825
43251D4B2C244B352B5B423947271F5A474EAAC3D3C6D7E2747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
746A6D747375747376747376747376747376747376747376747376747376747376747376
7473767473767473767473767473767473767473767B7A7CBFC8C4B4AFC050435058484A
786A7E6A575C59413E463733463A37594448644C4851423F6C514A56453A594944644C48
4F40364440382F2624817688B2C5D0C1D9E2A7B6B7747376747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
74787A74787A747376747376747376747376747376747376747376747376747376747376
747376747376747376747376747376747376747376747376747376757476858884BCC0B8
A5B0B084818DA1A3A58580984F495C4C475A3F37333F37354539373F3735423635382921
332C24B6B4BEC0C8D2C9D6DB8D9996747376747376747376747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
7473767574767E827A767A7C8E958DB3B7AEB3B8B0B8B7BDB8C1C7B8C2C7B9C2C8BEC8CE
C3D0DCBCC5CF74787A747376747376747376747376747376747376747376747376747376
747376747376747376747376747376747376747376747376747376747376747376747376
747376747376747376747376
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?oooeUdLgH4K4hm17QWG@=dI684M6]V17APF`AdJfH;M6MR17AP
F`AdI5L4K5eC171ID0AXCTD4K5A:0fA>A11XDDL4J4Y10f1=?@ATCDD4I4dm16A=A@B6WZd?M7=f17A[
KPAdMgXSM7=f5Oooo`005?oooeUdLgH4K4hm17QWG@=dI684M6]V17APF`AdJfH;M6MR17APF`AdI5L4
K5eC171ID0AXCTD4K5A:0fA>A11XDDL4J4Y10f1=?@ATCDD4I4dm16A=A@B6WZd?M7=f17A[KPAdMgXS
M7=f5Oooo`005?oooeUdLgH4K4hm17QWG@=dI684M6]V17APF`AdJfH;M6MR17APF`AdI5L4K5eC171I
D0AXCTD4K5A:0fA>A11XDDL4J4Y10f1=?@ATCDD4I4dm16A=A@B6WZd?M7=f17A[KPAdMgXSM7=f5Ooo
o`005?ooo`AdLgH4M6]]17AcM@AdLgH4M6]]0gAcMB=dLgH4M6]]17AcMAMdLgH4M5E417UXIP=dI5X4
M6]U17APF`AdJfH4M6MR17APD`M[F4/4JeE816==A@ANBT44GTLn169=A0=KAch4J51626QAA`QXBT03
H4e316A=A@ATCCd4I6ac18JP[a=dLgH4M7Qj8gAcMQGoool001Coool4M7=f17A[K@AdLgD4M7=f17A[
K@=dLgDSM7=f17A[K@AdLgDGM7=f17AEA0AiJ6H3M6AJ17A[I@AdH5/4M6]V17AWHPAdH5<7JeQ;16]E
B0ASCDD4GTY115i7?PARCD@3FdLn16Q@APQXDDL8J4Y00f1=@`ATCDD4I4dm16A/L`B6X:lCM7=f17Ah
NR=dLgHEoooo000Doooo17AcMPAdJfd4M7=e17AcMPAdJfd3M7=e8gAcMPAdJfd4M7=e5gAcMPAdED@4
NFQV0gATFPAdJfD4M61K17A[IPAdIf84M61C1f]HB`A[EDP4Hde515i:@@ANAch4HTe40e]7?PAXD4H8
J55726Q:@0=PCD<4I4e516A=?@ATK7<4QZ2_4gAcMPAdN7XSM7=f5Oooo`005?ooo`AdLgH4M6]]17Ac
M@AdLgH4M6]]0gAcMB=dLgH4M6]]17AcMAMdLgH4M5E417UXIP=dI5X4M6]U17APF`AdJfH4M6MR17AP
D`M[F4/4JeE816==A@ANBT44GTLn169=A0=KAch4J51626QAA`QXBT03H4e316A=A@ATCCd4I6ac18JP
[a=dLgH4M7Qj8gAcMQGoool001Coool8M7=f17A_LPAdLgD4M7=f0gAhNPAdLgH4M6]]17AcM@AdJfd4
M7=e4gAcMPAdN7XGM7=f16]>?@AcHeT3M6AN17ASHPAdIf84M6AN17AOFPA[F4`3DUEC16I@B@AW@d44
GTHn16=AA`AXED/4J5Q>0fUAA`ATCD<<GdY015m=?@=PCD<8I4e318RQ]0B8SiHCM7=f17A[K@AdLgDO
M7=f5Oooo`005?ooo`QdLgH4M6mb17AcM@AdLgH3M7Qj17AcMPAdJfd4M7=e17A[K@AdLgDCM7=f17Ah
NQMdLgH4Jdhm17=SF@=dI5h4M6=R17AWHPAdI5h4M5mJ16]HC0=BEE<4IU1916M3@@ANASh4He5716QE
B`AXF4h3JE5716A=@`aOBT04Gddm0f1=@`QTCD<4R:6d18R?UQ=dLgH4M6]]17AcMAmdLgHEoooo000D
oooo27AcMPAdKg84M7=e17AcMP=dN7X4M7=f17A[K@AdLgD4M6]]17AcMA=dLgH4M7Qj5gAcMPA[CSd4
Lf=I0gATGPAdHf84M6MR17ATGPAdGeX4JeQ<0e9ED`AVD4T4Id=115i6?PASDDL4J5E;16QHCP=YDDL4
I4e335m:@0AOCCd3H4e326A=@`B8XK@4R8nF4gAcMPAdJfd4M7=e7gAcMQGoool001Coool8M7=f17A_
LPAdLgD4M7=f0gAhNPAdLgH4M6]]17AcM@AdJfd4M7=e4gAcMPAdN7XGM7=f16]>?@AcHeT3M6AN17AS
HPAdIf84M6AN17AOFPA[F4`3DUEC16I@B@AW@d44GTHn16=AA`AXED/4J5Q>0fUAA`ATCD<<GdY015m=
?@=PCD<8I4e318RQ]0B8SiHCM7=f17A[K@AdLgDOM7=f5Oooo`005?ooo`QdLgH4M6]^17AgNPmdLgH4
M7Qj17AcMPAdN7X^M7=f17A>?@AiIfH3M6AR17ATGPAdHeh4M61K17ATEPAdI5l3NfUW181UF0AnFUh4
KUU<179AA`QbCDX3JD0n161:@11TCD<3KEA<16E=@`ATCD<4QYj]6gAcMPAdN7XOM7=f5Oooo`005?oo
o`QdLgH4M6]^17AgNPmdLgH4M7Qj17AcMPAdN7X^M7=f17A>?@AiIfH3M6AR17ATGPAdHeh4M61K17AT
EPAdI5l3NfUW181UF0AnFUh4KUU<179AA`QbCDX3JD0n161:@11TCD<3KEA<16E=@`ATCD<4QYj]6gAc
MPAdN7XOM7=f5Oooo`005?ooo`QdLgH4M6]^17AgNPmdLgH4M7Qj17AcMPAdN7X^M7=f17A>?@AiIfH3
M6AR17ATGPAdHeh4M61K17ATEPAdI5l3NfUW181UF0AnFUh4KUU<179AA`QbCDX3JD0n161:@11TCD<3
KEA<16E=@`ATCD<4QYj]6gAcMPAdN7XOM7=f5Oooo`005?ooo`QdLgH4M6]^17AgNPmdLgH4M7Qj17Ac
MPAdN7X^M7=f17A>?@AiIfH3M6AR17ATGPAdHeh4M61K17ATEPAdI5l3NfUW181UF0AnFUh4KUU<179A
A`QbCDX3JD0n161:@11TCD<3KEA<16E=@`ATCD<4QYj]6gAcMPAdN7XOM7=f5Oooo`005?ooo`adLgH4
M7QjBGAcMPAdED@4M6QM0gATEPadI5h4M6AO17A/JP=dK6H4M6EO171QE`A/FE04MEaC17EPEPA]DD/3
MF1C16Y:A0A]AD<4KE]H16E>A0M]CD<4H4Y016eKD0B7WjhnM7=f5Oooo`005?ooo`adLgH4M7QjBGAc
MPAdED@4M6QM0gATEPadI5h4M6AO17A/JP=dK6H4M6EO171QE`A/FE04MEaC17EPEPA]DD/3MF1C16Y:
A0A]AD<4KE]H16E>A0M]CD<4H4Y016eKD0B7WjhnM7=f5Oooo`005?ooo`adLgH4M7QjBGAcMPAdED@4
M6QM0gATEPadI5h4M6AO17A/JP=dK6H4M6EO171QE`A/FE04MEaC17EPEPA]DD/3MF1C16Y:A0A]AD<4
KE]H16E>A0M]CD<4H4Y016eKD0B7WjhnM7=f5Oooo`005?ooo`adLgH4M7QjBGAcMPAdED@4M6QM0gAT
EPadI5h4M6AO17A/JP=dK6H4M6EO171QE`A/FE04MEaC17EPEPA]DD/3MF1C16Y:A0A]AD<4KE]H16E>
A0M]CD<4H4Y016eKD0B7WjhnM7=f5Oooo`005?oooeUdLgH4M5E317ATFP=dI684M6AJ27ATGPAdK6H4
M6AN0gAOFPAdIf84M6EO17UYG`AaHU<4L5UF175IC`=/F4X4J4]816UHBPAXD484JEA?16A>A0=OCD<4
H4e317mlP@B3UjLKM7=f17A[K@AdLgDKM7=f5Oooo`005?oooeUdLgH4M5E317ATFP=dI684M6AJ27AT
GPAdK6H4M6AN0gAOFPAdIf84M6EO17UYG`AaHU<4L5UF175IC`=/F4X4J4]816UHBPAXD484JEA?16A>
A0=OCD<4H4e317mlP@B3UjLKM7=f17A[K@AdLgDKM7=f5Oooo`005?oooeUdLgH4M5E317ATFP=dI684
M6AJ27ATGPAdK6H4M6AN0gAOFPAdIf84M6EO17UYG`AaHU<4L5UF175IC`=/F4X4J4]816UHBPAXD484
JEA?16A>A0=OCD<4H4e317mlP@B3UjLKM7=f17A[K@AdLgDKM7=f5Oooo`005?oooeEdLgH4FSP`179B
@0AdI683M6AJ17ATEPAdI684M6aV17ATGPAdIf87M6aV17APF`AdI5l4M5eD17UMD`AaFD`3LEU?16e>
B`A]DD@4JDY1161=@PAPAc/3KDe316E=@`AnSI/4N8F<7gAcMPAdN7X7M7=f17A[K@AdJVd4M7=e27Ac
MQGoool001CooomEM7=f15Xh<0AbDT04M6AR0gATFPAdI5H4M6AR17A/IPAdI5h4M6MR1gA/IPAdH5/4
M6AO17AME0AiGE<4LEU<0g5IC`A]CT/4KE5416U:@@APCD84H4Lk0fe=@`AUCD<4OXfK17R5S1mdLgH4
M7Qj1gAcMPAdJfd4M6Y]17AcM@QdLgHEoooo000DooooEGAcMPAJ>304LU9017ATHP=dI5X4M6AF17AT
HPAdK6H4M6AN17AWHPMdK6H4M61K17ATG`AdGE@4NEeC175IC0=aFDl4KDi;16eAA0AYBT44H4e21617
>`=]CD<4IDe317j=V`AhQH`OM7=f17AhNPMdLgH4M6]]17AZK@AdLgD8M7=f5Oooo`005?oooeEdLgH4
FSP`179B@0AdI683M6AJ17ATEPAdI684M6aV17ATGPAdIf87M6aV17APF`AdI5l4M5eD17UMD`AaFD`3
LEU?16e>B`A]DD@4JDY1161=@PAPAc/3KDe316E=@`AnSI/4N8F<7gAcMPAdN7X7M7=f17A[K@AdJVd4
M7=e27AcMQGoool001CooomAM7=f11`B3PAVBCP4PgAT17ATHP=dI5l4M6AS17ATHPAdJfH4M61K17AS
EP=dIf48M61K27ATEPA[DE04JeA<0g1AC`AXDD44HdXn16=AA`AYCD<4IDe30faKD0AYEDX4Qin^17Ul
ObidLgH8M7Qj27AcMQGoool001CooomAM7=f11`B3PAVBCP4PgAT17ATHP=dI5l4M6AS17ATHPAdJfH4
M61K17ASEP=dIf48M61K27ATEPA[DE04JeA<0g1AC`AXDD44HdXn16=AA`AYCD<4IDe30faKD0AYEDX4
Qin^17UlObidLgH8M7Qj27AcMQGoool001CooomAM7=f11`B3PAVBCP4PgAT17ATHP=dI5l4M6AS17AT
HPAdJfH4M61K17ASEP=dIf48M61K27ATEPA[DE04JeA<0g1AC`AXDD44HdXn16=AA`AYCD<4IDe30faK
D0AYEDX4Qin^17UlObidLgH8M7Qj27AcMQGoool001CooomAM7=f11`B3PAVBCP4PgAT17ATHP=dI5l4
M6AS17ATHPAdJfH4M61K17ASEP=dIf48M61K27ATEPA[DE04JeA<0g1AC`AXDD44HdXn16=AA`AYCD<4
IDe30faKD0AYEDX4Qin^17UlObidLgH8M7Qj27AcMQGoool001Coool8M7=f17A[K@AdLgDmM7=f1596
C`@80P84[Hj617UXGPAdK6X3M6AO17A/IPAdI5l4M6=N17AWHPAdK6L3M6AR17APD`AdCDl4Jda21695
?PA[CDD4L5Q<0fQIC`ANCT44K4i716UDB@APBSX4H4e30fA=@PAOAch4PIVX@WAcMQGoool001Coool8
M7=f17A[K@AdLgDmM7=f1596C`@80P84[Hj617UXGPAdK6X3M6AO17A/IPAdI5l4M6=N17AWHPAdK6L3
M6AR17APD`AdCDl4Jda21695?PA[CDD4L5Q<0fQIC`ANCT44K4i716UDB@APBSX4H4e30fA=@PAOAch4
PIVX@WAcMQGoool001Coool8M7=f17A[K@AdLgDmM7=f1596C`@80P84[Hj617UXGPAdK6X3M6AO17A/
IPAdI5l4M6=N17AWHPAdK6L3M6AR17APD`AdCDl4Jda21695?PA[CDD4L5Q<0fQIC`ANCT44K4i716UD
B@APBSX4H4e30fA=@PAOAch4PIVX@WAcMQGoool001Coool8M7=f17A[K@AdLgDmM7=f1596C`@80P84
[Hj617UXGPAdK6X3M6AO17A/IPAdI5l4M6=N17AWHPAdK6L3M6AR17APD`AdCDl4Jda21695?PA[CDD4
L5Q<0fQIC`ANCT44K4i716UDB@APBSX4H4e30fA=@PAOAch4PIVX@WAcMQGoool001Coool<M7=f17A_
LPAdLgDeM7=f17ekOP@:1084P6E<1=FfVPAdI5h4M6=R0gAPF`AdHeh4M61K17ATGPAdHeh4M6MR0gAP
F`A[G504Jdi<16]HB@AXDDP4K5A:16MAA`=XDD44I4]116M:@0ASBT04JDY116e=A@=UCD<4KEA917ii
O@AcLG<nM7=f5Oooo`005?ooo`adLgH4M6mb17AcMCEdLgH4OG]n10X40PB0ID`4eKJJ17ATGPAdHf83
M61K17ASGPAdH5/4M6AN17ASGPAdIf83M61K16]LD0A[CT`4JeQ916QAB0A/E4X4Ie570fQA@@ATBd44
IdY016=:@0AYBT44KDe50fE=@`A]E4T4OWUm17=aLcidLgHEoooo000Doooo37AcMPAdKg84M7=e=GAc
MPAmNgh42P@2181UC0CE]YX4M6AN17ASHP=dH5/4M6=N17APF`AdI5h4M6=N17AWHP=dH5/4Jea@16]>
C0A[F4T4J55816aDBPAWDDL3J55116A;@@AWBT04HdY016U:@@A]CDD3IDe316eDB@AnNGd4Lg5c?WAc
MQGoool001Coool<M7=f17A_LPAdLgDeM7=f17ekOP@:1084P6E<1=FfVPAdI5h4M6=R0gAPF`AdHeh4
M61K17ATGPAdHeh4M6MR0gAPF`A[G504Jdi<16]HB@AXDDP4K5A:16MAA`=XDD44I4]116M:@0ASBT04
JDY116e=A@=UCD<4KEA917iiO@AcLG<nM7=f5Oooo`005?ooo`QdLgH4M6]]17AcMPAdN7XeM7=f10T3
0@A_ET/4dJnS17UXGPAdI687M6AN17ATEPQdI5h4M6aV17ATGP=dH5/4K2la170`=@AX:b`4J2/^16`]
<@A/C4<3HdLn16=7@0AX@cX4H4dl26Q=@`=PCCd4K4Dl15m8?PAgPXLZM7=f17A[K@AdLgD<M7=f5Ooo
o`005?ooo`QdLgH4M6]]17AcMPAdN7XeM7=f10T30@A_ET/4dJnS17UXGPAdI687M6AN17ATEPQdI5h4
M6aV17ATGP=dH5/4K2la170`=@AX:b`4J2/^16`]<@A/C4<3HdLn16=7@0AX@cX4H4dl26Q=@`=PCCd4
K4Dl15m8?PAgPXLZM7=f17A[K@AdLgD<M7=f5Oooo`005?ooo`QdLgH4M6]]17AcMPAdN7XeM7=f10T3
0@A_ET/4dJnS17UXGPAdI687M6AN17ATEPQdI5h4M6aV17ATGP=dH5/4K2la170`=@AX:b`4J2/^16`]
<@A/C4<3HdLn16=7@0AX@cX4H4dl26Q=@`=PCCd4K4Dl15m8?PAgPXLZM7=f17A[K@AdLgD<M7=f5Ooo
o`005?ooo`QdLgH4M6]]17AcMPAdN7XeM7=f10T30@A_ET/4dJnS17UXGPAdI687M6AN17ATEPQdI5h4
M6aV17ATGP=dH5/4K2la170`=@AX:b`4J2/^16`]<@A/C4<3HdLn16=7@0AX@cX4H4dl26Q=@`=PCCd4
K4Dl15m8?PAgPXLZM7=f17A[K@AdLgD<M7=f5Oooo`005?ooo`adLgH4M7Qj=WAcMP=BATP4LeUE1=2^
XPAdH5/4M6AG17ATHPAdI5h7M5a?17ALDPQdHeh4M4Y<0gA<C`A/<344J3T`15hX8@A/?CX4HcL_16`l
>P=L=S<4GdDl15m=?@APBCl4K4e516Q=@`=YCD<4KDHo16UGC0A[DDH4LVm`:WAcMPAdN7X<M7=f5Ooo
o`005?ooo`adLgH4M7Qj=WAcMP=BATP4LeUE1=2^XPAdH5/4M6AG17ATHPAdI5h7M5a?17ALDPQdHeh4
M4Y<0gA<C`A/<344J3T`15hX8@A/?CX4HcL_16`l>P=L=S<4GdDl15m=?@APBCl4K4e516Q=@`=YCD<4
KDHo16UGC0A[DDH4LVm`:WAcMPAdN7X<M7=f5Oooo`005?ooo`adLgH4M7Qj=WAcMP=BATP4LeUE1=2^
XPAdH5/4M6AG17ATHPAdI5h7M5a?17ALDPQdHeh4M4Y<0gA<C`A/<344J3T`15hX8@A/?CX4HcL_16`l
>P=L=S<4GdDl15m=?@APBCl4K4e516Q=@`=YCD<4KDHo16UGC0A[DDH4LVm`:WAcMPAdN7X<M7=f5Ooo
o`005?ooodIdLgH31`@317EMBPAhHe88M6AF17ATHPAdI5H3JeE916]@B0AcIed4M6QV17AEB@A[;c03
HR/U15Tl=@A8:Ad4HVUI175]H`AL:244GbPR0f<f;PAU@CX4I51516A6<`ATD3h;J4e316Q@A@AXD4H4
PXN;17AbM3IdLgHEoooo000DooooAWAcMP<710<4MEe:17QSDPQdI5H4M6AR17ATEP=[EDT4Je1817=W
G@AdJ6H4M5E916/_<0=R:bD4FC`e14PY7@ARJET4LFeS15`X8@AO:283HcH^16E1>PATD4D4I4Hc16A@
?P]XCD<4J51516Q@APB2Qh/4M79d=WAcMQGoool001Cooom6M7=f0`L40`AeGDX4N6=B27ATEPAdI684
M6AF0f]EB@A[D4P4LfMM17AXIPAdEDT4Jbl`0f8[9@AI?3D4B2TM169YF@AaKF<4G2PQ15lX8P=S=Rh4
ID4j16A@A@ATAS<4I50n2fQ=@`AXD4D4J51618:7R`AdLW@fM7=f5Oooo`005?ooodIdLgH31`@317EM
BPAhHe88M6AF17ATHPAdI5H3JeE916]@B0AcIed4M6QV17AEB@A[;c03HR/U15Tl=@A8:Ad4HVUI175]
H`AL:244GbPR0f<f;PAU@CX4I51516A6<`ATD3h;J4e316Q@A@AXD4H4PXN;17AbM3IdLgHEoooo000D
oooo47AcMPAdJfd3M7=e:gAcMP@g:2X3BB/O1=>/TPAiJ6H4JeE<17=[J@AdI6<4M5E90f=6>@AN>C84
MeIK16<T:0@G0`84G4=10fQ7?PAeJF44QYRG1850>`AH<b/4A38S15=GC`<h;b<4GBPR15a6>@ATAC44
KDU416eDC0=bG4X4JDi316QDB@AXCD<4Idi4179XI@AdLW@bM7=f5Oooo`005?oooa1dLgH4M6]]0gAc
MB]dLgH4=bPZ0dT[7`CC[984NFQV16]EC0AcJfT4M6AS17AEB@=SAST4GSTb17MFF`AS92P45`<215a3
@@=XAch4MFUQ18JHU`B1@3/4F3<[14@b8`ACEdl3>2lS15dX8PALAST4I4Da16e9A0A]E4`3LUa:16U>
@`AXE4T4J4e316M>A0AbJ6D4M79d<WAcMQGoool001Coool@M7=f17A[K@=dLgD[M7=f13LX:P=9:al4
djbB17UXIPA[ED`4Lf]Y17ATH`AdEDT3HdHi15hi<PAgEU/4Hb@X11L30PAL@d43J4Ln17EYH@B6V9L4
PD0k15Pc:`A4<R<4DeM?0cP_8`AM:284G4Hi16A5<@A]BD@4KEA<0g9LBPAYCT<4J5A916Q=@`AWCT@4
LVQU17AbM39dLgHEoooo000Doooo47AcMPAdJfd3M7=e:gAcMP@g:2X3BB/O1=>/TPAiJ6H4JeE<17=[
J@AdI6<4M5E90f=6>@AN>C84MeIK16<T:0@G0`84G4=10fQ7?PAeJF44QYRG1850>`AH<b/4A38S15=G
C`<h;b<4GBPR15a6>@ATAC44KDU416eDC0=bG4X4JDi316QDB@AXCD<4Idi4179XI@AdLW@bM7=f5Ooo
o`005?ooo`QdLgH4M6]]17AcM@AdLgH3M7Qj:gAcMP@;1`H3SGAN19:0O0AdI5X4K4i317QZJ0AdH5/4
M5I90e/d:0AK=2h48`P814eMFPB3ZJ@4_MKB0gnIY0AnW:H4NHN716aIBPB0ZZP4R8jC16ATJP<d81/4
9AXA150b9PAXDT44K4U4179ND`=bF4h4KEE716U=@`AXBT04J5A916MfUPAZJW83Lg9e;gAcMQGoool0
01Coool8M7=f17A[K@AdLgD4M7=f0gAhNR]dLgH42`L60hedGPBBP7`4M6AJ16a>@`AhJVP4M61K17AF
B@=K=2P4Fc@^12<820A=GEX4PjVT1;gFdP=oVJ@4OYbV17V7Q`A/FDX4P:ZX18R>T`ATI6X3=20K12DJ
4@A@<RH4J59116a9A0AbGU<3LUQ>16eEA`AYCD<4J4Y016QDB@AWMYH4JVYb0g=bMBmdLgHEoooo000D
oooo27AcMPAdJfd4M7=e17AcMP=dN7X[M7=f10/71P>=M5h4TX1l17ATFPA/CT<4N6YX17APF`AdETT3
Fc@X15/d;P@S20P4CEeJ18>YY0Bme]83OiVT17jLYPAiQhL4K5U:182ZZ0B8SY<4I6AZ0c@P6`@U6Q44
D38V16QB@@A/BD@4LUiC0g9HCPA]EDL4JDe316Q:@0AXE4T4IgJF16YZLP=cLWD_M7=f5Oooo`005?oo
o`QdLgH4M6]]17AcM@AdLgH3M7Qj:gAcMP@;1`H3SGAN19:0O0AdI5X4K4i317QZJ0AdH5/4M5I90e/d
:0AK=2h48`P814eMFPB3ZJ@4_MKB0gnIY0AnW:H4NHN716aIBPB0ZZP4R8jC16ATJP<d81/49AXA150b
9PAXDT44K4U4179ND`=bF4h4KEE716U=@`AXBT04J5A916MfUPAZJW83Lg9e;gAcMQGoool001Coool<
M7=f17AhNRidLgH4FU=U10L20P>kVH44N6MM17ATEPAdIE/4NG1]17ATGPAS>c43ABlO14PN60@T2`L4
W6EI17iA@PA[?SL3LfUV17AGA0AdFTL4HcXc16mUJ`AS>Bd4NfAJ0g=??`AaIE/4=R0I15L`9PASA3h4
L5i;0gETF@A]ED/4I4i716Q6?@AXC484H6IQ15M<@0=LF6/4LW5e:gAcMQGoool001Coool<M7=f17Ah
NRidLgH4FU=U10L20P>kVH44N6MM17ATEPAdIE/4NG1]17ATGPAS>c43ABlO14PN60@T2`L4W6EI17iA
@PA[?SL3LfUV17AGA0AdFTL4HcXc16mUJ`AS>Bd4NfAJ0g=??`AaIE/4=R0I15L`9PASA3h4L5i;0gET
F@A]ED/4I4i716Q6?@AXC484H6IQ15M<@0=LF6/4LW5e:gAcMQGoool001Coool<M7=f17AhNRidLgH4
FU=U10L20P>kVH44N6MM17ATEPAdIE/4NG1]17ATGPAS>c43ABlO14PN60@T2`L4W6EI17iA@PA[?SL3
LfUV17AGA0AdFTL4HcXc16mUJ`AS>Bd4NfAJ0g=??`AaIE/4=R0I15L`9PASA3h4L5i;0gETF@A]ED/4
I4i716Q6?@AXC484H6IQ15M<@0=LF6/4LW5e:gAcMQGoool001Coool<M7=f17AhNRidLgH4FU=U10L2
0P>kVH44N6MM17ATEPAdIE/4NG1]17ATGPAS>c43ABlO14PN60@T2`L4W6EI17iA@PA[?SL3LfUV17AG
A0AdFTL4HcXc16mUJ`AS>Bd4NfAJ0g=??`AaIE/4=R0I15L`9PASA3h4L5i;0gETF@A]ED/4I4i716Q6
?@AXC484H6IQ15M<@0=LF6/4LW5e:gAcMQGoool001CoooljM7=f11`B3P@20004DBhQ0mRdV0AiJ5h4
M5E<17ADC0AdHeT4M6AF16@l<P=^G584S8Al19nZUPBmWIX4MF=L16Q:A`=WBdD4JRLX15Ta<PAI7al4
HR0L15HJ5PAQE4X3DbXR15hi?0A><Rd4=@h716M9@`AeGD/3M6AL16Q>?`ATAch4H4Y116QHC0AYFTl4
RHJ@0fYRM`B1Pgd[M7=f5Oooo`005?ooocYdLgH4718>108000AA;R43f;BH17UXGPAdED`4M5A<17AS
F@AdI5H4I3`b0fiLDPB<Q7`4WjZF1;fMVPAeHe`4J4Y70fM;A@AZ9bP4FC4b15TO7`AR81`4EQXF165D
BP=C:R84GSTl14hb;@@e3PL4IdU317EMB`=dI5`4J4ho16A7?PAPBT44J5Q<16UJC`B9QY03JV9g1863
OB]dLgHEoooo000Doooo>WAcMP@L4Ph40P00154^8@?H]9P4NFQN17AEC0AdE4`4M6=I17ATEPAT?383
KUaB18b4O0BOZYH4_IfJ17ESG0AXBTL3Id]516XW:0AI<C84FAlO168P70AF6QH4HEA:0e<Z8PAN>C`4
CS8]13D>1`AWBD<4MEe;0gATG0AXCSl4I4Ln161:@@AXF4`4JEY?18V6T0=ZHWL4PH=m:gAcMQGoool0
01CooolDM7=f0gA[K@AdLgDKM7=f15Y<EP@000044Pd;1=:bXP>BQG<4M5aC17A=D`A[I5X4Lf]Q17A=
D`AT@CX3DcT[17aaKPAiL6h4M6ES17AbI`AjOgL3Og]d17ikJ`AbKEX4NfYJ17=`E`AcKU`4KEQ90g8_
<PAV;b`4Db0F14HC3PAP8a/4JE=50gAJE0AXCSl4I4M11616?@A/C484J51611H?3P=]JFX4Ogeg17=b
MBMdLgHEoooo000Doooo57AcMP=dJfd4M7=e6gAcMPAJC5H40000118=2`CB/Z83TXEc17ALD`AdCE<4
JfAJ17=[H@AdCE<4I44j0e<i:`AlLFh4NG1^17AUH`AdLVL4NWmg0gmkM0AnNf/4LVeJ17]ZFPAcL5L4
LfiL16eHB@=b;c84IRl/15<P5PA64`h4H2<K16UCA@=dFU@4J4ho16A7@@APASd4K4a216Q@AP@F3`h3
KFUZ17mmM`AcLWDWM7=f5Oooo`005?oooaAdLgH3M6]]17AcMA]dLgH4FTaF100000@B3@/4d[:R0i:5
L`AdG5<4M4eC16]TFPAcJf44M4eC16A1>P=C>B/4O75^17U`KPAdIF<4M79W17YoM`=oNg@4OW][179]
FPAkJUX4Lg1G17=^G0A]F4T3LRlb16H_;0AC81H4AQ<>160S6`AYDdD3M5YD16Q>?`ATAd44H4Hm16a<
@PAXD4H45Pl>0feYJPAoOGL4Lg9e9gAcMQGoool001CooolDM7=f0gA[K@AdLgDKM7=f15Y<EP@00004
4Pd;1=:bXP>BQG<4M5aC17A=D`A[I5X4Lf]Q17A=D`AT@CX3DcT[17aaKPAiL6h4M6ES17AbI`AjOgL3
Og]d17ikJ`AbKEX4NfYJ17=`E`AcKU`4KEQ90g8_<PAV;b`4Db0F14HC3PAP8a/4JE=50gAJE0AXCSl4
I4M11616?@A/C484J51611H?3P=]JFX4Ogeg17=bMBMdLgHEoooo000Doooo5gAcMPAdN7XKM7=f15]E
I`B?L5P4kjF:1=R_T`=cHeH4M5eC17AYGPAdFEL4NFMM17AUFPATDd<3I4@l189eJPAcHed4M6MR17AT
G`AdHeh3M6MR17A=D0A/CDH4L5Q?16QAB0A/CTL4G4/k0em:?`AKFd<4IU];17EUEPAmH5d4OVU80g1J
C`AXDD44I4M1161=?@A/DDD4J5A911hP8@>CT8h4LWIh17UlObMdLgHEoooo000Doooo5gAcMPAdN7XK
M7=f15]EI`B?L5P4kjF:1=R_T`=cHeH4M5eC17AYGPAdFEL4NFMM17AUFPATDd<3I4@l189eJPAcHed4
M6MR17ATG`AdHeh3M6MR17A=D0A/CDH4L5Q?16QAB0A/CTL4G4/k0em:?`AKFd<4IU];17EUEPAmH5d4
OVU80g1JC`AXDD44I4M1161=?@A/DDD4J5A911hP8@>CT8h4LWIh17UlObMdLgHEoooo000Doooo5gAc
MPAdN7XKM7=f15]EI`B?L5P4kjF:1=R_T`=cHeH4M5eC17AYGPAdFEL4NFMM17AUFPATDd<3I4@l189e
JPAcHed4M6MR17ATG`AdHeh3M6MR17A=D0A/CDH4L5Q?16QAB0A/CTL4G4/k0em:?`AKFd<4IU];17EU
EPAmH5d4OVU80g1JC`AXDD44I4M1161=?@A/DDD4J5A911hP8@>CT8h4LWIh17UlObMdLgHEoooo000D
oooo5gAcMPAdN7XKM7=f15]EI`B?L5P4kjF:1=R_T`=cHeH4M5eC17AYGPAdFEL4NFMM17AUFPATDd<3
I4@l189eJPAcHed4M6MR17ATG`AdHeh3M6MR17A=D0A/CDH4L5Q?16QAB0A/CTL4G4/k0em:?`AKFd<4
IU];17EUEPAmH5d4OVU80g1JC`AXDD44I4M1161=?@A/DDD4J5A911hP8@>CT8h4LWIh17UlObMdLgHE
oooo000Doooo=WAcMPAeED84PfA?17A]K0AaJEh3Kf1F17=TFPAdJ6H4M6ES17AiKPAdI6<4K5I>0fe?
A@AXB3h4KV5G17=[I@AdJ684M6AO0gA[IPAdHE@4K5U:16Q4>`AXD404FdLh14a3>P=K?c<4G3`b15`o
<PAL?384G48b175NC0=fGeT4K4i415a0>PAPACd4I4do15m=@P@;3@d3Xj6m18N>UR]dLgHEoooo000D
oooo=WAcMPAeED84PfA?17A]K0AaJEh3Kf1F17=TFPAdJ6H4M6ES17AiKPAdI6<4K5I>0fe?A@AXB3h4
KV5G17=[I@AdJ684M6AO0gA[IPAdHE@4K5U:16Q4>`AXD404FdLh14a3>P=K?c<4G3`b15`o<PAL?384
G48b175NC0=fGeT4K4i415a0>PAPACd4I4do15m=@P@;3@d3Xj6m18N>UR]dLgHEoooo000Doooo=WAc
MPAeED84PfA?17A]K0AaJEh3Kf1F17=TFPAdJ6H4M6ES17AiKPAdI6<4K5I>0fe?A@AXB3h4KV5G17=[
I@AdJ684M6AO0gA[IPAdHE@4K5U:16Q4>`AXD404FdLh14a3>P=K?c<4G3`b15`o<PAL?384G48b175N
C0=fGeT4K4i415a0>PAPACd4I4do15m=@P@;3@d3Xj6m18N>UR]dLgHEoooo000Doooo=WAcMPAeED84
PfA?17A]K0AaJEh3Kf1F17=TFPAdJ6H4M6ES17AiKPAdI6<4K5I>0fe?A@AXB3h4KV5G17=[I@AdJ684
M6AO0gA[IPAdHE@4K5U:16Q4>`AXD404FdLh14a3>P=K?c<4G3`b15`o<PAL?384G48b175NC0=fGeT4
K4i415a0>PAPACd4I4do15m=@P@;3@d3Xj6m18N>UR]dLgHEoooo000Doooo<WAcMPA[HfD4LeA316]E
C0ARASD4DU1I0gMPE`AiIfH4M6aZ27A/IPAdJ684M4i@0g5EC@A]Bd44NVEJ17QVI0AdIf84M4Y<0f]K
CPAcGe84HdLo16Q;@@AK>C04FdI015dj<`=U@S<4HDHm16U?=`AQASL4HD8a17YJD@=bD4H4HdLn15a3
>PATBCl4I51516eDC0@41`T3Uh^517]nMb]dLgHEoooo000Doooo<WAcMPA[HfD4LeA316]EC0ARASD4
DU1I0gMPE`AiIfH4M6aZ27A/IPAdJ684M4i@0g5EC@A]Bd44NVEJ17QVI0AdIf84M4Y<0f]KCPAcGe84
HdLo16Q;@@AK>C04FdI015dj<`=U@S<4HDHm16U?=`AQASL4HD8a17YJD@=bD4H4HdLn15a3>PATBCl4
I51516eDC0@41`T3Uh^517]nMb]dLgHEoooo000Doooo<WAcMPA[HfD4LeA316]EC0ARASD4DU1I0gMP
E`AiIfH4M6aZ27A/IPAdJ684M4i@0g5EC@A]Bd44NVEJ17QVI0AdIf84M4Y<0f]KCPAcGe84HdLo16Q;
@@AK>C04FdI015dj<`=U@S<4HDHm16U?=`AQASL4HD8a17YJD@=bD4H4HdLn15a3>PATBCl4I51516eD
C0@41`T3Uh^517]nMb]dLgHEoooo000Doooo<WAcMPA[HfD4LeA316]EC0ARASD4DU1I0gMPE`AiIfH4
M6aZ27A/IPAdJ684M4i@0g5EC@A]Bd44NVEJ17QVI0AdIf84M4Y<0f]KCPAcGe84HdLo16Q;@@AK>C04
FdI015dj<`=U@S<4HDHm16U?=`AQASL4HD8a17YJD@=bD4H4HdLn15a3>PATBCl4I51516eDC0@41`T3
Uh^517]nMb]dLgHEoooo000Doooo<WAcMPAdE484NE]?16=7?`ANAch4MF]R0hQDC`AdIfD4M6]V37AW
HPAdHE@3M69@16UB@PA/CD84N6i[17A[IPAdHE`3M75W17UXIPA/CTh4KEE;16A<@PA]Ed/4GCXa0f51
=`AQACd4J4a216e9A@AlG5<4NfIL0f=:@@ASBT04JDe316E9?`ATD3l4I4e210P820<g:2<4Ph:817Ac
MBMdLgHEoooo000Doooo<WAcMPAdE484NE]?16=7?`ANAch4MF]R0hQDC`AdIfD4M6]V37AWHPAdHE@3
M69@16UB@PA/CD84N6i[17A[IPAdHE`3M75W17UXIPA/CTh4KEE;16A<@PA]Ed/4GCXa0f51=`AQACd4
J4a216e9A@AlG5<4NfIL0f=:@@ASBT04JDe316E9?`ATD3l4I4e210P820<g:2<4Ph:817AcMBMdLgHE
oooo000Doooo<WAcMPAdE484NE]?16=7?`ANAch4MF]R0hQDC`AdIfD4M6]V37AWHPAdHE@3M69@16UB
@PA/CD84N6i[17A[IPAdHE`3M75W17UXIPA/CTh4KEE;16A<@PA]Ed/4GCXa0f51=`AQACd4J4a216e9
A@AlG5<4NfIL0f=:@@ASBT04JDe316E9?`ATD3l4I4e210P820<g:2<4Ph:817AcMBMdLgHEoooo000D
oooo<WAcMPAdE484NE]?16=7?`ANAch4MF]R0hQDC`AdIfD4M6]V37AWHPAdHE@3M69@16UB@PA/CD84
N6i[17A[IPAdHE`3M75W17UXIPA/CTh4KEE;16A<@PA]Ed/4GCXa0f51=`AQACd4J4a216e9A@AlG5<4
NfIL0f=:@@ASBT04JDe316E9?`ATD3l4I4e210P820<g:2<4Ph:817AcMBMdLgHEoooo000Doooo<WAc
MPAdED<4JeaC14`Z7@AdJel4PemT0gUXGPAdL6H4M6]V17A`LPAdJ6<4M6MR17APF`=dIE/4I4m616aE
A`AdLVD4Lf=M17APD`=dK6H4M6AO16aFB@AOA3T4HdLn161=@`APAcd3JDlh1652=`AXBd44MUQC17YW
G0A]F4h3I5E;16QEBPQPCD<4I55616eKD`AM?RT3EbXO12/P7@AZKW4WM7=f5Oooo`005?oooc9dLgH4
M5E316]LD`A<:Qd4M6]O18=OI0=iJ5h4M71V17A[IPAdL784M6QS17AWHPAdH5/3M6EK16A?APA/EDL4
M79U17=SG@AdH5<3M6aV17ATG`A/ETT4Gd@i16=7?PAPCD<4H4Lm0fU?>0AQ@SL4J4]117IHD`AjIe`4
KEQ>0fAEB`AXEDX8H4e316AAAPA]Fe<4GChY0eLZ7`@[81d4JVia9gAcMQGoool001CooolbM7=f17AE
@`A[G5<4C2XM17A[G`B3Gf@3NFQN17A`IPAdJfH4M71b17AXH`AdIf84M61K0gAUF`ATCdH4K5E717Ab
I@AcHed4M61C0gA/IPAdI5l4K5I915m4>@ASAch4H4e31617?@=YCcP4HD8g16Q;@@AfF5<4NVML16eH
CP=TED/4J5E:261=@`ATDDH4KE]C15dn:@=G:Ql4:b0M16Y^LBMdLgHEoooo000Doooo;WAcMPAdDdP4
HbdQ158J6PAG=S04IgEc17MXGP=dL5h4M6AR17A[IPAdIf44M6=K17AWHPAdH5/3Jea@16aFC@AeKF84
OWA/17UXG@A[CDT3Lf9I17A:C0ASASH4GcXc1615?0AH?cH4I4D`0ddf;@AK?3L4LEiA17IOD`AdGe84
J5580fA>A0AXAch4JDY016E=?@A]AS`4KEY?1651>@=bDT/4`mcU1=3Gg2MdLgHEoooo000Doooo;WAc
MPAdDdP4HbdQ158J6PAG=S04IgEc17MXGP=dL5h4M6AR17A[IPAdIf44M6=K17AWHPAdH5/3Jea@16aF
C@AeKF84OWA/17UXG@A[CDT3Lf9I17A:C0ASASH4GcXc1615?0AH?cH4I4D`0ddf;@AK?3L4LEiA17IO
D`AdGe84J5580fA>A0AXAch4JDY016E=?@A]AS`4KEY?1651>@=bDT/4`mcU1=3Gg2MdLgHEoooo000D
oooo;WAcMPAdDdP4HbdQ158J6PAG=S04IgEc17MXGP=dL5h4M6AR17A[IPAdIf44M6=K17AWHPAdH5/3
Jea@16aFC@AeKF84OWA/17UXG@A[CDT3Lf9I17A:C0ASASH4GcXc1615?0AH?cH4I4D`0ddf;@AK?3L4
LEiA17IOD`AdGe84J5580fA>A0AXAch4JDY016E=?@A]AS`4KEY?1651>@=bDT/4`mcU1=3Gg2MdLgHE
oooo000Doooo;WAcMPAdDdP4HbdQ158J6PAG=S04IgEc17MXGP=dL5h4M6AR17A[IPAdIf44M6=K17AW
HPAdH5/3Jea@16aFC@AeKF84OWA/17UXG@A[CDT3Lf9I17A:C0ASASH4GcXc1615?0AH?cH4I4D`0ddf
;@AK?3L4LEiA17IOD`AdGe84J5580fA>A0AXAch4JDY016E=?@A]AS`4KEY?1651>@=bDT/4`mcU1=3G
g2MdLgHEoooo000Doooo;WAcMPAd@3d4I2l/15`^;0ATGdl4OgMY18Q[IP=dK6/4M6AS17A[IPQdIf84
M61K17APD`=/GE04NEU@175TF@AhIfH4M6a[17AUI0=iL6X4M5I=16AB@PAL@C/4F48h15Dl<`AH?SD3
GD<m17]RE@AkIUT4LUmE17ALDPAXDDP3I4i416Q:@@AXAT<4JDE316A6?`AXGUX4FCDX0fA8?PB@[K/[
M7=f5Oooo`005?ooobidLgH4M40m16@_;0AL;R`4I5m?17mgJ@B8JfH3M6a[17ATH`AdJfH8M6MR17AP
F`AdH5<3K5e@17UID0AaI5T4N6MV17A/J`AdIF@3NG1Z17AFC@ATDT84G44k15Q2>0AE?3<4F3he0ee3
?@AkHUD4NfII179OE@AdG584J5580fA>A0AXBT44J4I316U5@`ATASl4J5iJ15Te:0=TB3h4T:fk:gAc
MQGoool001Coool^M7=f17A0?@AT;b`4G2h/16AOC`AoMfT4R6]V0gA/J`AdI6<4M6]V27AWHPAdH5/4
M61C0faMD0AiFE04LFAI17QWIPAdK6/4M6ET0gU`JPAdETd4I59215a1>`AH@SP4EC`c15Pn=@=M@cd4
Nf9E17]VF@AbGeD4M5aB16QAB0=TCT@4J4Y116Q6@`AYAD<4I4Ho16QNFPAI=BP3I4Pn192]^b]dLgHE
oooo000Doooo;WAcMPAd@3d4I2l/15`^;0ATGdl4OgMY18Q[IP=dK6/4M6AS17A[IPQdIf84M61K17AP
D`=/GE04NEU@175TF@AhIfH4M6a[17AUI0=iL6X4M5I=16AB@PAL@C/4F48h15Dl<`AH?SD3GD<m17]R
E@AkIUT4LUmE17ALDPAXDDP3I4i416Q:@@AXAT<4JDE316A6?`AXGUX4FCDX0fA8?PB@[K/[M7=f5Ooo
o`005?ooob]dLgH3M5Y?17A>?0ATASL4E40^16aTE0B7Nfh4NFQV0gA[IPAdJ684M6AN17AOFPA[F4`4
LemB17A=C`=/E4`4Ke5916]LDPAhIfD4M6=F17APFP=dI5h4M4i@16A1>@AL@3P4GD<i1656>`AMCdD3
K5M5175KC`AaF4d4ME]B16aAA`AXBT43I4i416Q3>PAXAS`4H4Tl161A?@A/GUX4JD4g0fUGCPARK7P4
KFa^9gAcMQGoool001Coool[M7=f0gAJC`AdCS`4I4Hg15A0;PA/I5@4Qg]^17UXIP=dJfH4M6QR17AT
GPAdGeX4JeQ<17=ODPAdCDl3K5A<16mAB@A[G584N6MU17ASEPAdH5X3M6AN17A>D0AT@CT4G40h15e3
>@AQAS/4GDm50faGA@AaFdl4LEQ=17EKDPA/DDL4J4Y10fA>A0AX@cX4J4Hl1619?0APDCd4K5iJ16U1
=`=YEdh4HVah16e/KRMdLgHEoooo000Doooo:gAcMP=dFTl4M4hl16A6=`AD@2h4K6AD18MkKPAiJ6H3
M6]V17AXHPAdI5h4M5mJ16]HC0AcGe84M4e?0faDC0A_DDT4JeaB17QWI@AdHeH4M61J0gATGPAdCU04
I44i15a0>0AM@cT4HDHk15e?A@=/EdD4LE]?175HC@AeFe84K55716Q:@@=TCT@4J4<j16Q6?0APBC`4
H54m16aNFPAY@CL3JEM>169/N0A]K6hWM7=f5Oooo`005?ooob]dLgH3M5Y?17A>?0ATASL4E40^16aT
E0B7Nfh4NFQV0gA[IPAdJ684M6AN17AOFPA[F4`4LemB17A=C`=/E4`4Ke5916]LDPAhIfD4M6=F17AP
FP=dI5h4M4i@16A1>@AL@3P4GD<i1656>`AMCdD3K5M5175KC`AaF4d4ME]B16aAA`AXBT43I4i416Q3
>PAXAS`4H4Tl161A?@A/GUX4JD4g0fUGCPARK7P4KFa^9gAcMQGoool001Coool[M7=f0f<i9PA:9Qh4
91TD13/]9PAhK6<4PWM[17ATHP=dHeh4M5mJ17APD`AdG4l4K5a?16m@C`ARCDD3JeQ?171TFPA`JEd4
N6]P17ATGPAdI683M6AN16]MD0ASC3d4G4Hm15e3>@AQAC/4JDa20fe@A@AfE5<4LUQ=16aDBPAXF4l4
K5E;0fAAA`AXDDL4H5561619?`ATBDD4K5YJ15PU60=XGE44ICT_18J:RRMdLgHEoooo000Doooo:gAc
MP=S>BH4BRHN12@I50@k;BH4N6aS189gJ`AdI683M6=N17AOFPAdH5<4M5a?16aLC`A_D4l4HTe50f]H
C`A`I5X4L6UM17Q[H0AdI5h4M6AR0gATGPA[GE04Hd`m15a6?@AM@cT4HDDk16U<@P=]D4D4MUAC179H
C@A/E4X4J5Q?16aEB`=TDDL4J557161AAPAPBCl4I4U516aJFPAH9AP3J5eA16Di;`B6RXXWM7=f5Ooo
o`005?ooob]dLgH3HcTV14XV7P@T6A@4>bdV17Q/H`B2Mf/4M6AR0gASGPAdGeX4M61C17ALC`A/G4l4
Ke1?169=A@=[F4l4L6AJ171YG@AhJf04M6AN17ATHP=dI5h4Jee@16=<?@ALASd4GD<i1655>`AYC483
KE1517IDD`AbF4d4K5A:16QHC`A/ED/3I55716QAA`APDDH4H4To16A9A@A/FUX4F2DH0fQMD@AU>Bl4
QXZ:9gAcMQGoool001Coool[M7=f0f<i9PA:9Qh491TD13/]9PAhK6<4PWM[17ATHP=dHeh4M5mJ17AP
D`AdG4l4K5a?16m@C`ARCDD3JeQ?171TFPA`JEd4N6]P17ATGPAdI683M6AN16]MD0ASC3d4G4Hm15e3
>@AQAC/4JDa20fe@A@AfE5<4LUQ=16aDBPAXF4l4K5E;0fAAA`AXDDL4H5561619?`ATBDD4K5YJ15PU
60=XGE44ICT_18J:RRMdLgHEoooo000Doooo:gAcMP=K9AL45@h:12TO70@Y7Ad4PW5T17e_K0AdI687
M6AF17ATGPAdI6<4M6QW17UYI`AaFE@3K4Y715i9?@A_Edh4KemF17=SHPAdI5h3M6AF16a=B@AO?SH4
E3Lj15a2<`AI?cD4J4]10feGC0A/CD<4HU1316a=BPASASd4HTY00e]7?PAOBT04H4Y016A6?@ATBDD4
I512154f8P=OCch4Gc@b18J[^RMdLgHEoooo000Doooo:gAcMP=K9AL45@h:12TO70@Y7Ad4PW5T17e_
K0AdI687M6AF17ATGPAdI6<4M6QW17UYI`AaFE@3K4Y715i9?@A_Edh4KemF17=SHPAdI5h3M6AF16a=
B@AO?SH4E3Lj15a2<`AI?cD4J4]10feGC0A/CD<4HU1316a=BPASASd4HTY00e]7?PAOBT04H4Y016A6
?@ATBDD4I512154f8P=OCch4Gc@b18J[^RMdLgHEoooo000Doooo:gAcMP=K9AL45@h:12TO70@Y7Ad4
PW5T17e_K0AdI687M6AF17ATGPAdI6<4M6QW17UYI`AaFE@3K4Y715i9?@A_Edh4KemF17=SHPAdI5h3
M6AF16a=B@AO?SH4E3Lj15a2<`AI?cD4J4]10feGC0A/CD<4HU1316a=BPASASd4HTY00e]7?PAOBT04
H4Y016A6?@ATBDD4I512154f8P=OCch4Gc@b18J[^RMdLgHEoooo000Doooo9gAcMPAdHed3I3H]14P`
:0@g9Ah4;b0O1:V6L@AmKf<4Jea?0g=SGPAdI5X4FTHn15Q5>PA3;BD4@R`T148]:P==<C84HTTm16M9
?`AVDTX4N6MU17ATGP=dI5l4K4i=15m5>@AI@344HD8]15U5?@ATB3d3E4Pn14m2>PAOC484IeQ=15];
?PAXE4T3JE5716E=@`ATCD<4I4Hm16A9A@ATD4<4>R0I0chK5PAN=bX4QZ^d9gAcMQGoool001CooolW
M7=f17ASG@=T=Rd4B30X13LU7P@_81l4ZHIa17e_H`A[G4l3Lf=N17ATFPAJASh4F4Dj14<]9@A2;2@4
@RdZ0dda<PARBCd4IdTo16IBBPAhIfD4M6AN0gATG`A/CTd4GdDi15U0<@AQ@Rd4FDDm16A8?@=DB3h4
Cd8j15m<@PAWF4d4Fd/n16QDB@=YDDL4IDe316A=@`ATASd4I4U516A@@`@j81T3?Q/F15hg:PB6Zk@W
M7=f5Oooo`005?ooobMdLgH4M6=M0f@f;@A8<2P4=bDN12lP7`BYQW44OFmS16]LC`=cHeh4M6AJ15Y6
?PAHACX4@bdU148/90A2;BX3CC4b1699?@AWBCl4IU9:17QWI@AdI5h3M6AO16a>C@AOACT4FD0a1652
;@AIACd4I4Pm0eA8?PA?@SX4Gda216MHC@AKBch4J5A90fUAA`AUCD<4I4e316A6?@ATBDD4I51313XP
6@<n6aH4GSLZ18J[]2MdLgHEoooo000Doooo9gAcMPAdHed3I3H]14P`:0@g9Ah4;b0O1:V6L@AmKf<4
Jea?0g=SGPAdI5X4FTHn15Q5>PA3;BD4@R`T148]:P==<C84HTTm16M9?`AVDTX4N6MU17ATGP=dI5l4
K4i=15m5>@AI@344HD8]15U5?@ATB3d3E4Pn14m2>PAOC484IeQ=15];?PAXE4T3JE5716E=@`ATCD<4
I4Hm16A9A@ATD4<4>R0I0chK5PAN=bX4QZ^d9gAcMQGoool001CooolWM7=f16]6=P=S>S<410@310/<
30@O6AL4/I1i17AXG0AdG5<3NFMM17ATEPA]ETd4DT0h13`_9`@Q8b@451DG0b@I4@A5<bH4>QXD13TI
4`A`Fe44Lf=M0gATGPA/ETT4GdDi15U0<@AIC3L4D3`c16aCB0=bFdl4MeQ=17IAAPATAD84DClh16]C
B@=XDDL4H4Y115E6?@ADASd4He5516AA@`A19Ah3EBTO17@n<@B;[/4WM7=f5Oooo`005?ooobMdLgH4
JdHf0f<j<`@410<42``<11lI5`BaT7T4M6QL17ALD`=iIed4M6AF16eFC@AB@3P4?2lW124S90@D5AL3
91TA14Dc9P@j6Q@4>ATC171KD@AcHed3M6AN16aFB@AOACT4FD0a15U<=`A@?3<4K5=80g9KC`AgF4d4
MU5616A5@PAA?cP4Je=90fQAA`APBT44EDHm15A6?@ASDDD4I553144U7P=E:Al4M3ha18^^`BMdLgHE
oooo000Doooo9gAcMPA[ASH3HcXc10@40`@;30`47aTG1;6@N@AdJ5`4M5aC0gUWG@AdI5H4KEI=1590
>0@l;bL48B<T11@E5`<T6A44AC<V13XJ50@i6A<4L5]A17=SG@=dI5h4K5I915m5>@AI@344FD`g150l
<`A/DdP3LU]?17MHC@AfDDH4I4E2154o>0A[DdT3J557161:@@AEASd4E4Hm16=AA@ATDD<4@BDN0eDY
7`Ad?S44Rjk19gAcMQGoool001CooolWM7=f16]6=P=S>S<410@310/<30@O6AL4/I1i17AXG0AdG5<3
NFMM17ATEPA]ETd4DT0h13`_9`@Q8b@451DG0b@I4@A5<bH4>QXD13TI4`A`Fe44Lf=M0gATGPA/ETT4
GdDi15U0<@AIC3L4D3`c16aCB0=bFdl4MeQ=17IAAPATAD84DClh16]CB@=XDDL4H4Y115E6?@ADASd4
He5516AA@`A19Ah3EBTO17@n<@B;[/4WM7=f5Oooo`005?ooob=dLgH4OG]n17E8>0=O>S<46A@D120F
4P@_61D4aJ6817U/H@A`H5L3LfMM17ATFPAdIF<4HDU018aYI0@d:B@47a8@0bdI4P@d<C44DS@Z18A[
F`BGUhD4N7Aa0gAeMPA/GU44Gd8i14Xd;0A@>2`48PT715a0=P=C>2D4@C0X12dQ6PA>?SD4EDTl16a@
?`=OBT04H4Y015I0=PAMBCl4K4U515Do=P@^6aT3D38X17UBB`BEa=<WM7=f5Oooo`005?ooob=dLgH4
OG]n17E8>0=O>S<46A@D120F4P@_61D4aJ6817U/H@A`H5L3LfMM17ATFPAdIF<4HDU018aYI0@d:B@4
7a8@0bdI4P@d<C44DS@Z18A[F`BGUhD4N7Aa0gAeMPA/GU44Gd8i14Xd;0A@>2`48PT715a0=P=C>2D4
@C0X12dQ6PA>?SD4EDTl16a@?`=OBT04H4Y015I0=PAMBCl4K4U515Do=P@^6aT3D38X17UBB`BEa=<W
M7=f5Oooo`005?ooob=dLgH4OG]n17E8>0=O>S<46A@D120F4P@_61D4aJ6817U/H@A`H5L3LfMM17AT
FPAdIF<4HDU018aYI0@d:B@47a8@0bdI4P@d<C44DS@Z18A[F`BGUhD4N7Aa0gAeMPA/GU44Gd8i14Xd
;0A@>2`48PT715a0=P=C>2D4@C0X12dQ6PA>?SD4EDTl16a@?`=OBT04H4Y015I0=PAMBCl4K4U515Do
=P@^6aT3D38X17UBB`BEa=<WM7=f5Oooo`005?ooob=dLgH4OG]n17E8>0=O>S<46A@D120F4P@_61D4
aJ6817U/H@A`H5L3LfMM17ATFPAdIF<4HDU018aYI0@d:B@47a8@0bdI4P@d<C44DS@Z18A[F`BGUhD4
N7Aa0gAeMPA/GU44Gd8i14Xd;0A@>2`48PT715a0=P=C>2D4@C0X12dQ6PA>?SD4EDTl16a@?`=OBT04
H4Y015I0=PAMBCl4K4U515Do=P@^6aT3D38X17UBB`BEa=<WM7=f5Oooo`005?ooo`AdJVd4M7=e17A[
K@AdLgDCM7=f10@000AD91T3Hdi512TO6`@H5A/47a@@1;nTR`A_H5H4M6AJ0g1PEPA[G5<4Lf=R16eN
D@AbFDh4G4Lj19Q[F@>BFcl4QeHm19IWC0B9J5X4NVYN17Q_K@=dIf44K4i015ln=`AJ>R`4FChc14d^
9PANFEH38BDW10441@@Y6aT4<c4/11@B3`@d:2H3=RLM15Xh:PAEAC`4GDa216a9?`A0=b/47aLC0cHU
7PAoHE@4T;K116m_LB=dLgHEoooo000Doooo17AZK@AdLgD4M6]]17AcMA=dLgH4100015@T6@=SCTD4
:AlK11PE6`@O5104_jB;16mPEPAdI5X3L61F16]LD`AcHf84KEiA179ICPALAcX4V6]I0i9K?`B7ESd4
UVM<18UXFPAjJUh4N6m]0gAWH@A/CT04Gchg15Xj;0AI?S<4CBhV15iIEP<Q9BL40@@512TK6@@c<B`4
518?13@X9P<f9ad4FSPZ15E5?0AMC484K4To140g:`@O5a<3=RDN17mQE0B@]/44Kfma8gAcMQGoool0
01Coool4M6Y]17AcM@AdJfd4M7=e4gAcMP@40004E2@I0f=>A@@Y7a/461DK11lD40BoY8/4Kf1F17AT
FP=`H5H4JeaC17=SHPA]GU44LUU>15a7>PBHJeT3TU/o18MF?@BFId`4RFQJ17YZGPAhKfd3M6MQ16a>
@0AO?SL4FSX/15Tn<`A=;RH4GUUF0b4U9`@110D4:A/I13<a;0@D4Pl4=2PV0cHW7@AJ>2X4EDDl15e<
@PA/BCl4@3L[11lG4`<f9Ah4Of5D192f`@A_Kg4SM7=f5Oooo`005?ooo`AdJVd4M7=e17A[K@AdLgDC
M7=f10@000AD91T3Hdi512TO6`@H5A/47a@@1;nTR`A_H5H4M6AJ0g1PEPA[G5<4Lf=R16eND@AbFDh4
G4Lj19Q[F@>BFcl4QeHm19IWC0B9J5X4NVYN17Q_K@=dIf44K4i015ln=`AJ>R`4FChc14d^9PANFEH3
8BDW10441@@Y6aT4<c4/11@B3`@d:2H3=RLM15Xh:PAEAC`4GDa216a9?`A0=b/47aLC0cHU7PAoHE@4
T;K116m_LB=dLgHEoooo000Doooo17A_LPAdMgX4M7=f17AhNPmdLgH41P4110@10@@N1`@35a@C10<6
30@?3`d4:QPC1<nYS`A`H5H4N6MV0eXd=0AM@CX4MfIT17A/I`AjJVP4MeiK16i>A0=_ED/4OE]B18EY
F0AoHe/4MFQL17QcL0=dIf84K4]715m>A@AI@C84FTli16]6=0AmI5D3LTHf110<3@@m81H4<2HT124I
60AM>bd3J4<e17iPCPAQB3l4GDTo16aA?`@J5AH471DA0cDN5`B1?2h4P9^Z16m^LB=dLgHEoooo000D
oooo17A_LPAdMgX4M7=f17AhNPmdLgH41P4110@10@@N1`@35a@C10<630@?3`d4:QPC1<nYS`A`H5H4
N6MV0eXd=0AM@CX4MfIT17A/I`AjJVP4MeiK16i>A0=_ED/4OE]B18EYF0AoHe/4MFQL17QcL0=dIf84
K4]715m>A@AI@C84FTli16]6=0AmI5D3LTHf110<3@@m81H4<2HT124I60AM>bd3J4<e17iPCPAQB3l4
GDTo16aA?`@J5AH471DA0cDN5`B1?2h4P9^Z16m^LB=dLgHEoooo000Doooo17A_LPAdMgX4M7=f17Ah
NPmdLgH41P4110@10@@N1`@35a@C10<630@?3`d4:QPC1<nYS`A`H5H4N6MV0eXd=0AM@CX4MfIT17A/
I`AjJVP4MeiK16i>A0=_ED/4OE]B18EYF0AoHe/4MFQL17QcL0=dIf84K4]715m>A@AI@C84FTli16]6
=0AmI5D3LTHf110<3@@m81H4<2HT124I60AM>bd3J4<e17iPCPAQB3l4GDTo16aA?`@J5AH471DA0cDN
5`B1?2h4P9^Z16m^LB=dLgHEoooo000Doooo17A_LPAdMgX4M7=f17AhNPmdLgH41P4110@10@@N1`@3
5a@C10<630@?3`d4:QPC1<nYS`A`H5H4N6MV0eXd=0AM@CX4MfIT17A/I`AjJVP4MeiK16i>A0=_ED/4
OE]B18EYF0AoHe/4MFQL17QcL0=dIf84K4]715m>A@AI@C84FTli16]6=0AmI5D3LTHf110<3@@m81H4
<2HT124I60AM>bd3J4<e17iPCPAQB3l4GDTo16aA?`@J5AH471DA0cDN5`B1?2h4P9^Z16m^LB=dLgHE
oooo000Doooo27AhNQMdLgH42P<2134R6@@]61@39b0L10X92P@Y61<4<QPE1<FKPPAiH5H4L61F0gEV
H0AZHE84Ac0X144[8`@d9Ad48aXH11`E4P<V7AL4<R0J13PR6`AODD/4KfML17Q[J@=dGe84K4]015mA
A@AI>c<4HClb15e9=`AXETH3IDi317MLCPB^LEL4MDLf16i0;`BNHTh3QE]0165AAPATCCl4JUA815e9
?`@D4@l481DB0cXO60Ag;b84R[O59gAcMQGoool001Coool8M7Qj5gAcMP@:0`84<B8I12dH50<W81`4
2PT:12TH4`@b61D4aI^217UPEPA`H5H3MFIP16YQDPA7<2P4@B/S13@U7@@S6QP471DB0bHM5`@b81X4
>28K15mAB`A_Ie`4N6]Y0gAODPA/Bd04Ge5515Tk<`AQ?c84GDTg16QFAP=UCT<4Mea>1:iaE`AeAcH4
KT0_19iRCP>5Fd04HE5616A=?`AZE4P4GDTo11@A3`@P5A83>QlH17L_8PB:]lDWM7=f5Oooo`005?oo
o`QdN7XGM7=f10X30P@a8QT4;APD0bLP70@:2@X4:APC138H5@C5Vh84NF1F171PEP=eIV04JV5B14L`
:0A1:b<4=2DM12<J60@L5A839QdG138P6P@h8Q/4Ge5;16mWG0AhJfT3M5mB16a;@0AODDD4FC/c164o
<PAMBCL4J5I60fE>@`AgG4h4[W5G17E7=PA^@2l4WV9>0hEK@0AQDDH4I4do16YDB0AMBCl4514?120E
4P<j7aP4MblR18ZgaBMdLgHEoooo000Doooo7gAcMP@>10846`l;11@A3`<J4a047A8?11dE4@@b9b@4
ZXQ`17MSF@AdJ5h3NFQV17EUH0AnL6@4M5A?14Po@`AgD4`4MT`m0geKBPA^BC`4RFAF19R?O`B3M744
NFQV0gA=D0A/EDd4Ge9815Te>@@e7QP4=1lI15Y6=@=SCCh4I4dl16e>@`A`ET<4K5Y=17YQC0=IC484
I4U;15e9?`ASCCl4@3@[10P92@@D4@l3U5m:16/a8`BCaM<WM7=f5Oooo`005?oooamdLgH43P@211/?
2`@D4@l36Q<@11dB3`@M5A44<RLT1:Z8L0AgHeT4M6QN0gUXIPAeIF04OW1T17ADC`A8?d<4Me1<17I<
?@=mFdX4KTTl18UTEPBHSgl4PgAa17UXIP=dCE04K5E=15mBB0AI=CT4=AhH13@O6@AJASD3Hddn16A=
?0A]CT<4L5I316aJC@AjHD`3FDa216A9B`AMBCl4Hddo140d:`@82@T4514?0iAOBPA[<B<4TlGC9gAc
MQGoool001CooolOM7=f10h40P@K3`/4514?0aXC40@M4Pl47ADA138W90BZR704Mf=I17AXGP=iJ6H4
MFEP17i`I0AdE4l4B3m317M@C0AfC3d3OE]:16i9?0B9I5H4V8mo18=dL@AiJ6H3M4e@16aEC@AODTP4
FCDi13DN60@d7aT4FTHe0f==?PATCC`4KDi3171F@`A/FTd4NV5<0eU<@PATBD/4GDTo16==?`A0=2/4
20T911@A3`>DGdX4Jc4S19?5dbMdLgHEoooo000Doooo7gAcMP@>10846`l;11@A3`<J4a047A8?11dE
4@@b9b@4ZXQ`17MSF@AdJ5h3NFQV17EUH0AnL6@4M5A?14Po@`AgD4`4MT`m0geKBPA^BC`4RFAF19R?
O`B3M744NFQV0gA=D0A/EDd4Ge9815Te>@@e7QP4=1lI15Y6=@=SCCh4I4dl16e>@`A`ET<4K5Y=17YQ
C0=IC484I4U;15e9?`ASCCl4@3@[10P92@@D4@l3U5m:16/a8`BCaM<WM7=f5Oooo`005?ooo`QdLgH4
M6]]17AcM@mdLgH450P511l?2`@O5A436a@@10d720@O5104>2PT18QSD@AgHUL4LfMM0gATHPAdK6H4
M6aW17]cL@B=SXD4Y9F818b>Q@>FUY44UY:>19Z@P0AkM6P4N6m]16]MD0=[GDl4Jf5@16UEC0AcGU<4
KEY814D/;0@X7aX34a0@140[9PARC4@4H4dm16E=?`AMBCl3G3lh14dl<PASB484KDTo11XD4P@>2`/4
;2<O0gi1<0A071@47R8R16YZK2=dLgHEoooo000Doooo27AcMPAdJfd4M7=e3gAcMP@D20D47`l;11lE
4@<K51043@L811lD40@h:2@4R6=A17MRE`AcIed3M6AR17A/IPAdK6L4Ng=a18f>Q@BTUHP4S8j50iJF
T@BFTXh4VY2017]dJ0AhKfd4Jee@0f]MC`A[HE04JEE<17=ND`A]FTP4AB`/12PO6P<C4104@2/V169<
A0APCCd4IDdo15e9?`=L?cP4CC`b16=8@PA]BCl46Q@B10h;2`@/8al3OT4`140L50@N8R84JVY/8gAc
MQGoool001Coool8M7=f17A[K@AdLgD?M7=f11@81@@O3`/47aDA0a/D40@=1`P47a@@13PX90B8He44
Mf9G17=WG@=dI684M6aV17A/I`AkLg44SHj51:BER0B<SXD3UYJA19JBSPBJT804NgAX17Q_K@A[GE03
Jee?16]QD0AYED`4LeiC16eJB0A5;2`4:1lJ0a<@40A0:bH4HTa4161=?@AUCCl4GDTo0e`o>0A=?384
HdQ216e9?`@J51843P/;12`S7`=n@C04@1`D11hR8PAZJV`SM7=f5Oooo`005?ooo`QdLgH4M6]]17Ac
M@mdLgH450P511l?2`@O5A436a@@10d720@O5104>2PT18QSD@AgHUL4LfMM0gATHPAdK6H4M6aW17]c
L@B=SXD4Y9F818b>Q@>FUY44UY:>19Z@P0AkM6P4N6m]16]MD0=[GDl4Jf5@16UEC0AcGU<4KEY814D/
;0@X7aX34a0@140[9PARC4@4H4dm16E=?`AMBCl3G3lh14dl<PASB484KDTo11XD4P@>2`/4;2<O0gi1
<0A071@47R8R16YZK2=dLgHEoooo000Doooo37AcMPAdN7X?M7=f10d81`@P6AL47QDA0alD40@F40`4
91HB13HX90B9G4T4QViQ17Q[H0=dI684M6]V17AWHPAdL788M75c17AXH`=dL788M6QS17AUF`AiIed4
M61C0g5ID0A`DDT4LEaC17EQEPAfFUL4LUmK18iUF@=N@c/4>R@M11LE4@@S6AL4828Q12lS7@<f9Ad4
Id]717I?A0AL@SH43@`<11LA3`@T61T390d:12L@30@X:b/4`l[?8gAcMQGoool001Coool<M7=f17Ah
NPmdLgH43@P7120I5`@N5A437a@@11H@30@T5Q84=RPT18ULB@B6KV44N6]P0gATHPAdJfH4M6MR17A`
LPQdLG<4M6QS0gA`LPQdJ6<4M6EK17UWG@AdH5<3LEU@171AB@AaG5<4MF5F17IJE`AbGe/4SVEI0ei3
>`@j91d45aDA12<I5`@P8R44;b<M0cHU7@AWBdL4MTm415a2=P@=30`45a4?12@H6@<T3@X49a0<12P[
:`C3b/lSM7=f5Oooo`005?ooo`adLgH4M7Qj3gAcMP@=20L481TG11hE4@<O51045Q0<12@F4P@f:2@4
REa918I^H@AhJf03M6AR17A[IPAdIf84M71b27AaL`AdJ6<3M71b27AXH`AdIE/4NFMM17APD`=aFE04
L559175LD`AeHEH4MUYG179OF`B>IET3GT<k13XT7@@G5A448aTG120R8@@_8ad3=RDM16M;A`AfCd@4
G48f10d<30@G4@l491PI0b@=2P@W40`4:2/[1<?:cb=dLgHEoooo000Doooo37AcMPAdN7X?M7=f10d8
1`@P6AL47QDA0alD40@F40`491HB13HX90B9G4T4QViQ17Q[H0=dI684M6]V17AWHPAdL788M75c17AX
H`=dL788M6QS17AUF`AiIed4M61C0g5ID0A`DDT4LEaC17EQEPAfFUL4LUmK18iUF@=N@c/4>R@M11LE
4@@S6AL4828Q12lS7@<f9Ad4Id]717I?A0AL@SH43@`<11LA3`@T61T390d:12L@30@X:b/4`l[?8gAc
MQGoool001CooolOM7=f11@:2@@l:BD461<?1alD40@W6A/4=RPU16e>?0AbH5@4MfYP0gATFPAdHeh4
M6MR17AWH@AdJfT8M6aZ0gA`LPAdHe/4M6MR17AXH`AdI5/4M6AJ0faFC@A`GE<4L5Q?171LDPA`EE<4
JEU<16UFB0=XDdD4Me];17QJB0A[ACD4FCd_17i=?P=dG4l4NTa>15A8?@A5?C<43`d=11dC40@I5103
50l;12DI5P@c<S04_/G;8gAcMQGoool001CooolOM7=f11@:2@@l:BD461<?1alD40@W6A/4=RPU16e>
?0AbH5@4MfYP0gATFPAdHeh4M6MR17AWH@AdJfT8M6aZ0gA`LPAdHe/4M6MR17AXH`AdI5/4M6AJ0faF
C@A`GE<4L5Q?171LDPA`EE<4JEU<16UFB0=XDdD4Me];17QJB0A[ACD4FCd_17i=?P=dG4l4NTa>15A8
?@A5?C<43`d=11dC40@I510350l;12DI5P@c<S04_/G;8gAcMQGoool001CooolOM7=f11@:2@@l:BD4
61<?1alD40@W6A/4=RPU16e>?0AbH5@4MfYP0gATFPAdHeh4M6MR17AWH@AdJfT8M6aZ0gA`LPAdHe/4
M6MR17AXH`AdI5/4M6AJ0faFC@A`GE<4L5Q?171LDPA`EE<4JEU<16UFB0=XDdD4Me];17QJB0A[ACD4
FCd_17i=?P=dG4l4NTa>15A8?@A5?C<43`d=11dC40@I510350l;12DI5P@c<S04_/G;8gAcMQGoool0
01CooolOM7=f11@:2@@l:BD461<?1alD40@W6A/4=RPU16e>?0AbH5@4MfYP0gATFPAdHeh4M6MR17AW
H@AdJfT8M6aZ0gA`LPAdHe/4M6MR17AXH`AdI5/4M6AJ0faFC@A`GE<4L5Q?171LDPA`EE<4JEU<16UF
B0=XDdD4Me];17QJB0A[ACD4FCd_17i=?P=dG4l4NTa>15A8?@A5?C<43`d=11dC40@I510350l;12DI
5P@c<S04_/G;8gAcMQGoool001CooolOM7=f11@81@@Z7AD48APE0b4D40@T40`4:QPE13@R60A6<bT4
MEM;17QZG`=cHeX4M6AR17A[IPAdL784M6MR17A[J@MdK6X4M6=K17AWHPAdH5<4M61K17ALD`=/CDH4
L5aB171MD`A`F4l4L5A;16QAA0A]BT43JDi416I>@`AhFDd4NEU=189RE@B0FDd3KTm;16e:?`AQB3P4
=28J11<>3@@M4a04:QPE0a/D40@Q5A44<B4H17i/K`A`Kg8OM7=f5Oooo`005?oooamdLgH450P512XM
5@@Q61D38A@@12@@30@Z61D4=28H14Hc:@AeEd/4N6YO0g=SFPAdI684M6]V17A`LPAdIf84M6]Y1gA/
JPAdHe/4M6MR17APD`AdH5/4M5aC0fa=APA`G584L5eC171HC`A`E4/4J55416e:@@=YCT@4ITi317QI
C@AiFDd4PV9E181IC@=^Cd/4KDXo1658>0@d8QX44`h=11dC40@Z61D36a@@124E4@@a8AP4OVa_171_
LQmdLgHEoooo000Doooo7gAcMP@D20D4:QdE124H5@<Q5104910<12XH5@@d8QP4AS<Y17EGB`AhJUl3
Lf=J17ATHPAdJfH4M71b17AWHPAdJfT7M6aZ17ASF`AdIf84M61C17APF`AdG5<3K4e6171LDPA`GE<4
L5Q?171DB`AXDD@4KDY10fU>A0AVCT<4N5U=17UIC@B2HUD4P5U=0fi?B`A]BSl4HDPh13@R6P@C3Pd4
7A<@12XH5@<K51048ADA134Q60AnK6l4L6mb7gAcMQGoool001CooolOM7=f10d610@`:2L48aXH0bLG
4`@E40`47A@A11`C40@i91`4EcPV17YXG0=hIed4M6AR17A[IPAdL744M6aZ17AWHPAdJfT7M6=K17AW
HPAdH5<4M6AJ16]EB@=[FE04L5Q?171DB`A`E4`4L5Q?16QAB0ASCT@3He5716UHCPATCD<4J4Y016E=
@`AEASd3E4To15A9?@@o=bd441<C10/;2@@Q5aT45A0@0a<?2`@=1`P4:1PE16A?C0B=V9TOM7=f5Ooo
o`005?oooamdLgH43@H4130X9`@S6QP39aLC11D@30@M514471<@13TT70AG>2H4NVQL0gQWG@AdI684
M6]V17A`L@AdK6X4M6MR17A[J@MdHe/4M6MR17APD`AdI5X4JeE90f]ID0A`F4l4L5A;171DC0A`F4l4
J55816=>A0=SDDL4JEQ>16A=@`AXBT04IDe315E6?@=DBCl4E4Tm13lg;@@@4a<42`/9124G6@@E4103
4`l;10d720@X61D4I4m<18fHVAmdLgHEoooo000Doooo7gAcMP@=1P@4<2PW12<J60<W5a<45A0<11dD
4@@L4a04>B@L15Lh9PAjJ5`3N6MM17ATHPAdJfH4M71a17A/JPAdIf84M6]Y1gASF`AdIf84M61C17AT
FPA[EDT3JeU@171HC`A`E4/4L5A<171HC`AXDDP4Hdi40f=AA`AYF4h4I4e316Q:@0AUCD<4EDHm0eA9
?`ADBCd4?cL]110C4`@;2`T48ALI11D@40<C3`/43@L812PH5@ATCd`4SIRI7gAcMQGoool001CooolO
M7=f10d610@`:2L48aXH0bLG4`@E40`47A@A11`C40@i91`4EcPV17YXG0=hIed4M6AR17A[IPAdL744
M6aZ17AWHPAdJfT7M6=K17AWHPAdH5<4M6AJ16]EB@=[FE04L5Q?171DB`A`E4`4L5Q?16QAB0ASCT@3
He5716UHCPATCD<4J4Y016E=@`AEASd3E4To15A9?@@o=bd441<C10/;2@@Q5aT45A0@0a<?2`@=1`P4
:1PE16A?C0B=V9TOM7=f5Oooo`005?oooamdLgH450P512lT8P@]8Ql39a`H12LH50@R5A44:QdJ13`^
:`A1=2`4PVEJ0gMRF0AdHf84M6=N17AWH@AdJfT4M6aZ17A`LP=dHe/8M6MR17APF`A[G5<4JeE<1g1D
C0A`F4l4J5Q?16MAA`AXDDL4I4i40fQAA`AXD4H4JDi416A=@`APCD<4ETHm0fe9?`AN@SP4;R8N11D>
3P@V6QL44``<11@?3`<>20P45a0A12@F4PAJCDP4X:ne7gAcMQGoool001CooolOM7=f11@81@@_9284
;B8O0bLL60@W61@48QDA12XM6P@l;R/4@C@/189UFP=gHUP4M6=R17ASGPAdIf44M6]Y17A/JPAdL783
M6=K27AWHPAdH5/4JeaC16]EC0M`E4`4L5Q?16QHC`AWDDL4J55716A>A0=XDDL4J51616U>A0ATCD<4
H4e315I6?@=]BCl4GT8h12hR7P@E3Ph49QXG11<<30@D3`l33PP811L@4@@T5Q84FTe81:2_]AmdLgHE
oooo000Doooo7gAcMP@D20D4;b@R12dR7`<W71P49aPD128E4@@Z7AX4?2h[144d;0B2IEX3Mf9H17AS
HPAdHeh4M6MQ17A[J@AdK6X4M71b0gASF`QdIf84M61K16]LD`A[ED`7L5A<171HC`AXF4l4Ie5716QA
A`ATCT@3J55716Q@APAYCT@4I4e3161=@`AFASd3KDTo15i2>0@^8Qh45@h>12HJ5`@C30`450l?0`h8
20@G414491HB15Y=B0BP[kDOM7=f5Oooo`005?oooamdLgH450P512lT8P@]8Ql39a`H12LH50@R5A44
:QdJ13`^:`A1=2`4PVEJ0gMRF0AdHf84M6=N17AWH@AdJfT4M6aZ17A`LP=dHe/8M6MR17APF`A[G5<4
JeE<1g1DC0A`F4l4J5Q?16MAA`AXDDL4I4i40fQAA`AXD4H4JDi416A=@`APCD<4ETHm0fe9?`AN@SP4
;R8N11D>3P@V6QL44``<11@?3`<>20P45a0A12@F4PAJCDP4X:ne7gAcMQGoool001CooolOM7=f110:
2@@`:2L4=BPU0blS80@W5a@44`l;12TH5@@o9A`4G3PY18==>0=hIEX4LfMM17ATGPAdHeh4M6MQ17A[
J@MdK6X4M6QS17AWHPAdH5/4M6AG175ID0=XED`4Ie5716mACPAXDDL4K4Y116a=BPATCT@3J55716Q:
@0QPBT04G3lf16E5?0=M?3<4<R/X11hF4`@K4Q044`l;11<>3`@C30`35a0<11TA4P@]6AD4hNK[1;:k
`AmdLgHEoooo000Doooo7gAcMP@@2PT4<2PW13DX9@<_8b049aLD11<?2`@Y61D4?bDL15`h:@B3CCP3
N6EJ17=WG@AdI5h4M6=N17AWH@AdJfT7M6aZ17AXH`AdIf84M61K17ATE`AaFE03J5E<16MAA`A_DDh4
J55716a:@@A/CDX4I4i40fQAA`AXBT08H4Y015`o=PAUAC`3GC`c138[:0@N5Q<46a8@11<?2`@C3Pl4
4``<0aL@30@I4A84;ATE1>7Vj`Bb^l4OM7=f5Oooo`005?oooamdLgH440X9130X9`@e:2D3;b<P12LG
50@C3`/4:APE13lU70AL>2T4Pddh0gQUFPAcIed4M6AN17ASGPAdIf44M6]Y1gA/JPAdJ6<4M6MR17AP
F`AdI5L4LEU@0fQEC0AWDDL4Ke5>16QAA`A/BT44K4e:16A>A0=XDDL4J4Y0261:@0AL?cH4IDDl0edl
<`@b:bP47QHC11/B40@C3`/44`h?11<<30<G40`46A4B12dI5@CQi^/4/[_17gAcMQGoool001CooolO
M7=f110:2@@`:2L4=BPU0blS80@W5a@44`l;12TH5@@o9A`4G3PY18==>0=hIEX4LfMM17ATGPAdHeh4
M6MQ17A[J@MdK6X4M6QS17AWHPAdH5/4M6AG175ID0=XED`4Ie5716mACPAXDDL4K4Y116a=BPATCT@3
J55716Q:@0QPBT04G3lf16E5?0=M?3<4<R/X11hF4`@K4Q044`l;11<>3`@C30`35a0<11TA4P@]6AD4
hNK[1;:k`AmdLgHEoooo000Doooo5gAcMPAdJfd4Jf=U10d71`@/8Ql4<RLT0bdR7`@J4@h49a`I12dO
6`@[8Qh4EcX/16m;?`=hK6<4N6]P17ATHPQdK6H4M71a1gA/JPAdHe/4M6MR16]IC0AcG4l4K4e60g5D
C0AeFDl4K5E:16QDA`A/CT@4HeQ=16=AA0=P@d04GdY0161=@`ATCD<4IDHm15U<@P=6=bh4@C0V124H
4`@P5A<461<@11`E4@@L5A03614<11`E4@@]6AD4g>O/8gAcMQGoool001CooolGM7=f17A[K@A[HfD4
3@L712`R7`@b9b@3;B8O11XA3P@W71T4;AlK12/R7PAG>R`4Kd/o0gQ/H`AhJf04M6AR27A/IPAdL747
M6aZ17ASF`AdIf84JeU<17=LC`A/CDH3LEA<17EIC`A/EDX4J5A716a>A0ASF4d4He540f13@0AOBT04
H4e316A=@`AUASd4FDa20dHg;PA1<2H48APC120E4`@H4a0471DA11`E40<H4@`471DA12dI5@CLin`S
M7=f5Oooo`005?oooaMdLgH4M6]]16]SI@@=1`L4;28O138W90<]8Ql46Q4>12LL6@@]7a/4:b8N15Lj
;0A_Bcl3N6aS17Q[H0AdI688M6aV17A`L@MdK6X4M6=K17AWHPA[FD`4Lea?16a=AP=aE4`4MEU?16aE
BPAXE4L4K4i416=HC@ASDD@3H4=015m:@0APCD<4I4e316E6?@AIC483ASL^144`9P@Q61<481DC11PC
40@L5A4471D@0aPA30@L5A44;ATE1=cWk2=dLgHEoooo000Doooo5gAcMPAdJfd4Jf=U10d71`@/8Ql4
<RLT0bdR7`@J4@h49a`I12dO6`@[8Qh4EcX/16m;?`=hK6<4N6]P17ATHPQdK6H4M71a1gA/JPAdHe/4
M6MR16]IC0AcG4l4K4e60g5DC0AeFDl4K5E:16QDA`A/CT@4HeQ=16=AA0=P@d04GdY0161=@`ATCD<4
IDHm15U<@P=6=bh4@C0V124H4`@P5A<461<@11`E4@@L5A03614<11`E4@@]6AD4g>O/8gAcMQGoool0
01CooolKM7=f17AhN`@<20L4>R<J12lS80<b9b@4<2@P12XN6P@/8Ad4<b4H1552>0A>>2d3LUA917=V
F`AcHf84M6=N17AWHPAdIf47M69J17AKD`A[F4`4Je5516mPEPA[DDT3J55116MAA`AXDD44K5A:16aE
B`ATDDL4J4i40fU;@@AUDD<4I4Hm16A5?0AEASd4AS`c0d0[8`@S6AX45Q0@11DA3`@C3`/45Pl@114;
30<91`P44P/<14HX9@CBg>44Kfia7gAcMQGoool001CooolKM7=f17AhN`@<20L4>R<J12lS80<b9b@4
<2@P12XN6P@/8Ad4<b4H1552>0A>>2d3LUA917=VF`AcHf84M6=N17AWHPAdIf47M69J17AKD`A[F4`4
Je5516mPEPA[DDT3J55116MAA`AXDD44K5A:16aEB`ATDDL4J4i40fU;@@AUDD<4I4Hm16A5?0AEASd4
AS`c0d0[8`@S6AX45Q0@11DA3`@C3`/45Pl@114;30<91`P44P/<14HX9@CBg>44Kfia7gAcMQGoool0
01CooolKM7=f17AhN`@<20L4>R<J12lS80<b9b@4<2@P12XN6P@/8Ad4<b4H1552>0A>>2d3LUA917=V
F`AcHf84M6=N17AWHPAdIf47M69J17AKD`A[F4`4Je5516mPEPA[DDT3J55116MAA`AXDD44K5A:16aE
B`ATDDL4J4i40fU;@@AUDD<4I4Hm16A5?0AEASd4AS`c0d0[8`@S6AX45Q0@11DA3`@C3`/45Pl@114;
30<91`P44P/<14HX9@CBg>44Kfia7gAcMQGoool001CooolOM7=f11@:2@@a7aL4<2PV0c@X9@@W7AX4
8aDB138Q60@a9244@3D]13XP6`=YAc`4N75U17QWG@AdI5H4M6=N2gAODPAdH5X4M6AG175ID0A`E4/4
J4<k0fQ:@@A/CDd4K5A;16aDC@A/Ach4I4e41fQ:@0APCD<4I4Hm15a2>0A6?384@2/S0b<H60@N61<4
5a4>11LC40@Q51045a0A1a<<30@c6aH4oooo1<OHgB=dLgHEoooo000Doooo7gAcMP@D2PT4<AlG130X
9P<d:2D49adJ12<E4P@b8AP4<B@Q140e;@@j81/3JDLl17QaI@AhIed4M6AF17ASGP]dGe84M61J17AT
E`AaFE04L5A;16Q3>`=XBT44K4e=16aDB`A/E4d4K4Ln16A=A0MXBT04H4e316A6?@AL@SP4AS`b140[
8`<S61P47QPC11LA3P@G4a048A@@11L@4@LC30`4<a/F1?ooo`C7f=dSM7=f5Oooo`005?oooamdLgH4
50X9134O5`@`:2H3=2PU12LM6P@S5A84<R4H134T8@A0=Bd4>R0K0fU7?0AhLFD4N6MM17ATEPAdHeh;
M5mB17APFPAdI5L4LEU@171DB`AX@c/3J4Y116a=C@A/E4/4K5A=16a7?PATCD@7J4Y0161=@`ATASd4
G48h14Hl<PA0:b<38aPH11hH4`@G4@h45a<@124D40@G41474``<13<K5PCoool4amSM8gAcMQGoool0
01CooolOM7=f11@:2@@a7aL4<2PV0c@X9@@W7AX48aDB138Q60@a9244@3D]13XP6`=YAc`4N75U17QW
G@AdI5H4M6=N2gAODPAdH5X4M6AG175ID0A`E4/4J4<k0fQ:@@A/CDd4K5A;16aDC@A/Ach4I4e41fQ:
@0APCD<4I4Hm15a2>0A6?384@2/S0b<H60@N61<45a4>11LC40@Q51045a0A1a<<30@c6aH4oooo1<OH
gB=dLgHEoooo000Doooo7gAcMP@Q5aD4;28P12hT8P<h9b@4;AdE12/P70@V71T4;R@R12PN6P@]8b83
Ecd_16UC@PA^GU@4JeaC17=SF@AdI5H4M6AJ0f]LD`A[G584Lf=F16a>APAXAch4J5510f=:@0ARD4H4
HU1416a=A0ASAch4Hde316Q3@0=PCD<4H4dm15a0=PAE@SP4@cT`12hL6@<N61<45a4>114>2`@E3a04
81@@11D@40@>20P34``<12hJ5PC?fml4Kfia8gAcMQGoool001CooolOM7=f124G5@@/8R04;R@R0cPW
90@]7AD4:b0L12HL6@@^9284:1hJ12dS8P=G?Bl4JE=216iNE0A[G5<4Lf=I17ATEPAdI5X3JeaC16]L
DPAcHeH4K4i616Q7?PAXDD43HdY0169@APARD4@4K4e416=7?PASCD<4J4=00f1=@`APCCd4G40f15E2
>0A3>C04;Q`I0ahH4`@G4@h44@h;11D?40@P51045A0@10h820<C30`4;QXF1<oKg`A_KW4SM7=f5Ooo
o`005?oooamdLgH48ALE12`R80@^9283>2LT12dM5@@[81`49Q`I12hT8P@X7QX4;B<R0eLm;`AYDd84
KUiD16]LD`AcHeT4M6AF17ATFP=[G5<4JeaB17=SEPA/CTH4J4Ln16QA@@=SBT04HU16169@A0A/CD@4
HdLn16==@`AX@d03H4e3161=?@AL@3H4ED8h14<i<0@^71T37QPC11LA3P@A3P/45@l@120D40@E4104
3PP80a<<30@^6QH4cm_O16m^LB=dLgHEoooo000Doooo7gAcMP@Q5aD4;28P12hT8P<h9b@4;AdE12/P
70@V71T4;R@R12PN6P@]8b83Ecd_16UC@PA^GU@4JeaC17=SF@AdI5H4M6AJ0f]LD`A[G584Lf=F16a>
APAXAch4J5510f=:@0ARD4H4HU1416a=A0ASAch4Hde316Q3@0=PCD<4H4dm15a0=PAE@SP4@cT`12hL
6@<N61<45a4>114>2`@E3a0481@@11D@40@>20P34``<12hJ5PC?fml4Kfia8gAcMQGoool001CooolO
M7=f120F4@@Z8Al4=BPU0bhS80@Z8Ql47QHH12DJ5`@/8A`4=2PU134O5`<f8AT4D40f161:@`AVB404
KeM>16]DC0A[Fe83JeaC171IC`A_F4l4Hde615i4>`ARBD03HdM016Q5?0AXBD04IdY016=:@0APASd4
GdHl0eQ2=PAD?cH4ACTc13/]90@h:1l471HA0a@@3P@E4@l45A0<118;30@B2`/42@L810X820<`6aH4
?B0F1=7Kh2MdLgHEoooo000Doooo7gAcMP@P5Q44:R4O13DX9@<^8b04:R8O11hF60@U6QL4;24L13@X
9@@a7aL3=R4I1510=PAPBT<4ITQ016mGCPA[E4`4Je]B0f]LD`A`FDl4KeQ?16==APANA3/4HTU00f=7
@0AXAC`4J4U016M:@0ASBT04H4Hm15m6?0=H@SH4E3lf14Di<`@k;B@4>2PO11`F4@<D40h45A4?11D@
30@B2``44P/;10T720@:20P3<1/F13dP5PCAfn0WM7=f5Oooo`005?oooamdLgH481HA12XQ7`@e:2D3
;R<P12XR7`@N5QP49AXG12`Q70@d:2D4<AlG0cHQ6@A@@3H4H4Y316I8@0A_Edh4JeA<16]KDP=[G5<4
L5U?16mHC`ASCDH4GT@k1699@0=SAd04J4Dl16Q9@0AWBT04HdY01616?@AOAS`3F48f15@o=PA5>C<4
>bdT13PX7`@L5Q43510>11DA3`@E40`44P/<118;2`@91`P42PP80c0K5P@m81H4dM_P9gAcMQGoool0
01CooolOM7=f120F4@@Z8Al4=BPU0bhS80@Z8Ql47QHH12DJ5`@/8A`4=2PU134O5`<f8AT4D40f161:
@`AVB404KeM>16]DC0A[Fe83JeaC171IC`A_F4l4Hde615i4>`ARBD03HdM016Q5?0AXBD04IdY016=:
@0APASd4GdHl0eQ2=PAD?cH4ACTc13/]90@h:1l471HA0a@@3P@E4@l45A0<118;30@B2`/42@L810X8
20<`6aH4?B0F1=7Kh2MdLgHEoooo000Doooo7gAcMPAAA4h4<R8Q138W90<]8Ql4>bhZ130O5P@X61<4
>B/X12XO70@b9b@38aXH13Tc:`@]9R84@B/U15m;@PAF?cP4GDa:0ee9B0AMBD44IU=;15M0>0@m;2D4
Ac<Z0eHh:PAOAC`4GdTo15li<0AOAC`4H4H`15a2>0=E?3<4D3T_14Hi;`@c81d49aPC11LA40<J4@l4
5A0<218;30@?20P42PP811D<30<U5Q44cLgC1=3PjRMdLgHEoooo000Doooo7gAcMPAAA4h4<R8Q138W
90<]8Ql4>bhZ130O5P@X61<4>B/X12XO70@b9b@38aXH13Tc:`@]9R84@B/U15m;@PAF?cP4GDa:0ee9
B0AMBD44IU=;15M0>0@m;2D4Ac<Z0eHh:PAOAC`4GdTo15li<0AOAC`4H4H`15a2>0=E?3<4D3T_14Hi
;`@c81d49aPC11LA40<J4@l45A0<218;30@?20P42PP811D<30<U5Q44cLgC1=3PjRMdLgHEoooo000D
oooo7gAcMPAAA4h4<R8Q138W90<]8Ql4>bhZ130O5P@X61<4>B/X12XO70@b9b@38aXH13Tc:`@]9R84
@B/U15m;@PAF?cP4GDa:0ee9B0AMBD44IU=;15M0>0@m;2D4Ac<Z0eHh:PAOAC`4GdTo15li<0AOAC`4
H4H`15a2>0=E?3<4D3T_14Hi;`@c81d49aPC11LA40<J4@l45A0<218;30@?20P42PP811D<30<U5Q44
cLgC1=3PjRMdLgHEoooo000Doooo7gAcMPAAA4h4<R8Q138W90<]8Ql4>bhZ130O5P@X61<4>B/X12XO
70@b9b@38aXH13Tc:`@]9R84@B/U15m;@PAF?cP4GDa:0ee9B0AMBD44IU=;15M0>0@m;2D4Ac<Z0eHh
:PAOAC`4GdTo15li<0AOAC`4H4H`15a2>0=E?3<4D3T_14Hi;`@c81d49aPC11LA40<J4@l45A0<218;
30@?20P42PP811D<30<U5Q44cLgC1=3PjRMdLgHEoooo000Doooo7gAcMPAfMWP4:R8H12DM6P</8Ql4
;R<P120L6@@N5QP4<R8I12dR7`@m;b`3<bLT138V8P@c:2L4@RhW13`]8`@W9BP49BLU0c8S6P@o<RP4
@3<[12XQ80@a8a`4>2HN0d4`8PA7;RL4BcDW15/l;@A<>c44?RXR14@Z9@=9<RX4>2l/130Q7P@U5A44
7a<A11LA3`<C3`/44@/<10h820P:20P42`P811lF4P<_6QH4fn3U17UlObMdLgHEoooo000Doooo7gAc
MPAfMWP4:R8H12DM6P</8Ql4;R<P120L6@@N5QP4<R8I12dR7`@m;b`3<bLT138V8P@c:2L4@RhW13`]
8`@W9BP49BLU0c8S6P@o<RP4@3<[12XQ80@a8a`4>2HN0d4`8PA7;RL4BcDW15/l;@A<>c44?RXR14@Z
9@=9<RX4>2l/130Q7P@U5A447a<A11LA3`<C3`/44@/<10h820P:20P42`P811lF4P<_6QH4fn3U17Ul
ObMdLgHEoooo000Doooo7gAcMPAfMWP4:R8H12DM6P</8Ql4;R<P120L6@@N5QP4<R8I12dR7`@m;b`3
<bLT138V8P@c:2L4@RhW13`]8`@W9BP49BLU0c8S6P@o<RP4@3<[12XQ80@a8a`4>2HN0d4`8PA7;RL4
BcDW15/l;@A<>c44?RXR14@Z9@=9<RX4>2l/130Q7P@U5A447a<A11LA3`<C3`/44@/<10h820P:20P4
2`P811lF4P<_6QH4fn3U17UlObMdLgHEoooo000Doooo7gAcMPAfMWP4:R8H12DM6P</8Ql4;R<P120L
6@@N5QP4<R8I12dR7`@m;b`3<bLT138V8P@c:2L4@RhW13`]8`@W9BP49BLU0c8S6P@o<RP4@3<[12XQ
80@a8a`4>2HN0d4`8PA7;RL4BcDW15/l;@A<>c44?RXR14@Z9@=9<RX4>2l/130Q7P@U5A447a<A11LA
3`<C3`/44@/<10h820P:20P42`P811lF4P<_6QH4fn3U17UlObMdLgHEoooo000Doooo8gAcMP@f;3D4
:1lN0cLZ9`@_:2D4;b<P11PB3`@]8Qd4>Rl^13/^:P<l<Bd4?c<_14Tk<0A3=bd4=2lX12TR8P@/6aD3
;A/J130O70@a92048Q/L12TP7`@e8Qd3=b<I134P7@@m;bD4>R/T12hU7P@k;284=BDL0c8Z9@@]7a/4
:Q`F11XC4@@O6QP44Pl;0aD@30@C30`43`P820/820@V5Q846Q4B0h9RG@CFh>D[M7=f5Oooo`005?oo
ob=dLgH4=R`e12PO7P<g:RL4;bPU12lS80@H4Pl4;B8M13X_;P@k;RX3?34]13lc;`A9>c04@cL]13@_
:0@Y8R84;1/E0bdK6P@`7a`4<B@P128K70@Y81l4=B8M0cLS6@@a81d4?BlU13X[90@^9Ah4>b`R13DU
70<b:RD4;AlK12XL5P@J4a447aXH118?2`<E40`44``<10l820P;20P49QHB11XA4P>2HUd4e^3U:gAc
MQGoool001CooolSM7=f13H/=@@X7ah3=bXW12lX9@@_8b04618?12dR7@@j;bh4>bhZ0c`a;@@o<bl4
BC/`14<g;@@d;bP4:B8R12`K5@<]6aX4<1lL134T80@R6a`4:B0O13DR7@<g8aT4<B0M13d_9@@j:b@4
;RDN13//8P@e9A`3<RXU12dO6`@Z71H46Q<A11lJ60@B3`/35A0<11<<30@?20P82`P812HF4P@J4A83
PV9M1=KPiB]dLgHEoooo000Doooo8gAcMPAXGfT4:A/G0blS80@/8Ql4;R8O130T80A0;b/4?Bl/13`a
;@<`9B84;B<Q13<N70@m8A`4<AdG12PO7@@O61D3:R<Q11lE4P@U8Al491lM12@M6@@O51436aLF11/C
4P@O4a447QPD11lI50@Q6QD46Q4@0ahB4@@I4A046a<B118A3P@C3`/43`X;1a8;30@:20P42`P812HF
70@V5Q84=bTU0n_[k0BR/KL[M7=f5Oooo`005?ooob=dLgH4J5mY12TK5`<_8b04;28O12hR7`@`9204
@2l[13d_;0@l<Bd3<2DR12dS8@@c7Q`4?B4L134M5`@X7ad47aPE0bXS8@@O5A849B4O12@O7@@T7AT4
7a@A0a/G5P@K4a847a<A11hH50@O6A@48AXE11XA40<N4Q446A4@11/C4P@B4@h44`l;10l:2`LB2``4
2PP810/820@V5Q`49QHB13LY9@?[jn`4X[6g:gAcMQGoool001CooolSM7=f16QOJ@@Y6aL3;b<P12`R
7`@^8Ql4<2@P140_:`@m;b`4?34]0c0U8P@]8b44<ahL13dQ70@a7AL4:1lM11lH5@<Z8b447aDB12DQ
7`@T7ad491dI11lD4@<K5aH46a<B11lC4@@N61@47aTD124J5@@J4A037Q8A11TA40@K4a844Q4>11<?
2`@?2P/74P/<10X820@;20P49QHL12HF4P@g:BD3jn_/1::a]b]dLgHEoooo000Doooo8gAcMPAXGfT4
:A/G0blS80@/8Ql4;R8O130T80A0;b/4?Bl/13`a;@<`9B84;B<Q13<N70@m8A`4<AdG12PO7@@O61D3
:R<Q11lE4P@U8Al491lM12@M6@@O51436aLF11/C4P@O4a447QPD11lI50@Q6QD46Q4@0ahB4@@I4A04
6a<B118A3P@C3`/43`X;1a8;30@:20P42`P812HF70@V5Q84=bTU0n_[k0BR/KL[M7=f5Oooo`005?oo
ob=dLgH4MGAf14@m?0<]8b04;R<P13@X9@@_8b04@C@`12LM6P@e:RL38aXG138V8`A6<bT4<2TU12HR
80@Z8b44:AhK0cl[:0@O5AH49R8N12<E4P@S51846a4>0aLC40@L4Pl49QLD12@G50`I4@l391LD11/C
40@L4a044`l;11H@30LC30`82PP811D<30@b81/4:QTC1>CYkP?@em`_M7=f5Oooo`005?ooob=dLgH4
MGAf14@m?0<]8b04;R<P13@X9@@_8b04@C@`12LM6P@e:RL38aXG138V8`A6<bT4<2TU12HR80@Z8b44
:AhK0cl[:0@O5AH49R8N12<E4P@S51846a4>0aLC40@L4Pl49QLD12@G50`I4@l391LD11/C40@L4a04
4`l;11H@30LC30`82PP811D<30@b81/4:QTC1>CYkP?@em`_M7=f5Oooo`005?ooob=dLgH4MGAf14@m
?0<]8b04;R<P13@X9@@_8b04@C@`12LM6P@e:RL38aXG138V8`A6<bT4<2TU12HR80@Z8b44:AhK0cl[
:0@O5AH49R8N12<E4P@S51846a4>0aLC40@L4Pl49QLD12@G50`I4@l391LD11/C40@L4a044`l;11H@
30LC30`82PP811D<30@b81/4:QTC1>CYkP?@em`_M7=f5Oooo`005?ooob=dLgH4MGAf14@m?0<]8b04
;R<P13@X9@@_8b04@C@`12LM6P@e:RL38aXG138V8`A6<bT4<2TU12HR80@Z8b44:AhK0cl[:0@O5AH4
9R8N12<E4P@S51846a4>0aLC40@L4Pl49QLD12@G50`I4@l391LD11/C40@L4a044`l;11H@30LC30`8
2PP811D<30@b81/4:QTC1>CYkP?@em`_M7=f5Oooo`005?ooobMdLgH4GU1I0bLE4`@e:2D4=2PU12dR
7`@R7QX4<bTV14@f<P<[9R<4:QlL13LQ6@@L5A@49QdI12PN6P@I5AX391lK11/D5@@X5a<4714G21LC
40<E40`46Q@@11TD40@G4a044`l;110;2`@E3`/37Q@@11<?2`@@2`/45@l<11L@4@@C30`32PP811<<
30@P5Q84<b4L12lJ5PCKhNH4fnK[<WAcMQGoool001CooolWM7=f15i@F@<W5A<4=BPU13@X9@@]8Ql4
8QhJ13<Y9PA4=S83:bHS12XO70@g8AT471DD12HM6@@X7QX46ADJ0b@O6`@K51D4:1LC11`A5`PG4a03
5A0<11XD40@I51045a<@11<?2`@@2`/45@l;0ahD40@C3`/440/;11D?30@G41444``<0`X820@C30`4
81HB13<Q70@_6QH4fn7V1=_Vjc9dLgHEoooo000Doooo9gAcMPAND5T39aDC13DX9@@d:2D4;B8O128N
6P@c:BH4A3Hb0b/V8`@Z7a`4=b4I11`E50@V7AT4:1hJ11TE6P<T7a/46a@E12PG4`@L4AL85a<@0aD@
30@J51046A@@11LC40@C3`/440/;11D?2`<N51044`l;110;2`@E3``45a0A11<<30<:20P44``<120F
4P@c8A`4;aXF1=_QiPCKi^/bM7=f5Oooo`005?ooobMdLgH4GU1I0bLE4`@e:2D4=2PU12dR7`@R7QX4
<bTV14@f<P<[9R<4:QlL13LQ6@@L5A@49QdI12PN6P@I5AX391lK11/D5@@X5a<4714G21LC40<E40`4
6Q@@11TD40@G4a044`l;110;2`@E3`/37Q@@11<?2`@@2`/45@l<11L@4@@C30`32PP811<<30@P5Q84
<b4L12lJ5PCKhNH4fnK[<WAcMQGoool001CooolWM7=f17EeM`<_9R44;2@P138W90@]8Ql4=BPU138Z
9P@_9B838aXG12<H5@@T6QL45a4>12/P70PP5QL37a<>11`A5`@D3`l43`/;11D?3`@F3a034P/<11L@
4@@A2``45Pl@118;30@G41447ADA0aL@4@@A2``@2PP80aPA4@@J4Pd44``<120?2`C>bLh4f^GZ=WAc
MQGoool001CooolWM7=f17EeM`<_9R44;2@P138W90@]8Ql4=BPU138Z9P@_9B838aXG12<H5@@T6QL4
5a4>12/P70PP5QL37a<>11`A5`@D3`l43`/;11D?3`@F3a034P/<11L@4@@A2``45Pl@118;30@G4144
7ADA0aL@4@@A2``@2PP80aPA4@@J4Pd44``<120?2`C>bLh4f^GZ=WAcMQGoool001CooolWM7=f17Ee
M`<_9R44;2@P138W90@]8Ql4=BPU138Z9P@_9B838aXG12<H5@@T6QL45a4>12/P70PP5QL37a<>11`A
5`@D3`l43`/;11D?3`@F3a034P/<11L@4@@A2``45Pl@118;30@G41447ADA0aL@4@@A2``@2PP80aPA
4@@J4Pd44``<120?2`C>bLh4f^GZ=WAcMQGoool001CooolWM7=f17EeM`<_9R44;2@P138W90@]8Ql4
=BPU138Z9P@_9B838aXG12<H5@@T6QL45a4>12/P70PP5QL37a<>11`A5`@D3`l43`/;11D?3`@F3a03
4P/<11L@4@@A2``45Pl@118;30@G41447ADA0aL@4@@A2``@2PP80aPA4@@J4Pd44``<120?2`C>bLh4
f^GZ=WAcMQGoool001Coool[M7=f0gYjO0A;?S`4:AlK12`R7`@^:2D4;2LT13X/:@<]8R@49AHC12HK
60@G4Pl47Q@@11HA3P@M4`l740/;11D?3`@G41044``<11L@40<C30`4614A11<<30@_6QH42PP811PA
4@@L5A035Q0@20X820@@20P46Q4B11XB4P<J4A84;ATE13`U6`B3CcT4h>W]17UlOcIdLgHEoooo000D
oooo:gAcMP=jNW`4Bchl12TO6`@/8Ql4;RPU12`W90@j;2T3;B8T12DF4`@V6aP45a8?11hD40@F4@h4
7A<?1a0;2`@E3`l45a0@11<<30@G41034``<11PA4@@C30`4;aXF10X820@H4A4471D@0aH@40P:20P4
40P811XA4P@J4Q836Q4B12dI5@@l9A/4Pdli1>3Yk@AiO7lfM7=f5Oooo`005?ooob]dLgH3NWYl14/n
?0@Y7a/4;28O12hX9@@/9b@4>R`Y0bdR90@U5Q<49Q/H11LB3`@N51045Q4>11dC3`L@2`/45@l?11L@
40@C30`45a0@0a<<30@H4A444``<12lJ5P@:20P4614A11`E40<F41082PP8110820@J4A846Q8B0aXA
4P@]6AD4?2DK18=?>@CPjNd4NGao=WAcMQGoool001Coool^M7=f17YjO0A<>3H4<R/W12PN6P@j;2T4
>b`Y0cH[:0@T7aX4;28N11dC60@F41047a@@11H@40<J51047AHA11PA4@PB2``44``<0a8;30@C30`4
71D@11PA4@@];Cd4>S@e128E6P<B2``45a0@220F4P@I4Q84=2@O0bhO6P@]6AD4ES<Y1<oKi@BW_llj
M7=f5Oooo`005?ooobidLgH4NWYl14`h=P@b:bL4:1hJ13X/:@@k;2T3=R/X12@O6P@/8Qh47A<H11H@
40@O51045Q0@0aXD40@M5Q44614A218;30@C30`34P/<11<<30@L5A04614A12d]?@@j=3D48QDJ0a8;
30@G410881HB11TB4P@d91l3;QlJ12dI5@AF<bT4cm_U1:NoccYdLgHEoooo000Doooo;WAcMPAjNW`4
C3Pf138[9`@X7QX4>R`Y13//:@<f:bP491lJ12`R7P@M4aP45Q0@11lD40@F41036Q@@11dF4@@H4A48
4P/<11<<30<B2``44``<11`E40@H4A44;Bdm13Xd=@@R5AX34P/<11L@40PP5Q846A8B13@T7`<^7aX4
;ATE15Hc:@C?fnD4Yko?>WAcMQGoool001Coool^M7=f17YjO0A<>3H4<R/W12PN6P@j;2T4>b`Y0cH[
:0@T7aX4;28N11dC60@F41047a@@11H@40<J51047AHA11PA4@PB2``44``<0a8;30@C30`471D@11PA
4@@];Cd4>S@e128E6P<B2``45a0@220F4P@I4Q84=2@O0bhO6P@]6AD4ES<Y1<oKi@BW_lljM7=f5Ooo
o`005?oooc9dLgH4Q8>614`j=`@l;BX4:QlL12XU8P<l<Bd4=b/X13<P5`@V6QL46Q@?11L@40@A2``3
5a0;11H?40PB2``4614A11<<30<H4A484``<138^<@@]7RX4A38Y14Hd;P<i:RT4CCTc13DU7`@K5104
;1dJ12dN6P<g:RL4Cb`S1=[IgPBgc]LnM7=f5Oooo`005?oooc9dLgH4Q8>614`j=`@l;BX4:QlL12XU
8P<l<Bd4=b/X13<P5`@V6QL46Q@?11L@40@A2``35a0;11H?40PB2``4614A11<<30<H4A484``<138^
<@@]7RX4A38Y14Hd;P<i:RT4CCTc13DU7`@K5104;1dJ12dN6P<g:RL4Cb`S1=[IgPBgc]LnM7=f5Ooo
o`005?oooc9dLgH4Q8>614`j=`@l;BX4:QlL12XU8P<l<Bd4=b/X13<P5`@V6QL46Q@?11L@40@A2``3
5a0;11H?40PB2``4614A11<<30<H4A484``<138^<@@]7RX4A38Y14Hd;P<i:RT4CCTc13DU7`@K5104
;1dJ12dN6P<g:RL4Cb`S1=[IgPBgc]LnM7=f5Oooo`005?oooc9dLgH4Q8>614`j=`@l;BX4:QlL12XU
8P<l<Bd4=b/X13<P5`@V6QL46Q@?11L@40@A2``35a0;11H?40PB2``4614A11<<30<H4A484``<138^
<@@]7RX4A38Y14Hd;P<i:RT4CCTc13DU7`@K5104;1dJ12dN6P<g:RL4Cb`S1=[IgPBgc]LnM7=f5Ooo
o`005?oooc9dLgH4Lg=e17EfN0A4;RH4?S4]13LZ9`=1<Rh4>Rl[13da;P@T6aP49a/H13XY9@@_9Al3
91HA11`E4@@G4104614A11<<30@B2``37ADK11L@40@M5Q44614A12@M60@b9Ah43@/<0a0>30@D40d4
3P`<11/A3P@[7AX4<b4H0fHn;@BZWJ`4^]7K17AhNSidLgHEoooo000Doooo<WAcMPAcLgD4MGIh14@^
9P@n<Bd4=bXW0d4b;P@j;b/4?C4^12@K60@W6aP4>RTU12lU7`<T5Q4471DA11L@40@H4A444``<118;
30<M5A/45a0@11dF4@@H4A4491dH138U7P@=2``340h<11@@3@@>30`46a4>12/M6P@c8AP3ISh]1:ZM
[0BjdM/4M7Qj?WAcMQGoool001CooolbM7=f17=cM@AeMWP4A2hV13ha;@@g:RL3@C8^13X_:`@m<Bh4
91/H12LK60@j:BD4;bDO0b@F4@@L5A445a0@11PA4@@C30`44P/<0adE6`@G41047AHA11PA4@@T7AP4
<RDN10d;30<@3P`4510=10h<30@K4@h4:adJ13<Q60=V?Rd4ZYf/1;[Af`AdN7XnM7=f5Oooo`005?oo
oc9dLgH4Lg=e17EfN0A4;RH4?S4]13LZ9`=1<Rh4>Rl[13da;P@T6aP49a/H13XY9@@_9Al391HA11`E
4@@G4104614A11<<30@B2``37ADK11L@40@M5Q44614A12@M60@b9Ah43@/<0a0>30@D40d43P`<11/A
3P@[7AX4<b4H0fHn;@BZWJ`4^]7K17AhNSidLgHEoooo000Doooo>WAcMPAkNgh4AShg12<K60<a9R<4
AcXg14Q1?P@l<2d49a`H124F60@S5183<bDQ12/T7`@F41044P/<128I7`@T6b03;bHP124I7@A2<2/4
71@J150m=`@c9BL4<2@P0c`[9@@c91l4>RTU158o<@@h:BD4L4Hd0m7Af`B^a]D4Ph^8@WAcMQGoool0
01CoooljM7=f17]kOPA6?SL48a/H0c4V8`A7>SL4B44n13``;@@W71P48AHH12<D4P<c9B44:b@O11H@
40@B2``48QTO12@K80<_9R048ATM148`:`@L51X4D3dg13<U9`@`9203?2/U13<T7`@j:BD4DSla13PY
9@A`AS@3dM7K1:k6e@B3RhQ2M7=f5Oooo`005?ooocYdLgH4Ng]n14Hn=`@S6aP3<BHS14Lj=`A8@Ch4
?30]12LL60@Q5QP48a@B0c<U8@@[91l45Q0@118;30@R6Al491/P0blV80@Q6Ad4@S0[11`D6PA@?CL4
<bDW130T80<l:bD4<b@O13XY9@AB?c44>2TU1716=0?AdM/4[/KE18>;R49dLgHEoooo000Doooo>WAc
MPAkNgh4AShg12<K60<a9R<4AcXg14Q1?P@l<2d49a`H124F60@S5183<bDQ12/T7`@F41044P/<128I
7`@T6b03;bHP124I7@A2<2/471@J150m=`@c9BL4<2@P0c`[9@@c91l4>RTU158o<@@h:BD4L4Hd0m7A
f`B^a]D4Ph^8@WAcMQGoool001CooolnM7=f17]jO@BFRid3B3Te138V8`@^9284=3@m14Tl>@AIAd<4
Fe5:0c@X:P@Y:2/4B3i?16EFC`@o;Bd4<2Pb0cLX9`A8?Dh4?RhW12hR7`A6=2d4=2@Q13/S7`<k8aX4
=BPU14`f;0AY@C04=QlI1<gEf`>W`<l4M7QjAWAcMQGoool001CooolnM7=f17]jO@BFRid3B3Te138V
8`@^9284=3@m14Tl>@AIAd<4Fe5:0c@X:P@Y:2/4B3i?16EFC`@o;Bd4<2Pb0cLX9`A8?Dh4?RhW12hR
7`A6=2d4=2@Q13/S7`<k8aX4=BPU14`f;0AY@C04=QlI1<gEf`>W`<l4M7QjAWAcMQGoool001Coooln
M7=f17]jO@BFRid3B3Te138V8`@^9284=3@m14Tl>@AIAd<4Fe5:0c@X:P@Y:2/4B3i?16EFC`@o;Bd4
<2Pb0cLX9`A8?Dh4?RhW12hR7`A6=2d4=2@Q13/S7`<k8aX4=BPU14`f;0AY@C04=QlI1<gEf`>W`<l4
M7QjAWAcMQGoool001CooolnM7=f17]jO@BFRid3B3Te138V8`@^9284=3@m14Tl>@AIAd<4Fe5:0c@X
:P@Y:2/4B3i?16EFC`@o;Bd4<2Pb0cLX9`A8?Dh4?RhW12hR7`A6=2d4=2@Q13/S7`<k8aX4=BPU14`f
;0AY@C04=QlI1<gEf`>W`<l4M7QjAWAcMQGoool001Cooom2M7=f17IfN0>AUiD4CCm913lc;`@`<3T4
EDU814U4B0A2?3X3@c/h15YADPALAT04B3P_130T8PA2=Bh3<B<Q12PN6@@X7AL4>2`Y13@X9@A39Ad4
Bb`T0d/e:`AK@ST4AbLO15Y7CPBZ`m<4a]ORCGAcMQGoool001Cooom2M7=f17IfN0>AUiD4CCm913lc
;`@`<3T4EDU814U4B0A2?3X3@c/h15YADPALAT04B3P_130T8PA2=Bh3<B<Q12PN6@@X7AL4>2`Y13@X
9@A39Ad4Bb`T0d/e:`AK@ST4AbLO15Y7CPBZ`m<4a]ORCGAcMQGoool001Cooom2M7=f17IfN0>AUiD4
CCm913lc;`@`<3T4EDU814U4B0A2?3X3@c/h15YADPALAT04B3P_130T8PA2=Bh3<B<Q12PN6@@X7AL4
>2`Y13@X9@A39Ad4Bb`T0d/e:`AK@ST4AbLO15Y7CPBZ`m<4a]ORCGAcMQGoool001Coool4M6Y]17Ac
MD5dLgH4NgYl1;o8a0Bd[l04D4=@15Q8BPAhJWh3JUML15U1?PA6=c<4ASXg15U4B0ATC4P3DD8o16aA
BPAFACX4FDU416A<B0A?@3H4A40h0blV90B1MXP4//G@1<7IhPBW][MAM7=f5Oooo`005?ooo`AdJVd4
M7=e@GAcMPAkNW`4_lS41;B_`0A@@e04F4Q:17QZOP=ZEe`4FD4n14Hg<`A6>SL4FDA816A<B0=A@Sl4
K55:15I5>PAIBD@4I4a814m0=PA4@3P3;bHT185fR0BbaM04`MWR1:Nf]e5dLgHEoooo000Doooo17AZ
K@AdLgE1M7=f17]jO0Bob<@4]:o01513D0AHB4X4N6Yn0fYGG0AI@Ch4ASLc14Hj=`AIA4P4I4a80e52
?`A/DDX4ETDj15U9A0ATC4P4Cd0f14A0>0<_9R@4PGJ81;;5d0C1fN84YkJgDGAcMQGoool001Coool4
M6Y]17AcMD5dLgH4NgYl1;o8a0Bd[l04D4=@15Q8BPAhJWh3JUML15U1?PA6=c<4ASXg15U4B0ATC4P3
DD8o16aABPAFACX4FDU416A<B0A?@3H4A40h0blV90B1MXP4//G@1<7IhPBW][MAM7=f5Oooo`005?oo
o`QdN7Y9M7=f17EdMPB5R8@4_<2h1:F`/0>4PHd4XJ>U18F0V0A?BE`4C4MJ13lg<`<o=cD4ACTg13lg
=@A2=SD4>2TQ13</90Bf];h3`<SB1<WFf`B=VIIIM7=f5Oooo`005?ooo`QdN7Y9M7=f17EdMPB5R8@4
_<2h1:F`/0>4PHd4XJ>U18F0V0A?BE`4C4MJ13lg<`<o=cD4ACTg13lg=@A2=SD4>2TQ13</90Bf];h3
`<SB1<WFf`B=VIIIM7=f5Oooo`005?ooo`QdN7Y9M7=f17EdMPB5R8@4_<2h1:F`/0>4PHd4XJ>U18F0
V0A?BE`4C4MJ13lg<`<o=cD4ACTg13lg=@A2=SD4>2TQ13</90Bf];h3`<SB1<WFf`B=VIIIM7=f5Ooo
o`005?ooo`QdN7Y9M7=f17EdMPB5R8@4_<2h1:F`/0>4PHd4XJ>U18F0V0A?BE`4C4MJ13lg<`<o=cD4
ACTg13lg=@A2=SD4>2TQ13</90Bf];h3`<SB1<WFf`B=VIIIM7=f5Oooo`005?ooof5dLgH3MGAf17j2
NPAfNW`4SYF=1;>g[PBc^;03^;Nm1;S1a`Bh`/L4^L;81;k8cPC3d=`4_<G?0gAhNV5dLgHEoooo000D
ooooHGAcMP=eM7H4OX9j17IjO0B>UHd4/kN^1;>h/0>h]kd4^<771;S2a`Bi`/P4_/S>1<?@g0BlaLl3
M7QjHGAcMQGoool001CooomQM7=f0gEdMPAnPWX4MWYl18jES@Bc]jh4/kR`0kRg_@Bh`LL4^<;71;W2
b0Bnb<h4`m3L1;c5c`=dN7YQM7=f5Oooo`005?ooof5dLgH3MGAf17j2NPAfNW`4SYF=1;>g[PBc^;03
^;Nm1;S1a`Bh`/L4^L;81;k8cPC3d=`4_<G?0gAhNV5dLgHEoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo002Ioooo0`0008Coool009coool0
0`000?ooooooo`21oooo001koooo1@000003oooo0000000000<000000oooo`000000000200000ooo
o`@00002oooo0`0000?oool300000oooo`80001noooo001moooo00<0003oooooool00oooo`050000
oooooooooooo000000Goool010000?ooooooo`0000;oool00`000?ooooooo`03oooo00@0003ooooo
ool00023oooo001moooo00<0003oooooool00oooo`030000oooooooo00;oool00`000?ooooooo`02
oooo00@0003oooooool00002oooo100000;oool010000?ooooooo`0008?oool007goool00`000?oo
ooooo`03oooo00<0003oooooool00oooo`030000oooooooo00;oool300000oooo`800004oooo1000
08;oool007goool00`000?ooooooo`03oooo00D0003oooooooooool000000_ooo`030000oooooooo
00?oool00`000?ooooooo`2=oooo001loooo0P0000Coool200001?ooo`800005oooo0P0008ooool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(135) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
738787738787738787738787738787738787738787738787738787738787738787738787
7387877387877387877387877387877387877387877387877387877387877387876D695A
74766873756D737B7273736B737B7273797073797073797073736B7375666D6F616F6B5D
6960536B6255655D50675E50675E50675E50675E5067594B615A47635A4D635A47635A4D
79979B738787738787738787738787738181738888738787738787738787738787738787
738787738787738787738787
738787737E7F738485738787737E7F738485738787738787738787738787738787738787
738787738787738787737E7F738485738787738787738787738787738787738787757160
777872737567737B7073736B737B727379707371616B6757696757696354635B515D574C
5D554960594D5B5448655C4F675E50675E5067574A67574A615A4D635A4E635A4763797A
79A2A9738787738787738787738787738989738B8B738787738787738787738787738787
738787738787738787738787
738787738989738283738485738989738B8B738787737E7F738485737E7F738485738787
738787738787738787738989738B8B7387877387877387877387877387877387876B6758
70726373756C73726E73797073756C736F676B695C546560605E5565504C5F5248635E51
676456676759696253635A4C5D55495D55495D574A5D5A465F5A4B635A4C635A4D83A7AF
83A0A2738787738787738787738787738787737E7F738485738787738787738787738787
738787738787738787738787
738787738787738181738888738787738787738787738989738B8B738989738B8B738787
73878773878773878773878773878773878773878773878773878773878773878775695A
77767173756F73756C73726A73716973756475776E807D76807A697D6F6D72695B725E50
725953725955694D4961554A635A4C635A4C635A4C635A4D6A6155655B4D635A4C79979B
738787738787738787738787738787738787738989738B8B738787738787738787738787
738787738787738787738787
738787738787738989738B8B738787738787738787738787738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787737160
73786873756273756A73756C73756C73756E737D77737F757579726F77666D6D60756E61
7571616D62567571606D59506C504C6C6662655D506A5A4C6A584B61574A6A695A7C9C9F
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787736F5F
73756773756F73756773756A73756C737D7373756C736F67737970757972797F6F717663
6F6962716B5D6B65556A5E55696855675B4969625A635D505D5A4C5F5A4C7986867D9EA6
738787738787738787738787738787738787738787737E7F738485738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
7387877387877387877387877387877387877387877387877387877387875B4A406B5D4D
73756F73756773756473756D737D7373756C737970737F75737D7373736B73756E757165
79706071695971695B6D5F566D5E5069594B5F56485F54456A5A4C655A4C748F95749396
738787738787738787738787738787738787738787738989738B8B738787738787737E7F
737C7D738485738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787738787738787738787738787738787211F1A534E3F7D816E
73756D73756E73757173756F737B7273736B73726273776C737169737169737564737765
6B645F6B63596F5F5A69614D635948635E50695B4D655A4C68695A6964557E9FA2778F8E
738787738787738787738787738787738787738787738787738787738787738787738989
738D8D738B8B738787738787
738787738787737E7F738485738787738787738787738787738787738787738787738787
738787738787738787738787738787738787738787738787545860130B0B7C767277786C
737D7573776E737D7373776E73726A737970737F7773756F737161735D5B6B574E615047
695B4F6F675767695A5F5D4F6B5D526961535F59455F5A4B6156495D5347759397738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738989738283738485738787738787738787738787738787738787738787
7387877387877387877387877387877387877387877A8F8F130F0A7E785CBFBC9873756C
73726E73716973726A73716973756C73726A73776E73736B6B6D5F6961596B6756696154
696153655E51675E4A655A4C64574A63554969574B6C5A4E655A4C6A6153747773707D7B
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787737E7F738787738B8B738787738787738787738787738787738787738787
7387877387877387877387877387877387877387870D0A076E6A5DC0BBA977786C73756D
73756C73756C73756473756A73756C737D7373756C7371696D3D3F6F373C673134673034
6B32366B5149635348635349674F445F5844655A4B675A4C615A466850435B4B3E6D7E7C
738787738787738787738787738787738787738787738787738787738787738787737E7F
738485738787738787738787
738787738787738989738B8B738787738787738787738787738787738787738787738787
73878773878773878773878773878773878754585A8C8A83BBB4A473716973756673756D
73756C736D5D736B5B736B5C73726873726A735A5A7357596D44436743395F312768433E
634037683F3D5E3C3B5D4D435D5A465F554868584D675A4C695A4D6A5449696254645142
6B706B738787738787738787738787738787738787738787738787738787738787738989
738B8B738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
7387877387877387877387877387877387870F0E0D504D3E74725D73756273756473756D
7375646B6758695E537074667378707365566B3E3B61312B59473D4934255C755F6D816E
5E352A5B2C24633A3265463F63584D63543C615B44655A4B675A4C675C4D675B4D675C4F
78847F738280738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787737E7F738485738787738787738787738787738787738787
7387877387877387877387877387873B373A5D493AB6A98C7778726B655B707873737771
7365586656455D453B6F595C632D311A0303463E3B67584C7573688BB8B0814E4758372F
45432E4F6657363829532B245C463B61503A6A53496A5F546F6A54695D4D676153675A4C
6050436B6860738280738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787737E7F738485738989738B8B738787738787738787738787738787738787
7387877387877387877387877387871615146F705E898C837375676D615274736C737169
73695B6044355B3F352309093D595793DBCCB1EADD7FBCC07DB7BD7796936F826C84C5BA
8FB0B0697B7C3A2E271F1E133F302562554568564C6F68596F65596D6653695B4C67574A
675F5160778F64747E708282738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738989738B8B738787738787738787738787738787738787738787738787
7387877387877387877387875B6677150E0D86806D747666737564757B6C77807673756C
634C414A3E2A47261C2E0F097F544876504269463D706D67736953736851664B436A696B
63493C8075658371597D7E6D33271E442C245D48406A66517373626D6659655F53675347
6756495F6A5B525547545D6D6B7D82738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787211F1A000000523C2FBAAF9177786A736559736156737062737562
685344746E618FA491B0D8B4B1B1A4756F67675852634F47662F315935375929275E1F1B
561D1B5A4F4656392E6242425D463D300F0750403C6E6351706F6169604C6556485F594B
6564556963548894966D7684758985738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787737E7F738485738787738787738787738787738787
7387877387875B5F67050605100E0C9FA1918B927D736D60735F616B7167707A6B735D60
68554C55433271726B77807C737E7575897A7B978A7F94877D997F76856B7C846C748B68
7484696D604F713D3D6937315A261A501A13512118594A416E6259695E4C65574B615246
685649675B4E17110E555D587B8C83708282738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738989738B8B738787738787738787738787738787
738787738787627180B2A98AFFCEA3C1B18E707262736F61737D6A756964777168737B69
68695569574B787567706E6573797073776E73726A737970735F606D5D556F675A696155
6B5D525E5A465B5B495B6E4F69715A7D7E6680746B746D4C686151675F4D65574B615C47
685D4D675F512F32306E7C766B817F778F8E738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
7387877387877A6F567F756075847F717C6D6C6E61707567737872737B7373887C737773
6F6D6170645565504468655870786E737B7273776E737B72737A666D6D59675145675C49
5B56424E4F44584B3B5A44385A48385A46385C4E386C6855706A5F6B5B505E4E455F5046
6158465D5849161514798AA07E98A0738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
7387876B7677706B5B6B655761513D525C626F6E66777671737D77737F75737D73737B72
75636473675D705E4F756A5C746F6973776E735C5C6B6458706F5F665C4F675C4E5B4339
5B4F4760463C624C3B5F5245665A3F61533E5F4C387260536F5C4F6354485D5145635548
635B4E6A61550C0D0E666E666E8278738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787756A56776D60665A505F554B75746481635D73716E737B72737970737970737970
737A667576606C675169584972736B737B72737A6F7582767778746F65616D6659675F50
6C625360493C5F4A3E5F4F4364564B6C564E7B6B5E77726363594B63574A695C4D655649
635B4661584915110E26201C5B676C738485738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787736F5F6B6D5E503B2A6E72637F6D6E77786A738070737B72738280737C74737970
73736D73796C6864576B66536E7966707066737161737D7173776E6D6B5B615546635448
5F5A4C615749685D40614D3D64544771645C7774666D67596566586764555F5B4D5F5C4D
635D4F6A695C7A5D3C5D33231F1816475558738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
73665A633D315220205A403A6077726D7B6A73806A73756D737B7273776D73756A737970
73736B6B6D5F6D6B5E757F707B83767778686B5D56706C60735A58665444614A3F5F5044
58493E6150384D413557463D6C6657706C5A706B5B696154655B4E67544869574A655A46
6A52446A635566554A7F6A5BCFF9F2BDE0DB738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
73585668403D603D376364537B7D6B817A71737D79737771737B72737970737970737169
7371616D6F5E776B5D717264747671737D79757E77778077736B5C6863525E5247584E41
55473B54473D5E4F46766F5D7772616F6D5F706A5D696154655D5067594B67524C69504D
6352496566605A443461524482A3A5758989738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787736D60
736751685D49595139686B567E8271777870737B72737B7273756C736F676B6758706F5D
735D5D6D61596C60556B685B74746D73726273716773756C736162685047604E435E4F42
6152445D5B4D68644D6C65556D645673685B6B5F5267584C655B4E6751456752445F5544
5F5D4668685E6B554868625558676B657376738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787634F3C
4A302626201A36332B6B6E637A807073756D73726A736F67737161736D5B6D6D5D6C5E5A
615D5169655A6F74676F7A6A747A6973756C73756F73756C6B736066614E6055485E4F42
5F50436856496A5B4E715F5A6F645769615367675A6B66586560526762535F60515F5649
63534E68635F583222656052654233797F79738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787603E2E
1B140D26221F251F1F62655C76797373756F73756473756273756C737773757A76797F78
736D656B58525D51456A60556C6C5F70726C73756C7375646D5F58614F455644455C4C3C
584A3B6254476A6254685A4B605B4C6859536351466055495B54485D55495F574A635447
63554D61584853493059533E5D413B799DA2738787738787738787738787738787738787
738787738787738787738787
73878773878773878773878773878773878773878773878773878773878773766F6A564D
5D46383A2B212E25228279667679696B6D5B70726A7375695B564A554F4141362B3C3027
3E343049393A5E5045625045625A5072716B73756C73756E6D635E6356495C503A5F4C35
5A50435E51435150444C4D425956496264545B5A4A655F51696052655B4D635A4C635447
63554D635B4C3E2B22381D1753392B779A98738787738787738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387877387877387876B5C4B664F44
0A0605090D0C1A1A17817E6A707365736D60777666737564726D5F5650443E3B31212929
0F1819191A12363126361E173217135D514770706673756C6D6B5B6358495C4E3C58593F
504739655C4E726959786858745E4F634F49524B42645D50675E5061594B555246515246
5F5D4D635D4C4B36295432246840337B99A0738787738787738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387877387877A8F8F776656634C40
2E25212019132B1A15918975777C6D6F72647076687375677579736C6254917E74433A30
211612261A13293130483E317F79638A99837482797389856D756763574A4E41364E3F32
250C084938314F3F2A3F372C2B271F4442375553446459455D55475F574A594D405B5346
66534D55493F3427224A3A2D6C594F86B3B7758989738787738787738787738787738787
738787738787738787738787
737C7D738485737E7F738485738787738787738787738787738787080202321816665E51
3C30271C1A201B15128689746C6E617375676F7063696B5E70726C7277676F695971624F
A9886B9A704B8962418D745380735F757163747A7273776D6D6253635246604A375B493B
574031555B55202C2F0003051B1A192B312C101411242626302B21503C2C5750435B574A
6655464442342420192E272067625282ABAA718585738787738787738787738787738787
738787738787738787738787
738283738888738989738B8B7387877387877387877387870B0606090706120502080D0F
0609100F110E261A14968E796F70637476715D43425A47406F6D67757F777B837D7C766F
715F517368597E6E5F81755F7B7264737465747D767379706D605A6362565C533F5C5D41
6C573E7F6F597E5A431712113020162B2725221F1C4D3C2D624B3B7469546354465D5346
665D48221E1D1D1A152F211864382B71858B6E8383738787738787738787738787738787
738787738787738787738787
738D8D738B8B7387877387877387877387877387877387871C120F2F261B2C1D1721211C
0A0A0A251A142E1B1691826E776E616F6E5F7882756D756245372D3A2B243028211F1F1C
1818161F1D182A221C30231D5150496A7365747770736F5F6D60506361515C4C41614839
5B553E62604A675F4F947E64B388657B563E754D37946B538168475F5B4B615B496A6151
5B55491F1C161F17143322195F2F22769A9E738787738787738787738787738787738787
738787738787738787738787
73878773878773878773878773878773878773878773878721160F19100B121210171410
1C15101916112C2B267D78646F6D6075786A7778707A7E7588907E78685E4D4C4E765F58
7E5F4A7F6A546E574585735F8F97817F837C777872735D5F6D655C6363555C464737261E
30201B4D46365F5844635A446F5D4D766A516F6C58736D5358594C6355535B53495F5846
4440330D0F0D1213107C624C663B297AA7A9738787738787738787738787738787738787
738787738787738787738787
738787738787737E7F738485738787738787738787738787291F1721110C1E1611181511
0A07071B1410312A25665A4B69665A70746673756D737D7375817980938999AF9BA2B19C
92AF9F9AB4A79CB4A897A992798472747E766B6F5E69715D6B725D6C675A7676637A775E
4B3935231F1B0C0F102E28265851485F5A47675C485B55485C4B414B46385E52496A5349
221C18130F0D292721603E2E402419171A19495357738787738787738787738787738787
738787738787738787738787
738787738787738989738B8B7387877387877387877387871E1D1B211F1C1D17121D1511
16120C2017122F2A256C584777716274776973756D737B72737970738280738584738584
737C74738280737C74737B7475796C777666757363716B5D6F6055716C5E7572627A6F67
837F729B7F6C6A554734281F1014111717181A232328262031292160514B715A4C5C4E3F
17131217131020191A1A0C0A1F110D2A2E2C92ABAA738787738787738787738787738787
738787738787738787738787
73878773878773878773878773878773878773878773878729221F3C302B1916121C1511
1E1611241B1C302A26554B3B6060536F736673756573726873776E73776D737B75737E79
73817D73828073776E737970737B7473776B7375676D695C6F6E606F675A6F6A5D6F655E
6C69596B6A57746A5584745C816F566A513C5B4533785745766B5970565353524645493C
1915131C151117151111100B1D1A162D33308EA7A6738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787271C15292017231D191F1612
22100C271A152F23193932295E54496E6E6170726573756D737B72738280737970737B75
737E79737E7973776E737970737161737169736D626D5F546F6A5D6F6E606F675A6F6356
695F506D584C6B5D50695D4F7A6A59806E5C8575617C67566E5A536C5849635341392B20
1A14111C1511281B161B16121D16112A21185A5555647072738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387871E19122E2D2A241F1B261A16
13110C1915111813102F231C43352466635674746673756D737B7273807C73817D737970
737B7573756A73756A7379707373657375656B67586B6B5D6F675A6F61566F63576F675A
696154635D50635E50696759635B4D67574A655A4C5554475155465155463F4236151B19
0B0D0A1E191A12101111100B0B07072018154B4542738987738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787291E172D28242D282426201B
271B1720171227201B35312D37362F645D546F695D73726C73726A73746B737B7573817D
73828073776E73797073797073736D6B6D626B675B6F63576F63576F675A67675A655F52
675F52655D50675E50675C4F695D50635B4D5F5A4C5954476A55485F4E41332C261A1312
261E1A100C0C1210100C07071511121E17124647437F9B9C738787738787738787738787
738787738787738787738787
73878773878773878773878773878773878773878773878722221F2F2E2B332E292F2A25
261B1612100C24191538271D543C2B6E4C376B665870746573756A73726A73746B737B75
737E7973817D737C7473797073736B757767716D5F676559655F526C5E58695E526B584C
6B5953655B50675E5067574A5F55495F574A5C4B3F6550445B473B35332E231E181E1613
11100B121010110C0C15110C161212281B16BADAD6A5C7C4738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787737E7F6B74751E1B182A26222F2B272C2723
19141026201B2A221D262420483C2E6050426B6C6172756873756D737D73737D7373807C
737E79737E7973776E7379706B6B5C706B5B6D5F5471635775695B6B64556762526B5D50
6365566360505F4F4A5D554A5F5A4C635A4C65554858574A474437453B2D272017201815
1816111A17121A171116120C191611271B169EB9B7758989738787738787738787738787
738787738787738787738787
73878773878773878773878773878773878773898975908F1D1B1736271D2D2722302C28
312B2629211C29241F30241A44443A433C306053476B6B5E70726C73726A73776E73776D
737266737266736D636B67586B62536C6E616B6458675F4C655E4F675F4C6B62536B6456
655E50675B4E695A4B655D4C63524663504455524647473B40352A241F1E181413131310
11100B1310110F0B0C0707070E0B0C3C2A269CB4B26E8383738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387872A231F2E241A2E2D29322D29
26221D2218142F23192E292438372E33251F53453A6B7163747666737562737268736F5F
736F5D736F5D737167757767716D5F6F615667524767574C6B59566B61566B62576B5448
65594D67574A67574A615A4C6354475C4E41494639403429241D1D1F1C1617130F161511
1E1611161112100C0C120C0C2E1D17DCFEF3B8E2DD738787738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387873736322E2B272B2825352B27
2E22192A251F231F1B2A272424201C272726453E30574F3E656457696B5E707263737564
7375676B6D60696B5C7072626D6155675549675F4C63594A605C4E605C4D68594D635649
63584B674F4A5F584C5F5A465C4D3F554E4147443830241E211D1616130F100F0B121011
1C15111411110C0707100C0C271B1693ADAB6E8383738787738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387873332292E2B26332E292B2823
2927241D191A221D1928231E322D292E23192D221A3E3D34524A426050466A6055696156
69695D6B6D606F695C6C6558635F545F554860544963544A67504467534764554963574A
5F52465D5244584C3E53483D45453B3A352A382E24201C1514120F13131013110C100C0C
0F0B0C0607070707072B1D173822179AB2AE738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787686F7B3C312F312C282C2723
38332F31251A271A15352F2A28231E2F2C28211E1B2C312B222623312B26534B4254493F
5853505A53525A554C625F54584E433F382E41392F503F2F5B4F425D53465D43385D4D42
5F52395C4E3E55473B504236484236352923261B1619141219141013100C0F0B0C100C0C
0C0708080708120C0D1F1612B2D1CFBBE4E2738787738787738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387877F99953D3E3026231E2A2622
2A26221F211D1D191B2C23192C262239342F342F2A2E29252D2C2B37312B302C2323282B
1E292728251D38342B39372F292926302B22342B213834253F3229463A2B5646334C4335
3C312940302946382E3837322F2722261A151F161317131011100B0F0B0C0C0708080707
0807080808081B17122A1C179FB8B6778F8E738787738787738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387877387874D535D2F2B28342F2A
2D2E292E292517151026231E36343038332F3B38333F3C364642353F3F3330352D272624
291E17271D1D29201D2C262222202125242430262132261B2B231F3531283330272C2A21
383227322B202D2E282C231E2921191A16131E1D1A11110C13100C100C0C0D0808080808
09080822181218121272665FB0CBC7738787738787738787738787738787738787738787
738787738787738787738787
73878773878773878773878773878773878773878773878773878778878C382F292D2823
2B26222C2622312B263C342E39342F3A37322E2B272B27242F211F39241F31211A272320
1D1B182526231B17141F222022232122201C1B15131719171715141813121919151B1B16
1C1B16171212191312161311191513121310100F0B0D0A0B100B0C100C0C080808080808
22181D221813352D27C1E0D898BEBD738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787778F8B5D6865332F2A
2C2823322D292D28243D3A3426221D2F2D29231F1B2E2A26413A2E2E2F2A252725292824
28231E3A2F2A20191A22231F201713211613191310141410181410221915211915171210
16121016131020191519151119141012100B14100C100C0C110C0C080708080708120C0D
2B221C281C16C9E9E4BDE0DB738787738787738787738787738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387877387877387876D747B352622
342D29322D292C27231F201C312F2B403C362D2E2927231E30231B1D191623201B25211D
18171D1E201D1B18182519151A131914141115151113100C17151116151114141011100B
0E0B0C11100C1A151011100B0E0B0C12100C151112100C0C080708110C0C1D18122F241D
2B1C17C6E9E3C6EDE7738787738787738787738787738787738787738787738787738787
738787738787738787738787
7387877387877387877387877387877387877387877387877387877387877A9490454840
2E2B262F2B272C2723342E2A2F2E292B2925231F1B211B18201C1916131027221E1E1819
1F18191C140F1A13181110100C0B0B1210101310110F0B0C1410110F0B0C1310110F0B0C
1511121A17121411120F0B0C07070807070707070707070715121218130D100C0C1B0F0B
B7CDC9C4E8E2738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
73878773878773878773878773878773878773878773878773878773878773878790ADAC
5E5D562B25202A26222B2D282B2C2837322D2E292A251915241E191715111A141014130F
1A14100E0B0B0D0B0B121010151111110C0C141111100C0C151111100C0C2A1C16090808
1411111916111411110807070807080E08081812121913131712122A1B173B2A1D7C593E
B8D1C8778F8E738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
90ADAC5F564F34332D26221D36302C38322D36322D25251F2926211D151B1410121C1511
1410111816111B1812161212100C0C100C0C100C0C100C0C100C0C1916111411112C3342
393C3C22181E100B0C1611111E18131E19131713123028212E231D2A1C174D362CB6DCDF
9CCBD0738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
73878799BAB75F575040373228231E2628243736313A342F33251B261F191A1711141111
0F0B0C14100C1310110F0B0C100C0C151212110C0C151212110C0C100C0C2D32332A212C
3F362E4840363D34314C4139362C241B171229211B29201B342F2A4D3428C4DFDAA9D5D5
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
7387877084858CACAA544637413B3437302B3B37323936313D3B3625201C271F1B392F29
2F2C242319131A1712151211161212110C0C100C0C1A161C1512121B1712131010201F19
2B27200C0B0D0D0E0C0F100D0C0C0D191310271F1B30241A5D432FA1ACB1A5D1D4738B8B
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
73878773878773878792B5B555574A25211C2C292542403B474B46403E3728211C1E1819
211613322A252B2923161212100C0C1F1B21221E242C2A22201D213E352F1C181E474039
332B2C322B263B312A3329233A30294F473738312A684D39C0DBDAA8D9DB7F9C96738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
73878773878773878773878792B0B0ACBBC6504B432E2A26292724323B434B4A465B564D
5C6055353030282E3048495968665D413634302E38342C2D4746543B342E312A243E372F
342B263A28233A281D352E29493D316448353B281DAFD3D29CCDD2738B8B738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
7387877387877387877387877387877C9692A8CEC65C5A623F3C372E353B4C5051495053
414642474A445B5E5B5A5147464037342F2A413C32312A27241F1925211B36322D322D29
3F2B214A33284B3C305B4A3E462E24504B51ABDDE5B5E0DF738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
737C7D738485738787738787738787738787738787738787738787738787738787738787
73878773878773878773878773878773878773878792B0A9CDF9ECC5DBE0565563545154
777B8C6F6B6F5B4E4847423C45443F5B525365595257524A6D615659524457534B655A52
4F4D40424A3E2E2C29717A88B6EAEEC5FFFB9CC2BD738787738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738D8D738B8B738787738787738787738787738787738787738787738787738787738787
738787738787738787738787738787738787738787738787738787778F8B9ABAACBFE5D4
A6CEC38DA5ADA7C7C792A4B7565E724852653D413F3E403D41413D40413F403E3B342E26
323229A6BEBFD0FCFAC1F0E887A9A2738787738787738787738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787778F897B968D7C9A949EC1B0BBDFCBBEE4D6C2E2DEC2EBE7C2EDE9C4F0EBCBF9F6
CFFFFFADD1D2738B8B738787738787738787738787738787738787738787738787738787
738787738787738787738787738787738787738787738787738787738787738787738787
738787738787738787738787
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?oooeUcQhL4KFUJ17AfJ0=cMFd4Lg]b17=cJ`AcNg8;LgU`17=c
J`AcMFH4KFmQ16m[G@AYH5<4Jf9E0fEMD11WGU04IeU;0f5JA`ASFTd4HeY716=JC@AiUi/?LhN717>1
P@AcR8PSLhN75Oooo`005?oooeUcQhL4KFUJ17AfJ0=cMFd4Lg]b17=cJ`AcNg8;LgU`17=cJ`AcMFH4
KFmQ16m[G@AYH5<4Jf9E0fEMD11WGU04IeU;0f5JA`ASFTd4HeY716=JC@AiUi/?LhN717>1P@AcR8PS
LhN75Oooo`005?oooeUcQhL4KFUJ17AfJ0=cMFd4Lg]b17=cJ`AcNg8;LgU`17=cJ`AcMFH4KFmQ16m[
G@AYH5<4Jf9E0fEMD11WGU04IeU;0f5JA`ASFTd4HeY716=JC@AiUi/?LhN717>1P@AcR8PSLhN75Ooo
o`005?ooo`AcQhL4Lgio17>4Q@AcQhL4Lgio0g>4QB=cQhL4Lgio17>4QAMcQhL4MG5P17MhLP=cMFL4
Lg]`17=cJ`AcNg84LgU`17=aH@=[IeL4JFMG16USE0ASFe44GEM<15eEB@APFDd3FeA816ELC`QWGU08
IeM:0f5JC@ASFTh4HeY716=iNPAiXZT?LhN717>9R@AcRh/SLhN75Oooo`005?ooo`AcQhL4Lgio17>4
Q@AcQhL4Lgio0g>4QB=cQhL4Lgio17>4QAMcQhL4MG5P17MhLP=cMFL4Lg]`17=cJ`AcNg84LgU`17=a
H@=[IeL4JFMG16USE0ASFe44GEM<15eEB@APFDd3FeA816ELC`QWGU08IeM:0f5JC@ASFTh4HeY716=i
NPAiXZT?LhN717>9R@AcRh/SLhN75Oooo`005?ooo`AcQhL4Lgio17>4Q@AcQhL4Lgio0g>4QB=cQhL4
Lgio17>4QAMcQhL4MG5P17MhLP=cMFL4Lg]`17=cJ`AcNg84LgU`17=aH@=[IeL4JFMG16USE0ASFe44
GEM<15eEB@APFDd3FeA816ELC`QWGU08IeM:0f5JC@ASFTh4HeY716=iNPAiXZT?LhN717>9R@AcRh/S
LhN75Oooo`005?ooo`AcQhL4Lgio17>4Q@AcQhL4Lgio0g>4QB=cQhL4Lgio17>4QAMcQhL4MG5P17Mh
LP=cMFL4Lg]`17=cJ`AcNg84LgU`17=aH@=[IeL4JFMG16USE0ASFe44GEM<15eEB@APFDd3FeA816EL
C`QWGU08IeM:0f5JC@ASFTh4HeY716=iNPAiXZT?LhN717>9R@AcRh/SLhN75Oooo`005?ooo`AcQhL4
LhV917>2P`AcQ8D4LhV90g>;R`AcQhL4Lgio17>4Q@AcOWl4LhB53g>7Q`AcRHT4Lh^;5g>7Q`A[IeP4
L79S0g=eK0AcLVh4LgU`17=eK0AcKfL4JfUL0eAUH0APGUD4IE1<15mBB0ASGU44IfAF16MWF@=YHU<4
HeY<25eEB@AMEdX4GEY60emJB`ASFT`4HeY=18>W[`B3X:8CLhN717=nO`AcQ8DOLhN75Oooo`005?oo
o`AcQhL4LhV917>2P`AcQ8D4LhV90g>;R`AcQhL4Lgio17>4Q@AcOWl4LhB53g>7Q`AcRHT4Lh^;5g>7
Q`A[IeP4L79S0g=eK0AcLVh4LgU`17=eK0AcKfL4JfUL0eAUH0APGUD4IE1<15mBB0ASGU44IfAF16MW
F@=YHU<4HeY<25eEB@AMEdX4GEY60emJB`ASFT`4HeY=18>W[`B3X:8CLhN717=nO`AcQ8DOLhN75Ooo
o`005?ooo`AcQhL4LhV917>2P`AcQ8D4LhV90g>;R`AcQhL4Lgio17>4Q@AcOWl4LhB53g>7Q`AcRHT4
Lh^;5g>7Q`A[IeP4L79S0g=eK0AcLVh4LgU`17=eK0AcKfL4JfUL0eAUH0APGUD4IE1<15mBB0ASGU44
IfAF16MWF@=YHU<4HeY<25eEB@AMEdX4GEY60emJB`ASFT`4HeY=18>W[`B3X:8CLhN717=nO`AcQ8DO
LhN75Oooo`005?ooo`AcQhL4LhV917>2P`AcQ8D4LhV90g>;R`AcQhL4Lgio17>4Q@AcOWl4LhB53g>7
Q`AcRHT4Lh^;5g>7Q`A[IeP4L79S0g=eK0AcLVh4LgU`17=eK0AcKfL4JfUL0eAUH0APGUD4IE1<15mB
B0ASGU44IfAF16MWF@=YHU<4HeY<25eEB@AMEdX4GEY60emJB`ASFT`4HeY=18>W[`B3X:8CLhN717=n
O`AcQ8DOLhN75Oooo`005?ooo`QcQhL4Lh6117>8R0]cQhL4LhV917>;R`AcRHT4Lh^;;W>7Q`AeJEX4
MgIa0g=eK`AcMF`4Lg9Z17=aJ@AcMF@4MGM^0h1mMPB0NVT4OFm]179YF`AbGU04LUUC179IE@=YCDT4
HEE:36=JC0ASFTd3JV5E16EKC@ASFT`4NINK5g>7Q`AcRHT4Lh^;7g>7QaGoool001Coool8LhN717>1
P@AcR8P;LhN717>9R@AcRh/4LhV917>;RbicQhL4MFUJ17MfL@=cMFl4LgE/17=bJPAcLFT4LgET17Eg
KP>0OGH4P7YY17e_K@AbJE/4LUi@179ID`AbFED3JDe9165EBPaSFT`4HeY=0fYQE@AUFdd4HeY<17VG
VaMcQhL4LhV917>;RamcQhLEoooo000Doooo27>7Q`AcPH44LhR82g>7Q`AcRHT4Lh^;17>9R@AcRh/^
LhN717EYFPAgMW43LgE_17=eK0AcLVX4Lg5Y17=eI0AeMfh3P7ef181jJ@AmKfd4LVUK179ND0AbFE<4
LUUE0fU=B@AQEDX<HeY<16=JC@=ZHED4IE]=16=JC0AiUi/GLhN717>9R@AcRh/OLhN75Oooo`005?oo
o`QcQhL4Lh6117>8R0]cQhL4LhV917>;R`AcRHT4Lh^;;W>7Q`AeJEX4MgIa0g=eK`AcMF`4Lg9Z17=a
J@AcMF@4MGM^0h1mMPB0NVT4OFm]179YF`AbGU04LUUC179IE@=YCDT4HEE:36=JC0ASFTd3JV5E16EK
C@ASFT`4NINK5g>7Q`AcRHT4Lh^;7g>7QaGoool001Coool8LhN717>9R@AcRh]9LhN717=aH0AcN6P3
LgER17=eJPQcMF`4LgE^17=mM`=cOgD4MGUb16mgIPA]KF04MFiQ17EaH@A]HUH3MG5P16eID0A/D4`4
K6IR16EMD0AZFT`3JUQ;165GBPAZJEX4O9bO?W>7QaGoool001Coool8LhN717>9R@AcRh]9LhN717=a
H0AcN6P3LgER17=eJPQcMF`4LgE^17=mM`=cOgD4MGUb16mgIPA]KF04MFiQ17EaH@A]HUH3MG5P16eI
D0A/D4`4K6IR16EMD0AZFT`3JUQ;165GBPAZJEX4O9bO?W>7QaGoool001Coool8LhN717>9R@AcRh]9
LhN717=aH0AcN6P3LgER17=eJPQcMF`4LgE^17=mM`=cOgD4MGUb16mgIPA]KF04MFiQ17EaH@A]HUH3
MG5P16eID0A/D4`4K6IR16EMD0AZFT`3JUQ;165GBPAZJEX4O9bO?W>7QaGoool001Coool8LhN717>9
R@AcRh]9LhN717=aH0AcN6P3LgER17=eJPQcMF`4LgE^17=mM`=cOgD4MGUb16mgIPA]KF04MFiQ17Ea
H@A]HUH3MG5P16eID0A/D4`4K6IR16EMD0AZFT`3JUQ;165GBPAZJEX4O9bO?W>7QaGoool001CooomI
LhN717=_G`AcMFL3LgE_17=eI`AcMFX4LgE/17=mL`AcMF`3LfmW17=iL0AeNG84NGm_175fH`A_JF84
LF]M0f]UE@AZGUD4JFQE16MKB@AYHUX4Hee@0eeJC0AOFT`4NHJ617fNYQ]cQhL4Lgio17>4QA]cQhLE
oooo000DooooFG>7Q`AcKel4LgEW0g=eK`AcMFL4LgEZ17=eK0AcOG<4LgE/0g=_I`AcNG04MGUb17Uo
K`AaMV<4KfUR175[G@=[IED4JUiE16UXE@AWFdT4JF9J16=MD0=MFT`4GeY<17V6QPAmWZHKLhN717=n
O`AcQ8DKLhN75Oooo`005?oooeUcQhL4LfmO17=eI`=cMFl4LgEW17=eJPAcMF`4Lgec17=eK0=cKfL4
LgU`17EiLPAiOfl4LGIS16mYHPAaJed3JfEE16YNE@AYJ5D4Ie]916URFPASGE03GEY<15mJC0AiQXH4
OIjV6g>7Q`AcOWl4LhB56g>7QaGoool001CooomELhN715]:@0A[GDd4LgE_0g=eI`AcMF@4LgE]17=m
L`AcMF`4LgU`0g=oM@AcOG<4Lg=[17=eKPAeLFD4NG1P175YF@=aJE/4KEmF16eND0AYFD/4GeI815mD
A@=ZFT`4IEY<17B?U@AdTiHKLhN717>9R@AcRh/7LhN717=nO`AcO7d4LhB527>7QaGoool001CooomE
LhN715]:@0A[GDd4LgE_0g=eI`AcMF@4LgE]17=mL`AcMF`4LgU`0g=oM@AcOG<4Lg=[17=eKPAeLFD4
NG1P175YF@=aJE/4KEmF16eND0AYFD/4GeI815mDA@=ZFT`4IEY<17B?U@AdTiHKLhN717>9R@AcRh/7
LhN717=nO`AcO7d4LhB527>7QaGoool001CooomELhN715]:@0A[GDd4LgE_0g=eI`AcMF@4LgE]17=m
L`AcMF`4LgU`0g=oM@AcOG<4Lg=[17=eKPAeLFD4NG1P175YF@=aJE/4KEmF16eND0AYFD/4GeI815mD
A@=ZFT`4IEY<17B?U@AdTiHKLhN717>9R@AcRh/7LhN717=nO`AcO7d4LhB527>7QaGoool001CooomE
LhN715]:@0A[GDd4LgE_0g=eI`AcMF@4LgE]17=mL`AcMF`4LgU`0g=oM@AcOG<4Lg=[17=eKPAeLFD4
NG1P175YF@=aJE/4KEmF16eND0AYFD/4GeI815mDA@=ZFT`4IEY<17B?U@AdTiHKLhN717>9R@AcRh/7
LhN717=nO`AcO7d4LhB527>7QaGoool001CooomALhN7124O6PACCSl4OH5^17=eK@=cMFh4LgEa17=e
K`AcNg84Lg=[17=bHP=cMf`8Lg5Y17=eI0AcMfD4JfAO16]SF@=_GeX4JF5=16=IB0ASGU04JE]=16EJ
C0=XJEX4JFAE17jOXPAgShhZLhN717>9R@AcSHd4Lh^;27>7QaGoool001CooomALhN7124O6PACCSl4
OH5^17=eK@=cMFh4LgEa17=eK`AcNg84Lg=[17=bHP=cMf`8Lg5Y17=eI0AcMfD4JfAO16]SF@=_GeX4
JF5=16=IB0ASGU04JE]=16EJC0=XJEX4JFAE17jOXPAgShhZLhN717>9R@AcSHd4Lh^;27>7QaGoool0
01CooomALhN7124O6PACCSl4OH5^17=eK@=cMFh4LgEa17=eK`AcNg84Lg=[17=bHP=cMf`8Lg5Y17=e
I0AcMfD4JfAO16]SF@=_GeX4JF5=16=IB0ASGU04JE]=16EJC0=XJEX4JFAE17jOXPAgShhZLhN717>9
R@AcSHd4Lh^;27>7QaGoool001CooomALhN7124O6PACCSl4OH5^17=eK@=cMFh4LgEa17=eK`AcNg84
Lg=[17=bHP=cMf`8Lg5Y17=eI0AcMfD4JfAO16]SF@=_GeX4JF5=16=IB0ASGU04JE]=16EJC0=XJEX4
JFAE17jOXPAgShhZLhN717>9R@AcSHd4Lh^;27>7QaGoool001Coool8LhN717=nO`AcQ8DmLhN715AH
H0@C2`/4O7Ib17MhK0AcOGD3LgM^17=mL`AcMfh4Lg9Z17=iL0AcOgL3LgE_17=aH@AcGE/4JeM>165@
A`AYFdl4KfMG0fMYFPAOGDl4JeeB16UQD`AOFDD4GeY;0f5FB@AMDdL4MI>G@W>7QaGoool001Coool8
LhN717=nO`AcQ8DmLhN715AHH0@C2`/4O7Ib17MhK0AcOGD3LgM^17=mL`AcMfh4Lg9Z17=iL0AcOgL3
LgE_17=aH@AcGE/4JeM>165@A`AYFdl4KfMG0fMYFPAOGDl4JeeB16UQD`AOFDD4GeY;0f5FB@AMDdL4
MI>G@W>7QaGoool001Coool8LhN717=nO`AcQ8DmLhN715AHH0@C2`/4O7Ib17MhK0AcOGD3LgM^17=m
L`AcMfh4Lg9Z17=iL0AcOgL3LgE_17=aH@AcGE/4JeM>165@A`AYFdl4KfMG0fMYFPAOGDl4JeeB16UQ
D`AOFDD4GeY;0f5FB@AMDdL4MI>G@W>7QaGoool001Coool8LhN717=nO`AcQ8DmLhN715AHH0@C2`/4
O7Ib17MhK0AcOGD3LgM^17=mL`AcMfh4Lg9Z17=iL0AcOgL3LgE_17=aH@AcGE/4JeM>165@A`AYFdl4
KfMG0fMYFPAOGDl4JeeB16UQD`AOFDD4GeY;0f5FB@AMDdL4MI>G@W>7QaGoool001Coool8LhN717>9
R@AcPX<4LhB5=G>7Q`AjShl44`l:17ihG0Bo_9P4LgE/17=bKP=cLFT4Lg9Z17=aJ@AcMF`4Lg9Z17=g
KP=cLf/4JfeO16UQF@A[IeH4JF5D16UQD`AUGU43Iei:16EJC0ATEdX4HeE916UGB`A/FTh3IEY<16YQ
D`AdMg<4L7ek?W>7QaGoool001Coool8LhN717>9R@AcPX<4LhB5=G>7Q`AjShl44`l:17ihG0Bo_9P4
LgE/17=bKP=cLFT4Lg9Z17=aJ@AcMF`4Lg9Z17=gKP=cLf/4JfeO16UQF@A[IeH4JF5D16UQD`AUGU43
Iei:16EJC0ATEdX4HeE916UGB`A/FTh3IEY<16YQD`AdMg<4L7ek?W>7QaGoool001Coool8LhN717>9
R@AcPX<4LhB5=G>7Q`AjShl44`l:17ihG0Bo_9P4LgE/17=bKP=cLFT4Lg9Z17=aJ@AcMF`4Lg9Z17=g
KP=cLf/4JfeO16UQF@A[IeH4JF5D16UQD`AUGU43Iei:16EJC0ATEdX4HeE916UGB`A/FTh3IEY<16YQ
D`AdMg<4L7ek?W>7QaGoool001Coool8LhN717>9R@AcPX<4LhB5=G>7Q`AjShl44`l:17ihG0Bo_9P4
LgE/17=bKP=cLFT4Lg9Z17=aJ@AcMF`4Lg9Z17=gKP=cLf/4JfeO16UQF@A[IeH4JF5D16UQD`AUGU43
Iei:16EJC0ATEdX4HeE916UGB`A/FTh3IEY<16YQD`AdMg<4L7ek?W>7QaGoool001Coool8LhN717=n
O`AcQhL4Lh^;=G>7Q`@=2PL4KVYM1<2kZ@AgN6`4LgE]1g=eK0AcMF@4LgEZ17=eK0AcOG<4LgE/0g=a
J@A]?Cl4KcLl16La=0AW<3@4Jc8f16]AB@=SDdP4He=916M?A0AOF4@4IEY;16MJC0=QFTH4J51315];
?PA]OW`ZLhN717=nO`AcQ8D<LhN75Oooo`005?ooo`QcQhL4Lgio17>7Q`AcRh/eLhN710d:1`A^JUd4
`;^Y17MhK0AcMFd7LgE/17=eI0AcMFX4LgE/17=mL`AcMF`3Lg5Y16dm?`A_=c`4Ic4d16L`=0A[<SH4
Je590f=CB0ASDdT4Idm415mHA0AUFT/4IeY<0f5JAPAXD4<4Fd/n16enO2YcQhL4Lgio17>4Q@acQhLE
oooo000Doooo27>7Q`AcOWl4LhN717>;RcEcQhL43@X716iZG@C0^jT4MgQ/17=eK@McMF`4LgET17=e
JPAcMF`4Lgec17=eK0=cLFT4KCdo16lg?0AW<C@4Ic0d16/b=PA[DDT3He=816=CB@AWCd@4GeQ416EJ
B`AWFT`3HEY616Q@@`AKBch4KGil:W>7Q`AcOWl4LhB537>7QaGoool001Coool8LhN717=nO`AcQhL4
Lh^;=G>7Q`@=2PL4KVYM1<2kZ@AgN6`4LgE]1g=eK0AcMF@4LgEZ17=eK0AcOG<4LgE/0g=aJ@A]?Cl4
KcLl16La=0AW<3@4Jc8f16]AB@=SDdP4He=916M?A0AOF4@4IEY;16MJC0=QFTH4J51315];?PA]OW`Z
LhN717=nO`AcQ8D<LhN75Oooo`005?ooo`QcQhL4LhV917>;RcIcQhL3E5QJ18b:P`Bk]:@4Lg5Y17=e
IPAcMFd4LgE/0g=]G@AcJe/4Lf]L17=bJ0AcLVX4LeYJ0g=GF@A]A4<4Id<i15la9`AX@ch4Hd0g16Po
?@=N?3/4GDe315eJAPAOEDP4J5Q=16MJC0=YFTd4JUA916URE0ATDD84Jg1[9W>7Q`AcRHT4Lh^;37>7
QaGoool001Coool8LhN717>9R@AcRh/fLhN70eAHFPB<RX<4^kBT17=aJ@AcMFH4LgE]17=eK0=cKEd4
Lf]K17=[G0AcLVP4Lg9Z17=JFP=cEeT4KDA316M3>@AO<BL4J4<n16=0=`AX?cd3GS`k15e=@`AMFTH4
GeE816QHC@AWFT`3JEY=16YDB@AYHU@4I55216]`JbIcQhL4LhV917>;R`acQhLEoooo000Doooo27>7
Q`AcRHT4Lh^;=W>7Q`=DF5X4S8Z31;^dY0AcLFT4LgEV17=eK@AcMF`3LfeM17=[F`AcJe`4Lg9X17=b
JPAcFUX3LeMI16e4@`AW@cT4Gc4W16Q3?PAS@3L4J3lm0ehl>`AMCD<4GEY615mEB0AXF4d4IeY<0fUJ
C@AZE4T4JF9D16AA@PA[L6/VLhN717>9R@AcRh/<LhN75Oooo`005?ooodIcQhL33`h=151=?PAdLUd4
LgER17=eI0AcMFd4LgET0f]WF0AYGU<4L7AV17=hL0AcIEH4Jchk0f4a:`AIAcd4BC@U15aeG`A]PFh4
GSDZ15//90=S>S84IDHo16=HC@ASE3`4HE]416EJB`=WFT`4Iea=16MKC@AWG4l4N8Ao17>2P3IcQhLE
oooo000DooooAW>7Q`<?3Pd4D4dn17AbG@AcMF84LgET17=eK@AcMF@3JfMH16UND`A`M6H4LgQ`17=U
EPA[?S/3HC4[15U7?@A9=2D4G7EO16f1KPAN=BX4Fb`T0f<j<PAUASl4HeQ=16=D?0AQFd@4IEY;0fMJ
C0AWG4d4Ie]=16MLC`AhQ7l4Lh:0=W>7QaGoool001Cooom6LhN70`l>3@A@CCh4M79M17=eHPAcMF@4
LgE]17=eI0=[IeP4JEiC171dIPAcN704LfEF16/n>`=Q<B/4FDLm14Td9@ALMEl4KH5^15he:PAK;2@3
HcXb16E6?`ASF4d4He@l165KA0AUFT/3IeY<16MLC@AWFdd4Iea?17R4O`AcPX0fLhN75Oooo`005?oo
odIcQhL33`h=151=?PAdLUd4LgER17=eI0AcMFd4LgET0f]WF0AYGU<4L7AV17=hL0AcIEH4Jchk0f4a
:`AIAcd4BC@U15aeG`A]PFh4GSDZ15//90=S>S84IDHo16=HC@ASE3`4HE]416EJB`=WFT`4Iea=16MK
C@AWG4l4N8Ao17>2P3IcQhLEoooo000Doooo47>7Q`AcOWl3LhB5:g>7Q`@k=cX3GDTj1;JYS0AgN784
JfEK171hL`AcMg44LfEH0fIFA@AMAC/4KeUL16<]<@@J0`<4AShk0fMHC0AeLfP4RkR`185>A`AH=bl4
AD<^14mVE`<f>2T4Db/T15a6>`AQD3X4JU=916YOE0=_JU@4JEe=16MQD`AWFT`4H51316]XH0AcPX0b
LhN75Oooo`005?oooa1cQhL4Lgio0g>4QB]cQhL4>cLj0ee9>PBfZH`4MgQb16]UF`A`N7<4LgMa17=U
F0=VETD4GDDk16mIG0AS;C446P<314Hn>`=WF4`4MG=X18^h/0B1CTL4F3L_14E3;PA?IUL3=SPY15<[
90ALAS/4HE0j16YCB@AZGe@3KfYD16UMC@AWHE<4IeY<161@@`A[J604Lh:0<W>7QaGoool001Coool@
LhN717=nO`=cQ8D[LhN713/g>P=MBCX4]ZV<17MhLPA[IE/4L7Qc17=gL@AcIEP3IUI515e5>`A_FE`4
Hbda11X30`A6?S/3IeQ<17EcJ0B;^;04PDi715Pg;`A5@bh4CfIG0cHh:@AC:b@4G4Hk165@>PAZDdT4
JUmD0fmZE0AYGDd4If5C16MJC0APD4<4JfQP17>2P39cQhLEoooo000Doooo47>7Q`AcOWl3LhB5:g>7
Q`@k=cX3GDTj1;JYS0AgN784JfEK171hL`AcMg44LfEH0fIFA@AMAC/4KeUL16<]<@@J0`<4AShk0fMH
C0AeLfP4RkR`185>A`AH=bl4AD<^14mVE`<f>2T4Db/T15a6>`AQD3X4JU=916YOE0=_JU@4JEe=16MQ
D`AWFT`4H51316]XH0AcPX0bLhN75Oooo`005?ooo`QcQhL4Lgio17>4Q@AcRHT3Lh^;:g>7Q`@F5A@3
Kg1N18V<P`AcMFL4KF5B17AcK0AcLFT4LfUK0f14=@AK?cD48`T913eIE`BCfl`4/N[M0gnl`0Am]kd4
MiJC16n2K0B4aKX4Sk2`16UkO0<j;RL47ahC13l`9@AREDD4J5I<16mXF@=_IET4KFIC16UKC0AWEdX4
IemA161gS`ATM7h3L8:2;g>7QaGoool001Coool8LhN717=nO`AcQ8D4LhV90g>;Rb]cQhL45QDD0fm`
GPB9S8<4LgEW16eQDPAdLf`4Lg5Y17=YF`=PA3D4Fcle12<92@@mFEL4Tm_<1;7Zg@=o_<04OKNm17NF
T`A_PV`4Q<Fj18n`/0AYNg`3>RhW11lN4`@o<2D4HUE516QFC0A_J5T3KfEI16eVD`AYFd`4IeM:16MO
D@APMhl4I7An0g22PRmcQhLEoooo000Doooo27>7Q`AcOWl4LhB517>9R@=cRh/[LhN711HE50=_L5h4
RHb317=eI`A]HE84M7=/17=aJ@AcJE/3H4@e15/o=@@S2@T4?EUG19?Kc0Baj]d3Okc017fg_@AgUY<4
Kh9/18C5^PB?/;04JG]l0cX^9`@O7Q<4?c0U169EA@AXET`4KfQI0fmUF@A]IU<4JE]<16MGBPAWGe44
H7N?16AdOP=`PX8_LhN75Oooo`005?ooo`QcQhL4Lgio17>4Q@AcRHT3Lh^;:g>7Q`@F5A@3Kg1N18V<
P`AcMFL4KF5B17AcK0AcLFT4LfUK0f14=@AK?cD48`T913eIE`BCfl`4/N[M0gnl`0Am]kd4MiJC16n2
K0B4aKX4Sk2`16UkO0<j;RL47ahC13l`9@AREDD4J5I<16mXF@=_IET4KFIC16UKC0AWEdX4IemA161g
S`ATM7h3L8:2;g>7QaGoool001Coool8LhN717>9R@AcRh/^LhN715]VM`@E3Pd3QX1]17AfIPAcMF@4
MG]/17N0MPAcMF`4Hda10dXn:PA79Q`4;Pl917mDB0AfD484JDHm0g1]I`AcJE<4LfQA16I;@`AZJF/4
HdTl181eI@>3LET4OGi]13<W7PA4;2@4GDQ016YVD@=cLf84KFII16EOD`AWDdL4IeI915mZF`ABEDL3
E5e]16]mPR]cQhLEoooo000Doooo27>7Q`AcRHT4Lh^;;W>7Q`AKIWL45@h=0hJ0K@AdMVH4LgET17Ek
K0AgP7H4LgE/16=<@@=:?RX4AbHL12h?2@AoE4P4MU1216U6?@=`KFL4LfUC17=XD@AVBd<4JVU[16=9
?0B0MFD3Pg5I17enK@@c9ah4A2`T15e8@0AZIU43Lg=R16eVF@AUGe<4Ie=716MFB@AOJU/4DUE70eAM
K@A[OH8[LhN75Oooo`005?ooo`QcQhL4LhV917>;RbicQhL4FfIg11D>3@>6P6d4M7IV17=eI0AeNf`4
Mh1f17=eK0ASC443BShZ14LV70@^3`T4OeA817I@@PAYASd3L6eW17=YD`AcJ544IT]316YYJ`ASBC`4
P7EU0h=aF@AmOVd4<bLN14@/90AMB404JVIA0g=cHPA]IUT4IEmC16MCA`AWETT4GfYK159EA`=DGFd4
Jgf2:g>7QaGoool001Coool8LhN717>9R@AcRh/^LhN715]VM`@E3Pd3QX1]17AfIPAcMF@4MG]/17N0
MPAcMF`4Hda10dXn:PA79Q`4;Pl917mDB0AfD484JDHm0g1]I`AcJE<4LfQA16I;@`AZJF/4HdTl181e
I@>3LET4OGi]13<W7PA4;2@4GDQ016YVD@=cLf84KFII16EOD`AWDdL4IeI915mZF`ABEDL3E5e]16]m
PR]cQhLEoooo000Doooo>W>7Q`@Q7aX40000158l;`>j[i44MgQZ17=UF@AcHEH4Lg1R17=eHPAXDd@3
M6iQ18nTT@B`f;@4/K6T17E_I`AWF583Hdm716H_<@AI=CL4FBTW15hO6`AF7A/4FTm60eHi;PAR@T84
GDHm130?1`A@@3`4KV=A0g1_H@AYH4`4IEI815mIB`AUI5D4JF=D18RDUP=]MX@4MHV5:g>7QaGoool0
01CoooljLhN7124O6P@00004DS`_0kZ_T@AgN6X4LfEI17=QEPAcL684LgER16QCA0=dKV44SjBA1;3H
]0Ba/J@4MFmW16MHDP=SCdL4IRla15Te=`AI:BL4GQlK15HM6`AJCdH3EST^1692@PAMASd4<0l71510
?0A^He43L6mQ16UPC0AUETP4GeU;16ETE@AYHe@4R9BF0fefQ0AeRHD[LhN75Oooo`005?ooocYcQhL4
8AlJ100000AB?2l3^ZnA17MhJPAcIET4Lf5F17=`HPAcMF84J5=40gA^H@B?Y944/=Rd1;6aY0AeKfL4
IeQB0f=?A`AV;c44FCDg15TY9`AN7a/4EQdK15Y?AP=F>Bh4HT9215e6?@@`3`L4D40l16iSD@=`Kf44
JF1<16EFB0AOFD/4IFAE16USE0B8U9H3KGJ417F9QB]cQhLEoooo000Doooo57>7Q`=cOWl4LhB56g>7
Q`AKGfL41@H5110>30BOXI43Ri9m17=]H0AcGf44Jg5W171jJ`AcGF04J5E<0eE3<PAaLV/4Mh1l17=n
M@AeRGX4NiN:0gnDQ`AmVGl4MXE[17b4K0AdRfP4M8AY16ePC`=a?Cd4JCLa15XV6PA@6Q<4DB4H15U:
@@=^HUT4JEi<16EGB`AQDTH4J5I916MKCP@G4@h3EEeH17^<P`A`PX8WLhN75Oooo`005?oooaAcQhL3
Lgio17>4QA]cQhL4FemW10D61@@@3P`4Wj6A0h^BO@AcKF04LemQ16]aI`A`NV/4LeeP16QEC0=E@c84
LG9[17N0O0AcOWD4MHUj17^GRP=oU8L4OIUo17J5J`AlQ6`4M8]X17B4J@A]H4l3LCdm16Tg<@AJ9QX4
D1XC154Q60AIBT43KV9I16UNC0AUEd/4HE9616QFB@AWFdh45a4>0eEMF0AkS8<4L8:29g>7QaGoool0
01CooolDLhN70g=nO`AcQ8DKLhN715]OI`@51PD440h<19nQT@>;TWd4LfeP17=OH@A[LFL4L7Y[17=M
H0AXED`3ED<b175bJ`AgP7`4Lgie17F9NPAkUhX3OiB717fIO`AfQF/4O8A/17B;J0AdQ6T4KF1?0g4m
?@AY=c44FRHJ150J4`AA8AP4FDY10fiRF@AYGT`4IEM;165BAPAXETT4Ie]>11LA3P=EGEP4Nhb31722
PRMcQhLEoooo000Doooo57>7Q`=cOWl4LhB56g>7Q`AKGfL41@H5110>30BOXI43Ri9m17=]H0AcGf44
Jg5W171jJ`AcGF04J5E<0eE3<PAaLV/4Mh1l17=nM@AeRGX4NiN:0gnDQ`AmVGl4MXE[17b4K0AdRfP4
M8AY16ePC`=a?Cd4JCLa15XV6PA@6Q<4DB4H15U:@@=^HUT4JEi<16EGB`AQDTH4J5I916MKCP@G4@h3
EEeH17^<P`A`PX8WLhN75Oooo`005?oooaAcQhL3LhV917>;Ra]cQhL4HW601;:YRPCocZ<4`K6>0g1b
HPAcKf44LgeZ17EYI0AgLFP4Lg]Y16QYE@=YEd/4N7EW171^I@AcNG04LgM^17=bJP=cNG04LemP16eM
E@A_IeX4JF5E16]MDPANFTH3Fe]915]^C`AYLEX4OGiV181dJ`AdKD`3J65A16MOC@AUEd/4HEa716QM
C@AWGe44;c8`0filMPA[PGl4Mhn>9g>7QaGoool001CooolDLhN70g>9R@AcRh/KLhN7169aP0BbZHX4
oljS1<6aSP=`LV84LfmQ17=mJPAeJF@4Mg5X17=kJ@AXJED3JEM;17QeI`A`KVD4LgU`17=gKPAcLVX3
LgU`17=OH0A]GED4KfMJ16UQE@A[GE84GUY60e]KB@AKKTl4JG5J17enIPB0M6/4M6e<0fQQD@AWGdd4
IEM;165LA`AXGDd4IemA12lb<0=^O7H4Jh5o17N?SRMcQhLEoooo000Doooo57>7Q`=cRHT4Lh^;6g>7
Q`ARLH04/ZV:1?o>X`C1/Hh3L79R17=_H@AcOFX4MFUT17MaJ0AcNfT4J6UE0fUGB`AhMFL4L6iU17=i
L0AcMfh4Lg9Z0g=iL0AcGf04KEeE16mWFPAYHED4JeeB15iJAP=KFdT4Ffi?16UaFPAmOVH4P7A[17A]
C0=XHE44Iem=16EGB`AQG4L4J5e=16MOD@@_<S03KWaf16^1O`AgShhWLhN75Oooo`005?oooaAcQhL3
LhV917>;Ra]cQhL4HW601;:YRPCocZ<4`K6>0g1bHPAcKf44LgeZ17EYI0AgLFP4Lg]Y16QYE@=YEd/4
N7EW171^I@AcNG04LgM^17=bJP=cNG04LemP16eME@A_IeX4JF5E16]MDPANFTH3Fe]915]^C`AYLEX4
OGiV181dJ`AdKD`3J65A16MOC@AUEd/4HEa716QMC@AWGe44;c8`0filMPA[PGl4Mhn>9g>7QaGoool0
01CooolfLhN717Y_EPAoMF04MHAo175lK@=/KV44L7EW17=hLPAcNg<4LhQl17=gL`A_KF43L6AE16E@
A0AXIEP4L7Q^17=kLPAcMfh3Lg]b17=jIPA]KET4Ie5516MLB@AKET84CTm40eQ;>`AJA3P4FTPh15Y6
>0ALCSP4K6QE0g1ZG`A[Fe04GTi515m@APAQF4H4GEQ911HE50=iRZ04OYRP:g>7QaGoool001Cooolf
LhN717Y_EPAoMF04MHAo175lK@=/KV44L7EW17=hLPAcNg<4LhQl17=gL`A_KF43L6AE16E@A0AXIEP4
L7Q^17=kLPAcMfh3Lg]b17=jIPA]KET4Ie5516MLB@AKET84CTm40eQ;>`AJA3P4FTPh15Y6>0ALCSP4
K6QE0g1ZG`A[Fe04GTi515m@APAQF4H4GEQ911HE50=iRZ04OYRP:g>7QaGoool001CooolfLhN717Y_
EPAoMF04MHAo175lK@=/KV44L7EW17=hLPAcNg<4LhQl17=gL`A_KF43L6AE16E@A0AXIEP4L7Q^17=k
LPAcMfh3Lg]b17=jIPA]KET4Ie5516MLB@AKET84CTm40eQ;>`AJA3P4FTPh15Y6>0ALCSP4K6QE0g1Z
G`A[Fe04GTi515m@APAQF4H4GEQ911HE50=iRZ04OYRP:g>7QaGoool001CooolfLhN717Y_EPAoMF04
MHAo175lK@=/KV44L7EW17=hLPAcNg<4LhQl17=gL`A_KF43L6AE16E@A0AXIEP4L7Q^17=kLPAcMfh3
Lg]b17=jIPA]KET4Ie5516MLB@AKET84CTm40eQ;>`AJA3P4FTPh15Y6>0ALCSP4K6QE0g1ZG`A[Fe04
GTi515m@APAQF4H4GEQ911HE50=iRZ04OYRP:g>7QaGoool001CooolbLhN716]fM`A`Je/4JfEG165A
?@ABG683KfiV17MfL@AcOGL4Lgme17=mL`AcNg84MF=T0g=WG@A`GTl4MFYL17A_J@AcMfh4LeaL0f]T
F0A`Kel4IUa?16MLCPAK@cT4Fdm71616?0=RC3/4Ge9516IJ?`AQDch4Gd`h179PD`=_G4l4HeA815eA
A@ASEDP4He]>16YQE@@<3@h3IViV16j2N2]cQhLEoooo000Doooo<W>7Q`A[MWL4L6]K16]UE`AQDCd4
DUaR0fm^IPAgMW44Lgeg17=oM@AcOG<4Lg]b17ESI0=cIed4L5i?17EZG0AdKfT4LgM^17=LG0=[I5P4
L6mO16ILC`AWG4h4Fd<i15]?A`APAS`3HT`k15mBA@AVFSl4HE<n15m<>0AbH5<3Kea?16=DB0AMDDD4
HeE816=KCPAZHED430d>0fI^IPA^PWP[LhN75Oooo`005?oooc9cQhL4JgIg171[F`A[IEL4HE4m159L
HP=_KVH4MgIa17=mM`AcOgD4Lgec17=kLPAeHf@3LfMM171NC`AeJU`4M6mY17=gKPAcG5`3JfAH171_
G`AVG4l4Iea>15]3>@AKCdL4H4Hl0f9<>`AODTD4IUXo165C?PAOC3P4LV1C0fmLC`ASE4P4GE5516=E
B0ASFdh4JV5E10`=3P=VKVH4KX9h:g>7QaGoool001CooolbLhN716]fM`A`Je/4JfEG165A?@ABG683
KfiV17MfL@AcOGL4Lgme17=mL`AcNg84MF=T0g=WG@A`GTl4MFYL17A_J@AcMfh4LeaL0f]TF0A`Kel4
IUa?16MLCPAK@cT4Fdm71616?0=RC3/4Ge9516IJ?`AQDch4Gd`h179PD`=_G4l4HeA815eAA@ASEDP4
He]>16YQE@@<3@h3IViV16j2N2]cQhLEoooo000Doooo<W>7Q`AeJUH4MfeP16IJD0AOED/4MGAT0h5S
G@AcLFh4Lg]b37=iL0AcNVH3MGIP16aWD@AYF4T4LW=[17=kLPAcNVl3MH9f17MhM0A_IF44KFII16MO
D0A/HU<4H4Tl0em:?PAOCd<4I5I;16aFCPAkJeh4Mg9S0f=IB`ASEdX4JEa=16EFB@ASFdH4HEQ911DA
3P<V81`4FfM/17>4QBMcQhLEoooo000Doooo<W>7Q`AeJUH4MfeP16IJD0AOED/4MGAT0h5SG@AcLFh4
Lg]b37=iL0AcNVH3MGIP16aWD@AYF4T4LW=[17=kLPAcNVl3MH9f17MhM0A_IF44KFII16MOD0A/HU<4
H4Tl0em:?PAOCd<4I5I;16aFCPAkJeh4Mg9S0f=IB`ASEdX4JEa=16EFB@ASFdH4HEQ911DA3P<V81`4
FfM/17>4QBMcQhLEoooo000Doooo<W>7Q`AeJUH4MfeP16IJD0AOED/4MGAT0h5SG@AcLFh4Lg]b37=i
L0AcNVH3MGIP16aWD@AYF4T4LW=[17=kLPAcNVl3MH9f17MhM0A_IF44KFII16MOD0A/HU<4H4Tl0em:
?PAOCd<4I5I;16aFCPAkJeh4Mg9S0f=IB`ASEdX4JEa=16EFB@ASFdH4HEQ911DA3P<V81`4FfM/17>4
QBMcQhLEoooo000Doooo<W>7Q`AeJUH4MfeP16IJD0AOED/4MGAT0h5SG@AcLFh4Lg]b37=iL0AcNVH3
MGIP16aWD@AYF4T4LW=[17=kLPAcNVl3MH9f17MhM0A_IF44KFII16MOD0A/HU<4H4Tl0em:?PAOCd<4
I5I;16aFCPAkJeh4Mg9S0f=IB`ASEdX4JEa=16EFB@ASFdH4HEQ911DA3P<V81`4FfM/17>4QBMcQhLE
oooo000Doooo<W>7Q`AcKel4JfeN150k:PA^LV<4Ofe^0gMhJPAcP704Lg]b17>2P0AcO7@4LgU`17=c
K@=cNF`4J6AG16]VD`A^NFH4L71V17=aH@=cOG44LgM^16e[F`AQEDH4HeA815mJC0AQEdT3J5e0165=
?@ATE4L4LFAL17MdIPA]IeT3IFIH16MTE@AOFdd4Gea=16=MC`AZJE`4NUdl0edc8`@O61H4AeEH9g>7
QaGoool001CooolbLhN717=_G`A[KEh4D3/Z16ibH`AoKFh3MgQZ17>0L0AcNg84Lh:017=lM0AcNG04
Lg=]0g=iK0AXI5L4JfIC16iiIPA`L6H4Lg5Q0g=mL@AcMfh4KF]K165EAPASE4P4GeY<165GB@=XGD04
HDdm16ADA`AaI5`4MgAV16eWF@=UIUP4IfAE15mKC@AOG4d4Hee?16YYG0AjGC`3GC<S11lH5PA7EEPW
LhN75Oooo`005?oooc9cQhL4LfmO16]]GPA@>bX4KW9S17m]KP=gN6X4Lh1`17=kLPAcPX04Lgad17=i
L0AcLfd3LgU/16QTE`A[IU<4KWUV171`IPAcLF43Lgea17=gKPA]Je/4HEE616=DB0AOFT`4HEM90fQM
@0AQCCd4I5A7175TG0AgM6H4KFMI0fEVF0AWI5D4Ge]=15mLC@ASGDl4JVUL17YM?0=M<b<47aPF14ME
F2McQhLEoooo000Doooo;W>7Q`AcIUX4Hcda158P80AJ@3X4H7Mb16ekJP=cP6X4LgE]17=kLPAcMfd4
LgEZ17=iL0AcLf/3JfeO16e[GPAeOg04Nh=f17MhJ0A[GEH3L6aP17=JF0AVE4@4HDXo15m@A0AHBCh4
HE0h0de1=@AGASd4K6IG171/FPA`Je/4JF5D0fEKCPAWE4P4JEM:16EJAPAZDT@4JV=E16IEBP=oJU/4
coWb1;gPfbMcQhLEoooo000Doooo;W>7Q`AcIUX4Hcda158P80AJ@3X4H7Mb16ekJP=cP6X4LgE]17=k
LPAcMfd4LgEZ17=iL0AcLf/3JfeO16e[GPAeOg04Nh=f17MhJ0A[GEH3L6aP17=JF0AVE4@4HDXo15m@
A0AHBCh4HE0h0de1=@AGASd4K6IG171/FPA`Je/4JF5D0fEKCPAWE4P4JEM:16EJAPAZDT@4JV=E16IE
BP=oJU/4coWb1;gPfbMcQhLEoooo000Doooo;W>7Q`AcIUX4Hcda158P80AJ@3X4H7Mb16ekJP=cP6X4
LgE]17=kLPAcMfd4LgEZ17=iL0AcLf/3JfeO16e[GPAeOg04Nh=f17MhJ0A[GEH3L6aP17=JF0AVE4@4
HDXo15m@A0AHBCh4HE0h0de1=@AGASd4K6IG171/FPA`Je/4JF5D0fEKCPAWE4P4JEM:16EJAPAZDT@4
JV=E16IEBP=oJU/4coWb1;gPfbMcQhLEoooo000Doooo;W>7Q`AcIUX4Hcda158P80AJ@3X4H7Mb16ek
JP=cP6X4LgE]17=kLPAcMfd4LgEZ17=iL0AcLf/3JfeO16e[GPAeOg04Nh=f17MhJ0A[GEH3L6aP17=J
F0AVE4@4HDXo15m@A0AHBCh4HE0h0de1=@AGASd4K6IG171/FPA`Je/4JF5D0fEKCPAWE4P4JEM:16EJ
APAZDT@4JV=E16IEBP=oJU/4coWb1;gPfbMcQhLEoooo000Doooo;W>7Q`AcF5H4J40m160m=`ASI5<4
Nge[185jL@=cOGT4LgMa17=kLPQcNG04Lg5Y17=aH@=]Keh4Mf]M175bI0AdMW44Lgei17EnM`=gP7L4
Lf]L16QSDPANDTL4F4i115E7>`ADAcd3GTm617I_G@AgLV44KfeO171ZG@AYHE@3IEe@16MIB`AWDT`4
JE1=16=BB@AUIV04FT@d0f5BA0B2XjD4MHV99g>7QaGoool001Coool^LhN717=HEPAX@3d4H3dg16=T
D`AkOF/4PGYa0g=mN@AcMg44Lg]b27=iL0AcLFT4Lg5Q0fe_GPAgJed4LG9T17AfL@AcOGT4MGig0gN0
M`AcJe`4J6=B15iBA`AHCT44EDLk15A7?@=NCdH4MVmM17MbH@A_KEl4L6YM16UQE0=UGE04IeU;16MB
C0AYD4d4He9916EVH0AJA3@3HE9418:SY@AeRHTWLhN75Oooo`005?ooobicQhL4LeQF16Q0?@AP?CL4
HfAC17]mJ`B1NW43Lgei17=gL@AcNg88LgU`17=aJ@AcLF43KFmN17M[G@AaLV@4M7Ia17=mN@AeOWL3
Mh1g17=[G0AXHe84GU9715Q>@@AEAc/4E4Lm0ei?APAfKed4Mg9Q16m]G`A`JUd4JF5D0fEMD0AWFD/4
Ie9<16U@C@ASDTT4IFIP15Y4=0=QDT@4PZ>U17F9RBMcQhLEoooo000Doooo;W>7Q`AcF5H4J40m160m
=`ASI5<4Nge[185jL@=cOGT4LgMa17=kLPQcNG04Lg5Y17=aH@=]Keh4Mf]M175bI0AdMW44Lgei17En
M`=gP7L4Lf]L16QSDPANDTL4F4i115E7>`ADAcd3GTm617I_G@AgLV44KfeO171ZG@AYHE@3IEe@16MI
B`AWDT`4JE1=16=BB@AUIV04FT@d0f5BA0B2XjD4MHV99g>7QaGoool001Coool[LhN70g=]H0AcIe44
J5e915UA>@AXJeH4OX9a17MhL0McNg84LgE/17=_I`A[IeP4L6mM17=MG@=]HET4K61E16]XF`AdM6d4
Lg9R17=aI`=cMF`4Lf5R16Q@A`APCT<4GTm2165BA0AMFdd3J6A=16aUE@A]I5H4LfQK16]ODPAWF4`3
IE]>16MAA@AWDT@4GeE415mMAPAXJ5h4JeE80fQRE@AHIf/4IG=f9g>7QaGoool001Coool[LhN70g=]
H0AcIe44J5e915UA>@AXJeH4OX9a17MhL0McNg84LgE/17=_I`A[IeP4L6mM17=MG@=]HET4K61E16]X
F`AdM6d4Lg9R17=aI`=cMF`4Lf5R16Q@A`APCT<4GTm2165BA0AMFdd3J6A=16aUE@A]I5H4LfQK16]O
DPAWF4`3IE]>16MAA@AWDT@4GeE415mMAPAXJ5h4JeE80fQRE@AHIf/4IG=f9g>7QaGoool001Coool[
LhN70g=]H0AcIe44J5e915UA>@AXJeH4OX9a17MhL0McNg84LgE/17=_I`A[IeP4L6mM17=MG@=]HET4
K61E16]XF`AdM6d4Lg9R17=aI`=cMF`4Lf5R16Q@A`APCT<4GTm2165BA0AMFdd3J6A=16aUE@A]I5H4
LfQK16]ODPAWF4`3IE]>16MAA@AWDT@4GeE415mMAPAXJ5h4JeE80fQRE@AHIf/4IG=f9g>7QaGoool0
01Coool[LhN70g=]H0AcIe44J5e915UA>@AXJeH4OX9a17MhL0McNg84LgE/17=_I`A[IeP4L6mM17=M
G@=]HET4K61E16]XF`AdM6d4Lg9R17=aI`=cMF`4Lf5R16Q@A`APCT<4GTm2165BA0AMFdd3J6A=16aU
E@A]I5H4LfQK16]ODPAWF4`3IE]>16MAA@AWDT@4GeE415mMAPAXJ5h4JeE80fQRE@AHIf/4IG=f9g>7
QaGoool001Coool[LhN70f=??0A:<2H49R0J13Hc:`A[KV<4NX1`17=eK@=cLVX4LfmW17=aH@AcKE/4
KFeM16aNFPAQGE43JFEJ16mdI`A_NVX4M7YY17=eK0AcMFl3LgE/16]cH0AVHDh4H5E815i?@PAOD4<4
J5I90fYKCPAaGeX4KfAG16UQD`AWIeX4JfIH0fEPDPAWHU<4Gf1A15mFB@ASDdh4J6=O15Pb8P=UH584
ID8c17UoNBMcQhLEoooo000Doooo:g>7Q`=SCc`4BS0V12HP6P@f<b/4JfiS17Z0L0AcMFd3Lg9Z17=_
I`AcLF44LfeK16e]G@A/GUX4HEeA0fUUFPA_M6L4KgYZ17AjJ@AcMF`4LgE_0g=eK0A[Lf04IV5>161E
B0ANCd84Ge1316QFB@=ZFdh4LEmJ16mTE`AYHE<4IfMJ16]VF0=UH584If9C15mPD@AOETT4He=>16QS
G`AH<R83IF1B16E2<`AiOgTWLhN75Oooo`005?ooob]cQhL3Hdll14X`9P@V81X4=S<[16]^H`AjP704
LgE]0g=bJPAcKfL4Lg5Q17=]F`A]KEd4K5iJ165MD@=YIEX4KgAW16mjJPAdNVT4LgE/17=eK`=cMF`4
Jg=P16IQCPAPEDP4GTm215m@@`AXETT3JU]>175OFPA_I5L4JF5C16MWFPA[IUP3IF1B16MRD`AOH544
GeI916=CCPAXHel4F38R0fEPDPAU@S<4NGmi9g>7QaGoool001Coool[LhN70f=??0A:<2H49R0J13Hc
:`A[KV<4NX1`17=eK@=cLVX4LfmW17=aH@AcKE/4KFeM16aNFPAQGE43JFEJ16mdI`A_NVX4M7YY17=e
K0AcMFl3LgE/16]cH0AVHDh4H5E815i?@PAOD4<4J5I90fYKCPAaGeX4KfAG16UQD`AWIeX4JfIH0fEP
DPAWHU<4Gf1A15mFB@ASDdh4J6=O15Pb8P=UH584ID8c17UoNBMcQhLEoooo000Doooo:g>7Q`=P?Rh4
6a@=12HR7`@U7al4HVEL17IiL`AcMFl3LgET17=eHPAcMF`4LgMc17EjMPAiOgP4LfeU0f]HDPAMDDD4
JV1E16a/G`A`LV`4LgE/0g=eI0A]GeP4HDm515I4A@ALC3`4F4Xk169DA`=ZHU@4J5Y;161KC0AXFE<4
He56161EB@=KE4P4GEE915mGBPASE4L4HeE=165HB0ACBC03FE<n15e1>`AiWJ8WLhN75Oooo`005?oo
ob]cQhL3H3h^11/D3@@V8Ql49AlO169UG0AfNG<4LgE_0g=eI0AcMF84LgE/17=gL`AeNWH4NGmh17=]
I@=[F584GE5516YPE@A/K5l4L79/17=eK0=cMF@4KEmH165?A@AFA4D4G4`l15Q:>`ARE4L3JV9D16QJ
B`APFd`4J5UC16=AAPAPEDT3FeA815eEB@AOEdX4HeA716=EC@AQF4P4DdT`0eUC?PAM@C/4NIfR9g>7
QaGoool001Coool[LhN70f0n;P@K50d49R8O12DO7`ARIE`4MWUc17=eK`=cMF@4LgER17=eK0AcMg<4
MGYf17UoN0AcKFD3JeQB15eAA@AZH5D4K6aO171bK0AcMF`3LgET16eOF0AQCdD4ETA515a<?0AHBS/4
HUA70fYRE0AXFT/4H5]<16QID`ASDDH4H5E90e]DB0AMEDT4GeM:16=DA`ASEDd4HEQ815=9<0=IDch4
GD4k17VMXRMcQhLEoooo000Doooo9g>7Q`AcMVl3JUI=15e6>0@j:b44;RDR189iIPAfNFT4JfeK0g1b
JPAcMFT4FeI:15E?@@A1=R/4?30W13hd<0=9>CX4GU15169@A@ARFU04LW5[17=eK0=cMFh4KF=N16=F
B@ALD3X4Gd`e15Y@@`ANDD<3DE1414a=@PAIETT4HVAD15]JBPAUGe43JF1B16EKC@ASFT`4HeA716=E
C@ASFd`4?R/R0cPM5`AC>B/4MiZH9g>7QaGoool001CooolWLhN717=fK`=ZETd4GDHh13X[8@@^9B84
PWUV17IiJ@A[KE/3L79Z17=eJ@AKETX4EDm1144f:`@l<2L4?S@`0dTi>PAND4D4HU15169JD0AbLF/4
LgE/0g=eKPA]Heh4HeI915a@>PAOC3D4FU1315iA@`=AD4@4C4e215UFB@ARI5@4FeY:16EOD@=YH584
IE]=16=JC0ASE4L4HeE=16=KC0@n:b83>1dG15<i:`AgVYPWLhN75Oooo`005?ooobMcQhL4LgI_0fYF
C@AMASP4>R/Q12hU8PB2NFH4MWUY16]]F`=`LVX4LgEY15]FBPAECd44@CH[13``9`@n=303BCTj15i@
A@ARD4D4HUY@179aJ`AcMF`3LgE^16eSGPASETT4G50j15m<=@AJD4<4GU530e5@A0A<CD84FEI9169T
E0AKFTX4IEmA0fUPDPAUFdd4HeY<16=DA`ASEDd4He]<13h[8P<h7AL4DcT[17NJV2McQhLEoooo000D
oooo9g>7Q`AcMVl3JUI=15e6>0@j:b44;RDR189iIPAfNFT4JfeK0g1bJPAcMFT4FeI:15E?@@A1=R/4
?30W13hd<0=9>CX4GU15169@A@ARFU04LW5[17=eK0=cMFh4KF=N16=FB@ALD3X4Gd`e15Y@@`ANDD<3
DE1414a=@PAIETT4HVAD15]JBPAUGe43JF1B16EKC@ASFT`4HeA716=EC@ASFd`4?R/R0cPM5`AC>B/4
MiZH9g>7QaGoool001CooolWLhN716]LB`=VCd@42PH510T=30@J6QL4PGiZ171cI@AcKF03MgIV17=e
I0AbKEl4EU1413hk<@@Q:BT43aPI0aTJ4P@f<BH4=QhG138G4`AMDDL4L71V0g=eK0A]Je/4HeQ915a>
?0AHFCl4D4Li16ELCP=bJET4N6QH17ANC`ASCdT4DT]216AMD0=WGU04HEU;15EBAPAADTH4Gee=16=M
C0A;=RT3E38T16Q0<`AkVJ0WLhN75Oooo`005?ooobMcQhL4Jea;0fI?A0@:1PD42@d<11XJ5`B1OVX4
L7=U17=]H0=gMVH4LgET179]G`AFD4@4?S/a124Y:@@?61T36AXB13Ha9P@f7QL4<QLC15eAA`A`L6H3
LgE/16e[F`ASF4T4G4hl15QI?`A@AcT4IEa>0g9YF@AhJ5P4M5i?16=?B@ABBd84I5e@0fMND0AQFD/4
EE96155BAPAOGDd4Hee<14/f:@=D<R@4J40c17^IX2McQhLEoooo000Doooo9g>7Q`A[G4/3ITm410X6
1@@93@`46QXG185nJPA`LfD4LfeP0gMfIPAcMF@4LVeO15I@A0@n>c448BTY10lH6@<I6Q84=S4V13HN
5`@b5a<4GE57171`IP=cMF`4KF]K16=HB@ALCS`4F5To1517>@AUG4h3LVUI17QXF0AdGTl4Hdm9159;
@PATGE03Iei@165IB`AEDTH4DE9615mMC@ASGD`4BcHY0e@b90AX@3<4NiVP9g>7QaGoool001CooolW
LhN716]LB`=VCd@42PH510T=30@J6QL4PGiZ171cI@AcKF03MgIV17=eI0AbKEl4EU1413hk<@@Q:BT4
3aPI0aTJ4P@f<BH4=QhG138G4`AMDDL4L71V0g=eK0A]Je/4HeQ915a>?0AHFCl4D4Li16ELCP=bJET4
N6QH17ANC`ASCdT4DT]216AMD0=WGU04HEU;15EBAPAADTH4Gee=16=MC0A;=RT3E38T16Q0<`AkVJ0W
LhN75Oooo`005?ooob=cQhL4NXn?17MVEP=SC404;RDQ120I4`@[6QD4THUe17MlK@A_LV@3L7IX17=e
I`AeNG<4K69D195nM0A3>S048AHB0bHJ4`@Y<C04B3ha17miH`B:VH<4M89i0g>9Q@A]MFL4HeM:14i1
=PA>?c849@`814Th<@=??bX4?cL/12/W7`A4@SL4EE=416AIA@=MEDL4GeM:15U=@0AKDdH4IU==15E9
?`@d9b83BSX]16aIC`B6/kL4MHV98g>7QaGoool001CooolSLhN717Z?S`AgIUH3Hda012hU8@@P6A<4
:aXE1969M@AgO6d4Kg9T0g1fJ0AcMFL4MGUc16aRE0BAOW@4@cX`124F4P<V6Q<4:C4`14Pn<@AoNF<4
RYV317B2N@=cRHD4KGEW16=GBPA>@CH4CSlb12D<20A9>343CclZ13lg;0@[9al4A48g15ECA0ATFDD3
GEE715mGBPAICD04Fe=616ICC@AEBCl4=2LR0dXj;@A/FDl4Q[>g17F9RB=cQhLEoooo000Doooo8g>7
Q`AjShl4MfIF0f=<@0@^9B4481TC12/J5@BARGD4Mga]16mbI0=`MVP4LgEW17EiL`A/HU@4TGid14<j
<0@Q5Q839QXC12Ta<0A8?S44OgUS18ZIP`AdPWT3LhV516eeI`ASEdX4CT4f14ho<P@U30P4BCPa0dlo
:P@o=b`4:bLO14A2=`AEDd@4I5U50eeEA`AOEdX4FDe015]CAPAVDdd4EDTo13@W8P=:>Rd4K5U?18Jc
]`AeRHTSLhN75Oooo`005?ooob=cQhL4NXn?17MVEP=SC404;RDQ120I4`@[6QD4THUe17MlK@A_LV@3
L7IX17=eI`AeNG<4K69D195nM0A3>S048AHB0bHJ4`@Y<C04B3ha17miH`B:VH<4M89i0g>9Q@A]MFL4
HeM:14i1=PA>?c849@`814Th<@=??bX4?cL/12/W7`A4@SL4EE=416AIA@=MEDL4GeM:15U=@0AKDdH4
IU==15E9?`@d9b83BSX]16aIC`B6/kL4MHV98g>7QaGoool001Coool4Lgam17>4Q@AcOWl4LhB54g>7
Q`@80P84<QPF0fIND@@l<2L471XP11/E4PB6RG@4K6iQ17=eI`=_L6<4JF]N171bK0AbMfL4KfUI175R
C`BYR6/3VW1;18UR@@B=M5<4P7=O17EaH`AdNW83LgM]16eRD`ASDTH4H4Xg15]9>`AG@344EE]E0b0/
;`@00`D46aXI12/a;0@@514492HV0c0[8@A@?2`4Ee1315]GBPAVEDH4A48d12@P6@<^9b04If9B18:[
ZPAaQHDSLhN75Oooo`005?ooo`AcO7d4LhB517=nO`AcQ8DCLhN710P20P@b61H3IUiA13``9`@L6R04
6aDB18J9M0A/KV44LgEW0fm`H`AYJeh4L79/179gI`A_JET4LF9?1:V8J`>JL4/4RF9118edD`B0Lel4
MG5S17AjLP=cMfd4KF9C16=BAPAPBSL4FdTk15M0<@AEFeD382`_10031@@K6QT4:c4/110D4@@T9RH3
<2/Q150l;0AGD4<4FeM:16IEAPA4@S@4920I0bhW80AWHU84PZ^Z1765QB=cQhLEoooo000Doooo17=l
O@AcQ8D4Lgio17>4QA=cQhL42082138H5P=VGU44?30W11`J80@K5A84QXUd16a^H@AcMFL3Kg1S16U[
GPA`LV`4LWMW16mYF@AaHTl4ZHQ[0iY`B`B9HT44SGAC181cG`AeLF<4M7Yb0g=gK@A]HU<4He96161:
=`AKBC/4Ed0a15EKE@<P;2l400<511/J6@@[<B`441@A12@V9P<`:b44D3`/15M@@`AKEdX4IUE614A2
=0@T81T3;RLP16MRDPB2ZjX4LHF58g>7QaGoool001Coool4Lgam17>4Q@AcOWl4LhB54g>7Q`@80P84
<QPF0fIND@@l<2L471XP11/E4PB6RG@4K6iQ17=eI`=_L6<4JF]N171bK0AbMfL4KfUI175RC`BYR6/3
VW1;18UR@@B=M5<4P7=O17EaH`AdNW83LgM]16eRD`ASDTH4H4Xg15]9>`AG@344EE]E0b0/;`@00`D4
6aXI12/a;0@@514492HV0c0[8@A@?2`4Ee1315]GBPAVEDH4A48d12@P6@<^9b04If9B18:[ZPAaQHDS
LhN75Oooo`005?ooo`AcPX<4LhR817>9R@AcRh/?LhN710/61P@91`H44PD20`P=3`@62A043a4>12HJ
50BFSWT4Kg1S17AfL@=M@d84FTM016m]I`AeOgL4Nh=m17afK`AaGe43LfQI17i^G`B1MEl4Ng9T17=d
I@AdOGH3LgU`16ePFPASHUH4G5<o15aM@@A/Ech4OfmI0giJ@`@G4Q44<20F12/W9@@R7a`4CC`]0f9;
>`AdJE@4HeA615eCAPAVGDP48QhM11dJ5@<_8AP4I3P[1765R`A^Ph<SLhN75Oooo`005?ooo`AcPX<4
LhR817>9R@AcRh/?LhN710/61P@91`H44PD20`P=3`@62A043a4>12HJ50BFSWT4Kg1S17AfL@=M@d84
FTM016m]I`AeOgL4Nh=m17afK`AaGe43LfQI17i^G`B1MEl4Ng9T17=dI@AdOGH3LgU`16ePFPASHUH4
G5<o15aM@@A/Ech4OfmI0giJ@`@G4Q44<20F12/W9@@R7a`4CC`]0f9;>`AdJE@4HeA615eCAPAVGDP4
8QhM11dJ5@<_8AP4I3P[1765R`A^Ph<SLhN75Oooo`005?ooo`AcPX<4LhR817>9R@AcRh/?LhN710/6
1P@91`H44PD20`P=3`@62A043a4>12HJ50BFSWT4Kg1S17AfL@=M@d84FTM016m]I`AeOgL4Nh=m17af
K`AaGe43LfQI17i^G`B1MEl4Ng9T17=dI@AdOGH3LgU`16ePFPASHUH4G5<o15aM@@A/Ech4OfmI0giJ
@`@G4Q44<20F12/W9@@R7a`4CC`]0f9;>`AdJE@4HeA615eCAPAVGDP48QhM11dJ5@<_8AP4I3P[1765
R`A^Ph<SLhN75Oooo`005?ooo`AcPX<4LhR817>9R@AcRh/?LhN710/61P@91`H44PD20`P=3`@62A04
3a4>12HJ50BFSWT4Kg1S17AfL@=M@d84FTM016m]I`AeOgL4Nh=m17afK`AaGe43LfQI17i^G`B1MEl4
Ng9T17=dI@AdOGH3LgU`16ePFPASHUH4G5<o15aM@@A/Ech4OfmI0giJ@`@G4Q44<20F12/W9@@R7a`4
CC`]0f9;>`AdJE@4HeA615eCAPAVGDP48QhM11dJ5@<_8AP4I3P[1765R`A^Ph<SLhN75Oooo`005?oo
o`AcSHd4Lh^;5g>7Q`@L4Pl4;bHK12`M5`<Q8A`42PX:12DJ50@^6aH4TH9^17M^H@A_KUl3N89e16ee
HPA5=bd4>R/T130X8@@O7a`461PF0alM60@Z8Q`4<2<M155@B@AZLfD4M7M`0g=_G`A]H504Hf5A15a<
@@AQB3T4FeDn169PBP=WGdl4U7iT1;>8I@AkESh4MDdg19A[D`>1J4L4Ge];165KB@AZHE44FeE911lL
5P@O5a@3<b8I15l_8PAfVYhWLhN75Oooo`005?ooo`AcSHd4Lh^;5g>7Q`@L4Pl4;bHK12`M5`<Q8A`4
2PX:12DJ50@^6aH4TH9^17M^H@A_KUl3N89e16eeHPA5=bd4>R/T130X8@@O7a`461PF0alM60@Z8Q`4
<2<M155@B@AZLfD4M7M`0g=_G`A]H504Hf5A15a<@@AQB3T4FeDn169PBP=WGdl4U7iT1;>8I@AkESh4
MDdg19A[D`>1J4L4Ge];165KB@AZHE44FeE911lL5P@O5a@3<b8I15l_8PAfVYhWLhN75Oooo`005?oo
o`AcSHd4Lh^;5g>7Q`@L4Pl4;bHK12`M5`<Q8A`42PX:12DJ50@^6aH4TH9^17M^H@A_KUl3N89e16ee
HPA5=bd4>R/T130X8@@O7a`461PF0alM60@Z8Q`4<2<M155@B@AZLfD4M7M`0g=_G`A]H504Hf5A15a<
@@AQB3T4FeDn169PBP=WGdl4U7iT1;>8I@AkESh4MDdg19A[D`>1J4L4Ge];165KB@AZHE44FeE911lL
5P@O5a@3<b8I15l_8PAfVYhWLhN75Oooo`005?oooamcQhL48AH?11T@2`@B4Q035a@@11`E40@I5Q44
;2/V17ehI0A_KF04MGQZ0gMhL0AjOWD4R91n17QXGPA=C4h4MUmH17iOBP=oJU@4KUM518EcG`B?Uh44
Oh=l17MhLP=cGEl4KFEL16=SE@ALATL4=bHN130P6`A=ASH3GeQ416=JA0A_GDd4MVYA16m/F0AcKE<3
F5U<16=ED`AKDdT4GeQ614A0<`@=3`d44Q<@0gaRC0AV>bT4NZNY9g>7QaGoool001CooolOLhN7124F
3`@I40/44Q8@0aLD40@L5A046AHA12`[9PAmN6@4KfeP17EhJP=gN704NWie18R@OPAhJ5h4CDa>17IO
F0AnGdX3OfYD16iGA@B5Lel4SiN117n3O0AgN783LeeO16eUG0ASHeD4G4I713LV7P@`81/4CDHf0emH
A0ASFT@4Kee=17IZD@A_K5P4LfeC0eQIC0ASEE<4Fe=915mHAPA4@3<43@l=118C40=lHT`4IS/Y17ZW
ZBMcQhLEoooo000Doooo7g>7Q`@Q5Pl46A0;118B40<G510471D@11TF4@@/:bH4OGQT16m]H0AeN6X3
MgQ`17YnM@B8T7h4N6QN14e<CPAfGeP4OUm:0gmZE0A^EdD4QG=O18nGP@AoPg`4MgQb0g=MG`A]IE`4
Hf=E15a6A`@g9Qh4<20K14e6=P=OF4@4HeY416mMC@AfJU44KfaH17=]D`=HFD`4HeEC15]CB@AOF4H4
A40c10d?3@@B4a03O69<16Hk:@AjYjTWLhN75Oooo`005?oooamcQhL48AH?11T@2`@B4Q035a@@11`E
40@I5Q44;2/V17ehI0A_KF04MGQZ0gMhL0AjOWD4R91n17QXGPA=C4h4MUmH17iOBP=oJU@4KUM518Ec
G`B?Uh44Oh=l17MhLP=cGEl4KFEL16=SE@ALATL4=bHN130P6`A=ASH3GeQ416=JA0A_GDd4MVYA16m/
F0AcKE<3F5U<16=ED`AKDdT4GeQ614A0<`@=3`d44Q<@0gaRC0AV>bT4NZNY9g>7QaGoool001Coool8
LhN717=nO`AcQ8D?LhN712TO5`@Q4@`47QHA0aPE4@@:1`L46a@@134Z9@AVFT/4JFIJ171dIP=cMFd4
Lgec17F1N@B0ThT4VJnK1::aW0BB[il3V[BW19bdZ0BGZI84NHAb17AnMPA[Keh3JG5M16]bG@A/IeX4
MWIS17YgGPA;>CD48alK0``?40@^:2H4F55815mJA`AWG4P4FeE80ea;@@A;ASP4GU9916YCB@@R71P4
4`l=12TW8@=P?Rh4@2@I11LJ6@A9DeLSLhN75Oooo`005?ooo`QcQhL4Lgio17>4Q@mcQhL4:AlG124A
30@N5Q4361DA10X71`@K5104<BXU16IJB`AYIUX4L7AV0g=eK@AcOG<4MH5i182CR@BI[i/4X[6L19:_
W`>J]:L4W;BX19NYTPAiQ784M7if16]_GP=YLEd4Jg9M16aWFPAfMV<4NWMN14/i=@@S7a/330l@12hX
9PAHDDP4GeY716MLB0AKEDP3G4]114]6>0ANDTT4JU=9128L60@C3`d4:BLQ0f0n;PA091T45aXI14UC
Eb=cQhLEoooo000Doooo27>7Q`AcOWl4LhB53g>7Q`@Y7aL48A4<11hF4@<H5A442PL711/D40@a:RD4
IUY;16UVFPA`M6H3LgE]17=mL`AePGT4P9>919V_V`BR/I`4TZnO0iZdY`BL]:P4UjVB17V4LPAdOWH4
JfmN0fUaG@A[LUd4K6MJ17IfH`AjMeh4BcTe12<O6`<<3a04;RPV15QAB0AOFTL4Iea815]EB0=LBd44
BdHh15iBB@AZDdT48Q`H11<?3@@Y9b43H3h^140T6@@G6QT4BE=G8g>7QaGoool001Coool8LhN717=n
O`AcQ8D?LhN712TO5`@Q4@`47QHA0aPE4@@:1`L46a@@134Z9@AVFT/4JFIJ171dIP=cMFd4Lgec17F1
N@B0ThT4VJnK1::aW0BB[il3V[BW19bdZ0BGZI84NHAb17AnMPA[Keh3JG5M16]bG@A/IeX4MWIS17Yg
GPA;>CD48alK0``?40@^:2H4F55815mJA`AWG4P4FeE80ea;@@A;ASP4GU9916YCB@@R71P44`l=12TW
8@=P?Rh4@2@I11LJ6@A9DeLSLhN75Oooo`005?ooo`QcQhL4LhV917>;R`mcQhL47QdK124O70@M5a83
7ADA11HB30@P5a84;bXU16aHA`AgLF84M7MY0g=eK@AcNg84LgU`17>2P0QcQH@4Lgad0g>2P0AcO7@4
Lg]d17EiK0AgMVH4MG=S0g5[G@A_H5D4LFaN17EbHPAjKfL4Pgmb19]oK0=ZEDL4=2PO110D4@@G5aP4
6R<S12PV80<a:B44H55;175JC0ALCSl45a<B11LC40@P6AX36P`:11lA3@@Z;R`4TZ^Z8g>7QaGoool0
01Coool8LhN717>9R@AcRh/?LhN711hM6`@Q7a`47ALB0adE4@@F4P`481LB12lZ9@A/F4L4Mg5R17Ag
J@=cMFd4Lg]b17=iL0AcPX08LhF417=lM0=cPX04Lgad17=kM0AeNF`4MgIV17EcH`=aJed4Kf1E175/
GPAeLV84NVmW18=oLPBKOf`3JUE713@X7`@@51445aLH11XS8`@X9R03<BTQ161AB`AaFT`4G4ho11LC
4P@G4a0481TJ0aX<2P@O4@d4:Rh/19:[ZR=cQhLEoooo000Doooo27>7Q`AcRHT4Lh^;3g>7Q`@N7A/4
8AlL11dG4P<M5A445Q8<120G4P@_:RD4K5Q717MaHPAdMfT3LgE]17=kLPAcNG04Lh:027>5Q0AcO7@3
Lh:017=lM0AcNg@4MGU/17MfIPAeLf<3LF]M16mPE@AaK5h4MG9R17Y_I`B3Og84Vgm/0fYEA`@d:1l4
41@A11LG60@J8b<4:2HP0c4Y8@APDD/4LEY<15a>?`@G4a845a<@120I6P<J30X47a4=12X^;0BBZjXS
LhN75Oooo`005?ooo`QcQhL4LhV917>;R`mcQhL47QdK124O70@M5a837ADA11HB30@P5a84;bXU16aH
A`AgLF84M7MY0g=eK@AcNg84LgU`17>2P0QcQH@4Lgad0g>2P0AcO7@4Lg]d17EiK0AgMVH4MG=S0g5[
G@A_H5D4LFaN17EbHPAjKfL4Pgmb19]oK0=ZEDL4=2PO110D4@@G5aP46R<S12PV80<a:B44H55;175J
C0ALCSl45a<B11LC40@P6AX36P`:11lA3@@Z;R`4TZ^Z8g>7QaGoool001CooolOLhN712TR7`@l<2/4
6AHB0a`E4@@N5Q4491/L130Z9PAEBc/4H61C16mcIP=cMFD4Lg9X17=gKPAcMfd4Lg]e17=nN@AcPGd3
Lh:017=gKPAcNG04Lg]d17=gJ`AcMFL3KFUL16m^H0A_IeX4KfYM16mUGPA/JET4JfYG0gAZE@B4M5`4
PFmF16YA?0AKAC<4N5M50gI[F@A`EU<4De9614E9?0@I5A<471DA11LE4@<A40/47AXF12dc<0B>YjHS
LhN75Oooo`005?oooamcQhL4:B8O13``:`@I5Q8371DA11hF4@@T6a`4<2XV15E;>`APH5<4Kg=V0g=e
I@AcLVP4LgM^17=gK@AcNgD4Lgii17>1O@=cPX04LgM^17=iL0AcNg@4LgM[17=eI`=]JE`4KfiP16mW
FPA_JUd4KfEN16aYF@A[JUL3M6YE18AdG0B1KeH4JU4l15]5<`AhEdD3MV]I171FD`ACDTH4ADTl11TE
4`@L5A445aDA0a4@2`@M6QH4;C<`18jWYR=cQhLEoooo000Doooo7g>7Q`@Y8Ql4?30[11TF4P<L5A44
7QHA12@K70@`:RH4ED/k161PD`A_LfH3LgEU17=bJ0AcMfh4LgM]17=kM@AcOWT4Lh5m0g>2P0AcMfh4
LgU`17=kM0AcMf/4LgEW0feYG0A_KV04KfMJ16mZG@A_IEh4K6UI16]ZE`=dJUD4Q7AL185_EPAZDC`4
FdDc17QGA@=fJeT4L5IC15=BAPA5BC`46ADC11`E4@@G5A434A0;11dJ5P@]<c04SZNV8g>7QaGoool0
01CooolOLhN712TR7`@l<2/46AHB0a`E4@@N5Q4491/L130Z9PAEBc/4H61C16mcIP=cMFD4Lg9X17=g
KPAcMfd4Lg]e17=nN@AcPGd3Lh:017=gKPAcNG04Lg]d17=gJ`AcMFL3KFUL16m^H0A_IeX4KfYM16mU
GPA/JET4JfYG0gAZE@B4M5`4PFmF16YA?0AKAC<4N5M50gI[F@A`EU<4De9614E9?0@I5A<471DA11LE
4@<A40/47AXF12dc<0B>YjHSLhN75Oooo`005?oooamcQhL49a`E12TP5`@S7AT37aHB128@30@W6QD4
;b<I13Tb:@ANE4T4KViQ0g1bI@AcMFd4Lg]b17>2P0AcNG04Lg]e1g=nN@AcMfh4LgU`17=aH@AcLFT4
LfeR0feOE0A_JUd4KfiP16mWFPA_HeH4JEm@16eHC0=[GE04JEe?17YZF@B0KU`4QGEQ17aWEP=^FU<4
K5Q916=C@@@i:b046Q@A11`E4@@X6aH36aHB11dF4@@Z8AP4FUEE16A`LQmcQhLEoooo000Doooo7g>7
Q`@W71D4:B0G12<M6@<O5Q848Q0<12LJ5@@_8aT4>C8Y15iDB@A^KV43L79U17=eK@AcNg84Lh:017=i
L0AcNgD7Lgii17=gKPAcNG04Lg5Q17=aJ@AcKF83KEmD16mZG@A_KV04KfMJ16mSEPAYGe04KEQ<0f]M
D0AYGDl4NVYI181^G0B5MF44O6MF0fiJD`A/F4T4He=113T[80@J514471DA12PK5P<K5Q847AHA12XQ
60AJEED4I71b7g>7QaGoool001CooolOLhN712LL5@@Y81L48adI0alF4P@R40`49aXE12lS6@@i<RT4
GUA916i^H@=`LVD4LgE]17=kLPAcPX04LgU`17=kM@McOWT4LgM^17=iL0AcLF44Lg5Y17=]HP=]Ge@4
KfYM16m^H0A_IeX4Kf=F16UOD0A]F4`3Jee@16UMC`AjJUT4P6iL18EeH@AlIeH3KUYC16aHB@ASDd44
>B/P11XD4@@L5A44:1/F0a/F4P@M5Q44:R4H15YEE@ATL78OLhN75Oooo`005?oooamcQhL47QTB12h]
:P@T7a/39QXF11<A30@I5A4461<@12lS70A3=B@4IV=F0gAdIPAcMFd4Lg]b17>0O0AcPGd4LgU`17=k
M@McMFX4LgU`17=cI@AcMFD4JfMH0f][G@A_IeX4Kf5F16mSE`A_IeX4JF5D16=MD0=SGU04JFMI16=K
C@AWEdX4IEY<15EDA`MAEDH4?d8f11DK6@@;3@X47QTJ118@4@<A40/42`L7120H5@A;AD84LhV77g>7
QaGoool001CooolOLhN711hI4P@^;BX491lK0bHJ5P@C4@`46ADA11PC40@_8a`4@cDT16ISEP=dM6H4
LgE]17=kLPAcP7`4Lh5m17=iL0AcNgD7LgEZ17=iL0AcLfD4LgEU16]WF0=[Jed4KfMJ16mQEPA_HeL4
KfMJ16UQE0ASGE03Hei@16UWF@ASFdd4IeM:16EJC0AEE4L7DEE613m2=P@E6aT42`d:11hI6P@B4143
4A0;10/71`@P61D4BdE217>9QamcQhLEoooo000Doooo7g>7Q`@N6A84;RdZ12@O6`<V6QH44a4<11TE
4@@H4a04;b<L14<e90AVHeH3M7AV17=eK@AcNg84Lh1l17>1O@AcNG04Lg]e1g=eJPAcNG04Lg=U17=e
I@A[IeP3Jf]M16mWFPA_HEH4Kf=G16mWFPAYHE@4Hee@0f=ND0AYIeT4He]=16MGBPAUFT`4EEA71e5E
AP@o@SH45A/I10/=2P@N6AX44Q0A0a4@2`@;1`L481PE14]5@PAcRHLOLhN75Oooo`005?oooamcQhL4
7QTB12h]:P@T7a/39QXF11<A30@I5A4461<@12lS70A3=B@4IV=F0gAdIPAcMFd4Lg]b17>0O0AcPGd4
LgU`17=kM@McMFX4LgU`17=cI@AcMFD4JfMH0f][G@A_IeX4Kf5F16mSE`A_IeX4JF5D16=MD0=SGU04
JFMI16=KC@AWEdX4IEY<15EDA`MAEDH4?d8f11DK6@@;3@X47QTJ118@4@<A40/42`L7120H5@A;AD84
LhV77g>7QaGoool001CooolOLhN712TN5`P]:2@39R0K12LK5`@P5a849b0K13Da;@@g=Rl4I5eD0fmY
G@AcLV`4Lg9Z17=dJ`AcNgD4Lh5m17>2P0=cMfh8LgU`17=cK@A[KF84JfMK1fmSE`A_IeX4IfMJ16EO
DPAWGe84IEe@0fMND0AWG4l4JEe@16=KC@AOFT`4FEA70fYEB0AOCT44<b`V11XC4P@V7QX440`<118@
40<<1`L45A4B11hG4PA6Ad<4Oi^L7g>7QaGoool001CooolOLhN712TN5`P]:2@39R0K12LK5`@P5a84
9b0K13Da;@@g=Rl4I5eD0fmYG@AcLV`4Lg9Z17=dJ`AcNgD4Lh5m17>2P0=cMfh8LgU`17=cK@A[KF84
JfMK1fmSE`A_IeX4IfMJ16EODPAWGe84IEe@0fMND0AWG4l4JEe@16=KC@AOFT`4FEA70fYEB0AOCT44
<b`V11XC4P@V7QX440`<118@40<<1`L45A4B11hG4PA6Ad<4Oi^L7g>7QaGoool001CooolOLhN712TN
5`P]:2@39R0K12LK5`@P5a849b0K13Da;@@g=Rl4I5eD0fmYG@AcLV`4Lg9Z17=dJ`AcNgD4Lh5m17>2
P0=cMfh8LgU`17=cK@A[KF84JfMK1fmSE`A_IeX4IfMJ16EODPAWGe84IEe@0fMND0AWG4l4JEe@16=K
C@AOFT`4FEA70fYEB0AOCT44<b`V11XC4P@V7QX440`<118@40<<1`L45A4B11hG4PA6Ad<4Oi^L7g>7
QaGoool001CooolOLhN712TN5`P]:2@39R0K12LK5`@P5a849b0K13Da;@@g=Rl4I5eD0fmYG@AcLV`4
Lg9Z17=dJ`AcNgD4Lh5m17>2P0=cMfh8LgU`17=cK@A[KF84JfMK1fmSE`A_IeX4IfMJ16EODPAWGe84
IEe@0fMND0AWG4l4JEe@16=KC@AOFT`4FEA70fYEB0AOCT44<b`V11XC4P@V7QX440`<118@40<<1`L4
5A4B11hG4PA6Ad<4Oi^L7g>7QaGoool001CooolOLhN7128R7`@_;R/4<bhY0blZ9@@V6aH44Q0<12@I
5@@h9ad4E3`[16i<=`=[IUP4L7AU17=eJPAcLVX4LgA[17=kM@AcOWT3Lh5m17=lM0AcNG04Lg=[17Eg
I`AaKEl3IfEI16EODPA/GUP4JEiB16]HC0A[FE<4IE]@0fMND0AWEdX4GeE915mGBPALBcl4IE140e]7
>`@e<bh48ahH11hF4`@A40/44Q0@114<30<E4@`45Q8B12PK5PBjf]H4YLO47g>7QaGoool001CooolO
LhN7128R7`@_;R/4<bhY0blZ9@@V6aH44Q0<12@I5@@h9ad4E3`[16i<=`=[IUP4L7AU17=eJPAcLVX4
LgA[17=kM@AcOWT3Lh5m17=lM0AcNG04Lg=[17EgI`AaKEl3IfEI16EODPA/GUP4JEiB16]HC0A[FE<4
IE]@0fMND0AWEdX4GeE915mGBPALBcl4IE140e]7>`@e<bh48ahH11hF4`@A40/44Q0@114<30<E4@`4
5Q8B12PK5PBjf]H4YLO47g>7QaGoool001CooolOLhN7128R7`@_;R/4<bhY0blZ9@@V6aH44Q0<12@I
5@@h9ad4E3`[16i<=`=[IUP4L7AU17=eJPAcLVX4LgA[17=kM@AcOWT3Lh5m17=lM0AcNG04Lg=[17Eg
I`AaKEl3IfEI16EODPA/GUP4JEiB16]HC0A[FE<4IE]@0fMND0AWEdX4GeE915mGBPALBcl4IE140e]7
>`@e<bh48ahH11hF4`@A40/44Q0@114<30<E4@`45Q8B12PK5PBjf]H4YLO47g>7QaGoool001CooolO
LhN7128R7`@_;R/4<bhY0blZ9@@V6aH44Q0<12@I5@@h9ad4E3`[16i<=`=[IUP4L7AU17=eJPAcLVX4
LgA[17=kM@AcOWT3Lh5m17=lM0AcNG04Lg=[17EgI`AaKEl3IfEI16EODPA/GUP4JEiB16]HC0A[FE<4
IE]@0fMND0AWEdX4GeE915mGBPALBcl4IE140e]7>`@e<bh48ahH11hF4`@A40/44Q0@114<30<E4@`4
5Q8B12PK5PBjf]H4YLO47g>7QaGoool001CooolGLhN717=nO`A[M7D47Q/H12XV8P@_:bL3;2LS11TD
40@V81/4:R8M12HT80A8?2h4H5120f]/H@AbMFP4LgE]27=mL`AcP7`7Lgii17=gKPAcNG04Jf]L171[
F`A]Ge@3LF=G17EYF`A[I5D4If9B16]MD0ASIEH4Hf1@0em?BPAMEDX4GeY<16=JC0AUEDP4F5M:0dM4
=`A5>bd49b0G120H5@@H5Q446QLB11XG4@<F4P`46AHA12LK5PBN^KL4MHV97g>7QaGoool001CooolG
LhN717=nO`A[M7D47Q/H12XV8P@_:bL3;2LS11TD40@V81/4:R8M12HT80A8?2h4H5120f]/H@AbMFP4
LgE]27=mL`AcP7`7Lgii17=gKPAcNG04Jf]L171[F`A]Ge@3LF=G17EYF`A[I5D4If9B16]MD0ASIEH4
Hf1@0em?BPAMEDX4GeY<16=JC0AUEDP4F5M:0dM4=`A5>bd49b0G120H5@@H5Q446QLB11XG4@<F4P`4
6AHA12LK5PBN^KL4MHV97g>7QaGoool001CooolGLhN717=nO`A[M7D47Q/H12XV8P@_:bL3;2LS11TD
40@V81/4:R8M12HT80A8?2h4H5120f]/H@AbMFP4LgE]27=mL`AcP7`7Lgii17=gKPAcNG04Jf]L171[
F`A]Ge@3LF=G17EYF`A[I5D4If9B16]MD0ASIEH4Hf1@0em?BPAMEDX4GeY<16=JC0AUEDP4F5M:0dM4
=`A5>bd49b0G120H5@@H5Q446QLB11XG4@<F4P`46AHA12LK5PBN^KL4MHV97g>7QaGoool001CooolG
LhN717=nO`A[M7D47Q/H12XV8P@_:bL3;2LS11TD40@V81/4:R8M12HT80A8?2h4H5120f]/H@AbMFP4
LgE]27=mL`AcP7`7Lgii17=gKPAcNG04Jf]L171[F`A]Ge@3LF=G17EYF`A[I5D4If9B16]MD0ASIEH4
Hf1@0em?BPAMEDX4GeY<16=JC0AUEDP4F5M:0dM4=`A5>bd49b0G120H5@@H5Q446QLB11XG4@<F4P`4
6AHA12LK5PBN^KL4MHV97g>7QaGoool001CooolGLhN717>9R@AeT8l47A/G13HW7@@]9b83<2`X134[
9P@Y8A`4:B@O130T6PA4A3X4@c``0f1CA`A[Jeh4L79/17=bJPAcMfh4LgM]1g=bIPAcKF<4JfMH16]R
D`A/KV44JfAH0fMOC0AUGTl4Iem<16]RD`A[I5H4IEi@16MKCP=YFT/4IEe<16=BAPASD4@4EE9614M7
>`=0=BX491lN11PD4`@C4a044A0;11<@4@@?2``31`L710h;30@l:RH4W;Bb16j3PamcQhLEoooo000D
oooo5g>7Q`AcRHT4MI2?11dK5`@f9ad4;BLR0c0/:0@a:bH4:B4L12TT7`@`91X4A4@j14<l<0=PDdL4
Jf]N171bK0AcLVX4LgM^17=gK@McLVH4LfeS16]WF0A[HU<4K6iQ16]TF0=WGd`4IEi?16MOC0A[HU<4
JfAF16END0AWFdh3JEY;16EMC0ASDTH4He1415EBAPA7Ac/3@3DZ12@O7P@H51<44a<@114@2`@C4144
3`/<0`L71`@>2``4?2XV19bd/PA^Ph<OLhN75Oooo`005?oooaMcQhL4LhV917F@S`@M6aL4=RLM12dW
8P<`;2P4<B/V12TQ70@Y91l4<2@J14A4>PA3?303H5=716][GPA`LV`4Lg9Z17=gKPAcMfd7Lg9V17=]
H`A[IeP4Jf9C16a^H@A[I5P3Iem<16ENC`AWGd`4Jf9C16]TEPAUGU04Ie]>0fUJB`AUGD`4He9616=@
A0AEDTH4AdLk0d0e:P@T7ah461@C11<C40@A40/44a0A10l;30<71`L43P/<13`Z9PBL];84KX>37g>7
QaGoool001CooolOLhN712XS7`@^91X4;RdY0c8]:@@V8Qd48QPD12lS6@@^:B@4>3L^13<U7`=CACX4
Jg5S17AfIPAcMF84Lg9X17=_G`McKed4Lg5W17EgI`AaKEl4Kf5F16MBA`=WEd`4JeUF16]QEPA[HUL4
JeA816EIC@MWEdX4HEY<16=DA`ALCT44BDHi140d:@<T7Ad47a`F11LC3`@F5A447QHA11HA4P@@30`3
4P`<12hM5`CLo_<4^>;M8g>7QaGoool001CooolOLhN712XS7`@^91X4;RdY0c8]:@@V8Qd48QPD12lS
6@@^:B@4>3L^13<U7`=CACX4Jg5S17AfIPAcMF84Lg9X17=_G`McKed4Lg5W17EgI`AaKEl4Kf5F16MB
A`=WEd`4JeUF16]QEPA[HUL4JeA816EIC@MWEdX4HEY<16=DA`ALCT44BDHi140d:@<T7Ad47a`F11LC
3`@F5A447QHA11HA4P@@30`34P`<12hM5`CLo_<4^>;M8g>7QaGoool001CooolOLhN712XS7`@^91X4
;RdY0c8]:@@V8Qd48QPD12lS6@@^:B@4>3L^13<U7`=CACX4Jg5S17AfIPAcMF84Lg9X17=_G`McKed4
Lg5W17EgI`AaKEl4Kf5F16MBA`=WEd`4JeUF16]QEPA[HUL4JeA816EIC@MWEdX4HEY<16=DA`ALCT44
BDHi140d:@<T7Ad47a`F11LC3`@F5A447QHA11HA4P@@30`34P`<12hM5`CLo_<4^>;M8g>7QaGoool0
01CooolOLhN712XS7`@^91X4;RdY0c8]:@@V8Qd48QPD12lS6@@^:B@4>3L^13<U7`=CACX4Jg5S17Af
IPAcMF84Lg9X17=_G`McKed4Lg5W17EgI`AaKEl4Kf5F16MBA`=WEd`4JeUF16]QEPA[HUL4JeA816EI
C@MWEdX4HEY<16=DA`ALCT44BDHi140d:@<T7Ad47a`F11LC3`@F5A447QHA11HA4P@@30`34P`<12hM
5`CLo_<4^>;M8g>7QaGoool001CooolOLhN713Lf<P@^:bL4:bPU0cD[9`@^8QT4:RDO12<O6`@Z9b@4
920L12LW9P=5?S04Edln16ETE`AYJeh4L79S17=eI0AcMFL3JfeP16U[G0A`LV84KF5E16MEB@AWGd`3
HeU:161LCPAPG4d4J5U=16=FB@ASF4/4Idm:0emHC0AOFTH4G4do15E>@@A7A3P4<2@N0b4M5P@F4`l4
40l;118@4@@L5A44514A10`71`<@30`49a/F19>]Z`A^Ph<SLhN75Oooo`005?oooamcQhL4=cHb12h[
9`@[:2D3=B/W12hR6@@Z9Al48alK12XW90@T81`49bLV0dDn<0AGCch4IFAG16U[GPA`LV<4LgET17=e
I`=[KF04JF]L171bHPA]HED4IeE916MOC0=SFDX4H5a>161LC@AXFDd4HeI916=HB`AWCdX3GeQ<15mJ
APALCCl4EDi114M4>0@`91h38AdF11HC3`@@3`/44Q0A11`E4@@D4A4430L70a0<30@W6aH4Tjf[16j3
Pb=cQhLEoooo000Doooo7g>7Q`@g=S84;R/W12/X9@<e:bL4;R8I12XU7`@S7a/4:RLT12@P70@W9bH3
ACh`15M??PAUI5L4JF]N171bH`AcMF@4LgEW0f]]H0AYJe`4L79R16eQE@AWEDT4Iem<0f=IBPAPG4h4
H5a=16QIC@ASETT4HeQ;16M?BP=OF4`4GeY615a=?`AECT44Ad@h130T7P<Q7AH45Q<?110?2`@B4144
71DA11@A4@@<1`L340`<12LK5PBC[J/4KX>38g>7QaGoool001CooolOLhN713Lf<P@^:bL4:bPU0cD[
9`@^8QT4:RDO12<O6`@Z9b@4920L12LW9P=5?S04Edln16ETE`AYJeh4L79S17=eI0AcMFL3JfeP16U[
G0A`LV84KF5E16MEB@AWGd`3HeU:161LCPAPG4d4J5U=16=FB@ASF4/4Idm:0emHC0AOFTH4G4do15E>
@@A7A3P4<2@N0b4M5P@F4`l440l;118@4@@L5A44514A10`71`<@30`49a/F19>]Z`A^Ph<SLhN75Ooo
o`005?oooamcQhL4<c8Y12h[9P@c;RT3:bPS12TW90@M6AX48QdI12PS7P@b;BT4;R<I0bdR6P@n?C@4
DTY2161@APAZH5D4JF5F16UYG@=[KF04KfUL16aUF0ASGe@4GeE8161DB@=SE4X4Ie1416MCA`ATEDT4
HeM:15mBAPAMDT@3F4`n15=8?@A5AC/4>SDZ13P^90@P71D3518?11<C40@C4@`440`<10l;30@61`L4
1`L70b/M5`@h8QL4V[:^9g>7QaGoool001CooolOLhN713<b:@@^:bH4<bhY0b/X8`@Y9b@47ATJ128M
6@@X8ah4<RdY12hS6@<]8QX4?Sdd159:@PAPD4H4JV1E16UQEPAYJEd3JfeP16mYG0A/IEP4HemD15mE
B0APE4T3HeA:16M@A0AWDdL4I5E916=GBPAODTH4GE940eQ<?PACB3d4ADDk13Xe:P@h;R@481`E0a@B
3`@C4a044a4<110<30@?2``41PL710L71`<[7AL4>28G19Zb[RMcQhLEoooo000Doooo7g>7Q`@c<RT4
;R/V13<^:@<[:2<4:BLT11dI6P@R7AT4:2<N138]:@@^8aT3;B8J13hm=0ABBT84H51616YPE@AYHEH4
JFUM0f]]H0A_JE`4K6EH16=OE0AOEDP4H5A90f=DBPAWD4@4Ie=716AEB@ASEdX4Ge9615eBA0=HC3h4
DdPm14E5>`@j=BX4>2hT120L5@<D4Pl44a<@11<A30@@30`43`/<10H71`@71`L3:adG13PR5`BJ/ZhW
LhN75Oooo`005?oooamcQhL4<c8Y12h[9P@c;RT3:bPS12TW90@M6AX48QdI12PS7P@b;BT4;R<I0bdR
6P@n?C@4DTY2161@APAZH5D4JF5F16UYG@=[KF04KfUL16aUF0ASGe@4GeE8161DB@=SE4X4Ie1416MC
A`ATEDT4HeM:15mBAPAMDT@3F4`n15=8?@A5AC/4>SDZ13P^90@P71D3518?11<C40@C4@`440`<10l;
30@61`L41`L70b/M5`@h8QL4V[:^9g>7QaGoool001CooolOLhN716Q_N`@l<Bl4<B`X0b`W8`@h<bl4
<BDJ12LJ5@@e;bX4:2<N12l/:0<Q7Q/4;34[128V8`@a:bH4Dd]215A9?`AHDe03FU=B15YEC0ARGe@4
F4i313lh;PA1>Bl3D3l_15]?@PAMDdH4GD<h15e=@PAODST4G4hn0eE7>`A@@SH4B48f13DY8`@V6aH4
6A@B0aTD40@C40`43`/<110<30@<1`P420L8118<3@<O5Q84/]7?1;_ThRMcQhLEoooo000Doooo7g>7
Q`AXKg/4?34_134/:0</9b<4>3<_134U6P@W6QD4=BlZ12PS7P@_;2P38AhK12`a:`@R9R<4<B/V15=;
@PADBCl4F5=@0eYCDPAJED`4HUmD15Q>@`@o>2h4@CT_0e0o;`AKCd84GE=615e3>0AMCD84Ge8i15a>
?P=EAc/4D48f14Q2=P@e:B<49Q/F11TD4P<I51044a0<10l;30@@30`430L810P720@B30d37aHB1;;A
c`Bki>8WLhN75Oooo`005?oooamcQhL4J6mk13`a;`@a;2P3;2LS13Pc;`@a9AX49aXE13D_:P@X8ah4
;b`X0b4N6`@/<B/48RHS134[9PACBd84E4To15QCD0=JDe84FUE<169OE0AHCT<4?cP^144i;`=@?bl4
Fdm215eCAPAM@cP4GDe215mB>@ALCSh3EDLk1512=PA8@SH4=BTS12HK5P@I51836A@@11<@30@?2``4
40`<10`720@81`P44P`=0alF4PBbdLl4^nCR9g>7QaGoool001CooolOLhN716Q_N`@l<Bl4<B`X0b`W
8`@h<bl4<BDJ12LJ5@@e;bX4:2<N12l/:0<Q7Q/4;34[128V8`@a:bH4Dd]215A9?`AHDe03FU=B15YE
C0ARGe@4F4i313lh;PA1>Bl3D3l_15]?@PAMDdH4GD<h15e=@PAODST4G4hn0eE7>`A@@SH4B48f13DY
8`@V6aH46A@B0aTD40@C40`43`/<110<30@<1`P420L8118<3@<O5Q84/]7?1;_ThRMcQhLEoooo000D
oooo7g>7Q`AoVID4?Ch`12HS7PLZ9R847b4M11dI6`@/8aT4;2HR13Td;`<d;bX4;RTU12d/:`@g<B/4
<2`S12<X:`@N:BL3:2DM13Pd:`@i=bl4:BTV130[8P@d:b43>3@U13lb:@A6>R/4ETHc14a3=@@l<BT4
@30Y0dHh;P@h=c84;bLR12HJ5@@O5Q<45a<@0a4@2`@?2``430L810P71`@81`P420P811/G4P<Z71L4
WkRf17N?SRMcQhLEoooo000Doooo7g>7Q`AoVID4?Ch`12HS7PLZ9R847b4M11dI6`@/8aT4;2HR13Td
;`<d;bX4;RTU12d/:`@g<B/4<2`S12<X:`@N:BL3:2DM13Pd:`@i=bl4:BTV130[8P@d:b43>3@U13lb
:@A6>R/4ETHc14a3=@@l<BT4@30Y0dHh;P@h=c84;bLR12HJ5@@O5Q<45a<@0a4@2`@?2``430L810P7
1`@81`P420P811/G4P<Z71L4WkRf17N?SRMcQhLEoooo000Doooo7g>7Q`AoVID4?Ch`12HS7PLZ9R84
7b4M11dI6`@/8aT4;2HR13Td;`<d;bX4;RTU12d/:`@g<B/4<2`S12<X:`@N:BL3:2DM13Pd:`@i=bl4
:BTV130[8P@d:b43>3@U13lb:@A6>R/4ETHc14a3=@@l<BT4@30Y0dHh;P@h=c84;bLR12HJ5@@O5Q<4
5a<@0a4@2`@?2``430L810P71`@81`P420P811/G4P<Z71L4WkRf17N?SRMcQhLEoooo000Doooo7g>7
Q`AoVID4?Ch`12HS7PLZ9R847b4M11dI6`@/8aT4;2HR13Td;`<d;bX4;RTU12d/:`@g<B/4<2`S12<X
:`@N:BL3:2DM13Pd:`@i=bl4:BTV130[8P@d:b43>3@U13lb:@A6>R/4ETHc14a3=@@l<BT4@30Y0dHh
;P@h=c84;bLR12HJ5@@O5Q<45a<@0a4@2`@?2``430L810P71`@81`P420P811/G4P<Z71L4WkRf17N?
SRMcQhLEoooo000Doooo8g>7Q`A=Ded4;b/X0c@_:P@];RT4;RTU11LE40@V8ah4=S@`13Pc;`<k>3<4
?c`f14I2=@@o?c<4<3D]12LV90@Y7QL39adM12TP7@@/9R848R0Q12DT90@`9R43<RHK12/S7`@e<BP4
<c0W12`Z8@@h<RL4<R/P0bd^:0@/8ah4:B4I11XF4`@N7AX44A4<0a<@30@@30`43@P810P820@920P4
8QPB11PB4P=bIUl4/<_7:g>7QaGoool001CooolSLhN714eCG@@_:bP3=2lZ12d^:@@^:BD45aD@12HS
7P@f=304>3<_0c/h<`@o?3H4AT8e13lo<`@`=Bd49bHT12TN5`<W7Ad4:B0M12`V8P@R82449B@T130V
8@<b9Q/4:b<O13Da:0@c<2L4;2XQ13Pb9`@b:b03;BhX12`S7P@Y8AT46QHC11hM6P@A4@`34a0<110<
30@=20P420P810T820@R6184618B0g9VG`B`blL[LhN75Oooo`005?ooob=cQhL4CE=M12l[:0<d;bX4
;BhY12hY9@@G5A049R<N13Hd<0@h<bl3>cPc13ll=PA6@SD4?clc130e;@@W9R@4:AhG0bLM7@@Y81d4
;2HR128P8@@U92@4<2HQ0c8V6`@[8al4=C4X13<`9`@/:R44>38W138[80<];RP4;2<N12TQ6@@J5Q<4
7QdJ114A30<C40`440`<10d820@820P42@P8128H4P@H4Q83LVIO1;3;ab]cQhLEoooo000Doooo8g>7
Q`AhQh`4>2lY0bdX8`@[9R84;2HR134[9P@l=2h4>C@_13Xg<P<^:bL4:bLT12lQ7`@i91l4<B4J12LS
80@M6aP39BHS11/G50@O8R048R<Q128P70@K5A<35aTG11LE50@H4a846ATE11/K5P@L6aH45a8B0aTC
4P@F4a446ADC118C40@@3`/43@X;0a0;30@@30`820P8128H7@@R61<4=BdW0l7Pf0BH_[d[LhN75Ooo
o`005?ooob=cQhL4N8N<13P_:@<]:2<4:bHR12`V8P@a:bH4?3@^13Td;`@j=c83;R/W12/W90@_8Al4
>B@O134Q6P@W8b047A/H0bDV8`@K5a@47b8P128S8@@R81`46aDC0aLI5`@G5A@461<B11TI5@@K6aH4
71/F11LB4P<I4a845Q<A11TE4`@B4a0440l;10d:2`<@2``440`<20P820@R61d48QPC13D]9`?1h=P4
V;jm:g>7QaGoool001CooolSLhN717R7S0@h;bT3;BPS12/V8P@/9R84<B/V13`d;P@i=2l4>SLb0bh[
9`@[9b@4;b4O13TT7`@a8AX49b<P11dK60<U9R<46aLD11lR80@R8b448R0L11/E4`<G6AL45aDD11PC
4P@I6AD46a/F11`K5P@G4Q836A<B11HC4@@I5A<44Q<@110?2`@=2P/340/<110<30P820P48QPM128H
4`@e;BL3`N3H19Rn_B]cQhLEoooo000Doooo8g>7Q`AhQh`4>2lY0bdX8`@[9R84;2HR134[9P@l=2h4
>C@_13Xg<P<^:bL4:bLT12lQ7`@i91l4<B4J12LS80@M6aP39BHS11/G50@O8R048R<Q128P70@K5A<3
5aTG11LE50@H4a846ATE11/K5P@L6aH45a8B0aTC4P@F4a446ADC118C40@@3`/43@X;0a0;30@@30`8
20P8128H7@@R61<4=BdW0l7Pf0BH_[d[LhN75Oooo`005?ooob=cQhL4Mhn;15eXI@<c;bX4;2PS138]
:@@]:2@4?CXd12HR7@@_;BT38alK12hZ9PA1>Rh4;RlZ12DW9@@Y:2@4:2<N0cX_:P@P6AX48R<O120G
4`@Q5Q<46A<@0a@D40@H51048QTE124I5@@G4Q045Q8@11HC40<P6AD46ADA11TD40@B40/4510<110<
30<A30`820L8118<3@@[8Q`4:1`F1<WYi0>mh=/_LhN75Oooo`005?ooob=cQhL4Mhn;15eXI@<c;bX4
;2PS138]:@@]:2@4?CXd12HR7@@_;BT38alK12hZ9PA1>Rh4;RlZ12DW9@@Y:2@4:2<N0cX_:P@P6AX4
8R<O120G4`@Q5Q<46A<@0a@D40@H51048QTE124I5@@G4Q045Q8@11HC40<P6AD46ADA11TD40@B40/4
510<110<30<A30`820L8118<3@@[8Q`4:1`F1<WYi0>mh=/_LhN75Oooo`005?ooob=cQhL4Mhn;15eX
I@<c;bX4;2PS138]:@@]:2@4?CXd12HR7@@_;BT38alK12hZ9PA1>Rh4;RlZ12DW9@@Y:2@4:2<N0cX_
:P@P6AX48R<O120G4`@Q5Q<46A<@0a@D40@H51048QTE124I5@@G4Q045Q8@11HC40<P6AD46ADA11TD
40@B40/4510<110<30<A30`820L8118<3@@[8Q`4:1`F1<WYi0>mh=/_LhN75Oooo`005?ooob=cQhL4
Mhn;15eXI@<c;bX4;2PS138]:@@]:2@4?CXd12HR7@@_;BT38alK12hZ9PA1>Rh4;RlZ12DW9@@Y:2@4
:2<N0cX_:P@P6AX48R<O120G4`@Q5Q<46A<@0a@D40@H51048QTE124I5@@G4Q045Q8@11HC40<P6AD4
6ADA11TD40@B40/4510<110<30<A30`820L8118<3@@[8Q`4:1`F1<WYi0>mh=/_LhN75Oooo`005?oo
obMcQhL4KGAk0cDV8P@d;BT4<RdY12`W8`@O81`4<Bl[140l=P<];RT49b<N130S6`@M6AH48b0K12DQ
7@@H5ad37R0M11/H60@U6AD46Q<I11@D4@@E5A434a0<11LE4@@F5A4451@@114@2`@>2``44A0<0aXE
40@A40/43P/<118@30@E4A8440`<0`P720@A30`47APB12lT7@@[71L4a^WS1<K]ic9cQhLEoooo000D
oooo9g>7Q`A]M7/3=BHR13@]:@@b;BT4;2LS11lP70@a;b/4@3`f0bd^:@@W8ah4<2<K11dI5P@S81/4
9B4M11PG7@<N81d46aPH12DI5@@J4aT451@A11DE4@<C40`45aDA11HE4@@D51044A0;10h;30@A40`3
6QD@114@2`@>2``44Q0<11DA4P@@30`320L8114<30@M6184;b@M12/L5`C6jN<4a^gW<W>7QaGoool0
01CooolWLhN716edN`<e9R84=2dY138]:@@/9b<47b0L134_:`A0?3H3;BhY12LS7P@`8a/47ATF12<P
6`@U8Ad461LM0ahP7@@K61P49ATE11XC6@@D51445ADA0a<@30@G5A445QDA11@D40@A40/43P/<114@
30<J5A044A0;10h;30@B40`45A4B110<30<81`P44@`<11dH4P@_91d4:a`G1<KYh`C6kNLbLhN75Ooo
o`005?ooobMcQhL4KGAk0cDV8P@d;BT4<RdY12`W8`@O81`4<Bl[140l=P<];RT49b<N130S6`@M6AH4
8b0K12DQ7@@H5ad37R0M11/H60@U6AD46Q<I11@D4@@E5A434a0<11LE4@@F5A4451@@114@2`@>2``4
4A0<0aXE40@A40/43P/<118@30@E4A8440`<0`P720@A30`47APB12lT7@@[71L4a^WS1<K]ic9cQhLE
oooo000Doooo9g>7Q`AjU903ADQ012h[9P@_:bL4;2LS13@^:P@_;RT4:bTU0b<O6`@Q6aP481`I11HC
40@W8Qh47QPI11lH6@<L50l46Q<H114@40@<2`/44Q0@11<@4@<?2``4510A10l;30@C41443`/<11DA
4P@J5a83514B10l;30@71`P<1`L70aDB4P@H4`d440`<11/?2`BgcLT4a>SR=W>7QaGoool001CooolW
LhN717ZDT0=5B404;R/V12l[9`@/9b<4=2hZ12l^:@@[:BD38alK124K60@P71T45Q<@12LR7P@N61T4
7aPI0a`D3`@J4aP44A0@10`;2`@B41044a0A0`l;30@D41443`/<11<@4@@?2``45A4B11XG4P<D4A84
3`/<10L720`71`L35A8B11PC3@@@30`46`l;1;O=b@C4j>8fLhN75Oooo`005?ooobMcQhL4NYB@0dE8
@0@^:bH4;b/W12`W8`@d;RX4;bhY12/Y9@<S7a/48A/H120L6@@F4a049b8N11hH6@@O61T371@?11XC
60@A410430/;118@40@C41433`/<11@@4@@?2``44a0A10l;30@E4A846QLB0a@A4P@?2``41`L830L7
1`<E4Q8461<=110<30@K3`/4]lg91<CXhSIcQhLEoooo000Doooo9g>7Q`AjU903ADQ012h[9P@_:bL4
;2LS13@^:P@_;RT4:bTU0b<O6`@Q6aP481`I11HC40@W8Qh47QPI11lH6@<L50l46Q<H114@40@<2`/4
4Q0@11<@4@<?2``4510A10l;30@C41443`/<11DA4P@J5a83514B10l;30@71`P<1`L70aDB4P@H4`d4
40`<11/?2`BgcLT4a>SR=W>7QaGoool001Coool[LhN70i2][0ANGEH4:bDP12XV8P@[;BP4:b`X13Lb
;@<^:BX49ATE12@N6@@G5A446Q@@11@C3`@J51033P/;10d;2`@B41045A4A114<30@D4A4340`<11DA
4@@@30`4:Q`F10T820@D4A446AHA0a@A4@@81`L420L810h820@H4Q846A<C0aLB4P@Z6aL4>bXM17aI
?PBhdLP4Mhn>=W>7QaGoool001Coool[LhN70i2][0ANGEH4:bDP12XV8P@[;BP4:b`X13Lb;@<^:BX4
9ATE12@N6@@G5A446Q@@11@C3`@J51033P/;10d;2`@B41045A4A114<30@D4A4340`<11DA4@@@30`4
:Q`F10T820@D4A446AHA0a@A4@@81`L420L810h820@H4Q846A<C0aLB4P@Z6aL4>bXM17aI?PBhdLP4
Mhn>=W>7QaGoool001Coool[LhN70i2][0ANGEH4:bDP12XV8P@[;BP4:b`X13Lb;@<^:BX49ATE12@N
6@@G5A446Q@@11@C3`@J51033P/;10d;2`@B41045A4A114<30@D4A4340`<11DA4@@@30`4:Q`F10T8
20@D4A446AHA0a@A4@@81`L420L810h820@H4Q846A<C0aLB4P@Z6aL4>bXM17aI?PBhdLP4Mhn>=W>7
QaGoool001Coool^LhN7192][0AOETl4=3<]12HR7@@f<2`4>38]0cHb;@@U9Al4:BHQ11dE6`@D4184
71DA11@@4@<H5Q446aPB11HB4Q<@30`46AHA11@A4@@/<d84>C`l128H7P<@2``45Q4A11hH4`@N6A<4
5a<B130X8@<^8ad4:Q`G14df;0Bfg=l4W<_@>W>7QaGoool001Coool^LhN7192][0AOETl4=3<]12HR
7@@f<2`4>38]0cHb;@@U9Al4:BHQ11dE6`@D418471DA11@@4@<H5Q446aPB11HB4Q<@30`46AHA11@A
4@@/<d84>C`l128H7P<@2``45Q4A11hH4`@N6A<45a<B130X8@<^8ad4:Q`G14df;0Bfg=l4W<_@>W>7
QaGoool001Coool^LhN7192][0AOETl4=3<]12HR7@@f<2`4>38]0cHb;@@U9Al4:BHQ11dE6`@D4184
71DA11@@4@<H5Q446aPB11HB4Q<@30`46AHA11@A4@@/<d84>C`l128H7P<@2``45Q4A11hH4`@N6A<4
5a<B130X8@<^8ad4:Q`G14df;0Bfg=l4W<_@>W>7QaGoool001Coool^LhN7192][0AOETl4=3<]12HR
7@@f<2`4>38]0cHb;@@U9Al4:BHQ11dE6`@D418471DA11@@4@<H5Q446aPB11HB4Q<@30`46AHA11@A
4@@/<d84>C`l128H7P<@2``45Q4A11hH4`@N6A<45a<B130X8@<^8ad4:Q`G14df;0Bfg=l4W<_@>W>7
QaGoool001CooolbLhN719Vj]`AOEe04@3Lb12PS7P@V:2@3=cHa13Xd;`@c9A/49QlI11XG4@@D4A44
3`/<0a@@30@C41443`/<110<30@E4Q844@`<0aDB4P@A30`440`<12db<`@Z8B`4?cH^14Q0=P<m=344
C44i13H/90@K5a84:B4K12TP6`<d;bX4CC@X1<COfPBYeMDnLhN75Oooo`005?oooc9cQhL4VKZg15mG
D0A0=c84:2<N12HX90<g=S44>S@_13<U6`@V7aT46QLA11@A4@@?2``3510<11<@4@@?2``440`<11DB
4P@A30`35A8B114<30@@30`4;C8c12XQ;0@o=Rh4B40f0cdd<@A<@CT4=R`T11/G4P@Y8A/4:B0K0c@_
:PA==2P4a=oJ1:WEeCicQhLEoooo000Doooo<W>7Q`BI^[L4GeM@140g<P@X8ah49RPT0cLf<@@j=2l4
<bDK12HO6@@J5a44514A10l;30<D40`44a0A10l;30@@30`45A8B114<30<E4Q844@`<110<30@]<S<4
:R4/13lf;PA8@3H3?C@a14a1>@@f;2@46aLB12TQ6`@Y81/3=2lZ14dd:0C4gmX4ZMGE?W>7QaGoool0
01CooolbLhN719Vj]`AOEe04@3Lb12PS7P@V:2@3=cHa13Xd;`@c9A/49QlI11XG4@@D4A443`/<0a@@
30@C41443`/<110<30@E4Q844@`<0aDB4P@A30`440`<12db<`@Z8B`4?cH^14Q0=P<m=344C44i13H/
90@K5a84:B4K12TP6`<d;bX4CC@X1<COfPBYeMDnLhN75Oooo`005?oooc9cQhL4L8B518b/ZPADASL4
@C/d13L`:`<k=c84>CHa13dk=P@U81`49alK13T_:@@_;2@38aTC11XG4P@E4Q445Q8B114<30@@30`3
6QHL11DB4P@K5a844a0@120O6@@[9b0430/=0`d>30@?40d430`=11TC40@W7a/4<2@J0ee3;`BQ[;44
YM7D17>;RcicQhLEoooo000Doooo<W>7Q`A`Q8D4S:bZ15A6=`A1>c@4=c0[0c/g<P@i=S44?C/f12DP
70@W7a/4>BlY12l/90<S6A<46QLB11DB4@@F4Q844@`<110<30<J5Q`45A8B11/G4P@C410481lI12/W
80@<2`d33@h<10l@3@@<30d46A<@12LO6`@`91X3GD<_1:6//@BUdM@4Lh^;?W>7QaGoool001Cooolb
LhN71724Q@B<[:X4E4Hg144k=0@g<2/3>cLb13Tf<@@m>cH49B0L12LO6`@i;bT4;b`T0b<I4`@J5a84
5A8A11HB4P@A30`440`<0aXF70@E4Q846aLB11<@40@P7aT4:bLP10`;3@<=3P`43a0=10`<3@@I4a04
9alK130T6P=M@bl4XJba1:GAe0AcRh/nLhN75Oooo`005?oooc9cQhL4L8B518b/ZPADASL4@C/d13L`
:`<k=c84>CHa13dk=P@U81`49alK13T_:@@_;2@38aTC11XG4P@E4Q445Q8B114<30@@30`36QHL11DB
4P@K5a844a0@120O6@@[9b0430/=0`d>30@?40d430`=11TC40@W7a/4<2@J0ee3;`BQ[;44YM7D17>;
RcicQhLEoooo000Doooo>W>7Q`BB]KD4EEM:12DQ70</:BD4@T0k14M;APA0?SL4:24L11hH6@@Q5Q<3
<RXU12/Y8`@F4Q8440`<11lK8@@R7R@3;2XR120M8@@n=Bl471PN14M0>@@c:b`4<R/V0c/a:P@c:B<4
>S0Y14m7=`@h<BX4J4di0l3KfPBXfM/4OibF@W>7QaGoool001CoooljLhN719:e]@AEEdX49B4L0b`Y
9@A2@3/4Ad]6140n=`@X8A`47QPI124F4`<b:RD4:bTS11HB4P@@30`47a/Q128N90</:R8481dQ13he
;`@L61h4Ad0i13<[;0@b:bH3>c4Z13<Y8`@j<2T4CdLg13Pa:PAXCCT3`=_J1:SIf`AoW9I2LhN75Ooo
o`005?ooocYcQhL4T[Fe15EGBP@U8A`3;2TU1490>`A7BdH4@3hg12PQ70@N61T48AHC0c8Z9@@[:B<4
5Q8B110<30@O6b448QhT0b`Z8P@P7B44?SD_11`H7PA7@3T4<b//138[9P<k<BX4<bTS13X`:@A?AcL4
>34Z16Q=>@?0fmX4Z=WK17nLUT9cQhLEoooo000Doooo>W>7Q`BB]KD4EEM:12DQ70</:BD4@T0k14M;
APA0?SL4:24L11hH6@@Q5Q<3<RXU12/Y8`@F4Q8440`<11lK8@@R7R@3;2XR120M8@@n=Bl471PN14M0
>@@c:b`4<R/V0c/a:P@c:B<4>S0Y14m7=`@h<BX4J4di0l3KfPBXfM/4OibF@W>7QaGoool001Coooln
LhN719:`/0B/^lH3D4]312hZ9P@Y9b@4<S]314]:APAKETd4G61E0cD`<0@X;S04B4UI16QVG@A1=S@4
<2hh0c@/;@A7AU@4>c@^134Z90@n=bl4=2/V13XX8`<j:1d4=BhY14Tm<@ATB3D4>bPM1:oCdP>LcM84
Lh^;AW>7QaGoool001CooolnLhN719:`/0B/^lH3D4]312hZ9P@Y9b@4<S]314]:APAKETd4G61E0cD`
<0@X;S04B4UI16QVG@A1=S@4<2hh0c@/;@A7AU@4>c@^134Z90@n=bl4=2/V13XX8`<j:1d4=BhY14Tm
<@ATB3D4>bPM1:oCdP>LcM84Lh^;AW>7QaGoool001CooolnLhN719:`/0B/^lH3D4]312hZ9P@Y9b@4
<S]314]:APAKETd4G61E0cD`<0@X;S04B4UI16QVG@A1=S@4<2hh0c@/;@A7AU@4>c@^134Z90@n=bl4
=2/V13XX8`<j:1d4=BhY14Tm<@ATB3D4>bPM1:oCdP>LcM84Lh^;AW>7QaGoool001CooolnLhN719:`
/0B/^lH3D4]312hZ9P@Y9b@4<S]314]:APAKETd4G61E0cD`<0@X;S04B4UI16QVG@A1=S@4<2hh0c@/
;@A7AU@4>c@^134Z90@n=bl4=2/V13XX8`<j:1d4=BhY14Tm<@ATB3D4>bPM1:oCdP>LcM84Lh^;AW>7
QaGoool001Cooom2LhN717bFTP>Xc/H4G5YR13ll=`@^=C/4C51A14U@D`A1AT83AdY415]NF`AJDDL4
AT0g13@_:PA1?383<BXW12@O6@@U8A/4=S8]138]:@@o:b44BS<X0d/l<0AKBSh4ARhT151;D@B[gND4
]N3OCG>7QaGoool001Cooom2LhN717bFTP>Xc/H4G5YR13ll=`@^=C/4C51A14U@D`A1AT83AdY415]N
F`AJDDL4AT0g13@_:PA1?383<BXW12@O6@@U8A/4=S8]138]:@@o:b44BS<X0d/l<0AKBSh4ARhT151;
D@B[gND4]N3OCG>7QaGoool001Cooom2LhN717bFTP>Xc/H4G5YR13ll=`@^=C/4C51A14U@D`A1AT83
AdY415]NF`AJDDL4AT0g13@_:PA1?383<BXW12@O6@@U8A/4=S8]138]:@@o:b44BS<X0d/l<0AKBSh4
ARhT151;D@B[gND4]N3OCG>7QaGoool001Coool4Lgam17>4QD5cQhL4T[2Y1<gik0C5fn04EUES15AA
E0AgNh`3Kf]_15]>B0A7@S`4AD@o15]BD`AUFE83Ee9:16eQEPAIDT@4Ee=;16EJDPA?CD04@TXn0bh/
:@AaNXP4]^[^1<Gon`BL`[eALhN75Oooo`005?ooo`AcO7d4LhB5@G>7Q`BB/:T4cOW/1<GKh0AFEF<4
E55D17MkS0=_Jfl4Fdi814M2?0A5A3l4Fe9C16EIDP=GDTX4KF5F15UBA0AGDd/4IEYB14m=@0A2BSh3
;R`Y175jR0Bfj^h4aOok19c2_E5cQhLEoooo000Doooo17=lO@AcQ8E1LhN719:`Z@C=nN`4aM_P15IE
H`ADDE@4Mg^<0fm[K`AKCTP4Ad8l14E4?`AKDU<4IEUB0eMBBPA]HEH4FE9415MCB`AUFU84Cde0149:
?P<^;2T4LGZ81;KZkPC5oo/4W<:mDG>7QaGoool001Coool4Lgam17>4QD5cQhL4T[2Y1<gik0C5fn04
EUES15AAE0AgNh`3Kf]_15]>B0A7@S`4AD@o15]BD`AUFE83Ee9:16eQEPAIDT@4Ee=;16EJDPA?CD04
@TXn0bh/:@AaNXP4]^[^1<Gon`BL`[eALhN75Oooo`005?ooo`AcSHd4Lh^;BG>7Q`AgSh/4V[Z/1;oU
e0BVc/<3SJF]1:O7a`BBY;L4EUib14QBI@@m@Cl3?T0m1451?@A0@Cl4@3hk13@^9P@b<RT4Y[jo0m3l
nPC1l>P4QjVRFG>7QaGoool001Coool4Lhf=17>;RdUcQhL4Mhn;19Zj[0BoiM@4Y/k30hfU[@BWalL4
TZBg15INLPA8DVD4?D4o0ci0?@A1@Cd4@44o140n>`@d;RH4<S8Y1:Jn_`?@o?X4`O3X18NYXUUcQhLE
oooo000Doooo17>=S@AcRh]9LhN717N?R`BJ^Z`4_nGD1:K>``>=YJd4YlO719:T]`AFGW84B59U13e1
?`<n@3d4@D4m1411?`A0?S/4=2hV138b:@BV_[l3d?cj1<7`j0B7ZJ9ILhN75Oooo`005?ooo`AcSHd4
Lh^;BG>7Q`AgSh/4V[Z/1;oUe0BVc/<3SJF]1:O7a`BBY;L4EUib14QBI@@m@Cl3?T0m1451?@A0@Cl4
@3hk13@^9P@b<RT4Y[jo0m3lnPC1l>P4QjVRFG>7QaGoool001CooomQLhN70gN?R@AkUXd4O9ZD19k1
/0Bkgl/4_^CF0l;RgPC2jnL4`^gY1<C`j`C;nOH4cooo1:gAdP=cRh]QLhN75Oooo`005?ooof5cQhL3
Mhn917^FS@AlVY@4W/6`1;_Ob`Bni=H3`^;N1<;[i`C2kNT4a?3[1<_imPC?ool4[M7B0g>;Rf5cQhLE
oooo000DooooHG>7Q`=gShT4NiJ=17bJU0BN`K04^mo;1;kTeP?2h]h4`^_W1<;]j@C4l>/4boWf1<oo
o`B]dM83Lh^;HG>7QaGoool001CooomQLhN70gN?R@AkUXd4O9ZD19k1/0Bkgl/4_^CF0l;RgPC2jnL4
`^gY1<C`j`C;nOH4cooo1:gAdP=cRh]QLhN75Oooo`00ooooob7oool00?oooolQoooo003ooooo8Ooo
o`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Ooo
o`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00VOooo`<00024oooo002Loooo00<0003ooooo
ool0POooo`00Noooo`D00002oooo0P0000Coool200001?ooo`@00002oooo0`0000?oool300000ooo
o`80001noooo001moooo00D0003oooooooooool000000_ooo`040000oooooooo00000_ooo`040000
oooooooo00000_ooo`040000oooooooo00001Oooo`040000oooooooo0000Poooo`00OOooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00@0003oooooool00002oooo00<0003oooooool01000
00;oool010000?ooooooo`0008?oool007goool00`000?ooooooo`04oooo00@0003oooooooooool2
00001?ooo`<00003oooo0P0000Coool40000P_ooo`00OOooo`050000oooooooooooo000000;oool0
1@000?ooooooooooo`000007oooo00<0003oooooool0SOooo`00O?ooo`800004oooo0P0000Coool3
00001?ooo`80002?oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(158) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80686C63
6A6C626A6C666A706A6A6D676A706A6A716B6A716B6A716B6A6D676A6C6368695F67655A
655D52645C5161584D60584D60584D60584D60584D6054495E54455D54485D54455D5448
6774766A7D806A7D806A7D806A7D806A7A7D6A7C7F6A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A76796A797D6A7D806A76796A797D6A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A76796A797D6A7D806A7D806A7D806A7D806A7D806A7D806E7369
6D6F6C6A6C626A70676A6D676A706A6A716B6A6A5E646052616052615C515E554E575149
575148595349584F455D554B60584D60584D6051476051475E544B5D544A5D54455D6F6E
67858B6A7D806A7D806A7D806A7D806A81846A80836A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A81846A797C6A797D6A81846A80836A7D806A76796A797D6A76796A797D6A7D80
6A7D806A7D806A7D806A81846A80836A7D806A7D806A7D806A7D806A7D806A7D80646960
67695C6A6C676A69666A716B6A6C676A666264635B525F5C5658525E4B495B4B455D564D
605F53606155645D515D5449574F45574F455751475754435A54475D54495D544B778D92
7790946A7D806A7D806A7D806A7D806A7D806A76796A797D6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7A7D6A7C7F6A7D806A7D806A7D806A81846A80836A81846A80836A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806E6C63
6D6C696A6C696A6C676A69646A6A656A6C606E706A7D7672787569746C6A6F645A6B584D
6B534F6B53516449485E4E475D54495D54495D54495D544B635A5060564B5D5449677476
6A7D806A7D806A7D806A7D806A7D806A7D806A81846A80836A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A81846A80836A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7369
6A6F616A6C5D6A6C646A6C676A6C676A6C6A6A73706A77706E73706773646869606E685F
6E6B5C685D536E6B5C6B574F664A49665D5B60594F6354496351475E51476360546B7C7D
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7067
6A6C626A6C696A6C626A6C646A6C676A736D6A6C676A66626A716B6E7370717A6D6B7161
67635E6B665B645E51655C53646253605344645C565D594F5754495A54496C767870878D
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A76796A797D6A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D805849435E534B
6A6C696A6C626A6C606A6C666A736D6A6C676A716B6A77706A736D6A6D676A6C6A6E6C64
716B5C6B63566B6358685B5368584D6454495A4E425A4F4463544960544964767A6A8287
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A81846A80836A7D806A7D806A7679
6A72766A797D6A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D8028221F3E3F38707466
6A6C666A6C6A6A6C6D6A6C696A706A6A6D676A695D6A6D656A6A656A6A656A6C606A7062
64615D645D56675956655C4C5D54455D584D64564B6054495F6054645F536E80806D8386
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A8184
6A84876A80836A7D806A7D80
6A7D806A7D806A76796A797D6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D8052555F2212114A4A506D6F67
6A736D6A706A6A736D6A706A6A69646A716B6A77746A6C696A6A5E6A5857644F4C5B4943
61554B6760546163565B584E64584F645A4E5A54435A54475A4E45574D436471736A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A81846A797C6A797D6A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D8071858720161074725AA1A1846A6C67
6A69666A6A656A69646A6A656A6C676A69646A6D686A6D6764665D615F56646054655C52
60594E5E564C6156476156495C51475D4F4564514966544A605449635A4E645D59676D6E
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A76796A7D806A80836A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D80170D0B68655DA5A6996D6F676A6C66
6A6C676A6C676A6C606A6C646A6C676A736D6A6C676A6A65683E42673138612C32612A31
642B336444425D4D455D4D45604B425A51415D54476054495E54435F4A3F533E345E615F
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7679
6A797D6A7D806A7D806A7D80
6A7D806A7D806A81846A80836A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D805255599A9B979D9B906A6A656A6C636A6C66
6A6C676A665A6A62576A62566A69616A69646A56586A4F54684848613F385B2F27603C38
5D3D356035375B363857453F5754435A4F445F514860544964544B63504664594E584034
5E58546A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A8184
6A80836A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D801B15132B2D296A69586A6C5D6A6C606A6C66
6A6C6064635661585067685F6A6F686A5F54643E3B5B2C2855423A473427536A58637B69
5B372D5328215D322D603E3A5D4E485D503B5A533F5D544760544960574B60534860554B
6868636A75756A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A76796A797D6A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D803E393D6B55479189746D6F6C645F59676C6A6A706C
6A5F57625244574239614A4F5E2B312104042E2B2D61574D6E675F87B3AE7B4E4855302B
4445314860523537294626205739335A4A39634C4463574E67635164594B605A4E605449
5541375E524C6A75756A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A76796A797D6A81846A80836A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D80251F1C4E564F797D766A6C62685E536A645F6A6A65
6A665C5F4437583C332509082C434598E3D49DD6CB78BABF74AFB76D87896C8D7980BCB2
8EB1B3697A7B41332C1D1D132F261E59483E5F5248675D52675E55686251645649605147
60574C5561745966746775796A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A81846A80836A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D8058617327171650524D6A6C5E6A6C606E776A6D756D6A6C67
5E4C444B3F2E44251C38120B5E352F693D35613E37675A566A64526A5F4C624B4560565A
5E483D7D6C5F8B7B63837F6F33281F30211E533D395F5A4A6A6A5B686258615B51604F45
604E455A59494B4C41494E5C5E6D796A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D8028221F0600004F3B32948B796D6F646A5F566A59516A665A6A6C5D
66574A73696089A490B3DEB89DA5986E656261534F5A413C5D2B30552C33542828561716
51191A4F3A37563B32613D3D674A432F1008392B2D625449666358655D4C6152455A5549
5D5C5064574B7E85856A717C6472776A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A76796A797D6A7D806A7D806A7D806A7D806A7D80
6A7D806A7D80585B65130B0A150F0D68766F7D83746A665C6A5B5F646763676E646A585C
66554F523F31605B586D76766A7B726E837775918678908474977F73826A75836D6F8A69
6F81666757496B3D3E67342F5D251B581D15431A14463433625650655A4C6155495E4D43
5F4E456052491D0F0C3B3D38707D7A6775796A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A81846A80836A7D806A7D806A7D806A7D806A7D80
6A7D806A7D80637381C7BEA2FFD1A5A1947967695D6A695F6A77646E63616D64626A7765
66685768584D675F5567625B6A716B6A706A6A69646A716B6A5B5F685855676056655C54
64584F5B5745535947586A4E67715A7D7F667D7369665D455C544661594B6155495E5745
5F564860574C3F3A364953525E70706D83866A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D80777058746C5E6E7F7C6B756A63655B676C626A6F6C6A776F6A7C766A706F
6C6D636C64565D473F5C534A676C646A746E6A706A6A706A6A7866686959614D44615445
5852404D4B42514739543F35544235544135574935625E5066605864554D5B4B435A4A43
5A5143575145241A174E5C726F84916A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D80646F73676961645F535B493A4F53596165646D6C696A73706A77706A736D6A746E
6E61646F635E6C5D4F6A5A516A615D6A6D686A595A64585167665B625B5161594E583F38
5847435E443B5C47395A4D4160533D5D503C5A473665534967554B5D4F455B4E435D4F44
5D534A635A501B1112373F3C5D6A666A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806E68586D675E6258515B514A6E6656735D5A6A64656A706A6A716B6A716B6A716B
6A78666E715F68665260514466605B6A706A6A786E6E78726D6F6F6C6563686258655F51
665A4E5E483D5A453C5A493F5C4E4866524C74645A6D675C5D54495D514764574B605246
5D53435A51452617121A14143238416A797D6A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7067646659503E2F6363577465666D6F646A75686A706A6A78786A75716A716B
6A6D6B6A736B66635964625163685867665E6A6A5E6A736A6A706A68695C5E53465D4F45
5A54495E554963583F5D493A5C4C42665C566D6A60686155616255605F535A564B5A574B
5D564C6360568E6944623323180D0C232A326A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A61595E3E364F1F1F583B395562615E73646A75646A6C666A706A6A6C656A6D666A716B
6A6D6764665D68695E6E786C70786D6D6F61645854675E576A5655624F455F4A3F5A4A41
55443B5A4A364C3E3450413A625B4F666354666255655C5261554B604F45645147605443
634D4163574E64564E846D5CCCEAE0A1C1BF6A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A5B5D6643425F3E395D564A706B5D736E696A73736A706C6A706A6A716B6A716B6A6A65
6A6A5E68695C6D655A6B685D6A6C696A73736E7B756D75716A695B6660535B514755493E
5243394E413A5B4B436B66576D675A67655A666258655C5261584D605449604D49644A4B
5D4D465D5A565845365A4A3F6D7A7B6E81846A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A685F
6A695566614D59513A5F5D4C6E6F646D6F686A706A6A746E6A6C676A6662646055676658
6A585A685856635B52645E556A68636A695D6A6A616A6C676A5E62664E485F4C425A4B40
5D4D425A564A5F5D4A625C4E635B506A5F5564594F61534961554B604D43604D415A4F41
5A56435F5D5367564C635A4F4C4D505862686A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D805E5243
472E2628201B302E295A5B546C70656A6C666A69646A66626A6A5E6A665768665A635855
5B584E615C55676B636771656A6E616A6C676A6C696A6C6764705F6262515F52475A4B40
5A4B40634E4462534A665754675B5360594E616056646256615A4F605E515A5C4E5A5246
5D4C4A5F57565534265D5146603D2F675B566A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D805F483B
24160F261F1D241D1E414847696A676A6C696A6C606A6C5D6A6C676A706F6E7372717A74
6F696464534F5748415F554E6362596769636A6C676A6C60685B565E4E4755424357473B
544539594C4263594E5F544759524760534F5D4A43594E45584F45574F455A51475D5045
5D4F485A4E42524C3550463557403A6772776A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A6F6C6A605B
6D4D3E3E2A2030242058564F696A5D6466576769646A6C655852474D463C3E322A352822
382F2C42353756464159463F5A4D486664606A6C676A6C6A68625E62554B5B4E395A4734
574B3F564A3F4C473F464840504E45595B4E58574A5D574C645A4F60564B5D54495D5045
5D4F485D5349422D25341A16463025636E696A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80645B50625147
1709070F0C0C1B17164E564F66675D6A665C6D6C5E6A6C60706D60564E44403B32242728
111518131611292620321B162C110F48353267665E6A6C6768695C62584B5B4C3D54543D
4E43365B53486D62547362546C594C5D48454F464059544A60584D5E5449524D434C4D43
5656485D5649523B2E51312459362D66686D6A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80718587726C62624D41
442E282719142B18145A5B546D7266676C61676C626A6C626E736F7065598D7971513F34
2717132417122228293E3B3174705D7781706A756E6A7F7E68746A62594D4F40374B3930
2A0D093625254838283C312829241E393830524C41585041574F435A5147584A3F564C42
5B4C4852443D3B2A2544362C5C50487083866E81846A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A72766A797D6A76796A797D6A7D806A7D806A7D806A7D806A7D8012050411050C625A4F
4D382C251C211D15124C575163655B6A6C6267685E61625967696370776A6764557E6955
AE8C6D9B714D855B3D7D6B4E7268576A61576A6B666A6C65686056625449624B39594539
5E46354B4D4A222A2F070406121416262826131210181C202A251F443327554A3F565146
5B4F434740342C231C29231E4D4F466D817F6B7E816A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A797C6A7C7F6A81846A80836A7D806A7D806A7D806A7D80150909140B0B0D040200030A
0F0B1116110F2819145C5D5667685E6A6C695B4343533D3B615D5A6E777475817D797570
6E5C517165597A6A5D766A59706A5D6A695D6A6E686A716B685F5C6260575B53425B583F
69573E7B6550835B45241514281B142A2121271F1D3E3228594439665E4E6050435A4C42
5B56442D211F231A162D1E174529235C575C687A7E6A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A84876A80836A7D806A7D806A7D806A7D806A7D806A7D80311D1931231A301E18211D1A
120B0B2618142F19165A544E6D655B6765587382756B726340312932201D2C221D1E1D1B
1816171A1716231D19291C1A413E3B5F675C6A6B656A665B685F51625C505B4D435D4338
564F3C595743645C4DA78669AF86657B543D774C3684614D7760445952455A5647665B4C
564F462D2219231714301F1946281F5E62666A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D803622191E0F0B17120F1B1310
2215111C15112A27234F544C6161586E6F646D6F68777B7688938276675E514A4C6F5B56
7F5F4C7B65516B55447A6B5A7F82727478726D6F6C6A585D685F5B6260545B47483A2520
2D1A1840372E56513F5D54416A594B7769526E695667634E54544A5D4F4E564C46565143
473E331913101612106254445E3A2A5C6C6E6A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A76796A797D6A7D806A7D806A7D806A7D803F2E2328120D2315111D1511
1107081D13102E242144413B56564F67685F6A6C666A736D6E7B777D948B9AAD9A96AB99
8EADA094AFA499B3A88CA18E71796B6A736C64695C616D5A646A5A6964597275627F7B63
513B37221A190C0C0E1E1D204C46405A5445645744564F4457473E484135564A44624C46
2D1E1A1D110F2C241F43312741251A160D0E272B336A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A81846A80836A7D806A7D806A7D806A7D80322B2827201C221712221511
1C120D2216112C24214D443B635D546A6B616A6C666A706A6A716B6A78786A7D7F6A7D7F
6A75716A78786A75716A74716E736B6D6C5E6E6D606B655A675B526B645A6E6B5E766C66
8A85779F816F72574932251E0F0F0E101114181C2024221E2C251F55474468534857493D
2518151E1310221718170B0A1B0F0D3029275E6F736A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D803F312D3F2F2A2017131F1511
231511271A1B2E26233E3B334C4D4661645B6A6C5F6A69616A6D686A6C656A716D6A7573
6A797A6A78786A716C6A716B6A74716A70686A6C6268665B67685C67605667615767615A
696356686856796C5789765E846F56664F3A5A41316D5041736656634E4C4F4A4344463B
281A162115111B141015100C1B18152C2C2A5C6C706A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D803C2A202C1F162A1D19231612
25100C2918142E20172F292444413C5E5C5467695F6A6C666A706A6A78786A716B6A716D
6A75736A75736A716C6A716B6A6A5E6A6A656A665F685B5267615767685C676056675D51
65594D68534968584D67594D7765577F6E5C81715F73615269534E655446604D3E3E2B21
2517132115112A19162016121F1511271D15362F3253585F6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D8032261D302B28291F1B2A1A16
19110D1B14101B1210281E1931281E4E4A436A685F6A6C666A706A6A74726A797A6A716B
6A716D6A6D666A6D666A716B6A6D636A6C5F64635664655A676056675A51675D54676056
655C525D584D5D584D6461555D564B6051476054495250454C4F434C4F433F40351F1D1C
130E0B201819181011160F0C1107071E1413342F2F5561636A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D803F2C233025223027232A201B
2C1B17241612291E1A312C29302F2C454542615A536A69636A69646A69626A716D6A797A
6A78786A716C6A716B6A716B6A6D6B64665F646358675D54675D546760566160565E594F
61594F61584D60584D60554B64584D5D564B5A5449585045624F445D493E392C27241613
2B1E1A160C0C170F101208081A11111F1511343635596C706A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D8036312E322C29342C28332925
2A1B1719100C24171435221B4C3528563D2E5A524967685C6A6C646A69646A69626A716D
6A75736A797A6A75716A716B6A6D676E70666B685D6161565E594F63565365564F645349
64534F61554D60584D6051475A4F455A514757473D604A4156433938312D2A1F1A251714
170F0B181010160C0C1A110C1B11112819168DA9A98FAEAE6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7679646B6F3227242B23203028252E2622
1F15112A1E1B2B201C26211E3B332A50453C5A585266675E6A6C666A736D6A736D6A7472
6A75736A75736A716C6A716B64675A676257685B526B5D546E6358645F51615C4F64584D
5D5E505D5A4D5A4B47574E475A54495D5449605247545146474237493A2D2F2219261815
1E15121E16111F17111B120D1D15112719155D6E726E81846A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A81846E888A30272235241C302420312926
362C272C201C2B221E3022193A3A3339362D4C413B5E59526769636A69646A6D686A6C65
6A69606A69606A6760646055645D5263655B6461576159495E564A615949645C4F645F53
61584D60554B6457496056495D4D435D4A41524D4347433941352B291F1E1F1414191310
17100C181010150B0C0E0708130A0C352623647073687A7E6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D8041322E2F221A302926332B27
29211D2618142F20182F2623322F292F231E3D35305A5A536A6C5E6A6C5D6A69616A665B
6A66586A66586A6A616E70666B685D675A51614F46615049645350645953645C53644F45
6153496051476051475E54495D504557493E494137413329291E1E241C161E14101C1411
2215111B1111160C0C180C0D2E1B17AFD2CB9FC5C36A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D804C4944342C282C2523342825
3222192D241E261D1B2B2422251D1B26252434332B433C3258544B61625967695C6A6C60
6A6C6264665C61625667695D685E556151486159495D54475955495955496053495D5248
5D5147604B475A51495A5443574A3D52493E494237342520281D161C130F160F0B181010
1F14111A1111130808160C0C251815546468687A7E6A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80464138352C27342C282C2522
2C262322181A251B1928201C332B272F2119271D182D2E2B413B3756454060554E615951
615F5764665C676258635B535E5C525B5348594C455D4F47604A41604C435C4F455D5147
5A4D43574D4155463B4F423B444139393229392C23281E171A120F19131019110C160C0C
140B0C0D07070E08082A1A16372016606C6C6A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D8078818E4637343329262E2622
37302C36261B2B1A15342A272A211D2F2927241D1B2327251C201F242220443B374E433C
504848534B4D534E495A574F554B423F372F3A332C48382C54483D574C43573F3657453D
5A4D3857493A5243394E3D34483D34382924281A162114131F141119100C150B0C160C0C
1308080F0808170C0D1F141190B0B29DC0C06A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D807E9A964F4C3D2B231E2B2320
2B232023201D21191B2A1F182F2420372F2C382F2B2D25232C28282E2B2826231F212226
1B2223211F1A302B2633302B2A2726302923312820302E23372C244033274D4131493D31
392D283B2B2643332B3934303024222B1A152416131D131017100C150B0C1208080E0808
0E08080F08081E16112B1B166273766D83866A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80606572392F2D342C28
302C283128241D151125201C352F2D37302C3B3531413A35443E333D3B312F322C282422
291C17251A1B241A1A29201F261F202421232E232130221A28201D2E2A252E2B252C2720
362E2531281F2B29252E211D2C1F19201614221C1918110C18100C160C0C1308080F0808
0F08082516121C11125F58558495946A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80809195483833302522
2D23202E2421362A263B302C372F2C3934303028252B24222E1F1E37211D341F192A211F
201B182523211E16141E1D1D252120241F1B1C15131917171914131810111915131C1915
1C18151A12121B11111912111C1412181310150F0B140B0B150B0C160C0C0F08080F0808
25161C251613362A2590B0AD86A7A86A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80728A87717C7A3B322D
2E2522332B273027233A343029211D2D2826271F1C2E27243E362D302D292826242C2523
2C231E382B28261A1B23201D2216132415121E13101913101C13102318152317151B1210
19110F1A12102218151E14111D131018100C19100C160C0C160C0C0F08080F0808170C0D
2A1F192C1B16A5C1BFA1C1BF6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80757D85452F2B
362B27332B272E2622211D1A312C2A3E3733322E2A29211D2C201A221816251D1A281F1C
1D171D1E1D1C2018182717141F13191913111A141118100C1B141019141018131016100C
130B0C160F0C1C131017100C130B0C18100C1A1111160C0D0F0808160C0C22171231221C
2C1B16A7C8C5A7CBC86A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D8077928F585951
342C273028252E2622362C282F2A272B2623271E1B251B18211A181C1310271F1C221719
2317181F130F1E1217160F11120B0B170F10181011150B0C180F11150B0C170F10150B0C
1A11111E1612191111150B0C0E08080E07080D07070E07071A11111C120D160C0C1C0E0B
98ADACA3C3C06A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D809ABBBB
6D69613026212B23202C29262D2926352F2B32282A291916271C191C15111C131019120F
1E130F140B0B130B0B1810101A1111160C0C191010160C0C191011160C0C2B1A15100808
1810101D15111A11110F08080F08081308081C11121E13131B11122B1A163D281D72523B
8A978F6D83866A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
9ABBBB6F635B39322E29211D352C29372F2B38302C2A26202B242023161B1910121F1411
1910111D15112017121B1211160C0C160C0C160C0C160C0C160C0C1D151118111130313E
3A3A3C26191F170C0D1B11112218132218131B121230251F32231D2B1B1646302995B8BE
89B1B76A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D80A2C9C86F635A4438332A211D27242235322E3E342F35251B2B1F19201711191111
150B0C180F0C181010150B0C160C0C1A1111170C0D1A1111170C0D150B0C2D2D2F2B1F28
3C302C4C40364335324C3E373A2B242017122B1F1A2A1E1A342C284C3228A3BDBB92B7B9
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D8067797D97BCBC614F40453A34392E2A38312E3A34303F3A362C211D2B1F1B3B2D27
342B242719131F16111B12111B1212160C0C160C0C1D151A1B12121F1712170E0E211C17
29221D120B0D120D0C130E0C120C0D1D1210281C19302219543B2B919B9F89ADB46A8083
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D809EC7CA6160522C221D2A24223E3937474743463F392E221D201618
2415133428243028231C1212160C0C221A1F261D232D2721261D213C312E23191E3F3734
352A2B382C273D2F293628233C2E284D43353B30295D4737A5BFBF98C5C5748D8C6A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D809EBFC2B6C7D1584F482E272429222133373F4E4B485D544B
5C5D543830302C2C2F49485668655D453633332C36342A2C47434F3B322F362B2439302B
372A263B27223B251D382C2746392F5C423242291E89ACB089B5BA6A80836A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D807A9693B2DAD569646C413A3730303543484C484D51
4142404A4A445B5A57564D43443C3539302C42392F342927251C17271F1B362F2B332B27
3D28214930264B392F59463B472C23464148A1CED89BC1C26A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A72766A797D6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D809EBFB8CEFBF1C8DEE05A57664E4A51
7273856F6A715A4B46473F3B44403D5A4F516354505B514A6C5E555B5143544E47625750
4F4C4140463C302B295E6776B0E2EABCF7F289AAA86A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A84876A80836A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80728A87A4C5B6B6DFD2
9DC5B88DA8B1A3C4CA96A8BA5B6076444D613C3F403E3D3A3D3C3A413F3E3F3A39322B24
332E288EA4A7D2FFFDAFDFD67A97946A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D80728A84708B877A9992A3C6B4B8DDC8BCE5DBBFE1DFBFE8E5BFECE9C3F0ECC9FBFA
CCFDFF95B8BA6A80836A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D806A7D80
6A7D806A7D806A7D806A7D80
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?oooeUZOH04J6aS16Y/HP=ZK6H4JW1Z16Y]I`AZL6X;JW5[16Y]
I`AZK6<4J6UO16MUFPAUGE84I5aA0f5HCA1PF4d4H5A90eiDA@AME4P4GEA515eDB0AWM7H?JWf016Yj
O@AZO7lSJWf05Oooo`005?oooeUZOH04J6aS16Y/HP=ZK6H4JW1Z16Y]I`AZL6X;JW5[16Y]I`AZK6<4
J6UO16MUFPAUGE84I5aA0f5HCA1PF4d4H5A90eiDA@AME4P4GEA515eDB0AWM7H?JWf016YjO@AZO7lS
JWf05Oooo`005?oooeUZOH04J6aS16Y/HP=ZK6H4JW1Z16Y]I`AZL6X;JW5[16Y]I`AZK6<4J6UO16MU
FPAUGE84I5aA0f5HCA1PF4d4H5A90eiDA@AME4P4GEA515eDB0AWM7H?JWf016YjO@AZO7lSJWf05Ooo
o`005?ooo`AZOH04JWIi16YiO@AZOH04JWIi0fYiOB=ZOH04JWIi16YiOAMZOH04KW=Y16e_K0=ZK684
JW1W16Y]I`AZL6X4JW5[16YZGP=TH584HF1B165LD@ANEDh4Ee5915MAB0AIDdT3F4m515eEB`QPF4d8
H5570eiDB`AME4X4GEA515e_KPAWQH/?JWf016Z1Q0AZP8<SJWf05Oooo`005?ooo`AZOH04JWIi16Yi
O@AZOH04JWIi0fYiOB=ZOH04JWIi16YiOAMZOH04KW=Y16e_K0=ZK684JW1W16Y]I`AZL6X4JW5[16YZ
GP=TH584HF1B165LD@ANEDh4Ee5915MAB0AIDdT3F4m515eEB`QPF4d8H5570eiDB`AME4X4GEA515e_
KPAWQH/?JWf016Z1Q0AZP8<SJWf05Oooo`005?ooo`AZOH04JWIi16YiO@AZOH04JWIi0fYiOB=ZOH04
JWIi16YiOAMZOH04KW=Y16e_K0=ZK684JW1W16Y]I`AZL6X4JW5[16YZGP=TH584HF1B165LD@ANEDh4
Ee5915MAB0AIDdT3F4m515eEB`QPF4d8H5570eiDB`AME4X4GEA515e_KPAWQH/?JWf016Z1Q0AZP8<S
JWf05Oooo`005?ooo`AZOH04JWIi16YiO@AZOH04JWIi0fYiOB=ZOH04JWIi16YiOAMZOH04KW=Y16e_
K0=ZK684JW1W16Y]I`AZL6X4JW5[16YZGP=TH584HF1B165LD@ANEDh4Ee5915MAB0AIDdT3F4m515eE
B`QPF4d8H5570eiDB`AME4X4GEA515e_KPAWQH/?JWf016Z1Q0AZP8<SJWf05Oooo`005?ooo`AZOH04
JX6416YiO0AZNGd4JX640fZ0P`AZOH04JWIi16YiO@AZMWT4JWUm3fYmP0AZPH@4JX235fYmP0ATJF04
IfUL0fY/I`AZJFH4JW5[16Y/I`AZIV84I6=K0e9OG0AFF584GT]915];A@AMETd4H5mC161QE@=TGE44
GEA925M?A@AGDDL4EeA30eYDA`AME4T4GEA;17N=TPAgT9@CJWf016YfN@AZNGdOJWf05Oooo`005?oo
o`AZOH04JX6416YiO0AZNGd4JX640fZ0P`AZOH04JWIi16YiO@AZMWT4JWUm3fYmP0AZPH@4JX235fYm
P0ATJF04IfUL0fY/I`AZJFH4JW5[16Y/I`AZIV84I6=K0e9OG0AFF584GT]915];A@AMETd4H5mC161Q
E@=TGE44GEA925M?A@AGDDL4EeA30eYDA`AME4T4GEA;17N=TPAgT9@CJWf016YfN@AZNGdOJWf05Ooo
o`005?ooo`AZOH04JX6416YiO0AZNGd4JX640fZ0P`AZOH04JWIi16YiO@AZMWT4JWUm3fYmP0AZPH@4
JX235fYmP0ATJF04IfUL0fY/I`AZJFH4JW5[16Y/I`AZIV84I6=K0e9OG0AFF584GT]915];A@AMETd4
H5mC161QE@=TGE44GEA925M?A@AGDDL4EeA30eYDA`AME4T4GEA;17N=TPAgT9@CJWf016YfN@AZNGdO
JWf05Oooo`005?ooo`AZOH04JX6416YiO0AZNGd4JX640fZ0P`AZOH04JWIi16YiO@AZMWT4JWUm3fYm
P0AZPH@4JX235fYmP0ATJF04IfUL0fY/I`AZJFH4JW5[16Y/I`AZIV84I6=K0e9OG0AFF584GT]915];
A@AMETd4H5mC161QE@=TGE44GEA925M?A@AGDDL4EeA30eYDA`AME4T4GEA;17N=TPAgT9@CJWf016Yf
N@AZNGdOJWf05Oooo`005?ooo`QZOH04JWYm16YlO`]ZOH04JX6416Z0P`AZPH@4JX23;VYmP0A^K6<4
KFaY0fY/J@AZK6L4JVUT16YZI@AZK604KW1Z0gefLPAhMFT4M6aZ16mTFPA[F4d4Je=?16]CD@=TBDP4
GTi735eDB@AME4/3HeY@161FB`AME4T4IgAf5fYmP0AZPH@4JX237fYmP1Goool001Coool8JWf016Yj
O@AZO7l;JWf016Z1Q0AZP8<4JX6416Z0PbiZOH04KVaS16e/J@=ZK6T4JVaW16YYI0AZJVD4JVaP16i`
JP=mMW84N7EY17A/JPA_I5X4JeQ=16]CC`A[De43I4U815i>A`aME4T4GEA;0f=JD0APET/4GEA916Md
MQMZOH04JX6416Z0PamZOH0Eoooo000Doooo26YmP0AZNWd4JWao2fYmP0AZPH@4JX2316Z1Q0AZP8<^
JWf016i/H`A]K6T3JVaY16Y/I`AZJF@4JVYU16Y/H0A^L6X3OGIb17QeJ@AdK6X4KfAJ16]HC@A[Ddl4
Je=A0fA9B0ANCTL<GEA915eDB`=SFU04H5I;15eDB@AWM7HGJWf016Z1Q0AZP8<OJWf05Oooo`005?oo
o`QZOH04JWYm16YlO`]ZOH04JX6416Z0P`AZPH@4JX23;VYmP0A^K6<4KFaY0fY/J@AZK6L4JVUT16YZ
I@AZK604KW1Z0gefLPAhMFT4M6aZ16mTFPA[F4d4Je=?16]CD@=TBDP4GTi735eDB@AME4/3HeY@161F
B`AME4T4IgAf5fYmP0AZPH@4JX237fYmP1Goool001Coool8JWf016Z1Q0AZP8=9JWf016YcJ@AZKf43
JVaM16Y/I0QZK6L4JVaZ16YcL0=ZMg04KW=`16McI0AXJF04KVQO16i[G0AXGE<3KV]L16]GC`AVBTT4
IUeK161IC`ASE4T3He5715iAA`ASH5@4Jgam?VYmP1Goool001Coool8JWf016Z1Q0AZP8=9JWf016Yc
J@AZKf43JVaM16Y/I0QZK6L4JVaZ16YcL0=ZMg04KW=`16McI0AXJF04KVQO16i[G0AXGE<3KV]L16]G
C`AVBTT4IUeK161IC`ASE4T3He5715iAA`ASH5@4Jgam?VYmP1Goool001Coool8JWf016Z1Q0AZP8=9
JWf016YcJ@AZKf43JVaM16Y/I0QZK6L4JVaZ16YcL0=ZMg04KW=`16McI0AXJF04KVQO16i[G0AXGE<3
KV]L16]GC`AVBTT4IUeK161IC`ASE4T3He5715iAA`ASH5@4Jgam?VYmP1Goool001Coool8JWf016Z1
Q0AZP8=9JWf016YcJ@AZKf43JVaM16Y/I0QZK6L4JVaZ16YcL0=ZMg04KW=`16McI0AXJF04KVQO16i[
G0AXGE<3KV]L16]GC`AVBTT4IUeK161IC`ASE4T3He5715iAA`ASH5@4Jgam?VYmP1Goool001CooomI
JWf016Y`I`AZK683JVaY16Y/HPAZK6@4JVaW16YcK@AZK6L3JVIR16YaJ`A^Lg04LGY]16]aH@AWHeh4
JfIK0fAND@AUG5<4I69C161CA0ATG5H4GEU?0eMDB@AJE4T4K7Ih1727SA]ZOH04JWIi16YiOA]ZOH0E
oooo000DooooFFYmP0AZL6L4JVaR0fY/J@AZK684JVaT16Y/I`AZLfd4JVaW0fYVHPAZLF/4KW=`175j
K@A[LF44If=N16]VF`=TGU44IEaC16ARD`APDd@4I5aF15eIC`=GE4T4FUA916afN0A`QhdKJWf016Yf
N@AZNGdKJWf05Oooo`005?oooeUZOH04JW1W16Y/HP=ZK6T4JVaR16Y/I0AZK6L4JW=]16Y/I`=ZIV84
JW5[16icL0AaNVd4Jg5Q16MSGPA[IU/3I5iA16ELD`ATHU<4H5=416ALEPAMFDl3EeA915YDB@A/MWP4
L8N=6fYmP0AZMWT4JWUm6fYmP1Goool001CooomEJWf015Q9@`ANDd/4JVaY0fY/HPAZK604JVaV16Yc
K@AZK6L4JW5[0fYgL0AZLfd4JVeW16Y/JPA^K6@4LF]L16]SEP=[HeP4J5]C16QHC@ATE4T4FTi215Y?
A0=SE4T4H5A916AfNPAZPXLKJWf016Z1Q0AZP8<7JWf016YfN@AZLWH4JWUm26YmP1Goool001CooomE
JWf015Q9@`ANDd/4JVaY0fY/HPAZK604JVaV16YcK@AZK6L4JW5[0fYgL0AZLfd4JVeW16Y/JPA^K6@4
LF]L16]SEP=[HeP4J5]C16QHC@ATE4T4FTi215Y?A0=SE4T4H5A916AfNPAZPXLKJWf016Z1Q0AZP8<7
JWf016YfN@AZLWH4JWUm26YmP1Goool001CooomEJWf015Q9@`ANDd/4JVaY0fY/HPAZK604JVaV16Yc
K@AZK6L4JW5[0fYgL0AZLfd4JVeW16Y/JPA^K6@4LF]L16]SEP=[HeP4J5]C16QHC@ATE4T4FTi215Y?
A0=SE4T4H5A916AfNPAZPXLKJWf016Z1Q0AZP8<7JWf016YfN@AZLWH4JWUm26YmP1Goool001CooomE
JWf015Q9@`ANDd/4JVaY0fY/HPAZK604JVaV16YcK@AZK6L4JW5[0fYgL0AZLfd4JVeW16Y/JPA^K6@4
LF]L16]SEP=[HeP4J5]C16QHC@ATE4T4FTi215Y?A0=SE4T4H5A916AfNPAZPXLKJWf016Z1Q0AZP8<7
JWf016YfN@AZLWH4JWUm26YmP1Goool001CooomAJWf012PR7`@n?cP4L7AV16Y/IP=ZK6X4JVa]16Y/
J@AZL6X4JVeW16YYG@=ZKFD8JVYU16Y/H0AZL684I65M16AMEP=WFEH4IEa<15eDA@AMF4d4I5I;161D
B@=OH5@4I5mC16j0P0A]PhHZJWf016Z1Q0AZQ8L4JX2326YmP1Goool001CooomAJWf012PR7`@n?cP4
L7AV16Y/IP=ZK6X4JVa]16Y/J@AZL6X4JVeW16YYG@=ZKFD8JVYU16Y/H0AZL684I65M16AMEP=WFEH4
IEa<15eDA@AMF4d4I5I;161DB@=OH5@4I5mC16j0P0A]PhHZJWf016Z1Q0AZQ8L4JX2326YmP1Goool0
01CooomAJWf012PR7`@n?cP4L7AV16Y/IP=ZK6X4JVa]16Y/J@AZL6X4JVeW16YYG@=ZKFD8JVYU16Y/
H0AZL684I65M16AMEP=WFEH4IEa<15eDA@AMF4d4I5I;161DB@=OH5@4I5mC16j0P0A]PhHZJWf016Z1
Q0AZQ8L4JX2326YmP1Goool001CooomAJWf012PR7`@n?cP4L7AV16Y/IP=ZK6X4JVa]16Y/J@AZL6X4
JVeW16YYG@=ZKFD8JVYU16Y/H0AZL684I65M16AMEP=WFEH4IEa<15eDA@AMF4d4I5I;161DB@=OH5@4
I5mC16j0P0A]PhHZJWf016Z1Q0AZQ8L4JX2326YmP1Goool001Coool8JWf016YfN@AZNGdmJWf0159E
G`@R4Q44BTY@16e_I`AZLfd3JW1Z16YcK@AZL6X4JVUT16YaJ`AZMg@3JVaY16YZGPAZF5L4I4m<15]9
@`AQED/4If1D0f5SEPAKF4h4I5Q?16AJCPAJE4<4FUA70eY>A@AGCD<4I75c@VYmP1Goool001Coool8
JWf016YfN@AZNGdmJWf0159EG`@R4Q44BTY@16e_I`AZLfd3JW1Z16YcK@AZL6X4JVUT16YaJ`AZMg@3
JVaY16YZGPAZF5L4I4m<15]9@`AQED/4If1D0f5SEPAKF4h4I5Q?16AJCPAJE4<4FUA70eY>A@AGCD<4
I75c@VYmP1Goool001Coool8JWf016YfN@AZNGdmJWf0159EG`@R4Q44BTY@16e_I`AZLfd3JW1Z16Yc
K@AZL6X4JVUT16YaJ`AZMg@3JVaY16YZGPAZF5L4I4m<15]9@`AQED/4If1D0f5SEPAKF4h4I5Q?16AJ
CPAJE4<4FUA70eY>A@AGCD<4I75c@VYmP1Goool001Coool8JWf016YfN@AZNGdmJWf0159EG`@R4Q44
BTY@16e_I`AZLfd3JW1Z16YcK@AZL6X4JVUT16YaJ`AZMg@3JVaY16YZGPAZF5L4I4m<15]9@`AQED/4
If1D0f5SEPAKF4h4I5Q?16AJCPAJE4<4FUA70eY>A@AGCD<4I75c@VYmP1Goool001Coool8JWf016Z1
Q0AZNG`4JWUm=FYmP0AaQHL481H@17AbFPBQXH@4JVaW16YYIP=ZJVD4JVUT16YZI@AZK6L4JVUT16Y]
J0=ZKFL4I6IM165OEPATH5@4IEaB161ICPANET`3HEI7165FB@ALDDL4GDm516AAB@AVE4X3H5A916=J
CPATGET4Ife^?VYmP1Goool001Coool8JWf016Z1Q0AZNG`4JWUm=FYmP0AaQHL481H@17AbFPBQXH@4
JVaW16YYIP=ZJVD4JVUT16YZI@AZK6L4JVUT16Y]J0=ZKFL4I6IM165OEPATH5@4IEaB161ICPANET`3
HEI7165FB@ALDDL4GDm516AAB@AVE4X3H5A916=JCPATGET4Ife^?VYmP1Goool001Coool8JWf016Z1
Q0AZNG`4JWUm=FYmP0AaQHL481H@17AbFPBQXH@4JVaW16YYIP=ZJVD4JVUT16YZI@AZK6L4JVUT16Y]
J0=ZKFL4I6IM165OEPATH5@4IEaB161ICPANET`3HEI7165FB@ALDDL4GDm516AAB@AVE4X3H5A916=J
CPATGET4Ife^?VYmP1Goool001Coool8JWf016Z1Q0AZNG`4JWUm=FYmP0AaQHL481H@17AbFPBQXH@4
JVaW16YYIP=ZJVD4JVUT16YZI@AZK6L4JVUT16Y]J0=ZKFL4I6IM165OEPATH5@4IEaB161ICPANET`3
HEI7165FB@ALDDL4GDm516AAB@AVE4X3H5A916=JCPATGET4Ife^?VYmP1Goool001Coool8JWf016Yf
N@AZOH04JX23=FYmP0@G3@/4J6EM1:FVV@A]KfL4JVaV1fY/I`AZK604JVaT16Y/I`AZLfd4JVaW0fYZ
I@AX?T84Ic4h164/<PAQ:S44I2/c16A4@PMMCDD4H4]215YA@@AME4L4H5A90eiD@`AOBSl4Dchd15iQ
GbYZOH04JWIi16YiO@aZOH0Eoooo000Doooo26YmP0AZMWT4JWf016Z0PcEZOH045`d;16QUG@BUYYT4
KFmW16Y/IPMZK6L4JVaP16Y/I0AZK6L4JW=]16Y/I`=ZJVD4J3i216La>0AQ;384HBXa16@[<`ATA487
GDe5161;@PAJDD44GEA7161DB@=NE4<4GdXo15<n=0ANHElZJWf016YfN@AZNGd<JWf05Oooo`005?oo
o`QZOH04JWIi16YmP0AZP8<eJWf011L=2`AXIEd4YJJI16e_I`AZK6H7JVaW16Y/H0AZK6@4JVaW16Yc
K@AZK6L3JVYU16Pn@PAW<CP4HB`b164Z<@AT:c<4I4A21ee=A@APBd84FU5115eDA`APE4T3GUA315m:
?`AC?S@4GV5O:VYmP0AZMWT4JWUm36YmP1Goool001Coool8JWf016YfN@AZOH04JX23=FYmP0@G3@/4
J6EM1:FVV@A]KfL4JVaV1fY/I`AZK604JVaT16Y/I`AZLfd4JVaW0fYZI@AX?T84Ic4h164/<PAQ:S44
I2/c16A4@PMMCDD4H4]215YA@@AME4L4H5A90eiD@`AOBSl4Dchd15iQGbYZOH04JWIi16YiO@aZOH0E
oooo000Doooo26YmP0AZPH@4JX23=VYmP0=BEET4VY^G19fKT0AZJVD4JVaS16Y/IPAZK6L3JVIJ16YR
E`AZHUH4JVUQ16YYI0AZEUP3JTmD16Q8B0AQ?cP4FblW160l>0AM?CD4H3Dg0e/f>0AGACl4EeA315Y?
A0AODDP4H5A90fADB`ASD4H4I5U>15Q0=0ANF5@VJWf016Z1Q0AZP8<<JWf05Oooo`005?ooo`QZOH04
JX6416Z0PcIZOH03DUEI19ZKU`BMVi04JVYU16Y/H`AZK6H4JVaW0fYVFPAZHUL4JV9F16YYH@AZJF@4
JUIH0fY?E0AXB4P4HClh15/_9`AP?3P4GCde160e=`=K=SP4EdDo15MD@`AJCd@4Ge58161DB@=TE4/4
He1616AICPAH@3@4GUQD9VYmP0AZPH@4JX2336YmP1Goool001Coool8JWf016Z1Q0AZP8<fJWf00e9E
F@BJViL4WI^@16YZI@AZK6<4JVaV16Y/I`=ZIUX4JV9G16YREPAZJF44JVUT16YFF0=ZCe@4J4Q8164o
>0AK;bL4H3`h15dm=@AP=CL3FcHh15M5?`AGE4<4FTm415mAB0APE4T3I5A;16=@APATFDh4F40d15iH
E2IZOH04JX6416Z0P`aZOH0Eoooo000DooooAVYmP0<K5A<4:bdY16YYF0AZK5d4JVaP16Y/IPAZK603
I6=F165HD0AWJ5l4JVmX16YOE0AT?S/3Fb`X15E2>PA7=2L4DfYH16=kJ@AK=bd4DbPQ0edb;@AP?SX4
GDi815e@>`AJDcl4GEA70f1DB@APEd/4H5=8161EB`AXJ6<4JWEe=VYmP1Goool001Cooom6JWf00a/E
4`@[;BT4JVUH16Y/G@AZK604JVaV16Y/H0=THeH4HEQ@16MXG`AZKfP4JUmD16@n>`=K;2P4ED8j14Ld
9`ACJUP4Hg]Y15/g;@AC:243GC8]160n>PAMCTP4GE0k15YC?`AME4L3H5A9161GB`APDdP4H5E;16QX
H`AZMGDfJWf05Oooo`005?ooodIZOH036aDC12/]:@AZJEP4JVaM16Y/H0AZK6H4JVaP0fASEPAQF504
IfQO16Y_J0AZGe@4I3hk0e//:0AE@SX4Ac@W15=ZF0ASNfT4FcL]15<X8@=M<Rd4H3hj15e>B0AMD3/4
FU<o15eDA`=PE4T4H5M;161CB0APED/4J6QS16YeMCIZOH0Eoooo000DooooAVYmP0<K5A<4:bdY16YY
F0AZK5d4JVaP16Y/IPAZK603I6=F165HD0AWJ5l4JVmX16YOE0AT?S/3Fb`X15E2>PA7=2L4DfYH16=k
J@AK=bd4DbPQ0edb;@AP?SX4GDi815e@>`AJDcl4GEA70f1DB@APEd/4H5=8161EB`AXJ6<4JWEe=VYm
P1Goool001Coool@JWf016YfN@=ZNGd[JWf013hi?@=[EDL4THUd16e_K0ATGeT4IfaZ16Y`K0AZGeL3
HU9415M2>@AQBTl4GR/a124410@^:bd3HEM=16iWG`B7/jh4Ndi815D`:`A4AC44B61B0cDg:@A69R04
EcTc15Y:>@ASC4@4HeM>0fMSD@ATFD/4H5Y>161DB@AE@CL4GU9<16YeMC9ZOH0Eoooo000Doooo46Ym
P0AZMWT3JWUm:fYmP0@n>Cd3JeE71969M0A]Kf`4I5mI16M/JPAZL6`4JUmG0f9BA0AG@ST4HDY?15h[
<@@Q10@4;R/]0f5GC@A^Iel4Qk>^17]>B0AE<2/4A4Da14QPDP<e=bT4ARHP15Li<`AJBST4Hda416=G
CP=WHe44I5U;161JCPAPE4T4ED4g15iBC0AZMGDbJWf05Oooo`005?oooa1ZOH04JWIi0fYiOB]ZOH04
?STm0f]EA`BARG@4KFm/16AOF@AWK6X4JW1/16YOE`=RDT@4Ed8i165:C`AN:c448@@412h[;@=QEdd4
KVMO18Nc[PAkCTP4EC0[14A5<@A8H583=CLY14HV80AG>C<4FTXi16=<A0ASEdh3If=A16AIB`APFTh4
H5A915E1=`ANDT`4JWEe<VYmP1Goool001Coool@JWf016YfN@=ZNGd[JWf013hi?@=[EDL4THUd16e_
K0ATGeT4IfaZ16Y`K0AZGeL3HU9415M2>@AQBTl4GR/a124410@^:bd3HEM=16iWG`B7/jh4Ndi815D`
:`A4AC44B61B0cDg:@A69R04EcTc15Y:>@ASC4@4HeM>0fMSD@ATFD/4H5Y>161DB@AE@CL4GU9<16Ye
MC9ZOH0Eoooo000Doooo26YmP0AZMWT4JWUm16Z1Q0=ZP8<[JWf012DO70=>ETl4NGef16Y/HPAXGU<4
JVAO16YZI@AZIU`3Gd@g15Pl<`@U2@P4;4=519SSe0BMe//3N;Zo17B_]`A]QhT4K8ei182l/PB>/K<4
JGYk0d4c;0@M7A<4;bHN15U8?PAODTP4IeeB0fMNE@AXHU44I5I9161AA`APEd`4EF5d15UVM0=WMGT_
JWf05Oooo`005?ooo`QZOH04JWIi16YiO@AZPH@3JX23:fYmP0@U7a`3CUI?17UmMPAZK684J5iC16YT
G`AZJVD4JVIL0em4=`AH?3<49@T812a3A@BHhm@4WMK;0gRj_`Ad[kL4KHN916b=N@B0_;84S[6c16Uj
N`=1<b`47AdC12lV7PAIB3h4Ge9816MMDP=WGUD4J69A16AFB@APDDL4H5M<15EQM0AIIW@3IgEi;fYm
P1Goool001Coool8JWf016YfN@AZNGd4JX640fZ0Pb]ZOH049AlL0diFC`AiOGH4JVaR16QND`AZI5l4
JVYU16YVG0=OA3L4F3`c12D920@/@dD4V>?D19gFb`=h^[l4M:ng16f7R@A/SGT4P;bb18ja/`AYNW/3
@C</11dM4`@_9Qh4FDPn15mBB0AWGE83IeiE16QRD@ATETT4H557161GC0AEHG@4FFId0fMeNBmZOH0E
oooo000Doooo26YmP0AZMWT4JWUm16Z1Q0=ZP8<[JWf012DO70=>ETl4NGef16Y/HPAXGU<4JVAO16YZ
I@AZIU`3Gd@g15Pl<`@U2@P4;4=519SSe0BMe//3N;Zo17B_]`A]QhT4K8ei182l/PB>/K<4JGYk0d4c
;0@M7A<4;bHN15U8?PAODTP4IeeB0fMNE@AXHU44I5I9161AA`APEd`4EF5d15UVM0=WMGT_JWf05Ooo
o`005?ooo`QZOH04JX6416Z0PbiZOH04F65c12LG5P=@DTd4JVaN16Y/H0A^MfX4KGE]16Y/I`ANC4@3
Bcl^14@U70@h4P/4GSD_16Tm=@AQ?SL3IeYF16YTDPAZGd`4HT]5161FFPANB3d4OFaO0h]kH`B3Ofl4
<bPO130Q7PAC?CT4GeY:0fYZF`AXHUP4HE]A161?A@APCTD4FUU914]<@@=9CU`4GVei:fYmP1Goool0
01Coool8JWf016Z1Q0AZP8<^JWf015QQL`@W5aH3D59=16Y/GPAZK604KWMZ16eeK@AZK6L4GTa40d/o
;PA49A`4>18;15he;`AY?CD4HChg0fMJEPAZI584JUm<169;A@APEUX4GTPm17e/G`>;Nf<4Pgm_13<X
7`@`8Ah4Dcdi15mJBP=ZJU/4J69H165KD@APCdD4H4i515YIB@A;C443BDiL15i]NB]ZOH0Eoooo000D
oooo26YmP0AZPH@4JX23;VYmP0AHHG<49aLF0e1BC@AZK5h4JVaP16igJPA]MFd4JVaW15i<A0=;?bh4
A2DL13PB2`AN=Bl4JCde164n=`=WFUH4JVAB16YOC0ARBdD4H5IJ15i8?@AmK5l3Rg]S18=oK`@c:1l4
<24N15<m>@AOFTX3JVYK16QRF0AQFe44H4m5161>A@AJFDT4Bda10dU>G0ANKGT[JWf05Oooo`005?oo
o`QZOH04JX6416Z0PbiZOH04F65c12LG5P=@DTd4JVaN16Y/H0A^MfX4KGE]16Y/I`ANC4@3Bcl^14@U
70@h4P/4GSD_16Tm=@AQ?SL3IeYF16YTDPAZGd`4HT]5161FFPANB3d4OFaO0h]kH`B3Ofl4<bPO130Q
7PAC?CT4GeY:0fYZF`AXHUP4HE]A161?A@APCTD4FUU914]<@@=9CU`4GVei:fYmP1Goool001Cooolj
JWf012PR7`@60004Cc/b0iB;N@A]Kf@4JUmF16YID@AZIUX4JVaM16IGBP=cJF04RJB@1;?N^0BMYIP4
KVER165CC`=J@C`4GB/`15D/<`AD:2P4EQLF154I6PA?>SL3ES/b164m?@AWBT<4;a0813T[;@ARE4T3
IV=H16EMC0AQDTD4FUE915eLD0ATEd/4OXF50fYaO0ATLWL[JWf05Oooo`005?ooocYZOH04:28O10H0
00A?>c83U8]i16e_I0AZGeH4JUUA16YVFPAZK5d4IUM:0g=YH0B9Y904/mjh19fUV0A^IF84HE=?0eY1
?0AM:c04EB`c15@X:0AF5aH4DATJ14lj=`=F>c84HCdm16M:@`@_40P4>B/]169DB@=VHeP4IEe<165B
A@AJEDT4GEa@16AGB`AnQHD3JW5l16AbMb]ZOH0Eoooo000Doooo>VYmP0@X8Ql41P0014lk<P>DRgT4
KFmT16YOEPAZFE44JVIJ16Y/G@AVEdX3LfUP18VTT0Bcg[P4WJFH16iUHPAQDdl3FT4l15d[<0AE;3<4
E2PX15HG5PAA6AX4CcXg0eHk<PAQ?Cd4IdY312l@20@i:bd4HUA90fISF0AUGD`4HE9515YEB@AMG504
I5M;17j5Q@=ZLG`4I79g:fYmP1Goool001CooolDJWf00fYfN@AZNGdKJWf015QKI@@C2`X45@l=16Qf
K`=mPg@4JVIL16YKG`ATIf<4IfiT16YHG0AVEDl3DSla161KF0A]MWH4JW]b16j3M`AeTHH3N92417BG
O`AcPVX4MH=]16n:J@A_PFH4IeM90f/m?PAW=2l4GBDK15PM5@A36Q@4AS@c0f9FD0AUFT`4HEE915i=
@`AOCTD4H59911d?30<k?CP4L7ej16MeNBMZOH0Eoooo000Doooo56YmP0=ZMWT4JWUm6fYmP0AHFfD4
4`/:11D?3@AXMVl3OH=d16YVG0AZFel4I6MS16M^I0AZF5`4IUE?0e8o<@APFeP4KGIf16YkLPA^PgL4
MI660gR@Q0AdUgl4Lh9Z17F3K@A_RVT4Kh5V16MGB@=[?Ch4Ic@_15dU6`AH7AD4@aXD14Hd<`=REU04
IEY<165EB@ANCD<4Gdi5161BB@@M3``3>cdh171mNPAWMGTWJWf05Oooo`005?oooaAZOH03JWIi16Yi
OA]ZOH04F5]U11<;2P@E3`d4J7I_0gf3M0AZIU`4JU]O16AWH`AWKV@4JUQL16IEC`=B?c44H5]H16ef
MPAZNg84KX=g17FAQP=hT8@4M9Mo17>2JPAePfd4KhYY16n1IPAWEdT3Jcdn16Ld;`AM9A/4F1dE14<J
50A6=3<3HUI@16EJC0AQEDT4GTe315m>A@APDTT47@l<0c/m>0A`OGX4IgEi9fYmP1Goool001CooolD
JWf00fYfN@AZNGdKJWf015QKI@@C2`X45@l=16QfK`=mPg@4JVIL16YKG`ATIf<4IfiT16YHG0AVEDl3
DSla161KF0A]MWH4JW]b16j3M`AeTHH3N92417BGO`AcPVX4MH=]16n:J@A_PFH4IeM90f/m?PAW=2l4
GBDK15PM5@A36Q@4AS@c0f9FD0AUFT`4HEE915i=@`AOCTD4H59911d?30<k?CP4L7ej16MeNBMZOH0E
oooo000Doooo56YmP0=ZPH@4JX236fYmP0ASLh44akjR1?oAY@BQU7T3IfUM16YYG`AZMf@4KV=Q16eT
HPAZMfD4IVQG0fQHC@AWGeD4If9K16YaJ`AZL6X4JVUT0fYaJ`AZFel4J5QE16MPEPAUG5@4I5Q?15]G
A@=CFDL4F6Y>16MaFPAmOfH4OG=Y16IMA@=LE4H4HEU;165EB@ANEdD4GeI8161GC0@o>SH3BE=B15i`
L0A]PhHWJWf05Oooo`005?oooaAZOH03JX6416Z0Pa]ZOH04Hg>11<NnXPCodJD4XIAi0fMYG@AZJEl4
JWMT16iSH@A]I684JWMU16IXE`=XF4d4IemE16MRF`AZLF/4JW1Z16YYI0=ZLF/4JU]O16QHE@AWH5H4
IEaD16AHC`AKEdD3DeU715QZCPAWLEX4OGmV17ecJ@AVGDD3G5A6165IB`AQEDT4GUM515mFB0APEd`4
?cXf0dUCDPANL704KH>69fYmP1Goool001CooolDJWf00fZ1Q0AZP8<KJWf016=cP@C7_Z84om6U1:6D
N@=WJEd4JVUO16YgI0A^Hf44KFAR16YgI@AVJ5L3J5Q=16MOE@AWHU/4JW5[16Y`JPAZJF@3JW5[16YK
G`AXF5D4If1F16ELE0ATF4l4FeM50e=IA`AHJTh4Ig5J17eoIPAmLfT4IUe50eaDAPAQFD/4HEE915iG
A@AOETP4H5M<13lj=P=9De84GW1`16f3QRMZOH0Eoooo000Doooo56YmP0=ZPH@4JX236fYmP0ASLh44
akjR1?oAY@BQU7T3IfUM16YYG`AZMf@4KV=Q16eTHPAZMfD4IVQG0fQHC@AWGeD4If9K16YaJ`AZL6X4
JVUT0fYaJ`AZFel4J5QE16MPEPAUG5@4I5Q?15]GA@=CFDL4F6Y>16MaFPAmOfH4OG=Y16IMA@=LE4H4
HEU;165EB@ANEdD4GeI8161GC0@o>SH3BE=B15i`L0A]PhHWJWf05Oooo`005?ooocIZOH04Mg1H17A/
GPA^Og`4JgEZ0f=UF`AWK684JVm/16YgK`AZO7H4JW1_16a]H`=/I5H4GDLo15aCBPAWK6@4JWA^1fY`
JPAZN6H4J6UI165=A0AQE4D4F59014e;@P=AAcT4E3le15A2=@AD@CD4EdTe169ND0=VH5P4I5E=15];
@`AJBT<4FU5315MAA@@T6QL3CUab16n4TB]ZOH0Eoooo000Doooo=VYmP0AgL5P4M6aN16ioO0A[MFX3
HfEK16M/HPAZKf`4JWM_16YlMPAZL6l4K6eS0faTEPAMAcl4G5=:16M/I0AZM6h7JW1Z16YhIPAXJET4
HDe4165DA@AHDT04CD]20e57>@AD?cD4E48e15A1=@AGBCD4HUi@0fIPF0ATEDd4Fd]315Y:@`AJDD<4
Ee5512@J5`=>G784KhBA:fYmP1Goool001CooolfJWf017M`F0AdK5h4KWml16]eJP=SIE/4IfaR16Y_
K0AZMfl4JWaf16Y`K`A/KF<3K6AF15e7?`ALDdX4IfaT16YdKPMZL6X4JWQV16QYF@AQCD@4HEA515QB
@0A=Bd83DDLi15@o=@AD@SD4E44e15M9=@ARGU03IV1H16AEC@AKBd<4FTY315YA@`AGDDD491XG0diL
LPA_Q94[JWf05Oooo`005?ooocIZOH04Mg1H17A/GPA^Og`4JgEZ0f=UF`AWK684JVm/16YgK`AZO7H4
JW1_16a]H`=/I5H4GDLo15aCBPAWK6@4JWA^1fY`JPAZN6H4J6UI165=A0AQE4D4F59014e;@P=AAcT4
E3le15A2=@AD@CD4EdTe169ND0=VH5P4I5E=15];@`AJBT<4FU5315MAA@@T6QL3CUab16n4TB]ZOH0E
oooo000Doooo<VYmP0ATKg<4IfUQ16AOD`AKBCX4Ce=I0f5UI0A]K6T4JW=`16YgL0AZLfd4JWA^16iQ
I0=_Heh4K5e?16YJD@AZHEd4JVeX16YIFP=TF544IfIK169KD@AQFDh4F3lh15Q7@`ANA3/3G4Li15Y=
@@APDcd4GE0l15Y7=PAUDdT3IeE;15e?A@AKCT<4GDm415eCBPASFU046a4B0cLo?0AMJVH[JWf05Ooo
o`005?oooc9ZOH04I6mc16MYH@ATGe<4FdTj14mCF@=QIF@4KFaY16YcL0AZMg04JW=]16YdKPA^HF@3
Kf=N16aMC`AZFU44JV5M16Y]J0AZFEX3I5QA16MVF`ARFe44HEU>15Po>0AHAd<4GT@k0ea7>@AJCD44
H5<m15e@?0AJAcH4IE=90fMEB`AMCdD4Fdi315e?A0AMDdX4HeY@11/A4P<g?c`4GFYV:fYmP1Goool0
01CooolbJWf016A_L`AWJF44I5mC15]9>PA?DeT3HFET16e/J@AZLg04JWM`16YcK@AZM6h4KV5T0fmS
GPA/GDl4JUYA16YQG@AZKFP4JUUJ0fAHD@AWIU/4HU]A165ICPAH?cP4F4M315i4>`=LAcT4FTe1161C
?@AMD3`4FTLf16ECB@=WED/4GDm515]>@`AMCd@4GE=:16=JD0@K4A83=cll15eZIR]ZOH0Eoooo000D
oooo<VYmP0ATKg<4IfUQ16AOD`AKBCX4Ce=I0f5UI0A]K6T4JW=`16YgL0AZLfd4JWA^16iQI0=_Heh4
K5e?16YJD@AZHEd4JVeX16YIFP=TF544IfIK169KD@AQFDh4F3lh15Q7@`ANA3/3G4Li15Y=@@APDcd4
GE0l15Y7=PAUDdT3IeE;15e?A@AKCT<4GDm415eCBPASFU046a4B0cLo?0AMJVH[JWf05Oooo`005?oo
oc9ZOH04KVQH16eWGPARF544Fe5:16iVEP=cGEX4JVAU16Y`JPaZLF/4JWQV0fiaG`AXIU84H55416IP
F`AZL6X4JWQ^0fihLPA]Kfl4K6ES16QRF0AUGe44IUY>15i8?@=JAC`4FTTo15a>B0AVDT`4M6AJ16eW
G0=ME4T4GE5716AGB`APDTH4GE=315YAA@@V5a836Q@D138h@@AZNGdWJWf05Oooo`005?oooc9ZOH04
KVQH16eWGPARF544Fe5:16iVEP=cGEX4JVAU16Y`JPaZLF/4JWQV0fiaG`AXIU84H55416IPF`AZL6X4
JWQ^0fihLPA]Kfl4K6ES16QRF0AUGe44IUY>15i8?@=JAC`4FTTo15a>B0AVDT`4M6AJ16eWG0=ME4T4
GE5716AGB`APDTH4GE=315YAA@@V5a836Q@D138h@@AZNGdWJWf05Oooo`005?oooc9ZOH04KVQH16eW
GPARF544Fe5:16iVEP=cGEX4JVAU16Y`JPaZLF/4JWQV0fiaG`AXIU84H55416IPF`AZL6X4JWQ^0fih
LPA]Kfl4K6ES16QRF0AUGe44IUY>15i8?@=JAC`4FTTo15a>B0AVDT`4M6AJ16eWG0=ME4T4GE5716AG
B`APDTH4GE=315YAA@@V5a836Q@D138h@@AZNGdWJWf05Oooo`005?oooc9ZOH04KVQH16eWGPARF544
Fe5:16iVEP=cGEX4JVAU16Y`JPaZLF/4JWQV0fiaG`AXIU84H55416IPF`AZL6X4JWQ^0fihLPA]Kfl4
K6ES16QRF0AUGe44IUY>15i8?@=JAC`4FTTo15a>B0AVDT`4M6AJ16eWG0=ME4T4GE5716AGB`APDTH4
GE=315YAA@@V5a836Q@D138h@@AZNGdWJWf05Oooo`005?oooc9ZOH04JW1W16AVF@A@?Rl4Hf=G17AU
IP=]Kf@4JWEX16Y`JPAZN7P4JWEa16YaJ`AZKF/3JW=[16ISF@ATHU44HfQH16MVGPAZJUh3JW=Z16Y`
JPAXJE`4GU=615e?A@AJE4T4GUE90f=H?`AMBCX4G4a216ILEPA]JV04J65E0f5RE@APGe<4FUI;15YG
B`AMET`4Hf1F18iYA0=R<b<460d<12<Z<RMZOH0Eoooo000Doooo<VYmP0AZL6L4I6II150n;`ASHeL4
M6EV0fe_I0AZMFP4JW1Z16YhN0AZMG44JW5[16Y]J`=ZLf/4IV=I16ARD@ASJ5P4IfIN16YZGP=ZLfX4
JW1Z16QYG0ANDdH4GDm515YDB@ANEDT3HePo15e9>PALC484IUaF16eZH0AXHED3HF9E161OD`AJET/4
FUM;15eFC0ASH5H4SVU40f8c8`@H3@`48bXb9fYmP1Goool001CooolbJWf016Y`I`ATIUT4D3h_16=S
E`AdIFH3KFmT16YeJ0AZL6X4JWQh16YeL@AZLF/4JVe[0fYcJ`AVHeT4I69A16=XF0AWIUh4JVYN0fYc
JPAZL6X4J6UL15iCAPAMCdD4FUA915iEB@=SF3l4GDTj15a<@PAVG5H4KFYP16QQE@=QHUD4H5mC15YF
B`AJEd/4GEI<16=PEPB>JD@3HS<S11P=30@S:S8WJWf05Oooo`005?ooobiZOH04JV5I15hn=PA?7al4
F3/i15ERH@ANLf@3JWET16Y/IPAZL6X4JVaU16Y]IPAZLF/4JVeW0fAVG@AXJEh4KWQ/171hK@A]Kf44
I5QD0fMNE`AZEUD4HTm515m:?`AJBT44ED@k15Y:=P=<?S@4D44j169KC`AVHe@4IV9E16ELDP=QED/4
H4m516AAA`APE4<4Hde116=GCPATETh3Q6eL1<cZh0BQ`KlWJWf05Oooo`005?ooobiZOH04JV5I15hn
=PA?7al4F3/i15ERH@ANLf@3JWET16Y/IPAZL6X4JVaU16Y]IPAZLF/4JVeW0fAVG@AXJEh4KWQ/171h
K@A]Kf44I5QD0fMNE`AZEUD4HTm515m:?`AJBT44ED@k15Y:=P=<?S@4D44j169KC`AVHe@4IV9E16EL
DP=QED/4H4m516AAA`APE4<4Hde116=GCPATETh3Q6eL1<cZh0BQ`KlWJWf05Oooo`005?ooobiZOH04
JV5I15hn=PA?7al4F3/i15ERH@ANLf@3JWET16Y/IPAZL6X4JVaU16Y]IPAZLF/4JVeW0fAVG@AXJEh4
KWQ/171hK@A]Kf44I5QD0fMNE`AZEUD4HTm515m:?`AJBT44ED@k15Y:=P=<?S@4D44j169KC`AVHe@4
IV9E16ELDP=QED/4H4m516AAA`APE4<4Hde116=GCPATETh3Q6eL1<cZh0BQ`KlWJWf05Oooo`005?oo
obiZOH04JV5I15hn=PA?7al4F3/i15ERH@ANLf@3JWET16Y/IPAZL6X4JVaU16Y]IPAZLF/4JVeW0fAV
G@AXJEh4KWQ/171hK@A]Kf44I5QD0fMNE`AZEUD4HTm515m:?`AJBT44ED@k15Y:=P=<?S@4D44j169K
C`AVHe@4IV9E16ELDP=QED/4H4m516AAA`APE4<4Hde116=GCPATETh3Q6eL1<cZh0BQ`KlWJWf05Ooo
o`005?ooobiZOH04JU]M16I3@PAO?ST4GEI:171[G@AcKVT3JW=c16Y`K0AZL6X8JW5[16YZI@AZJUh3
J6UL16eUFPA[J5d4JVaY16YcL`A^NgD3KGEa16YYF`AVH5<4Fe5715E9?PAB@cT4CT4j0e];@`A[IUL4
KFMJ16MUFPAVHUP4IEaB0f5HC@APE4T4H4e916A:B`AMCDH4GEYF15Q5=P=JBSl4KGYk16j1Q2MZOH0E
oooo000Doooo;VYmP0AZFed4IT=215ln>@AMETX4L6]M17=^J@=ZLg<4JW1/16Y`JPQZLF/4JVYU16YZ
GP=XJE`4KFEJ16]XG@AZK6T4JW=c16ikM@=]MG44JVUK16IPD`AKDDL4EDTn1593>@A>@CX3Fd]316]V
E`A]IeX4IfEJ16IRF0AUG583HEQ=161DB@APCDT4I4Y;15e=APAMFUH4F4Df0eY:?`A]NW/4KX649fYm
P1Goool001Coool^JWf016YKG@AV@d84Gchi15eFBPA`Jed4LfiY0fYcL`AZL6`4JW1Z26YaJ`AZJVD4
JVYN0fQYG0A]IEX4JfQM16Y/J@AZLg<4KW]e0feeL@AZJE/4IV1C15]AA`AEBCh4DT<i14i1>P=KBd<4
JfIG16eWFPAWIEX4IV9H16ELDP=QF4d4H5A9161=B@ATBT/4GDe615eJEPAHACH3FTXo16ejN`A^PH@W
JWf05Oooo`005?ooobiZOH04JU]M16I3@PAO?ST4GEI:171[G@AcKVT3JW=c16Y`K0AZL6X8JW5[16YZ
I@AZJUh3J6UL16eUFPA[J5d4JVaY16YcL`A^NgD3KGEa16YYF`AVH5<4Fe5715E9?PAB@cT4CT4j0e];
@`A[IUL4KFMJ16MUFPAVHUP4IEaB0f5HC@APE4T4H4e916A:B`AMCDH4GEYF15Q5=P=JBSl4KGYk16j1
Q2MZOH0Eoooo000Doooo:fYmP0=ZJ5l4JVUE16IQC@AIDCX4Gee<16i_I0A]KfP3JW1Z16YdKPAZK6L4
JVIR16APE@AWIUP4JUQJ0fQHEPASFe84I5iE16YXH`AZJEd4JVYQ0fY/I`AZGV84ITi815m<@PAJBd04
GDe215YFBP=OGDX4HUa>16=KD0AZGeD4I5U?165CB@=QED/4H4e3161=@@AJCd44FUI315mMD`AWET`3
HeY?14a=D0AHHVPWJWf05Oooo`005?ooob]ZOH03JVQO16YYE@AVHDd4FE4j15mMC0A^Kf@4KFmX0fY`
JPAZM6h4JVaW16YVHPATH5D4IfIH16YHFP=XF5H4He]B16ANE@AZJ6<4JVUM16YZH@=ZK6L4JUiR16I>
B0AOC484FT]015e=@PAJETX3Gee:169LCPASFe04JUmE16AIC`AQDdT3HEE;161=@`APCD44FTm115YF
@`AOGE<4IeI<0f=JC`A<CE04F69X9fYmP1Goool001Coool[JWf00fYXG`AZJED4IV5=15UA>PAOGD`4
KVmT16e_J0=ZL6X4JWA^16Y/I`AZIV84I61E16MVF0AZF5X3J5QF16=KDPATGUD4JVQS16YYG@AZJV43
JVaW16YNHPAVCTP4Gda215Y;@0AMCD84FUI:0emMBPARG4h4He]@16YOE@ATFDl4HE=90f5EB`APCD<4
H4e115Y?@@AJET<4GeeC16MFC0=SFTl4C4e@15QRJ2MZOH0Eoooo000Doooo:fYmP0=ZJ5l4JVUE16IQ
C@AIDCX4Gee<16i_I0A]KfP3JW1Z16YdKPAZK6L4JVIR16APE@AWIUP4JUQJ0fQHEPASFe84I5iE16YX
H`AZJEd4JVYQ0fY/I`AZGV84ITi815m<@PAJBd04GDe215YFBP=OGDX4HUa>16=KD0AZGeD4I5U?165C
B@=QED/4H4e3161=@@AJCd44FUI315mMD`AWET`3HeY?14a=D0AHHVPWJWf05Oooo`005?ooob]ZOH03
GU9314L^9P@X81/4<2hY15YKE0A/L6D4JVaV0fYYI0AZIV84JVYN16YVE`AXIUX4HeQE15]HCP=QG5D4
If]S16MaI@AZKV44JVaW16Y/J@=ZK6L4I71O169RD@AODTL8FT]016=>A0=RDdX4IUMD16MKD`APFDh4
HF1F16AREP=QFTl4H5iA15YLCPAJDTH4GDa:15mGEPAE=2H3GE56160m;`AWFeHWJWf05Oooo`005?oo
ob]ZOH03GU9314L^9P@X81/4<2hY15YKE0A/L6D4JVaV0fYYI0AZIV84JVYN16YVE`AXIUX4HeQE15]H
CP=QG5D4If]S16MaI@AZKV44JVaW16Y/J@=ZK6L4I71O169RD@AODTL8FT]016=>A0=RDdX4IUMD16MK
D`APFDh4HF1F16AREP=QFTl4H5iA15YLCPAJDTH4GDa:15mGEPAE=2H3GE56160m;`AWFeHWJWf05Ooo
o`005?ooob]ZOH03GU9314L^9P@X81/4<2hY15YKE0A/L6D4JVaV0fYYI0AZIV84JVYN16YVE`AXIUX4
HeQE15]HCP=QG5D4If]S16MaI@AZKV44JVaW16Y/J@=ZK6L4I71O169RD@AODTL8FT]016=>A0=RDdX4
IUMD16MKD`APFDh4HF1F16AREP=QFTl4H5iA15YLCPAJDTH4GDa:15mGEPAE=2H3GE56160m;`AWFeHW
JWf05Oooo`005?ooob]ZOH03GU9314L^9P@X81/4<2hY15YKE0A/L6D4JVaV0fYYI0AZIV84JVYN16YV
E`AXIUX4HeQE15]HCP=QG5D4If]S16MaI@AZKV44JVaW16Y/J@=ZK6L4I71O169RD@AODTL8FT]016=>
A0=RDdX4IUMD16MKD`APFDh4HF1F16AREP=QFTl4H5iA15YLCPAJDTH4GDa:15mGEPAE=2H3GE56160m
;`AWFeHWJWf05Oooo`005?ooob]ZOH03GdPk12@F3`@V7ad491dN1458A`AYJVL4JVaY0fY/H0AZK5d4
JVaW16Y`K`A^Lg84LGYd16mYI0=TDdl4EdQ115mECPASHUT4IfUS16Y/I`=ZK604J5]F15i>A`AE@T<4
EdLk15A5>@AIC483HeU>15mDA`AIDTL4H5=?15e:@`AICTD3F4m515M?A@AJDDL4GE1515e?B0AJCT84
DT`e0e16=@AG@3X4Ig9g9fYmP1Goool001Coool[JWf00em8>`@T5Pl49QlM12@M7PA1B4L4JFYW16Y/
J@=ZK604JVaM16Y/I`AZL6l4KW=b175jM0A_JF@3I5=?15M8@@AOEDh4Hf9I16MYH`AZK6L3JVaP16QK
EPANCTL4ED9315M7>`ADACT4FDa20f=ICPAOE4L4FE97161CC`AMBT<4FDi50eQ?A@AGCdD4FU5715e@
A@AMCdP4FTi2159<=@=@ASD4Ed0j16MbMbMZOH0Eoooo000Doooo:fYmP0=OB3/491H?12HO7@@T7Ah4
@DQ716UZI`AZK6T3JVaP16Y/G@AZK6L4JW1_16icLPAaNW@4KfUT0fACC`AGB444GeE>16=RF@AWJF<4
JVaW0fY/H0AXFeH4GTi715E2@`AGAc/4E4Di15U<@P=SFDh4GeA715UBA`APDdl4GDY315U>A@=HCdD4
Edm515YAA`AMD4D4GDm815Y>@PABC3D3D4He15M0>PAWLWLWJWf05Oooo`005?ooobMZOH04JVm/0fYP
F`A]CCh4?RXP130T80AHETl4JFYM16AVE`=WJF@4JVaU15QBA`A=AS`4?S8Z13DX8P@h;b`3@SDg15I6
@@AIASl4FTe816ITH0AZK6L3JVaZ16QRGPARED/4Fdhi15Y7=0AGBcl4ETXo0da7?`A6B404D4i515UK
CPAHEdX4GEM<0fAJC`APET/4GEA915e@A@AMCdP4GE=9148]9@<d6QH4AS0U16=^JBMZOH0Eoooo000D
oooo9fYmP0AZKf`3JV1K16e=?P@n:R04<2@P15QFC`AYJUd4I6IG0fMYI0AZK6D4F59714e6?0@n<RX4
=BPR13P_;0=2=CL4ETI115U6?`AJCDP4IVAP16Y/I`=ZK6X4J69N169EB`AKCST4FTLd15M;?`AFBSl3
C4Lo14I8@0A@CTD4FE]>15QGBPAMEd`3I5Y?161FB`AME4T4GE1515e?B0AMDdT4@RdU0c@J5PA6<2D4
HfiY9fYmP1Goool001CooolWJWf016Y_K0=ZH5/4KDdn13hZ80@`9204F5I?16UZG@ATIUL3IfUT16Y/
I@AHDTL4CDHl13hb:P@e:284>2l/0d8e=`AFAT44FDHo15Y=B0AVI604JVaW0fY/JPAXHUh4HUE;15]>
>@AJAc@4Ed/o15I:?`=<Acl4ATQ0151>A@AIFdh4F5M:15eGC0=TFTl4H5I;15eDB@AMD4D4GDm815eC
B@A2;BD3=1XF14H`9@ASKVTWJWf05Oooo`005?ooobMZOH04JVm/0fYPF`A]CCh4?RXP130T80AHETl4
JFYM16AVE`=WJF@4JVaU15QBA`A=AS`4?S8Z13DX8P@h;b`3@SDg15I6@@AIASl4FTe816ITH0AZK6L3
JVaZ16QRGPARED/4Fdhi15Y7=0AGBcl4ETXo0da7?`A6B404D4i515UKCPAHEdX4GEM<0fAJC`APET/4
GEA915e@A@AMCdP4GE=9148]9@<d6QH4AS0U16=^JBMZOH0Eoooo000Doooo9fYmP0ATFe03HU5711L9
1`@?30`46aLF14iFC`AVIed4JVIL0fe/GPAZK604L6eP15I>A0A0>c8492LX114E60<C5Q44:BHP138K
5P@/4@l4B3Db16MVGP=ZK6L4J6UL169HB`AKC3d4E5@m14i3=PAKDdP3KF9D17=RE0A/FD`4GDQ514m6
@0AIE4X3H5Q=15iDB@ABCD<4C4e315IFB0AMETT4DS/^0e4a90AI=Rd4IVQ]9fYmP1Goool001CooolW
JWf016AKD0=RDDL45`T710l<30@K5aH4CUI?16IWG@AZIU`3KFaN16Y/H0A`KF04ETi4140k<P@T9bP4
4ADH0a<F4@@Y9R04<Q/F12`A3`A8=C84IfIN0fY/I`AXJE`4HUQ;15]<?@ADE3d4CT<f15]CB0=]HU@4
Lf9D16aIC0AMB4D4CdI015UDBP=PF4d4GUA9159=@`A<CD<4EUI815eFB@AB>bh3DC4T15Tf;@AVJ6dW
JWf05Oooo`005?ooobMZOH04I5]@0f9AA`@G2@L43``<11/G5PA>ETl4IVMM16YVG0=]K5h4JVaP171]
H0AFCT@4@3/b12@W:0@A5AP34aHA12TV80@b6aH4;14?14Pe<PAWIUh3JVaW16QYG0ARF4/4Fd`m15AD
?@A>@cH4Fe=80feRE0AcHU@4K5U<15e8A@A?AT04FEA:0f1HC@ANE4T4DTe314a=@`AFETP4GEI9158k
;P=A<B@4FCH]16IXKBMZOH0Eoooo000Doooo9fYmP0ATFe03HU5711L91`@?30`46aLF14iFC`AVIed4
JVIL0fe/GPAZK604L6eP15I>A0A0>c8492LX114E60<C5Q44:BHP138K5P@/4@l4B3Db16MVGP=ZK6L4
J6UL169HB`AKC3d4E5@m14i3=PAKDdP3KF9D17=RE0A/FD`4GDQ514m6@0AIE4X3H5Q=15iDB@ABCD<4
C4e315IFB0AMETT4DS/^0e4a90AI=Rd4IVQ]9fYmP1Goool001CooolSJWf01765Q`AbK683HTe114@^
:0@W6A@4:aPD15YKE0A]LVH4IfaQ0fM/HPAZK684KW=_171UF@B=NG44DCld12LG4`<T5a848RPY13hk
<@AdL5d4Mh5`16YeKP=ZOgh4J7AZ169IC@A?@3L4BcT`12X=2@@f9BD3B3PX13`a:0@Y91h4>CP`159<
@@AHD443Edm315YAA`AHBSl4ETa215]<B0ABA3d4>bXU0d@f;0ALD4P4L8>616j1Q2=ZOH0Eoooo000D
oooo8fYmP0AaQHL4LVaR0f9=@@A4;RP49aTD12/H50AJFe@4KG9V16M/H@=WK684JVaR16icK`A`IET4
SGUa154o=0@W5a<391LB128X:@@n>c44M71M17N1L0AZMFh3JWmn16QdJPARFDd4Cd0g14/i<0@Z3@T4
=RDU0dPh:0@l<BP4:B@N13Th<0ABC444F5110eM?@`AJDDL4F4Xo15I<@PAKC4P4DT@m13/Z9@=4=R`4
G5181723QPA^PH@SJWf05Oooo`005?ooob=ZOH04LHF7179/HP=RCD44A2hX12LI50@[61@4FU]D16eb
IPAWK643IfaR16Y/HPA^Lfl4L6EI18eiL@AA?c@49aLC0b@G4P@R:2T4?S/a17A`G@AgPG04JWE^0fYo
OPAXM6X4HUU=14m0=`A;>C04:Pd913HU9@=8>2P4?34X12TT7P@i>304DTa115Q@@@=GCd<4FU5715Q:
?`AFC484Fda81594?@@k:RD3A3H/15a@B0A`PhH4KX648fYmP1Goool001CooolSJWf01765Q`AbK683
HTe114@^:0@W6A@4:aPD15YKE0A]LVH4IfaQ0fM/HPAZK684KW=_171UF@B=NG44DCld12LG4`<T5a84
8RPY13hk<@AdL5d4Mh5`16YeKP=ZOgh4J7AZ169IC@A?@3L4BcT`12X=2@@f9BD3B3PX13`a:0@Y91h4
>CP`159<@@AHD443Edm315YAA`AHBSl4ETa215]<B0ABA3d4>bXU0d@f;0ALD4P4L8>616j1Q2=ZOH0E
oooo000Doooo16YbMPAZNGd4JWIi16YiOA=ZOH044PD4114530=RFTl4CCP/12DL8@@M5A84C5MA16=U
F`AZK683IfQN165RF@AWJF<4L7MZ16MTE@AnJED4[Xa]0i]aC@B5Fcd4OF]>179XE`AZHEL4JV]V0fY/
I@AXH5H4HUA9169;>@AIACT4GTHe14]=BP<R:Rl41`@6118D5P@V:2H44a8@11PL80<Z9Al4A3<W15E:
?`AFDDH4Fdm314M0=0@/8a`3:B<N14e?APA]PGl4Jgj18fYmP1Goool001Coool4JW9f16YiO@AZMWT4
JWUm4fYmP0@B1@@44@D<0f9JC`A=>2`49A`Q11dE4PA<Ee44HfEK16Y/HP=WJ5h4HF9I16MYH`A`MfX4
IfAE17iYE@B^S6d3Vg5=18EK?@AmJdh4LVQG16YQE`AZJfH3JVaU16QPEPARE4T4HT/i15U5>@ANASD4
Bde:0b8Z;`@710H44Q@F12HX9P@C4Q0461`P0bXU7`A4<bL4EDXo15IAAPAKCd<4Ad0d12`S70<Y8ah4
CDm616f1O`A[OX4SJWf05Oooo`005?ooo`AZLWH4JWUm16YfN@AZNGdCJWf0118510@A1@`3HUY?14dh
;0@U72447ADB14aGD@ASIE/4JVaR0fMXGPAQHUT4IfUS171gJPAWI5D4OVUE1:j<K@>KLDd4QE/m17e[
CPAbJ5L4JV5G16Y[IP=ZK6D4J61F169DB@ARBcT4FDDi15i6=@A;CDX38RX_10L41P@B51H49RPV11<B
40@H7203:RDO14@c9`AEBSl4EU5615]?@`A7@3@4;2<L0bTS7PA=CdH4KH5o16]nPB=ZOH0Eoooo000D
oooo16YbMPAZNGd4JWIi16YiOA=ZOH044PD4114530=RFTl4CCP/12DL8@@M5A84C5MA16=UF`AZK683
IfQN165RF@AWJF<4L7MZ16MTE@AnJED4[Xa]0i]aC@B5Fcd4OF]>179XE`AZHEL4JV]V0fY/I@AXH5H4
HUA9169;>@AIACT4GTHe14]=BP<R:Rl41`@6118D5P@V:2H44a8@11PL80<Z9Al4A3<W15E:?`AFDDH4
Fdm314M0=0@/8a`3:B<N14e?APA]PGl4Jgj18fYmP1Goool001Coool4JWUl16YlO`AZPH@4JX233fYm
P0@E2@T450/;10d40P<00`X43`/A11HA3`@X6A@4G5eF16MXGPAZK6T3Fd=315<m>`AQGEX4KWMd17F1
O@AiMG04KUaA0g5UF@AjJUd4MVYI171ZG@AZJEd4JViX0fYaJ`AXGe`4HV1G15]C@PAKF3l4JELn17]U
D0>3FdD491DD12PK50@Z8B449alM13hb:0=IA3T4IUi>161@@`AJC484FeI412dQ7`@S6QH3;AhG14DY
8`ALEe`4J7Yn8fYmP1Goool001Coool4JWUl16YlO`AZPH@4JX233fYmP0@E2@T450/;10d40P<00`X4
3`/A11HA3`@X6A@4G5eF16MXGPAZK6T3Fd=315<m>`AQGEX4KWMd17F1O@AiMG04KUaA0g5UF@AjJUd4
MVYI171ZG@AZJEd4JViX0fYaJ`AXGe`4HV1G15]C@PAKF3l4JELn17]UD0>3FdD491DD12PK50@Z8B44
9alM13hb:0=IA3T4IUi>161@@`AJC484FeI412dQ7`@S6QH3;AhG14DY8`ALEe`4J7Yn8fYmP1Goool0
01Coool4JWUl16YlO`AZPH@4JX233fYmP0@E2@T450/;10d40P<00`X43`/A11HA3`@X6A@4G5eF16MX
GPAZK6T3Fd=315<m>`AQGEX4KWMd17F1O@AiMG04KUaA0g5UF@AjJUd4MVYI171ZG@AZJEd4JViX0fYa
J`AXGe`4HV1G15]C@PAKF3l4JELn17]UD0>3FdD491DD12PK50@Z8B449alM13hb:0=IA3T4IUi>161@
@`AJC484FeI412dQ7`@S6QH3;AhG14DY8`ALEe`4J7Yn8fYmP1Goool001Coool4JWUl16YlO`AZPH@4
JX233fYmP0@E2@T450/;10d40P<00`X43`/A11HA3`@X6A@4G5eF16MXGPAZK6T3Fd=315<m>`AQGEX4
KWMd17F1O@AiMG04KUaA0g5UF@AjJUd4MVYI171ZG@AZJEd4JViX0fYaJ`AXGe`4HV1G15]C@PAKF3l4
JELn17]UD0>3FdD491DD12PK50@Z8B449alM13hb:0=IA3T4IUi>161@@`AJC484FeI412dQ7`@S6QH3
;AhG14DY8`ALEe`4J7Yn8fYmP1Goool001Coool4JXB716Z0PaMZOH04<AdI134S6P@`7QP38AdJ118;
2`@V61@4;aTF15YDCPA]IE/4IfEH0g>2M@A[LV<4@34Y138P7@@/8Qd47QdK11PF5`<J5aH48adI12TL
6PA1?S/4GfML16Y[I@=ZIU/4J5mA169LD0AKCD<4GD<h15I??0AIEd<3I5a=1:N6J@B_QVD4Ne@m17M<
=PB4HDd3Mf1415UBA@AJETL4IU]<15I?AP@]8QT48aLD0c0O6@A6:1l4GV9V9fYmP1Goool001Coool4
JXB716Z0PaMZOH04<AdI134S6P@`7QP38AdJ118;2`@V61@4;aTF15YDCPA]IE/4IfEH0g>2M@A[LV<4
@34Y138P7@@/8Qd47QdK11PF5`<J5aH48adI12TL6PA1?S/4GfML16Y[I@=ZIU/4J5mA169LD0AKCD<4
GD<h15I??0AIEd<3I5a=1:N6J@B_QVD4Ne@m17M<=PB4HDd3Mf1415UBA@AJETL4IU]<15I?AP@]8QT4
8aLD0c0O6@A6:1l4GV9V9fYmP1Goool001Coool4JXB716Z0PaMZOH04<AdI134S6P@`7QP38AdJ118;
2`@V61@4;aTF15YDCPA]IE/4IfEH0g>2M@A[LV<4@34Y138P7@@/8Qd47QdK11PF5`<J5aH48adI12TL
6PA1?S/4GfML16Y[I@=ZIU/4J5mA169LD0AKCD<4GD<h15I??0AIEd<3I5a=1:N6J@B_QVD4Ne@m17M<
=PB4HDd3Mf1415UBA@AJETL4IU]<15I?AP@]8QT48aLD0c0O6@A6:1l4GV9V9fYmP1Goool001CooolO
JWf013HR6@@N3`/45a8?0a/C40@R5A4471DA12XW8`A?E4`4HF5H16i_I0=]KfP4Mg]f18RCPPAfIeh4
DDY<16mKEPAoGd`3NfEA16]EA0AjJeX4Oh9b17AhLPA]Kf`3JUQM16QOF`ARH5@4FdM813XU80@]6QP4
@3L^0eIA?`AME444JUU;17MYDPA^JEH4If=>0eADBPAMCdh4ETa615IA@`A7?S<46A<@11HB40=RE4@4
GSXZ15a/KRMZOH0Eoooo000Doooo7fYmP0@f8QT47Pl;11LB3`<K4a048QDA11`E4@@Z9b<4CeA<165Q
F0A^Kf@3KFmX17MkMPB8Th84MVMN155:C0A_FeH4Oem<0g]UD@A[ED@4NV]J17n2LPAdN784KFm/0fYH
G@AXGe/4HV1D15]7B0@j9B04;AXH140g;P=FDCl4GEA116YIB`AgJE84KVUF16MSCP=DE4X4GDm>15I<
APAFDD<4Achc11TC40@F4Q03HUA415hj:PALK6hWJWf05Oooo`005?oooamZOH04=R8I11h?2`@G4Pl3
6a<@128E4@@L5A44:RLS14mDC0AQHEP4KVmT0fe_J0AgNgH4R9>217IWGPAABT`4Ke]F17mOC0=kIE44
JeE417Y[FPAoPW84M7Qb16e_K0=ZF5d4J5mK169PE0AKAdP4>RDP12dJ60A0=bh3EU4o15eD@@AZFD/4
MfUB16iYEPAWHdh3E5A:15e?CPAFC4H4EU5314Ln<`@I4a045Q8@0f9DA0AN>RX4G6a^9fYmP1Goool0
01CooolOJWf013HR6@@N3`/45a8?0a/C40@R5A4471DA12XW8`A?E4`4HF5H16i_I0=]KfP4Mg]f18RC
PPAfIeh4DDY<16mKEPAoGd`3NfEA16]EA0AjJeX4Oh9b17AhLPA]Kf`3JUQM16QOF`ARH5@4FdM813XU
80@]6QP4@3L^0eIA?`AME444JUU;17MYDPA^JEH4If=>0eADBPAMCdh4ETa615IA@`A7?S<46A<@11HB
40=RE4@4GSXZ15a/KRMZOH0Eoooo000Doooo26YmP0AZMWT4JWUm3fYmP0@o;R<4:18=12<E4@<M5A44
4@L811dC40@^9244A44k15IFC`AWJ5l3JVaV16YcK@A^NgL4OIB;19Z]VPBFZiT4SZfP0iB_Y0BI/jP4
S:6>175iJ`AZLf`4I6UL0f5]FPATJUX4JFAI179eHPAoNf<4DC/g128J6@<<30h47QdP14a6@0AJE4D4
I5M415I?A0=GAch4B44e15I:A0ARC4H4;AhJ11dA3`@/91l3@c4W144U6P@F3@h49b/c8fYmP1Goool0
01Coool8JWf016YfN@AZNGd?JWf013l^8`@X4Pd48aDA0adE4@@A1`P47A<@12hT8@A4@C/4EUI?16MX
G`=ZK6H4JW=]16ikM`AmU8/4VZfJ19J[V@B>[J03U:nT19VcZ0B<XHh4LGU[16YcK0ATJE`3HFeJ16AZ
FPAYI5T4LWER17mkH`AA>cL48QXI0``<3P@N7B04C4I015YDA@ATEd@4ETm40eM7?PA8@CD4ETY4169<
AP@]7QX47A4?12`T7`=3<BL4@BDJ11H=3P@W:c<SJWf05Oooo`005?ooo`QZOH04JWIi16YiO@mZOH04
?bhS12PB3@@S5A437ADA114720@M4a04;R@Q14A1>`AFETl4IfQO0fY/IPAZLfd4KW]g17fDR`BJ[IX4
UZ^I18j]X0>D[j@4VK>X18bQSPAaNF/4JW=/16AYG0=QKEX4I6YJ16UTF@AbMF84Og]S154k=`@R6QT3
30`>11hM80A<AT04FUA516AGA0AFCd@3EdLn14Q1=@AFBT@4HTa612dN6P@M4@l4;2@O0d<a9`A19AX4
5Pd>12L[<b=ZOH0Eoooo000Doooo26YmP0AZMWT4JWUm3fYmP0@o;R<4:18=12<E4@<M5A444@L811dC
40@^9244A44k15IFC`AWJ5l3JVaV16YcK@A^NgL4OIB;19Z]VPBFZiT4SZfP0iB_Y0BI/jP4S:6>175i
J`AZLf`4I6UL0f5]FPATJUX4JFAI179eHPAoNf<4DC/g128J6@<<30h47QdP14a6@0AJE4D4I5M415I?
A0=GAch4B44e15I:A0ARC4H4;AhJ11dA3`@/91l3@c4W144U6P@F3@h49b/c8fYmP1Goool001Coool8
JWf016Z1Q0AZP8<?JWf0138[:0@W81`48QLB0b8E4@@L4Pd48QHA12`T8@A=A3/4HeeD16Y[H@=ZK6H4
JW1Z16YaJ`AZN7P8JWeo16YeL@=ZN7P4JWEa16YdL@A^Lf/4KFaN16i]H0=[IEX4Ie]B16]TFPA^Jeh4
MVaV18Z5M`BOPFl3LUM9138U7P@?3`h4414D11PL80@T8Qh3;2DO15E7A0AXDdP4EdTm12DH5@@N4a04
8QLH0aL;2P@K3`d4<2TW15i_Lb=ZOH0Eoooo000Doooo26YmP0AZPH@4JX233fYmP0@b:bP49b0L128G
4P<R5A44718=128F4@@/9244CD@k16=ME0AZJf43JVaV16Y`JPAZLF/4JWQh26YmO`AZMG43JWQh16Ye
L@AZM744KW=[16e/GPA^KF03JfEJ16MKDPA[I5X4KV]N17I/IPB:QGL4Wh5_0g9GB@@b9Ah43`l>110A
50@H7204928N0b`U7`AEAd@4J5=815M9?@@U61D47Q<@128G60<G2`X46`l=130Y9`ANKg<SJWf05Ooo
o`005?ooo`QZOH04JX6416Z0P`mZOH04<R/X12LP70@R5a838QDA11`B3@@R5Q44;2@Q14e4>`ASGE@4
JV]Q0fY/IPAZL6X4JW5[16YhN0QZOGl4JWEa0fYhN0AZMG44JWAa16icJ`A]K5h4KVeP0f]UFPAWFe84
JfAJ16i[GPAfK6H4RXEg19n1K`=bEdT4<RDN10l?3P@@4A@461`P12@R7P</9Al4EDM416QCB0AGBCd4
9APE11hC40@R5aP35`/:11/?3@@`:BL4GVmc8fYmP1Goool001Coool8JWf016Z1Q0AZP8<?JWf0138[
:0@W81`48QLB0b8E4@@L4Pd48QHA12`T8@A=A3/4HeeD16Y[H@=ZK6H4JW1Z16YaJ`AZN7P8JWeo16Ye
L@=ZN7P4JWEa16YdL@A^Lf/4KFaN16i]H0=[IEX4Ie]B16]TFPA^Jeh4MVaV18Z5M`BOPFl3LUM9138U
7P@?3`h4414D11PL80@T8Qh3;2DO15E7A0AXDdP4EdTm12DH5@@N4a048QLH0aL;2P@K3`d4<2TW15i_
Lb=ZOH0Eoooo000Doooo7fYmP0@o<Bd4?blZ120G4`<O5A448aDA12LJ6`@^9R<4?S/c14a=APAQI5/3
JVaO16YYH@AZKFP4JVaU16YaK@AZMG<4JWUj0fYhN0AZLF`4JW5[16YdL@AZL6P4JVaR0fQVF`AWJ5`4
If1F16MQE`AWHEX4JF=F16QXEP=iK5L4RGIN18A_EPAVCcX4FT4a16e@@@=cIUH4Hdi<14m:@`A4AS/4
:1XF124E4@@K51035A0<11/H5@@/;2X4G6a`8fYmP1Goool001CooolOJWf013la;@@o;bX481LC0alE
4@@S5A449aXK12hV8`@n>c<4C4e6165TF`=ZK5l4JVUQ16Y]J0AZK6D4JW5]16YeL`AZNGX3JWQh16Ya
K0AZLF/4JWAa16Y`J0AZK683J6IK16MXG0AWH5H4If5G16MQFPAYHeH4J6QF0gU/E`B9MUh4Q6mF16I?
>PAJ@C44KE110g=VEPASCT`4CdY314A6>`@X6QH48ADA11/D40<E40`46aPE12`/:PALK70SJWf05Ooo
o`005?oooamZOH04?c4]13l_:P@P5a<37aDA12<E4@@W6Q/4;RHS13hk<`A<CDH4HFAK0fY/G`AZJF44
JVeX16Y/I@AZLFd4JWEc16YiNP=ZN7P4JW5/16YaJ`AZM744JW1X16Y/HP=XIU/4IfQL16MPEPAWHEL4
If5J16USEPAXJ5H3NFaG18UfGPB4KeH4ITlj15Y1<@A]D443LfIF16=>C0A?BT<4A4Hk12PJ5P@Q5A44
6a@@0aD@30@K61D4;2`Z15a/L2=ZOH0Eoooo000Doooo7fYmP0@o<Bd4?blZ120G4`<O5A448aDA12LJ
6`@^9R<4?S/c14a=APAQI5/3JVaO16YYH@AZKFP4JVaU16YaK@AZMG<4JWUj0fYhN0AZLF`4JW5[16Yd
L@AZL6P4JVaR0fQVF`AWJ5`4If1F16MQE`AWHEX4JF=F16QXEP=iK5L4RGIN18A_EPAVCcX4FT4a16e@
@@=cIUH4Hdi<14m:@`A4AS/4:1XF124E4@@K51035A0<11/H5@@/;2X4G6a`8fYmP1Goool001CooolO
JWf013`Z80@/7aH4:QdI0b<F4P@U40`4:APD12hP5`@_:B@4A44l15iLE0=WJEl4JVaV16Y`JPAZN7P4
JW5[16YaK@MZMG<4JW5/16YaJ`AZJUh4JVYU16YVG`=XFe84If5G16MXG0AWH5H4IeeA16EIC@AXDdT3
J5Q=16MIC@AgIEL4OfiL185aG`AcHE83JE=>16EDAPAPCCh4?R/Q12DG4`@Q5A44:QTF0b0F4P@O5A44
9adE13H_<PACF5lOJWf05Oooo`005?oooamZOH04?2XP12`O5P@Z7AT38aHB12D@30@Y61@4;R0G12lY
90A4@C`4GUaD0fMYG`AZK6H4JW1Z16YhN0AZLF/4JW5]1fYeL`AZLF`4JW5[16YZGPAZJVD4JVIO0fQK
DPAWHEL4IfQL16MPEPAWGE44IEU=16QCB@=XF4d4IeU=17MUE`AoKU`4PG5O17=QDP=YDdh4IEA6161=
?P@n:b449ALC124E4@@Z6AH381HB11lE4@@W7AD4=Rlb15=HGamZOH0Eoooo000Doooo7fYmP0@l:R04
;1lF12XM6@<S5Q849A0<12TH50@^81L4;bTT14A1?0ANG5@3IfUO16Y/IPAZL6X4JWQh16YaJ`AZLFd7
JWEc16YaK0AZLF/4JVYN16YZI@AZIUl3J5]B16MQE`AWJ5`4If1F16MMD@AUFDd4J5=90fQHC@AWFDd4
MfEG17m^G0B1LEl4Lf5B0fUCCPAUE4H4H4dn13h[8@@U5a<48ADA12XI5P<P5Q847aDA12LM5@@f;c84
DeQO7fYmP1Goool001CooolOJWf0138V7@@`:bP4:AlK0bXJ5P@I4@d46a@@11/B40@X7QT4<BPN14i:
@`=ZJ5l4JVaV16Y`JPAZM784JWUj16YaJ`AZLFd7JVeV16YaJ`AZKF<4JVaO16ASEP=TIEX4If1F16MJ
D@AWGE@4If1F16ELDPMMF4d4I65E15eFB`APDDL4H5A9159@A@M<Cd<4?d0e11lM70@C3P/481PI11P@
4@<F3``44@L711hD4`@d;bl4EF5S7fYmP1Goool001CooolOJWf0138V7@@`:bP4:AlK0bXJ5P@I4@d4
6a@@11/B40@X7QT4<BPN14i:@`=ZJ5l4JVaV16Y`JPAZM784JWUj16YaJ`AZLFd7JVeV16YaJ`AZKF<4
JVaO16ASEP=TIEX4If1F16MJD@AWGE@4If1F16ELDPMMF4d4I65E15eFB`APDDL4H5A9159@A@M<Cd<4
?d0e11lM70@C3P/481PI11P@4@<F3``44@L711hD4`@d;bl4EF5S7fYmP1Goool001CooolOJWf0138V
7@@`:bP4:AlK0bXJ5P@I4@d46a@@11/B40@X7QT4<BPN14i:@`=ZJ5l4JVaV16Y`JPAZM784JWUj16Ya
J`AZLFd7JVeV16YaJ`AZKF<4JVaO16ASEP=TIEX4If1F16MJD@AWGE@4If1F16ELDPMMF4d4I65E15eF
B`APDDL4H5A9159@A@M<Cd<4?d0e11lM70@C3P/481PI11P@4@<F3``44@L711hD4`@d;bl4EF5S7fYm
P1Goool001CooolOJWf0138V7@@`:bP4:AlK0bXJ5P@I4@d46a@@11/B40@X7QT4<BPN14i:@`=ZJ5l4
JVaV16Y`JPAZM784JWUj16YaJ`AZLFd7JVeV16YaJ`AZKF<4JVaO16ASEP=TIEX4If1F16MJD@AWGE@4
If1F16ELDPMMF4d4I65E15eFB`APDDL4H5A9159@A@M<Cd<4?d0e11lM70@C3P/481PI11P@4@<F3``4
4@L711hD4`@d;bl4EF5S7fYmP1Goool001CooolOJWf013l/8`@`9B84<2LS0bXP6`@/6aL491HB12TN
6P@a;2T4<2l/14E5@P=QFU<4JVUS16YYI0AZJF84JW5]16YiNPAZN7P3JW5/26YaJ`AZKF/4I6IO16AS
F0MWGE@4If1F165PEPANFDl4HEU?165HC@=PF4d4H5E;16AHC@AMET/4FUA915Q@A@=RCd@4GDTn13T/
9`@T5Q<4:ahJ11H<30@G3a034PP811XA4@@O5A44=3He15U/L1mZOH0Eoooo000Doooo7fYmP0@o;2<4
<2DR130W8`<Z81/4;1/G12@F4P@Y7QX4<B`Y130_;0A5AD83HEYC16YYH`AZJF@4JVUR16YaK@AZNGX4
JWQh0fYaK0QZLF/4JVe[16AVG`ATHeP7IeeD16MPEPAQH5H4GUU?165IC`AQF4d3H5Q=161EB`ATF4d4
GEI;15YDB@AHD4D3HTm415e9?P@i;2L491HC12/N6P@F30`45`l@0a8820@J4A447aDA13@f=@AIK70O
JWf05Oooo`005?oooamZOH04?b`S130U8P@`9b<3:R0K12`K5`@T5Q84:AhJ134/:@@`;b`4ADE20f5J
D`AZJF<4JVUT16YYHPAZLFd4JWUj16YhN0=ZLF`8JW5[16Y]J`ATIUl4I6=H1fMME0AWH5H4HF1F15iI
C`AQFDl4HEQ=0f1HC@APED/4I5Q=15eFB`AJE4T4F5150f9?A0AMBCh4>B`W12@F4`@[7QX45P`<11L?
40<B20P46Q4A11lE4@@d=SD4FFa`7fYmP1Goool001CooolOJWf013l/8`@`9B84<2LS0bXP6`@/6aL4
91HB12TN6P@a;2T4<2l/14E5@P=QFU<4JVUS16YYI0AZJF84JW5]16YiNPAZN7P3JW5/26YaJ`AZKF/4
I6IO16ASF0MWGE@4If1F165PEPANFDl4HEU?165HC@=PF4d4H5E;16AHC@AMET/4FUA915Q@A@=RCd@4
GDTn13T/9`@T5Q<4:ahJ11H<30@G3a034PP811XA4@@O5A44=3He15U/L1mZOH0Eoooo000Doooo7fYm
P0@f<Bh4<R`Y13@/:0<c:BD4:Q/G11T@30@T5a@4=B8K14`e:0AF?Bh3FU9916MXG0AZK6@4JVUT16YY
HPAZLFd4JWEc0fYiNPAZMG44JW5[16Y]I`A^L6H4JfQM0f5QEPANFDl4HeIC16EFC`ATDdT4I5=?165E
C@=PF4d4H55715Y?A@AJDDL4EdLm161:@@=F@cT4>34]12XO6P@U5a@45`l;11P@40@F30`36Q4<11/A
4@@X6AH4SJVY18n^[QmZOH0Eoooo000Doooo7fYmP0@f<Bh4<R`Y13@/:0<c:BD4:Q/G11T@30@T5a@4
=B8K14`e:0AF?Bh3FU9916MXG0AZK6@4JVUT16YYHPAZLFd4JWEc0fYiNPAZMG44JW5[16Y]I`A^L6H4
JfQM0f5QEPANFDl4HeIC16EFC`ATDdT4I5=?165EC@=PF4d4H55715Y?A@AJDDL4EdLm161:@@=F@cT4
>34]12XO6P@U5a@45`l;11P@40@F30`36Q4<11/A4@@X6AH4SJVY18n^[QmZOH0Eoooo000Doooo7fYm
P0@f<Bh4<R`Y13@/:0<c:BD4:Q/G11T@30@T5a@4=B8K14`e:0AF?Bh3FU9916MXG0AZK6@4JVUT16YY
HPAZLFd4JWEc0fYiNPAZMG44JW5[16Y]I`A^L6H4JfQM0f5QEPANFDl4HeIC16EFC`ATDdT4I5=?165E
C@=PF4d4H55715Y?A@AJDDL4EdLm161:@@=F@cT4>34]12XO6P@U5a@45`l;11P@40@F30`36Q4<11/A
4@@X6AH4SJVY18n^[QmZOH0Eoooo000Doooo7fYmP0@f<Bh4<R`Y13@/:0<c:BD4:Q/G11T@30@T5a@4
=B8K14`e:0AF?Bh3FU9916MXG0AZK6@4JVUT16YYHPAZLFd4JWEc0fYiNPAZMG44JW5[16Y]I`A^L6H4
JfQM0f5QEPANFDl4HeIC16EFC`ATDdT4I5=?165EC@=PF4d4H55715Y?A@AJDDL4EdLm161:@@=F@cT4
>34]12XO6P@U5a@45`l;11P@40@F30`36Q4<11/A4@@X6AH4SJVY18n^[QmZOH0Eoooo000Doooo5fYm
P0AZMWT4I6]_138W90@[8b04<2PU0bhV8P@O5A44:QhK12/P70@V8Ah4>c<Z1515?0=JF584IVMN16Y/
IPQZLfd4JWAb1fYeL`AZLF`4JW5[16AWFPAWHUL4J5]B0f]ME0A^HeP4I5mA165LC`ATF4d4GEi@15eJ
C@=JBdL4Edi715YDB@AME4T4H59715AAAP=7@SL4BCX]12lR6@@V61D47QDB11hF4@@O5a436a8=11dE
4@@W6AD4GFib16j1Q1mZOH0Eoooo000Doooo5fYmP0AZMWT4I6]_138W90@[8b04<2PU0bhV8P@O5A44
:QhK12/P70@V8Ah4>c<Z1515?0=JF584IVMN16Y/IPQZLfd4JWAb1fYeL`AZLF`4JW5[16AWFPAWHUL4
J5]B0f]ME0A^HeP4I5mA165LC`ATF4d4GEi@15eJC@=JBdL4Edi715YDB@AME4T4H59715AAAP=7@SL4
BCX]12lR6@@V61D47QDB11hF4@@O5a436a8=11dE4@@W6AD4GFib16j1Q1mZOH0Eoooo000Doooo5fYm
P0AZMWT4I6]_138W90@[8b04<2PU0bhV8P@O5A44:QhK12/P70@V8Ah4>c<Z1515?0=JF584IVMN16Y/
IPQZLfd4JWAb1fYeL`AZLF`4JW5[16AWFPAWHUL4J5]B0f]ME0A^HeP4I5mA165LC`ATF4d4GEi@15eJ
C@=JBdL4Edi715YDB@AME4T4H59715AAAP=7@SL4BCX]12lR6@@V61D47QDB11hF4@@O5a436a8=11dE
4@@W6AD4GFib16j1Q1mZOH0Eoooo000Doooo5fYmP0AZMWT4I6]_138W90@[8b04<2PU0bhV8P@O5A44
:QhK12/P70@V8Ah4>c<Z1515?0=JF584IVMN16Y/IPQZLfd4JWAb1fYeL`AZLF`4JW5[16AWFPAWHUL4
J5]B0f]ME0A^HeP4I5mA165LC`ATF4d4GEi@15eJC@=JBdL4Edi715YDB@AME4T4H59715AAAP=7@SL4
BCX]12lR6@@V61D47QDB11hF4@@O5a436a8=11dE4@@W6AD4GFib16j1Q1mZOH0Eoooo000Doooo5fYm
P0AZPH@4KXR:130W8P@e91`4<2@P0c4Y9P@f;2L4;20L12/R7P@`8QT4>SXc13Tf;@=<@C/4GUUB16MY
H`AZJF@4JVeX16Y/I@MZJF04JVMP16APE@ATGE84HfEK16AQE`=QFDT4GUI:165IB@ATG4l4I5mC165H
C@APED/3I5M9161FB@AMCD<4GDY1159=@`A7@cT3@CD[12TO7P@O51@46A<@11L@30@H41045@/<0`h7
20@C2P`4=BHS16A`L`AXNWhOJWf05Oooo`005?oooaMZOH04JX6416j8RP@`9b84=B@L130T80<a:BH4
=R`W12`P70@[8Qh4<28I13Xj<`@i=Rd3C44k15iIDPAWJF<4JVUT16Y]J0AZK6D7JVUP16YWH0ATH5D4
I5eB16=UF`ATHEL3HEU915iFBPAQFDT4I5a?16AOD`AQF4d4H5E;0fAGB@APETT4GDe315e:@@ABCD<4
Ad<i0d4e:`@Y7ah47a@D11TC40@G40`4610@11D;30<>1`P44`X<13DV8`ATL7<4J7Yn7fYmP1Goool0
01CooolGJWf016Z1Q0A^R8X4<2LR13DT70@`9203<BTV13H/9`@/81`4:b8N130R6@@j>S<4>CH]0da1
>`ANFE84IfUS16YYI0AZKFP4JVaU1fYYH0AZIf04I61E16AMDPASIE/4I65G0f5IB@ANETX4HEU916AL
C`ATGe<4HEQ=161EB`=TEdT4H5I915e=@`AMBT44DTe314M3>@=1=B/4:AlN11lD50@I4a045a0<11P@
40@E2``33PL811<:30@e9R<4I71c16QjOQmZOH0Eoooo000Doooo7fYmP0A1<Rh4;b8J130Y9P<c:bL4
:B4M12HH50@_81P4;bHS138_:@@_8ah3?CD`15YJD`AZK5h4JVaM16YYH@AZIU/7JVIH16YZH@A^L6H4
JfQM16MJD@AQCdH3HE1916ACD0ATFE<4I5aC16A?A@AQDdT7H55715iDB@AMD4D4EdTn14U1=`A1<bT3
:AhN12@L5P@N510471@A128E4@@K4A445P`<0aP<3@@^6aL4[m;;19o5`b=ZOH0Eoooo000Doooo7fYm
P0A1<Rh4;b8J130Y9P<c:bL4:B4M12HH50@_81P4;bHS138_:@@_8ah3?CD`15YJD`AZK5h4JVaM16YY
H@AZIU/7JVIH16YZH@A^L6H4JfQM16MJD@AQCdH3HE1916ACD0ATFE<4I5aC16A?A@AQDdT7H55715iD
B@AMD4D4EdTn14U1=`A1<bT3:AhN12@L5P@N510471@A128E4@@K4A445P`<0aP<3@@^6aL4[m;;19o5
`b=ZOH0Eoooo000Doooo7fYmP0A1<Rh4;b8J130Y9P<c:bL4:B4M12HH50@_81P4;bHS138_:@@_8ah3
?CD`15YJD`AZK5h4JVaM16YYH@AZIU/7JVIH16YZH@A^L6H4JfQM16MJD@AQCdH3HE1916ACD0ATFE<4
I5aC16A?A@AQDdT7H55715iDB@AMD4D4EdTn14U1=`A1<bT3:AhN12@L5P@N510471@A128E4@@K4A44
5P`<0aP<3@@^6aL4[m;;19o5`b=ZOH0Eoooo000Doooo7fYmP0A1<Rh4;b8J130Y9P<c:bL4:B4M12HH
50@_81P4;bHS138_:@@_8ah3?CD`15YJD`AZK5h4JVaM16YYH@AZIU/7JVIH16YZH@A^L6H4JfQM16MJ
D@AQCdH3HE1916ACD0ATFE<4I5aC16A?A@AQDdT7H55715iDB@AMD4D4EdTn14U1=`A1<bT3:AhN12@L
5P@N510471@A128E4@@K4A445P`<0aP<3@@^6aL4[m;;19o5`b=ZOH0Eoooo000Doooo7fYmP0A<BD@4
=2`X12`U8`<d:2D4<R8I12dT7P@V7A/4:b@R12DM6`@V9B@3=3<[14<l<PAHE4/4HF9I16MYG0AZK604
JVaR0fAVG0AQHUH4IfUM16QNE@AQDDP4HEU90eeDA`QIEDT4H5=915eBB0AMDDL4H4]70eYAB@AJE4<4
EdXm1599?PA9@SL4=2DP0bPM5P@L4`l45Pl;11P@40@O51446Q4A11<820<F30`49APE15ATJ0AXNWhS
JWf05Oooo`005?oooamZOH04C4U413@/:0@/9B<3=2PU138R6@@]91h49QdK12/T8P@U7A/49RDT0c@c
:`A3?384F5A;165RF@AWJE`4JVaP16Y/HP=TIU`4HF9F16MYG@AXGUD4HE58165IB@=ME4L8FEE9161C
B@AMDTP4GE57161;A`=JDDT4FUA315M:?@ABBCh4BD8g13@U80<X7AH471<?11H?2`@H41047a@A11XA
4@@C20P35P`<12DH5@ADI6P4J7Yn8fYmP1Goool001CooolOJWf014a9A0@d;2P4;2DS0c@X9@@b8QT4
;B@N12HM6`@[92849AdK12HU90<d<b/4@c`b15QDB`AQHUT4IfUL16Y/H0AZK683I6IL165REPAWJEd4
J5iE165AB0AQFDT3GEA725UEB@APDdT4GE9815eAA`APBdL3FU5915YD@`AGBSd4DTTn14U2=`@d9B03
:1dF11`C3`@F3`/4610@11lD4@@J4A444`P80aH<30@U61D4E6AX16QjOR=ZOH0Eoooo000Doooo7fYm
P0A<BD@4=2`X12`U8`<d:2D4<R8I12dT7P@V7A/4:b@R12DM6`@V9B@3=3<[14<l<PAHE4/4HF9I16MY
G0AZK604JVaR0fAVG0AQHUH4IfUM16QNE@AQDDP4HEU90eeDA`QIEDT4H5=915eBB0AMDDL4H4]70eYA
B@AJE4<4EdXm1599?PA9@SL4=2DP0bPM5P@L4`l45Pl;11P@40@O51446Q4A11<820<F30`49APE15AT
J0AXNWhSJWf05Oooo`005?oooamZOH04AT4h13D/9`@d;2P3;2DR12`V8`@R61X49A/I12PP70@c:bL4
;b4I0bLM60@];R/4@C/g15I5@0APEDh4HEUA165OE`=TIU`4If9H16=KD`ANG584Fe=815U<A@=MCdL4
H4Y1161<@`ALCdD4GE5715Y=@`AGCD43EDHk14m2>`A4@CT4>C8Y13T/8`@X7QL36Q8?11TC40@I4@`4
5P`<11@;30@=1`L43PP80bXJ5P@g81H4H6a/9fYmP1Goool001CooolOJWf014I1>0@e;2L4=2`X0b`U
8P@/9R<48QPJ12DK6@@X81`4<b/W12lQ6@<W7AP4;Bh[144k=`AFAD04H5E>165ID@AQGeL3I6IL16MR
F0ASFe<4GUaB15]CB0AIC4D3GDm7161:@@APC4<4G4m515eAA`AJCD<4Ede10eE6>`A?@S/4A44i13Tb
:@@i;2<4:1hG0aXB3`@I4a046A4<11H<30@D2``43@L710h820<Z6QH4=b0F161/K2MZOH0Eoooo000D
oooo7fYmP0A6@CP4=B`W13@/:0</9B84;2HS128H6P@U6aT4:20L13<[9`@_8AT39adH12d^:`A1>cL4
ETE0161ECPAQFE44HEmG0fAVG0AWHUP4He]C15iLDPAKDdP4FDa50ee?A`APBT44H4a315a?A@AMDDL4
FTe315M=@@=EAS/4Cd8k14A1>@@i<RT4>B`S12PN5`<J4Pl46A<@11TA30@F30`450/<10d71`@>20P3
:QXF13LP5PAPK6`WJWf05Oooo`005?oooamZOH04AT4h13D/9`@d;2P3;2DR12`V8`@R61X49A/I12PP
70@c:bL4;b4I0bLM60@];R/4@C/g15I5@0APEDh4HEUA165OE`=TIU`4If9H16=KD`ANG584Fe=815U<
A@=MCdL4H4Y1161<@`ALCdD4GE5715Y=@`AGCD43EDHk14m2>`A4@CT4>C8Y13T/8`@X7QL36Q8?11TC
40@I4@`45P`<11@;30@=1`L43PP80bXJ5P@g81H4H6a/9fYmP1Goool001CooolOJWf017R1SPA6=c@4
<bTV0bhV8P@g<2`4=RHK12/J5@@d:RL4:R4M12lY9`<T7A/48bLU11`P7`@T8R04A3/g14i3?0A@B4P3
Dd]=15=>B@AJEdl4ED]213lg;`@j<b`3B3P/15A8?@AGC4<4Eclf15M5?@AJCCP4EdTj0e93>@A>?C@4
B3dd13PY90@X6QH48A@C0alD4@@I40`45@/<11H<30@C20P43`P811L<3@<O5144T;2b19g0`2MZOH0E
oooo000Doooo7fYmP0AhPHh4ASLd13<Y9P<^9R84=c0/13HV6`@[6QD4=2XW12XQ7@@_:BL391dK12<W
9@@L81l4928P14@k=`A>@c`4D4Q80e=;C@ACCTT4FUM?15E;@P@o=bl4>S</0dPh;0ADB3d4Eda315Lo
=PAGACd4FTdh15M9>P=B@cT4CSdd14Pm=0@h:B@4:1XF124D4`<O51446A0<11D;30@F30`44`P810l8
20@G30d37a@A192`/PBM`<0WJWf05Oooo`005?oooamZOH04N86>14Hg=0@c:BH3;RHR13L`;0@f9Q/4
:aXE13@Z9`@Z8Ad4;bTW0b@M6`@S9bD4720O12@R80A4>cL4CT<l1518B0=CBdd4Ddi915YGC`AEBd84
?cL_13Xc;0=8>2`4E4Pm15M<@`AG?cH4EdDm15Y=>0AGBCX3DT<i14hm=0A8?C@4>2TT12PJ5P@Q51<3
7a@A11T@30@E2``45P`<11<820@?20P45``=0alD4@B@/;84WL309fYmP1Goool001CooolOJWf017R1
SPA6=c@4<bTV0bhV8P@g<2`4=RHK12/J5@@d:RL4:R4M12lY9`<T7A/48bLU11`P7`@T8R04A3/g14i3
?0A@B4P3Dd]=15=>B@AJEdl4ED]213lg;`@j<b`3B3P/15A8?@AGC4<4Eclf15M5?@AJCCP4EdTj0e93
>@A>?C@4B3dd13PY90@X6QH48A@C0alD4@@I40`45@/<11H<30@C20P43`P811L<3@<O5144T;2b19g0
`2MZOH0Eoooo000Doooo7fYmP0AnVYH4Cd`m12/S7PL[8b048b0M124I6`@Z7aP4;b@P13L_;0<h;b/4
;BDS12`X:0@^:bP49R<O124R9P@K8R<38AlJ130[9P@c<2/4:RLV130Y8`@a:203<2hS13L/90A0<bL4
CD4a14Tm<@@i;BP4>b/V0d<c:`@i=304<2@R12/J5@@T5Q<47A<@0aL@30@E2``44PP820h820@?20P4
7QHA0b/K5PARLgH4KH>69fYmP1Goool001CooolOJWf017jJUPA?C3d4:b<N1b/S80@S81d48ATK12XO
60@_9204=bl/0cP_:`@]9B<4;2PX12h[:0@V8al48B8V11/R8`<Q7aX4<2/V13<`:`@Z9bH4<2TS134X
80<`;R<4=b`T140c9`A=@C44BCda13T]:0@k:bH3@c<[13Td<0@`9284:aXE12@F4`@M4a035a0<11D;
30@B20P83PP810l820@N5Q43:a/F169cMPA]PhHWJWf05Oooo`005?oooamZOH04OYZF14m<?@@[8ah7
:b<P12<P7@@Q6A/4:QlH12lT80@g;b`3>2l[12dU8`@/:2P4;R/X12HS7`@Q8RH46b8S0b4O6P@`:bH4
<c0[12XW9P@`:B<4<BPP0c0^8`@g;2@4@3<W14e1<@A9?C44>BdX13/[9P=3<b/4>C@`130T8P@[6QD4
91HC11dC40<G40`45@/<118820P>20P43`P811hF4@<[6aH4HW=f16f3QRMZOH0Eoooo000Doooo7fYm
P0AnVYH4Cd`m12/S7PL[8b048b0M124I6`@Z7aP4;b@P13L_;0<h;b/4;BDS12`X:0@^:bP49R<O124R
9P@K8R<38AlJ130[9P@c<2/4:RLV130Y8`@a:203<2hS13L/90A0<bL4CD4a14Tm<@@i;BP4>b/V0d<c
:`@i=304<2@R12/J5@@T5Q<47A<@0aL@30@E2``44PP820h820@?20P47QHA0b/K5PARLgH4KH>69fYm
P1Goool001CooolSJWf0161ULP@i;bd3=2`X130/:0@a:2@47ADA12DP70@e;bd4=c0/0c/e<@A1>SD4
A3hc13dk<@@_<R`4:2@R12TL5`<U6Q/491XJ12TP7`@V7b04924S12hS8@<`8QX4:20M12hZ9@@^:bD4
;2LP13H^9@@a:1l3:bTU12hQ7@@/7aT481HD128L6@@H4@`3610<11H<30@C20P83`P812DF4P@L4A83
GeQE18BEU2]ZOH0Eoooo000Doooo8fYmP0APIG84>Bl]0c@/:0@`;2P4<BPT11dE4@@U81`4=Bl]13L`
;0<k=C44@CXe14@n<`@m>c44;c8/12PT8P@Y71L39AXK12@J6P@Y81l49QlP12@Q8`@^8b43<28J12PP
7@@^:RD4;R/U12`W80@f;RD4<BPO0b/Y9@@^8Ad4;1lI120F50@R71T4614<0aP@30@F30`44`P820l8
20@U5Q84714B0emHE@B4UI@[JWf05Oooo`005?ooob=ZOH04H6Eb13T_;@<d;2P4<2`X134X90@M5A44
9B0L13D_;@@g<2`3>cDa144j=@A4?S<4?C/a12lb;0@X9284:A`G0bDJ6`@T6QX4:B0O12HO80@T8B<4
;R<Q0c0R6P@X81d4;RXU12h[9@@/9b04=RhU134X7`<[:BD4;R4M12`O6@@P5Q@48Q`I11PA30<H40`4
5P`<11<820P?20P49AHB11`A4P=OF5D4Q9FD:fYmP1Goool001CooolSJWf0182AU@A8>3<3<2DR12dS
80@^9244=RXV13/`;0@g;b`4>C@`0c0X9@@[9284;QlN13LQ7@@d7aT4:R4O120K60<U8b447QHD11hM
7@@U8B0491lK11`E4`<I5aL46A@C11P@4@@I5A<471TE11`H5@@J4Q836a4A11TB4@@L518461<@11D?
2`@D2`/35@/<11H<30P?20P49AHL12DF4`@f:RD3T;2]18JWZ2]ZOH0Eoooo000Doooo8fYmP0B0TID4
B3Pc0c0U8P@]8b04;R@Q13HZ9P@k<2`4=bl/13Td<0<`:2D4:b@R12hO7P@g8Ad4=1lI12XQ7`@P6aP3
9B<Q11hF50@N7Ad49B4P12@O6`@L5A<36ALG11TD4`@H41446ADC11`I5@@L61D46Q8B0a/A4@@I4Q44
71@B11PC40@E3`/450/;0aD;30@F30`83`P812DF70@U5Q<4=RXU0i2`[@B6YjP[JWf05Oooo`005?oo
ob=ZOH04P96E14Ph<`<`9B84;B<P12hT8@@f:RH4>c0/13L_;0@i=303<2PU12/T8P@^7ah4=b4M13@O
6@@Z8Al481/H0bDS8@@N5Q@47QdM12DQ80@T7a/471DC0aTG5`@I51<4610A11TE4`@L6AD471PE11XB
4P<K4A446A8A11`D4P@H4a045@l;11@;2`<E2``45P`<20l820@U5Q`49AHC13HZ9@>@/:d4QZNX:fYm
P1Goool001CooolSJWf0182AU@A8>3<3<2DR12dS80@^9244=RXV13/`;0@g;b`4>C@`0c0X9@@[9284
;QlN13LQ7@@d7aT4:R4O120K60<U8b447QHD11hM7@@U8B0491lK11`E4`<I5aL46A@C11P@4@@I5A<4
71TE11`H5@@J4Q836a4A11TB4@@L518461<@11D?2`@D2`/35@/<11H<30P?20P49AHL12DF4`@f:RD3
T;2]18JWZ2]ZOH0Eoooo000Doooo8fYmP0AbRXL4LGaj0c/b;@@^9B84<b/W130W8`@j=304:B4M12dX
9P<W7a`4;RLT13hf;@@`;BT4:2HT12`U8`@/8ah3>2/X12HJ6`@S81d48QHC12@E4P@N4a036A<@11`C
40@S61D48aLE11/B40@I4@l46Q8@0b8H5@@N51447A<@11P@30@I40`75P`<20l820@G30d4:QlI12`K
5PBU`Kl3XL6o;fYmP1Goool001CooolSJWf017::Q`AaO7X3>c8]12hU8P@c:bL4<2LS13Xd<0@Y8Ad4
;BPV0bLO70@^9b@4?SH]130]:@@X9R@4;2DS12`S7P<h:bP49QXK12<P7@@R5Q<491DB11hC40<I4a04
71<@12<H5@@S5aD46a8@11TA3`@J4Q038QPE11hD4@@M4a04610<11T@30LF30`83`P811L<3@@Z7aT4
;1/F1:G1_`>Q`Kl_JWf05Oooo`005?ooob=ZOH04LXZ7175lNP<k<Rd4;RDR13<[9`@`9b<4>S@`12TQ
7@@]:2H39alL12hW90@n=Rd4<2dY12PV90@/9B<4;2<N0cP[:0@V6Q/48b0M128F4`@T5A847Q<@0aTC
40@L4a048aPE12<G5@@K4Q046A4?11XB40<R61D47Q@A11dC40@H40`46A0<1aH<30P?20P45``=12XO
6@@/6aH4YL6o0j71_bmZOH0Eoooo000Doooo8fYmP0AbRXL4LGaj0c/b;@@^9B84<b/W130W8`@j=304
:B4M12dX9P<W7a`4;RLT13hf;@@`;BT4:2HT12`U8`@/8ah3>2/X12HJ6`@S81d48QHC12@E4P@N4a03
6A<@11`C40@S61D48aLE11/B40@I4@l46Q8@0b8H5@@N51447A<@11P@30@I40`75P`<20l820@G30d4
:QlI12`K5PBU`Kl3XL6o;fYmP1Goool001CooolWJWf017EmQ@=5;b/4=R/W13<[9`@^9R848AdJ134/
:P@n=c<3<RhZ12TQ7@@/81X48QPF12DM6P@X7a`47ALM0ahM70@P61P49aLD11lC6@@I4a446Q@A0aP@
30@K51046A@@11PC40@F40`44`/<11H?30<L4a045a0<11<;30@H40`46Q4A11H<3@<?20P45P`<128G
4P@a8Q`4;1/F1:O8a@BWblPbJWf05Oooo`005?ooobMZOH04MGf50dD_:`@f:bL4<b/W12hV8P@Q7AX4
<B`Z13hg<`<b;RX4:B4M12`P6P@R61H49AdJ12PO70@M5ad37QdL120H60@W5a@47a<I11TC4@@J5143
610<11/D40@I510461<@11H@30@C2``45Pl<0a`C40@G40`44`/<11P@30@J4A445P`=0`l820@F30`4
8QLB134R70@/6aH4YlS51:O;b39ZOH0Eoooo000Doooo9fYmP0AeOHD3ABl[13H[9`@c:bL4;RHR124M
6P@a;2X4?SLc0c8^:P@Y8Ad4;20J128H5P@U7AX4:1lL11dG7@<N7A`481PH12LG50@O4aT46A<A11XD
4@<H40`46a@@11TD40@H4a045Q0<11<;30@F3``371<@11L@30@C2``4610<11XA4@@F30d33`P811H<
30@R5a84<B8L12`K5PBWb<D4Yl_8<VYmP1Goool001CooolWJWf017EmQ@=5;b/4=R/W13<[9`@^9R84
8AdJ134/:P@n=c<3<RhZ12TQ7@@/81X48QPF12DM6P@X7a`47ALM0ahM70@P61P49aLD11lC6@@I4a44
6Q@A0aP@30@K51046A@@11PC40@F40`44`/<11H?30<L4a045a0<11<;30@H40`46Q4A11H<3@<?20P4
5P`<128G4P@a8Q`4;1/F1:O8a@BWblPbJWf05Oooo`005?ooobMZOH04Mi:?0eQID@@d;2L4<2PU12hV
8P@f;2P4;bXW12/V8`<W7Q/49A/H124J60@L4a049alL128G6@@S5aP37a<?11hB5`@F3a444P/;11L?
40@H41435@/<11P?4@@E2``45`l@11D;30@J4A447QHB0aTA4@@E2``43PP810h720@=1`L43PL70aXA
4@@L4Pd45P`<11`>2`BH[J`4Xl?0=VYmP1Goool001CooolWJWf017NBS`=HFE44=2`W130X9@@^9R84
=R`X12lZ9`@[9R<39ahK12DK60@Q6QP471<@12LO70@R5aT48aLH0alC3`@N4QL45PlA118;2`@G3a04
610A0aD;30@H3a445@/<11L?40@E2``46Q4A11hF4P<I4A445@/<10h820@>1`P43@L710h71`<J4A44
718=11H<30@L3P/4V:f/1:?3`3IZOH0Eoooo000Doooo9fYmP0AgTXl3F5UA13@/9`@`:2D4;RHR13H/
:0@_:RL4:bHS0bLN6`@U6aP48AXH11`C40@W7a`48QLI12<G60<O4`l47Q8G11H?4@@B2`/45`l@11P@
4@<E2``460lA11D;30@G3a045@/<11XA4@@N5Q836A4A11D;30@>20P43PL810d71`@>1`L36Q4A11`B
3@@F30`470h;19R][0BS`l0fJWf05Oooo`005?ooobMZOH04Mi:?0eQID@@d;2L4<2PU12hV8P@f;2P4
;bXW12/V8`<W7Q/49A/H124J60@L4a049alL128G6@@S5aP37a<?11hB5`@F3a444P/;11L?40@H4143
5@/<11P?4@@E2``45`l@11D;30@J4A447QHB0aTA4@@E2``43PP810h720@=1`L43PL70aXA4@@L4Pd4
5P`<11`>2`BH[J`4Xl?0=VYmP1Goool001Coool[JWf00iZk^`A]JF44<2HQ12/S80@/:BH4;BTV13D_
:`<b:2X4:ATF12LL6@@L5A4471<@11TB3`@N4`l350/;11<;2`@H41046Q4A11H<30@I41035P`<11T@
4@@F30`4:aXE110820@H41047ADA0aXA4@P?20P44`P811`A4P@N4a<36a4B12/J5P@m:1d4LU8k18ZG
S`A]PhHfJWf05Oooo`005?ooob]ZOH03V[^k16eYH@@`9R44:b<P12`Y9P@]:BH4=Bl[0c8X:P@Y6AH4
9a`I11`E4@@L4a046A8?11hC3`<D2`/44`/;11P@40@J4A445P`<11T@40<F30`46A0A11H<30@[6QD4
40P811P@40@M5A436Q4A20l820@C20P4714B11hC4`<K4A84:aXF13dX7@AbDS/4RYN?16f3QSIZOH0E
oooo000Doooo:fYmP0>J^k/4KFUQ130V8@@[8b04;2TV12dY9P@e;b/3<RPZ12TI5P@W71T471DA11`C
40@I4Pl47Q<?0a@;2`@C2`/4610@11XA4@@F30`46A0@0aH<30@I41445P`<12/J5@@@20P4610@11dE
4@<J4A483`P811<820@L4A847Q<C0a/A4P@[6QH4?BPM179B>`B:Uhl4KH>6=VYmP1Goool001Coool^
JWf019Zk^`A_He/4>C8^12TQ7@@e;2T4=bl[0cP`;0@Z9R04:b@P12<F6`@I41847a@A11T@4@<M5A44
81LB11/B4A<F30`47ADA11PA4@@`<Ch4>SXl12HI7`<G30d46a4A228H4`@K4Q84<2DO0c8S7@@[6aH4
AS0Y19Fh_PB9/KLjJWf05Oooo`005?ooobiZOH04V[^k16mSF`@i<Rh4:B4M13D/:@@g;b/3>30/12XV
80@[92048aHK11T@4P@O51446A0A0adE4@@P5a846a8A4aH<30@M5A44614A130a?P@j>S`49QTO0aL<
3@@K4A488QPC11/B4P@`9Al3<R<M12/K5PA6<2T4UKRn18Va]cYZOH0Eoooo000Doooo;VYmP0BJ^k/4
Kf=K13Tb;P@Y8Ad4=B`Y13L_:`<h<2`4:RHP12/T80@S5Q/46A0B11lD4@@I41437ADA120G4P@K4Q4C
5P`<11dE4@@H4A44<34n13Xj?0@V6Al35``=11/A4@PR61<46a8B130U7`<b8ad4:a/F14H`:@BE^;h4
RK6g>VYmP1Goool001Coool^JWf019Zk^`A_He/4>C8^12TQ7@@e;2T4=bl[0cP`;0@Z9R04:b@P12<F
6`@I41847a@A11T@4@<M5A4481LB11/B4A<F30`47ADA11PA4@@`<Ch4>SXl12HI7`<G30d46a4A228H
4`@K4Q84<2DO0c8S7@@[6aH4AS0Y19Fh_PB9/KLjJWf05Oooo`005?oooc9ZOH04X/W816mSFPA4>3<4
:R4M12LT8P<e<Rh4?S@_13DU6`@[7aT481LA11TA4@@E2``360l<11P@40@E2``45P`<11XA4@@G30d3
6Q4A11L<3@@E2``4;Bd_12/O:0@l<2`4C40f0d<e<PA<?SL4>R/T120G4P@[7aX4:QhJ0c@/:0A<<RP4
Xkfk19:g^CiZOH0Eoooo000Doooo<VYmP0BRbLP4Kf=J14@h<`@Z8Ad49b@R0cDb;P@n=2l4=BDK12/O
6@@P5a446A4A11D;30<H3``4610@11D;30@F30`46Q4A11L<3@<J4A445``=11D;30@];Bl4:alX13``
;0A<@3H3@cDb14`n=`@j:b@481LB12/O6P@Z7QX3=2`X14`b:0BS_K/4T[Ni?VYmP1Goool001Cooolb
JWf01:;9b0A_HeX4A3Pc12XQ7@@W9283=C8^13hd;`@e9A/4:alI120G4@@I4A445@/<0aP?30@H4104
5@/<11H<30@J4A445``=0aXA4@@G30d45@/<12d];`@[7bP4?30/14a0=P=3=C84C3hg13X[90@P5a84
:alJ12XN6P<d;2P4C38X1:>m^`BB]kTnJWf05Oooo`005?oooc9ZOH04X/W816mSFPA4>3<4:R4M12LT
8P<e<Rh4?S@_13DU6`@[7aT481LA11TA4@@E2``360l<11P@40@E2``45P`<11XA4@@G30d36Q4A11L<
3@@E2``4;Bd_12/O:0@l<2`4C40f0d<e<PA<?SL4>R/T120G4P@[7aX4:QhJ0c@/:0A<<RP4Xkfk19:g
^CiZOH0Eoooo000Doooo<VYmP0AWNGd4Ukbl165?@0A5>S@4>BhZ0cPa;P@j=304?cXf12`Q7@@[7a/4
>bdW13@[90<W6A<47aHA11/B4@@K4Q885P`<0adE6P@K4Q847aLB11L>3P@Q71L4:B8M118;3@<B3@`4
4`h<118<3@@M4Q04:1`I130R6@=D>b/4TI^O18V]]0AZP8<nJWf05Oooo`005?oooc9ZOH04IgUm19Nl
_0AQCd04ACXd13T^:P<h<Bh4>S@`13lj=P@/8Ad4:alK13/]9`@d:b@39aTC11lF4@@K4Q446a8B21H<
30<M5AX46a8B11lG4P@G3Ph48A`G12TR7@@B2`d34Pd<11<>30@B30d47A8@12PL6@@`8QT3E3/[196K
W`B9[K@4JX23?VYmP1Goool001CooolbJWf016MiO@BG_;`4HDm014Dj=0@i;RX3>34^13Xd<0@o>SH4
;24M12/O6`@k;BL4=2/T0bLI4`@O5Q446a8A11/B4PPF30`37ADJ11/B4P@O5a845`h>124L5`@Y8Qd4
4P/=0a8=30@C3P`44P`=11dB40@X71T4<28I0e@k:`BAVil4RJfd16Z0PciZOH0Eoooo000Doooo<VYm
P0AWNGd4Ukbl165?@0A5>S@4>BhZ0cPa;P@j=304?cXf12`Q7@@[7a/4>bdW13@[90<W6A<47aHA11/B
4@@K4Q885P`<0adE6P@K4Q847aLB11L>3P@Q71L4:B8M118;3@<B3@`44`h<118<3@@M4Q04:1`I130R
6@=D>b/4TI^O18V]]0AZP8<nJWf05Oooo`005?ooocYZOH04W/O:165PDP@/8Qd3:R@R13hi=`A7Ad<4
ASli12hR7@@P5QP491DC0c@X90@`:2<4718B11H<30@R6Ql49QdS0bdW8@@V7B44?34^12<I7P@o=c@4
=BX[13P/9`<m;bT4=RPS13`^:0A=@cD4>c0Y15e7=`>U_kl4V<G517B=S49ZOH0Eoooo000Doooo>VYm
P0BNalX4HF1B12`R7@<Z9284?STg14M7@`A6?cT4;R8M120F60@T5A<3=2PT130X8`@L4Q845P`<128J
7`@V7B<3;BLQ12HM8@@l<Bh48aTN13lg=0@e:R/4>2`W0cd_:@@f:2<4?2hX14e3=@@k<2T4GDLg0jFo
_`BHaLD4M8f<@VYmP1Goool001CoooljJWf019k7bPAQH584;28M0bXT8P@n>CL4AdM314Ho>@@^8Qd4
81HH12@E4`<d:2@4<2PS11`B4P@F30`48QXO12HM8`<]9b449QdQ13`a;P@S6Ah4?cLd13DZ:`@h;2L3
?BlY13HX8`@l;RP4CD<e13/`:@AMAcL3YKno19S5a@AdSHa2JWf05Oooo`005?ooocYZOH04W/O:165P
DP@/8Qd3:R@R13hi=`A7Ad<4ASli12hR7@@P5QP491DC0c@X90@`:2<4718B11H<30@R6Ql49QdS0bdW
8@@V7B44?34^12<I7P@o=c@4=BX[13P/9`<m;bT4=RPS13`^:0A=@cD4>c0Y15e7=`>U_kl4V<G517B=
S49ZOH0Eoooo000Doooo?VYmP0BN_l84]/OA0eQ?B0@^9b@4:B8Q13<g?`A>BdP4GEA;15aME0<h<304
;2`_14U8EPAXIEd4ACHc13</=P<d:R`4Ad=?13/b;`@f:b@4>C0[13LZ9P@k9b83>bDM13P/9`A6>Bl4
G48b148Y7PB9[;03RKFj16Z0PdIZOH0Eoooo000Doooo?VYmP0BN_l84]/OA0eQ?B0@^9b@4:B8Q13<g
?`A>BdP4GEA;15aME0<h<304;2`_14U8EPAXIEd4ACHc13</=P<d:R`4Ad=?13/b;`@f:b@4>C0[13LZ
9P@k9b83>bDM13P/9`A6>Bl4G48b148Y7PB9[;03RKFj16Z0PdIZOH0Eoooo000Doooo?VYmP0BN_l84
]/OA0eQ?B0@^9b@4:B8Q13<g?`A>BdP4GEA;15aME0<h<304;2`_14U8EPAXIEd4ACHc13</=P<d:R`4
Ad=?13/b;`@f:b@4>C0[13LZ9P@k9b83>bDM13P/9`A6>Bl4G48b148Y7PB9[;03RKFj16Z0PdIZOH0E
oooo000Doooo?VYmP0BN_l84]/OA0eQ?B0@^9b@4:B8Q13<g?`A>BdP4GEA;15aME0<h<304;2`_14U8
EPAXIEd4ACHc13</=P<d:R`4Ad=?13/b;`@f:b@4>C0[13LZ9P@k9b83>bDM13P/9`A6>Bl4G48b148Y
7PB9[;03RKFj16Z0PdIZOH0Eoooo000Doooo@VYmP0AjUY<3/][E16UTK0A1>SL4<30e14=8C0A8CE44
@D900dY:A0AKFUL4ETe314@l=@@i<2`4@ST_0c@Y9`@U71L49alK13H_:`@c:bL4?BPQ14T`9P=;>Bl4
FDHk14L/8`A6@DP4XLkH19_1`TeZOH0Eoooo000Doooo@VYmP0AjUY<3/][E16UTK0A1>SL4<30e14=8
C0A8CE44@D900dY:A0AKFUL4ETe314@l=@@i<2`4@ST_0c@Y9`@U71L49alK13H_:`@c:bL4?BPQ14T`
9P=;>Bl4FDHk14L/8`A6@DP4XLkH19_1`TeZOH0Eoooo000Doooo@VYmP0AjUY<3/][E16UTK0A1>SL4
<30e14=8C0A8CE44@D900dY:A0AKFUL4ETe314@l=@@i<2`4@ST_0c@Y9`@U71L49alK13H_:`@c:bL4
?BPQ14T`9P=;>Bl4FDHk14L/8`A6@DP4XLkH19_1`TeZOH0Eoooo000Doooo16YbMPAZNGe1JWf019jo
^0C>no44b=kP15YGIPA>BU44LW>50fmZL@AJBdH4Aclk14A0?@AJCe44HeA@0e]ABPA/GUD4Fe5315A>
A`AREe04Cda11416?0<`:bT4GVMf1;3RjPBlmo84RJZXDFYmP1Goool001Coool4JW9f16YiOD5ZOH04
W[nh1<kkl@C8g^04FUMV14i:D@AbLhD3KfYa15Y;APA7?c/4A40m15Y?D@ASE503Fe5:16aNE@AKDD<4
E4i7169GD0A?C444@4Hl0c0[:@ANIgH4/>;Z1;cglPB9ZZQAJWf05Oooo`005?ooo`AZLWH4JWUm@FYm
P0BN_kP4c__a1<SNh0AJEfH4CTYA179cQ@=_JW44FT]614Lo>`A4@3d4FTmA16=DD0=KDDX4K5iE15]A
@`ADCTL4HUM@14m<@@A0AS`3<2/Y15iWMPB`h^X4_?Ob18VZZ55ZOH0Eoooo000Doooo16YbMPAZNGe1
JWf019jo^0C>no44b=kP15YGIPA>BU44LW>50fmZL@AJBdH4Aclk14A0?@AJCe44HeA@0e]ABPA/GUD4
Fe5315A>A`AREe04Cda11416?0<`:bT4GVMf1;3RjPBlmo84RJZXDFYmP1Goool001Coool4JXB716Z0
PdUZOH04LXZ71:C5]PBfgm84WLFh0hfX/@BSa<X4UZRj15]PMPA4CF44?3m00chm>P@m?3X4@Cln13lj
>@@b:b@4<bhX18jTY`?Bood4[moF17ZGU5UZOH0Eoooo000Doooo16Z4Q`AZP8=9JWf017::Q`BTaKH4
]]oB19g5^0>=Z;44XlC:19JX^PAKH7H4A4eQ13`o@0<n?CX4?C`j144o?P@o>ST4<R/T13<^:0B>Y:L3
d_om1:oOePAjUiAIJWf05Oooo`005?ooo`AZQ8L4JX23BFYmP0AbRXL4Y<Ff1;KOdPBMaKP3SJRa1:?4
bPBFZ;X4Ff1f14A=H@@l?d03?Sdj13dl>PA1?ch4?cXi138[90@c;RP4SZBW0m;oo@B_gmH4NYNDFFYm
P1Goool001Coool4JXB716Z0PdUZOH04LXZ71:C5]PBfgm84WLFh0hfX/@BSa<X4UZRj15]PMPA4CF44
?3m00chm>P@m?3X4@Cln13lj>@@b:b@4<bhX18jTY`?Bood4[moF17ZGU5UZOH0Eoooo000DooooHFYm
P0=bRX@4L8^717ZITPBSa[@4^=g81;cUf`>ohMl4_nSU1;o/j@C3l>`4bO_j1<cmo`BE^;X3JX23HFYm
P1Goool001CooomQJWf00g::Q0A`RhL4NYVB1:?6]0BhgLP4_>GK0koQg`Boj>D4_ncY1<?`k0C9noX4
c?go19Fh^P=ZP8=QJWf05Oooo`005?ooof5ZOH03LXZ4172;Q`AjVI84XlJd1;SMb0BliM/3_n7O1;oX
i@Bok>T4`o3/1<WknPC<oOl4UKRj0fZ0Pf5ZOH0Eoooo000DooooHFYmP0=bRX@4L8^717ZITPBSa[@4
^=g81;cUf`>ohMl4_nSU1;o/j@C3l>`4bO_j1<cmo`BE^;X3JX23HFYmP1Goool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool009Woool30000Q?oo
o`00W?ooo`030000oooooooo087oool007_oool500000_ooo`800004oooo0P0000Coool400000_oo
o`<00003oooo0`0000?oool20000O_ooo`00OOooo`050000oooooooooooo000000;oool010000?oo
ooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`0000Goool010000?ooooooo`00
08?oool007goool00`000?ooooooo`04oooo00@0003oooooool00002oooo00@0003oooooool00002
oooo00<0003oooooool0100000;oool010000?ooooooo`0008?oool007goool00`000?ooooooo`02
oooo0P0000Coool200001?ooo`<00003oooo0P0000Coool40000P_ooo`00OOooo`030000oooooooo
00;oool00`000?ooooooo`02oooo00@0003oooooool00005oooo00<0003oooooool0SOooo`00O?oo
o`800004oooo0`0000?oool200001Oooo`80002?oooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(180) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B79837B
75736779776B797870797A72797870797B73797B73797B73797A7279776D797568757163
746A5B7164577062546C5F526C5F526C5F526C5F526C5D4F6B5A4B685A4B685A4B685A4B
68625B798A8B798A8B798A8B798A8B79898A798687798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798485798586798A8B798485798586798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798485798586798A8B798A8B798A8B798A8B798A8B798A8B7E8981
7A787179776A79786C797A72797870797B73797668746C5B6F6C5B6F685B6E6256655D52
655C50665B4F66594C675C4F6C5F526C5F526C5A4D6C5A4D6B5A50685A4E685A4B68716C
687777798A8B798A8B798A8B798A8B798F90798B8C798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798F90798586798586798F90798B8C798A8B798485798586798485798586798A8B
798A8B798A8B798A8B798F90798B8C798A8B798A8B798A8B798A8B798A8B798A8B747E77
74726279776F79726C797B7379776F79716A747066646C6460635A6B58526A554D6B5F53
6C675A6C685A716658685A4D62564A62564A625A4D625A48675A4B685A4D685A507D817E
7D9193798A8B798A8B798A8B798A8B798A8B798485798586798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B79898A798687798A8B798A8B798A8B798F90798B8C798F90798B8C798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B7E837B
7A736D79777079776F79726B79766E7977697E7B738F8079828073807871806C63775F52
775B54775B5771534F6B564D685A4D685A4D685A4D685A506D60536C5E50685A4D68625B
798A8B798A8B798A8B798A8B798A8B798A8B798F90798B8C798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798F90798B8C798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798981
79786679776579776B79776F79776F797773797C757981787E7F7A757F6C79746A7B7166
7B726175665A7B72637A5F5672514D72615E6C61566D5A4D6D574B6B5A4D6D65586D6C64
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B79857E
79776A79777079776A79776B79776F797C7479776F79716A797B737E7F7A7F85767A7B6A
756D647A706271645775685C7168586C584871645C686156625A4D675A4D737473777F7F
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798485798586798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B695D54696159
79777079776A79776979776B797C7479776F797B73798178797C74797A727977737E796F
7F76647A6D5E7A6C5F75655A765F54715D4F67544567594B6D5A4D6C5A4D686D69758487
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798F90798B8C798A8B798A8B798485
797F81798586798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B39352E404B42777668
79776B797773797774797770797870797A7279726579776B79766E79766E797769797B6C
746E6674675E75635C7466546B5D4C6B5F52715E506C5A4D6865587167587271697A8C8D
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798F90
799091798B8C798A8B798A8B
798A8B798A8B798485798586798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B64686F311C1A272E387A786E
797C71797B73797C74797B7379726B797B7379817D79777079766879655F7459566A554B
6F625375685B706C5C6A6257716255716053675D4A675A4B63544862554A676159798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798F90798586798586798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B7E90912F24197E7C6689877179776F
79726C79766E79726B79766E79776F79726B79776F797A727471676F6E5F74685D746659
6C60536B5F52705F4D706151675A4D6B564A715A4F725A4E6C5A4D6D605368554A747573
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798485798A8B798B8C798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B22191378776E92928A7A786E79776B
79776F79776F79776979776B79776F797C7479776F79766E794E4F753C3F703539703237
7133387149466B554C6B554A6C5448675746675A4B6C5A4D6B5A486851435D4134655B52
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798485
798586798A8B798A8B798A8B
798A8B798A8B798F90798B8C798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B646869BCBAB888857F79766E79776D79776B
79776F797163796D60796D5D79726779726B79656379595C795A5770463D6A362C6B3F3A
6B42396B37386B3E3D624A43625A4867554968574B6C5A4D715A506D584B715D505E3F30
695B51798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798F90
798B8C798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B27221E1B252375726079776579776979776B
7977697470616F6357746E6379786C796C5E744E466A3530644C42563D2E5D69576C7B68
6B3F345D2B236B352F6C403C68514B685840635741675A4B6C5A4D6C5E506C584B6C5C4F
6C5D5179807C798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798485798586798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B504D4F897160746E617A7871746C6374736D797B73
796C6273604F654E416A4C4E6E393A2F08062E2D2A7060557B655D97B6B284534D62372F
52523A5161523F3B2B4B29216338336351406D52456D5C507269557161506C60536C5A4D
5D423569554879807C798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798485798586798F90798B8C798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B352F2B3E4D4B7A7A7279776A796D5F75675E79766E
7974687253426646382F0B09314142B0EADF93BCB785C1C480AEB77A87887EA89290B6AD
9DB6BA76807F4E3D351D1E132E231C60473F68594A725E5372645A766B58715E4D6C5A4D
6C5C505D5C64646D7A748082798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798F90798B8C798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B6973803623202530347573637977697E84747A7A6E79776F
6E5C515F4D384F2C1F48160B4B1F1C6E3F366F4B40745E56797460796B56735D546B5856
6E594C8F7766A18E759083733229202C1E1C5A4139675B4B766F5F756B607065586C584B
6C534867584154564B52555E697582798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B39352E0A05035D4B42756C637A786A796C5F796458796E5E797765
786A5985716794AA94C6E0BD93988D7B6765705D5666453D6A3A3C643639643632611C18
602422583733684C3E7044407A574E2D0F0732232468534A716758746A56705C4C675D4F
676153715A4C888680777B8067707A798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798485798586798A8B798A8B798A8B798A8B798A8B
798A8B798A8B696D7417120E120F0D3A5151807F73797164796968746E69747468796564
78655D6147366657507A7D7B79897B7E8C8084988C85978B80A087848971828C757C9070
7C8368725649774946763A336D2B1F6622183A1510462D2E6B595074665670604F6B5448
6853486C584C26150E393A2D78807F748082798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798F90798B8C798A8B798A8B798A8B798A8B798A8B
798A8B798A8B778992ECDAC4FFCDA587796574726579756879816A7E6C687A6A6779846D
78766479645769574B746A5F797B73797B7379726B797B7379696B79656075685C74665C
7162556B614D5D624C666F547677608B836A84736965544163564570635370604F6B5E4B
685B4B6C5C505449412E35346976737A8C8D798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B89856B7C776B7E8A857A7D71706E6274776A79787179847879807B797B78
7E7C707B7160674B41655549747368798077797B7379787079887379746470584B705B4B
665C475C54485A4F3E5E45395E49395E4839635039695F536D6357715E546B564A675148
63574662574830221C2E3C4A73818E798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B747E80747C76746C5B6A55425F5E5E6A6E6C7A736D797C75798178797C74798077
7E71717F6F687B675872584F75665D79776F796866746059747164736C5D70645666473D
664E476B4D40644D3E64544469574168573F644C3A6A5346725C4F6B594C6A574A685549
68574E6D60532015160F1C19606965798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B7E7B6B7A756B73685D6A5C537B6853786763796A69797870797B73797B73797B73
7988737E7B6979725C6C5748705F5779787079887A7E7E797A78757E7570756B60756B5A
725D4F6B534464493F644E4264534C72584F7D695D74685B6B5D4F6B5A4D715E506C594B
685746635748321D160A0C0D1F2327798586798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B79857E747160634F3B6C64567C6A687A786A797A6C79787079827E79807B797B73
797A76797F75787164716B586C6654746E63797668797C70797B737978686E5F516B594C
675A4D6B5E506D5D44684F3D6450446E6159776C6275685B706B5D6C6758675E50675E50
685B516D6559AF7C516434230E0706191E22798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
7973696E52485F2B276947435B5B57657D6A797A6A79776B79787079766C797A72797B73
797A727471677978697B7E727B7B6E7A786674655E74655B79655F735C516F5848675146
624C4063513B58453959483D695B4F6D6656716659746659705E516C594C715A4D6C5A48
6D54466D5A4F746359987763D3D6CB8DA3A3798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
7972747854516F494168514878675878746D797C7A797B73797870797B73797B7379766E
7976687975677A71637A6F6275736D797C7A7E897F7A7A76797866786B5E6B5D4F625043
5E4B3E56463F68534670675874685A726A5D71695D7466597062546C5D4F6C544D715150
68544B675B55665240634F416D625B7E8F90798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B79786F
797E6978705B6A5A4168594A726B607A786C79787079807779776F79716A746C5F747160
79656379635F70665A74655A756F6579726579766A79776F796D6E785B536F564A675346
685446645A4D65604D695E4E6C6154766559716356705D51705E516C574A6C5446675546
675B48685F527563596D5D50514540626A6D798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B6E6858
563C30372C233A352E5B564E726E6379776B79726B79716A79766879715F79716370635C
6A65566F645C75736975786A75746479776F79777079776F747E6B736F5E6F5B4D675346
6451446D53476A574E6E5C567261576C605370685C716B5D7063556C675867625367594B
68524E685A5562402F674F436C4432684E44798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B726152
321E122D231F251E1E31383B716C6779777079776979776579776F797B787E7C797F857C
7F746E715D56654F476A5C52706A5E74726879776F7977697969616E5D53654C4A634D40
5F4B3C6050446D5D50685A4B66584C6B5B546B524966564B66594C62564A675A4D68584B
68554B635145615A40574431624B41685654798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B797E7A7E7C77
8A5B48412B20332521393E3E716C5D74715F74726B79776E6960505A51434D3E32413229
453B344E3F3E614C47624C4265544B706A6179776F7977737972697462566A5940644C39
6351425C4E42554B41505045595348626151666051675C507163556C5E50685A4D68584B
68554B68574D51372C3A1D17493325635145798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B747064736457
1E0A070E0C0C17171528393B716C607971647A7363797769837C6C665A4C4E463A2B2D2C
13191A131A122927213B221A33141147302B746E6379776F7978687466566A56445F5941
5949386055497766577D6859735F51684E485D4F475F584D6C5F526B5D4F5E5448555448
5F5B4B685B4D65473657342656332B644743798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B7E909183847B735B4B
5C3A322317132516132C36397A796B75766874736779776A7E7F7786766799807562493B
2819151F17121D25263F4035776C5B736F62757A6F7988847982787468595F4B3F543E33
331009312020513E2C47392C332C233F3D325E52455C5444625647675A4D6653455F5246
61524B5E4C424A352C47392E5A4D456E5E5B7E8F90798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
797F81798586798485798586798A8B798A8B798A8B798A8B798A8B1A0907090C13746658
664435261D231713111C2F33706E6279776A7572656F6D61747268838779726C5A9C7A63
BC91739F725085583B77684F72655472615675706679766C797266746455745641634A3C
6F503B4743412930350202050F1517252725151612171E21312C2248382A6251435F5649
61554656483B372B2028231F42483F6D655C7D8E8F798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798586798687798F90798B8C798A8B798A8B798A8B798A8B2012101D1412020000000409
130F1514110E22171429343775726575736D6D534F6046416A61597E817D848E888A817A
7B6458806E61836F617B6959786F5F766C5F757167797B7379706B746D616A5F4B675D42
735E4384634C92644C2517171A161229201F292220342E255A463B645C4C6C5545645246
615B493A2924281F192A1E1732231E5D3E3978898A798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
799091798B8C798A8B798A8B798A8B798A8B798A8B798A8B452A242F22192E1E181B1917
0E090A2116132918152C30337A6E62756E5E8492827A796A4B392D3C2922392E252A2923
211E1C201C1829231C30211D443E396A6B5F75706679716479715E7466586A5A4D68483C
5F553F605943716553C69473AC83677F553D7E4E387A5B4A786045605445635E4C72604F
5F554B3B2B1F2217142B1E1835251D593A36798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B4D32241A0D0A11110E16110E
1F141014120F2425222B39396A665B7E786A7A786C8989829BA08F826E635F515175615A
8B66528065536F58477C6B5A7D76687C7B737A7871796567796C65746B5C6A5451452C25
341D1A41372D5F5741685A46766250857159776D5968634F5F5A4F68554F5F524B5F5746
5648381D171311110F4E4B3F5C3C2B513E39798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798485798586798A8B798A8B798A8B798A8B59423428110C1E120F161310
08040617100E26211F2A323158564E746F6379776B797C747E85808FA396ADB29F98AB9C
9DB2A79FB0A6A5B8AD91A0907C7B6C75796E7475676F7A637473637A6F6281816993866F
5B403B2319190D0E0F1D2021514940675A4B715E495F5549634F435148395E4F486A524B
3A261F21141026221E2929234B2B1E1508061E2225798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798F90798B8C798A8B798A8B798A8B798A8B463F3A27211E1D15111C1310
16100C19130F25211F37383460595075706479776B797870797B7379827E798787798787
79807B79827E79807B79807C7E7F757A73637E7A6B7A716375665A7A6D607B736485786F
A29382AC86767C5B4D2E251E0E100E1114161E21222A2822322B225B49446C574A635042
311E191C13101C15170E09081A100C362825363F41798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B5947403F302C1D1713191310
1E141120181A2723212D332E4849416A675C79776679726779776F79766C797B7479817D
79868579827E797F79797B7379807C797B7179776A79746575726475685C75695D756C60
7A6C5E76735F8D7760977D658C7159664F3B5F42316B52437A6757614F4A594F484F4E40
33201A1D131015120F0E0F0B1316142A2826353E40798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B543D2F2B1F162B1F1A1E1411
1F0E0B241612291E162625213A3B37625B5274726679776B79787079827E797B73797B74
79817D79817D797F79797B7379766879766E79716879695D75695D75726475685C756758
746355765D51766254756253826C5C8C756389746277635473574F6E5C4B6C51434B3326
2D1B161D13102618151B141117120F201A141C1818595B60798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B46372A302B28281F1C271916
130F0C15110F15100E211B1726241C4A433B756F6379776B797870797C76798685797B73
797B74797A72797A72797B73797A6F79776674706174716375685C75635875675B75685C
7466596B62546B5F5271685A685E506C5A4D6C5A4D5E584B5555465555484B483B272420
100E0B1B1618110E10100D0A0804061611112223224A4C4C798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B5940332E252130292527201C
2A1A171E1411241D192929282A2D2C3539376A5E5479726879726B797268797B74798685
79827E797F79797B73797B73797A7674716874706275675B75675B75685C70685C6B6356
7063567062546C5F526C5C4F716254685E50675A4D66584B6A554968504346352D2A1915
2A1E1B0F090B100D0F0A0406120E10161210242B2B444C4E798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B4D4742322D2A332D29332B27
271A17130F0B1D15122F201947342848382B5D4F44746F5F79776B79726B797268797B74
79817D79868579807B797B73797A727E7B707A7566706C5E6B6356705F58745F56715D51
715B54705E546C5F526C5A4D67564A675A4D634F426C51455F4B3E45383234261E281915
110D0A120E100E090B130F0B130F0F21171567797C869C9D798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798485747A7B463A352A24212E29262E2724
1D1511271D1A251E1B201F1D3230284A433A5B524A706B6079776B797C74797C74797C76
79817D79817D797F79797B73747466746D6079695D7A675B7B6C5F716757706456716254
6B64546B635467544D62564D675A4D685A4D6C5B4E5F5649534B3D56413136261C251915
1A1411181410191511130F0B17130F1F1714272D307E8F90798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798F907E959543383133241C2E2420302A27
372E29281F1B28221E2D221930353036372E483E36665A5174726879726B79776F79766C
79756A79756A79756C746C5F746B5D706E62746F617063516B5F5070635171645471675A
705F526C5E5171614F6C5B4D6854486851465E5448534B3E4B3D30302321231715151210
110E0A110D0F0D080B0404060A070A2C232135353878898A798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B5B48422D231B302925312B28
28221E2418152B1F172D26232D2C272E262034302C5D544D757363797765797267797164
79716079716079766A7E7B707A7566756358705C4F705A51715B5471605A71645771594C
705B4F6C5A4D6C5A4D6B5A4D68584B63504357483B4B3B2F302321281F181C1410171310
1D1411140F100F090B10090B26181585A1A090A8A8798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B6A655E362F2C2A2522322926
32231A2B241F211C1A282321211D1B2326262A2F2940372D60584C6F6D61747262797769
79776A7471646F6D5D747265796D60705C507063516B5D4D665C4C665C4F6B5B4F6B5C4F
6B574B6C544D67574D675A486353425E504357493C3C2B242D211819120F110E0A110D0F
181210140F100A05060D090A1C15131F252978898A798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B605B4F3A312C332D292A2623
2B272520181A211B19241F1C312B282D2119211C18262A28433B35604E456B5C526F6458
6F695D747164756D607064596E6A5D6A5F5166534A6B594D6C51466C524767564A6B5A4D
675448625446624D405949404F4A3E43392D4332272E231918120F151210130F0B0E090A
0B080A0404060404062217142F1D15302F2E798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B99A1AF513F3C322A272E2724
35302D37281C2719142F282627211E2E2A29211D1B1C23221B2220242522493D375B4D43
5B4F4B605554605952655F5465574B4E4337433A30503E305E4E4062524662473B624A40
67543D63503E5E4B3E5943375443374130292C1C172316141C1310130E0B0E090B0E090B
0A04060504060E090B15110F759095889B9D798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B93AEA86561502C251F292421
28232022221F1E191B241C162E2621342F2C39312D2923222A29292A2C2926241E292929
20272626261F37312A3B372F36312C3A3128362C223330243D302548382A554835544134
43342D4431284C392F433933372925311F172516141B1210110E0A0D090B0A0406040406
0404060504061513102318152C35387A8C8D798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B808492403533312B28
2E2D293029251915111E1E1C332F2C35302D3C3733413C37423D333C3C3330342E2A2623
2B1E19241C1C241B1A2C23212B242325242530262231231B2A221D302B25322E26342C22
3D3328362C212F2B2534251F2F231B211714201C19130F0B120E0B0F090B0A0506060406
0504061C1310140F104F4E4D606363798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B9BABAD5846412E2623
2C24212C2623372C28362E2B342F2C393531302A272B26242C201F37221E36211A2B2320
1E1B192323201B16141B1C1C262321221F1C191413161617161312140F101816131C1A15
1B19151A13121910101812111A131214120F0E0D0A0D090A0D080B0E090B050506050406
1C131A1C1311322924647F8183999A798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B839994909A9A403732
2C2623312B282E272438343028221E2A282628211E2B27243C372E302E2B2827252B2623
2B2420342A27241B1C1E1E1C1F16132115121A120F13110E16120F1E16141F151417100F
14100E16110F1E16141A131018120F120E0A120E0B0F090B0E090B0504060504060E090B
201B17271A168798998DA3A3798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B8F989E553B36
352B28312B282E27241D1D1A312F2C3B363234312D25211E281F1A231916231E1B25201C
1A171D181C1B1F19192215131A1219131210141310120E0B14120F12120F12120F100E0A
0C080A0E0D0A15110E110E0A0C080A110D0B120E100F090B0504060E090B1A141129201B
25181590A5A590A6A7798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B89A49E73726A
362E292E29262E2724352D292B2A2729272428201D221B181C191819120F221D1B1E1719
2017181A110F1911170F0D100B080A100D0F110D100E090B100D0F0D080B100D0F0E090B
120E10171311110E100D090B050406030406030405040406120E10140F0B0D090A140B09
808F8F8A9C9D798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8BB9D8D8
7F78703128232924212A29262C2A2733302C322A2C271917231B1818141115100E14110E
18120E0D090A0B0809110D0F130F110E090B110D0F0F090B110E0F0F090B231714070507
0F0D0F151210130F100505060504060A0406140F10161011130F1025181539271C684D39
6260567A8C8D798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
B9D8D882726A39342F27211D332C2935302C39332E2A282328231F20151C120E111A1210
120E10171411191511130F100E090B0E090B0D080A0E090B0D080A1713100F0E0F2E303D
34383C21171F0F090B140F101B15111B1611140F1029231E2E221C251915402D277D949C
849DA0798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8BC0E5E5827068473B3627211E25252334332F41373233251C2A1F191B1511110E10
0D090B100D0A110D0F0E090B0E090B120E100F0A0B120E100F0A0B0C080A272B2C251D26
382F2E4D443A433534483C37372B251B1512261E19231C19312B284A33298A9B9B889B9D
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B748586B8DCDC715B4B493D36382F2B35312E3B3732413D3A2B221E291E1B372C27
312B24221713191410141011130F110E090B0E090B1612191410121814110E0B0C1C1D17
22201D0D0B0D0D0D0C0C0D0B0C0B0D19110F211A182D22194D3829888E90788D95798B8C
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8BBEE7EC6F6A5C2E26202724223D3A374949454B453F2C221E1B1517
2115133128242D28231611120E090B1C181E201B23272420211C21362F2D1F181E353232
332B2C392E293A2E29332823392E28484035392F2956443693A2A396B3B07C908F798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8BBEDDE2C9D2DC5D534E2B2724292423353A4252504E5E554C
5C5C553830312B2D3049495667635F423634302C3630282E46424D373131392D26312C29
392D283A27243A261D382D2843382F584032482C206D899084A2A5798B8C798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B8EA9A3CEEEEC766F78423C3A3031333F484F4C5155
44464450514A5D5A57544D44463E393F3731423A30332B2A211B1626211E35302C312B28
3C2A224A31274C3A305B453A472E25433F45A5C1CC8BA3A4798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
797F81798586798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8BBEDDD4D8FAF8D3DFE05F5E6E504E55
767485766F795F504B4C44404945415F545565565361564E6D5F585D5245534E47655852
504E4542473D332D2A555D69B5DBE7BEEAE7849A9A798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
799091798B8C798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B839994C0DBCCB8DAD3
A3C2B59DB4BFADC7D3A5B0C265687F47506341444744423F3F3F3D474443413E3B332F27
38332B829293DDFFFFA6CBC47E9393798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B8399907B92918EAA9FB8D4C5C0DCCCC6E7E5C7E1E1C7E5E5C7EAEACCEFEFD2FAFE
D3F7FD89A3A5798B8C798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B798A8B
798A8B798A8B798A8B798A8B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?oooeUiRX/4NH=k17EcI`=iMf/4NGQ`17UjLPAiN70;NG]c17Uj
LPAiMfd4NGEX17EaH`AdJU/4LFAG0g1RE11/Ge84K5e?0f]JB`aXFT/4J69K3gV:R`AiRHX4NHJ78gV:
RaGoool001CooomINHZ;17V3N`AeLfL3NGM[17UhL0AiNW84NGQ`2gUkL`AiNW84NGM]17UeJ0AeLF<4
M6YK175TE`=`HU@@K5mB16aMC`=[FT/<J5Y;16QRF`miRX/4NHV:17V6Qb=iRX/Eoooo000DooooFGV:
R`AiPg/4MG=W0gUgJ`AiN704NGYb17UhL0]iNg<4NGYb17UgK@AiMFP4MG5S17AZF`AaI5L3L69D46aO
DPA/GDl3JeY;36QJB`AXHU/?NHZ;17V9RPAiQXLSNHZ;5Oooo`005?ooo`AiRX/4NHB517V5QPAiRX/4
NHB50gV5QR=iRX/4NHB517V5QQMiRX/4OXV117YhL@=iMfX4NGQ/17UjLPAiN704NG]c17UfJ0=dK5/4
KfaK16mXF`A^HUH4IEeB16ELD0AVFdl3IUU<16MLC`Q/Ge88K5Y=0f]JD0AXFTh4J5Y;16QaK0AXMgL?
NHZ;17V?T0AiRh`SNHZ;5Oooo`005?ooo`AiRX/4NHB517V5QPAiRX/4NHB50gV5QR=iRX/4NHB517V5
QQMiRX/4OXV117YhL@=iMfX4NGQ/17UjLPAiN704NG]c17UfJ0=dK5/4KfaK16mXF`A^HUH4IEeB16EL
D0AVFdl3IUU<16MLC`Q/Ge88K5Y=0f]JD0AXFTh4J5Y;16QaK0AXMgL?NHZ;17V?T0AiRh`SNHZ;5Ooo
o`005?ooo`AiRX/4NHB517V5QPAiRX/4NHB50gV5QR=iRX/4NHB517V5QQMiRX/4OXV117YhL@=iMfX4
NGQ/17UjLPAiN704NG]c17UfJ0=dK5/4KfaK16mXF`A^HUH4IEeB16ELD0AVFdl3IUU<16MLC`Q/Ge88
K5Y=0f]JD0AXFTh4J5Y;16QaK0AXMgL?NHZ;17V?T0AiRh`SNHZ;5Oooo`005?ooo`AiRX/4NHB517V5
QPAiRX/4NHB50gV5QR=iRX/4NHB517V5QQMiRX/4OXV117YhL@=iMfX4NGQ/17UjLPAiN704NG]c17Uf
J0=dK5/4KfaK16mXF`A^HUH4IEeB16ELD0AVFdl3IUU<16MLC`Q/Ge88K5Y=0f]JD0AXFTh4J5Y;16Qa
K0AXMgL?NHZ;17V?T0AiRh`SNHZ;5Oooo`005?ooo`AiRX/4NHn@27V5QPAiSi03NH^<17V:R`AiQ8D4
NHF617V4Q@AiQHH?NHZ;17V?T0AiRh`GNHZ;17AnM`AdLV83NGM_17UbK0AiNg<4NGM_17UaJPAdL6H3
I6aT161SFPA[F584JUE=16]OD`A/IeX4K6QJ0g5VF0AXFTd8HUI:169JC@ARFTP3IeY;16QJC@AXFU04
OH5n17fATa=iRX/4NHB517V5QQmiRX/Eoooo000Doooo17V:R`AiSi08NHF617V?T0=iRh`4NHZ;17V4
Q@AiQHH4NHB517V5QPmiRX/4NHn@17V;S1MiRX/4M7ig17AbHP=iMfl4NG9/17UkL`AiMfl4NG5Z17A`
IP=TK6@4H6=J16]HDPAZEDd4JemC16aWFPA/J5X3LFIH16QJC@QRETX4HUY=169JB0=WFT/4J5Y=16QJ
D0AmPGh4OI6C4gV:R`AiQ8D4NHF67gV:RaGoool001Coool4NHZ;17V?T0QiQHH4NHn@0gV;S0AiRX/4
NHB517V5QPAiQ8D4NHF63gV:R`AiSi04NH^<5gV:R`AdOWL4M79R0gUgK`AiLV`4NG]c17UgK`AiLFX4
M71V0fA/I0APHeX4JeQB16YEC@A[Ge<4K6MJ16aXFP=aIUP4J5Y=269FBPARFTd4HUY80fMJB`AXFTd4
J5Y@17f1OPAmTI<CNHZ;17V4Q@AiQHHONHZ;5Oooo`005?ooo`AiRX/4NHn@27V5QPAiSi03NH^<17V:
R`AiQ8D4NHF617V4Q@AiQHH?NHZ;17V?T0AiRh`GNHZ;17AnM`AdLV83NGM_17UbK0AiNg<4NGM_17Ua
JPAdL6H3I6aT161SFPA[F584JUE=16]OD`A/IeX4K6QJ0g5VF0AXFTd8HUI:169JC@ARFTP3IeY;16QJ
C@AXFU04OH5n17fATa=iRX/4NHB517V5QQmiRX/Eoooo000Doooo27V:R`AiRHX4NHJ72gV:R`AiSi04
NH^<17V?T0AiRh`^NHZ;17j3N`AjLfd3NGM`17UgK`AiLV/4NGI^17UgJ@AnNg<3Sh1i18:0L`B0N744
P6aS17MODPAgFe@4Me]G0g5CC`A[ETd<J5Y=16QJD0=]H5<4K5i@16QJC@AXHU/GNHZ;17V?T0AiRh`O
NHZ;5Oooo`005?ooo`QiRX/4NHV:17V6Q`]iRX/4NHn@17V;S0AiSi04NH^<;WV:R`AnPg/4NW=]0gUg
L0AiMfl4NG9[17UfKPAiMfT4OW]c0hn0N@B2P7<4P7Qa181/H`AgGe84Me]D17MKE`=aDdl4JeI=36QJ
C@AXFU03KF1C16aND0AXFTd4J69K5gV:R`AiSi04NH^<7gV:RaGoool001Coool8NHZ;17V9RPAiQXL;
NHZ;17V?T0AiRh`4NHn@17V;S2iiRX/4OX=k17YcK@=iMg04NGM_17UbJ`AiMVh4NGMY17ikL`>?P7T4
PX1c181hL@B0K6<4MemB17MKE0AgFeL3LE=?16]FC@aXFTd4J5Y@0fePD`A/GU04J5Y=16QRFaMiRX/4
NHn@17V;S1miRX/Eoooo000Doooo27V:R`AiRHX4NHJ72gV:R`AiSi04NH^<17V?T0AiRh`^NHZ;17j3
N`AjLfd3NGM`17UgK`AiLV/4NGI^17UgJ@AnNg<3Sh1i18:0L`B0N744P6aS17MODPAgFe@4Me]G0g5C
C`A[ETd<J5Y=16QJD0=]H5<4K5i@16QJC@AXHU/GNHZ;17V?T0AiRh`ONHZ;5Oooo`005?ooo`QiRX/4
NHn@17V;S4UiRX/4NHV117UhIP=iMfD4NGM[27UgK`AiMg<4NGae0gV1N0AnOgX4MGm/17UdJPAkLFH4
Ng9Q17EVFP=kLV<4NUmF179AC@AbHEh4K65F16eJC@=]Ed/4JeY=16eUF0A]K6@nNHZ;5Oooo`005?oo
o`QiRX/4NHn@17V;S4UiRX/4NHV117UhIP=iMfD4NGM[27UgK`AiMg<4NGae0gV1N0AnOgX4MGm/17Ud
JPAkLFH4Ng9Q17EVFP=kLV<4NUmF179AC@AbHEh4K65F16eJC@=]Ed/4JeY=16eUF0A]K6@nNHZ;5Ooo
o`005?ooo`QiRX/4NHn@17V;S4UiRX/4NHV117UhIP=iMfD4NGM[27UgK`AiMg<4NGae0gV1N0AnOgX4
MGm/17UdJPAkLFH4Ng9Q17EVFP=kLV<4NUmF179AC@AbHEh4K65F16eJC@=]Ed/4JeY=16eUF0A]K6@n
NHZ;5Oooo`005?ooo`QiRX/4NHn@17V;S4UiRX/4NHV117UhIP=iMfD4NGM[27UgK`AiMg<4NGae0gV1
N0AnOgX4MGm/17UdJPAkLFH4Ng9Q17EVFP=kLV<4NUmF179AC@AbHEh4K65F16eJC@=]Ed/4JeY=16eU
F0A]K6@nNHZ;5Oooo`005?oooeUiRX/4NHEn17UgJP=iMg04NGMZ17UgJ`AiMfl4NGad17UgK`=iLFX4
NG]c17ioNPAoQGH4NW]Z17E]I0AjL683LFAG17EXG0AaJ5P4K5Q8175TG0AXHEH3HUY=16MJC@AcM7<4
Mgmo6gV:R`AiQ8D4NHF66gV:RaGoool001CooomINHZ;17V5OPAiMfX3NGM`17UgJPAiMf/4NGM_17Ul
M0AiMfl3NG5Z17UkL`AnOgX4OhEf17YkJPAeKF@4NW1R0g5TE`AeJ5`4LFQH16aHB0AaI5`4J65F0f9J
C@AWFTd4LgAc17MoOa]iRX/4NHB517V5QQ]iRX/Eoooo000DooooFGV:R`AiQGh4NGMZ0gUgL0AiMfX4
NGM[17UgK`AiO7@4NGM_0gUaJPAiNg<4OWmj17n5MPAjNfX4MFeT17Y`HP=aI5L4MFQL175XF0A/F4P4
LFAL16QQEP=RFTd4IeY=17=dL`AgOglKNHZ;17V4Q@AiQHHKNHZ;5Oooo`005?oooeEiRX/4JEeD16UQ
F@AiMg03NGMZ17UgJ@AiMf/4NGad17UgK`AiNg<3NH5h17UlM0AiNW84NGMc17iiK`AoMV@4NVeN0gY/
G`AeIEX4MUmD175MC`AWE4D4IeU;0feJC@A/FTd4J6eY17F4Qa]iRX/4NHn@17V;S0MiRX/4NHB517Uo
P@AiQHH8NHZ;5Oooo`005?oooeEiRX/4JEeD16UQF@AiMg03NGMZ17UgJ@AiMf/4NGad17UgK`AiNg<3
NH5h17UlM0AiNW84NGMc17iiK`AoMV@4NVeN0gY/G`AeIEX4MUmD175MC`AWE4D4IeU;0feJC@A/FTd4
J6eY17F4Qa]iRX/4NHn@17V;S0MiRX/4NHB517UoP@AiQHH8NHZ;5Oooo`005?oooeEiRX/4JEeD16UQ
F@AiMg03NGMZ17UgJ@AiMf/4NGad17UgK`AiNg<3NH5h17UlM0AiNW84NGMc17iiK`AoMV@4NVeN0gY/
G`AeIEX4MUmD175MC`AWE4D4IeU;0feJC@A/FTd4J6eY17F4Qa]iRX/4NHn@17V;S0MiRX/4NHB517Uo
P@AiQHH8NHZ;5Oooo`005?oooeEiRX/4JEeD16UQF@AiMg03NGMZ17UgJ@AiMf/4NGad17UgK`AiNg<3
NH5h17UlM0AiNW84NGMc17iiK`AoMV@4NVeN0gY/G`AeIEX4MUmD175MC`AWE4D4IeU;0feJC@A/FTd4
J6eY17F4Qa]iRX/4NHn@17V;S0MiRX/4NHB517UoP@AiQHH8NHZ;5Oooo`005?oooe5iRX/4>CD^141;
@PAgMVP4NGM[0gUgL`AiMg@4NGM`17UhL0AiNW84NG9U0gUgJ`QiMVh4NGMY17UkK0AdKVH4M6MN0gES
G0AdIU@4Jee<16]ODPAaGU04K5Y=0fQUF0AaIeP4LW5Y17Z<SBYiRX/4NHn@17V@T@AiRh`8NHZ;5Ooo
o`005?oooe5iRX/4>CD^141;@PAgMVP4NGM[0gUgL`AiMg@4NGM`17UhL0AiNW84NG9U0gUgJ`QiMVh4
NGMY17UkK0AdKVH4M6MN0gESG0AdIU@4Jee<16]ODPAaGU04K5Y=0fQUF0AaIeP4LW5Y17Z<SBYiRX/4
NHn@17V@T@AiRh`8NHZ;5Oooo`005?oooe5iRX/4>CD^141;@PAgMVP4NGM[0gUgL`AiMg@4NGM`17Uh
L0AiNW84NG9U0gUgJ`QiMVh4NGMY17UkK0AdKVH4M6MN0gESG0AdIU@4Jee<16]ODPAaGU04K5Y=0fQU
F0AaIeP4LW5Y17Z<SBYiRX/4NHn@17V@T@AiRh`8NHZ;5Oooo`005?oooe5iRX/4>CD^141;@PAgMVP4
NGM[0gUgL`AiMg@4NGM`17UhL0AiNW84NG9U0gUgJ`QiMVh4NGMY17UkK0AdKVH4M6MN0gESG0AdIU@4
Jee<16]ODPAaGU04K5Y=0fQUF0AaIeP4LW5Y17Z<SBYiRX/4NHn@17V@T@AiRh`8NHZ;5Oooo`005?oo
o`QiRX/4NHB517V5QSeiRX/4I6Q_134L6P@W;SP4NWQ^17UlL@=iNg<4NGad17UkL`AiLV/4NG]c17V1
O@=iMg04NGIX17UUG`AdFEH4JUE;16mRD`AeJ5/3L6aL16YRE`AaHUD4LF1C16MMBPAWFT/3HeA8169E
BPAWHEU2NHZ;5Oooo`005?ooo`QiRX/4NHB517V5QSeiRX/4I6Q_134L6P@W;SP4NWQ^17UlL@=iNg<4
NGad17UkL`AiLV/4NG]c17V1O@=iMg04NGIX17UUG`AdFEH4JUE;16mRD`AeJ5/3L6aL16YRE`AaHUD4
LF1C16MMBPAWFT/3HeA8169EBPAWHEU2NHZ;5Oooo`005?ooo`QiRX/4NHB517V5QSeiRX/4I6Q_134L
6P@W;SP4NWQ^17UlL@=iNg<4NGad17UkL`AiLV/4NG]c17V1O@=iMg04NGIX17UUG`AdFEH4JUE;16mR
D`AeJ5/3L6aL16YRE`AaHUD4LF1C16MMBPAWFT/3HeA8169EBPAWHEU2NHZ;5Oooo`005?ooo`QiRX/4
NHB517V5QSeiRX/4I6Q_134L6P@W;SP4NWQ^17UlL@=iNg<4NGad17UkL`AiLV/4NG]c17V1O@=iMg04
NGIX17UUG`AdFEH4JUE;16mRD`AeJ5/3L6aL16YRE`AaHUD4LF1C16MMBPAWFT/3HeA8169EBPAWHEU2
NHZ;5Oooo`005?ooo`QiRX/4NHn@27V5QSEiRX/4OY2A12lT6@AnO6H4RHMa17UgK`AiLV`3NGI^17Ub
J`AiMVh4NGM_17UbJ`AiMfl3NGYb17AaI`A_KUl4M6QM17AVF@A/H5<4JemB0g1OC@A`HE44IeY=16]F
BPAaFTl4LUY>0faJC@A]H5<4J5E:17AeLciiRX/Eoooo000Doooo27V:R`AiSi08NHF6=GV:R`AnT944
;b@I17ilIPB9Qg44NGM_17UbK0=iMVh4NG9[17UfKPAiMfl4NG9[17UgK`=iNW84M75W16m^G`AdJ5d4
M6II16aPD`A[Ge83L5m=171QD@AWFTd4JeI:175JC`AbFTh3K5Y=16ePD`AXEDX4M7Ec?WV:RaGoool0
01Coool8NHZ;17V?T0QiQHHeNHZ;17j@T@@_91T4OWaV18V7L@AiMfl4NG9/0gUfKPAiLV/4NGI^17Ug
K`AiLV/4NGM_0gUjLPAdLFL4KfiO17AXG@AdIUT4K61C16]ODP=`Gdd4L65A16MJC@A[ETX4LEY?179J
CP=/FTd4KF1C16QEBPAdMG<nNHZ;5Oooo`005?ooo`QiRX/4NHn@27V5QSEiRX/4OY2A12lT6@AnO6H4
RHMa17UgK`AiLV`3NGI^17UbJ`AiMVh4NGM_17UbJ`AiMfl3NGYb17AaI`A_KUl4M6QM17AVF@A/H5<4
JemB0g1OC@A`HE44IeY=16]FBPAaFTl4LUY>0faJC@A]H5<4J5E:17AeLciiRX/Eoooo000Doooo27V:
R`AiQ8D4NHZ;17V;S3EiRX/48QTC17QgKPBBTXX4NWQ^17UgJ`MiMfl4NGMY17UgJ`AiMfl4NGad17Ug
K`=iMVh4NDi?17Dl?`A`=CT4L38g174c>0AaBDH3JeE<16]EBPA/E4P4IeM616MJB`A/FTd3JeY816QA
@`AM@C@4IE]B:WV:R`AiQ8D4NHF637V:RaGoool001Coool8NHZ;17V4Q@AiRX/4NH^<=GV:R`@R6A<4
N7M^19:BRPAjN6h4NGM[1gUgK`AiMfT4NGM[17UgK`AiO7@4NGM_0gUfKPAiCTl4MC`o170e>@A`<SL4
LC<h1759AP=[ED`4JeE:16aDB0AWEdH4IeY;16aJC@=[FTP4J55315e1=0AUFe8ZNHZ;17V4Q@AiQHH<
NHZ;5Oooo`005?ooo`QiRX/4NHB517V:R`AiRh`eNHZ;128I4`AhMfh4TY::17YhKPAiMf/7NGM_17Ug
J@AiMf/4NGM_17UlM0AiMfl3NGI^17U>C`Ae?3l4L3Di170b=`Aa<cP4LDU60f]EC0A[EDX4K5A816MG
APAWFT/4K5Y=0f]JB0AXDD<4GD4d16EKDRYiRX/4NHB517V5QPaiRX/Eoooo000Doooo27V:R`AiQ8D4
NHZ;17V;S3EiRX/48QTC17QgKPBBTXX4NWQ^17UgJ`MiMfl4NGMY17UgJ`AiMfl4NGad17UgK`=iMVh4
NDi?17Dl?`A`=CT4L38g174c>0AaBDH3JeE<16]EBPA/E4P4IeM616MJB`A/FTd3JeY816QA@`AM@C@4
IE]B:WV:R`AiQ8D4NHF637V:RaGoool001Coool8NHZ;17V?T0AiRh`fNHZ;0fAXJ@Bl^[P4R8Eo17Uf
KPAiMfd4NGM[17UgK`=iLF<4NFeP17U]G@AiLVL4NG9[17UUH`=iFE`4NEYG1716?@AZ=R`4Jclj16]2
>@A[=cP3Jchm169:@`ARFTP4IeE916QGB`A/FTd3LEY@16eHB`AaGE04GSl`16UKDBIiRX/4NHn@17V;
S0aiRX/Eoooo000Doooo27V:R`AiSi04NH^<=WV:R`=TJ6T4_;Zh18R5O`AiMVh4NGM]17UgJ`AiMfl3
NG5S17U]H0AiKEd4NG9W17UbJ`AiIF<3NEUL17UJE`A`ASd4JSH/16/o>PA[@ST4JcLh0f/n?@ARBT<4
HUY816MEB@AXEd/4K5Y=0g5JD0A]F4/4LEe@15ho<0AYFe4VNHZ;17V?T0AiRh`<NHZ;5Oooo`005?oo
o`QiRX/4NHn@17V;S3IiRX/3I6QY1;bj^0B8QGl4NGI^17UgK@AiMf/4NGM_0gUaH`AiKF04NFeM17Ub
I`AiLV/4NFES0gUIG0AiFUL4L4Hm16Xf;0A[?cX4Jd8i16/g>0=[?Sd4HTY3169JB0AWEDT4J5M;16aJ
C@=aFU04KEQ;175MD0AN?c04JE]A9WV:R`AiSi04NH^<37V:RaGoool001Cooom6NHZ;0bLR7P@K9B<4
MG9P17UgI@AiMfT4NGM[17UgJ@=dL644Kf=G17A^H`AiN6`4NFaN17A>AP=Z=C04I4a215Hm;PAMJEL4
K7]X16/o=0AM:b<3JcD_16a0?0AXDD/4J5Q016=G@@AWFT/3K5Y=16aND0A/F4/4K5a?16aMD@AiP7`f
NHZ;5Oooo`005?ooodIiRX/39b8N11/U8`AeLV04NGMU17UgJ@AiMf/4NGMY0gA`H@A_HeL4M6iS17Uh
K0AiK5h4M4i60fXe<0ATC484ESd^15eYE`A/NfP4Jcld15d[8`=[=Bl4K40l16QAB`AXF404HeM116MJ
B`=/FTd4K5i@16aHB`A/G4l4K5eA17V0O3IiRX/Eoooo000DooooAWV:R`<W8Qh46bDS17EbH0AiMfD4
NGMY17UgJ`AiMfT3M71Q16mSE`AdKV<4NGQ/17U/GPAdCTH3JSD`16A<@PAF?Bh4GFUG16akJ0A[?c@4
GB/S0f/e;`A/@3`4J55;16QH@0ASEd44IeY;0faJC@A/GU04K5Q;16aLC`A/GE44NH1l=WV:RaGoool0
01Cooom6NHZ;0bLR7P@K9B<4MG9P17UgI@AiMfT4NGM[17UgJ@=dL644Kf=G17A^H`AiN6`4NFaN17A>
AP=Z=C04I4a215Hm;PAMJEL4K7]X16/o=0AM:b<3JcD_16a0?0AXDD/4J5Q016=G@@AWFT/3K5Y=16aN
D0A/F4/4K5a?16aMD@AiP7`fNHZ;5Oooo`005?oooa1iRX/4NHB50gV5QR]iRX/4D4e?0hUaH0AdKV44
NWQa17A/H`AdLfd4NG]c17U/HP=cH4l4IDi116Y<CPA^>CX4;`P612h]:P=`H5D4NfEM19Nf/PB4Ddd4
HSL_159B>PAAHE83?c/[14/Y8@AS>3<4He5016eBA@A]G503LVUE175QD0A/H5<4K5Y=15e2=@AYEDP4
NH1l<WV:RaGoool001Coool@NHZ;17V4Q@=iQHH[NHZ;151=C`>9LF04M6iQ17YhL@AdK6<4M7=]17Uk
L`AiK683Lf1?16E>@@AZC4h4KSTj12l81P@^;BX3L61E17]UG@BG][84Q5==168g;`ABDSX4DF5B0clk
:`A;:B44HcPc16=A@0A]DTD4KEa@0g9YE@AaHE04K61C16aJC@AM@SD4JEE817V0O39iRX/Eoooo000D
oooo47V:R`AiQ8D3NHF6:gV:R`A@CDl3RG5P17A^H@AjN744M6aS17AcK@AiNg<4NFaR0g=PC`AUCT44
JTa>16hi>P@_20H4;RdZ0g1PE@AkIEd4UkJb18ACC@AR=bl4DU8j155QDP<o>b/4BbTQ16<h<`ASDD04
KE9516eLD0=bJED4LF5@16aPD`A/FTd4GD8e16UEB0AiP7`bNHZ;5Oooo`005?oooa1iRX/4NHB50gV5
QR]iRX/4D4e?0hUaH0AdKV44NWQa17A/H`AdLfd4NG]c17U/HP=cH4l4IDi116Y<CPA^>CX4;`P612h]
:P=`H5D4NfEM19Nf/PB4Ddd4HSL_159B>PAAHE83?c/[14/Y8@AS>3<4He5016eBA@A]G503LVUE175Q
D0A/H5<4K5Y=15e2=@AYEDP4NH1l<WV:RaGoool001Coool8NHZ;17V4Q@AiQHH4NHn@0gV;S2]iRX/4
=Bl[0ci=B`AjNW84NGMZ17U]G`AeIeh4NGI^17UdJ0=bDd84ITHh12l;2@@a@D84/>[O19>l]`>5`L@4
P:jg17Z7R0AnZ984T;J]19ff^PAfP7l3CSde11dN4`@^8a`4H4Lo16QIBPAbGU<3LVAJ17I[F0AaGTd4
K5Y=16aLD0AMG6@4I6ej0gB0PRmiRX/Eoooo000Doooo27V:R`AiQ8D4NHF617V?T0=iRh`[NHZ;13D_
:`<nCD/4NWYb17UgJPAiKEl4MFMN17UfKPAiM6P3LU=216I6>0@_2`T4<D521;3Zg`BC_;L3QL74182^
]`AjQhP4OZRB192f[@BM][X4MX1o0dhm=@@M7Q<4;R<L1617?`AXFDX4LUiC0g9TFPAfJeP4LEi=16aJ
C@A/G504GEaT16A]NP=dP88_NHZ;5Oooo`005?ooo`QiRX/4NHB517V5QPAiSi03NH^<:gV:R`@e;b/3
?Te;17YjLPAiMfX4NFeO17EWGPAiMVh4NGAX0g9C@PAVASP4;`/91351@PB`j]l4Tkbg0hG1a0B0[[L4
NXN817jXTPB@]Zd4WKJj17J0O`=>?CD47AhC12hS70APAcl4J5U:179ND`=bI5X4MV]H175NC@A/FTd4
K5a@15eLI0ATKGX3M822;gV:RaGoool001Coool8NHZ;17V4Q@AiQHH4NHn@0gV;S2]iRX/4=Bl[0ci=
B`AjNW84NGMZ17U]G`AeIeh4NGI^17UdJ0=bDd84ITHh12l;2@@a@D84/>[O19>l]`>5`L@4P:jg17Z7
R0AnZ984T;J]19ff^PAfP7l3CSde11dN4`@^8a`4H4Lo16QIBPAbGU<3LVAJ17I[F0AaGTd4K5Y=16aL
D0AMG6@4I6ej0gB0PRmiRX/Eoooo000Doooo27V:R`AiSi04NH^<;WV:R`AYLh04=R<P0bD`=0AeLf<4
NGMY17j4M0AjNVh4NGM_16iLD@=OCCP4Cb`O14PF2`A;7a`4KSlf16m;@0=dGUH4NGAP17U[EPAcGE@4
JeQF16iIC0B?MfH3XHie1923L`@b:B04;1hL15Y1>@AWFd/3MVmO17E[H0A`IEP4K5Q;16aCB0AWF444
E5I;0e9EGPAYMH8[NHZ;5Oooo`005?ooo`QiRX/4NHn@17V;S2iiRX/4JG>013HS80<U<3@4MG=S17Ug
J@AnQ7@4NWY^17UgK`A^G543Gddh14l/7`A85P/4BalL16ho=PA_Bd03M5iF17UdH0AiJeH4LeeD16]H
EPA^FD`4SgMV0j6>M@B@Pg<4<RTP12`N70AJ@CT4Ie];0gI_G`AeJf04L6EH16aHB`A/DdP4IeQ115AF
B`=BEEh4JGF2:gV:RaGoool001Coool8NHZ;17V?T0AiRh`^NHZ;16UcP0@f8b039C0d17EcH`AiMfT4
OXAd17YjKPAiMfl4KUaA0em=>0A?;1l4B1H;14/O70A^?cH4Kd]00gANEPAiM604NF]F17=ME0A[F5H4
KUU<18mgIP>QSWD4T8=c138Y80@/7Q`4FT4i16MKB`=fKel4MF]P171UF0A/F4/4K5=816MH@@ADET/3
DUEN16UePR]iRX/Eoooo000Doooo27V:R`AiSi04NH^<;WV:R`AYLh04=R<P0bD`=0AeLf<4NGMY17j4
M0AjNVh4NGM_16iLD@=OCCP4Cb`O14PF2`A;7a`4KSlf16m;@0=dGUH4NGAP17U[EPAcGE@4JeQF16iI
C0B?MfH3XHie1923L`@b:B04;1hL15Y1>@AWFd/3MVmO17E[H0A`IEP4K5Q;16aCB0AWF444E5I;0e9E
GPAYMH8[NHZ;5Oooo`005?ooocYiRX/4>CD^10X50`AMBd83MFaS17YhJPAiK5l4NFAH17U^GPAiMfD4
N6YI0hEaI`BDZY@4a^2m19>HS@AkIfD4L5eF0fI5?@AZ>S`4I3Hi16@f<PAQ71P4H2@R15Pg<`=XC3h4
L4A017YGCP@]3`L4<R<T16QCBP=aIeP4M6YF171LC0AWGDl4If5C175JC0B8QX03Mg^016M`NR]iRX/E
oooo000Doooo>WV:R`@i=Bh42PD315e;@P=eK6<4NWQZ17U/G`AiI5P4NFiN17UgI@AhJUT3QG5W19BZ
U0C6h;d4TiR=17]WI@A`GEH3ITDm16Xj?0AT=ST4I3Hb164L60AP9284F3Lc0fQ<?PA`A404NUM>12d?
1`@b8b@4J5=:0g5WF0AdJUH4L5a<16MMC`AWHE<4LEY<18R6P0=gNh04Ig1j:gV:RaGoool001Cooolj
NHZ;13Te;P@:1@<4GD]20gE/H`AjN6X4NFaO17UTF0AiKUh4NGMU17QZF@>5LFL4U:ZD1<KP_@BCV8d4
NfMU171MEP=VACd4JSXl16@f>@AT=S84HA`H160T8PAH=c<3J4`n1714@0AjEdh4;@l7138S90AXDdX3
LFMH17AZEPA`G4`4Iee?16MQD`AaFT`4R8J00gMkP0AWL7X[NHZ;5Oooo`005?oooaAiRX/3NHB517V5
QQ]iRX/4JFed11LB3P@B3`d4>U5A0h1oL`AiLF@4NFUX17A^J@AdM6P4NFET17QUG@=QAcH4IUM@17Ym
N`AiRG/4OXb018BHS0>5Uh/4P:2718B9L@B2S7D4O91`17b3J0AbETT3MdU617Hj<`A]:al4IR8H13XE
40A6;Bh3JeU@17AVEPA`H4l4JeA816QCB0A/F4`49QD>0cTj;@AhP7l4M8229gV:RaGoool001CooolD
NHZ;0gV4Q@AiQHHKNHZ;16U]M0@G4Ph44Pl=13YAD@>0Og<4NG5T17UYJ0AdKVT4M7AX17UUI0AhIEd3
HDLf16IGD0AjOG/4NHUk17j<P0B4V8`3QIN;182PQ`B4RG44PXae17b@L0AlPfP4LUI90gM9APAf>S<4
KB/O16HR60@j5A04ARd^0f]ID0AdIUH4L61?16]DB0AXDdP4K5Q<12HE3P<i>Rd4N81o17B0PRMiRX/E
oooo000Doooo57V:R`=iQ8D4NHF66gV:R`AYKG@45a8>118?3@@jDE43P7mc17UaI0AiJFP4M6iY17Ad
J0AiIF@4N6EM0f57=PAVEe04NWek17V9N`AnS804Q9R<0hFGR`B0X8L4Q8Ua18:<M@AlT704O8=X179F
B@=gBDH4MSXc16d[7`AV8QP4>QD@14H];P=[FE04M6IF171PC`A[E4P4J5=816aHC0@V5@h3>CX]17R0
O`AdP88WNHZ;5Oooo`005?oooaAiRX/3NHB517V5QQ]iRX/4JFed11LB3P@B3`d4>U5A0h1oL`AiLF@4
NFUX17A^J@AdM6P4NFET17QUG@=QAcH4IUM@17YmN`AiRG/4OXb018BHS0>5Uh/4P:2718B9L@B2S7D4
O91`17b3J0AbETT3MdU617Hj<`A]:al4IR8H13XE40A6;Bh3JeU@17AVEPA`H4l4JeA816QCB0A/F4`4
9QD>0cTj;@AhP7l4M8229gV:RaGoool001CooolDNHZ;0gV?T0AiRh`KNHZ;17N9TPC/f/@4olfU18Mi
I@=dLVD4NGEX17V1JPAnK6P4NVYW17V4K@AhMV@3NFAG16UGB`AdJUl8NG]c17UbJ`=iNg<4NFU[17UU
H0AeJ5`4M6IL175RE@A[HDd3GF9<16I_E0AfMf04Rh=Z18AcJ@AUE443HeI5171SD`A`H4l4Jei;16QK
B`A/G504E4U10bhe=0AYMW<4NXb=9gV:RaGoool001CooolDNHZ;0gV?T0AiRh`KNHZ;17N9TPC/f/@4
olfU18MiI@=dLVD4NGEX17V1JPAnK6P4NVYW17V4K@AhMV@3NFAG16UGB`AdJUl8NG]c17UbJ`=iNg<4
NFU[17UUH0AeJ5`4M6IL175RE@A[HDd3GF9<16I_E0AfMf04Rh=Z18AcJ@AUE443HeI5171SD`A`H4l4
Jei;16QKB`A/G504E4U10bhe=0AYMW<4NXb=9gV:RaGoool001CooolDNHZ;0gV?T0AiRh`KNHZ;17N9
TPC/f/@4olfU18MiI@=dLVD4NGEX17V1JPAnK6P4NVYW17V4K@AhMV@3NFAG16UGB`AdJUl8NG]c17Ub
J`=iNg<4NFU[17UUH0AeJ5`4M6IL175RE@A[HDd3GF9<16I_E0AfMf04Rh=Z18AcJ@AUE443HeI5171S
D`A`H4l4Jei;16QKB`A/G504E4U10bhe=0AYMW<4NXb=9gV:RaGoool001CooolDNHZ;0gV?T0AiRh`K
NHZ;17N9TPC/f/@4olfU18MiI@=dLVD4NGEX17V1JPAnK6P4NVYW17V4K@AhMV@3NFAG16UGB`AdJUl8
NG]c17UbJ`=iNg<4NFU[17UUH0AeJ5`4M6IL175RE@A[HDd3GF9<16I_E0AfMf04Rh=Z18AcJ@AUE443
HeI5171SD`A`H4l4Jei;16QKB`A/G504E4U10bhe=0AYMW<4NXb=9gV:RaGoool001CooolfNHZ;18V5
J`AlMf/4OXZ517YmL@=`KV84M7MZ17UhL@AiQ7P4NH1k17UkN0AnO703Ng5P16M;@@AUEDT4M7=X17V0
M`AiNg<3NGQ`17V8L`AiM6@4L5Q;171KB`AVG4L4G5A80eY??PANACT4GTTi15i8>@ASD3T4JEmC0feS
E`AaGU@4JeI:16MAB0ASEdH4HUM8130R70<^?4X4Lh6>:gV:RaGoool001CooolfNHZ;18V5J`AlMf/4
OXZ517YmL@=`KV84M7MZ17UhL@AiQ7P4NH1k17UkN0AnO703Ng5P16M;@@AUEDT4M7=X17V0M`AiNg<3
NGQ`17V8L`AiM6@4L5Q;171KB`AVG4L4G5A80eY??PANACT4GTTi15i8>@ASD3T4JEmC0feSE`AaGU@4
JeI:16MAB0ASEdH4HUM8130R70<^?4X4Lh6>:gV:RaGoool001CooolfNHZ;18V5J`AlMf/4OXZ517Ym
L@=`KV84M7MZ17UhL@AiQ7P4NH1k17UkN0AnO703Ng5P16M;@@AUEDT4M7=X17V0M`AiNg<3NGQ`17V8
L`AiM6@4L5Q;171KB`AVG4L4G5A80eY??PANACT4GTTi15i8>@ASD3T4JEmC0feSE`AaGU@4JeI:16MA
B0ASEdH4HUM8130R70<^?4X4Lh6>:gV:RaGoool001CooolfNHZ;18V5J`AlMf/4OXZ517YmL@=`KV84
M7MZ17UhL@AiQ7P4NH1k17UkN0AnO703Ng5P16M;@@AUEDT4M7=X17V0M`AiNg<3NGQ`17V8L`AiM6@4
L5Q;171KB`AVG4L4G5A80eY??PANACT4GTTi15i8>@ASD3T4JEmC0feSE`AaGU@4JeI:16MAB0ASEdH4
HUM8130R70<^?4X4Lh6>:gV:RaGoool001CooolbNHZ;17AnP0AdO7H4M6aK16YE@PAOGUh3JVi/17Yc
K@AiO7D4NH5h17UlM0AiP7L4OW5a0gm_J0AkIeP4LUQ?17EVG@AiMfl4NFQV0gAPF@AdLF@4LfaM171T
EPAVAcd4ITi716]=@0=TCCh4I5A416UG@@AXEcl4I4`j16YCAP=bG4l4JeU<16YGBPAXEDT4J5M>16eP
D`@P5AH33a`I161YIB]iRX/Eoooo000Doooo<WV:R`AdOX04M7af17A/F`AZED84GeiN0fY^K0AjLfd4
NGae17V1N0AiO7@4NH1g17iaL@=oKfP4NfMH179HC`AeIUd4NGM_17UXIP=dH5T4M75T17=/G@A`I5H4
ITLm16I>A`A[CD03I4dn16ADA0AYEd44J5Lo16A<>PAZDdH3LUa?16]IC0AZEdX4J5E916QGCPA]H5<4
81DF0`lL6@APJFD[NHZ;5Oooo`005?oooc9iRX/4M7j017AlMPAdK5/4JUE215mNGP=ZKV`4NW=]17Ul
M@AiPGP4NGad17V0M`AnLG43OfmX17]WF0AbF4l4MFIM17UgK`AiJ6H3M61I17AaI0AcK5d4L6AF16I7
?@AVCTL4Jde00fA=?PATE4@4JEM116QG?`ATC3X4JU=60g9LC`A[FD`4JUM:16QEB@AXEdh4KF1C120E
5P<?71T4H6UU:gV:RaGoool001CooolbNHZ;17AnP0AdO7H4M6aK16YE@PAOGUh3JVi/17YcK@AiO7D4
NH5h17UlM0AiP7L4OW5a0gm_J0AkIeP4LUQ?17EVG@AiMfl4NFQV0gAPF@AdLF@4LfaM171TEPAVAcd4
ITi716]=@0=TCCh4I5A416UG@@AXEcl4I4`j16YCAP=bG4l4JeU<16YGBPAXEDT4J5M>16ePD`@P5AH3
3a`I161YIB]iRX/Eoooo000Doooo<WV:R`AnNf/4NWE[17=XG@AZG5<4NfQC0gQWH`AiJVT4NGQ`37Uk
L`AiR7<3OW]Y17UbG0A/EdP4L5mG17UhL0AiR7X3OWii17YhM@AnMG04MF]P17E[FPAbGDl4Je=40fA9
?`ATCT84I5=<179HC`AmJEd4M6QK0f]MC`A[FTd4LEi@16aIB`AXEdH4HeM8138M5P<:30d47b<W17V5
QRMiRX/Eoooo000Doooo<WV:R`AnNf/4NWE[17=XG@AZG5<4NfQC0gQWH`AiJVT4NGQ`37UkL`AiR7<3
OW]Y17UbG0A/EdP4L5mG17UhL0AiR7X3OWii17YhM@AnMG04MF]P17E[FPAbGDl4Je=40fA9?`ATCT84
I5=<179HC`AmJEd4M6QK0f]MC`A[FTd4LEi@16aIB`AXEdH4HeM8138M5P<:30d47b<W17V5QRMiRX/E
oooo000Doooo<WV:R`AnNf/4NWE[17=XG@AZG5<4NfQC0gQWH`AiJVT4NGQ`37UkL`AiR7<3OW]Y17Ub
G0A/EdP4L5mG17UhL0AiR7X3OWii17YhM@AnMG04MF]P17E[FPAbGDl4Je=40fA9?`ATCT84I5=<179H
C`AmJEd4M6QK0f]MC`A[FTd4LEi@16aIB`AXEdH4HeM8138M5P<:30d47b<W17V5QRMiRX/Eoooo000D
oooo<WV:R`AnNf/4NWE[17=XG@AZG5<4NfQC0gQWH`AiJVT4NGQ`37UkL`AiR7<3OW]Y17UbG0A/EdP4
L5mG17UhL0AiR7X3OWii17YhM@AnMG04MF]P17E[FPAbGDl4Je=40fA9?`ATCT84I5=<179HC`AmJEd4
M6QK0f]MC`A[FTd4LEi@16aIB`AXEdH4HeM8138M5P<:30d47b<W17V5QRMiRX/Eoooo000Doooo<WV:
R`AiQGh4M75P16=?>`A/I5H4O6YX0gYhJPAiNV`4NGQ`17V2OPAiP7/4NG]c17UjMP=iOgD4N75T175[
F0A/IU@4M6iS17UfJ0=iO704NG]c17UhJ0A^Ge44JeU<16MJC@A[GU03KEe416Q??@ATD4@4KV5I17M/
HPAeJ5/3L6]M16aWF0QWGU04J5]A16eUF@B_O543I3@S10h71P@I7R8WNHZ;5Oooo`005?oooc9iRX/4
NHEn17AaH0ASCc/4K6AF17aZJ0=jN6X4NGY/17UhL0AiPWh4NH1k17UkL`AiNWH3NGme17QaI0AaJeP4
K6ID17A^H`AiMVP3NGa`17UkL`AiN6P4KUmA16]IC0AWFTd4Jei@0feMA0AXCcd4I51416iQF@AgK684
MFQK0g1[G@A/IeP8Iei@16QKD@A]IET4[gaA0f@d8`@>1`H46AhR9gV:RaGoool001CooolbNHZ;17V5
OPAdLF04Hdlk16aTEPAlJVP3NWQZ17UjK0AiN704NH9n17V0N`AiNg<4NGYf0gUoM@AhLF@4LF]H16aV
E0AdKV<4NGIX0gUlL0AiNg<4NGQX16iOD@A[FD`4IeY=16]ND0=]GD@4J4lm16A@A0A^HET4MfaR17EX
F`=`Jed4K6MH26MND0AXFe44KFEI1:mlD@=T=2<43PL611TN8RMiRX/Eoooo000Doooo;WV:R`AiLfT4
KU9815l[9`AYAd<4Fe]G16EmJP=iNVX4NGM[17UhL0AiMV`4NGYb17UkL`AiNW83M75W17UhJ@AkOW84
Ng]^17YhIPAdIEh3M6EK17UUG`AcG544KeQ816MAAPARC404He4k0eQ5>@AIB3d4JE]?16eVEPAaIUT4
M6II0g1ND@A/FD`4LEY=16aJB0A]E4H4KEY?17ASF@>HMf<4dmK;18fSXbMiRX/Eoooo000Doooo;WV:
R`AiLfT4KU9815l[9`AYAd<4Fe]G16EmJP=iNVX4NGM[17UhL0AiMV`4NGYb17UkL`AiNW83M75W17Uh
J@AkOW84Ng]^17YhIPAdIEh3M6EK17UUG`AcG544KeQ816MAAPARC404He4k0eQ5>@AIB3d4JE]?16eV
EPAaIUT4M6II0g1ND@A/FD`4LEY=16aJB0A]E4H4KEY?17ASF@>HMf<4dmK;18fSXbMiRX/Eoooo000D
oooo;WV:R`AiLfT4KU9815l[9`AYAd<4Fe]G16EmJP=iNVX4NGM[17UhL0AiMV`4NGYb17UkL`AiNW83
M75W17UhJ@AkOW84Ng]^17YhIPAdIEh3M6EK17UUG`AcG544KeQ816MAAPARC404He4k0eQ5>@AIB3d4
JE]?16eVEPAaIUT4M6II0g1ND@A/FD`4LEY=16aJB0A]E4H4KEY?17ASF@>HMf<4dmK;18fSXbMiRX/E
oooo000Doooo;WV:R`AiLfT4KU9815l[9`AYAd<4Fe]G16EmJP=iNVX4NGM[17UhL0AiMV`4NGYb17Uk
L`AiNW83M75W17UhJ@AkOW84Ng]^17YhIPAdIEh3M6EK17UUG`AcG544KeQ816MAAPARC404He4k0eQ5
>@AIB3d4JE]?16eVEPAaIUT4M6II0g1ND@A/FD`4LEY=16aJB0A]E4H4KEY?17ASF@>HMf<4dmK;18fS
XbMiRX/Eoooo000Doooo;WV:R`AiLW@4N5AA16m9@@AXDDP4N6MH17QdK@=iO7X4NG]c17UhL0QiNg<4
NGI^17UfJ0=iMFL4NW5S17Y_HPAeLfd4NGaj17j9O`=jNWH4NGQV17Q[GPA[GDl4HU1315i;?PAFASl3
J5=6171WF0AdJ5X4LVYM175YG@AdIUT3L69D16aMC`A/E4d4LE5@16QDB`AWFeD4IU900f=?@@A]HU/4
OXn@9gV:RaGoool001Coool^NHZ;17UbM0AhE544KdU116QAB0AhIeP4N7A]0gUlNPAiNg<4NGQ`27Uk
L`AiMVh4NGIX0gUeI`AjLF<4NVmR17EcK@AiO7X4OXUo0gYjMPAiN6H4N6]N16]MC`ARD4<4GT/n15I6
?`=XDdH4L6MH17AXFPAbJUd4LFUM17AVF@=`HU@4K5e?16aDC@AaDE04J5A;16MKE@AVDT03Hdm116eR
F`AnSi0WNHZ;5Oooo`005?ooobiiRX/4NG9d17QDD@A_BD44J55817QWF0AhM6d3NGaj17UkL`AiN708
NG]c17UfKPAiMVP3NGEW17YaH`AjKf84MG=]17UlNPAnRGl3NWYf17UhIPAhJeh4Jee?169@@`ANBch4
ETHo0fQCAPA`IeP4M6QJ179ZG@AaJEd4M6II0g1RE0A/GDl4K5A=175AD0AXE4/4Ie]E16IB@0=SCd44
KF9K17j?T2MiRX/Eoooo000Doooo;WV:R`AiLW@4N5AA16m9@@AXDDP4N6MH17QdK@=iO7X4NG]c17Uh
L0QiNg<4NGI^17UfJ0=iMFL4NW5S17Y_HPAeLfd4NGaj17j9O`=jNWH4NGQV17Q[GPA[GDl4HU1315i;
?PAFASl3J5=6171WF0AdJ5X4LVYM175YG@AdIUT3L69D16aMC`A/E4d4LE5@16QDB`AWFeD4IU900f=?
@@A]HU/4OXn@9gV:RaGoool001Coool[NHZ;0gUhK`AiOVT4N71K16YJ@@AXFDX4LV]P17YhK0=iN704
NH1g17UgK`AiLFX4M6aO17AaH0AiIF<3NF=O171VFPAdIEX4MFmU17UbI@AiMVX3NGM_17U]KPAhFe<4
KeI:16MCAPAXE4H4I5Y=0fEPC@AYGTh4K65D17IUF@AaHeH4L5eA0g1ND@A/EdX4K5A616MEAPAWFdP4
J5mB17ESF@=]GE04DDE0169ZKBMiRX/Eoooo000Doooo:gV:R`=iN6l4NGiY17Q`F`AZFT44J5U:179[
H0AjN6`3NGQ`17V0M`AiMfl4NG5Z17A/G`AdLF04NFES0gUSG`A`IUX4M6EJ17E_I@AiLVD4NGIZ0gUg
K`AiKFh4N5]C16mFBPAWDdH4J5A616AJC@=UH4d4JEi>16aQE0AfIET4LF=F171MD@=`GU44K5M:16aD
APAWEDH4Ie]816QODPAeHeT3KEe@1555@0ARJVdWNHZ;5Oooo`005?ooob]iRX/3NGQ_17UnJ@AhL5/4
JUY116QIBPAbJf04NWQ/0gUhL0AiP7L4NGM_17UaJPAdK5l4M75P17UUH`=iHel4L6IJ17AUFPAeKfD4
NG9U17UfJP=iMfl4NFe^17QKD`A_ETX4Ie=616QDAPATFTd3IF1=16UNCPA/HE@4MVEI175SEPA`GE43
L5iA16aGBPA/E4H4IeE616MKB0AXGe84MF=I0feMD0AAAD04HVY]9gV:RaGoool001Coool[NHZ;0gUh
K`AiOVT4N71K16YJ@@AXFDX4LV]P17YhK0=iN704NH1g17UgK`AiLFX4M6aO17AaH0AiIF<3NF=O171V
FPAdIEX4MFmU17UbI@AiMVX3NGM_17U]KPAhFe<4KeI:16MCAPAXE4H4I5Y=0fEPC@AYGTh4K65D17IU
F@AaHeH4L5eA0g1ND@A/EdX4K5A616MEAPAWFdP4J5mB17ESF@=]GE04DDE0169ZKBMiRX/Eoooo000D
oooo:gV:R`=^J5P4ES``13L/8`@j=Bh4FeI>179^H`AiMf/3NG9[17UaJPAiMVP4NG5O17UaH`A`He`4
JVEF0fmTG0AeLfT4MGQZ17EdI0AiMfl4NGM`0gUgK`AdOV/4LfmN16mKC@AWDdH4I55416eCA`=ZEdh4
KUaF179QE`A/H5<4L6QL175[G@=`HeD4K6MH16MRD`AWFD/4J59>16QJE@AR@2l3Idm316a4<PAXCT@W
NHZ;5Oooo`005?ooob]iRX/3KVQH15Hl<0@g;2<4>SD^15]FCPAbKV<4NGM[0gUbJ`AiLFX4NGIX17Ua
G`AiLF<4L6=L16YUEP=_I5`4MG=Y17EhJPAeM6@4NGM_17UgL0=iMfl4M7i[17=_GPA_Fdd4Ie=616AA
A0A]DdL3JUM>16iLEPAbHEL4K61C171XG0AaJed3L6=E16aWF0AWHU<4IeU;16QBCPAXFUD4HT0_0fM?
@`A/A384J4i49gV:RaGoool001Coool[NHZ;0fiXF0AF?304=b`S13Xe;PAKETh4LViS17UgJ`=iLV/4
NG5Z17UfJ0AiLEl4NG5S171SG0AZIEH3KfAL17EcJ@AeN6X4MGAT17UgK`AiMg03NGM_17AnJ`AcKeh4
Ke]=16MCAPATDD@4KE=70fYGCPA^G5H4LV5G16aPD`A`J5`4LF]M0g1SE@A/IeP4If9C16MIB`AXDTh4
J5YE1690;`=WCd<4K4@b16Q>A2MiRX/Eoooo000Doooo:gV:R`=^J5P4ES``13L/8`@j=Bh4FeI>179^
H`AiMf/3NG9[17UaJPAiMVP4NG5O17UaH`A`He`4JVEF0fmTG0AeLfT4MGQZ17EdI0AiMfl4NGM`0gUg
K`AdOV/4LfmN16mKC@AWDdH4I55416eCA`=ZEdh4KUaF179QE`A/H5<4L6QL175[G@=`HeD4K6MH16MR
D`AWFD/4J59>16QJE@AR@2l3Idm316a4<PAXCT@WNHZ;5Oooo`005?ooob]iRX/3LV5B138N4P@]8al4
9AhN134h>`AaK6L4NGM`0gUgJ@AiMfD4NGM_17UkN0AnO7T4OhEl17mdKP=aGEH4IDm716YLDPA`JUh4
M79X17UgK`=iMfT4NFUQ16iMD`AUC4X4Hde015m;?0APD4@3KEe@16QJB`AVF4`4Je]D16]BB@AVET/3
IUU<169FBPAWFTd4J5Q;16QEB`ASDDD4HEY00eM4<@ARBd44J5ID9gV:RaGoool001Coool[NHZ;0g9Q
DP@b7Q84;B<O12DN7P@a>3/4LFaW17UgL0=iMfT4NGMU17UgK`AiNgP4OWai17n5O0AoM6h3LEeF16E?
A`AZG584L6YN17AbJ0AiMfl3NGMY17UYH@A^GE<4IDa:16==@0AOBc`4H5140feMD0AXFT/4IUQ<16]K
E0A[DTT4IUI;0fIIC0ARETX4IeY=16QHB`AXED/4He55165J@0=GA344HT]116QFE2MiRX/Eoooo000D
oooo:gV:R`=bHE84<QhB12dS7`@U7Qh4<CPk175/I`AiMg03NGMY17UgI@AiMfl4NG]h17ilN@AoQG`4
OgA^0g5MEPAUCdL4JUaB171ZGPAdLVP4NGM_0gUgJ@AiJF44KUeC16E<BPASCD04Gd/l161@A0=]GE04
J5Y;16IHC0A[Fe@4Je9916IFB`=VFD`4HUI:16MJC@AXF4/4J5E;16=AA@AQFT03Ed@a169;@@AXEU@W
NHZ;5Oooo`005?ooobMiRX/4NGij0gilM`B:FdP4@B/P13<U8@@i?Sh4LFaM17AaG`=dLV/4NGM^16UP
D0AJDD<4CChb144b:@A5>c@3CSln165<A`ARC484IEA;171ZH@AiMfl3NGMc17UbJ@AdHUH4JUU016A<
>@ASDD84G4i20eE;@@A@D4D4FE=8169QD@AVH544Iea@0g5SE@A/GU04J5Y=16QHB`AXED/4J5M=154g
;0<j7AL4BC<U16=AABMiRX/Eoooo000Doooo9gV:R`AiOWX3OWag18YKB0A1:b04<bDQ13Tn?PAaK5d4
M75O0gAbJ`AiMfh4JF1@15YA@`A=?S84@C8Y14Dk=0=>?ch4HDa7169<@PAUE4/4L6YQ17UgK`=iMg<4
NG9Y17AREPAZFD04I4`i16=A@PALCT83ED]1151@A@AIDdP4HV5A16IPD@AWG503LF=E16aND0AXFTd4
J5Q;16QEB`AXEdd4DCL/0cXM5`A9<bD4He559gV:RaGoool001CooolWNHZ;17UnNP=nO7L4RU]8144[
80@c9B44>Chn175/G@AdLEl3M79[17UgKPAYH504FU5314dn<PA1<RT4AC/d0dho?PAQC4L4HTa216ED
B`A`JV44NGM_0gUgL`AiLVT4M69F16YI@0ATC3T4He5215a>@P=EBd44D51515UCB0ARHE44IV1A16ML
D0=aHeD4K5i@16QJC@AXF4/4J5E;16QGC@AA=b`3>QdG14Tc9@ASDDDWNHZ;5Oooo`005?ooobMiRX/4
NGij0gilM`B:FdP4@B/P13<U8@@i?Sh4LFaM17AaG`=dLV/4NGM^16UPD0AJDD<4CChb144b:@A5>c@3
CSln165<A`ARC484IEA;171ZH@AiMfl3NGMc17UbJ@AdHUH4JUU016A<>@ASDD84G4i20eE;@@A@D4D4
FE=8169QD@AVH544Iea@0g5SE@A/GU04J5Y=16QHB`AXED/4J5M=154g;0<j7AL4BC<U16=AABMiRX/E
oooo000Doooo9gV:R`AdL6@3LfAG11h:1`@>30`45aLE12Pi>`AaK604NG5T0gYcH`AiMfT4Pga/16IJ
C0A>ASX4:bd/11<I6P<C6Q84:BLQ13/R6P@c5144Ac0[17A^H`=iMfl4NGQX17AVEPAZET@4GeU115U9
>0APEDT3MfIG17eXF@AcGe44J4i815e?A`AOF4d3K5mB16]MC`ANE4P4EEA815mKB`AXFdd4IDLf0eLd
9PAF<b/4I4M39gV:RaGoool001CooolWNHZ;17A`I0=cI5L47PX710h<30@G5aD4:3Tk175/H0AiLF@3
NW=S17UgJ@B3O6`4IUY<14i6>P@[;B`44aTJ0a<J4P@Y9b44>b8J13<D4@A7<2/4M6iS0gUgK`AiN6P4
M6IF16YFA0AOFD44FDTh161EB@=gIUL4OFQI17=OD@AXCTP4GDm715mHC@=/Ge84Jee?15iDB0AEE4P4
Ge];16QKC@AUAcH3Ec@V15Hc:`ATAd<WNHZ;5Oooo`005?ooobMiRX/4M71T0g=TE`@N2PL43P`<11LG
5@@X>C/4LFaP17UaI0=jLf<4NGMY18=lK0AVFT`4CTHj12/];0@C6AX34aXB12TW8@@k8QX4<a@A14L`
:`AdKV<3NGM_17UhJ0AdIUH4JUI415mI@@AIBCP4H5E90gMVE`AmJ5T4LemA16Q>B0AMCdL4GeQ=0faO
DPA[GDl4GUA815EDB0AOFd/4J5]=16E7=P=G=2H4ES<[16A7@bMiRX/Eoooo000Doooo9gV:R`AdL6@3
LfAG11h:1`@>30`45aLE12Pi>`AaK604NG5T0gYcH`AiMfT4Pga/16IJC0A>ASX4:bd/11<I6P<C6Q84
:BLQ13/R6P@c5144Ac0[17A^H`=iMfl4NGQX17AVEPAZET@4GeU115U9>0APEDT3MfIG17eXF@AcGe44
J4i815e?A`AOF4d3K5mB16]MC`ANE4P4EEA815mKB`AXFdd4IDLf0eLd9PAF<b/4I4M39gV:RaGoool0
01CooolSNHZ;17j@T@B3Q7/3Le];15`j<P@S5a<49AHC12`f>@AjNF/4MGIX0gAcI`AiMfX4OWmg18If
I`BIP7D4HTTk12PI5@<O5a847BDV13m0=@AgK5/4LfmR17EjK`=iR8@4NH9h17AXF@AOBcl4E3hc13<@
2@@a8203DCh/14Li;0@c;2<4?cdb15iBA@ALE4@3HUI716MJC@AVDdD4Ge96165BB`ANC484BSD/0dLi
;PAJCDD4KUiK17j?T2=iRX/Eoooo000Doooo8gV:R`AnT944PhAk0g=KB`AL>S848aLC12DF4`@/=ST4
NWU[17EfJ0=dLfL4NGMZ17ioM`B6MVL4VH1e1699>`@X6AD37aLB11dU9P@o@3D4MfaK17=_HPAeNVl3
NHR417V2N0AdJ5T4Gd/o15@n<`@c40T4<B0P0e4n;0A7>B`4<b`S13lm<PANDTD4G5A40f9FA`AWFTd4
IU=515mBAPAQDT/4GTa214Xe;0=7>Bh4FTe516iNF`AnSi0SNHZ;5Oooo`005?ooob=iRX/4OY2A18>4
N`=cFd/4G3Xb12<G4`@U5Q<4;3Hi17YiJ`AeMVP3M7=W17UgJPAnOgL4QWIW19V0M@ARBC/4:1TE0alG
4P@M9BH4?d0e17M/F`AcKf84MGY_0gV8Q0AiPWP4M6QI15m;?`AD?S<4<a09134P80=A?R`4AcT/13</
8`@o?C84GU9515aDA0=RETL4IeY=16ICA@AODTH4HE9;15i<@PA:=B`3AcT^15Y=A@A^GU/4OXn@8gV:
RaGoool001CooolSNHZ;17j@T@B3Q7/3Le];15`j<P@S5a<49AHC12`f>@AjNF/4MGIX0gAcI`AiMfX4
OWmg18IfI`BIP7D4HTTk12PI5@<O5a847BDV13m0=@AgK5/4LfmR17EjK`=iR8@4NH9h17AXF@AOBcl4
E3hc13<@2@@a8203DCh/14Li;0@c;2<4?cdb15iBA@ALE4@3HUI716MJC@AVDdD4Ge96165BB`ANC484
BSD/0dLi;PAJCDD4KUiK17j?T2=iRX/Eoooo000Doooo17UoP@AiQHH4NHB517V5QQ=iRX/46PT710T<
4`=dIUP4IT@e12HM8`@G4a4472lc171^HPAiMfX3MG9U16m]H@AdLVP4PhMi179/FPBLNV<4_95c0imb
D0B5F3/4MfQ?179UE0AbHEH4MG1V0gUfK0AiLVH4M6AE17AF@@ASBS`4Ke0k14M3@@<Y<3D40P8510lE
5`@U9bD45AHB11LN8@<a;284B3PZ169A@`AOETT4HEE615I8>`@g:b03:2<O1498?`A]IE`4OHj?8gV:
RaGoool001Coool4NGn117V5QPAiQ8D4NHF64gV:R`@J2@L42@`C0gAVF0AVA3D49QdS11LC4@@L;c<4
L6iR17UgJP=eLVD4KfeQ17AbJ0B3QgT4LVaJ19ajH`BlTG<3Wg9@18EH>`AgJ4l4LVED179QEPAeL6H3
NGI/17UbIPAdI5D4M5I116=:?0A_D3/4Ad=10bT`=@@20PD43aDG12DW9@@E5Q845ahQ0c4/8PA8>2X4
HU5315mFB@AQEDH4ETPk13L[80<X8al4@TPo16eUG0AmSXlSNHZ;5Oooo`005?ooo`AiOh44NHF617V4
Q@AiQHHCNHZ;11X91`@931<3M6IH16I4=@@V7B<45a<A11`_<`A`KV84NGMZ0gEbI@A_KF44M79X18>7
N@AbK5X4W7YS1;bAL`>OLU04QEPk17MXC`AbIE@4LV5F17E`IP=iMV`4NG9V17ATE@AdET44HdXl16m@
>`A7@d43:C0e10821@@?5AL49BLU11DF4P@G7R43<B`R14Ph:PARDD<4GeI9165EAPAFB3/4=b/P0bPS
7`A2B3l4KFEL17f>Sb=iRX/Eoooo000Doooo17UoP@AiQHH4NHB517V5QQ=iRX/46PT710T<4`=dIUP4
IT@e12HM8`@G4a4472lc171^HPAiMfX3MG9U16m]H@AdLVP4PhMi179/FPBLNV<4_95c0imbD0B5F3/4
MfQ?179UE0AbHEH4MG1V0gUfK0AiLVH4M6AE17AF@@ASBS`4Ke0k14M3@@<Y<3D40P8510lE5`@U9bD4
5AHB11LN8@<a;284B3PZ169A@`AOETT4HEE615I8>`@g:b03:2<O1498?`A]IE`4OHj?8gV:RaGoool0
01Coool4NHF617V6Q`AiSi04NH^<3gV:R`@P4Q047A@B108000<010T44`lE11@A3P@R5a@4:C@g17Eb
I@AeLfd3KE=?1616@@AZHET4OX5m18B>R0B:PGX4NfAH0h1^H@B3Kf44NfUI17Q_G`AfK5l4MG5W0gUk
L`AiL6/4M6eQ16YOB`AWGD84Lei318ASC0>BI4`49ALG11XF4P@Y81l4:B8P13@^9@=JAS/4I5a<16aE
A@ATDTH4HE]913XY90@X7aT3:QhG138S7PAM?ST4N8V:8gV:RaGoool001Coool4NHF617V6Q`AiSi04
NH^<3gV:R`@P4Q047A@B108000<010T44`lE11@A3P@R5a@4:C@g17EbI@AeLfd3KE=?1616@@AZHET4
OX5m18B>R0B:PGX4NfAH0h1^H@B3Kf44NfUI17Q_G`AfK5l4MG5W0gUkL`AiL6/4M6eQ16YOB`AWGD84
Lei318ASC0>BI4`49ALG11XF4P@Y81l4:B8P13@^9@=JAS/4I5a<16aEA@ATDTH4HE]913XY90@X7aT3
:QhG138S7PAM?ST4N8V:8gV:RaGoool001Coool4NHF617V6Q`AiSi04NH^<3gV:R`@P4Q047A@B1080
00<010T44`lE11@A3P@R5a@4:C@g17EbI@AeLfd3KE=?1616@@AZHET4OX5m18B>R0B:PGX4NfAH0h1^
H@B3Kf44NfUI17Q_G`AfK5l4MG5W0gUkL`AiL6/4M6eQ16YOB`AWGD84Lei318ASC0>BI4`49ALG11XF
4P@Y81l4:B8P13@^9@=JAS/4I5a<16aEA@ATDTH4HE]913XY90@X7aT3:QhG138S7PAM?ST4N8V:8gV:
RaGoool001Coool4NHF617V6Q`AiSi04NH^<3gV:R`@P4Q047A@B108000<010T44`lE11@A3P@R5a@4
:C@g17EbI@AeLfd3KE=?1616@@AZHET4OX5m18B>R0B:PGX4NfAH0h1^H@B3Kf44NfUI17Q_G`AfK5l4
MG5W0gUkL`AiL6/4M6eQ16YOB`AWGD84Lei318ASC0>BI4`49ALG11XF4P@Y81l4:B8P13@^9@=JAS/4
I5a<16aEA@ATDTH4HE]913XY90@X7aT3:QhG138S7PAM?ST4N8V:8gV:RaGoool001Coool4NI2A17V;
S1MiRX/4ABXT12lR6@@^7QP36aTG10h92P@Q5Q<4:APE12``<`AjKV84MFiN0hBBPPAjNFX4BcT]13`Y
8P@i;RD4:RTS124N70<P71P4:B<L130Q7@A4?ST4JV]O17E`IP=iLF@4NG5N17AVF0AZFTd4J4Pl15mE
?`APFD<3LFEC1<JDL`B/PfL4OeDm17i>>0AjFdX3N615161DA@ASGT`4LV1?15mEB`@k:al48QLD0b/N
60@e9Ad4FCXf9gV:RaGoool001Coool4NI2A17V;S1MiRX/4ABXT12lR6@@^7QP36aTG10h92P@Q5Q<4
:APE12``<`AjKV84MFiN0hBBPPAjNFX4BcT]13`Y8P@i;RD4:RTS124N70<P71P4:B<L130Q7@A4?ST4
JV]O17E`IP=iLF@4NG5N17AVF0AZFTd4J4Pl15mE?`APFD<3LFEC1<JDL`B/PfL4OeDm17i>>0AjFdX3
N615161DA@ASGT`4LV1?15mEB`@k:al48QLD0b/N60@e9Ad4FCXf9gV:RaGoool001Coool4NI2A17V;
S1MiRX/4ABXT12lR6@@^7QP36aTG10h92P@Q5Q<4:APE12``<`AjKV84MFiN0hBBPPAjNFX4BcT]13`Y
8P@i;RD4:RTS124N70<P71P4:B<L130Q7@A4?ST4JV]O17E`IP=iLF@4NG5N17AVF0AZFTd4J4Pl15mE
?`APFD<3LFEC1<JDL`B/PfL4OeDm17i>>0AjFdX3N615161DA@ASGT`4LV1?15mEB`@k:al48QLD0b/N
60@e9Ad4FCXf9gV:RaGoool001CooolONHZ;14db90@J3@X44A4>0aHA3P@O5104518?12@U8P@[>CT4
JVIK17ihJP=jN6`4RHV219^PS`B2KV<4Ge5A17EQFPB;IU83P6EC16mHA`AlJeX4OGIX17akL`AjN743
NFEW17U/I@AdJe`4JUAA14D/9@@d7AX4@CL]0emG@@AXFTH4MV9@18EaF@AgKET4J6=?0emJC`AXEDl4
Ge9;15mGAPAFB3P47ALC114A3`=>Bcl4G3`[154n>BMiRX/Eoooo000Doooo7gV:R`A=<R@46Pd:114A
3P<F4@h47a@@11@B3`@T9B84:cTi16YVF`AnN6X3NWQ/18V9PPBKX8l4PViS15mAD@AeHEX4RfIB0h1U
D`A_F4L4O6]J17efJ0AlNg<4NWQa0gUUI`AiK6D4M6]L16YDD@A5;2D4=1dJ144g;@=OEd44J5Y617IR
D0B5LET4MfeI16QSC`=OFTl4J5E?15mBB`AOEdH4ETPh11dG4`@A4@l3CT/o15`l:`AA?STWNHZ;5Ooo
o`005?oooamiRX/4CC8T11X=2P@A4@h35Q4>11lD40@D4Pl492DR12/i>@AZIU/4OWQZ0gYhK0B9RH84
Vj2?189^H`AODE44MF5J18]VDP>0IE<4KeQ717a[FPAmMVP4O7]c17YhL@=iIFL4NFaU17A[G0AZE544
AB`U13@M6PA1=bd3GeM116QJAPAfHU04QG5I17M]F@AXHdl3GeY?16QEC`AODT/4GeM615I8>0@M5a<4
4A4?0di;?`AL?2/4DChi9gV:RaGoool001CooolONHZ;14db90@J3@X44A4>0aHA3P@O5104518?12@U
8P@[>CT4JVIK17ihJP=jN6`4RHV219^PS`B2KV<4Ge5A17EQFPB;IU83P6EC16mHA`AlJeX4OGIX17ak
L`AjN743NFEW17U/I@AdJe`4JUAA14D/9@@d7AX4@CL]0emG@@AXFTH4MV9@18EaF@AgKET4J6=?0emJ
C`AXEDl4Ge9;15mGAPAFB3P47ALC114A3`=>Bcl4G3`[154n>BMiRX/Eoooo000Doooo27V:R`AiQ8D4
NHF63gV:R`AI@S@4:14<11hB3`<F4a0420@611L@3P@V8Al4:S8a15QFCPAdKf<3NGM[17UlM0AnQH04
Sj>F1:fbW`BHZi`4WK:W0in`YPBU^:d4TJ2@17akK0AeNFh4M7EW0fmjH`AdLf<4NVmR1861J@BCQVl4
Fd0k12<I6@<=3Pl47B0Q1559@0AWFT/4LEi915mEB@=SCd<4DDPi15i?B0AZDT/4>RHO124D40@V8Qh3
:BTS14/[7P@E20H47R8U8gV:RaGoool001Coool8NHZ;17V4Q@AiQHH?NHZ;15U2=0@X4@`47Q8?0aHC
40@810H45a0>12HQ7`@Z<S44F5I>17A_H`=iMf/4NGad17j5P0B?XiH4[K:O19R[W0BM/ZL3Wk2V1:Fh
[@BAX904O7]/17EiKPAdMFL3KgYS17AcH`AjKf84PH5Y19>6K`AK@3/48aTI0`d>3`@M8244DDU016MJ
B`AaGTT4GeE90f=?@`AAB3T4GTm816YBB`@j9Ql48A@@12HR7P<Y:B<4Bb/N11D81P@N8RDSNHZ;5Ooo
o`005?ooo`QiRX/4NHB517V5QPmiRX/4FD8d12PA30@N4Pl35Q<@10P41P@G40h49R4O12Xb<@AHETh4
M6mS0gUgJ`AiO7@4OXF018nSUPB]/Yl4V:^L19fbY`>O/:H4YKR]196PT0AlNf`4MGU^17AeI`=_NV<4
M7=S17Y_HPB1PFT4ThI_15]0>`@S6AT33@h?11dP8@AABD04IeY;175NB@AOEDT3Hdm31558>@ANCdP4
JU9;13XV7`@Q51049R8N0bTY8`A;:ah45@P611hR9B=iRX/Eoooo000Doooo27V:R`AiQ8D4NHF63gV:
R`AI@S@4:14<11hB3`<F4a0420@611L@3P@V8Al4:S8a15QFCPAdKf<3NGM[17UlM0AnQH04Sj>F1:fb
W`BHZi`4WK:W0in`YPBU^:d4TJ2@17akK0AeNFh4M7EW0fmjH`AdLf<4NVmR1861J@BCQVl4Fd0k12<I
6@<=3Pl47B0Q1559@0AWFT/4LEi915mEB@=SCd<4DDPi15i?B0AZDT/4>RHO124D40@V8Qh3:BTS14/[
7P@E20H47R8U8gV:RaGoool001Coool8NHZ;17V?T0AiRh`?NHZ;14Ho>P@W8Ah47ADA0a`C40@F40`4
6A<?12DQ7`@g>3@4H5U@17E`I0=iMf/4NGQ`17UkL`AiPWh8NHN717V0N`=iPWh4NH1k17V0O0AnOgD4
NW=S17ijJ`=jLF<4MFIJ17Y]H0AkLf@4QGQ_1::CPPB/QWH3O5]=12hU7P@>40h44A@F11hQ8P@Z:283
<R/R15]9A0A/EdX4He12134N6@@L4a0471DG0`h920@J40`4=RPU13Ho@B=iRX/Eoooo000Doooo27V:
R`AiSi04NH^<3gV:R`A6?cX49b4N11dE4@<L4a045Q0<11TC3`@U8Al4=cPd161ID0AeL6@3NGM[17Uh
L0AiNg<4NH9n27V7Q`AiP7/3NH9n17V0N`AiP7`4OWme17YcH`AnNV/3NW5S17EVFPAjKF04Ng=T18Eh
K`BRTh84[8If0gaKC@@^9Ah43Q0>114D5P@N8B84:RPR0c8[8PAKBD@4K5M:16=@@P@a7QT471<@11`E
5`<>2@P46Q0<13HX9@@f?d4SNHZ;5Oooo`005?ooo`QiRX/4NHn@17V;S0miRX/4ASlj12LQ7P@M5A43
71<@11H@30@I4`l49B4O13Lh=0APFE04MG1T0gUgJ`AiN704NG]c17V2OPQiQhL4NH1k0gV2OPAiP7/4
NH1l17ioM@AjLf<4OWY[0gYaH`AeIUX4NVeP17]cI0B5N6l4XY>21:b6MP=lFdd4;RDN10h@3P@A51H4
7R4R12XX8P<b:b84FdU416aGBPASD484<AhI11`C40@L5AL33PT811X@30@f:2D4=Sm18gV:RaGoool0
01Coool8NHZ;17V?T0AiRh`?NHZ;14Ho>P@W8Ah47ADA0a`C40@F40`46A<?12DQ7`@g>3@4H5U@17E`
I0=iMf/4NGQ`17UkL`AiPWh8NHN717V0N`=iPWh4NH1k17V0O0AnOgD4NW=S17ijJ`=jLF<4MFIJ17Y]
H0AkLf@4QGQ_1::CPPB/QWH3O5]=12hU7P@>40h44A@F11hQ8P@Z:283<R/R15]9A0A/EdX4He12134N
6@@L4a0471DG0`h920@J40`4=RPU13Ho@B=iRX/Eoooo000Doooo7gV:R`AIAd04?c0/11dG4`<I4a04
7Q@A120H6P@W8b44;C<^14Q9@@AZIe`3NGMV17UbI`AiMfl4NGI/17UkM0AiPGd4NHJ50gV2OPAiOgT4
NG]c17V0O0AiNg44NGMZ0gUdI@AeLV@4MFQL17EYG@AeK604NVaN17IcG`>=Mf04UgeU18aaF@AVCc/4
Gd8a16]B@`=jIeL4HDm:15U?B0A?CT04<b0J11dC40@E4Pl33Pl;11<F50@Z:2H4=Ci08gV:RaGoool0
01CooolONHZ;15U7@0@o<2`47ALC0aTC40@N514481PJ12LS8@@]<bh4B4U116YWG0=iMfH4NG9W17Ug
K`AiMV`4NG]d17V1O@AiQXD3NH9n17UoN@AiNg<4NH1l17UkL@AiMfX3NGAU17EbI0AeJ5`4MFUM17E/
H0AjK5h4MW=O0hegH0BGOFD4S75I16I?>`AO@S44Je930gYWE`AQCdX4FDm814m>@0@c81X47A<@11DB
3`<>3`/44aHD12XX9P@e?T0SNHZ;5Oooo`005?oooamiRX/4FDM013l`;0@M5a<36A<@11hD4@@P61X4
9b<Q12dc;PA8BD44JVML0gUgIPAiLVL4NGM_17UfK0AiNg@4NH5m17V6Q@=iPWh4NGmi17UkL`AiP7`4
NG]a17UgJP=iM6D4MG9T17EXG0AeJEd4MFaP17Y/GPAfLel3SGMP19MmI@B<LET4ITlk15m2<@A[DT<3
NVMG165?BPAICdP4Cdi013<P6P@M4a045A8?0`h?2`@C5Q@4:RPV13Dn@2=iRX/Eoooo000Doooo7gV:
R`AIAd04?c0/11dG4`<I4a047Q@A120H6P@W8b44;C<^14Q9@@AZIe`3NGMV17UbI`AiMfl4NGI/17Uk
M0AiPGd4NHJ50gV2OPAiOgT4NG]c17V0O0AiNg44NGMZ0gUdI@AeLV@4MFQL17EYG@AeK604NVaN17Ic
G`>=Mf04UgeU18aaF@AVCc/4Gd8a16]B@`=jIeL4HDm:15U?B0A?CT04<b0J11dC40@E4Pl33Pl;11<F
50@Z:2H4=Ci08gV:RaGoool001CooolONHZ;15@m;`@[7aH4:alJ0ahD4@@O3P/491HB12TN5P@V9B44
>S/g169KDP=dLVH4NGM[17UhL0AiPWh4NG]c17UkM0MiPGd4NGmi17UkL`AiMVP4NGI^17UaJ0=iJEd4
MFUM17EbI0AeJ5`4MFMH17ASE@AfGE43MV9D17ERD`B2K5`4S7ES18UdHPAgHe@3LeM?16iLB`A/DD<4
Bc<V12dK5P@M4a049QPE0a/D4@@G4Pl481XD11`H60AIFf0ONHZ;5Oooo`005?oooamiRX/4E3d_12/O
5P@[7aX37Q@A11l>2`@T5Q84:AhF12HU8@@j>cL4HU]B0gAbIPAiMf/4NGQ`17V2OPAiNg<4NG]d1gV1
O@AiOgT4NG]c17UfJ0AiMVh4NG5X0gUYG@AeJEd4MG9T17EXG0AeIeP4M6=E17IMD@=fHU@4MF9C189/
G0B<MF<4RGAR17MSE0=cEdl4KUa;16aA@`A;<bH4;A/F11dC40@V61D36a@A11LB3`@P6Q@471PH15UK
H1miRX/Eoooo000Doooo7gV:R`AD?Bl4:alF12/O6P<N51447`h;12@F4P@Y7QH49RDQ13Xk=`ARFe83
M79V17UgJ`AiN704NH9n17UkL`AiNg@7NH5m17UoN@AiNg<4NGIX17UfKPAiLFP3NFUM17EYG@AeLV@4
MFQL17EWF0AdHeD4MUeA0gIRE0AeHU<4PVaL18aeH`B9M684Mf=D0g=GC`A^G4/4K55314/c9P@]6aH4
7A<@12HH5@<K51445a8?120J50@L61P4FE]P7gV:RaGoool001CooolONHZ;14Hg:P@`:bP4:1lL0bLI
5P@C3``45A4?11D@3P@Q6aL49R@L14Y3>`=eKf<4NGM[17UhL0AiO7H4NHJ517UkL`AiNg@7NGYb17Uk
L`AiNVl4NGMV17A`H@=dLF<4MFQL17ESF0AeIe/4MFQL17AVF@A[HU@3JemB175XFPAXGU08K5Y=15iH
B`=EEDH4EEE814]8>`@W920440h;11/F60@A3Q0340d:10P41P@F4A448R<R14Y<C1miRX/Eoooo000D
oooo7gV:R`A6=bX4<2/X12PO70<W6AH44`l<11DA3`@E40h48A/G12HT70A:@c/3MFmS17UgJ`AiN704
NGaf17V6Q@AiNg<4NG]d1gUjLPAiNg<4NGY_17UgIPAdL643M75S17EXG0AeHeP4MFMK17EXG0AdIUT4
Jf9D0f]ODPAaJ5X4J5i@26aJC@ANF4/3EEE615EEB0A;B3/49b@P110>2`@K5QP44@h@0a0=2P@810H4
5Q4A128S8PA:C4`ONHZ;5Oooo`005?oooamiRX/4ASLZ130[:0@X7a`39aTF11<?30@E4@l45A0>124K
5`@V91`4BT<k0gE_H`AiMf/4NGQ`17UlMPAiQXD4NG]c17UkM0MiNW84NG]c17UjK`AiMfH4M71Q0gAa
H`AeJ5`4MF=H17EWF`AeJ5`4M6II16]RE0=[Ge84LFQJ16QND0Q/FTd4GUQ;0eEEAPAEEDP4BdPk12LT
80@@3P/46aHH114>40<@3@X420@611HA4@@R8b84BTa<7gV:RaGoool001CooolONHZ;14Hg:P@`:bP4
:1lL0bLI5P@C3``45A4?11D@3P@Q6aL49R@L14Y3>`=eKf<4NGM[17UhL0AiO7H4NHJ517UkL`AiNg@7
NGYb17UkL`AiNVl4NGMV17A`H@=dLF<4MFQL17ESF0AeIe/4MFQL17AVF@A[HU@3JemB175XFPAXGU08
K5Y=15iHB`=EEDH4EEE814]8>`@W920440h;11/F60@A3Q0340d:10P41P@F4A448R<R14Y<C1miRX/E
oooo000Doooo7gV:R`AI@3<4;RDQ130Y9@<W81`4:QXG11hD4@@T7AT4:BTX12X];0@e>CL3JUiD17Ub
J0AiLV/4NG9X17UkM0AiQXD4NH9n0gUoN@QiNg<4NGYf17AaJ0AdL687MFMK17EXG0A`J5`4Jf=F171S
EPA`HU@3K5mB16aLC`AaHU@4J5i@16MJC@AVF4/3JUE916Q@@`A6=Bd4:QTE12XN6`@?2@/440d?0`X4
1P@B3Q045Q8@12@[:`A4C4hONHZ;5Oooo`005?oooamiRX/4FD0c12hU8@@`:BD39b0L12XJ5`@N5144
91dI12TY:0@Z;B`4=CTg0fYNE0AiLVP4NG9[17UbJ0AiNg@4NHJ517V2OP=iOgT8NG]c17UjMPAdLFP4
M71R1gEWF`AeJ5`4L6QL16]SEPA`HeH4L69D0faODPA/G4l4LF9D16QND0AWFTd4IUQ;0fYEB@AXD4<4
ASD]12XI5@@Z7Q/43`T;110=3`<:10H44Ph@11HB40@T:b/4A4a>7gV:RaGoool001CooolONHZ;15U0
<`@^9B44<2TU0bLP70@Z6QL47Q@A12@M6@@Y:BP4:Rd/13Di=`=ZGU@4NG9X17UbJ`AiLVP4NG]d17V6
Q@AiPWh3NGmi27UkL`AiNWH4M75X17A`HPMeIe/4MFQL171XG0A[HeH4L6=F171RE0=/Ge84K5a?175R
E0AXGU04IeY=16IHB`=ZEDT4J51314He;@@Z6AD4:QhK10l92`@@3@l32P@6118>40@F4Q0492/[14A<
CQmiRX/Eoooo000Doooo7gV:R`AI@3<4;RDQ130Y9@<W81`4:QXG11hD4@@T7AT4:BTX12X];0@e>CL3
JUiD17UbJ0AiLV/4NG9X17UkM0AiQXD4NH9n0gUoN@QiNg<4NGYf17AaJ0AdL687MFMK17EXG0A`J5`4
Jf=F171SEPA`HU@3K5mB16aLC`AaHU@4J5i@16MJC@AVF4/3JUE916Q@@`A6=Bd4:QTE12XN6`@?2@/4
40d?0`X41P@B3Q045Q8@12@[:`A4C4hONHZ;5Oooo`005?oooamiRX/4CDM2138]:P@c;BT3<b/W12LJ
5`@C3`/47ADB12lP6@A7=2P4B3P[0ee?A0AdKel4NGM[17UbJ`AiLVP4NG]d17V1O@=iQXD4NH1k17Uk
L`AiNW84OW]`17YeIP=`K5h4Jf=F171OF0AdGeH4LEeA175KE0A`GU@3K5mB16aJC@AWETX4IeY=16=?
@PA/DDD3Gd/n14Dh<P@d9Qh4:1TE114=2P@B3Q043PT;0a<?2`@C3`l48ALE16MiO0B6W9dONHZ;5Ooo
o`005?oooamiRX/4CDM2138]:P@c;BT3<b/W12LJ5`@C3`/47ADB12lP6@A7=2P4B3P[0ee?A0AdKel4
NGM[17UbJ`AiLVP4NG]d17V1O@=iQXD4NH1k17UkL`AiNW84OW]`17YeIP=`K5h4Jf=F171OF0AdGeH4
LEeA175KE0A`GU@3K5mB16aJC@AWETX4IeY=16=?@PA/DDD3Gd/n14Dh<P@d9Qh4:1TE114=2P@B3Q04
3PT;0a<?2`@C3`l48ALE16MiO0B6W9dONHZ;5Oooo`005?oooamiRX/4CDM2138]:P@c;BT3<b/W12LJ
5`@C3`/47ADB12lP6@A7=2P4B3P[0ee?A0AdKel4NGM[17UbJ`AiLVP4NG]d17V1O@=iQXD4NH1k17Uk
L`AiNW84OW]`17YeIP=`K5h4Jf=F171OF0AdGeH4LEeA175KE0A`GU@3K5mB16aJC@AWETX4IeY=16=?
@PA/DDD3Gd/n14Dh<P@d9Qh4:1TE114=2P@B3Q043PT;0a<?2`@C3`l48ALE16MiO0B6W9dONHZ;5Ooo
o`005?oooamiRX/4CDM2138]:P@c;BT3<b/W12LJ5`@C3`/47ADB12lP6@A7=2P4B3P[0ee?A0AdKel4
NGM[17UbJ`AiLVP4NG]d17V1O@=iQXD4NH1k17UkL`AiNW84OW]`17YeIP=`K5h4Jf=F171OF0AdGeH4
LEeA175KE0A`GU@3K5mB16aJC@AWETX4IeY=16=?@PA/DDD3Gd/n14Dh<P@d9Qh4:1TE114=2P@B3Q04
3PT;0a<?2`@C3`l48ALE16MiO0B6W9dONHZ;5Oooo`005?oooaMiRX/4NHB517AjN`A6>SD4:R@Q12hY
9P<^9b@47ADA12LM6P@U7Q/481lM138`:0A:@cX3Fe9:171[H0AiMf/8NGad17UlMPMiPGd4NGmi17Uk
L`AdM6H4M6eP17UYG@=jIe/4NfaO175WE`A`I5H4LF9D16]TE0A[He@3IeA=169FC@AWFTd4J5Y=16aK
CPAOETT3Dd/m15I1<@@f9Q`49ATE11XD4@@H51046ADA0a<?2`@G4`l47aLD12L]<0AnSi0ONHZ;5Ooo
o`005?oooaMiRX/4NHB517AjN`A6>SD4:R@Q12hY9P<^9b@47ADA12LM6P@U7Q/481lM138`:0A:@cX3
Fe9:171[H0AiMf/8NGad17UlMPMiPGd4NGmi17UkL`AdM6H4M6eP17UYG@=jIe/4NfaO175WE`A`I5H4
LF9D16]TE0A[He@3IeA=169FC@AWFTd4J5Y=16aKCPAOETT3Dd/m15I1<@@f9Q`49ATE11XD4@@H5104
6ADA0a<?2`@G4`l47aLD12L]<0AnSi0ONHZ;5Oooo`005?oooaMiRX/4NHB517AjN`A6>SD4:R@Q12hY
9P<^9b@47ADA12LM6P@U7Q/481lM138`:0A:@cX3Fe9:171[H0AiMf/8NGad17UlMPMiPGd4NGmi17Uk
L`AdM6H4M6eP17UYG@=jIe/4NfaO175WE`A`I5H4LF9D16]TE0A[He@3IeA=169FC@AWFTd4J5Y=16aK
CPAOETT3Dd/m15I1<@@f9Q`49ATE11XD4@@H51046ADA0a<?2`@G4`l47aLD12L]<0AnSi0ONHZ;5Ooo
o`005?oooaMiRX/4NHB517AjN`A6>SD4:R@Q12hY9P<^9b@47ADA12LM6P@U7Q/481lM138`:0A:@cX3
Fe9:171[H0AiMf/8NGad17UlMPMiPGd4NGmi17UkL`AdM6H4M6eP17UYG@=jIe/4NfaO175WE`A`I5H4
LF9D16]TE0A[He@3IeA=169FC@AWFTd4J5Y=16aKCPAOETT3Dd/m15I1<@@f9Q`49ATE11XD4@@H5104
6ADA0a<?2`@G4`l47aLD12L]<0AnSi0ONHZ;5Oooo`005?oooaMiRX/4NHn@17jEU@A3>344<b@L12hT
80<`:RL4=bhY12PO6`@X8Qh4;B8I130e<0@f=bh3B3hf16IJD@AdLVP4NG9[17UgK`AiMV`7NGEZ17Ue
K0AdK5l4M6]M171^HPAdKf43L6=A16]OD0A`He44LFAD175WFPA`Ge84K5iA0g5QC`A/Fdd4J5A816QA
APANE4P4Dd/n0d/m<0@`8b448aLE11DB40@A3PX44@d?10d82`<410H42PL:12`S8@@e=CP4N8V:7gV:
RaGoool001CooolGNHZ;17V?T0AnUID4@cPa13<T70@^9203<2XW13L^:@@X7a/4:28N12dR6@@`=C04
=SL^0dPn=PAVFU44M79X17UbJ`AiMfl4NGI/1gUeJPAiMF`4M6aO17A[G@A`KV84M6mQ0g1SD@A[Ge04
L6=A175TE0AaIeX4L5mB16aND@=aHDl4K5]=16QDB0AXDDH4GUA815=;?P=;?C04<2<Q12<G5@@E4Q04
4@h:114=3`@=20/310@610X72P@/8b44=CDh17R9RQmiRX/Eoooo000Doooo5gV:R`AiSi04OYFE14<h
<@@c91`4;R@P0c0Z9`@g;RT4:1lK12PR7P@]8QT4<3D`13Hg;P=8?SH4IUYA17AbJ0AiLV/4NGM_17Uf
K0MiMFX4NGE/17A/G`AdJed4L6iR17A_H@=`He44Jem@171SD@AaI5@4LFMJ171ODPA/GU43LF5?16aK
C@AXE4P4J55615iDB0ACBch3Bcd`130S8@@S5aD45A8@114>2P@A3@l43@P;0`@41P@:1`X4;2<Q13De
>0AhRHXONHZ;5Oooo`005?oooamiRX/4FdQ212dS6`@`:BD3<B/X12PR7P@T61D4:alG12dV8`@];2L4
;RHP0c@`;0AME4d4MG=S17UgI@AiLVL4NG5T1gUaH0AiMVX4OW]`17YeIPAeHeP4L5a?0g1JD@AaFe@4
LF1J175TE`AaFD`4L5]?1faJC@A[FTd4J5Q;16=@@`AGB3/4Bc/_0c0S8@@X7aP471@@11LC40@M5144
50l@10l92`<@2@/49QPE18FQX0B@Z:PSNHZ;5Oooo`005?oooamiRX/4FdQ212dS6`@`:BD3<B/X12PR
7P@T61D4:alG12dV8`@];2L4;RHP0c@`;0AME4d4MG=S17UgI@AiLVL4NG5T1gUaH0AiMVX4OW]`17Ye
IPAeHeP4L5a?0g1JD@AaFe@4LF1J175TE`AaFD`4L5]?1faJC@A[FTd4J5Q;16=@@`AGB3/4Bc/_0c0S
8@@X7aP471@@11LC40@M514450l@10l92`<@2@/49QPE18FQX0B@Z:PSNHZ;5Oooo`005?oooamiRX/4
FdQ212dS6`@`:BD3<B/X12PR7P@T61D4:alG12dV8`@];2L4;RHP0c@`;0AME4d4MG=S17UgI@AiLVL4
NG5T1gUaH0AiMVX4OW]`17YeIPAeHeP4L5a?0g1JD@AaFe@4LF1J175TE`AaFD`4L5]?1faJC@A[FTd4
J5Q;16=@@`AGB3/4Bc/_0c0S8@@X7aP471@@11LC40@M514450l@10l92`<@2@/49QPE18FQX0B@Z:PS
NHZ;5Oooo`005?oooamiRX/4FdQ212dS6`@`:BD3<B/X12PR7P@T61D4:alG12dV8`@];2L4;RHP0c@`
;0AME4d4MG=S17UgI@AiLVL4NG5T1gUaH0AiMVX4OW]`17YeIPAeHeP4L5a?0g1JD@AaFe@4LF1J175T
E`AaFD`4L5]?1faJC@A[FTd4J5Q;16=@@`AGB3/4Bc/_0c0S8@@X7aP471@@11LC40@M514450l@10l9
2`<@2@/49QPE18FQX0B@Z:PSNHZ;5Oooo`005?oooamiRX/4JVEN13H_;0@Z9B83<RTV138S6P@[91l4
8A`J12PS8@@Q7A/48bHV0bX_:@A0=bd4H5Q<16m]H@AdLV84NGMY17UgJP=dLF@4KfeM17AbI@AiKF04
L5a@171SD@=[GDd4IUa<16ILC`A[Fdl4Jea?16]GB`A/E4d3IeM=16MJB0ASDd84GU1315M9?0@l:b@3
;B4H11TB3`@A3PX44@d?11PB40@D3a042PD60`d92P@L5A<47bDY17R9RR=iRX/Eoooo000Doooo7gV:
R`AZIEh4=Rl/12XU8P<b:BH4<R<J12/T7`@Q71X4:2<Q124M6`@S9RH3:RlY140g;@APF4`4KfeQ17Ab
HPAiMfT4NGMZ0gAaI0A_KEd4M79U17U]H0A`G504L6=A0f]MC@AVG4`4IUa?16]KC`A[G4l4JeM;16aD
C@=WEdd4IeY816=C@PAND4<4EdTl13`[90<]8AP46A8?114>2P@A3@l4618@11@?40@:1@H33@T:11`E
4`@O9BT4N8V:8gV:RaGoool001CooolONHZ;16YUGP@f;b`4:RDR0c8Y9P@b8aX4:b@O124L6P@X8b44
8AdK12<V9P<Z;bT4@3L]161HC0A_KF44M79R17UgJ@AiMfX3M75T16m]G@AdLVD4NFeP171LD0A`He43
Jee=16ILC0AVG4l4Je]?16]LC`A[Ed/4K5A=0fMGC@AWFTP4He=215i@@`AGBC`4?2/T0bdQ60@I4Pl4
4@h:114=3`@H4Q0450l@10X51P<=2@X471DC11lU:@AhRHXSNHZ;5Oooo`005?oooamiRX/4JVEN13H_
;0@Z9B83<RTV138S6P@[91l48A`J12PS8@@Q7A/48bHV0bX_:@A0=bd4H5Q<16m]H@AdLV84NGMY17Ug
JP=dLF@4KfeM17AbI@AiKF04L5a@171SD@=[GDd4IUa<16ILC`A[Fdl4Jea?16]GB`A/E4d3IeM=16MJ
B0ASDd84GU1315M9?0@l:b@3;B4H11TB3`@A3PX44@d?11PB40@D3a042PD60`d92P@L5A<47bDY17R9
RR=iRX/Eoooo000Doooo7gV:R`APFdl4>S4/13<]:@<Z9R<4:bLU120H6P@Q6aT491lL134[:0@]8AT3
8A`H12HZ:0A3>cD4H4i516]LDPA_I5P4KfUM0gAaI0AeKF04L6AI16iZG@AZGe44IU=:0f]IC@A/DDH4
K59716MFBPA[FTd4IeA8169DAP=RCD04FDU014m:?PA3>Bd4@c8W12hS6@<H4Pl45A8@11<?2`@>2@X4
2`P:20@41P<R5a@4;adE130_;RMiRX/Eoooo000Doooo7gV:R`APFdl4>S4/13<]:@<Z9R<4:bLU120H
6P@Q6aT491lL134[:0@]8AT38A`H12HZ:0A3>cD4H4i516]LDPA_I5P4KfUM0gAaI0AeKF04L6AI16iZ
G@AZGe44IU=:0f]IC@A/DDH4K59716MFBPA[FTd4IeA8169DAP=RCD04FDU014m:?PA3>Bd4@c8W12hS
6@<H4Pl45A8@11<?2`@>2@X42`P:20@41P<R5a@4;adE130_;RMiRX/Eoooo000Doooo7gV:R`APFdl4
>S4/13<]:@<Z9R<4:bLU120H6P@Q6aT491lL134[:0@]8AT38A`H12HZ:0A3>cD4H4i516]LDPA_I5P4
KfUM0gAaI0AeKF04L6AI16iZG@AZGe44IU=:0f]IC@A/DDH4K59716MFBPA[FTd4IeA8169DAP=RCD04
FDU014m:?PA3>Bd4@c8W12hS6@<H4Pl45A8@11<?2`@>2@X42`P:20@41P<R5a@4;adE130_;RMiRX/E
oooo000Doooo7gV:R`APFdl4>S4/13<]:@<Z9R<4:bLU120H6P@Q6aT491lL134[:0@]8AT38A`H12HZ
:0A3>cD4H4i516]LDPA_I5P4KfUM0gAaI0AeKF04L6AI16iZG@AZGe44IU=:0f]IC@A/DDH4K59716MF
BPA[FTd4IeA8169DAP=RCD04FDU014m:?PA3>Bd4@c8W12hS6@<H4Pl45A8@11<?2`@>2@X42`P:20@4
1P<R5a@4;adE130_;RMiRX/Eoooo000Doooo7gV:R`BIXJl4DCll138Z9`<^9b@4=C0]13LX70@W6A@4
;bPV12LQ7P@^:RT38AdK11`S8P@K8R0492DR14Tm=`AKCD<4Fdm;0f1EE0APFE84IEmD16EGB`A>@cL4
@cX`0e0n<0ANCT04HU961697>`ARBT04Ie@m16=@?P=NBch4FD<g15A3=`A1<2T4;1`G12<F50<L4a04
4`h;20h92`@:10H41@@610h92`<E4@l4MI2E18RKWBMiRX/Eoooo000Doooo7gV:R`BIXJl4DCll138Z
9`<^9b@4=C0]13LX70@W6A@4;bPV12LQ7P@^:RT38AdK11`S8P@K8R0492DR14Tm=`AKCD<4Fdm;0f1E
E0APFE84IEmD16EGB`A>@cL4@cX`0e0n<0ANCT04HU961697>`ARBT04Ie@m16=@?P=NBch4FD<g15A3
=`A1<2T4;1`G12<F50<L4a044`h;20h92`@:10H41@@610h92`<E4@l4MI2E18RKWBMiRX/Eoooo000D
oooo7gV:R`BIXJl4DCll138Z9`<^9b@4=C0]13LX70@W6A@4;bPV12LQ7P@^:RT38AdK11`S8P@K8R04
92DR14Tm=`AKCD<4Fdm;0f1EE0APFE84IEmD16EGB`A>@cL4@cX`0e0n<0ANCT04HU961697>`ARBT04
Ie@m16=@?P=NBch4FD<g15A3=`A1<2T4;1`G12<F50<L4a044`h;20h92`@:10H41@@610h92`<E4@l4
MI2E18RKWBMiRX/Eoooo000Doooo7gV:R`BIXJl4DCll138Z9`<^9b@4=C0]13LX70@W6A@4;bPV12LQ
7P@^:RT38AdK11`S8P@K8R0492DR14Tm=`AKCD<4Fdm;0f1EE0APFE84IEmD16EGB`A>@cL4@cX`0e0n
<0ANCT04HU961697>`ARBT04Ie@m16=@?P=NBch4FD<g15A3=`A1<2T4;1`G12<F50<L4a044`h;20h9
2`@:10H41@@610h92`<E4@l4MI2E18RKWBMiRX/Eoooo000Doooo7gV:R`BC[ZP4IF5@12`U7`<Y9244
:2<P128R7`@N6A/491`F12hV8@@d;b`3>C4]12TS8P@Z:BT4:R`Y12HT7P@Y:BT482LV0bHV7`@g<BX4
>cL_13Ha;0@j<BP4=R`R0c<`90@m<2D4B3PZ15E8=@AD@C@4@c@]14@a:0=<>Bl4@cTc13LY9@@a7aL4
9AHD11/B40<A3PX43@T;10X41PP410H41@@611DC40<S61D4;3Dh17Z<SBMiRX/Eoooo000Doooo7gV:
R`BC[ZP4IF5@12`U7`<Y9244:2<P128R7`@N6A/491`F12hV8@@d;b`3>C4]12TS8P@Z:BT4:R`Y12HT
7P@Y:BT482LV0bHV7`@g<BX4>cL_13Ha;0@j<BP4=R`R0c<`90@m<2D4B3PZ15E8=@AD@C@4@c@]14@a
:0=<>Bl4@cTc13LY9@@a7aL49AHD11/B40<A3PX43@T;10X41PP410H41@@611DC40<S61D4;3Dh17Z<
SBMiRX/Eoooo000Doooo7gV:R`BC[ZP4IF5@12`U7`<Y9244:2<P128R7`@N6A/491`F12hV8@@d;b`3
>C4]12TS8P@Z:BT4:R`Y12HT7P@Y:BT482LV0bHV7`@g<BX4>cL_13Ha;0@j<BP4=R`R0c<`90@m<2D4
B3PZ15E8=@AD@C@4@c@]14@a:0=<>Bl4@cTc13LY9@@a7aL49AHD11/B40<A3PX43@T;10X41PP410H4
1@@611DC40<S61D4;3Dh17Z<SBMiRX/Eoooo000Doooo7gV:R`BC[ZP4IF5@12`U7`<Y9244:2<P128R
7`@N6A/491`F12hV8@@d;b`3>C4]12TS8P@Z:BT4:R`Y12HT7P@Y:BT482LV0bHV7`@g<BX4>cL_13Ha
;0@j<BP4=R`R0c<`90@m<2D4B3PZ15E8=@AD@C@4@c@]14@a:0=<>Bl4@cTc13LY9@@a7aL49AHD11/B
40<A3PX43@T;10X41PP410H41@@611DC40<S61D4;3Dh17Z<SBMiRX/Eoooo000Doooo8gV:R`B0Q984
@3Dc0c4[:0@^;BT4<2TU11TE4@@N7Q`4<bl/13D`;@<l=c<4@C`g148m<`@l?3<4<3@^12XV8`@[7QT3
91`L12@K6P@/8b44:b@S12DT9@@`9R83<B<K12XR7@@`:bD4<RhV13@/8P@m<bP4=R`Q0bl[9@@d9Al4
;b<K124G50@P71T44`l;0a8>2`@?2@/42PD610H41P@510H471<@11@?40=?CTd4H6=S:gV:RaGoool0
01CooolSNHZ;1824TPA0=C<3<B/X12h]:@@`:BD46ADA11hN70@c;b`4=C0]0c`g<`A1?3L4@Sdc13`l
<`@`=2h4:RHS12/N6@<T71`491/J12`S8@@[92<49B@U130V8P<a8a/4:R8M130[9@@b;RH4=2`R13dc
:0@f;243;b/U13@U7`@_8a/48ALD120L6@@C3`/34Ph;10l92`@:1@H41P@610D41P@L4a0450l@0dm>
C@APHf<[NHZ;5Oooo`005?ooob=iRX/4P8BB140e<`<a:bP4;RdY130Y9@@I5A447QhL13<_;0@e<2d3
?3Lc144l=`A2?C<4?3`c130d;P@Z9R<4:ahI0b@L70@T6aX4;2<Q12/T8`@U92D4<2HR0c4S6`@Z8Qd4
<2/U138^9P@d;284?C<X13H/8@<_:bD4=2DO12lS6`@Q5a@481`I11<?2`<B3P/43`T;10X51P@610H4
1@@611`C40@D3a03Cdi=161SHb]iRX/Eoooo000Doooo8gV:R`BKZjd4F4I10bhV8`@/9244;2HS13L/
:0@f;R/4=2l/13Te<@<`:RL4:bHT12`P7`@g8Qh4=R4J12/S80@N6aT38b<P11/F50@K71`49R<Q128O
70@I51<35QHG11HC4P@D3a0461HC11`J5@@K6AD46Q<B0aT@40@H4Q446Q<B11@B3`@>3@X43@T:0`d8
2`@>2@/41@D610D41P@L4aX471<A138Y90=TOh44PiVJ:gV:RaGoool001CooolSNHZ;19^[[@AHAT43
;RHS12`T8@@/9R<4=b`X13H^:`@d;b`4>CDa0c0Z9`@[9R@4;20O13LR7P@f8AX4:b<P11hK6@<S8b04
6aHD11/L70@V8b448QlL11TD4`<F5QL45Q<B11@?40@H5Q<471XE11/I5@@J4a836A0@11PB4@@J4a84
518?10h=2P@=2@X33@P;10h92`@51@H41@@611`C6P@L4a44<RTT0fAoP@B3VIX[NHZ;5Oooo`005?oo
ob=iRX/4Vj^]15Q6@@<^9R<4;2@Q12`V8`@g;2P4=Rh[13@_;0@i=C43<2XW12/V90@/81l4=b8N13HQ
6P@[8b047Q/I0b<S80@K5Q@46a`L12HS8@@R7a`46A@C0aHF5`@F4a8450l@11PF4`@L6QD46aTE11XC
4P<I4104618A11XC4P@D4Pl43Pd:10d92P<=20/43PT;10D51P@510H471<J11`C4@@b:B@3I7n118>I
VR]iRX/Eoooo000Doooo8gV:R`BKZjd4F4I10bhV8`@/9244;2HS13L/:0@f;R/4=2l/13Te<@<`:RL4
:bHT12`P7`@g8Qh4=R4J12/S80@N6aT38b<P11/F50@K71`49R<Q128O70@I51<35QHG11HC4P@D3a04
61HC11`J5@@K6AD46Q<B0aT@40@H4Q446Q<B11@B3`@>3@X43@T:0`d82`@>2@/41@D610D41P@L4aX4
71<A138Y90=TOh44PiVJ:gV:RaGoool001CooolSNHZ;18>IU0B@VYX3@3Lb12`V8`@a:bP4;RLT13Pd
<0@X8Qh4:RPV0bPQ7P@[9b@4?3L^130^:`@X9bD4:bHS12/T80<d:RL491/L11hN70@O5Q<48ADB11XB
3`<C4@h45Q8?11hF50@O5A@45a0?11@@3P@F4@l37QHD11XC40@H4Pl44Ph:118>2`@?2@/33PT;20D4
1P@>2@/481/G12LJ5PB7V9T3SJ>S;gV:RaGoool001CooolSNHZ;18>IU0B@VYX3@3Lb12`V8`@a:bP4
;RLT13Pd<0@X8Qh4:RPV0bPQ7P@[9b@4?3L^130^:`@X9bD4:bHS12/T80<d:RL491/L11hN70@O5Q<4
8ADB11XB3`<C4@h45Q8?11hF50@O5A@45a0?11@@3P@F4@l37QHD11XC40@H4Pl44Ph:118>2`@?2@/3
3PT;20D41P@>2@/481/G12LJ5PB7V9T3SJ>S;gV:RaGoool001CooolSNHZ;18>IU0B@VYX3@3Lb12`V
8`@a:bP4;RLT13Pd<0@X8Qh4:RPV0bPQ7P@[9b@4?3L^130^:`@X9bD4:bHS12/T80<d:RL491/L11hN
70@O5Q<48ADB11XB3`<C4@h45Q8?11hF50@O5A@45a0?11@@3P@F4@l37QHD11XC40@H4Pl44Ph:118>
2`@?2@/33PT;20D41P@>2@/481/G12LJ5PB7V9T3SJ>S;gV:RaGoool001CooolSNHZ;18>IU0B@VYX3
@3Lb12`V8`@a:bP4;RLT13Pd<0@X8Qh4:RPV0bPQ7P@[9b@4?3L^130^:`@X9bD4:bHS12/T80<d:RL4
91/L11hN70@O5Q<48ADB11XB3`<C4@h45Q8?11hF50@O5A@45a0?11@@3P@F4@l37QHD11XC40@H4Pl4
4Ph:118>2`@?2@/33PT;20D41P@>2@/481/G12LJ5PB7V9T3SJ>S;gV:RaGoool001CooolWNHZ;18nH
WP=E>cH4=B/X134[:0@^9b@47AdJ134_;0@k=S83=34]12DQ7P@X7aX48aTF12<N6`@U81`46QLM0aPL
6`@O6AT48QDC11XB6@@C4Q0451<@0a8>2`@D4Pl84Q8?110>2P@<20X43Pd:0aDA3P@A3PX430P:114=
2`@B3Q043`T;0`D41P@>2@/46Q@A12TP6`@U61D4T:FU192VYc9iRX/Eoooo000Doooo9gV:R`B?V9h3
EC/f13D[:0@a:bP4;RLT11dM6P@a;b`4>cHb0c@a;@@U8Ah4:1lJ12<I5P@S7Q/49B0L11XG7@<H71/4
7aTI128E4`@J4QT44a8@11@C40<B3P/4518?218B3`@@3PX430P:10h=2P<E4@h44@h:10`82P@A3@/4
4Ph@10l92`<510H43PT;11XD4@@Y81/49APE192UY@B@YZLbNHZ;5Oooo`005?ooobMiRX/4SiRN0eDk
=P@e:bP4<B/X12hW90@M7AX4<Bl/13/f<P<d<Bd49B4N12PO6P@S6AH48ahK12DP70@J5ad361`K11lI
6@@R5A<46Q8I11<B40@D4a034Ph;11@B3`PB4Pl440h:10`82P@>3@X35A4>114>2P@<20X44@d;118>
40@?2@/31@@610h92`@J5144:B0K12DH5@B@YJD4T:JW<WV:RaGoool001CooolWNHZ;18nHWP=E>cH4
=B/X134[:0@^9b@47AdJ134_;0@k=S83=34]12DQ7P@X7aX48aTF12<N6`@U81`46QLM0aPL6`@O6AT4
8QDC11XB6@@C4Q0451<@0a8>2`@D4Pl84Q8?110>2P@<20X43Pd:0aDA3P@A3PX430P:114=2`@B3Q04
3`T;0`D41P@>2@/46Q@A12TP6`@U61D4T:FU192VYc9iRX/Eoooo000Doooo9gV:R`B9Y9h3Lg9Z13H^
:@@^:BH4;RLT13D]:@@[:RL4:BLT0bPP7@@R6aP471TH11TB3`@R7A/47QLI120G60<J4@l46A4G10l=
40@;20X440d?114=40<>2@/440d?10d82`@@3@l43PT;118>40@G4a434@h@10d92`@510H40`@610<4
1@@410H34Ph@11@?2`@=2@X450/9182?S`B:W9dfNHZ;5Oooo`005?ooobMiRX/4RJBN0g=bJP@f;RT4
;RTV12hW90@e;BT4:bXW12TW90<X81d48Q/H11`I60@I4Pl48QdK11hG6@@P5aP36Q4?11TA5`@?3A04
2`P:110=3`@A3A033PT;110=3`@=20/440d?10h92`@B3Q045a<A0a4>40@=2@/41@@610<41P@310D4
10@60a8>40@D3`/43@T:11@;2@B0Shl4RYbM=WV:RaGoool001CooolWNHZ;18VTWP=cLVX4=RhY12hY
9P@^9b@4=BdY12/Z9`@Y9b@3:20M128K60@L6AP46A8?128M6`@N5aT481LH0aXA3`@I4AL43`d@10/8
2P@@3@l44@d@0`h92`@@3@l43@P;110=3`@>2@/44Ph@11LC4@<A3Q043@T;10D41P@310H40`@510@4
1P<B3Q0450l;10d92P@D2`T4P8n?18ZLWCIiRX/Eoooo000Doooo9gV:R`B9Y9h3Lg9Z13H^:@@^:BH4
;RLT13D]:@@[:RL4:BLT0bPP7@@R6aP471TH11TB3`@R7A/47QLI120G60<J4@l46A4G10l=40@;20X4
40d?114=40<>2@/440d?10d82`@@3@l43PT;118>40@G4a434@h@10d92`@510H40`@610<41@@410H3
4Ph@11@?2`@=2@X450/9182?S`B:W9dfNHZ;5Oooo`005?ooob]iRX/3^MSH17mhL0@a:2<4:B@Q12XY
9P@/:RL4<c0/0c8Z;0@W6AL48a/H11PD4@@E40h4514>11PB3P<=2@X42`P9114=3`@C3a443PT;114=
3`<?2@/44@h?10l92`@S5a@41`D710l=3`@E4Q034`l@10D51P@510H42P@611@?40@F41434`l@12DH
5@@i9a`4J4di169PEPAjS8dfNHZ;5Oooo`005?ooob]iRX/3^MSH17mhL0@a:2<4:B@Q12XY9P@/:RL4
<c0/0c8Z;0@W6AL48a/H11PD4@@E40h4514>11PB3P<=2@X42`P9114=3`@C3a443PT;114=3`<?2@/4
4@h?10l92`@S5a@41`D710l=3`@E4Q034`l@10D51P@510H42P@611@?40@F41434`l@12DH5@@i9a`4
J4di169PEPAjS8dfNHZ;5Oooo`005?ooob]iRX/3^MSH17mhL0@a:2<4:B@Q12XY9P@/:RL4<c0/0c8Z
;0@W6AL48a/H11PD4@@E40h4514>11PB3P<=2@X42`P9114=3`@C3a443PT;114=3`<?2@/44@h?10l9
2`@S5a@41`D710l=3`@E4Q034`l@10D51P@510H42P@611@?40@F41434`l@12DH5@@i9a`4J4di169P
EPAjS8dfNHZ;5Oooo`005?ooobiiRX/4^MSH189bJP@i=2l49b4M13</:@@e<2`3>C<^12XX8`@X8al4
81DL118>4@@J4Q044Ph@0aLD4@@I5A444`l@20h92`@=20X33PT;10d82P@G4a043`h?12h`?@@d>3`4
8ALO0`l92`@D3a046aDA11/F4@@D3a04:B<N0bhR70@U6AD4@2dW17fDW0B4WJ0jNHZ;5Oooo`005?oo
obiiRX/4^MSH189bJP@i=2l49b4M13</:@@e<2`3>C<^12XX8`@X8al481DL118>4@@J4Q044Ph@0aLD
4@@I5A444`l@20h92`@=20X33PT;10d82P@G4a043`h?12h`?@@d>3`48ALO0`l92`@D3a046aDA11/F
4@@D3a04:B<N0bhR70@U6AD4@2dW17fDW0B4WJ0jNHZ;5Oooo`005?ooobiiRX/4^MSH189bJP@i=2l4
9b4M13</:@@e<2`3>C<^12XX8`@X8al481DL118>4@@J4Q044Ph@0aLD4@@I5A444`l@20h92`@=20X3
3PT;10d82P@G4a043`h?12h`?@@d>3`48ALO0`l92`@D3a046aDA11/F4@@D3a04:B<N0bhR70@U6AD4
@2dW17fDW0B4WJ0jNHZ;5Oooo`005?ooobiiRX/4^MSH189bJP@i=2l49b4M13</:@@e<2`3>C<^12XX
8`@X8al481DL118>4@@J4Q044Ph@0aLD4@@I5A444`l@20h92`@=20X33PT;10d82P@G4a043`h?12h`
?@@d>3`48ALO0`l92`@D3a046aDA11/F4@@D3a04:B<N0bhR70@U6AD4@2dW17fDW0B4WJ0jNHZ;5Ooo
o`005?oooc9iRX/4`>GU189`J0A7>cH49b4N12DU8`<d<bl4@CLb13<U70@Z7aT46aDA114>40@=2@/3
40d:114=3`P>2@/44Ph@10l:2`<B3Q043`X;10`82P@W:b`49AdV13P_;PA=A3X3@cDd14Pl=`@g:bD4
6aDB12HN6@@S71T3<B/X14Xc:@B:Vi/4R9^M?WV:RaGoool001CooolbNHZ;1<3Ui@B2L6P4Ac/f12LQ
7P@U9B<3=3<_144g<P@c9A`4:QlI11/E4@@A3Q043@T;0a0=2P@A3@l83PT;118>40@?2P/34Ph@10l:
2`@<20X49b//12DM9P@h;bh4CD@j0d<e=0A8?3L4=b/U11/E4P@V7QT48a`I0c4[:0A:<bT4RY^K18RK
WCiiRX/Eoooo000Doooo<WV:R`C0iND4PW1X14Lk=P@W8Ah49BDS0c@c;`A1=c84<bDL12XO6@@K5A44
4@h@10d92`<@3@X44@d?20h92`@B3Q043`X;0a8>40@?2P/430P:12L[;0@U7BH4>2l^14e4>P=3=C@4
B3`g13L[9@@K5A849QhI12<L6@<a:bP4BS<Y18ZKV`B8VidnNHZ;5Oooo`005?oooc9iRX/4`>GU189`
J0A7>cH49b4N12DU8`<d<bl4@CLb13<U70@Z7aT46aDA114>40@=2@/340d:114=3`P>2@/44Ph@10l:
2`<B3Q043`X;10`82P@W:b`49AdV13P_;PA=A3X3@cDd14Pl=`@g:bD46aDB12HN6@@S71T3<B/X14Xc
:@B:Vi/4R9^M?WV:RaGoool001CooolbNHZ;17B5QPBhg=`4LE];14Tm=P@h;b/3=C4^13/g<PA1?CX4
:b8N12TN6`@g;2L4<B/T0b8G4`@I5104510A11<?4@P>2@/35Q8I11@@4P@H51443P/<11`M5`@R81d4
3@/=0`d=30@<3@/430/=11TA3`@Q6QP4;B8I0ddh:@B8SY04N8fE17V;S3iiRX/Eoooo000Doooo<WV:
R`AdQHH4^=cL175KB`A9?CH4>2l[0cDa;P@k=c84@Cdj12/R7P@Y7Q/4=b`W134[90<R5a<46A@@11@@
4@@C3a483PT;0aHB6@@D418461@A10h;30@L7AL48R0M10d;3@<=3@`430d;10`;3@@I4@l48AXH12dR
6@==>2T4R8j@17R=U@AiRh`nNHZ;5Oooo`005?oooc9iRX/4M8F61;SLg0AaFd/4BCdf13P_:`<e<Bh4
>cLb144m>P@[8Qh4:AhK13L/9`@a:b@38QLC11TD40@D41444`lA20h92`<F4QT4510B11PD4@@>2``4
71dG128P7@@=2`d33@d<10`=2`@<2`d46A4?124J60@]8QT3CCPY18R>T0AhSID4NH^<?WV:RaGoool0
01CooolbNHZ;17B5QPBhg=`4LE];14Tm=P@h;b/3=C4^13/g<PA1?CX4:b8N12TN6`@g;2L4<B/T0b8G
4`@I5104510A11<?4@P>2@/35Q8I11@@4P@H51443P/<11`M5`@R81d43@/=0`d=30@<3@/430/=11TA
3`@Q6QP4;B8I0ddh:@B8SY04N8fE17V;S3iiRX/Eoooo000Doooo>WV:R`Bnin`4KfYL12hV80<W9284
?CXg14U9A@A;ACl4;28N11/E5`@Q5A<3<BPT12dX8`@F4A843PT;11`H7P@P6b<39b@P124L8@@f;bd4
7aPN13Db<P@c:b`4>BhY0cX^:@@c:2<4>BhX14Q0=@@i;bT4ET@f0i>RX`BF/k04O92?@WV:RaGoool0
01CoooljNHZ;1;kWk0A_JU`4;RHP0bLT8P@m>SL4BDU514]5?`@/8Qh46aDG124E4`<a:2@4;BPS11HA
4P@>2@/471PN120K8`<W92048A`Q13H_;@@O61h4=C8b13<[;0@i;RT3>RhY13<X8`@i;RP4B40e13T_
:@AFA3H3Tj:S19Jc/0AlT8m2NHZ;5Oooo`005?ooocYiRX/4_^O/16mZG0@^9R039b@R13dj=`A9BDD4
BdDo12`R7P@K5AL48ADC0c4X90@]:2<45Q4B10h92`@L61h481/S0bLT80@Q7244=Rl]11lH7P@e<S84
<b//13T^:@<j;RT4<bPS13T^:0A8@3D4>BlY15I4=P>CXZ<4U[>`17b@Sd9iRX/Eoooo000Doooo>WV:
R`Bnin`4KfYL12hV80<W9284?CXg14U9A@A;ACl4;28N11/E5`@Q5A<3<BPT12dX8`@F4A843PT;11`H
7P@P6b<39b@P124L8@@f;bd47aPN13Db<P@c:b`4>BhY0cX^:@@c:2<4>BhX14Q0=@@i;bT4ET@f0i>R
X`BF/k04O92?@WV:RaGoool001CooolnNHZ;1;kMhPC9d]`3GE=>12/W90@Y92<4=CY2159@CPANED`4
G5aE0cP`<@@[;C04BDUF16MSG`A2=S@4<2`f0c0X;PA6@Td4=c4a13T]9P@a;2T4>BdX13XW90<j9Qd4
>2dX14<h;`AH@384B2`P16f9T0>4XZD4NH^<AWV:RaGoool001CooolnNHZ;1;kMhPC9d]`3GE=>12/W
90@Y92<4=CY2159@CPANED`4G5aE0cP`<@@[;C04BDUF16MSG`A2=S@4<2`f0c0X;PA6@Td4=c4a13T]
9P@a;2T4>BdX13XW90<j9Qd4>2dX14<h;`AH@384B2`P16f9T0>4XZD4NH^<AWV:RaGoool001Coooln
NHZ;1;kMhPC9d]`3GE=>12/W90@Y92<4=CY2159@CPANED`4G5aE0cP`<@@[;C04BDUF16MSG`A2=S@4
<2`f0c0X;PA6@Td4=c4a13T]9P@a;2T4>BdX13XW90<j9Qd4>2dX14<h;`AH@384B2`P16f9T0>4XZD4
NH^<AWV:RaGoool001CooolnNHZ;1;kMhPC9d]`3GE=>12/W90@Y92<4=CY2159@CPANED`4G5aE0cP`
<@@[;C04BDUF16MSG`A2=S@4<2`f0c0X;PA6@Td4=c4a13T]9P@a;2T4>BdX13XW90<j9Qd4>2dX14<h
;`AH@384B2`P16f9T0>4XZD4NH^<AWV:RaGoool001Cooom2NHZ;18jYX`?>k^`4MVmh148l>P@`<C<4
?dQ?14aAE@A4AT@3D55:15eJE`ADCD@4AShi13lg<@A2>S03<b/Z124K5P@V8Ah4=C0/134[:0@l:R84
BS4W0d`j<0AKACX4AbhU14<oA@BU`L`4Rj>TCGV:RaGoool001Cooom2NHZ;18jYX`?>k^`4MVmh148l
>P@`<C<4?dQ?14aAE@A4AT@3D55:15eJE`ADCD@4AShi13lg<@A2>S03<b/Z124K5P@V8Ah4=C0/134[
:0@l:R84BS4W0d`j<0AKACX4AbhU14<oA@BU`L`4Rj>TCGV:RaGoool001Cooom2NHZ;18jYX`?>k^`4
MVmh148l>P@`<C<4?dQ?14aAE@A4AT@3D55:15eJE`ADCD@4AShi13lg<@A2>S03<b/Z124K5P@V8Ah4
=C0/134[:0@l:R84BS4W0d`j<0AKACX4AbhU14<oA@BU`L`4Rj>TCGV:RaGoool001Coool4NGn117V5
QT5iRX/4_]gD1=Sjn0CCgn04Gei^151>E@AfM8D3MVmi15m@B`A<A404BDE115mDE@AUEU<3HEI>16eO
F0AMDTD4Ddi716EHDPA@CTD4@TLm0c<]:PAEGFT4]M_W1;kZi`B4VYYANHZ;5Oooo`005?ooo`AiOh44
NHF6@GV:R`BngM@4f?[h1=?Oh0AOGVh4D4iE17IdQ@=fKgT4Ge1;14a4@0A9AD44GeAE16EFD`=QETh4
KEmH15eBA@ACCTL4IEQB151>A@A2Acd3<bdZ15EMJ@BefnL4_^[W18BJVU5iRX/Eoooo000Doooo17Uo
P@AiQHI1NHZ;1;kMe0CHn_P4dmoP15mNKPA@CUD4MWB50gI_N@AOD4/4C4A014U5@@AOE5D4IEIC0f5F
CPA]GeP4GE9515=>A`AUF584D4i51497?@<c;BX4EEeY1;GKi`Bnj^L4Q9ZJDGV:RaGoool001Coool4
NGn117V5QT5iRX/4_]gD1=Sjn0CCgn04Gei^151>E@AfM8D3MVmi15m@B`A<A404BDE115mDE@AUEU<3
HEI>16eOF0AMDTD4Ddi716EHDPA@CTD4@TLm0c<]:PAEGFT4]M_W1;kZi`B4VYYANHZ;5Oooo`005?oo
o`AiT944NH^<BGV:R`B3VI@4`=_<1;SJd`BS`[D3WKBo1:g7d`BU/<84IFQo14M@H`A1A4L3A48o13lo
?@A7A4<4@Chk13<_9`@h<b/4PY:C0mgoo`BVbl@4OY>CFGV:RaGoool001Coool4NI2A17V;S4UiRX/4
PiVD1<3Kc0Bhf]<4Xl:e0ifd_`B]am<4YK3216EXO`A7D6<4@DA70dA2?`@o?cd4AdA3144n>`@c;bL4
>3<[18:BT`?Mool4Y/_417jCTeUiRX/Eoooo000Doooo17V@T@AiRha9NHZ;18>IU0C0fl`4^=[C1:?2
]@>M];l4[LOC1:F``PAUJ7l4Ae1S1454A`=4@Sl4?clm14M4@`A1?S/4<blW13Pc:`B2TY<3gOoo1:K;
a0AnTi=INHZ;5Oooo`005?ooo`AiT944NH^<BGV:R`B3VI@4`=_<1;SJd`BS`[D3WKBo1:g7d`BU/<84
IFQo14M@H`A1A4L3A48o13lo?@A7A4<4@Chk13<_9`@h<b/4PY:C0mgoo`BVbl@4OY>CFGV:RaGoool0
01CooomQNHZ;0h>IT0AkTY44SZZO1;SDa@C0g<`4a^OU0lOQh@C7iND4an[Z1<c_k`CBn_h4doOm18VS
Y@=iRhaQNHZ;5Oooo`005?ooof5iRX/3PiV@17^BT@B>ZYl4^=C51<3Lc0C6inD3an7Q1<OUi@C7j^X4
c>o_1=;joPCCmod4RJ>U0gV;S65iRX/Eoooo000DooooHGV:R`>3VI04Ni:A18jZW`Bhe<D4`=c<1<KW
i@?7hN44anGU1<OZjPC<knl4d_[n1=?go@B9XjD3NH^<HGV:RaGoool001CooomQNHZ;0h>IT0AkTY44
SZZO1;SDa@C0g<`4a^OU0lOQh@C7iND4an[Z1<c_k`CBn_h4doOm18VSY@=iRhaQNHZ;5Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00VOoo
o`<00024oooo002Loooo00<0003oooooool0POooo`00Noooo`D00002oooo0P0000Coool200001?oo
o`@00002oooo0`0000?oool300000oooo`80001noooo001moooo00D0003oooooooooool000000_oo
o`040000oooooooo00000_ooo`040000oooooooo00000_ooo`040000oooooooo00001Oooo`040000
oooooooo0000Poooo`00OOooo`050000oooooooooooo000000;oool010000?ooooooo`0000;oool0
10000?ooooooo`0000;oool00`000?ooooooo`0400000_ooo`040000oooooooo0000Poooo`00OOoo
o`030000oooooooo00;oool200000oooo`040000oooooooo00000oooo`<00003oooo0P0000Coool4
0000P_ooo`00OOooo`050000oooooooooooo000000;oool010000?ooooooo`0000;oool00`000?oo
ooooo`03oooo00<0003oooooool0SOooo`00O?ooo`800004oooo0P0000Coool200001Oooo`80002?
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(202) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96899E96
81847487897887887C878E8187887C878D81878D81878D81878E8187897D898A78838574
85816F7F77678177667A73637A73637A73637A73637A72627C6E5E766E5C766E5E766E5C
6D5D4B879B96879B96879B96879B96879C98879591879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879793879591879B96879793879591879B96879B96879B96879B96879B96879B96
879B96879B96879B96879793879591879B96879B96879B96879B96879B96879B968CA39C
86887C878978878878878E8187887C878D8187897983816E7E816E7E7D6E80796A767465
767464756F60776F60756F607A73637A73637A6F5F7A6F5F7C6E62766E5F766E5E767E71
6D736A879B96879B96879B96879B9687A09B879A96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B9687A09B87969287959187A09B879A96879B96879793879591879793879591879B96
879B96879B96879B9687A09B879A96879B96879B96879B96879B96879B96879B96839A93
81847087897D878478878D8187897D87857983867A7881756F786D7A70657B6C617B7464
7A7B6A7A7B6A7F7A69766E5F726B5C726B5C726F5F726E5B776E5C766E5F766E62847E6F
849792879B96879B96879B96879B96879B96879793879591879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879C98879591879B96879B96879B9687A09B879A9687A09B879A96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B968C9E96
86847887897C87897D87847987897D8789798C8E819E92858C92848B8D7F8F7F75847363
846F64846F67806B627C6B5F766E5F766E5F766E5F766E627A72627B7262766E5F6D5D4B
879B96879B96879B96879B96879B96879B9687A09B879A96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B9687A09B879A96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B9687A39C
87887387897487897887897D87897D878982878D808792858C928A83937C89887C888376
88836F847A6B8883728A74687F665F7F726B7B76687A6E5F7A6B5C7C6F5F7A7667736855
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879F98
87897887897C87897887897887897D878D8187897D878579878D818C928A8C9784888D7B
8380738884737F776785806E807A697A6A597F776C767668726E5F776E5F7C7C757F7F76
879B96879B96879B96879B96879B96879B96879B96879793879591879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B967C7B70757870
87897C878978878979878978878D8187897D878D81879285878D81878E818789828C8E80
8C8A74888070888070847B6B857366807262776756776F607A6E5F7B6E5F706E61818D89
879B96879B96879B96879B96879B96879B96879B9687A09B879A96879B96879B96879793
87928E879591879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B9655584E4B62597F8273
87897887898287898187897C87887C878E8187847587887887897D87897D878979878E7D
838578837C7083786C857C677B72607B73637F72627B6E5F7576677F7A69786D5A869A95
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B9687A09B
87A09B879A96879B96879B96
879B96879B96879793879591879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B967883834F3E3916263086887C
878D7B878E81878D81878E81878479878D8187928A87897C878979877D7183706A7A6C5F
7E7966837B6C7F806C7B776A7F776680726377725E776E5C716759726C5D6E5D4B879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B9687A09B879692879591879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B968A9E9A4C4739878E7976796887897D
87847887897D87847987897D87897D87847987887D878E818385797E8671837B70857C6B
7973647A74647F7460817764746F5F7B6B5C7F6F627F6E5F7B6E5F7A7263705A4981847C
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879793879B96879A96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B963E3B32878F8482898186887C878978
87897D87897D87897987897887897D878D8187897D87897D896C678357557F50507F4D4D
7F4D4D7F5C577B6C607B6C5C7A6A5B776A58756E5C7A6E5F7C6E5B7567566C54456F604F
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879793
879591879B96879B96879B96
879B96879B9687A09B879A96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96788380D2D9D3777A7587897D87897D878978
87897D87857587817187816D878474878479877D7587706D8979707F5D537B504579544C
7B584E794A497D5652725F55726E5B776A5B756A5C7A6E5F7F6E627A6E5E7F6E5F6A4F3D
756857879B96879B96879B96879B96879B96879B96879B96879B96879B96879B9687A09B
879A96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B9645463E1B302F818471878974878979878978
8789798386757E7869817E70878877878171836C5E7A50487764586B58486B7462788772
7D594C6C43397B4A437B544E76635B766E55716A52756E5C7A6E5F7A73627A6A5C7A6F60
735F4C879086879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879793879591879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96696E6BA595815F625986887C838175818378878E81
878175857965766857745D598057534B26213941397F7669887066A2BCB48D685F734F45
686D5461715F555242594037734A447167557A66547A6E5F7E7A668076627A72637A6E5F
6A5344756351879086879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B9687979387959187A09B879A96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B9653544C3B53547E807587897889857481746787897D
878A7C866E5B77604E472723404E4CC0EFE28AAAA391C8C48BB1B4868F8B8EC3AC9DB4A8
A8BEBD859088655A4F30382B3B37306C574F756D5A7E6D607E776A857F6980725F7A6F5F
7A6F606A645C727D8481908C879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B9687A09B879A96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B967C8B8F5546400E232D8184708789798C988486877787897D
80786A766A5263483763322642201F7651477E6556816D5F878B7787806A857A6D78665D
8076669E8975B2A78D9D918042423736322F67554A736959827F6C848071817B697A6D5E
7A6759776448646C5F61686775848C879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B9655584E25252070685F5E5C5886887887817187786A877F6C878974
8A87739583779DB49ACEE2BE8A95878875717F746875584D78585677504F76554C703630
72423E66453F7D6A59815C539072663C29203830307261597D766485816B817360777362
7572627F6A59908E7F858D886E7780879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879793879591879B96879B96879B96879B96879B96
879B96879B967C878732322C272B271E3F4283857A878575878178837F77818374877D75
8A8074745F4D6E6055868C84879C898C9B8D92A49591A3948BAD939497808D9C83899D7E
898F737F645783645D8652488145397B3E3240292550393B776A5D857C6B8177627C6A5B
7567597A6B5D403228414531818B8881908C879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B9687A09B879A96879B96879B96879B96879B96879B96
879B96879B968CA3A3FFF3DFF2CDA8726C5D818475878A788792788C8078867A7487987C
8A8C798B7C6C6F5D4F817B6C878D81878E81878479878D8187817D897D74837B6C857C6E
7F77667D77616C785E777F668688709891778C8074695B4E6E66527F78678177627C735E
756E5C7A6F6072685C242C2975847B869A95879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96989F8385897F8C9C92888D7F7D807081897887887C879885878B84878E85
8E93848A8773755F52726355818373879285878E8187887C879D858988777F70607F705E
77735C706A5B6966536E5B4E6E5F4E6E5F4E73664E746D627872627F73667D6E5E77665B
716A58726B594D4138202F3279868D879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B9683938F81959083816D7A6D5973746D74807C868478878D80879285878D81879285
8C89848E847A8A7E6B7C645981756787887D8781798372698185758585727F7B6A775F53
7764597C6555726253726956766954776C5272614E7262527E6F607B6F607C6E5E766A5B
766A5F7A726239333100110D69716C879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B968C9483868A7F8581737B746788755B7F7C75877A7387887C878D81878D81878D81
879D858C8D7B8A8870796B597B6A5D87887C879D8A8C8C858688818E8E84847F7186816E
7F6D5E7C6C5A725E5272625371665D7F6D6088796B7D75657B72627B6F5F7F73627B6D5E
766A58716B594E3C32131E1F1B211F879591879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879F98838570796E58777060857A7286887887877787887C87918887938A878D81
878E868792858A88787F7F69776F5B817F70878979878D7C878E81898F7C8077667B6F60
776E5F7C75647B705777645071625578726682796E847B6B817F6E7A7A69777262777362
766E627A7666C8986A704A381C1C1A1E2422879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
878B80807366734A427D615A6661596F8E7887877887897887887C878879878E82878D81
878E81838579898F7C888D7F868776868873837D71817568877D7185746881725F776658
7362547167506B5E4F695F5074695B7876637D7668857C6B8173637A6F607F6F5F7B6E5B
7A6A587A6A5D857C6FA88C73D0C5B37C8E8A879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
87908E8A726B826558765D54816F5F7F8378878D85878E8187887C878D81878D8187897D
878979898A79868574888070818478878D858C9C8D868780878F788A80727D7664736656
6F6253665B527869587874647D75657E7A6B7D7B6B857C6B8177667A72627A6A5F7F6662
766A5E756960786C587163527057468CA09B879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96878F83
879A838A8A727E715875645578726686887787887C87928587897D878579838172818571
877D758978717D7C6D837769817F6F87847587897987897D8785818A7469826F5E776959
776959736C5D70715D746E5C7873648277687F78687F74648173637A6E5E7A6A58776A58
776E5B756E5C847C707B6D5E5D4D3E707A78879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96808777
6B5B4B524B3E4E4E45625F547A776A8789788784798785798789798785718985757D786D
7A7D6A7E776D83847783887781836F87897D87897C87897D83937D858774827161776959
7265567B6657756A5F786F637E73677973647F7B6C7F7F6E8177667A7B69777664776D5E
76665F756A60735E4A755D4F7B5B466D4E3F879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96868574
4E3D2D433D363837352F3C3F7A796F87897C87897987897487897D878E858C8D858C9789
8E887F7F746876645B776F627D7B6D81847487897D87897989817580786A78665E736255
6F61506C62557A6E5F746E5C756B5D796F647B685C756C5E776F60726B5C776F5F766E5E
766A5C71635674765A6453407266576D4A3E879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B9687938B909E96
A47760524236453E372A393D7A796783857181847987897D7C79656C6858635B4B554D41
5A584C61595471605A6F605374675B7B7A6B87897D878982898A7C867B6C7D705572614F
736553686253665F526267596867596F7360777665756F607F77667B7262766E5F766E5E
766A5C766A5F6854464C382F55483967442F879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96838C7F858271
392722252725292F2C1431377D7A6C878575868470878979949380797262646252424842
2A353327342C383C35503E33472F294F3C35817F7087897D898F7C867F6C7D6D5A6F6D54
6B604C6B6659837665887A697E726276635970675C6A6A5D7A73637C72626F6A5B666A5B
6C6E5C766E5F7C6450654C3D5C453D673828879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B968A9E9A92A298857662
7C5A4E352F2A332E2A1227308688778389788184748789788C92859A907DA28F807B6453
3D342E2E2F2A2C38374C574B7C7665736B5F81877687968C89988C86836F746456665548
4B2D233A312F6155425B52424A483B4F52446F6658676655726B59776F5F786A596E6658
6B665C6F6257635246554F435F5C526F493D8CA09B879B96879B96879B96879B96879B96
879B96879B96879B96879B96
87928E879591879793879591879B96879B96879B96879B96879B9636292413282E867D6B
83624F3B373A282B29021D287D80708789788385747E8171818474949C8C7E7F6AB4957B
C2A080A2816189664A76735C76705E7C6C60817D6E878879898B7E86806D876F58736050
836B53504D48404A4B181D1E202E2E353C382D322C283535444539564F3F7467566E695A
6B6A586C605150483A383A354351487057458DA19C879B96879B96879B96879B96879B96
879B96879B96879B96879B96
87969287959187A09B879A96879B96879B96879B96879B963C332E3A3530111919151E21
2E2C30292B2732302C0B212B838574818478817067705D557470628C928A92A196999489
8A796B8F82728D7F6F817464817E6A827A6B817D6E878D81898A808684757D7761787054
8074578D6F57A07A613C3331232C283A36333D3D38393F3763594E6968597C6956736658
6B6E5B55463E3F3A323A362E2F332F623526879B97879B96879B96879B96879B96879B96
879B96879B96879B96879B96
87A09B879A96879B96879B96879B96879B96879B96879B96654E443F39303E37302A2E2C
222423302D2B37302C12222B86807083806C93A6928A8A7B5E5244504439504B3F43473E
3B3C373536303D3E35433B34514E45777A6B817E6F878575898A75867C6C7D7464775E50
6E6A526C6951807A65DAA985A78C7287664F88624C7565567D6E566E655471725E80725E
6E6A5E574A3935302C39362F3439315B2618879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B966D57442D2623242A26282A26
312E29252A27333B371932377476688C8878868877989C92A9B29D8E81737367637F746A
967965877361796A588177667E756885877B86887C877D7989817886806E7D6F675B483E
4937314D493E6C6A52766E5884766293846C847D686F705C6F6D60766A5E6E665E6C6A58
6C614F36342D242B2747534B6352414E2416879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879793879591879B96879B96879B96879B967A68553B2B252F2A27282B28
1B1E1F28292632363223383A606459817F70878978878D818C968E9EB5A3B9BBA599B0A0
A7BBAEA6B5A8ACBFB194A594878776818777838A797E8F758384748A85748F947AA49A82
6E595035302F232A272C38355D5B50776E5E80735B6E6A5B736656625F4E6C635975665E
55443939302A3638342237345F4737291D18242A28879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B9687A09B879A96879B96879B96879B96879B9666645C3B3B352F2D292E2B28
282A24282A2732363230403F646258817E7087897887887C878D81879188879792879792
87938A87918887938A87928A8C92858684708C8E7D888574837C6D888070888573938D7E
B4A891B494848B6F603C3B34232A26262F2E343B393E4339454539665B5274695A736657
4D3B34302D292D2C2D1D22212D2A254C3E38202321879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B967A6D634F474130302B2A2B28
2F2C283030303537352D3F3D4F544B74746787897487847487887D878879878C80879289
87989387918887938B878D8187928A878E81878978898A78838574837B6C837B6C838170
8A80708588729F8C74A48F769681696E624E6C55457063548475646660566B635B636555
4E3E352F2C28262B26202824232D2B3A3B37202422879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B967463513D382E3F38322F2D29
302723342E2937342D3038343D47436B675C81847487897887887C879188878D81878C80
87928987928987938B878D8187897987897D878579898170837B6C838574837B6C837C69
8578688574648577668576658E7E6C97887391836F7D72627F695E7A705E7C6556624F40
4638302F2C2836302C2D2D29272A272E302A161813646867879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96665C4B41413C3A383338322E
252924262A262629262E312D2D362F4E4D42817F7087897887887C878C7F879893878D81
878C80878E82878E82878D81878E82878974838675838674837B6C837769837C6C837B6C
857C6B7B77667B73637F7B6A7672627A6F5F7B6E5F6F6E5E666A58666A5B60605141413A
2629242D2F2F2327282327231A1E1F242928242D2A494742879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B967A66543F3B3542413C383833
3C332E2F2C28343430353D3A37413F33403E746D61878474878479878374878C80879893
87918887938B878D81878D81878E86838579838674837C6C837C6C837B6C7F7B6C7A7868
7F78688177667A73637A6F607F7766767262776E5F786E5E756A5B7766565D514542352F
3C37322123232326271C1E1F2427282529272836353B3E3A879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B966D6D6543433E43433E44423D
38332E2628242C2C293B362F4F473B47463B655B4E817F6C878978878479878374878C80
87928987989387938A878D81878E818C8E818889787F81707A78687D74688574687F7464
7F6F648173667A73637A6F5F776B5C776F5F7366577B67586E62535C52494D42383D342E
2427232528282022232528242327272F2E2C4B595880918D879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879793838E8A6660573B3C373E403B3F3F3A
302F2A3835313335312F36333A423B4F534A625A507B796C878978878D81878D81878C7F
87928987928987938B878D81838A79818171898170887C6C8880707F7B677F77687F7766
7B77647B7766776A5F726B5F776E5F766E5F7B71616F695A6763536B5A484C413539322D
2D2D29292C282A2D28252824272B272D2E2B0604038CA09B879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B9687A09B8CA5A0625C51413C333F3C3641423D
4846403837323839343C3930384540424B414F4C4371685C81847487847987887D878879
87887A87887A878A7E8381728382727D80708385737F78647A74617F78647F77647F7B6A
8173637A73637F77627B6E5F766A5B7666586F6A5B6762535F5748473F393A322E282C28
2427232327271F2223171E1F1C212235373518110F879B97879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B967D6F653C3A3241403940413D
3B3B3536312D3A362E3C3D39393F393E3F3839403B655D53818470878974878474878575
8785718785718789798C8E818889788378697F75647F70647F6F647F736A7F77677F6F60
816F607A6F5F7A6F5F7C6E5F766E5E7366566C5F505F5546473F3A3E3A30302E29292C28
2D2C28262828212324222323332F2B637B7983938F879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B968A8C824947433A3B3742403B
443C323C3C35323431383A35323532343E3B31403B48443B6C695A7E8171818470878979
8789788385757E816D8184758985747F74647F78647B725F756F5D756F60796F607B7362
7B6B5C7A6A5F776A5F776E5B736A576F66566C605152473C433B302D2C28242723232727
292B282628281C1E1F1F2222292C2A010000879B97879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B968082724E4C4443433E3A3D39
3D3F3C33313132333033363140413D3C39302F332E303B394E4D446F6458786F627E786A
7E7C6D8385758381707D78698082707B776675685C7B6F5F7A67587A6759746B5C7B6F5F
776A5B726A587362546B5F54636253585244574B3E453F332D2C28282C28252824202222
1D2122171E1F171E1F2F2E2B3B342C120A05879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96B4C4CB665B5543423D3F3F3A
44454148413438312C3D3D393839343E423E3336322836342C3A35343E38564F476D6557
6B645B706C66707065747365787060645F505552466055466D6353726658725F50725F53
776A537366516F62536B5A4C675A4C564C4141372F3A312C302D28252723202223202223
1C1E1F181E1F1F2223242826627B7D77817E879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96A4C2B68282703F3E373A3C37
383A36353B3731323233332D3F3D3741433F4B49433839373A403E36423D363A3340433F
36403C3A41384A49404E50454E4E45514C4149453943473B4E473A594F40645F4A675747
574D44564A3E5E50445751484C433C463A3139302C2E2C282427232022231C1E1F171E1F
171E1F171E1F242A27312F2C0B0F0E869A95879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B969EAAB355504C40413C
3F433E41413C2C2F292D343241433E4445414B4D4751514A4F5146495147414B433E3F38
3D37313536343534313F3C37413F3A383D3C423E39413B323C3B3341413A44463C4A4539
4F4B3E48453842423A493F36433D3435312D3334302629242427232123231C1E1F181E1F
171E1F2B2B272427274C575447433F879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96B1C7C072655E3F3D39
3D3C373D3D3949443E42423E41433F484B4541423D3C3E3A3D3936473B35483B323D3C36
313531343A362D2F2C2D3332393C383538332B2E2B292F2E292D2A2628282B2F2B30342D
2E322C2F2D2A2C2A282C2C2A2D2D2A282C282026222023231F2223202223181E1F171E1F
2B2B2F2B2B29403E38455E5D82938E879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B9692ACA1ADBCB954504A
3D3D3940413D3F3F3A4548433B3B353A3E3A3B3B363B3E3A494C424145403B3F3C3D3D39
3D3C37413F3B3835342E3431302F2B332E2A2D2C28252A26282B272E2F2B302D2B292A27
262926282B272F2F2B2D2C28292B27252723242723212323202223171E1F171E1F1F2223
2D312C37322E6E7A777C8E8A879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96A6B6B56F5A54
45413D40413D3F3F3A2F3531424641474A4446494336393437373137342E343632363833
2D3034293332333331322D2B2C2C30252B28262C28242723252B27242B27242B27232723
1E2222202622262A262427231E2222232623242728212324171E1F2022232A2C28363631
332F2C7B8C887B8C88879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B9698B7AB90968B
4946403E403B3F3F3A46433E3A3F3B393E3A3B3A353435302D322F2D2C28323430303030
32302F2B2A272B2B2E2227281E22222226272327282022242126271F2223212627202224
242728272B28222728202224171E1F151D1F151D1E161E1F2327282428231F2222242421
6D7C7876817E879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96CDEFEA
94928843413A3A3C373A403B3D423D41464144424238322F34332F2B2D29262926272B26
292B262022231D2121232627252828202223222627212324222627212324312E2B1A1F20
202626262A28252828181E1F171E1F1B1E1F24272727292923272733302D473D32675B49
463C2D869A95879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
CDEFEA988D834A4A4438393441423D4446414A4A433C413A383A35332E332427292B2B28
242728292C282A2D282528282022232022231F22222022231F2222272B282026273E454C
414B4D3230362223242628282B2D292B2E292428273738343D393333312C48413B6B7C7E
81918B879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96D3FBF6978A8057524B383934363C38434843524E48433D333C38302D2E29222728
2022232126222327272022232022232327282023242327282023241E2122353F3E333439
4543435C5A4E534C49534E4846413B2D2E2A35353031322F40413C55483E7683807F8985
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96819591CDF5F08676645A544B4745404246414B4D4751544E3E3B353A373245413B
41413A322F2A2A2C28262928252828202223202223262A2E26292A292C281F23232D352E
3036332126262028251F26242025262B2B2830312E3C393052493B828B866D787A879A96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96D3FFFF838271414038363A374A4D49575C565D5D543E3B352D2E2E
332E2B413F3A3E3E38282A2A2022232C3034303338353A353234374242413131353D4242
4342414B464047433E423E3847433C52524747453E5A5448838F8A92A79B859894879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96D3F5F5D2DEE06D69633B3E3A3B3C3946515361656269665C
666B634847453D4344565C636E716D504B474042483E3E435355594446464B463D3B3E3B
4A463F493F3A493D3448433D4F4C425F52445B4638597275819690879A96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B969EBCB0DCFCF889878C51514E414644495A5E5C6565
545B5762685E6869645D5F5454534E535149514E4343424032332D383B3744464140413D
49423957483D5A4E4466574B55453C4D4F51A4B8BB7E8E89879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
87928E879591879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96D3F5E5D7F6F2D4DFD86E737F5D6166
7E818A8281876C655E5C5B55595A546C68656F6762706B60766F676A64575E5E556F6A62
5D6258515A4F454540566266B5D4DAB9DDD381928E879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
87A09B879A96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B9692ACA1D1EDD9B4D5CE
A4C0AFA8C2C8B1CCD4B0BCC4767D8D55636F525B5C5658524E5550595B5751534E44473E
4B4B427A8883DDFCF59BBBAF849692879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B9692AC9B869E9B9EBBABC5E0CEC1DCCAC6E7E4C6E0DBC6E0DCC6E6E1CCEBE6D1F6F6
D0EFEF7F9690879A96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96879B96
879B96879B96879B96879B96
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?oooeV7ViH4RIjF1864M0>7RGP4QhQl18N>P@B7R7`;Qhf118N>
P@B7RGd4RHYh18>5M0B5PFl4OgMW0h5gIQ1jLf<4NW9R0ga^GPAfKU`4MViN17I^G0A]GD/?Qi^F18NL
V0B7UI4SQi^F5Oooo`005?oooeV7ViH4RIjF1864M0>7RGP4QhQl18N>P@B7R7`;Qhf118N>P@B7RGd4
RHYh18>5M0B5PFl4OgMW0h5gIQ1jLf<4NW9R0ga^GPAfKU`4MViN17I^G0A]GD/?Qi^F18NLV0B7UI4S
Qi^F5Oooo`005?oooeV7ViH4RIjF1864M0>7RGP4QhQl18N>P@B7R7`;Qhf118N>P@B7RGd4RHYh18>5
M0B5PFl4OgMW0h5gIQ1jLf<4NW9R0ga^GPAfKU`4MViN17I^G0A]GD/?Qi^F18NLV0B7UI4SQi^F5Ooo
o`005?ooo`B7ViH4QiNC18NET@B7ViH4QiNC0hNETB>7ViH4QiNC18NETAN7ViH4S:>L18J8O0>7RGP4
QhQh18N>P@B7R7`4Qhf118N9N@>3PFh4OX5^17imKPB0NFX4MWAU17IdI0AeKf03MfmP17E_H0QjLf<8
NVmO0ga^HPAfKUl4MViN17InL@A]LfX?Qi^F18NPV`B7VYHSQi^F5Oooo`005?ooo`B7ViH4QiNC18NE
T@B7ViH4QiNC0hNETB>7ViH4QiNC18NETAN7ViH4S:>L18J8O0>7RGP4QhQh18N>P@B7R7`4Qhf118N9
N@>3PFh4OX5^17imKPB0NFX4MWAU17IdI0AeKf03MfmP17E_H0QjLf<8NVmO0ga^HPAfKUl4MViN17In
L@A]LfX?Qi^F18NPV`B7VYHSQi^F5Oooo`005?ooo`B7ViH4QiNC18NET@B7ViH4QiNC0hNETB>7ViH4
QiNC18NETAN7ViH4S:>L18J8O0>7RGP4QhQh18N>P@B7R7`4Qhf118N9N@>3PFh4OX5^17imKPB0NFX4
MWAU17IdI0AeKf03MfmP17E_H0QjLf<8NVmO0ga^HPAfKUl4MViN17InL@A]LfX?Qi^F18NPV`B7VYHS
Qi^F5Oooo`005?ooo`B7ViH4QiNC18NET@B7ViH4QiNC0hNETB>7ViH4QiNC18NETAN7ViH4S:>L18J8
O0>7RGP4QhQh18N>P@B7R7`4Qhf118N9N@>3PFh4OX5^17imKPB0NFX4MWAU17IdI0AeKf03MfmP17E_
H0QjLf<8NVmO0ga^HPAfKUl4MViN17InL@A]LfX?Qi^F18NPV`B7VYHSQi^F5Oooo`005?ooo`B7ViH4
Qj2K18NFTPB7UI44Qj2K0hNJUPB7ViH4QiNC18NET@B7Ui<4QiFA3hNKUPB7X9/4QiZF5hNKUPB3VY<4
PHA`0hN9O@B7Q7P4Qhf118N9O@B7QGT4PhIj0gR1M@A_N6d4NW1U17]/H@AkM6@8NW]Z0gmjJ@AfKUl8
LV]L179_G`AbKU/3MfiL17I^G`AfKV84Q7i_18BGTQ>7ViH4QiNC18NETAn7ViHEoooo000Doooo18NK
UPB7X9/4QiJB18NET@B7X9/3QiZF18NKUPB7Ui<4QiFA18NGT`B7UI4?Qi^F18NPV`B7VYHGQi^F18>J
T`B1Q703QhUm18N4N0B7SH44QhUm18N5N@B3QWX3N85e16mhK@AjL6D4NfaQ17]dI0QjNfX3OgYY17I^
G`QbJe`4LVmO179^F`=gKU`4MViO17I^HPB4OVl4Q9NB4hNKUPB7Ui<4QiFA7hNKUQGoool001Coool4
Qi^F18NPV`B7UY84QiFA18NPV`>7VYH4Qi^F18NGT`B7UI44QiNC18NET@n7ViH4Qj2K18NJUQN7ViH4
PiZC1864L0>7RGd4QhAh18N=P@B7RGd4QhEi18>6NP=hPGD4KgQ]17Y`I@AkK644NgAT27YkJP=oNVT4
MViO279[G0AbKel4LViK0gM^G0AfKUl4MViR18AnK`B4Ui8CQi^F18NGT`B7UI4OQi^F5Oooo`005?oo
o`B7ViH4Qj2K18NFTPB7UI44Qj2K0hNJUPB7ViH4QiNC18NET@B7Ui<4QiFA3hNKUPB7X9/4QiZF5hNK
UPB3VY<4PHA`0hN9O@B7Q7P4Qhf118N9O@B7QGT4PhIj0gR1M@A_N6d4NW1U17]/H@AkM6@8NW]Z0gmj
J@AfKUl8LV]L179_G`AbKU/3MfiL17I^G`AfKV84Q7i_18BGTQ>7ViH4QiNC18NETAn7ViHEoooo000D
oooo28NKUPB7W9P4QiFA2hNKUPB7X9/4QiZF18NPV`B7VYH^Qi^F18bNUPB6Q7P3QhUl18N9O@B7Q7T4
QhUm18N9N@B<SX43WY:518bBQ0B;SGl4Sgme18AcH`B4Kf@4Q6mW0h1[HPAlJel<MViO17I^HP=jLV84
Ng9R17I^G`A]GD/GQi^F18NPV`B7VYHOQi^F5Oooo`005?ooo`R7ViH4QibH18NET@^7ViH4Qj2K18NJ
UPB7X9/4QiZF;XNKUPB<WYH4QXAh0hN9O0B7RGd4QhAi18N9O@B7RGT4S8j10ijBQ@B<TX@4Rheo18mo
M@B4Lf<4Q6mT18A_I`>0Jf84O6]O37I^G`AfKV83NW9R17]bHPAfKUl4KEe;5hNKUPB7X9/4QiZF7hNK
UQGoool001Coool8Qi^F18NLV0B7UI4;Qi^F18NPV`B7VYH4Qj2K18NJURj7ViH4S9jF18J4N0>7RG`4
QhUm18N4N@B7RGd4QhUi18b>P@>NTXD4S9:418^=O`B?OgD4Q7=S18A_I0B4KfL3P6]R17a[G`afKUl4
MViR0gYbHPAkLV84MViO16eMBaN7ViH4Qj2K18NJUQn7ViHEoooo000Doooo28NKUPB7W9P4QiFA2hNK
UPB7X9/4QiZF18NPV`B7VYH^Qi^F18bNUPB6Q7P3QhUl18N9O@B7Q7T4QhUm18N9N@B<SX43WY:518bB
Q0B;SGl4Sgme18AcH`B4Kf@4Q6mW0h1[HPAlJel<MViO17I^HP=jLV84Ng9R17I^G`A]GD/GQi^F18NP
V`B7VYHOQi^F5Oooo`005?ooo`R7ViH4Qj2K18NJUTV7ViH4Qj>L18N8L`>7RG@4QhUh28N9O@B7RH84
Qhf00hNBQ@B<TXX4Pi=l18V8O0B8PgH4R8=_18AjJ`>8Pg84RWAX17mVG`AoLV/4NgIX17Y^G`=jJe`4
O6mO17YfI`AcJ5DnQi^F5Oooo`005?ooo`R7ViH4Qj2K18NJUTV7ViH4Qj>L18N8L`>7RG@4QhUh28N9
O@B7RH84Qhf00hNBQ@B<TXX4Pi=l18V8O0B8PgH4R8=_18AjJ`>8Pg84RWAX17mVG`AoLV/4NgIX17Y^
G`=jJe`4O6mO17YfI`AcJ5DnQi^F5Oooo`005?ooo`R7ViH4Qj2K18NJUTV7ViH4Qj>L18N8L`>7RG@4
QhUh28N9O@B7RH84Qhf00hNBQ@B<TXX4Pi=l18V8O0B8PgH4R8=_18AjJ`>8Pg84RWAX17mVG`AoLV/4
NgIX17Y^G`=jJe`4O6mO17YfI`AcJ5DnQi^F5Oooo`005?ooo`R7ViH4Qj2K18NJUTV7ViH4Qj>L18N8
L`>7RG@4QhUh28N9O@B7RH84Qhf00hNBQ@B<TXX4Pi=l18V8O0B8PgH4R8=_18AjJ`>8Pg84RWAX17mV
G`AoLV/4NgIX17Y^G`=jJe`4O6mO17YfI`AcJ5DnQi^F5Oooo`005?oooeV7ViH4QinH18N9N0>7RG`8
QhUh18N9O@B7SH44QhUm0hN5N@B7SH44S9::18bGQ0B8SG/4Ph1c18R4L`=oMfL4QH1^181jJ@AjJUT4
OgM/17IfJ0=bKUl4MfiO17alM@AoOgHKQi^F18NGT`B7UI4KQi^F5Oooo`005?oooeV7ViH4QinH18N9
N0>7RG`8QhUh18N9O@B7SH44QhUm0hN5N@B7SH44S9::18bGQ0B8SG/4Ph1c18R4L`=oMfL4QH1^181j
J@AjJUT4OgM/17IfJ0=bKUl4MfiO17alM@AoOgHKQi^F18NGT`B7UI4KQi^F5Oooo`005?oooeV7ViH4
QinH18N9N0>7RG`8QhUh18N9O@B7SH44QhUm0hN5N@B7SH44S9::18bGQ0B8SG/4Ph1c18R4L`=oMfL4
QH1^181jJ@AjJUT4OgM/17IfJ0=bKUl4MfiO17alM@AoOgHKQi^F18NGT`B7UI4KQi^F5Oooo`005?oo
oeF7ViH4O7]`17EhL0B7RG`3QhUh18N9N@B7RGP4Qhf118N9O@B7SH43Qi:518N=P@B7SX44QhV218b>
P0B<RW@7R81`18AkJ`B5LfH4P79R17MWEPAgKf03NViO17]^G`A`KV44PHf96hNKUPB7X9/4QiZF1hNK
UPB7Ui<4Qi:>18NET@R7ViHEoooo000DooooEHNKUPAlNg04MGQ`18N9O0>7RGP4QhUi18N9N0B7SH44
QhUm18N=P@>7TXD4Qhf118N>P@B7RH84S8j018b:M0N8P704Q7][18EcIPB0LV84MfMF17M_H0=jKUl4
NfiO171^H@B1SHTKQi^F18NPV`B7VYH7Qi^F18NGT`B7TXh4QiFA28NKUQGoool001CooomEQi^F17ak
L0AeN704QhUl0hN9N0B7RGT4QhUh18N=P@B7RGd4Qhf10hNBQ@B7SH44Qhj118N9PPB<SX04S8Yd1hR0
L0B4Nf/4QG=V181bHPAgIeH4MfmP0gY^G`AkKUl4L6iQ186=RA^7ViH4Qj2K18NJUPN7ViH4QiNC18NB
SPB7UI48Qi^F5Oooo`005?oooeF7ViH4O7]`17EhL0B7RG`3QhUh18N9N@B7RGP4Qhf118N9O@B7SH43
Qi:518N=P@B7SX44QhV218b>P0B<RW@7R81`18AkJ`B5LfH4P79R17MWEPAgKf03NViO17]^G`A`KV44
PHf96hNKUPB7X9/4QiZF1hNKUPB7Ui<4Qi:>18NET@R7ViHEoooo000DooooDHNKUPAEF4h4Bf9I17n2
L`B7RGP3QhV218N9P@B7RG`4QhQl18N>P@B7Q7D3QhQh28N9O@B7RGT4Qhim18>5N0B3O703PgQ/18El
I`AkLV04Ng=S17mbHPAkKUl3MGIW17mjJ@AhKEX4QYZE:XNKUPR7X9/4QiZF28NKUQGoool001CooomA
Qi^F15EHCPA;HUT4Oh9c18N9N0>7RH84QhV118N9O0B7R7`4Qhj118N4M@>7R7P8QhUm18N9N@B7SWd4
PhEh18=lL0>3N6`4QGaW17]bH0AkLf<4Og9R17]^G`=eMVL4OgYY17Q]FPB6VYDZQi^F28NPV`B7VYH8
Qi^F5Oooo`005?oooe67ViH4EEQ>14]RF@AoPW<4QhUh0hN9PPB7RH44QhUl18N8O0B7SX44QhAe0hN8
N0R7RGd4QhUi18N>O@B3QGP4Pga`0h=hK0B5O6L4Ng9P17]cH`AoLV84NfiO0gEfI`AoNVT4N6eJ18JJ
UBZ7ViH8Qj2K18NJUPR7ViHEoooo000DooooDHNKUPAEF4h4Bf9I17n2L`B7RGP3QhV218N9P@B7RG`4
QhQl18N>P@B7Q7D3QhQh28N9O@B7RGT4Qhim18>5N0B3O703PgQ/18ElI`AkLV04Ng=S17mbHPAkKUl3
MGIW17mjJ@AhKEX4QYZE:XNKUPR7X9/4QiZF28NKUQGoool001Coool8Qi^F18NGT`B7UI4mQi^F17R3
P`A??ST45RH`18J8O0B7SG/3Qhj118N=P@B7SX44QhAi18N=P@B7TXX3QhUl18N9N@B7OG44Pg1Z17Y/
G`AnNFH4Pg]/0gn0K0AkMfX4OgMV181bH`AgLUh4MfiL0g5WF@AbK5d4KUe;@XNKUQGoool001Coool8
Qi^F18NGT`B7UI4mQi^F17R3P`A??ST45RH`18J8O0B7SG/3Qhj118N=P@B7SX44QhAi18N=P@B7TXX3
QhUl18N9N@B7OG44Pg1Z17Y/G`AnNFH4Pg]/0gn0K0AkMfX4OgMV181bH`AgLUh4MfiL0g5WF@AbK5d4
KUe;@XNKUQGoool001Coool8Qi^F18NGT`B7UI4mQi^F17R3P`A??ST45RH`18J8O0B7SG/3Qhj118N=
P@B7SX44QhAi18N=P@B7TXX3QhUl18N9N@B7OG44Pg1Z17Y/G`AnNFH4Pg]/0gn0K0AkMfX4OgMV181b
H`AgLUh4MfiL0g5WF@AbK5d4KUe;@XNKUQGoool001Coool8Qi^F18NGT`B7UI4mQi^F17R3P`A??ST4
5RH`18J8O0B7SG/3Qhj118N=P@B7SX44QhAi18N=P@B7TXX3QhUl18N9N@B7OG44Pg1Z17Y/G`AnNFH4
Pg]/0gn0K0AkMfX4OgMV181bH`AgLUh4MfiL0g5WF@AbK5d4KUe;@XNKUQGoool001Coool8Qi^F18NP
V`B7UY84QiFA=HNKUPB:WYX4C4Li18N>N@AfNFP4QhUm18N4N0>7RGd4QhAi28N9O@B7Q7T4QhQm0hN>
P@B3QGT4OXIa18=kL0B5O6/4NG=T17YdI0=oM604PGMT17A_G`AkJe`4OfmR17m^G`=kKUl4NW9S171J
B@B1Q7`nQi^F5Oooo`005?ooo`R7ViH4Qj2K18NFTPB7UI4eQi^F18ZNVPA<AcT4Qhii17IiJ0B7RGd4
QhAh0hN9O@B7Q7T8QhUm18N4N@B7R7d3Qhj118>5N@AnQW44Pg]`18ElJ`AiLf@4NWAT0gmdH0B1Mf@4
M6mO17][G0AoKf84OfiO0g]^G`AjLV<4L5Y91864O3j7ViHEoooo000Doooo28NKUPB7X9/4QiJB18NE
TCF7ViH4RYjJ14a7>@B7SWT4MWUX18N9O@B7Q7P3QhUm18N4N@R7RGd4QhAi18N8O@>7SX44PhEi17j6
L@B3Ng04QGa[17UcI0AjM6@3OgAP185gI0AdKel4Nf]L17m_HPAoKUl3NfiO17YbH`A`FTT4PHAl?XNK
UQGoool001Coool8Qi^F18NPV`B7UY84QiFA=HNKUPB:WYX4C4Li18N>N@AfNFP4QhUm18N4N0>7RGd4
QhAi28N9O@B7Q7T4QhQm0hN>P@B3QGT4OXIa18=kL0B5O6/4NG=T17YdI0=oM604PGMT17A_G`AkJe`4
OfmR17m^G`=kKUl4NW9S171JB@B1Q7`nQi^F5Oooo`005?ooo`R7ViH4QiNC18NKUPB7VYHeQi^F13hk
<PB7Sh@4PXV118J8O0B7RGP7QhUm18N9N@B7RGP4QhUm18N=P@N7RGd4RFaW18=GE@AoD508Ode=17mL
E`=kK604NfaL17YZF`AgJUP4MFiL17Y^G`=lKU/4MFMF16aDA@A_H4lZQi^F18NGT`B7UI4<Qi^F5Ooo
o`005?ooo`R7ViH4QiNC18NKUPB7VYHeQi^F13hk<PB7Sh@4PXV118J8O0B7RGP7QhUm18N9N@B7RGP4
QhUm18N=P@N7RGd4RFaW18=GE@AoD508Ode=17mLE`=kK604NfaL17YZF`AgJUP4MFiL17Y^G`=lKU/4
MFMF16aDA@A_H4lZQi^F18NGT`B7UI4<Qi^F5Oooo`005?ooo`R7ViH4QiNC18NKUPB7VYHeQi^F13hk
<PB7Sh@4PXV118J8O0B7RGP7QhUm18N9N@B7RGP4QhUm18N=P@N7RGd4RFaW18=GE@AoD508Ode=17mL
E`=kK604NfaL17YZF`AgJUP4MFiL17Y^G`=lKU/4MFMF16aDA@A_H4lZQi^F18NGT`B7UI4<Qi^F5Ooo
o`005?ooo`R7ViH4QiNC18NKUPB7VYHeQi^F13hk<PB7Sh@4PXV118J8O0B7RGP7QhUm18N9N@B7RGP4
QhUm18N=P@N7RGd4RFaW18=GE@AoD508Ode=17mLE`=kK604NfaL17YZF`AgJUP4MFiL17Y^G`=lKU/4
MFMF16aDA@A_H4lZQi^F18NGT`B7UI4<Qi^F5Oooo`005?ooo`R7ViH4Qj2K18NJUSJ7ViH3N8>01=;I
d`AgNWD8QhUm18N9N0B7RGd3QhEe18N1L@B7PFd4QhAd18N4N@B7OGD3Qg1]18UiL0AoGE<4Ne1517UD
C0AkF4h4NDY90geFDPAbGeD4LViK17MZF`AeJU`4NViO0gm^HPAjKUh4OfiO16Y??@AeJ5LVQi^F18NP
V`B7VYH<Qi^F5Oooo`005?ooo`R7ViH4Qj2K18NJUSJ7ViH3N8>01=;Id`AgNWD8QhUm18N9N0B7RGd3
QhEe18N1L@B7PFd4QhAd18N4N@B7OGD3Qg1]18UiL0AoGE<4Ne1517UDC0AkF4h4NDY90geFDPAbGeD4
LViK17MZF`AeJU`4NViO0gm^HPAjKUh4OfiO16Y??@AeJ5LVQi^F18NPV`B7VYH<Qi^F5Oooo`005?oo
o`R7ViH4Qj2K18NJUSJ7ViH3N8>01=;Id`AgNWD8QhUm18N9N0B7RGd3QhEe18N1L@B7PFd4QhAd18N4
N@B7OGD3Qg1]18UiL0AoGE<4Ne1517UDC0AkF4h4NDY90geFDPAbGeD4LViK17MZF`AeJU`4NViO0gm^
HPAjKUh4OfiO16Y??@AeJ5LVQi^F18NPV`B7VYH<Qi^F5Oooo`005?ooodJ7ViH3ADHn11/`;`B1Q744
QhUd18N9N@B7RGP4QhUi0h>6M@AnN6T4PGi`18N8M`B7PG44PfaN0gY@B0AgI5P4JeQ816]dHPAhQg84
OEU<16a3>@=kBT<4NeA>17ISF`AfKUD4LFYB17E^G0=jKUl4NW=R17YZG0AjKf04Lem<18N@QSJ7ViHE
oooo000DooooAXNKUP=5ASh46c0_1864L@B7RG@4QhUi18N9N0B7RGT3PhIe17ihJ@B1OW04QhQg18N1
L@B3K5h3NU1817MTF0A[F4P4JgAR17R7LPAmFD`4K4<i0g]:@`AkE4h4MV=K17I^E@AaJU84MFiL0gY^
G`AjLf84NVYL17Y_H0AcGd`4Qi26=XNKUQGoool001Cooom6Qi^F0dE6?P@K<2l4PHAa18N9M0B7RGT4
QhUh18N9N@>3QWD4OWQY185nL0B7R7L4Qh5a18=/GP=jD4P4MfAH16]HB0A[M684N8Mb17eIC0A/@cT3
NdY317]DCPAfHe/4MViE175ZDPAeKU`3NViO17YcHPAjJU`4NVmP17=OC0B7T8HfQi^F5Oooo`005?oo
odJ7ViH3ADHn11/`;`B1Q744QhUd18N9N@B7RGP4QhUi0h>6M@AnN6T4PGi`18N8M`B7PG44PfaN0gY@
B0AgI5P4JeQ816]dHPAhQg84OEU<16a3>@=kBT<4NeA>17ISF`AfKUD4LFYB17E^G0=jKUl4NW=R17YZ
G0AjKf04Lem<18N@QSJ7ViHEoooo000Doooo48NKUPB7Ui<3QiFA:hNKUPAYKV/3YIF115mRF@B6R7`4
Ph5e1863N0B7SX44Qh5e0hEiI@AfJ5L4M5eI181GD`A;9R44>D4i0gmfJ@B8L6H4X[bd18eXG`AcCdD4
J6eD165aG`=EDT84FD0g17=:A0AaIeD4NVID17Y^G`=nNVH4P7IR17YbH`AjKUl4JU=417ESD@B7T8Hb
Qi^F5Oooo`005?oooa27ViH4QiNC0hNETB^7ViH4JFi[0jFEP@AOHUT4QXQl18>1M@B1PgP4Qhj118N1
M@>5NFD4MVQG17AMF@B0Ee<4BbHQ13U1>@=oMVT4R71V1::l]0B=J5l4Ldm516Q]E0AQLEl3EE9215U0
=`AcBT@4LFME17YVE0AjKUl3OWYV181fHPAjLV<4NViO16YCA0AeHe44Qi26<XNKUQGoool001Coool@
Qi^F18NGT`>7UI4[Qi^F16U^J`>UUH44Gf9I18J8O0B3PGD4PH=h18N>P@B7PGD3QGUU17IXE`AdGET4
P5MC14/V8@@i@CT3OgIY18Q`IPBR_;@4SFQO17=?A@AXKE@4HG5O0eEB@PAI@3L4LdY4175WE@AjIU@4
NViO0gijIPB0MV84NW9S17Y^G`AZDd@4MF=A18N@QS:7ViHEoooo000Doooo48NKUPB7Ui<3QiFA:hNK
UPAYKV/3YIF115mRF@B6R7`4Ph5e1863N0B7SX44Qh5e0hEiI@AfJ5L4M5eI181GD`A;9R44>D4i0gmf
J@B8L6H4X[bd18eXG`AcCdD4J6eD165aG`=EDT84FD0g17=:A0AaIeD4NVID17Y^G`=nNVH4P7IR17Yb
H`AjKUl4JU=417ESD@B7T8HbQi^F5Oooo`005?ooo`R7ViH4QiNC18NET@B7X9/3QiZF:hNKUPACE4`3
>e=D17j0M@B7RGP4RHEd185dI`B7RGd4QhYl0hI^F`AgH4h4AbLS141>C0C0kn84RZZS0i78a0B;/K@4
QXn;18k3[0BM]:P4Z;jm18F@R0=UFTl4<3P[13/g<0A/Edl4MFeJ17i]H0=nMfX4QGmY181bG`AjKel4
NVmP16YTG0AbOH@3PI2<;hNKUQGoool001Coool8Qi^F18NGT`B7UI44Qj2K0hNJUR^7ViH4DeA<0c]C
E0AnP7D4QhUh18V5M0B1M6L4QhUm18N:O0>6KU/4Mf1>14LW8`A0CT`4`>oR18ZZX`>Ab<@4Rk6d18J?
R`B>`j`4WKBX1:Rn_@B5T8P3IEY?130h:`@k=c04K5M?17E]FPAnKF03OWMZ18EoJ@B0LUl4NVmO17Y_
H0AZI5`4LWf40h6@S2n7ViHEoooo000Doooo28NKUPB7Ui<4QiFA18NPV`>7VYH[Qi^F15=DC0<kDe@4
OX1e18N9N0B9QG@4PGAW18N9O@B7RW`3QViK17MPCPA79b<4@4i<1<3_hPB:ZZ<3TLS418^a]0B6Sh/4
S/>/19fdZ0BX_[d4QI280fEJC`@`>2/4>cL`16aGC`AeKEX4OVeP0gigJPB5OfT4P79O17Y_G`AjKf04
JVAL179mQ0>1T8`_Qi^F5Oooo`005?ooo`R7ViH4QiNC18NET@B7X9/3QiZF:hNKUPACE4`3>e=D17j0
M@B7RGP4RHEd185dI`B7RGd4QhYl0hI^F`AgH4h4AbLS141>C0C0kn84RZZS0i78a0B;/K@4QXn;18k3
[0BM]:P4Z;jm18F@R0=UFTl4<3P[13/g<0A/Edl4MFeJ17i]H0=nMfX4QGmY181bG`AjKel4NVmP16YT
G0AbOH@3PI2<;hNKUQGoool001Coool8Qi^F18NPV`B7VYH^Qi^F17b;S`AEAT033R<]1864L0B7RGT4
S9R418J7M`B7RGd4P7QZ0gIZDPASB3L4Hc8V148P7`AfDDL4OVEF0h5]G`B7RgL4Qh1Z18EjK@AhIUd4
P7IV19j9M@>bYhd4WI601492=`@f<Rl4IeE:17=YF@>2Of`4Q81a185kJ@AjKEh4NVMI17MTB0ATK5l3
HFQW17F4S2^7ViHEoooo000Doooo28NKUPB7X9/4QiZF;XNKUPAlRhl4EDI00`hS;@B1Q704QhUi18bH
Q0B6QgL4QhUm181hJP=fJU84HdPg16<b9PA281l4MU5717iUEP>1KEl4Qh]g18N0JPB5NVd4N6IM181f
IPBNRGD3/ZN=19fAP0A2@SL4=S8_16MEBPAcJET3PWm/18B0L@B1NfT4NVeN17YWF@AgI4P4I6aO0f5X
I`AeQ8`[Qi^F5Oooo`005?ooo`R7ViH4Qj2K18NJURj7ViH4O8^?15E6@0<>8bd4PHA`18N9N@B<V8@4
QXMg18N9O@B0N6X3MVYB16=8=`AS<RH4@R0O17IAA`AnIEH3PFeO18N;M`B7P6X4QGY]17QVG@B0MVH4
WXUe0k:WS@BMTH04@T8g13Hb;`AWEDX4LfUI0h9oK0B4P744PG]Y17Y]GPAjIeT4MfA816A/G`=QJ6L4
MHB<:hNKUQGoool001Coool8Qi^F18NPV`B7VYH^Qi^F17b;S`AEAT033R<]1864L0B7RGT4S9R418J7
M`B7RGd4P7QZ0gIZDPASB3L4Hc8V148P7`AfDDL4OVEF0h5]G`B7RgL4Qh1Z18EjK@AhIUd4P7IV19j9
M@>bYhd4WI601492=`@f<Rl4IeE:17=YF@>2Of`4Q81a185kJ@AjKEh4NVMI17MTB0ATK5l3HFQW17F4
S2^7ViHEoooo000Doooo>XNKUPAEF4h49BDP171XG`=NG5P4QXQh18N1L@B7N6X4Qgm/18N9M0B:Qg<3
UH=g19fdVPC>h[h4RYF718QeL@AoM6P3MEQ=17QHEPAgD4l4MUE<170f<0Ab@Sh4ITDo0geZF@B1G5<4
T79V13`Y80@h<304LV5I0gefI0B5PF/4PG=P17McHPAeLV84OfYI192>O`>5SHP4KWN0:hNKUQGoool0
01CoooljQi^F15EHCP@U9B04L6QO0eiLF0B6R7P4Qh5a18MhJPB7Of`4QhUd18Z7L`>EPgL4WKBJ1<kR
_PB:UHL4R7Ea17mdJ0=eF4d4N5QF17M@C`AfED`4L3H`1792?PAVACl3OFYI185LD`B@LVH4?2TP13P`
<0AbHET3OGIT18F1J`B1Lf04Mg=R17EbHPAoJUT4T8io0hF=R0A^Mh0[Qi^F5Oooo`005?ooocZ7ViH4
EEQ>12DU80A`J5l3GUaH18J8N0B7PG44QgQZ18MoK0B7RG@4RXMc0iF3M`BM]9X4c^:n18ZEQ`B8MG44
OgAX0gEHC@AhF5H4Me1?17IEC0A`=S04LT8n16I5?`=mJUT4PEaC191bIP@l:B04>30`179QF@=mMV@4
QH5[185cH0AgLf84MG9R17mZF@B@SWl3QHf816igP2^7ViHEoooo000Doooo58NKUP>7Ui<4QiFA6hNK
UPAlQhL4<S8/12L[9`@N?d83PhEj18N5M@B7PGP4Pgmg1863M0B7OGD4RX1d0gAOC@A^H5D4QXb418NL
R@B<Vhd4TZBE0i6SU0B;[I<4U9N018fLP`B9WGh4RHmc17mTE`>3I5d4QU981855>@Ak?S84@2TU150i
>`=gJUd4QGa[185gHPAlJU/4MFMI17Y[G@A0<RP3@DDa186;R0B1T8`WQi^F5Oooo`005?oooaB7ViH3
QiNC18NETA^7ViH4O8N7138b;0@W:bL47Sm20h>5NPB7QGD4Qh5h18=oM`B1Pg@4Qgee18Z0M0=dGdd4
KV1E18J<Q0B7W8T4S9^=19:TU@>AXi@4RjfC19BGP0B=W8<4RIen18V?L`AoI5L3PfAM18IBB0B1ACT4
Nchb140Y9@A@>C/3MfYM18ElJ`B1Mf84O6YK17EWF@AjJed4@38X0d55<@B1RhP4PI2<9hNKUQGoool0
01CooolDQi^F0hNGT`B7UI4KQi^F17b7Q`@b<R`49b/W11ho@P>3QGX4QhEe18N1N0B3OgL4PH=d18Mm
M@B:P7@3M5m=16iPE@B6S8@4Qib918bKS@BBY9D3TJ>D18^]T`BDUh04SIb318VMOPB9Sg<4OfAG0h=T
G@B6DTP4PDDi17/n<PA0:BD4D3Tk0gMZG@B5O6/4PGMR17aZF`AeIeT4NV]M140b:0=1AC44PH^8186@
S2N7ViHEoooo000Doooo58NKUP>7Ui<4QiFA6hNKUPAlQhL4<S8/12L[9`@N?d83PhEj18N5M@B7PGP4
Pgmg1863M0B7OGD4RX1d0gAOC@A^H5D4QXb418NLR@B<Vhd4TZBE0i6SU0B;[I<4U9N018fLP`B9WGh4
RHmc17mTE`>3I5d4QU981855>@Ak?S84@2TU150i>`=gJUd4QGa[185gHPAlJU/4MFMI17Y[G@A0<RP3
@DDa186;R0B1T8`WQi^F5Oooo`005?oooaB7ViH3Qj2K18NJUQ^7ViH4S:>S1?ocg`CbcJP4LVaM0h64
M@B7RWP4Qi9h18b0N0B6NW@4QiQl18Z<N@>;O6`4Kee?185kK0B7SH44Qhj118N4N@>7SH44Qh5m18Um
M0B3Nf`4QGa^17mgIPAmMf43K7QN17MoIPB6R704V95g18b0M0AYFdh3KVIB17mhI`B1Mf84O7=N17E^
G0AjKf04LVQL0b@/:@AeQ7/4QYZE9hNKUQGoool001CooolDQi^F0hNPV`B7VYHKQi^F18bSX`Colml4
l/fX179/G@>1Q7D4QhYh18NBN0B<P7P4QWYd18NHO0B:S7T3Rga/16mMC`B1Nf`4Qhf118N>P@B7Q7T3
Qhf118N1O@B9OG@4Pg]/18ElKPAoMfH4OGMQ0fahGPAgOfH4QXQ`19RAM`B<P7@4JE]>0fiVDPAoN6L4
PGMR17acGPAeKU`4NVmP179XG0<T;2T4MHAk18JJUBN7ViHEoooo000Doooo58NKUP>7X9/4QiZF6hNK
UPB<Xj<4oo?O1?;=Z0AbK5d3PHAe18N:N0B7TWP4S81h18IjM0B7V7`4RXai0h]lK0A_GDl4PG]/18N=
P@B7SX44QhAi0hN=P@B7PGd4RGed18=kK0B5O6h4OgMV17egH@=/N5h4MgmV18J8L0BHTGL4S81d16UK
CP=^IU84OgQW185gHPAlLeh4MFiL17Y_H0AbJ5`392`Y17F4N`B6VYDWQi^F5Oooo`005?oooaB7ViH3
Qj2K18NJUQ^7ViH4S:>S1?ocg`CbcJP4LVaM0h64M@B7RWP4Qi9h18b0N0B6NW@4QiQl18Z<N@>;O6`4
Kee?185kK0B7SH44Qhj118N4N@>7SH44Qh5m18UmM0B3Nf`4QGa^17mgIPAmMf43K7QN17MoIPB6R704
V95g18b0M0AYFdh3KVIB17mhI`B1Mf84O7=N17E^G0AjKf04LVQL0b@/:@AeQ7/4QYZE9hNKUQGoool0
01CooolfQi^F19ROP`B5RGl4S9bB18R=O`=mP704PHUh18N8O0B7V8D4Qh^418N>Q@B>Th@3RXMc17EO
DPAbHeD4PH=c18NBQ@B7SX43QhQl18NMQ@B9R7L4Og1P17m`GPAgLe`4L6YK0fUVD`A^Fdh8KUm>17=V
CPAdKF83N79R17mcIPAmKUh4MfIK175ZF0AbJeT4CD4h0b0_<PAiQXd[Qi^F5Oooo`005?ooocJ7ViH4
V9n318F9O`B<W984R8eo0gf0L0B1RGP4QhQl18NHQ@B7Rh@4Qhj518jCQ0>:Qg<4MEmB179SE@B1Pg<4
Qi:518N>P@>7R7`4Qif518V8M`AoL604Og1N17McG0A`JU/3JFIC16iKCPQ^Gdh4LfI>17A]HP=hLV84
Og=V17e^GPAgIU/4LFYH179[F@A=@CP382lb17V6SB^7ViHEoooo000Doooo=XNKUPBHWh<4QHUo18bL
TPB8SGl3OH1`1869N0B7R7`4QiR518N;Q0B7SXD4SY>40hZ7L`AeGe84LV=E1863L`B7TXD4Qhj10hN8
O0B7WHD4RHQg17m`H0AoL5h4Mg=L171ZF`=YIU<4KU]>26iOCPAcITh4M6eR0gQbHPAoLfH4OFiN17MV
F`AaJUP4LV]I14e1>0<P;c84NHJ=:hNKUQGoool001CooolfQi^F19ROP`B5RGl4S9bB18R=O`=mP704
PHUh18N8O0B7V8D4Qh^418N>Q@B>Th@3RXMc17EODPAbHeD4PH=c18NBQ@B7SX43QhQl18NMQ@B9R7L4
Og1P17m`GPAgLe`4L6YK0fUVD`A^Fdh8KUm>17=VCPAdKF83N79R17mcIPAmKUh4MfIK175ZF0AbJeT4
CD4h0b0_<PAiQXd[Qi^F5Oooo`005?oooc:7ViH4Pi>?186ET0B3PFd4NVeI17=dK@=dP7`4QXAh18N=
P0B7TXD4Qhf118NBQ@B<RH@3SXAj18YnJ`AlI5T4PGEW18N8O@B7PGT3Pg9Y1865M@B5QG84Og]Z17MO
D`AgI5T4O6EE0g9RD`AbJEH4MVUD17M/DPAbHDh4LV9B0gi_H0AkKf04O6iN17IZF`AfJUl4NW9R13Tc
<@<04@d4JG5/:hNKUQGoool001CooolbQi^F18>CS`B1UI04Ph5]17Y]F@AcM6d3M81l18J4N0B7SH04
Qi:518N=P@B7TXD4S8V40hj4NPB:OV/4O6AI185eI`B7R7d4Qh5i0h=bJ@B1QGD4QHEb17mkJPAgGe<4
MfAI17aUE@=bHU<4LVUF17IYE0AgK584LV5>179RDP=nKf04NfmP17a^GPAfJU/4MVYO17YbHP@i<c43
014=16UaK2^7ViHEoooo000Doooo<XNKUPB3Thl4PIF@18>1K@AjKET4LgA]0gB0O0B6Q7P4Qhf018NB
Q@B7SH44Qi:518b9Q0>>Q7X4RWi[17aTF@B1MFL4QhQm18N1N@>3LVT4PHEe18F5LPAoNfX4MemC17MT
F@AlIED3LV9C179YEPAfJE@4MfaB179QCPAbHU83OVmP17]_H0AlKUh4MVYK17IZG`AjLV84>C<a0`0A
3@AYLF`[Qi^F5Oooo`005?oooc:7ViH4Pi>?186ET0B3PFd4NVeI17=dK@=dP7`4QXAh18N=P0B7TXD4
Qhf118NBQ@B<RH@3SXAj18YnJ`AlI5T4PGEW18N8O@B7PGT3Pg9Y1865M@B5QG84Og]Z17MOD`AgI5T4
O6EE0g9RD`AbJEH4MVUD17M/DPAbHDh4LV9B0gi_H0AkKf04O6iN17IZF`AfJUl4NW9R13Tc<@<04@d4
JG5/:hNKUQGoool001CooolbQi^F18bDP`B6RWl4QH5c17]dI`B8ME/3Ogae18MjL`B7R7`<Qhf118NM
Q@><SG/4RXQ`17U[F@AkJUd4QhQl18NMRP><S8D4QXR118j>Q0B4Og44QX5^17m]GPAlK5X3LUiB179R
D`AaIUd4OfeP18QiJ`AmMFD3Ng9R17]_G`AoLf84NfeN17IZF0AaJeT4CS`b0a<N7`@K8Al4QiFA9hNK
UQGoool001CooolbQi^F18bDP`B6RWl4QH5c17]dI`B8ME/3Ogae18MjL`B7R7`<Qhf118NMQ@><SG/4
RXQ`17U[F@AkJUd4QhQl18NMRP><S8D4QXR118j>Q0B4Og44QX5^17m]GPAlK5X3LUiB179RD`AaIUd4
OfeP18QiJ`AmMFD3Ng9R17]_G`AoLf84NfeN17IZF0AaJeT4CS`b0a<N7`@K8Al4QiFA9hNKUQGoool0
01CooolbQi^F18bDP`B6RWl4QH5c17]dI`B8ME/3Ogae18MjL`B7R7`<Qhf118NMQ@><SG/4RXQ`17U[
F@AkJUd4QhQl18NMRP><S8D4QXR118j>Q0B4Og44QX5^17m]GPAlK5X3LUiB179RD`AaIUd4OfeP18Qi
J`AmMFD3Ng9R17]_G`AoLf84NfeN17IZF0AaJeT4CS`b0a<N7`@K8Al4QiFA9hNKUQGoool001Cooolb
Qi^F18bDP`B6RWl4QH5c17]dI`B8ME/3Ogae18MjL`B7R7`<Qhf118NMQ@><SG/4RXQ`17U[F@AkJUd4
QhQl18NMRP><S8D4QXR118j>Q0B4Og44QX5^17m]GPAlK5X3LUiB179RD`AaIUd4OfeP18QiJ`AmMFD3
Ng9R17]_G`AoLf84NfeN17IZF0AaJeT4CS`b0a<N7`@K8Al4QiFA9hNKUQGoool001CooolbQi^F18NO
V0B3QG04NFiH17M`H0B5NW83QXQh18N7M`B7R7`4Qi6818NCRPB7SH44Qhj60hNBQ@B:R7P4OgmY17M_
F`B1Og04QhUi0hN=O0B7SX44RHml181gIPAkKf04MfiO17aeI0=kL5L4MfA@175RE@AhLVH4PWU^18Ak
J`>1Ofh4NWYY17MbHPAgLf84MViR17YfIPC8V6X3L4Xh11`L6P@N928WQi^F5Oooo`005?oooc:7ViH4
QinH18>5L0AiKUP4Mg1P18EjLP>6R7P4QhMg18N8O0B7THP4Qi>:18N=P@B7SXH3Qi:518Z8N0AoOfT4
MfmK185oL0B7RGT3Qhel18N>P@B9Sg`4P7MV17]_H0AgKUl4O7ET0g]`E`AgI504LF9E17QbIPB2NFh4
Q7][0h5oKPAjNVT4Mg9R17McHPAfKV84NWIV1<RHJP=`BSP471`J11hT8RN7ViHEoooo000Doooo<XNK
UPB7WiP4PhE`17U^F0AgL604QGYb0hJ8N0B7QgL4QhQl18NAR0B7ThX4Qhf118N>QP>7TXD4RXQh17mo
J@AgKe/4PGm`18N9N@>7SG`4Qhj118V?O0B0MfH4NfmP17M^G`AlMF@3Ng1G17MTD0AaHUD4N79V189i
KPB4Nf/3PGm^17YjJ@AgLV84Mg=R17I^HPAjMVH4b9QZ0g1:>0@L71X47R@R9hNKUQGoool001Coool^
Qi^F18N;P0B0LfH4LdY217eQFPAVHET4Khih0hN7N0B7RGP4QhQl18N8N@B7SX84Qhf118N>P@>3QGT4
RHml18R=O`B6QgH4QXQc18=mL@>1MFP4Qgea18EdJ0B1LUl4MfIH17=RE0AaIe03Jei?16UOD0AdJE/4
N7IS17efJ0B5O6/3PG=S17Y_H0AoKel4NfiK17YZF0AjJUd4QGa_0jR<L`C@aK<4O8j:9hNKUQGoool0
01Coool^Qi^F18N;P0B0LfH4LdY217eQFPAVHET4Khih0hN7N0B7RGP4QhQl18N8N@B7SX84Qhf118N>
P@>3QGT4RHml18R=O`B6QgH4QXQc18=mL@>1MFP4Qgea18EdJ0B1LUl4MfIH17=RE0AaIe03Jei?16UO
D0AdJE/4N7IS17efJ0B5O6/3PG=S17Y_H0AoKel4NfiK17YZF0AjJUd4QGa_0jR<L`C@aK<4O8j:9hNK
UQGoool001Coool^Qi^F18N;P0B0LfH4LdY217eQFPAVHET4Khih0hN7N0B7RGP4QhQl18N8N@B7SX84
Qhf118N>P@>3QGT4RHml18R=O`B6QgH4QXQc18=mL@>1MFP4Qgea18EdJ0B1LUl4MfIH17=RE0AaIe03
Jei?16UOD0AdJE/4N7IS17efJ0B5O6/3PG=S17Y_H0AoKel4NfiK17YZF0AjJUd4QGa_0jR<L`C@aK<4
O8j:9hNKUQGoool001Coool^Qi^F18N;P0B0LfH4LdY217eQFPAVHET4Khih0hN7N0B7RGP4QhQl18N8
N@B7SX84Qhf118N>P@>3QGT4RHml18R=O`B6QgH4QXQc18=mL@>1MFP4Qgea18EdJ0B1LUl4MfIH17=R
E0AaIe03Jei?16UOD0AdJE/4N7IS17efJ0B5O6/3PG=S17Y_H0AoKel4NfiK17YZF0AjJUd4QGa_0jR<
L`C@aK<4O8j:9hNKUQGoool001Coool^Qi^F18N@SPB:LV/4PVEH17IME0B1Kel4Oh=h0hN=Q@B7SX44
QhQl28N=P@B7RGd4QhUi0hV:N@B6QG@4R81`1864N0B7SHD4S9b=0hJ7P0B7SgP4RX1b17efI0AcIUH4
Kf9C16IKDP=hJEP4N7AT17eeI@AnNV/4OG][18ElJ`>1MfH4NW9R17YZG`AoIV84MVYN17EYH0AhK5P3
LF=B171GAPB<X9/WQi^F5Oooo`005?ooobj7ViH4Qi2>18YbJ`B2IEP4MUeD185_G`AoPgP3Qhf518N>
P@B7R7`8Qhf118N9O@B7RGT3RHYi18J5M0B8P704PHAh18N=Q@B<W8d3QXN018N?N0B:P784OGIT17=V
EPA_HU<4IU]B0gQYF0AhM6@4OGEU17ijJ`AmNf/4QGa[0h5gIPAjLV84NVYO17mVHPAfJUh4MFUP17Q/
F0=aHe84L5M618bPVbN7ViHEoooo000Doooo;XNKUPB7T8h4RW9[189UF0AfGE@4PFmO17n3N0>7SHD4
Qhj118N8O0R7SH44QhUm18N9N@>9RWT4QXEd18R0L0B1Q7P4Qhf518bLS@>6Qh04Qhmh18Z0LPAmMV@4
LfIF16mRD`AVFe83N6UH17QdI0AmMFD4OWY[17ekJ`B5O6/3PGMV17YbHPAjJUl4OfIR17IZGPAeJF04
N6aH0g5SDPA`EdH4S:2K9hNKUQGoool001Coool^Qi^F18N@SPB:LV/4PVEH17IME0B1Kel4Oh=h0hN=
Q@B7SX44QhQl28N=P@B7RGd4QhUi0hV:N@B6QG@4R81`1864N0B7SHD4S9b=0hJ7P0B7SgP4RX1b17ef
I0AcIUH4Kf9C16IKDP=hJEP4N7AT17eeI@AnNV/4OG][18ElJ`>1MfH4NW9R17YZG`AoIV84MVYN17EY
H0AhK5P3LF=B171GAPB<X9/WQi^F5Oooo`005?ooob^7ViH3Qhn318NJP`B:RW84OW5H17ETE@AhLVH4
QXQg0hN8O0B7TXD4QhUm18N5N@B3PG84PHEa18MmM@>9N744OGa]18=gJ@B1Ofl4QhAe18N9N@>7RGd4
QhF118YdJ@B2Keh8MfUI17=/G@=`LEd4M6iL17QcI0B2MfP4OgQX17mdI0>1Lf<4NViN17YZF0AgJUP4
MfiK17E^G0B4O703NfeN15e=?PA`NWPWQi^F5Oooo`005?ooob^7ViH3Qhn318NJP`B:RW84OW5H17ET
E@AhLVH4QXQg0hN8O0B7TXD4QhUm18N5N@B3PG84PHEa18MmM@>9N744OGa]18=gJ@B1Ofl4QhAe18N9
N@>7RGd4QhF118YdJ@B2Keh8MfUI17=/G@=`LEd4M6iL17QcI0B2MfP4OgQX17mdI0>1Lf<4NViN17YZ
F0AgJUP4MfiK17E^G0B4O703NfeN15e=?PA`NWPWQi^F5Oooo`005?ooob^7ViH3Qhn318NJP`B:RW84
OW5H17ETE@AhLVH4QXQg0hN8O0B7TXD4QhUm18N5N@B3PG84PHEa18MmM@>9N744OGa]18=gJ@B1Ofl4
QhAe18N9N@>7RGd4QhF118YdJ@B2Keh8MfUI17=/G@=`LEd4M6iL17QcI0B2MfP4OgQX17mdI0>1Lf<4
NViN17YZF0AgJUP4MfiK17E^G0B4O703NfeN15e=?PA`NWPWQi^F5Oooo`005?ooob^7ViH3Qhn318NJ
P`B:RW84OW5H17ETE@AhLVH4QXQg0hN8O0B7TXD4QhUm18N5N@B3PG84PHEa18MmM@>9N744OGa]18=g
J@B1Ofl4QhAe18N9N@>7RGd4QhF118YdJ@B2Keh8MfUI17=/G@=`LEd4M6iL17QcI0B2MfP4OgQX17md
I0>1Lf<4NViN17YZF0AgJUP4MfiK17E^G0B4O703NfeN15e=?PA`NWPWQi^F5Oooo`005?ooob^7ViH3
P8Mg16]KB`ABBch4CTi5169OE0AjMfX4QhUh0hN4N@B7QGT4QhUi18N5L@B9QGD4OGQ]17YmJP=nMfd4
PhAg18>8M`B1Pfl4QhUm18N9O0>7RGd4Pi=m18F7M0B2LF44MfUI179UEPAkIUL3MFYO17Q_H`AnLfL4
NG=T17mkK0AoOfh3PGMV17YkJ@AgMV@4MfeN17IVG`AeJV04Lei:0gEMC`AkFdH4KDho9hNKUQGoool0
01Coool[Qi^F0h27M`A[Fd/4DT/n14i>A@ARGe@4NWMZ18N9N0>7Q7T4QhEi18N9N@B7QG44RHEe17eh
K@AjOFX3OWM]18>4M`B3R7L4PH=_18N9O@B7RG`3QhUm18>CO@B5Qg@4PW5Q17MYF@AbIEH4NfIG0gEZ
G`AhKf<4OW=W17UcI0AoNf`4Ogm^0h5gIPAjNfT4MgIT17M]GPAfIUl4MFYP17=NBP=eGDl4Ne]616e>
?bN7ViHEoooo000Doooo:hNKUP>0QgL4Je];159;?PA>CTD4HUmD17YgJPB7RGP3QhAi18N5N@B7RGT4
QhEa18V5M@AmN6d4NWeZ0gigK@B3Q7L4PhQg1863K`B7RGd4QhUl0hN9O@B3Tgd4QHMd189aH@AgJET4
LVEF17]VE`=eJUl4N6mS17icI`AiLf@4Og]/17moKP>1MfH4NW]Y17MfI0AgKEh4MVIO17EZH0AcGTX3
MEe?17]KAPA]CSlWQi^F5Oooo`005?ooob^7ViH3P8Mg16]KB`ABBch4CTi5169OE0AjMfX4QhUh0hN4
N@B7QGT4QhUi18N5L@B9QGD4OGQ]17YmJP=nMfd4PhAg18>8M`B1Pfl4QhUm18N9O0>7RGd4Pi=m18F7
M0B2LF44MfUI179UEPAkIUL3MFYO17Q_H`AnLfL4NG=T17mkK0AoOfh3PGMV17YkJ@AgMV@4MfeN17IV
G`AeJV04Lei:0gEMC`AkFdH4KDho9hNKUQGoool001Coool[Qi^F0hJ5M0A>?Bd4@cdf13Pg=@@_?3l4
NWU_18N9O0>7RGT4QhUd18N9O@B7SXD4S8f518bGR@B>R7l3OgAX17ITF`AgKf84OG]]1864M0B7RGd3
QhUi18V1M@B0N6X4N6IN17=RE@A_HE04K69E0gY^G`AdKU`4MF]M17U_I0AkJ5`4MFaN0gM_H0AbJe`4
MfmO17I^GPAfJU`4LF=F17AfFP=TDd04LVIG16e:?RN7ViHEoooo000Doooo:hNKUP>6QG@4CSd]14<m
=P@h=cD4;c`o17YiK`B7RG`3QhUi18N9M0B7RGd4Qhj518b=Q@B<UhT4SXQo0gmdJ0AfI5/4MfmR17ek
K@B1Q7@4QhUm0hN9N@B9PGD4P7QZ17QVGPAcHUD4Kf5@16aRE@=jKUl4M6iL17E[G@AiKf@4NfQL17E/
GP=gKf04LV]L17M_G`AfKUh4MVYL175SEPAdMUX3I5=0179VE`A]BShWQi^F5Oooo`005?ooob^7ViH3
QXEd14hm;@A3?CH4>3Le12ll?`AjNFl4QhUl0hN9N@B7RG@4QhUm18N>Q@B<SHD4S9N918j8O`=oM6P4
MVAK17M_HPAmNfd4PHAd18N9O@>7RGT4RH5e181hJPAhIUh4Lf9E16mQD0A/HUD3NViO17A^G0AeJed4
NFmT17]XG0AeK5h3MfmP179[G0AgKel4MViN17IZG0AaHeH4M7IJ0fAC@0AbIUL4KDXn9hNKUQGoool0
01CooolWQi^F18NCR`>@WYH4Y7MP1592=PA5?SL4:STm17YiI`B3QG43PHAi18N9O@AlNFD4K6QH16=K
B`AECD44FUQ<0f5IE0AaH5X4Kf1C17AWF`AkNV/4QhUm0hN9PPB9RW`4QW]/17e`E@AbHDl4LfEC16QR
D`=VGe84HVMI16QWF@A_Lf04MgIU17E_H0=oMfH4Ng9R17I^G`AfKUh4MVYL17IZG`AXE4H3C3P_15E8
>@AWA2lWQi^F5Oooo`005?ooobN7ViH4Qi>;0i2NUPBTMf04DT8f14Dn=`@Z>Cd4NWUW18>5L@>1Q7T4
QhUm17aiI@A/J5P4He];15E=@@AJF4`3HEUD175PFPA_H5<4M6MK17]jJ`B7RGd3QhV218V:O0B6Nf`4
OG1E179QC`AcIE<4J69C0fIODPARIeT4J6MI16mcH0AgMVD4MFmP0gmgIPAkLV84MViO17I^GPAfJU`4
MVYO16QDAP=<>2l4EDPi16M4;bN7ViHEoooo000Doooo9hNKUPB7Th/3T9jF1:AgH0AB@SH4AChg12Xi
?@AjNFL4PhEa0h64N@B7RGd4O7UU16aXF0ASFd/4EDe115YHC0=QFE@4LF1J16mPD`AdIe/4NgY[18N9
O@>7RH84RHYl18IkK0AmL5D4LV5?17=UD`AXHU<3IUmB169WF@AXIeT4Kg=P17MfI@AeKf03OgMV17]b
HPAfKUl4MViN17IZG0AfJUl4J5A60d`h;`AEB3T4Id@_9hNKUQGoool001CooolWQi^F18NCR`>@WYH4
Y7MP1592=PA5?SL4:STm17YiI`B3QG43PHAi18N9O@AlNFD4K6QH16=KB`AECD44FUQ<0f5IE0AaH5X4
Kf1C17AWF`AkNV/4QhUm0hN9PPB9RW`4QW]/17e`E@AbHDl4LfEC16QRD`=VGe84HVMI16QWF@A_Lf04
MgIU17E_H0=oMfH4Ng9R17I^G`AfKUh4MVYL17IZG`AXE4H3C3P_15E8>@AWA2lWQi^F5Oooo`005?oo
obN7ViH4Phao0hF2L@@i9b849BLU12T_;0@D<CL4OGY/18N5M@>6Q704QhUi19BCP0AiLV84I69B1498
@P@Z=C<39c@/13Pl=@A@?S<4AblY14ll=@B1Og03QhUm18V?O0B6Of`4OFeJ16m]E0A[H4`4JfII0h=f
I@B8NVT4OW9R17ISF@A`Ie`4JVYM0gYcH`AlLV84KfYK16IZF`A/KU`4MViO17aTD0=UC3d4G4Dm16Lh
:2N7ViHEoooo000Doooo9hNKUPB3S7l3QH9a13TW8P@U9bD4:Bl/11@a=`AmNV`4QhEe0hJ4L0B7RGT4
U9>017UbHPATHU84@TQ212Xe<`<W=2`4>3`e150n<`A7;bT4Cc`e185oL0>7RGd4RHml18IoK0AmKEX4
KfeD16]PC0A[IUT3PgIU18QjJ@AnLV84MV=I171WG0AZJUd3NW=S17abHPA_JU/4IVYK16a^G0AfKUl4
O6A@0fE<?@ALACd4IcPX9hNKUQGoool001CooolWQi^F18><O`>5PW44>BLR12DW9@@Y;b`4534g17ej
K0B7QGD3QXA`18N9N@BDTh04NG9R16ARDPA2B484:SDc0bLd;0@h?3D4D3hc14L_:@A??3D4PGm`0hN9
O@B9Sg`4QWm/17e]FPA_KE@4Jf1<16]VF@>3MVD4R7YY17ibHPAfHeT4L6ML16YZG@=jLf<4O79R16mZ
F`AVJU/4K6iL17I^G`AlI503ID`m15a5?@AW>2PWQi^F5Oooo`005?ooobN7ViH4Phao0hF2L@@i9b84
9BLU12T_;0@D<CL4OGY/18N5M@>6Q704QhUi19BCP0AiLV84I69B1498@P@Z=C<39c@/13Pl=@A@?S<4
AblY14ll=@B1Og03QhUm18V?O0B6Of`4OFeJ16m]E0A[H4`4JfII0h=fI@B8NVT4OW9R17ISF@A`Ie`4
JVYM0gYcH`AlLV84KfYK16IZF`A/KU`4MViO17aTD0=UC3d4G4Dm16Lh:2N7ViHEoooo000Doooo8hNK
UPB:WYX4TZ:H0hEfHPAlFTh4=BlZ13<^:P@B9c04QXQg18>9N0>1Q7@4QhUh18bBQ@BJT7d4XXn017]T
D`@m=2h3;RlZ12`h=`A<Ed/4O7IU17=[G`B1QgH3QiJ<18VHS0B6Pfl4M6AF16IEB0A;;B<4>S4_0f5E
@PAKDT84BTPk14mBA0A_IUP4IfIE0g9[F@AgKel4N6YI16iVF0A[IU`4Kf9G16=BAP=ECd<4GeaB16m9
?@B<X9/SQi^F5Oooo`005?ooob>7ViH4RYjJ19:RV0>5MV84O5Y>13D_:P@c;RX44RL`18J8M`B3RGP3
PHAd18N9N0B<TXD4VY1m1::?P0AkI5<4?C@^0bh_:P@/>3L4C5M;17afI@AcJel4PHMf0hNFS0B9V8`4
QX=_17ATEPAVEDP4BbdS13Xa;`=QED84Fe9214Y8>`A?DT@4KfIH16MVE@=bJeT4MfmO17QZF@A^IUP4
JfIL16mRE`ASDTH3EDm315mLDPA_BCd4S:2K8hNKUQGoool001CooolSQi^F18ZNVPBBXYP3QGIR17aJ
CP@e;bX4<bhZ118W<0B6R7L4PhUh0h64M0B7RGP4S9:519Z@O@BRSh04NfAC13dd;P<^;bX4;3Pg14aG
B`AlMVD4Lf]O1867MP>7UX`4RIR<18J3K`AdI5H4IUE814/]8`@j<Bl3HEE215]B@PA:B3/4Ce9416mV
F0AWIUD3LV]I17M_G`AhJUT4KVIH16]VG0A_HUL4He960eE?@`AOG584KdTm18bPVb>7ViHEoooo000D
oooo8hNKUPB:WYX4TZ:H0hEfHPAlFTh4=BlZ13<^:P@B9c04QXQg18>9N0>1Q7@4QhUh18bBQ@BJT7d4
XXn017]TD`@m=2h3;RlZ12`h=`A<Ed/4O7IU17=[G`B1QgH3QiJ<18VHS0B6Pfl4M6AF16IEB0A;;B<4
>S4_0f5E@PAKDT84BTPk14mBA0A_IUP4IfIE0g9[F@AgKel4N6YI16iVF0A[IU`4Kf9G16=BAP=ECd<4
GeaB16m9?@B<X9/SQi^F5Oooo`005?ooo`B7TXh4QiFA18NGT`B7UI4CQi^F13HY90@C:2h3QWe[18=R
C`@k=cX4:2/Y108M:0AmP704QhUh0h>5M0AnPG44PHAd19BLS0AnOfX4]9Ek1<:PP0>RPF44RFI:17Ic
G0AfL5h4O6aP185mKP>7R7T4RH]n18J0K@B7KeP4Lf1@18=[D`A@CDP3@4Y;11PM7P@P;Rh4=C`h12db
;0@X=CD3A4Di15I??`AdIeH4KVUJ16]ZF0A/H544D4Pj0cPj=@A3DDP4L5M518fQW2>7ViHEoooo000D
oooo18NBSPB7UI44QiNC18NETA>7ViH4=RTT11<X;P>6OF/4Pf9?13/g>P@X:bT40QdX17f0L0B7RGP3
PhEd17j1L@B1Q7@4U9b<17ioJPBdUG/4`Z200j:1H@B9ITX4MW=L17I`GPAlK604PGe^0hN8N@B9Rgh4
QX1]18M_F0AcH504Pf]C151=B0=0BT/461dN120^;P@e?3P4;C8/12Pe=@=4ACT4ETlo17AWEPA^JEX4
JfYH16aPD@A@B3X3>3Xe14=AB0A`EdD4SJ6L8hNKUQGoool001Coool4Qi:>18NET@B7Ui<4QiFA4hNK
UP@f:B@44bP^0hImJ`B3HTl4>cLj12P[:@@27BP4OH1`18N9N0>3QG@4OX5a1864M0BDW8`4OWmZ1;BE
N`C2X803XX5Q18UVBPAfLe`4MW1N17a/H0B1OFh3QhQi18V;OPB6P6d4QfmH17=PD0B3Je<4D4e80d1:
B`@H7Ah482h^13Dl>0@]<R`4:3De0dA5>@AFCcl4M6MF16iYFPA[JUP4K61A1518>P<h>SD4@e58171G
A@B=XI`SQi^F5Oooo`005?ooo`B7TXh4QiFA18NGT`B7UI4CQi^F13HY90@C:2h3QWe[18=RC`@k=cX4
:2/Y108M:0AmP704QhUh0h>5M0AnPG44PHAd19BLS0AnOfX4]9Ek1<:PP0>RPF44RFI:17IcG0AfL5h4
O6aP185mKP>7R7T4RH]n18J0K@B7KeP4Lf1@18=[D`A@CDP3@4Y;11PM7P@P;Rh4=C`h12db;0@X=CD3
A4Di15I??`AdIeH4KVUJ16]ZF0A/H544D4Pj0cPj=@A3DDP4L5M518fQW2>7ViHEoooo000Doooo18NF
TPB7UI44Qj2K18NJUPn7ViH4?3<^13Xe<0@A6AT35AhQ12h/<0@Y:bL4<S0/10/Q:`B3QG@4PHAh0h5`
I`A`GED4M71R18bBRPBBXIH4VIB918YiJ`>?PW84SGm_185dI0B1OVX4PWY[185mKP>7SH44RHZ018J4
M@AmMf44N71D181dE`B=KeL3X7YQ13`c<@@S;2P4>SHc13dm>0@i?cL3HeU>16UXF@AlJEH4LfIH16]^
F`AEASh4?cXb0cXf;P@_<bl4HSDV18NKUb>7ViHEoooo000Doooo18NFTPB7UI44Qj2K18NJUPn7ViH4
?3<^13Xe<0@A6AT35AhQ12h/<0@Y:bL4<S0/10/Q:`B3QG@4PHAh0h5`I`A`GED4M71R18bBRPBBXIH4
VIB918YiJ`>?PW84SGm_185dI0B1OVX4PWY[185mKP>7SH44RHZ018J4M@AmMf44N71D181dE`B=KeL3
X7YQ13`c<@@S;2P4>SHc13dm>0@i?cL3HeU>16UXF@AlJEH4LfIH16]^F`AEASh4?cXb0cXf;P@_<bl4
HSDV18NKUb>7ViHEoooo000Doooo18NFTPB7UI44Qj2K18NJUPn7ViH4?3<^13Xe<0@A6AT35AhQ12h/
<0@Y:bL4<S0/10/Q:`B3QG@4PHAh0h5`I`A`GED4M71R18bBRPBBXIH4VIB918YiJ`>?PW84SGm_185d
I0B1OVX4PWY[185mKP>7SH44RHZ018J4M@AmMf44N71D181dE`B=KeL3X7YQ13`c<@@S;2P4>SHc13dm
>0@i?cL3HeU>16UXF@AlJEH4LfIH16]^F`AEASh4?cXb0cXf;P@_<bl4HSDV18NKUb>7ViHEoooo000D
oooo18NFTPB7UI44Qj2K18NJUPn7ViH4?3<^13Xe<0@A6AT35AhQ12h/<0@Y:bL4<S0/10/Q:`B3QG@4
PHAh0h5`I`A`GED4M71R18bBRPBBXIH4VIB918YiJ`>?PW84SGm_185dI0B1OVX4PWY[185mKP>7SH44
RHZ018J4M@AmMf44N71D181dE`B=KeL3X7YQ13`c<@@S;2P4>SHc13dm>0@i?cL3HeU>16UXF@AlJEH4
LfIH16]^F`AEASh4?cXb0cXf;P@_<bl4HSDV18NKUb>7ViHEoooo000Doooo18NPV`B7VYHGQi^F16E>
A0@o>C04?SL`0bX^;0@R92<4<2d[13L`;0@B8R/4QX1`18>0K0>CYY84RXYk15iBA0A@A3T4D4/o14=7
?P@k?3L3=CH`13dn=@A3>c@4DDi517MjJ`B1OVl3QhEe18V:M@B6O6`4OGAT17MND0A^JU84K6UA0h1j
I@CJZHD4Yhab18MVC`B8HT`4MFEF0ge^EPA^IE@4LG9N181bGPA^JUh4EdXi13D`;0<i=Rl4=3Ta15/V
62N7ViHEoooo000Doooo18NPV`B7VYHGQi^F16E>A0@o>C04?SL`0bX^;0@R92<4<2d[13L`;0@B8R/4
QX1`18>0K0>CYY84RXYk15iBA0A@A3T4D4/o14=7?P@k?3L3=CH`13dn=@A3>c@4DDi517MjJ`B1OVl3
QhEe18V:M@B6O6`4OGAT17MND0A^JU84K6UA0h1jI@CJZHD4Yhab18MVC`B8HT`4MFEF0ge^EPA^IE@4
LG9N181bGPA^JUh4EdXi13D`;0<i=Rl4=3Ta15/V62N7ViHEoooo000Doooo18NPV`B7VYHGQi^F16E>
A0@o>C04?SL`0bX^;0@R92<4<2d[13L`;0@B8R/4QX1`18>0K0>CYY84RXYk15iBA0A@A3T4D4/o14=7
?P@k?3L3=CH`13dn=@A3>c@4DDi517MjJ`B1OVl3QhEe18V:M@B6O6`4OGAT17MND0A^JU84K6UA0h1j
I@CJZHD4Yhab18MVC`B8HT`4MFEF0ge^EPA^IE@4LG9N181bGPA^JUh4EdXi13D`;0<i=Rl4=3Ta15/V
62N7ViHEoooo000Doooo7hNKUPA]Ed@4;BHS12@Z9P<X:RH4<BhY12DZ9`@c>cL46C8g17AfJ0B<R7P3
QXQg19RLTPBY/Yd4SX5c17=WH`AoM6X4UWUU0hMcH@AiJUP4PGMV17ieJ0B5Qg/4QXQl0hMmN@B9PGP4
QX1^17e_I`AKB3h4BCLa14e9?P=/JU84MViH18AfHPBCQ6`4Q7eX16m`G0=_KF04MVYN16iVGPA/JUP4
K65?13Hd;@@T:bL3Ae=;16=B@@A>91HWQi^F5Oooo`005?oooan7ViH4KEM412dV8`@T:RH3:2XV134^
:@@U:RL4<c/g11Tb=`AdMVP4S8Qh0hJ8M`BHW984ZK:M18j1L`AcIf<4OgAZ19IiI@>7Lf44NFYH185g
IPAnMFP4QHMk18J8O0>7OGT4RH5h18J0KPAmKfL4FdPn14Tg<@A=BCh3K6YB17I^F0B4MV84ThA/18Am
J0A_L5`3KfeP17IZGPA^IUh4K6YH16aQC`@f=2d492/W0dMCB`ASDT44CR@F9hNKUQGoool001CooolO
Qi^F16eGA0@]9R<492XV0bPZ9P@a;RT49BXW13<k=`@I<SL4M7IX18b8N0>6R7L4V9bB1:VbW@B>PG<4
LfMS17mdJPBFNFD3Qg=Q17UZF0B1MfH4OWEX18F7N`B6R7`3Qgei18V1N0B6P6h4OFmW15]8?PA9=c44
CDTn0faZDPAfKUP4Q7IR19>4K0B4OFP4Kg1L0fm]H0AfJUh4KVIN16aZF0A/HDl4=S@]12@[9`=7Dd/4
He9114hT5RN7ViHEoooo000Doooo7hNKUPA]Ed@4;BHS12@Z9P<X:RH4<BhY12DZ9`@c>cL46C8g17Af
J0B<R7P3QXQg19RLTPBY/Yd4SX5c17=WH`AoM6X4UWUU0hMcH@AiJUP4PGMV17ieJ0B5Qg/4QXQl0hMm
N@B9PGP4QX1^17e_I`AKB3h4BCLa14e9?P=/JU84MViH18AfHPBCQ6`4Q7eX16m`G0=_KF04MVYN16iV
GPA/JUP4K65?13Hd;@@T:bL3Ae=;16=B@@A>91HWQi^F5Oooo`005?ooo`R7ViH4QiNC18NET@n7ViH4
NVQE13/[9@@_:RL3:2/X11/N7`@X:BH4<SHb12<h>PAPI5T4PGm`0hN9N0B7SH44S9J>19jeX`Bi^jD4
VK2P1:Nk[P>V]JP4[;na19BUU0B7QgH4PHMg18>:N@=nSgD4PhAd18Z5M0B?U7X4Y9Z216iID0@e<2l3
8bXW12`h=@AMFe04MfiN181cF`A^JU/3LfIF169OCPA/HeT4MFIN15E4>@@i<2X4=SPd0b8g=0AOAcL4
:AdH12@Z:2>7ViHEoooo000Doooo28NKUPB7Ui<4QiFA3hNKUPAjJ5D4>b/U12lZ9`<X:bP46ahO12PY
9P@b=S848cPj161TF@B1Og03QhUh18N=P@B<UXh4W[FS1;VkY@BI/:04Yk^^0jJeZ0B/_k44U:FD18N7
MPB1QgL4PhYi0gj?M@B3Q7@4RXEd18nDNPBTVX84KUU@13D`;`<S:RL4;3Pe15eKD0AgKUh4P7=K16iZ
F`=cIUH4HUm>16aSF@AeIUh4ED@i13T`:P@f>3@38SLd15m7=`@Y7AP492XX8hNKUQGoool001Coool8
Qi^F18NGT`B7UI4?Qi^F17YXE@@k:bD4;bXW0bP[:0@K7Ql4:2TV138f<P@S>3X4H6AI185oL0>7RGP4
Qhf118bFSPBN]J<4^K^U19V`X0BW^jh3Y[FX1:bo/@BDYI@4QhMf1867M`B3RWT3OXme18>4M0B:QG@4
SiAj1:BJPPA^FE04=C0_0b<Z9`@/>3D4GE]@17M^GPB0Le/4KVYK0g=VEPARGdh4K6=I17EVGPAEA3T4
>C0Z13Hh=0<R=c@4GdLg12TM60@T:RPSQi^F5Oooo`005?ooo`R7ViH4QiNC18NET@n7ViH4NVQE13/[
9@@_:RL3:2/X11/N7`@X:BH4<SHb12<h>PAPI5T4PGm`0hN9N0B7SH44S9J>19jeX`Bi^jD4VK2P1:Nk
[P>V]JP4[;na19BUU0B7QgH4PHMg18>:N@=nSgD4PhAd18Z5M0B?U7X4Y9Z216iID0@e<2l38bXW12`h
=@AMFe04MfiN181cF`A^JU/3LfIF169OCPA/HeT4MFIN15E4>@@i<2X4=SPd0b8g=0AOAcL4:AdH12@Z
:2>7ViHEoooo000Doooo28NKUPB7X9/4QiZF3hNKUPAVI5`4>c/e12l]:@<^:bP4:2XT12PZ9`@b=S84
<40o16ARF0B1OW03QhUh18N8O0B7SH44Qi6828NGTPB7ThX3Qi6818NCRPB7TXX4S9:518J4L0B<SWd3
R8Ed18=lK@B8P704R8Ec19>=OPBdZ944]9B40h]_H0@l>c@48bXV12H_;P@d>cT4?T<i0dE5>@AVFe84
M6UJ17=VE`A=>c@4<2dY12d/;@<M8R44;BXU14`n>0@P8b4SQi^F5Oooo`005?ooo`R7ViH4Qj2K18NJ
UPn7ViH4IVAL13/k=@@_;BT3;R/X12PZ90@X:RL4<SHb1310?`ATHUP4PGi`0hN9N0B7R7`4Qhf118NA
R0R7Ui84Qi>:0hNAR0B7ThX4Qi::18bBQ@B6Q704S8im0hR5M0B3O6d4R81`18R5L`BCSGh4]:RA1;BD
Q0>;Kf04?3/d12<Z9P@V;bh4=3/i13i3>@=5ACT4IU]B17AYFPAcIUL4CC/d130]:@@];2d37B8Q12dZ
9@A<?SP482<Q8hNKUQGoool001Coool8Qi^F18NPV`B7VYH?Qi^F16ITG0@k>cD4;bdY0bh[:0@X:R@4
:2XW138f<P@`@3l4I69H185nL0>7RGP4QhQl18N=P@B7THP8QiNB18NCRP>7THP4Qi>:18NBRPB<TXD4
QXA`18b>O@>8QG@4Pga]18R0L0B8QG<4Then1;BXT@BdU8@3RfmP13`k=0@S:RH49Rl^13@k>@@n@cT3
ADDi16IKDPAdJEX4LfIG14dk=0@`;BT4;B`]0adR8@@]:RD4C3hh120S8B>7ViHEoooo000Doooo28NK
UPB7X9/4QiZF3hNKUPAVI5`4>c/e12l]:@<^:bP4:2XT12PZ9`@b=S84<40o16ARF0B1OW03QhUh18N8
O0B7SH44Qi6828NGTPB7ThX3Qi6818NCRPB7TXX4S9:518J4L0B<SWd3R8Ed18=lK@B8P704R8Ec19>=
OPBdZ944]9B40h]_H0@l>c@48bXV12H_;P@d>cT4?T<i0dE5>@AVFe84M6UJ17=VE`A=>c@4<2dY12d/
;@<M8R44;BXU14`n>0@P8b4SQi^F5Oooo`005?oooan7ViH4NVeS14m7@@@`<2/3:R/X12l/:0@`<304
=CLe12do?@A?E4/4M7AW0hN9M0B7Q7@4QhQm18N8N@B7S804Qi:918NHT`>7THP4Qi>;18N=P@B7TXX4
Qhj118N9N0>9RWP4PhEd28=kK0B3PG04RX1`18F8LP>OS7@4Y8mf19J1J@A^HTh4K5E5171SE0>4MF@4
IV1F16]SF`ASIED4CShe12l/:0@V:bH382PT12<]:`@j>cL482@R8hNKUQGoool001CooolOQi^F17Y]
H`A?Ad44<30[0bX[:0@_;2P4<30`13Dg=@@]?cd4CeA;17AdI`>7RG@4QhAd18N8O@B7R7T4Qhb018NB
R@B7V9<3Qi6818NCR`B7SH44Qi::18N>P@B7RGP3RHYh18>5M0R3Nf`4Ph5`18Z0L0B5R783Whad1:B?
MPBFPFT4KV9>16aEA@A`He@3Q7ET16IPEPA[He/4HfEE14hn=@@_;2P49R/V0b0X90@S;B/4>S/g120T
8R>7ViHEoooo000Doooo7hNKUPAjKF<4CdM1130`:`<Z:bP4;b`X130`<0@e=cD4;Clm14mDB`AdM6L3
QhUd18N4M0B7R7d4QhQi18N<P0B7TXT4QiRC0hNAR0B7Th/4Qhf118NBRPB7SX44QhUh0hV:N0B3QG@8
Pg]/18>1L0B:P704QHQb0in<M0BTSgH4UX5Y16iRCPA/EDD4L6=D0hAeI0AVH5H4Jf=K16=UE@A>?SD4
;b`X12H[9P<P:2@48bd[13Xk=`@P928SQi^F5Oooo`005?oooan7ViH4NVeS14m7@@@`<2/3:R/X12l/
:0@`<304=CLe12do?@A?E4/4M7AW0hN9M0B7Q7@4QhQm18N8N@B7S804Qi:918NHT`>7THP4Qi>;18N=
P@B7TXX4Qhj118N9N0>9RWP4PhEd28=kK0B3PG04RX1`18F8LP>OS7@4Y8mf19J1J@A^HTh4K5E5171S
E0>4MF@4IV1F16]SF`ASIED4CShe12l/:0@V:bH382PT12<]:`@j>cL482@R8hNKUQGoool001CooolO
Qi^F17ASD@@m>2h4?cPb0bl]:@@`9b<4=2hY13Ld;@@`>3@4?DM316]WG0>1Q7@4QhUh18N8O0B7THP4
Qhf118N<P0N7TXT4Qi>;18N=P@B7RGT4QhUm18N5N@>9PG04Pg]/18>5M0B3Nf`4PgaY18EhJ0B5M6@3
QGMV18EfI@B>OV`4UhQc1963K`AmLV83OfUN17Y`GPAlIEH4HTm014Hh<0@_;2P4=S0/0bd]:@@W:RL4
;S0Z11HH4`ATJ6LOQi^F5Oooo`005?oooan7ViH4M6=A13dh;P@o>383;bdY130W8`@d;RT4=c@]130h
=0@mAd<4JfML0h64M0B7RGP4QhQl18NAR0B7SH44Qhb01hNBR@B7Th/4Qhf118N9N@B7RGd4QhEi0hV1
L0B3Nf`4PhEd18=kK0B3O6T4QGQX18EdI0>5MfH4QGIU18inK0BGR7<4TH=_17ebHP=oJEh4NW1N17aU
EPARCd04ASP`12l/:0@f<2`3;BdY12LZ9`@^<2X45QPC16AXIan7ViHEoooo000Doooo7hNKUPAdHe44
?CP^13lh<P<_;BT4<2LS13@^:@@g=2d4<3Pd13e7@`A[Ie`3PHAd18N9N0B7R7`4Qi6818N=P@B7S807
Qi:918NCR`B7SH44QhUi18N9O@B7QGT3RH5`18=kK0B3QG@4Pg]/18=lJ@B5N6P4QGAT0hEgIPB5MVD4
SWi/19N8L`BAPfl4OG9R0gmYGPAjL5h4O6EF169?@0A6>304;b`X13H`;0<];BT49bXW12h`:P@F61<4
I6QW7hNKUQGoool001CooolOQi^F16ILB`A1@C`4>SPc0cPb;P@U:B@49RXV12HY9P@^<Bd4;CH_14i=
@P>1Og04QhUh18N8O0B7S7l4QiRC18N=P@B7S807Qhj218N=P@B7SX84QhUd18>6M@>3QW@4Pg]/18=g
J@B3O6`4Pg]/18ElJ`AkMfH3Ng=S17mkJPAfLV84NVmO17]^G`A_KUh3IVYH16IZF`APH544@D4j12HY
90@];bl48bLX0b<W8`@J7Ql492TX12@]:PA9Ad8OQi^F5Oooo`005?oooan7ViH4IUa;1451?0@j>3<3
>38^12DY90@V:RH49RTV12ha;@@]=Rl4CTe20h5oL0B7RGP4QhQl18N<O`B7V9<4Qhf118N<P0N7SX84
Qhf118N>PPB7RG@4PhIe0h>6M0B3Nf`4PgMY18=lK0B3Nf`4QGa[17]gIP=kLf<4Og]Z17IbHPAjKel4
NfiO16m^GP=VJUP4IVYK161PD@A1@CX49RTT12d_;`@S9bP38bLS11XN7`@T:BP492dZ14U7@Qn7ViHE
oooo000Doooo7hNKUPAVG4/4@D4l13Xh<`<h<Rh49BTT12HZ9P@V:BH4;S4]12df;`A>CD83PGm`18N9
N0B7R7`4Qhao18NHT`B7SH44Qhb01hN>PPB7SH44Qhj218N9M0B3QWD3PhId18=kK0B3MfT4Pga/18=k
K0B5O6/4NgMV0g]cH`AoNfX4MW9R17Y_G`AkKUl4KfiN0fIZF0AVJU/4H61A1451>P@V:B@4;Bl_12<W
:0<S9b<46QhO12@Y:0@T;BX4BDM27hNKUQGoool001CooolOQi^F16ILB`A1@C`4>SPc0cPb;P@U:B@4
9RXV12HY9P@^<Bd4;CH_14i=@P>1Og04QhUh18N8O0B7S7l4QiRC18N=P@B7S807Qhj218N=P@B7SX84
QhUd18>6M@>3QW@4Pg]/18=gJ@B3O6`4Pg]/18ElJ`AkMfH3Ng=S17mkJPAfLV84NVmO17]^G`A_KUh3
IVYH16IZF`APH544@D4j12HY90@];bl48bLX0b<W8`@J7Ql492TX12@]:PA9Ad8OQi^F5Oooo`005?oo
oan7ViH4NVID13lk=@A2@C`3>3Pc13`c;P@_;2P4=3@`13Dm>P@g@Cl4<d0n0gA]H@B7Q7@4QhAi18N3
M0B7S804QiRC18NAR0>7Th/8Qhf118N>QPB3QGT4PhId1h=lK0B3Nf`4Og]/17YhJ0AoN6P4PGMV0gYc
H`AjKf04OgMV17IbHPAgKUl4N6iN0gEZF`AgIUH4GE55148e;`@l=c848B<S12<V9`<L7Ql492LX12DY
9`@X=SD4>chj7hNKUQGoool001CooolOQi^F17YVE0@o>cD4@T4l0cPh<`@l<bh4;b`X13@d<0@e?CX4
=d4o13=0?P=dKF44QhAd18N4N@B7Pg@4Qhb018NHT`B7THP3Qi>;28N=P@B7SXH4PhEi18>6M0N3O6`4
Pg]/17mkK0AjN6P4OgQX185gIP=jLf<4NVmP17mgIPAfLV84MfiO17Q^GP=eJU/4MfIF15eAA@A2=Bl4
?3Lb124S8`@S9RL371hO12@W:0@U:BL4:3He13/n>Qn7ViHEoooo000Doooo7hNKUPAjIU@4?c/e1491
?0<h>3<4?3<^12l/:0@d=304=Cdj13M1?`@c@3h3M6eQ18N4M0B7Q7T4Qh=d18N<P0B7V9<4Qi680hNC
R`R7SH44Qhj618>5N@B3QW@7Pga/18=kK0AoNf`4NWQX17mhJ0B1MfH3NW=S17Y_H0AoMfH4MW9R17M^
G`AhKUh3MFYK17MVEPAMDDD4@SD_13`g<P@Q8b<48bHW0a`N7`@T9bP49BTW12Pf=@@k?SXOQi^F5Ooo
o`005?oooan7ViH4NVID13lk=@A2@C`3>3Pc13`c;P@_;2P4=3@`13Dm>P@g@Cl4<d0n0gA]H@B7Q7@4
QhAi18N3M0B7S804QiRC18NAR0>7Th/8Qhf118N>QPB3QGT4PhId1h=lK0B3Nf`4Og]/17YhJ0AoN6P4
PGMV0gYcH`AjKf04OgMV17IbHPAgKUl4N6iN0gEZF`AgIUH4GE55148e;`@l=c848B<S12<V9`<L7Ql4
92LX12DY9`@X=SD4>chj7hNKUQGoool001CooolOQi^F16e]I@Q3@ch3A48m13Pc;P@V:2@4;2`Y13/f
;`A?Ac/4AdHk0fEKCPB1Of`4QhUh18N4N@B7Pg@4Qhb018NBR@>7V9<4Qi>:18N=P@B7SX44S8j118R9
N0=oPG04NWQX17edJ0B5M6P4OgAT17m_I0B1LfH3NW=S17Y_G`AgJe`4MfmO17=VE`AkIeP3KV9C15aB
B@A=@SP4?C@^12@W8`@U:2P4828S0bDX90@S9bL4;bh/14]IF0B0THdOQi^F5Oooo`005?oooan7ViH4
KFeU24=3?P=4@Sd4>3<^12HX90@/;2T4>cH_14m7>`A7AS/3IE]>185oK0B7RGP4QhAi18N3M0B7S804
Qi:90hNHT`B7ThX4Qhf118N>P@B<SX44R8Uh0gn1L0AjN6P4OGAX18EdJ0AoM6@4OfmT185cIP=jLf<4
NVmO17M[G0AgKel4LfIG17]WF0=^HU<4G59914e2>0@m=2h492LS12DX:0@P8R<39BPT12<W9`@_;R`4
BeUH182ASAn7ViHEoooo000Doooo7hNKUPA]KFD8@d<n0dA2?@@h<bh49RPT12`/:@@k=Rl4CdLk14M6
>`=UFdh4PGm/18N9N0B7Q7T4Qh=d18N<P0B7TXT3QiRC18NCRPB7SH44Qhj118b>P@B8RGP3Oh5`17Yh
J0AmM6P4QGAX17mdI0AoKf@4PG=V0gYcH`AjKel4Mf]L17M_G`AcIUL4NfMH0fiRD`ALDTT4CD8h13dd
;P@T9b<49BPX120R8`<U:2@48bLW12l^;0A;FEP4P96=7hNKUQGoool001CooolOQi^F16e]I@Q3@ch3
A48m13Pc;P@V:2@4;2`Y13/f;`A?Ac/4AdHk0fEKCPB1Of`4QhUh18N4N@B7Pg@4Qhb018NBR@>7V9<4
Qi>:18N=P@B7SX44S8j118R9N0=oPG04NWQX17edJ0B5M6P4OgAT17m_I0B1LfH3NW=S17Y_G`AgJe`4
MfmO17=VE`AkIeP3KV9C15aBB@A=@SP4?C@^12@W8`@U:2P4828S0bDX90@S9bL4;bh/14]IF0B0THdO
Qi^F5Oooo`005?oooaN7ViH4QiNC18>>RPAVH5L4>c`g13i0>`<o?cX4<2lZ13Pe<@@c=C44;cHc13Y2
>`A?DdX3HUY@17]iK0B7RGP8Qhf118N<O`N7TXT4Qi>;18N=P@B3RWT4PH5a18V1L0>8O6`4R81`17mk
I`AoMfP4OgMV17]gI0AkMfH3MfYO179[G`AgKUl4MViO17]aH@A_JEX3If=C16]JB0A<@CD4>C8]12d]
:@@Y;2P4:RdX0bDX90@W:bL4;Bh[10H40`B<X9/OQi^F5Oooo`005?oooaN7ViH4QiNC18>>RPAVH5L4
>c`g13i0>`<o?cX4<2lZ13Pe<@@c=C44;cHc13Y2>`A?DdX3HUY@17]iK0B7RGP8Qhf118N<O`N7TXT4
Qi>;18N=P@B3RWT4PH5a18V1L0>8O6`4R81`17mkI`AoMfP4OgMV17]gI0AkMfH3MfYO179[G`AgKUl4
MViO17]aH@A_JEX3If=C16]JB0A<@CD4>C8]12d]:@@Y;2P4:RdX0bDX90@W:bL4;Bh[10H40`B<X9/O
Qi^F5Oooo`005?oooaN7ViH4QiNC18>>RPAVH5L4>c`g13i0>`<o?cX4<2lZ13Pe<@@c=C44;cHc13Y2
>`A?DdX3HUY@17]iK0B7RGP8Qhf118N<O`N7TXT4Qi>;18N=P@B3RWT4PH5a18V1L0>8O6`4R81`17mk
I`AoMfP4OgMV17]gI0AkMfH3MfYO179[G`AgKUl4MViO17]aH@A_JEX3If=C16]JB0A<@CD4>C8]12d]
:@@Y;2P4:RdX0bDX90@W:bL4;Bh[10H40`B<X9/OQi^F5Oooo`005?oooaN7ViH4QiNC18>>RPAVH5L4
>c`g13i0>`<o?cX4<2lZ13Pe<@@c=C44;cHc13Y2>`A?DdX3HUY@17]iK0B7RGP8Qhf118N<O`N7TXT4
Qi>;18N=P@B3RWT4PH5a18V1L0>8O6`4R81`17mkI`AoMfP4OgMV17]gI0AkMfH3MfYO179[G`AgKUl4
MViO17]aH@A_JEX3If=C16]JB0A<@CD4>C8]12d]:@@Y;2P4:RdX0bDX90@W:bL4;Bh[10H40`B<X9/O
Qi^F5Oooo`005?oooaN7ViH4Qj2K18bUX0ARG544@C`c13ll=P=1@Sd4B4I013Pg<P@h>C@4?3T`13Q5
@0A2Bd43Cda3175XG0B1Q7@4QhAi18N8O@B7R7T7QhQj18N:OPB3PG84Ph9b17f0L0B3QG<3OgQT17Yd
H@AoN6@4OgMT17mkJPB1Lf<4NW=S0gmgHPAkKUl4MVYK17IVF0A_JU/4If9C0emGB0A7?cT4>S8^12P/
:0@T9b<48bLW11lR8`<G7Ql4724R13Dg=@@H4@l4Qi^G7hNKUQGoool001CooolGQi^F18NPV`B<YJ04
HUaA144l<`@o?3H3@D8m14Q6@0@h=c84>3Td13`i<0@hAD04@T]10dm<@`AaJ5`4PHAd18N4N@B7R7d4
QhQi1hN8NPB7RWh4Ph5b18>2LPAmP704PhEc0gmhI0AjM644OgQT17mgI0AoNfX4PG=S17YcH`=oMf84
NfiO17IZF`AfIUP4KfYK16MRD`=OEdP4Acli13Xb;P@X;2P492LS12<W9`@O8R<35ahO11`Q8P@e=cD4
614?18NKUan7ViHEoooo000Doooo5hNKUPB7X9/4S:FP169LD@A1?3<4?c`f0d52?@A8AT04>3Lb13Pi
=0@l>C04>4E0149;@@=?C4<4LFQL1864M0B7Q7T4QhQm18N8N@N7R7X4QhYn18>1LPB3PW84OH1`18>5
L`=oN6@4NWAQ17mhI0AoMf@4Og]Z185cH`AjLf<3OgMR17]^G`AfJU/4MVIH16mZF`AWHU<3GeM814Lo
>@@j<Rh4:2`X12@W8`@S9bL47b8S0aLN7`@L8B84=CLe11PA3`B7ViLOQi^F5Oooo`005?oooan7ViH4
OFmU13`j<PA1@3T3@44m13/k=@@f<Bd4>SH^13`m>@@i?cT4?Slh0cU0>`AUGE<4PHA`18N9M0B7Q7@4
QhEe1hN5L@B7RGT4S8j118R9N0B3N6T4OgET0gm`I0AoKf@4Og=Z17mgI`AoKf04PFmP1gY_G`AlKUl4
MViN17=VEPA/Ge04GeE60dLo>P@n>S04<2hY12T/:0@];2P49RPX124S90<R8b<4<bl[16=kN@B3ThlS
Qi^F5Oooo`005?oooan7ViH4OFmU13`j<PA1@3T3@44m13/k=@@f<Bd4>SH^13`m>@@i?cT4?Slh0cU0
>`AUGE<4PHA`18N9M0B7Q7@4QhEe1hN5L@B7RGT4S8j118R9N0B3N6T4OgET0gm`I0AoKf@4Og=Z17mg
I`AoKf04PFmP1gY_G`AlKUl4MViN17=VEPA/Ge04GeE60dLo>P@n>S04<2hY12T/:0@];2P49RPX124S
90<R8b<4<bl[16=kN@B3ThlSQi^F5Oooo`005?oooan7ViH4OFmU13`j<PA1@3T3@44m13/k=@@f<Bd4
>SH^13`m>@@i?cT4?Slh0cU0>`AUGE<4PHA`18N9M0B7Q7@4QhEe1hN5L@B7RGT4S8j118R9N0B3N6T4
OgET0gm`I0AoKf@4Og=Z17mgI`AoKf04PFmP1gY_G`AlKUl4MViN17=VEPA/Ge04GeE60dLo>P@n>S04
<2hY12T/:0@];2P49RPX124S90<R8b<4<bl[16=kN@B3ThlSQi^F5Oooo`005?oooan7ViH4OFmU13`j
<PA1@3T3@44m13/k=@@f<Bd4>SH^13`m>@@i?cT4?Slh0cU0>`AUGE<4PHA`18N9M0B7Q7@4QhEe1hN5
L@B7RGT4S8j118R9N0B3N6T4OgET0gm`I0AoKf@4Og=Z17mgI`AoKf04PFmP1gY_G`AlKUl4MViN17=V
EPA/Ge04GeE60dLo>P@n>S04<2hY12T/:0@];2P49RPX124S90<R8b<4<bl[16=kN@B3ThlSQi^F5Ooo
o`005?oooan7ViH4RXb214U7@`@j>cL3@T0k14@l<P@l?3D4<S@a13Pj=@@b=C84=3hk0c50>`A8A3/4
K6UJ17j1L@B1Q704QhUi18N9N0>3QGD4OX5]1864M@B9QG@4OgAT17mhI0=kLUl4MFmM17E_H0AiKf04
Ng=R17][G0AjJUl3MfYO17M^F`AcJUL4KfIF16aPD@ABAc`3@c/`12d/:0@T9b<48bLW12T[:0@V:2P4
71hO0alR8P@Y;2X40@0018NKUb>7ViHEoooo000Doooo7hNKUPB:S884BDM313Xk=`=2@3/4A3`b13`l
=@@b=344>3Xe138e<P@d?S/3<D0k14Q4>`A/JEX4OX5a1864L0B7RGT4QhUh0h>5M@AnPFd4PHAe18V5
M0AoM6@4OgQT0g]bG`AeKed4MFmP17U_H0AkLf84Nf]L17YZG`=gJUl4MfiK17=ZE`A_IUH4K61A1597
?0=3>c04;B`X12@W8`@S9bL4:B/X12HX:0@L7Ql37b8R12T/:P@10004Qi^G8hNKUQGoool001CooolO
Qi^F18Z<PPA9Ad<4>S/g0d90>`A4?384?3`e138d<@@h>SD4<SDb13@n>`<a@3/4B4@k16aYFPAnPG44
PHA`18N9N@B7RGP3PhEe17j1K@B1Q7D4RHEd17mdI0AoN6@3Ng9O17E_G@AeKf04NFmP17]cHPAkJe`4
NVYO0gMZG`AgKU/4LfYG16mVEPA/H544DTLl0d<k<0@];2P492LS12<W9`@Y:bP49RPX11`N7`<O8R84
:B`Z104000B7ViLSQi^F5Oooo`005?oooan7ViH4RXb214U7@`@j>cL3@T0k14@l<P@l?3D4<S@a13Pj
=@@b=C84=3hk0c50>`A8A3/4K6UJ17j1L@B1Q704QhUi18N9N0>3QGD4OX5]1864M@B9QG@4OgAT17mh
I0=kLUl4MFmM17E_H0AiKf04Ng=R17][G0AjJUl3MfYO17M^F`AcJUL4KfIF16aPD@ABAc`3@c/`12d/
:0@T9b<48bLW12T[:0@V:2P471hO0alR8P@Y;2X40@0018NKUb>7ViHEoooo000Doooo7hNKUPB0PW84
CTa414=3?P<j?CT4?Cll13<a<@@b<c04<cHa1411?@@l>C03;c<^130k>@A>CD@4KfAH17Q_HPAnN6X4
OWa]0h>5M@B3PG04OGQY1822L0AkMfH4MFQL0g]_G`AjIeP4NVMI17A[G0AkKel4MfYK179ZF0=cHU@4
JemD16=RD`AHDT@4Ed/n14Do<`<];2P4:2`X12DX90@P8R847B4R21LN7`<_;R/4>c@/118:1BN7ViHE
oooo000Doooo7hNKUPB0PW84CTa414=3?P<j?CT4?Cll13<a<@@b<c04<cHa1411?@@l>C03;c<^130k
>@A>CD@4KfAH17Q_HPAnN6X4OWa]0h>5M@B3PG04OGQY1822L0AkMfH4MFQL0g]_G`AjIeP4NVMI17A[
G0AkKel4MfYK179ZF0=cHU@4JemD16=RD`AHDT@4Ed/n14Do<`<];2P4:2`X12DX90@P8R847B4R21LN
7`<_;R/4>c@/118:1BN7ViHEoooo000Doooo7hNKUPB0PW84CTa414=3?P<j?CT4?Cll13<a<@@b<c04
<cHa1411?@@l>C03;c<^130k>@A>CD@4KfAH17Q_HPAnN6X4OWa]0h>5M@B3PG04OGQY1822L0AkMfH4
MFQL0g]_G`AjIeP4NVMI17A[G0AkKel4MfYK179ZF0=cHU@4JemD16=RD`AHDT@4Ed/n14Do<`<];2P4
:2`X12DX90@P8R847B4R21LN7`<_;R/4>c@/118:1BN7ViHEoooo000Doooo7hNKUPB0PW84CTa414=3
?P<j?CT4?Cll13<a<@@b<c04<cHa1411?@@l>C03;c<^130k>@A>CD@4KfAH17Q_HPAnN6X4OWa]0h>5
M@B3PG04OGQY1822L0AkMfH4MFQL0g]_G`AjIeP4NVMI17A[G0AkKel4MfYK179ZF0=cHU@4JemD16=R
D`AHDT@4Ed/n14Do<`<];2P4:2`X12DX90@P8R847B4R21LN7`<_;R/4>c@/118:1BN7ViHEoooo000D
oooo7hNKUPBda</4IU]E14=2?@<o?cX4A4E114Q1=0@h<B`4?Cdi13Pi=0@n@Sh3<cHb12Pf=0@/>SD4
=3hh15I?A`A]IEL4JfAK0g1/IPA`L6D4M7=U17Q`H0ATGe04EE960f1EAPA]He<4LVIH179OD0AbGe<4
MfYC17=VD@=_HU<4JeY<16MJC0AFC444@CL_13Xa;0<`;BP49BLS220R8`@L7Ql461hO11lR8`<T:2H4
HW]m17N1ORN7ViHEoooo000Doooo7hNKUPBda</4IU]E14=2?@<o?cX4A4E114Q1=0@h<B`4?Cdi13Pi
=0@n@Sh3<cHb12Pf=0@/>SD4=3hh15I?A`A]IEL4JfAK0g1/IPA`L6D4M7=U17Q`H0ATGe04EE960f1E
APA]He<4LVIH179OD0AbGe<4MfYC17=VD@=_HU<4JeY<16MJC0AFC444@CL_13Xa;0<`;BP49BLS220R
8`@L7Ql461hO11lR8`<T:2H4HW]m17N1ORN7ViHEoooo000Doooo7hNKUPBda</4IU]E14=2?@<o?cX4
A4E114Q1=0@h<B`4?Cdi13Pi=0@n@Sh3<cHb12Pf=0@/>SD4=3hh15I?A`A]IEL4JfAK0g1/IPA`L6D4
M7=U17Q`H0ATGe04EE960f1EAPA]He<4LVIH179OD0AbGe<4MfYC17=VD@=_HU<4JeY<16MJC0AFC444
@CL_13Xa;0<`;BP49BLS220R8`@L7Ql461hO11lR8`<T:2H4HW]m17N1ORN7ViHEoooo000Doooo7hNK
UPBda</4IU]E14=2?@<o?cX4A4E114Q1=0@h<B`4?Cdi13Pi=0@n@Sh3<cHb12Pf=0@/>SD4=3hh15I?
A`A]IEL4JfAK0g1/IPA`L6D4M7=U17Q`H0ATGe04EE960f1EAPA]He<4LVIH179OD0AbGe<4MfYC17=V
D@=_HU<4JeY<16MJC0AFC444@CL_13Xa;0<`;BP49BLS220R8`@L7Ql461hO11lR8`<T:2H4HW]m17N1
ORN7ViHEoooo000Doooo7hNKUPBT`[H4PX9`13ln=`<j?3L4>3Xf13Dk=`@a<S84<c<]13lm=`A1@cl3
BdU313Pi=`@j@3h4=T8m13Hj<`A0@cl4=T0l0cY1>0A:BD04CU1514i>A@AAC444BDDi0d=7>`A>AcX4
FDm016AOBPAWEdL4Ede415I:?P=ND4@4Ee5814a3?0A6>S44>C0/12h/:0<T9b<4828S11`N7``G7Ql4
92XW0c4_;0@;3`h4QYZE9hNKUQGoool001CooolOQi^F1:C2]PB2PW04?chg0cXl=`@h>SH4=C/g134b
<P@c<bd4?cdg1453?`=;BD<4>3Tg13Y0?P@f@Sd4=SXc1413?`@f@3`3>T4h14Y9@0A>D4D4CTi5155<
@@A9ACT3@dLk14i7>PAICd04I5m:16MGA`AGCD@4ETXn0ei@A0AGDDP4C4<l14Hj<@@i<2`4;R`X0b@W
8`@P8R<471hO31LN7`@T:RL3<Bl/10/?3PB6VYDWQi^F5Oooo`005?oooan7ViH4Y<:f18:2L0@o?SL3
>S`g13Pj=P@e>cL4<C8b13<c;@@o?CL4@D<o0d]9@`@h>CL4>T0n13I2?@@f>S<4@4<o13I0?0<j@CP4
BTU014i@A@A>CTD4DDa114U5>@=3Ac/4CTLj15U?@0ATGdX4IeM715M=A0AFBSh3GU1415MAB0A<@c`4
ASXa13T`;0@^;2P392LS120R8`@L7Ql<5ahO12@Z9`<a;b`42`l>18JJUBN7ViHEoooo000Doooo7hNK
UPBT`[H4PX9`13ln=`<j?3L4>3Xf13Dk=`@a<S84<c<]13lm=`A1@cl3BdU313Pi=`@j@3h4=T8m13Hj
<`A0@cl4=T0l0cY1>0A:BD04CU1514i>A@AAC444BDDi0d=7>`A>AcX4FDm016AOBPAWEdL4Ede415I:
?P=ND4@4Ee5814a3?0A6>S44>C0/12h/:0<T9b<4828S11`N7``G7Ql492XW0c4_;0@;3`h4QYZE9hNK
UQGoool001CooolSQi^F19jZ/`AED4`3@44l13m3?PA1@C`4;2lY12dd<PA1@ch4A4E10d]=A`AADDX4
Ce5614UAA`A1Bd<4?Slh13dg<@<e=S@4=C@a13ll=`A1?cX4>3dl148n>@=1>c84?3/c1451>PA4AS`4
BTDi14m;?PA8ACP3@T8j14To=PA3?C@4=C4]13<d<0@V:B@392LS124S8`@L7Ql461hO11LN7`@[:bL4
92LW0daGE0A7@cl[Qi^F5Oooo`005?ooob>7ViH4WZZc15E@C0=0@C`4?d<n1451?0@/;bT4;C@b1453
?PA4AD43Bde7155ABPA?DDH4BE57145;@`@n?cP4?CLa0cDf=0@e=344?c`g144o>P@h?C`4@Shi0d4k
<P@l>c<4@D4j14A6?0A:ACT4Cd/n14Q5>0=2@SX4BClf14<m=0@e<Bd4<c@`12HY90<T9b<48B<S11`N
7`@H7Ql45ahO12/[9`@T9bL3C5MD14M3?b^7ViHEoooo000Doooo8hNKUPBNZ[<4EE1<0d11?0@o@ch4
@D4l12`_:@@]=384@D<n14A5@@=;CDL4DE5:14mAAPA9DDL4@D]313ho>0@m=c43=CHd13Dd<@@o?3L4
@Clj13Pm?0A2?ST3@C/b13`k<`A1@CX4A4Hl14Y5>@A?Bch4B4Dh0d92>PA9?cH4@cdd13Da;@@c=304
9RTT0b@W8`@Q8b<471hO11PN7`@G7Ql4:b/W12@W9`=<Ee@4Ad<o:hNKUQGoool001CooolSQi^F1;77
`0AbIEh3?cdi13dl=`@m?CT4BD@n1492?PA1@cl4B4]50d52?@@l?SX4?CTf14Lk=@A8>c84?C`f134e
<@<d>SH4;Bl/12dc<P@i?3P4=CPc12/^:`<Y;bh4:BdZ12HX:0@[;b/4<3@]12hb;0@_;BX3;2XX12`/
:P@];BX4:2`X120V8P@P8b<37b8S120R8`@H7Ql45ahO12/[;`@[:bT4@3hh0dENG@B2Thh[Qi^F5Ooo
o`005?ooob>7ViH4/LO0179UGP<o?CT4?C`g13dm>@A9A3h4@T8n1453?`A8BdD3@D8m13`n>P@m>CH4
Ac/e14Pk<P@m?3H4<CDa0c@j=P@];b`4;C<b13Tl>0@e>3<4:bh[0bT_;P@Y;BX49RPX12/_:`@`=2d4
;S8/12l]:P</:RP4;2`Z12d]:P@X;2P482HR120S8`<O8R<4828S11PN7`@G7Ql4:b/_12/[:@A0?SP3
AEiM18:CSR^7ViHEoooo000Doooo8hNKUPBaal04LVEN0clm>@@m?3L4?Cdi14U4?PA2@Sh4@D<o14Q;
A@=1@Sd4?3hj13di=PA7>cD4B3/b13dl=P@a=C43=3Xf12d_;0@]<c84>C`h13Dh<`@[;R/3:Bl^12T]
:P@V:2P4:bl[130d;@@^<R`4;bdZ0b`Z:0@/;2X4;BdZ12P/:0@P9R8482<S0alR8`@P8R<461hO11LN
7`@[:bl4:b/Y140n>0=5GUd4PY>>:hNKUQGoool001CooolSQi^F1;77`0AbIEh3?cdi13dl=`@m?CT4
BD@n1492?PA1@cl4B4]50d52?@@l?SX4?CTf14Lk=@A8>c84?C`f134e<@<d>SH4;Bl/12dc<P@i?3P4
=CPc12/^:`<Y;bh4:BdZ12HX:0@[;b/4<3@]12hb;0@_;BX3;2XX12`/:P@];BX4:2`X120V8P@P8b<3
7b8S120R8`@H7Ql45ahO12/[;`@[:bT4@3hh0dENG@B2Thh[Qi^F5Oooo`005?ooob>7ViH4TZbQ1:fl
^@=DD4X4?Cdi1411?@@o?cX4ADQ313/k=@@j?SX3>c/f13/n>PA9C484@DE013/o?0@m?CT4?C`g0d4o
>`@h=C@4;S@a130_:`@c;RX4;B`X0bDZ9P@X:bL4;Rl[130]:`@Y:RL49RTV12P[9`<_;b/4;B`X12T[
9`@U9b<492LS124S8`<P8R<85ahO11lR8`@]<B`4=c8^16ijM`=lSXX_Qi^F5Oooo`005?ooob>7ViH4
TZbQ1:fl^@=DD4X4?Cdi1411?@@o?cX4ADQ313/k=@@j?SX3>c/f13/n>PA9C484@DE013/o?0@m?CT4
?C`g0d4o>`@h=C@4;S@a130_:`@c;RX4;B`X0bDZ9P@X:bL4;Rl[130]:`@Y:RL49RTV12P[9`<_;b/4
;B`X12T[9`@U9b<492LS124S8`<P8R<85ahO11lR8`@]<B`4=c8^16ijM`=lSXX_Qi^F5Oooo`005?oo
ob>7ViH4TZbQ1:fl^@=DD4X4?Cdi1411?@@o?cX4ADQ313/k=@@j?SX3>c/f13/n>PA9C484@DE013/o
?0@m?CT4?C`g0d4o>`@h=C@4;S@a130_:`@c;RX4;B`X0bDZ9P@X:bL4;Rl[130]:`@Y:RL49RTV12P[
9`<_;b/4;B`X12T[9`@U9b<492LS124S8`<P8R<85ahO11lR8`@]<B`4=c8^16ijM`=lSXX_Qi^F5Ooo
o`005?ooob>7ViH4TZbQ1:fl^@=DD4X4?Cdi1411?@@o?cX4ADQ313/k=@@j?SX3>c/f13/n>PA9C484
@DE013/o?0@m?CT4?C`g0d4o>`@h=C@4;S@a130_:`@c;RX4;B`X0bDZ9P@X:bL4;Rl[130]:`@Y:RL4
9RTV12P[9`<_;b/4;B`X12T[9`@U9b<492LS124S8`<P8R<85ahO11lR8`@]<B`4=c8^16ijM`=lSXX_
Qi^F5Oooo`005?ooobN7ViH4Y[Je0fmJE0A5@Cd4@44m13lo>P@_=C44@TI114M:A0=6BD<4=STd13Lg
<@@g=2h4=3Hb13Hh<`@]<3@3:C<b13<c<@@b;B/4;2``12D[:0@V;2P392LS12D[9`PT:bL48bLS11hR
8P@P9R839RXV12@W8`@N8R848bHS12@W:0@Q8b@35ahO120R8`@Z;2P4=SHa13<_;0QkS8PbQi^F5Ooo
o`005?ooobN7ViH4Y[Je0fmJE0A5@Cd4@44m13lo>P@_=C44@TI114M:A0=6BD<4=STd13Lg<@@g=2h4
=3Hb13Hh<`@]<3@3:C<b13<c<@@b;B/4;2``12D[:0@V;2P392LS12D[9`PT:bL48bLS11hR8P@P9R83
9RXV12@W8`@N8R848bHS12@W:0@Q8b@35ahO120R8`@Z;2P4=SHa13<_;0QkS8PbQi^F5Oooo`005?oo
obN7ViH4Y[Je0fmJE0A5@Cd4@44m13lo>P@_=C44@TI114M:A0=6BD<4=STd13Lg<@@g=2h4=3Hb13Hh
<`@]<3@3:C<b13<c<@@b;B/4;2``12D[:0@V;2P392LS12D[9`PT:bL48bLS11hR8P@P9R839RXV12@W
8`@N8R848bHS12@W:0@Q8b@35ahO120R8`@Z;2P4=SHa13<_;0QkS8PbQi^F5Oooo`005?ooobN7ViH4
Y[Je0fmJE0A5@Cd4@44m13lo>P@_=C44@TI114M:A0=6BD<4=STd13Lg<@@g=2h4=3Hb13Hh<`@]<3@3
:C<b13<c<@@b;B/4;2``12D[:0@V;2P392LS12D[9`PT:bL48bLS11hR8P@P9R839RXV12@W8`@N8R84
8bHS12@W:0@Q8b@35ahO120R8`@Z;2P4=SHa13<_;0QkS8PbQi^F5Oooo`005?ooobN7ViH4V;N[0i2F
R`A9AT04?T0k13lo>PA6@ch4>Slk13Tn>P<k>SD4=3D`12db;`@];2P4<S@`130`<0@b<2l3:bXW12/[
;P@R9bP47R8R128V9`@S9bP3828T124V9`@O8R<48BHW120R90@T9bP49b/X0b8W:0@P8R@45ahO11DM
7`@E7Ah45QhO0b<W:0@T:2<47b8R12@T8@A]O7P4MX5n=XNKUQGoool001CooolWQi^F19RgZ`>@UX/4
BDI013i0>`@o?cX4AT<n13Xo>`@i?SX3>cXe13@e<0@]<Rl4;B`X138d<0@`<304<S0_0b/Z9`@[:bh4
8RLX11hR8P@R9RL48bLX0b0R90@Q9RL47b8S124V9`@P8R@492LX12L[:0<R9bP4828T11LN7`@E7Al4
5AdN11HN7`<S9bP492PS11lR8P@T9244KGah17J1OSJ7ViHEoooo000Doooo9hNKUPBH]j/3T9J;14U6
@0@n@3/4?clj14I3?P@j?c/4>Chj0c/j=@@d=C04;C8_12d/:0@b=304<30`138`;`<[:RL4:b/^128W
:0@N8R848RHW12<W:0<P8R@48BHW11lR8`@Q9RL4828T12@W:0@W:bP38RLX120R90@G7Ql45AdO11DM
7P@F7Ql38bLX12@X8`@O8R8492@Q16elN0AfPGhfQi^F5Oooo`005?ooobN7ViH4V;N[0i2FR`A9AT04
?T0k13lo>PA6@ch4>Slk13Tn>P<k>SD4=3D`12db;`@];2P4<S@`130`<0@b<2l3:bXW12/[;P@R9bP4
7R8R128V9`@S9bP3828T124V9`@O8R<48BHW120R90@T9bP49b/X0b8W:0@P8R@45ahO11DM7`@E7Ah4
5QhO0b<W:0@T:2<47b8R12@T8@A]O7P4MX5n=XNKUQGoool001Coool[Qi^F0lg_jPBDTXP4@d4j13Xl
=`@j@3/4?D8m1456@@=4@T84>38_13@c;`@[;BT49RTV12L[9P@Y:bH3828S11dQ8@@S9RL49BPX120R
8`@R9RL38B<T128V9`@Q8b@4<Bh[11XO80@P9RH49RXX0bDX:0@H7Ql45ahO11/N7`@T9bL49bTY0b<W
9`@c<2d4Acdb16MKB@A6?2d4QYZE=XNKUQGoool001Coool[Qi^F0lg_jPBDTXP4@d4j13Xl=`@j@3/4
?D8m1456@@=4@T84>38_13@c;`@[;BT49RTV12L[9P@Y:bH3828S11dQ8@@S9RL49BPX120R8`@R9RL3
8B<T128V9`@Q8b@4<Bh[11XO80@P9RH49RXX0bDX:0@H7Ql45ahO11/N7`@T9bL49bTY0b<W9`@c<2d4
Acdb16MKB@A6?2d4QYZE=XNKUQGoool001Coool[Qi^F0lg_jPBDTXP4@d4j13Xl=`@j@3/4?D8m1456
@@=4@T84>38_13@c;`@[;BT49RTV12L[9P@Y:bH3828S11dQ8@@S9RL49BPX120R8`@R9RL38B<T128V
9`@Q8b@4<Bh[11XO80@P9RH49RXX0bDX:0@H7Ql45ahO11/N7`@T9bL49bTY0b<W9`@c<2d4Acdb16MK
B@A6?2d4QYZE=XNKUQGoool001Coool^Qi^F1<g_jPBHSH<4BTY413Pi=0A1@Sd4A4I10dY:@`@l@CX4
>3Xe13<^<`@T9bT4:b/X12@W:0<Y;2P4:RdX12DX:0PP8R<47b8R0b0R8`@O8R849b/X120V9`@nAD`4
@D]=138`=P<R8b@49RPX12/]:@@[;RT492PW13Lh=0<m>C<4<c4/14Q1>`A[O7h4PI6;>XNKUQGoool0
01Coool^Qi^F1<g_jPBHSH<4BTY413Pi=0A1@Sd4A4I10dY:@`@l@CX4>3Xe13<^<`@T9bT4:b/X12@W
:0<Y;2P4:RdX12DX:0PP8R<47b8R0b0R8`@O8R849b/X120V9`@nAD`4@D]=138`=P<R8b@49RPX12/]
:@@[;RT492PW13Lh=0<m>C<4<c4/14Q1>`A[O7h4PI6;>XNKUQGoool001Coool^Qi^F1<g_jPBHSH<4
BTY413Pi=0A1@Sd4A4I10dY:@`@l@CX4>3Xe13<^<`@T9bT4:b/X12@W:0<Y;2P4:RdX12DX:0PP8R<4
7b8R0b0R8`@O8R849b/X120V9`@nAD`4@D]=138`=P<R8b@49RPX12/]:@@[;RT492PW13Lh=0<m>C<4
<c4/14Q1>`A[O7h4PI6;>XNKUQGoool001Coool^Qi^F1<g_jPBHSH<4BTY413Pi=0A1@Sd4A4I10dY:
@`@l@CX4>3Xe13<^<`@T9bT4:b/X12@W:0<Y;2P4:RdX12DX:0PP8R<47b8R0b0R8`@O8R849b/X120V
9`@nAD`4@D]=138`=P<R8b@49RPX12/]:@@[;RT492PW13Lh=0<m>C<4<c4/14Q1>`A[O7h4PI6;>XNK
UQGoool001CooolbQi^F1=?kmPBGRX04Ee9;13Pi=0@f?3P3@dQ3159>B0A3?C<4?3P`12d^:@@R9bP4
828S0b4V8P@S9bL8828S12<W:0@P8b@38bLX120S90@N8B84=Cln13<d>@A5@d<4G5Y>0e=<B@ACCTP4
AT4k12d^:P@e=C04<C8_0d11?0AEB3h4MX>017n9QCj7ViHEoooo000Doooo<XNKUPCCnoH4UhZ015MB
B`@h>C@4=S`h0d=8@`ABCTP4@cdc13`h<0@];RT48RLX120R8`<Q9R848bLW220R8`@S9bP482<T0b<W
:0@P8b@47R4R13Do?P@c=3T4AD=315aJCP=CC4T4Ddi814I1>`@];RX4=CD`134b;`=0@C`4EDPn17J3
P0AoRHDnQi^F5Oooo`005?oooc:7ViH4do_f19N:P0AGDT/4>3Td13Hl>0=3B4<4DTi814<m<`@l>304
;BhY128W:0@P8R<38BHR12<W9`PP8R<48bLX120S90<S9bP482<T11hQ8P@e?ch4<c@i14E3@`ALFTh3
Dda915=>B0A6@C/4;BhZ13De<0@a<Rl3@44l15E8?PAfPh04OhV5?XNKUQGoool001CooolbQi^F1=?k
mPBGRX04Ee9;13Pi=0@f?3P3@dQ3159>B0A3?C<4?3P`12d^:@@R9bP4828S0b4V8P@S9bL8828S12<W
:0@P8b@38bLX120S90@N8B84=Cln13<d>@A5@d<4G5Y>0e=<B@ACCTP4AT4k12d^:P@e=C04<C8_0d11
?0AEB3h4MX>017n9QCj7ViHEoooo000Doooo<XNKUPB1UI44cOG`18IfI0AJE4/4AdE00d96@@A;CDL4
DEA>13hk=@@j=c84AD4k1451>P<b;bX4:R`X12HY:0@U:2P8828S0bHZ;P@V:BX4:B`X11lS8`@]=Bh4
<3Hc124V9P<P:2D47bHT120U9P@[:bP4<34^13`i<0=BBC/4PX^616ehNPB7VYHnQi^F5Oooo`005?oo
oc:7ViH4PIFA1<gel0B6MV@4FUA;14M5@0=2AT44Bde7155DCP@n>cD4>SLb14E1>`A1@CX3<RlZ12X/
:0@V:BP49BPX220R8`<V:Rh49RTZ12T/:0@O8b<4;CD^130f<`@Q9RH382PU11lV90@P9BH4:b/X130a
;P@l>C03DTTk18:;QPA]N7X4QiZF?XNKUQGoool001CooolbQi^F186ET@C=mO04QWIT15YDB`A7AD03
@TI114]=A`AAE4h4?S/e13Xg<PA5@C/4@D4j0c8_:P@Z;2P49RTX12DX:0PP8R<39RX^12HY:P@Y;2P4
7b<S12de;P@`=S<48BHV0b0X9@@O9R@482DV12/[:0@`<Bh4?3T`0e99>`B2RhH4KGQj18NJUSj7ViHE
oooo000Doooo<XNKUPB1UI44cOG`18IfI0AJE4/4AdE00d96@@A;CDL4DEA>13hk=@@j=c84AD4k1451
>P<b;bX4:R`X12HY:0@U:2P8828S0bHZ;P@V:BX4:B`X11lS8`@]=Bh4<3Hc124V9P<P:2D47bHT120U
9P@[:bP4<34^13`i<0=BBC/4PX^616ehNPB7VYHnQi^F5Oooo`005?ooocZ7ViH4dooo18>2L@A1@3P3
=SXg14Y=B@AGG5H4GEeD13hk=@@];Rh4<bh[0d4o>P@n?SP4:2XZ120R8`@/<3@4<3<h0cDj=@@b=3L4
@T91134a=@@m@T84@d9114]6@0=7@ch4@Shh14M3?0ABDTL4AdDn15YDB0>3ShX4TZNK18FHU4:7ViHE
oooo000Doooo>XNKUPCCool4Ph9a1450>0<f>SL4BTe915MLEPAMGE@4?S/e12d^;P@c;R/3@Clj13hn
>0@X:RX4828S12``=0@`<cP3=CXe138d=`A2@T44<C4e13e2@PA3@T44BdI00dM3?PA2?SP4Ad<l159B
A`A7ACh4FUA80h>?RPBBYi/4QIRD@XNKUQGoool001CoooljQi^F1=?oo`B3PW44@D0h0cHj=`A:CDT4
EeaF15eME0@n>cD4;Bh^13<^:`=1?cX4?Shh12PZ:P@P8R<4;30d130c>0<e>SD4<S@g1492@@@a<CD4
?D9214=2@@A;AT03Ad<n148n>0A7@c`4DU9714M5?PAJE4P3Phn:19:WV`B5V9A2Qi^F5Oooo`005?oo
ocZ7ViH4dooo18>2L@A1@3P3=SXg14Y=B@AGG5H4GEeD13hk=@@];Rh4<bh[0d4o>P@n?SP4:2XZ120R
8`@/<3@4<3<h0cDj=@@b=3L4@T91134a=@@m@T84@d9114]6@0=7@ch4@Shh14M3?0ABDTL4AdDn15YD
B0>3ShX4TZNK18FHU4:7ViHEoooo000Doooo?XNKUPCCmOD4d]kP0feYH`@k?SX4>c`i14IAD`AQIF84
JFIL16I[H`=8AdD4?D=415ILH`A^LFd4D4]71412B0<n?T<4DeEI14A6APA;ASd4>chk14Y6?`A9?cX3
BCdd14Q3?@A?C484Ge9415]6>0AILWD3PIJ@18NJUTJ7ViHEoooo000Doooo?XNKUPCCmOD4d]kP0feY
H`@k?SX4>c`i14IAD`AQIF84JFIL16I[H`=8AdD4?D=415ILH`A^LFd4D4]71412B0<n?T<4DeEI14A6
APA;ASd4>chk14Y6?`A9?cX3BCdd14Q3?@A?C484Ge9415]6>0AILWD3PIJ@18NJUTJ7ViHEoooo000D
oooo?XNKUPCCmOD4d]kP0feYH`@k?SX4>c`i14IAD`AQIF84JFIL16I[H`=8AdD4?D=415ILH`A^LFd4
D4]71412B0<n?T<4DeEI14A6APA;ASd4>chk14Y6?`A9?cX3BCdd14Q3?@A?C484Ge9415]6>0AILWD3
PIJ@18NJUTJ7ViHEoooo000Doooo?XNKUPCCmOD4d]kP0feYH`@k?SX4>c`i14IAD`AQIF84JFIL16I[
H`=8AdD4?D=415ILH`A^LFd4D4]71412B0<n?T<4DeEI14A6APA;ASd4>chk14Y6?`A9?cX3BCdd14Q3
?@A?C484Ge9415]6>0AILWD3PIJ@18NJUTJ7ViHEoooo000Doooo@XNKUPBN_;03g?ch18V7S0AADDh4
@DI414UJGPALIFD4E5]G0f9XGPAXJF@4GEmD15ACCPACDDT4DDi30d=2@0@b<bd4>3/g14A6@@A0@Cd4
BD8i15M8?@=JCT@4IUM;15E5?0A=Ce44Y;Rk17j>RDf7ViHEoooo000Doooo@XNKUPBN_;03g?ch18V7
S0AADDh4@DI414UJGPALIFD4E5]G0f9XGPAXJF@4GEmD15ACCPACDDT4DDi30d=2@0@b<bd4>3/g14A6
@@A0@Cd4BD8i15M8?@=JCT@4IUM;15E5?0A=Ce44Y;Rk17j>RDf7ViHEoooo000Doooo@XNKUPBN_;03
g?ch18V7S0AADDh4@DI414UJGPALIFD4E5]G0f9XGPAXJF@4GEmD15ACCPACDDT4DDi30d=2@0@b<bd4
>3/g14A6@@A0@Cd4BD8i15M8?@=JCT@4IUM;15E5?0A=Ce44Y;Rk17j>RDf7ViHEoooo000Doooo18NB
SPB7UI51Qi^F1=?ei@CGm_84e=oH16icO`AMHFH4OX6:0h:1Q`A/IEh4G5]E15UJE0A/J6D4KfMR0g1[
H0AfKfL4JVAG15iNE@A_JV84GF9H155JC`=5AD04EV9V1;GDfPBigM<4PI:>DHNKUQGoool001Coool4
Qi:>18NETD67ViH4doGU1=OflPCDgmP4KW=o15eQIPAnPHX3PX6716aUGPALFeD4FEYD16aXI@A_If83
L6]P17I_I`AZI5L4GUiE16mZHPAMHUP4DEY?0dE5@0AFHVH4]MCJ1;WMd`B1TXiAQi^F5Oooo`005?oo
o`B7TXh4QiFA@HNKUPCCmND4eoKb1=COf0A^Lgl4GF5V17j1RP>2PHL4K6EN15aKE@AIFU@4K6QU16mW
HP=`Jf04MVmW16YTE`ANGUD4KfYR15eRF0AAFTl3ADE015IRIPBee=X4^MgC186BSU67ViHEoooo000D
oooo18NBSPB7UI51Qi^F1=?ei@CGm_84e=oH16icO`AMHFH4OX6:0h:1Q`A/IEh4G5]E15UJE0A/J6D4
KfMR0g1[H0AfKfL4JVAG15iNE@A_JV84GF9H155JC`=5AD04EV9V1;GDfPBigM<4PI:>DHNKUQGoool0
01Coool4Qj2K18NJUTV7ViH4TZbQ1=7]f@BdeLh4Y<2_0jS2b0Bac=@4/;c417ImS@AEHfl4DU]L0eIH
DPA>EE04FE]G155CCPA4Ach4Bd]217Z8P`?Mo?D4Vk^_18BFTUV7ViHEoooo000Doooo18NPV`B7VYI9
Qi^F19:/X@CAkMT4]=G>1:C0[`>X`/P4/LcD1;2la0AfOHd4EF=_159KG0=FF584CUE@15UKE`AADdh4
A4Ln14];@PAjR8<3gOce19^k[`B4UY9IQi^F5Oooo`005?ooo`B7X9/4QiZFBHNKUPBB[:44dNgI1;CE
cPBT`:l3Z<;81;7<e0B`_<@4MWf=15ESK`ABFe`3EUQB14iED0AIFeL4DE=>14A7?PA;Bd84NXR30mgl
m@BK^jl4Q9JBFHNKUQGoool001Coool4Qj2K18NJUTV7ViH4TZbQ1=7]f@BdeLh4Y<2_0jS2b0Bac=@4
/;c417ImS@AEHfl4DU]L0eIHDPA>EE04FE]G155CCPA4Ach4Bd]217Z8P`?Mo?D4Vk^_18BFTUV7ViHE
oooo000DooooHHNKUP>B[9/4QYjK19jkZ`C5h<h4`Mc:1<KWi0?6h=/4a^3L1<KVh@C<jnH4dOKf1=3_
k`AoUY03QiZFHHNKUQGoool001CooomQQi^F0i:/V`B6WY/4W[^[1<GPcPC1g<X4a^OT0lKPf`C6h=`4
a^KQ1<c[iPCAm_H4d>o_17nFT0>7VYIQQi^F5Oooo`005?ooof67ViH3TZbK18JNV`BN^j/4aN3>1<7L
bPC6in@3a^3K1<KPg0C6i^44c>_V1=7fmPC@knl4OiJ@0hNJUV67ViHEoooo000DooooHHNKUP>B[9/4
QYjK19jkZ`C5h<h4`Mc:1<KWi0?6h=/4a^3L1<KVh@C<jnH4dOKf1=3_k`AoUY03QiZFHHNKUQGoool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
09Woool30000Q?ooo`00W?ooo`030000oooooooo087oool007_oool400000oooo`800003oooo1000
00?oool400000_ooo`<00003oooo0`0000?oool20000O_ooo`00Noooo`030000oooooooo00?oool0
10000?ooooooo`0000;oool00`000?ooooooo`03oooo00@0003oooooool00002oooo00<0003ooooo
ool00oooo`040000oooooooo0000Poooo`00O?ooo`030000oooooooo00;oool010000?ooooooo`00
00?oool00`000?ooooooo`02oooo00@0003oooooool00002oooo100000;oool010000?ooooooo`00
08?oool007goool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00;oool300000oooo`800004oooo100008;oool007_oool010000?ooooooo`0000;oool010000?oo
ooooo`0000;oool010000?ooooooo`0000Goool00`000?ooooooo`2=oooo001loooo0P0000Coool2
00001?ooo`800005oooo0P0008ooool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(225) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9A1ADA2
97907C9F95819F95879F9B8C9F95879F9B8D9F9B8D9F9B8D9F9B8C9F9586A196809A907A
9B8973947E6A967E698E79658E79658E79658E79658E786390735D89735C89735D89735C
8067539FADA99FADA99FADA99FADA99FAEA99FA6A29FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FA9A59FA8A49FADA99FA9A59FA8A49FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FA9A59FA8A49FADA99FADA99FADA99FADA99FADA99FADA9A4B2A8
9C93839F95819F95839F9B8C9F95879F9B8D9F98859C907A97907A978A789986728F806C
8F7E698C77648E76628A76628E79658E79658E75618E756190736289735E89735D898372
80796D9FADA99FADA99FADA99FADA99FB1AD9FAAA69FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FB1AD9FA7A39FA8A49FB1AD9FAAA69FADA99FA9A59FA8A49FA9A59FA8A49FADA9
9FADA99FADA99FADA99FB1AD9FAAA69FADA99FADA99FADA99FADA99FADA99FADA99CA99F
9A927A9F95879F92829F9B8D9F95879F94859C9484938E7D898473927C6C937866917D69
8E826D8E806C937F6A89735F87725E87725E87756187735B8B735D89735F89736294826F
949E999FADA99FADA99FADA99FADA99FADA99FA9A59FA8A49FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FAEA99FA6A29FADA99FADA99FADA99FB1AD9FAAA69FB1AD9FAAA69FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9A4ADA2
9C90809F95859F95879F92849F98899F9583A4998AB09B8B9B9A889E9282A28375977965
97776897776A93716490716189735F89735F89735F8973628C77628D766289735F806753
9FADA99FADA99FADA99FADA99FADA99FADA99FB1AD9FAAA69FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FB1AD9FAAA69FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FB2A8
9F937C9F957F9F95839F95879F95879F958B9F99899F9D8EA49D929A9C82A18F819C8978
9C8771997F6D9C88749C7567906B5F90776C8D79678C735F8C705D9075618C7B6885705B
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FAEA4
9F95819F95859F95819F95839F95879F998B9F95879F94859F9B8DA49D92A1A0899E937F
9A88779E8B76947D6A9C8671937C698E6E5A937E7189796787735F8B735F8D817692877A
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FA9A59FA8A49FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9968C80908E83
9F95859F95819F95839F95819F998B9F95879F9B8D9F9D8E9F998B9F9B8C9F958BA49987
A192799E88759E877499816D9979699378638B6D588B76638C735F8D735F837666979A95
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FB1AD9FAAA69FADA99FADA99FA9A5
9FA5A19FA8A49FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA96D62546C7B6F928979
9F95819F958B9F95899F95859F95879F9B8C9F92809F97859F98899F98899F95839F9986
9C8F7D9C86759A80719B836A9178629179659376628D735F887B68937D698A74609CA8A4
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FB1AD
9FAFAB9FAAA69FADA99FADA9
9FADA99FADA99FA9A59FA8A49FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99396965B372E2130369C9383
9F99859F998A9F998B9F998A9F92849F9B8D9F9D929F95859F98859F8A7B9C7F74957B68
97866F9A8472978771937E6D947E679377648B785F8B735D856D5B87735F8369559FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FB1AD9FA7A39FA8A49FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA9A1B0AC5B443197968466685B9F9587
9F92829F98899F92849F98899F95879F92849F97899F9B8C9C92829791799C84769B836F
907B67927D69977D65967F6889756191725E93756390735E8D735F8C77648365529A9A93
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FA9A59FADA99FAAA69FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA94F3B2BA1A4987378719C93839F9581
9F95879F95879F95839F95839F95879F998B9F95879F9889A1756D9A645C975954975651
94555094675C91736291735E8E705C8B70598A735D8E735F90735B886C57835F4B887565
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FA9A5
9FA8A49FADA99FADA99FADA9
9FADA99FADA99FB1AD9FAAA69FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA9939692E0DED7696C669F98899F95869F9581
9F95879F927F9F8E7C9F8E779F92809F92849F8B809F7F78A18175975F519350418F554B
91574B8F4D49935D5387665687735B8B6D5A88705C8E735F9373628C725C9372607E5A44
9083759FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FB1AD
9FAAA69FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA95243393A494597927E9F957F9F95839F9581
9F95839C927E9784719A8B799F93809F8E7B9C766695594D916D5E8556418474618C7E6A
935444834033914C418D574D89685B897252856E538A735D8E735F8E77628E6E5C8E7662
876B569FA49C9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FA9A59FA8A49FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA9837E7AB89D875258519C93839C8E7C9A91829F9989
9F8E7E9E856C8F725B8D6B62996158631E125D54479775679C7165AFB4AB986155885947
806F51776A576A4B37723E31865045856C538C6A538C7460927E669379628E77648E735F
815F4B907B699FA49C9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FA9A59FA8A49FB1AD9FAAA69FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA96152474D5D5D8A83759F9581A1907C9781709F9889
9F95849F765C8E664E5D1D15635F5BCBD9CD838C86A3C1BB9EA9A99C948EA5C8B0AEA79A
B1B3AE908A7E7454453D2F1C5736297E5E4F887057927261927D6C99856A93765F8E7561
8E7461816F648D90949AA4A09FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FB1AD9FAAA69FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9969EA25E3D3311262E9790789F9583A4A28B9C8F7C9F9587
9983709071517A452E7226144A201D8862559778679A83759F9C889F927C9E887890776A
998571B09582B9A3889C84734635274F32297D5D4C886F5B97867099857396816A8E715D
8E6D5B8B6E527C7B727D7E7D909AA09FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA96D625434221985736850504E9C937F9F8E799F87739F8E779F957F
A28F77A78575A5AA8ECDC6A6837F729C7770977C6C8E6456936862916058915E4F883D31
8C4C437F544897735D936154996F6041190C51353085685A927F689B896E9679628B7863
8A756293715D9E978794938E8388939FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FA9A59FA8A49FADA99FADA99FADA99FADA99FADA9
9FADA99FADA9969A9A34261C291E1718383B8F85799F927D9F8D809C8A7D9A8E7A9F8A7D
A28B798B634B856D5F9C978B9FA690A49F91A6A596A3A3939EAB91A8947D9E99809B9476
9B856B91625396685D965143904230833323471F1768433F8D74629B856E967C63906F5B
886D5B8E72605232226364539294959AA4A09FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FB1AD9FAAA69FADA99FADA99FADA99FADA99FADA9
9FADA99FADA9A3B2B2FFEBDAC7AB8D5E5C519A92809F96809F9C7FA4877F9C877C9FA284
A2917C9F7E6A8063519A8A799F9B8D9F998A9F92849F9B8D9F8D85A18A7B9A84719B8372
947E67937B6183795C8E7C62968068A1846A8F7064735344836D5797806A967C6390775D
88715C8E74617E64542C2E299098909CA8A49FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA9AEAE9497958EA4A6979E9382958C789A95819F93839FA28C9F928B9F998C
A59D899E8B738A64538B73609A91809F9F909F998A9F95879FA88FA18F7C977863977A63
8E795D87705C7E6A50825F4C82654C82624C86694C856F628A7661947A6993745F8B6B5B
85705887705B54382C2834348A90959FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99CA6A29AA69E9C8E76957C638E857B8D8C829C90809F99899F9D8E9F998B9F9F90
A4948CA38D7E9E816A8F6B5C9783729F97899F8F849C82759A94819E907897826D8E6351
8E6D5C8E6952826650846A53876A50886D4E84624A84675392766291766292735F896D5A
896E5E8C77623924210616118185849FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA9A4A6949C9A8E9E8C78937E6B9C7E628F867F9F877C9F95879F9B8D9F9B8D9F9B8D
9FA88FA49380A08E7290705A9277679F95879FA893A4938B9C9387A598899985739A846D
906E5B8E6E58845F4E84655183695B90705C967A678D76629178639175619377628D705C
896E5885705B512F22151715373B389FA8A49FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FAEA49C927A9376598E7A679780759C937F9F8F809F95879F9F949FA0949F9B8D
9F9B909F9D8BA2907B94856A8E76609A8E7D9F98859F99879F998AA19984987E6A917662
8B735F9077628B705288644C8366548B7566947D6D99806C9685708E7D698B76628B7762
8971618C7B66CF9262683C292218134549479FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9F9E929983738E5345956D5F7A665A88987F9F8F7F9F95819F95879F97869F9D909F9B8D
9F9B8C9C9282A199829C92809A8D789C937C9C8A7B9A85749F8B7D9E8270987A628B6B59
886754856C4F7F604C7E624C856C5A8A7964927D6C9B836F967A668E76629375618D735B
8C6F598C716098806DB0876ABFA8976E7A779FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9F9F9CA27B6F976554895D529274628F8E809F998D9F99899F95879F9B8D9F9B8D9F9889
9F9885A196829C907A9E8A779790809F998DA4A6939C8F859F997FA28777937A63886955
836450795E4F8B6B558574618D766392806D92826F9B836F967E698E78638E6F5F936B62
896F5C8A6F628C705685675381604DA4B1AD9FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FA296
9FA992A28E749370538865548A79699C93809F95879F9F909F95879F94859C907D9A947E
9F8A7FA186799588739C8370978C799F92809F98859F95879F9089A27D6C9775608A6B57
886A56836D5A80715A85715C8C7966977F6C94806C977C68967A668E735F8E6F598B6D59
8B715B88725F97806F8B6E5A7458488D94919FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9999782
8767526D513C6953437564558D7F6F9F95819F92849F94859F98859F927BA1927F958475
958A729780759A8E7D9A8F7B978E779F95879F95859F95879C9E859E8C779775608A6B57
8467548B6956856E5E8B7464927969907B67978471948570967C678E7F6A8B78638B705C
896A5E8871628860458A65538D60478062569FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99F8F77
5F3820573C2F43312A4344429083769F95859F95839F957F9F95879F998CA4978BA1A08E
A38F82947C6C8F6F61907D6B9588759A927E9F95879F9583A18D7E98816D8F6A5F866653
81634D7E66548C726087735D8C72618F776891705F8C76638E766287725E8B756189725D
896D5C85685889785778543C876B588051439FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FA69EA7A89E
B170565437274C352C2F393C90836F9C927B9A92849F958596856D8878647F6853745D4A
7865567C625988685D8568578D74649287759F95879F958BA194829D816E90735384624C
8567517A63507B6453796D5A7F6D5B8579648E7B678A7461937C678D766289735F89725D
896D5C896E5F7A523E6035246B4D377B4D399FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99C9D8D9E8E7B
3F180F2A1B152C241E1B32379284729F927D9C90789F9583AB9D858D77627A665152473D
39322B3C3323524135683E2C6132246C51449A8E7D9F9587A199849D846E907058816E50
7D60477C6A58927763947C678C746189695B856E5D7F705F8E7965907863836F5B7B6F5B
81715C89715F8D624870453168413478412D9FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9A1B0ACA8AFA29C7D65
865244301E1832201A10262E9C917E9A947F9A907C9F9581A49D8CAE957EA98E7D805D48
3E281F32241B36342F5D5443846E5B7B645897917E9FA195A1A1929D8971896652795743
5A2212503931775B41735942614B38695A47836A59786B5587725C8B75618B6D587F6A57
7C6A5C836756744F3E644A396C574A7F4A3CA4B1AD9FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FA5A19FA8A49FA9A59FA8A49FADA99FADA99FADA99FADA99FADA9431E153E47459E8670
905B4539292C241C17051D26958C789F95819A907B978E7A9A927EABA59292846CC4977B
B79274936F52815A3F736D56806D598F7463978B789F9786A199899D8770997054815E4B
8E644856443E504844150C0B342D26423A313B2D21403C355C4A356D563F876C577F6B59
7C6D587F624F5C412F43342A535245815C4AA6B3AF9FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FA7A39FA6A29FB1AD9FAAA69FADA99FADA99FADA99FADA94B2D25462F2613070332221D
352226291E172F221C061E289A907B9790809A7A6C8A6C5D8D806EA49D92A6A798AA9788
9A7C699E8470977C688C745F92826A97806E9789779F9B8DA196889D8C7890785D89704F
8C7050936B52A2755C36221F211E1842302A41332C3E392D6C57487266538C6952836A57
7C715A6340354833253F2C20393229794634A1AFAB9FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FAFAB9FAAA69FADA99FADA99FADA99FADA99FADA99FADA96D43373F2C213D271F29201C
1E13112E1F1B34211B1021299C8C789A8C75A9AE989C8A787559446F55446E5A48605142
543F344F3A2C5843325E40316D5D4D908472978A779F9481A1967E9D837090786388604C
7F6D4E7E6B4F927D64DBA07B8F77618159428458426D5C4D82694E7C655185765C8F735D
7F6D5C61422C36231D3D2B203C32266E2E1E9FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9784E372A1710221C15261B15
2E1F171F1B1534302A1B2F338D8270A4937F9C9380AEA699B6B09A987D6C826860897365
98725C886B587E634E86715E857061978D7E9C93839F8A82A18E7F9D87729073676E4534
5D362962523E817053897359957A629E83678C7760796C56816F5D896D5B7F6A5C817058
7F644D37281E221D16444B416546325F27189FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FA9A59FA8A49FADA99FADA99FADA99FADA986624C391B122B1B15221C16
130B0B241A15302B262938377770619A8C799F95819F998BA4A196B0B8A4C1B39E9AA799
B2B3A5ACAB9CB2B5A59B9C8A998A7697937F9C9682979A7F9C8C7AA08D78A0977AAE937C
754E43402A2333271D4840357463528B735D92775A7F6D5A866A5574624C80675A856A5C
633F2E3B241B322C2522302970422C371B144A504E9FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FB1AD9FAAA69FADA99FADA99FADA99FADA97160553B2E262C1D172A1C16
221911231A15312B26343F3B746A5C978A779F95819F95879F9B8D9F9F949FA49B9FA49B
9FA0949F9F949FA0949F9F94A49D8B9C9078A49B889E907A9A88739E8A769C8C77A69281
BEA48CAF87778762523F312631251B3F322B4A40365646355947357A6053806A57866956
5330252F1F182A1F1E1F140F3D201655372E2125229FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA986695D4F3D352B211A271C16
2B1D172B2120332C28333D37635C4F8D81709F957D9F92809F97899F97869F9D909FA198
9FA69F9F9F949FA2979F9B8D9F9F949F99889F9581A1957F9A8E799A84719A86739A8A76
A08775988C74AC8A70A4856C90735B6B5641714F3C725F4D886F5C6E5C507F675B786753
5432262C1D17221B151C1811241F1A40322C2327259FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9825E48402E213F2C242A1E17
2D171031201936291E36332C4E4E448173649A927E9F95819F95879F9F949F9B8D9F9D90
9FA1989FA1989FA2979F9B8D9F98859F98899F9281A18D789A86739A8E799A84719A866F
9B806D997C68987E69967A64997F6A9E846D957C67846E5B8D6A5B89735C8C6655714D38
4B2D222C1D1733211B271E17231B1530251C21211C8183829FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA97156404438313A2B2436241D
1F1811241A15241A153329203A3629665A4B978C799F95819F95879F9A8C9FA69F9F9B8D
9F9D909F9D909F9D909F9B8D9F9B8B9F957D9C927E9C907A9A84719A826F9A86729A8471
9B836F917E6991796593806C8976628E75618D735F83725D7B6D587B6D5B74624E4B392F
251A122B21201D17171E1710120B0A241C182C2D275D57539FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA986614B403129433730362B24
39251E291D1631262035322E3E3B3443463D8D7B6A9F927E9F92849F93829F9D909FA69F
9F9F949FA2979F9B8D9F9B8D9F9B909C92819C927C9A86729A86729A847197847192806C
97806C967E698E79658E7662937E698976628B735F8B725D856D5A8669556C4F3F472A21
3A2A231911101E1716130B0B1D1716201A152D322F4846419FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA97A695E463A32443A33443830
36251E2118112A1F193C2C225241334E46377C67569A8C759F95839F92849F93829F9D90
9FA1989FA69F9FA0949F9B8D9F9B8CA4998A9E937D978A7592806C957D6D9B7D6C947C68
947768967A698E79658E75618B725E8B7561866A568D6C597F64506F54455A3D2D40281F
1F17102018171810101E17111C16152C201B3B47477E88849FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FA9A59CA29E715B503D332C41373141352E
2E20193628222F2721302A25413C315B52447560519285749F95819F998B9F998B9F9A8C
9FA1989FA1989FA2979F9B8D9C98849A8E7CA18D789E86729C877494826A977E6C947E69
917D66917C698B70618771618B735F89735F8D7560816B597C65507A58415238273A251D
291E18231D16241D171E1710221C152A201B020202A4B1AD9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FB1ADA4B3AF6B554843322640322A433932
483A32342922372D263C2D213C3F385049396353458875659A927E9F92849F97899F9786
9F99899F99899F9A8C9C907D9C907C958C789C8F79978068927D66978068947E6894826D
9679658E7A66937B638D715F896F5B896B59836F5B7C64507058435238303F271F261D17
1F17101D16151810100D0B0B150F0F342C28140D0DA1AFAB9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9896B5E3D2F2344372E423832
3C302936241D3A2B1F3D332C3D382F47392E4A43397C675A9790789F957F9F92809F9481
9F947E9F947E9F9885A4998A9E937D9A836F97806A977968947766947B6D947E69947662
9677648E75618E756190735F89725D8669557F624E7056415239304732232F1F18251D16
291D171F17161911111A11102C201A475E5F787F7B9FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99A8D814A3C353C312A453731
4531243C30283127213A3029342B253A38313D3D335E4C3E867965978E7A9A927A9F9583
9F95819C927D978E779A9280A1907B977E699780689178618C76608C76648F7764917964
91705D8E70618B705F8B735B866D568369557D614D5F42334B33232D1E172018111D1615
251B16201816140B0B171010261E19000000A1AFAB9FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA991847153443A443A333C332D
403530322422322721332B244238323D2E21342C23423E36665748897361907D6B978773
978A779C927D9A8C78958572998D78937E688C6F5E9176618E6C598E6E5C89725E917561
8B6F5B876F598866547F65547866506B533F694C384D37262E1E17261D171F181118110F
1610100E0B0A0D0B0B2A1F1A36251B0F08049FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9C5C9D068504845393241352E
463D3648352535231C3D332E382E2741393333292331312B3D3A30504538715D4F87705D
8671648A796E8A7D6C8D7F6C907A657C65506E5745785B45836954876A5887634F876654
8B6F518669518364507D5C49775C496347384B2F223E251D2E1E171F1710191110181110
130B0B0E0B0B1710101E1914546769696C689FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9B8CDC28B7D6940332A3D332C
3A312A36312A30252334271E41342C423A344C3F37382F2A403A35413D35493B2E574940
4D463C544838645344675947665445664E3C58433157483464493570533E7962487B5844
6D4F406D4D397252416951435C40345133243E241D2E1D171F1710191110130B0B0D0B0A
0D0B0B0D0B0A1D1A152C201B040B0A9CA8A49FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9B0AFB756453E413731
403A3342362F2820182D2924433A33463D364F463E52494050493C4E4A3E49453948382F
4631273E302A443028503D324E3C334338334D382E4C3426493629533F335746355D4431
604A3756402D523F33573A2D4C362839251E3528212218111E1710191110140B0B0E0B0A
0D0B0A251B151D1615464C493C37349FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9C3CFCA765C5440332D
3F332C3E342D4839313E3630423A344C443C443A3341373142312C4E352B4D332741342B
33292338312A30221D342C273F342D372E272E221C2E25202E211B2D1D1935281F392C20
362A1F37231C331F1931211B32211B271E171C16101A11111710101811100E0B0B0D0B0A
251B1F251B173E322A31494B868D899FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9A8BBB1BABCB954433B
3E332D42383240352E4740393C30293F38323E322A3F36304C4538443B3440352F40332C
3D312941352F3627252E292331221C33211B2A1D17221B15261C162E211B30201B281C16
261B16271D162F211B2A1D16271C162017101E17101911101810100D0B0B0D0B0B171010
27221D34231D5963616E7A779FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9BAC0BF755149
46383242383241352E302B2447403848413A484038362E273B2F253A2921362C26372D26
2B23272A292433262330201B2A1D21221C17231D161E1710201B15201B16211C161E1710
1810101B1610231B151F17101810101D16101D17161911100D0B0B181010221C16302720
2E201B6875726873709FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9AEC4BA9D9287
4A3A3241373141352E463A333A36303E37303E30293529222D26212D1E173229232F2321
312321271B16281D201D17171811101C16161D16161911111B15151810101C1615191111
1D1716211B161C17161911110E0B0B0C0A0A0C0A0A0D0B0A1D16161C171017100F21140F
5E6A67646A689FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9DBF2EE
94867B42352C3D332C3C37303F3932443E3745383637251E332620261E18231A14241D16
261C161A111117100F1D16161E17171810101C16151911111C16151911112D1F1A100C0B
1A1515211B161F18160E0B0B0D0B0B120B0A1D16151E17171B16152F211C412F215B4C3B
362D219CA8A49FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
DBF2EE978075493F37392E27433A34463E374D42393B352D372E262F1F241E1717271B16
1E1716241D17231D161E171618111018111017100F18111017100F221C161A16153D3941
393C3D2C20251A11111F1717231D17231D171D1715332B25372A232F221C48372E5F6A6A
84867E9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA9DFFCF8977D72564840382E273A352F47423B54453D4231243A2B21281E181C1716
1911101B15101D16151911101811101D16161911101D1616191110160F0F3233322F262C
463D3D5950444D3D3B4B403A40332B271F183227202D251F413731533D30646D6B7C7A75
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99AA8A4DDF9F5886A575B4B41473B33453F3850473F544B443D2D25382A2340352D
3B332A2B1E18241D161F18171E1716181010181110201B1F1F1818221C161913122D2B23
322C291F1717201B151D19141D1716291D172D241F3C2D21514030797D786A6A6A9FAAA6
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA9E0FFFF83756343352C3A332D5049435B574F5F544A3B2D252B201F
33211C3F342D3931292219181811102721252A2328302C252D25293D36332A21243A3836
4137354A3A3241352F3D312942362E4B453943382F574A3C747B7590968997A1A09FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9E0F7F7C7C8C7685B533F36304339334E4F51645D5865594F
605D564639373D3A3953515864605C483B373C353D3B3336514B4F413A394B3B31393430
4E3E354A352E4A3327493A324F43375E4B3B5C3C2B506366848B829FAAA69FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA9B3C8BEDFF1F086797D52494344403E50585D626160
5B5751676358665F5B5C574C584F4B584A4051463A4238363429223D342E473E37423832
4E3A2E5A3F325D4639674F40573C30544D4CA2A7A5737A759FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FA5A19FA8A49FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA9E0F7EAC7D9D9C2C5BE6C6975676366
827E87837B7F716259645A526158507163606F5F5971625772645C66594B5D564C6F6259
5E594D5752454C3D355D5F60AEBEC1ABBDB4848B899FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FAFAB9FAAA69FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9A8BBB1DAEBDDA8C0BF
A4B5A7B0BEC7B1C0C8AFAFB57B77845E616B5E595961574F58534C6459535950484E4438
574A3D778079CCDED78CA1989199999FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA9A8BBAD9AAAABB3C6B8CBDACFB8C9C0BDD3D5BAC9C5BAC9C6BACECABFD2CEC1D9D9
BFD0CE7988829FAAA69FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA99FADA9
9FADA99FADA99FADA99FADA9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?oooeVO[JT4XJfR19N@O0>OUH44WiF719nKS0BOUHL;Wi^=19nK
S0BOUHH4XIJ019Z@NPBKRG<4U7iZ0iInJA2>NFD4SWQS0i1cG@B9Le`4RG=M18UcG0B0Ie<?WjfY19n^
Z@BOYZ8SWjfY5Oooo`005?oooeVO[JT4XJfR19N@O0>OUH44WiF719nKS0BOUHL;Wi^=19nKS0BOUHH4
XIJ019Z@NPBKRG<4U7iZ0iInJA2>NFD4SWQS0i1cG@B9Le`4RG=M18UcG0B0Ie<?WjfY19n^Z@BOYZ8S
WjfY5Oooo`005?oooeVO[JT4XJfR19N@O0>OUH44WiF719nKS0BOUHL;Wi^=19nKS0BOUHH4XIJ019Z@
NPBKRG<4U7iZ0iInJA2>NFD4SWQS0i1cG@B9Le`4RG=M18UcG0B0Ie<?WjfY19n^Z@BOYZ8SWjfY5Ooo
o`005?ooo`BO[JT4WjVU19nXY0BO[JT4WjVU0inXY2>O[JT4WjVU19nXY1NO[JT4Y;:X19bCP`>OUH44
WiF319nKS0BOUHL4Wi^=19nHQ@>LT7X4Ui1j19N:N0BIQW84Sh1/18mnJ@B<Mf@3SWIR18YfHPR>NFD8
SWEQ0i1cHPB9Leh4RG=M18V3LPB0NFd?WjfY19na[@BOZZHSWjfY5Oooo`005?ooo`BO[JT4WjVU19nX
Y0BO[JT4WjVU0inXY2>O[JT4WjVU19nXY1NO[JT4Y;:X19bCP`>OUH44WiF319nKS0BOUHL4Wi^=19nH
Q@>LT7X4Ui1j19N:N0BIQW84Sh1/18mnJ@B<Mf@3SWIR18YfHPR>NFD8SWEQ0i1cHPB9Leh4RG=M18V3
LPB0NFd?WjfY19na[@BOZZHSWjfY5Oooo`005?ooo`BO[JT4WjVU19nXY0BO[JT4WjVU0inXY2>O[JT4
WjVU19nXY1NO[JT4Y;:X19bCP`>OUH44WiF319nKS0BOUHL4Wi^=19nHQ@>LT7X4Ui1j19N:N0BIQW84
Sh1/18mnJ@B<Mf@3SWIR18YfHPR>NFD8SWEQ0i1cHPB9Leh4RG=M18V3LPB0NFd?WjfY19na[@BOZZHS
WjfY5Oooo`005?ooo`BO[JT4WjVU19nXY0BO[JT4WjVU0inXY2>O[JT4WjVU19nXY1NO[JT4Y;:X19bC
P`>OUH44WiF319nKS0BOUHL4Wi^=19nHQ@>LT7X4Ui1j19N:N0BIQW84Sh1/18mnJ@B<Mf@3SWIR18Yf
HPR>NFD8SWEQ0i1cHPB9Leh4RG=M18V3LPB0NFd?WjfY19na[@BOZZHSWjfY5Oooo`005?ooo`BO[JT4
Wk6]19nWX`BOZ:@4Wk6]0inZYPBO[JT4WjVU19nXY0BOZJD4WjRT3in]Z@BO/Jd4WjZV5in]Z@BLZIl4
VY9j0inEQ`BOTX84Wi^=19nEQ`BOU8D4W9B40i>>O@B9Q7<4TWa/19=hIPBAOFT4SX9]18j0K0>COfX4
RG=O28MbGPB7MF44Qg=K0h]cG@B9Lel4RG=R19B2K`BDWYTCWjfY19nYY@BOZ:@OWjfY5Oooo`005?oo
o`BO[JT4Wk6]19nWX`BOZ:@4Wk6]0inZYPBO[JT4WjVU19nXY0BOZJD4WjRT3in]Z@BO/Jd4WjZV5in]
Z@BLZIl4VY9j0inEQ`BOTX84Wi^=19nEQ`BOU8D4W9B40i>>O@B9Q7<4TWa/19=hIPBAOFT4SX9]18j0
K0>COfX4RG=O28MbGPB7MF44Qg=K0h]cG@B9Lel4RG=R19B2K`BDWYTCWjfY19nYY@BOZ:@OWjfY5Ooo
o`005?ooo`BO[JT4Wk6]19nWX`BOZ:@4Wk6]0inZYPBO[JT4WjVU19nXY0BOZJD4WjRT3in]Z@BO/Jd4
WjZV5in]Z@BLZIl4VY9j0inEQ`BOTX84Wi^=19nEQ`BOU8D4W9B40i>>O@B9Q7<4TWa/19=hIPBAOFT4
SX9]18j0K0>COfX4RG=O28MbGPB7MF44Qg=K0h]cG@B9Lel4RG=R19B2K`BDWYTCWjfY19nYY@BOZ:@O
WjfY5Oooo`005?ooo`BO[JT4Wk6]19nWX`BOZ:@4Wk6]0inZYPBO[JT4WjVU19nXY0BOZJD4WjRT3in]
Z@BO/Jd4WjZV5in]Z@BLZIl4VY9j0inEQ`BOTX84Wi^=19nEQ`BOU8D4W9B40i>>O@B9Q7<4TWa/19=h
IPBAOFT4SX9]18j0K0>COfX4RG=O28MbGPB7MF44Qg=K0h]cG@B9Lel4RG=R19B2K`BDWYTCWjfY19nY
Y@BOZ:@OWjfY5Oooo`005?ooo`RO[JT4WjjY19nVXP^O[JT4Wk6]19nZYPBO/Jd4WjZV;Yn]Z@BT[J84
W9200inEQ@BOUHL4Wi:419nHR@BOUH<4Y9V:0k2KR`BKVXP4WY:21::3M@BGNFD4UgMX19MgJP>CLF@4
T75Q38UcG`B9Lf83S7MR18efHPB9Lel4P6MC5in]Z@BO/Jd4WjZV7in]ZAGoool001Coool8WjfY19n^
Z@BOYZ8;WjfY19na[@BOZZH4Wk6]19nZYRjO[JT4Y:fR19b@P0>OUHD4WiF719nBQ0BOV8T4WiF31:BI
RP>`Vh/4ViZ819jBPPBRPgD4UgUU19MgJ0BGMfX3Tg5T191aH@b9Lel4RG=R0hagHPB=MV84RG=O181W
DaNO[JT4Wk6]19nZYQnO[JTEoooo000Doooo29n]Z@BO[ZT4WjJR2in]Z@BO/Jd4WjZV19na[@BOZZH^
WjfY1:B]XPBLT803WiF519nEQ`BOTX@4WiR919nEP`BTVHX3/9^;19^JR0BNTX84XX=e19MiI@BGMfP4
UgMZ0i=aI0B@LF4<RG=O18UcHP><Mf84SGIR18UcG`B0Ie<GWjfY19na[@BOZZHOWjfY5Oooo`005?oo
o`RO[JT4WjjY19nVXP^O[JT4Wk6]19nZYPBO/Jd4WjZV;Yn]Z@BT[J84W9200inEQ@BOUHL4Wi:419nH
R@BOUH<4Y9V:0k2KR`BKVXP4WY:21::3M@BGNFD4UgMX19MgJP>CLF@4T75Q38UcG`B9Lf83S7MR18ef
HPB9Lel4P6MC5in]Z@BO/Jd4WjZV7in]ZAGoool001Coool8WjfY19na[@BOZZI9WjfY19nbZ0BOTg`3
WiEo19nEP`ROUHL4WiF;19nIR@>OWHh4Y9fB19ZLPPBQSh44W8Uh19b7L@BIOfd3W8Qd19aeI`B@Jel4
T7M/18eiI`B<Lel3S71M191eH@B<NfP4QG1K?Yn]ZAGoool001Coool8WjfY19na[@BOZZI9WjfY19nb
Z0BOTg`3WiEo19nEP`ROUHL4WiF;19nIR@>OWHh4Y9fB19ZLPPBQSh44W8Uh19b7L@BIOfd3W8Qd19ae
I`B@Jel4T7M/18eiI`B<Lel3S71M191eH@B<NfP4QG1K?Yn]ZAGoool001Coool8WjfY19na[@BOZZI9
WjfY19nbZ0BOTg`3WiEo19nEP`ROUHL4WiF;19nIR@>OWHh4Y9fB19ZLPPBQSh44W8Uh19b7L@BIOfd3
W8Qd19aeI`B@Jel4T7M/18eiI`B<Lel3S71M191eH@B<NfP4QG1K?Yn]ZAGoool001Coool8WjfY19na
[@BOZZI9WjfY19nbZ0BOTg`3WiEo19nEP`ROUHL4WiF;19nIR@>OWHh4Y9fB19ZLPPBQSh44W8Uh19b7
L@BIOfd3W8Qd19aeI`B@Jel4T7M/18eiI`B<Lel3S71M191eH@B<NfP4QG1K?Yn]ZAGoool001CooomI
WjfY19n^Y0BOUH43WiF519nEP@BOUH<4WiF719nIR`BOUHL3WiB519nKS@BTWI84XJ2919jCO`BJR7L4
WX]f0iAmJPBLQW44TgaY18i^FPBCOW44RGUW0hMcG`B;Lel4SH5f19:7NQ^O[JT4WjVU19nXY1^O[JTE
oooo000DooooFIn]Z@BO[Z@4WiF10inEQ@BOUH44WiF319nEQ`BOVH/4WiF70inDQ@BOVhd4Y9fB1:6P
R@BNTgl4VXQg19j;MP>DOFX4W8Ia19=lJ@B>KUX4Tgia18UiI`>7Lel4Rg=O18f1MPBBQgXKWjfY19nY
Y@BOZ:@KWjfY5Oooo`005?oooeVO[JT4WjjT19nEP@>OUHD4WiF119nEP`BOUHL4WiV;19nEQ`>OU8D4
Wi^=1:BMTPBQX8T4WY=o19Z8M`BNRgH3U7eZ19b6L@BCO6T4SViJ19=nL@B9NFL3Qg=O18]cG`B=PGH4
TXMj6in]Z@BOZJD4WjRT6in]ZAGoool001CooomEWjfY19J<P0B@SX<4WiF50inEP@BOUH<4WiF119nI
R`BOUHL4Wi^=0inMSPBOVH/4Wi^<19nER`BTVHL4XI9i19j8M@>NQg@4VH5]19UiJ@BCN6<4RfeH18]f
H`><Lel4SG=O18=fIPBGVYDKWjfY19na[@BOZZH7WjfY19nYY@BOYJ44WjRT29n]ZAGoool001CooomE
WjfY19J<P0B@SX<4WiF50inEP@BOUH<4WiF119nIR`BOUHL4Wi^=0inMSPBOVH/4Wi^<19nER`BTVHL4
XI9i19j8M@>NQg@4VH5]19UiJ@BCN6<4RfeH18]fH`><Lel4SG=O18=fIPBGVYDKWjfY19na[@BOZZH7
WjfY19nYY@BOYJ44WjRT29n]ZAGoool001CooomEWjfY19J<P0B@SX<4WiF50inEP@BOUH<4WiF119nI
R`BOUHL4Wi^=0inMSPBOVH/4Wi^<19nER`BTVHL4XI9i19j8M@>NQg@4VH5]19UiJ@BCN6<4RfeH18]f
H`><Lel4SG=O18=fIPBGVYDKWjfY19na[@BOZZH7WjfY19nYY@BOYJ44WjRT29n]ZAGoool001CooomE
WjfY19J<P0B@SX<4WiF50inEP@BOUH<4WiF119nIR`BOUHL4Wi^=0inMSPBOVH/4Wi^<19nER`BTVHL4
XI9i19j8M@>NQg@4VH5]19UiJ@BCN6<4RfeH18]fH`><Lel4SG=O18=fIPBGVYDKWjfY19na[@BOZZH7
WjfY19nYY@BOYJ44WjRT29n]ZAGoool001CooomAWjfY16eRE0A/Nfl4TXUi19nEP@>OUH/4WiF919nE
Q@BOUHL4Wi^<19nBP0>OUhD8WiR919nEP`BOVHH4W8mm19b6M@>JP744Vh=Z195hHPBANFD4TgIR18ec
G`>8NfP4TgeY18YdH0BLZ:@ZWjfY19na[@BO[j/4WjZV29n]ZAGoool001CooomAWjfY16eRE0A/Nfl4
TXUi19nEP@>OUH/4WiF919nEQ@BOUHL4Wi^<19nBP0>OUhD8WiR919nEP`BOVHH4W8mm19b6M@>JP744
Vh=Z195hHPBANFD4TgIR18ecG`>8NfP4TgeY18YdH0BLZ:@ZWjfY19na[@BO[j/4WjZV29n]ZAGoool0
01CooomAWjfY16eRE0A/Nfl4TXUi19nEP@>OUH/4WiF919nEQ@BOUHL4Wi^<19nBP0>OUhD8WiR919nE
P`BOVHH4W8mm19b6M@>JP744Vh=Z195hHPBANFD4TgIR18ecG`>8NfP4TgeY18YdH0BLZ:@ZWjfY19na
[@BO[j/4WjZV29n]ZAGoool001CooomAWjfY16eRE0A/Nfl4TXUi19nEP@>OUH/4WiF919nEQ@BOUHL4
Wi^<19nBP0>OUhD8WiR919nEP`BOVHH4W8mm19b6M@>JP744Vh=Z195hHPBANFD4TgIR18ecG`>8NfP4
TgeY18YdH0BLZ:@ZWjfY19na[@BO[j/4WjZV29n]ZAGoool001Coool8WjfY19nYY@BOZ:@mWjfY19>F
UPAK=bh48C0f19bCP`BOVHD3WiV:19nIR`BOVHX4Wi:419nKS@BOWI83WiF519nHQ@BORW/4W7md19Ek
J0BGQVl4VXAb0iN7L@BCOVd4U7iW19=gI0B;N5l4Rg=M0hE]F`B7Lel4PfUE@Yn]ZAGoool001Coool8
WjfY19nYY@BOZ:@mWjfY19>FUPAK=bh48C0f19bCP`BOVHD3WiV:19nIR`BOVHX4Wi:419nKS@BOWI83
WiF519nHQ@BORW/4W7md19EkJ0BGQVl4VXAb0iN7L@BCOVd4U7iW19=gI0B;N5l4Rg=M0hE]F`B7Lel4
PfUE@Yn]ZAGoool001Coool8WjfY19nYY@BOZ:@mWjfY19>FUPAK=bh48C0f19bCP`BOVHD3WiV:19nI
R`BOVHX4Wi:419nKS@BOWI83WiF519nHQ@BORW/4W7md19EkJ0BGQVl4VXAb0iN7L@BCOVd4U7iW19=g
I0B;N5l4Rg=M0hE]F`B7Lel4PfUE@Yn]ZAGoool001Coool8WjfY19nYY@BOZ:@mWjfY19>FUPAK=bh4
8C0f19bCP`BOVHD3WiV:19nIR`BOVHX4Wi:419nKS@BOWI83WiF519nHQ@BORW/4W7md19EkJ0BGQVl4
VXAb0iN7L@BCOVd4U7iW19=gI0B;N5l4Rg=M0hE]F`B7Lel4PfUE@Yn]ZAGoool001Coool8WjfY19na
[@BOYj<4WjRT=In]Z@BQ/:`4Fd@a19NFQ0AVJ5/4WiF719nBPP>OV8T4Wi:419nHR@BOUHL4Wi:419nG
R@>OVh`4W9:219NAN@BLQ7H4Vh=_191kI`BBOFT3UgeU19IoJ0B9MF44TG9N19=eH`B@Leh3SG=O18ag
I0B3IE84VYZC?Yn]ZAGoool001Coool8WjfY19na[@BOYj<4WjRT=In]Z@BQ/:`4Fd@a19NFQ0AVJ5/4
WiF719nBPP>OV8T4Wi:419nHR@BOUHL4Wi:419nGR@>OVh`4W9:219NAN@BLQ7H4Vh=_191kI`BBOFT3
UgeU19IoJ0B9MF44TG9N19=eH`B@Leh3SG=O18agI0B3IE84VYZC?Yn]ZAGoool001Coool8WjfY19na
[@BOYj<4WjRT=In]Z@BQ/:`4Fd@a19NFQ0AVJ5/4WiF719nBPP>OV8T4Wi:419nHR@BOUHL4Wi:419nG
R@>OVh`4W9:219NAN@BLQ7H4Vh=_191kI`BBOFT3UgeU19IoJ0B9MF44TG9N19=eH`B@Leh3SG=O18ag
I0B3IE84VYZC?Yn]ZAGoool001Coool8WjfY19na[@BOYj<4WjRT=In]Z@BQ/:`4Fd@a19NFQ0AVJ5/4
WiF719nBPP>OV8T4Wi:419nHR@BOUHL4Wi:419nGR@>OVh`4W9:219NAN@BLQ7H4Vh=_191kI`BBOFT3
UgeU19IoJ0B9MF44TG9N19=eH`B@Leh3SG=O18agI0B3IE84VYZC?Yn]ZAGoool001Coool8WjfY19nY
Y@BO[JT4WjZV=In]Z@A?>b/4XJBH17=hL@BLTh<4WiF11inEQ`ROUH<4WiF719nIR`BOUHL3WiR91:5e
K@BJI5`4UeUD19MFD@BDEE04U6ML0i5cHPBALeh4SW1L18]`F@B:Led4SW=O0i1cF`B8K5L4Pem;18Qe
IBZO[JT4WjVU19nXY0bO[JTEoooo000Doooo29n]Z@BOZJD4WjfY19nZYSFO[JT4Cc/[1:6TV0AcN744
W9>319nEP@NOUHL8WiF319nEQ`BOVH/4WiF70inHR@BQMFd4VVAL19MIE0BGEU44U5E@19AWG0>ALf84
TG=N18i`G0B;L5T4RW=M18icG`>@Le/4R6aG18=OB`B8MFDZWjfY19nYY@BOZ:@<WjfY5Oooo`005?oo
o`RO[JT4WjVU19n]Z@BOZZHeWjfY14lk:`BQY9P4LgQa19bCP`BOUH47WiF729nEP`BOUHL4WiV;19nE
Q`>OV8T4XGE]19YTG0BGFE@4UeIA19AED0BDIe`3TG=R195cGPB>L5`4Rg1I18YcG@B>Lel3T7=K18Q/
E`B3Gd/4R7EU:Yn]Z@BOZJD4WjRT39n]ZAGoool001Coool8WjfY19nYY@BO[JT4WjZV=In]Z@A?>b/4
XJBH17=hL@BLTh<4WiF11inEQ`ROUH<4WiF719nIR`BOUHL3WiR91:5eK@BJI5`4UeUD19MFD@BDEE04
U6ML0i5cHPBALeh4SW1L18]`F@B:Led4SW=O0i1cF`B8K5L4Pem;18QeIBZO[JT4WjVU19nXY0bO[JTE
oooo000Doooo29n]Z@BO/Jd4WjZV=Yn]Z@>CUY84h=kG16U/IPBOV8T4WiF619nEP@BOUHL3Wi9o19n>
O0BOSWL4Wi:019nBQ0BORh03Wgmh1:61M@BGGe44Te1118mEB`BAEd/4Sde90i=MD`B7IUH4Qg=K18]]
FPB8L5`4SW=O0i=cHPB<LU`4Tg9P17iJA0B@PgDVWjfY19na[@BOZZH<WjfY5Oooo`005?ooo`RO[JT4
Wk6]19nZYSJO[JT3TiJB1>3Ne`AYK6H4WiR919nEQPBOUH44WiF70inBO`BOSW`4Whig19nBP0BOTX@4
Wh^00imoN0BQPGD4UemA19=@@@B?ED/4TEM;18m=B@>CGE<4QfIF18McF`B;KEX4R71L18icG`>CLf84
S79L19=bH0AnFT@4T8=e9Yn]Z@BO/Jd4WjZV39n]ZAGoool001Coool8WjfY19na[@BOZZHfWjfY0i>F
TPCPg]L4JFaV19nHR@BOUHH4WiF119nEQ`>OTWl4Whil19n>M`BOTX04Wi:419n;P0>OOgP4XH5e19MO
D@BCD444SeE;195GB`B?CDT3TeeC18MVEPB7Le/4RfeJ18Q`G0B>Lel3Tg=R18abG0BCLV04OUY41923
MBJO[JT4Wk6]19nZYPbO[JTEoooo000DooooAYn]Z@=B@cT4>TU519NBOPBOUGl4WiF319nEP@BOUH<3
W99n19N4L@BJRgT4Wi>019n>N`BLMVH3UEU=195]GPB5ET44Q7AQ18anJPBCE4@4Pd0c0i5<@@B=Edd4
RFQK18UbDPB5KU<4RW=M0hicG`B>Mf84SViL18ifHPB7JeH4WjBL=Yn]ZAGoool001Cooom6WjfY0e93
>@@jBDD4Ui9n19nEO`BOUH<4WiF119nEP`>LTWh4UhAa19Z;N@BOTh04Whik19afIP>EFDd4TFeN18EF
@@B4M644S7iZ19=DA0B3@3<3TDa118eGC@B9J5/4RG9B18E^D`B:Led3SW=O18igHPB>KU`4SWIR18M[
EPBOY9`fWjfY5Oooo`005?ooodJO[JT3DT<i13Y9A@BGTWh4WiEo19nEP`BOUH44WiF30ibBOPBGQ744
VX]i19nCP0BOSW/4W7IV0iEIC@BAKEh4QEI118AdH@B<OVX4TeA418=0<`>AC444SEM=18UXF`B9LU84
QFiC18YcG@>>Lel4SWMR18i^G0B>MV84Qf]F19nTW3JO[JTEoooo000DooooAYn]Z@=B@cT4>TU519NB
OPBOUGl4WiF319nEP@BOUH<3W99n19N4L@BJRgT4Wi>019n>N`BLMVH3UEU=195]GPB5ET44Q7AQ18an
JPBCE4@4Pd0c0i5<@@B=Edd4RFQK18UbDPB5KU<4RW=M0hicG`B>Mf84SViL18ifHPB7JeH4WjBL=Yn]
ZAGoool001Coool@WjfY19nYY@>OZ:@[WjfY18=nNP>hWHL4DUQA19bCP`BLSW`4VY6219nIR@BOSWh3
WXE/18mbF`B=Jf84VF5H16<N4PAME4L3UgEW19aaI@B_]:/4V65E18QIA`B0Ke44MfYG0fY;=`Ab?S44
QU1518E/D`B<JU<4S7AP0i9nIPBCNF84SWMT18icG`B1Gd/4T7]Y19nTW3:O[JTEoooo000Doooo49n]
Z@BOZJD3WjRT:in]Z@B3OWX3^9f7159HD@BLTh<4W8il19ZAPPBOVHT4Whin0ij5K0B?LU/4SF]R19UQ
F0AS7Q84GEA70iMeI`BLLFD4[kB[19QQE@B8FDL4P6mA17MZE`=ZBcL4LSha18I@A@B5K5<4S6YC18ad
H0>BOVH4TgUR18igI0B>Lel4PEm;191kJ@BOY9`bWjfY5Oooo`005?oooa2O[JT4WjVU0inXY2^O[JT4
Pgij0kRMQ`ABF544W9>319b>O0BJTH84WiV919n>OP>NQF`4Sg9K18e[HPBIHEP4HahB15eDA`>GMFL4
W75U1:ndZ`BHHED4R5U7181_D@AgJUL3JT/g178n<@B6D4D4QFaC18aZD`B<M603TWiV19=iHPB>Mf@4
SW=O185OB`B@NfT4WjBL<Yn]ZAGoool001Coool@WjfY19nYY@>OZ:@[WjfY18=nNP>hWHL4DUQA19bC
P`BLSW`4VY6219nIR@BOSWh3WXE/18mbF`B=Jf84VF5H16<N4PAME4L3UgEW19aaI@B_]:/4V65E18QI
A`B0Ke44MfYG0fY;=`Ab?S44QU1518E/D`B<JU<4S7AP0i9nIPBCNF84SWMT18icG`B1Gd/4T7]Y19nT
W3:O[JTEoooo000Doooo29n]Z@BOZJD4WjRT19na[@>OZZH[WjfY165BA`==GEd4RX=e19nEP@BQT7`4
Uh5`19nHR@BOUH@3WgIL18iVCPAM7AD4HemK1<_Ic@B3S8H3Xl6k19jYZ@BLU8h4YLR`1:jWVPBa/jh4
T8Yn0gADA@@m;a`4EcHY17iNC`B8L5L4TW9Q0i9mK0BIQFX4TgIO18ieH@B>M644PFmT18f@U0>JY:0_
WjfY5Oooo`005?ooo`RO[JT4WjVU19nXY0BO/Jd3WjZV:in]Z@AQDTL3CEeM18Z3M@BOUH44XI1l19N1
L0BOV8T4WiF40imfG0B>ITh4GAdE16=OF`C;fLd4Phb60j?1^`BNZJT4W9B>1:G8/0B^YiX4/K>^192:
OP=dE4D4?BlL15Lf:@AnGTl4R71G199bH@>BOF`4VHEZ19=fG`B>MF44SWAQ185_I0B=T9@3VZBP;in]
ZAGoool001Coool8WjfY19nYY@BOZ:@4Wk6]0inZYR^O[JT4HE970deMG@B:PgD4WiF11:6@O0BGPG04
WiR919nEQ0>OMU`4SVI>15dM5@ASGe/4bmW=18><QP>S`K/4WZVY19bDSPBUb;04[ZNJ1;6c[PB@RWh3
M5A513d_70AG=RT4OUi?18Q`E`BBLV43TWe/19V5JPBCMUl4SWEQ18idH@B1Kf@4SI2D0iZTX2nO[JTE
oooo000Doooo29n]Z@BOZJD4WjRT19na[@>OZZH[WjfY165BA`==GEd4RX=e19nEP@BQT7`4Uh5`19nH
R@BOUH@3WgIL18iVCPAM7AD4HemK1<_Ic@B3S8H3Xl6k19jYZ@BLU8h4YLR`1:jWVPBa/jh4T8Yn0gAD
A@@m;a`4EcHY17iNC`B8L5L4TW9Q0i9mK0BIQFX4TgIO18ieH@B>M644PFmT18f@U0>JY:0_WjfY5Ooo
o`005?ooo`RO[JT4Wk6]19nZYRjO[JT4UYjR15hm<`<A9Rh4Ui1h19nEP`BTXX/4W8ml19nEQ`BIPg03
T75A17Y5;PAb9Q@4BR0M18QRE@BGN6L3VX=e19nLR0BOTW`4WXQh191gJPBIQG44/9F20kVSR0BLQ7<4
ASDW14lb:@AmGD`4R6mK0iN6L0BIQG<4UX5Z18iaG@B>KE/4RfiB17akLP=mOWd4T9ZP:in]ZAGoool0
01Coool8WjfY19na[@BOZZH^WjfY19JNXPAN?C<34BH^19N@N0BOUH<4Y::;19b?O0BOUHL4VH=`0i1a
D@AjABh4LRHD14XP7@B8HUD4UgQW0iZ3M@BOW8P4Wi9l19j8N0B@MfX4VHEa1;2EPP>iXhP4W8Ac14He
9`A?<RT4OEe<18Q_F`>GQW04VHEc19J1JPB>LEd4SVeK18]^DPAlNg83OGim192JX2^O[JTEoooo000D
oooo29n]Z@BO/Jd4WjZV;Yn]Z@BFWZ84GSdc0a4V;PBGT7P4WiF31:BRR`BLSg`4WiF719V3L0>@LE44
NTD^178V50A:81d4R69E19MhI`>JPgD4Wib819nBO0BNR7P4T7MZ19V5L@B`UH83^J>819b4L`A6=BL4
Cc8Y17eMC0B8Ke/3UhI`19V5L`BFPFX4SW5M18i]F`B;KU84O7]b0genO@B@VZ0[WjfY5Oooo`005?oo
o`RO[JT4Wk6]19nZYRjO[JT4UYjR15hm<`<A9Rh4Ui1h19nEP`BTXX/4W8ml19nEQ`BIPg03T75A17Y5
;PAb9Q@4BR0M18QRE@BGN6L3VX=e19nLR0BOTW`4WXQh191gJPBIQG44/9F20kVSR0BLQ7<4ASDW14lb
:@AmGD`4R6mK0iN6L0BIQG<4UX5Z18iaG@B>KE/4RfiB17akLP=mOWd4T9ZP:in]ZAGoool001Cooolj
WjfY16eRE0@d8QT4QG=X0e1@CPBLTgl4Whii19n7L`BOSWL4WiEo1::?M`>WQGD4YJZ>1<g6YPB3Og84
W7M`19MlK0>>I5H4TfQR195PF0BAGTl4R3da18a<@`AoE4P3Ug=M19=QE0BIKf04@AT<154e<0B5J5X3
TWmX19^9KPBFNF84RgQS18YeHPBCLEd4WYN70iBCSPB3R9<[WjfY5Oooo`005?ooocZO[JT4KF9D13@R
6@B5LfP3D51>19bCO`BOSWT4WhMc19n>M`BOUGl4XXmg0jN5M@BUZXh4cLJV18=oLPBLMg04Uga/0hiT
EPBCJ684TF1H195NC`B8?C44S4a317mDB0>GLed4Tf5D19U_H0A16@`4DCD`18EXFP>BOfP4VhU^19Ii
HPB;N6<4RWER19=aG@BNUhL3U9>>18>8Tb^O[JTEoooo000Doooo>Yn]Z@A]HU@4=28I18EcJ0=@D4h4
W9=o19n>N@BOQg<4Whig19nEO`BRSgL3YhEe1:FZSPC=aZH4Pgmb19agL0BGO6`3SVAF19=XHPBAH5P4
TEi?18Pm<@B<C4<4OeA80iMcG@BCHE@4VFmP144I30AA=C04QFQJ0i9oJ0BKRFh4UWUR18]hH`B:MF84
Tg5M19jGQ`>DThh4PhRC:in]ZAGoool001CooolDWjfY0inYY@BOZ:@KWjfY19JJVP@d9Q`4:AhG11Ph
>`>?QGT4Wi9m19n=P0BLRWd4VXij19n:O@BRRgT3Rf=;18E]G`BLUh/4WjJ@1:BOT@BVYIH3Xj>C19j[
T@BXU7d4WYV019^DMPBKQF/4TF9C0iIXG@BFDD<4T48`18<c8`A77aL4J4<o0hedHPBKQFh4UWaS191_
F`B8KE/4SW9P158b8P=SI5<4TYBE19ZTX2NO[JTEoooo000Doooo59n]Z@>OZJD4WjRT6in]Z@BFVYX4
=2HL12TN5`@H>3/3ShEi19nBO@BOSH04W8Ym19Z>NPBORWd4XX]i0h]SB`B5KEl4W9N;19nVT0BTWi44
YZFF0j>ST`BNZi44Z9Am19jIP0BKU7H4VhE[195RD`>FJ5d4UU531912<0B3<b<4AalG16Q3?`>=M684
VhE^19IlH`B@Ke/4R6eK18ibH0AB<R83HfAC19:DU@BJY:0WWjfY5Oooo`005?oooaBO[JT3WjVU19nX
Y1^O[JT4UYZJ13@V70@Y7QL463Pk0hn5N@BOTWd4Whf019b:O@BJSWX4WhYm1::;N@>;Hd/4QFeO19bG
R`BOYY04Y9nA1:JUUP>SXi<4WZ^A1:RDO@BNVH04ViAf19^5J`BAHU<3UVQM19IA@`B@@S04Pc<S14LO
5`AX@cl3SGAR19^5KPBFO6<4T6mK18Q]F`B>LV04DS8R0f=TD`BBU9D4VZBP9in]ZAGoool001CooolD
WjfY0inYY@BOZ:@KWjfY19JJVP@d9Q`4:AhG11Ph>`>?QGT4Wi9m19n=P0BLRWd4VXij19n:O@BRRgT3
Rf=;18E]G`BLUh/4WjJ@1:BOT@BVYIH3Xj>C19j[T@BXU7d4WYV019^DMPBKQF/4TF9C0iIXG@BFDD<4
T48`18<c8`A77aL4J4<o0hedHPBKQFh4UWaS191_F`B8KE/4SW9P158b8P=SI5<4TYBE19ZTX2NO[JTE
oooo000Doooo59n]Z@>O/Jd4WjZV6in]Z@BS/[84on_J1<N[S@ANG543VY:019nFP0BOW7l4Y8Mo19b7
O0BOXX@4XY5l0imnJPB0He44VXYi19nKS@BOVHX4Wi:40inKS@BOSHD4XHYk19Z4L@BKPg84U7iW19=k
H@>3NE`4SWaR19J0J0BQQ6X4Sg1T17=CA0>3KEL4Uh1Z19IlH`B@Med4R75L18idH@AnI5@3;2hY192H
T0BLZ:@WWjfY5Oooo`005?oooaBO[JT3Wk6]19nZYQ^O[JT4Xk:b1?o[fPC7Zhd4GUaA0iZBP0BOUX04
Wiao1:B7O`BLQg`4Wj:41::AO0>OOVX4P6=A19Z:N@BOVhd4WiV:19nBQ0>OVhd4Whf51:6:N`BJQ744
Vh=b19AnI`BCNf43PgUL18ilHPBFP6P4XHAZ18m`I0AcDd@3PfeG19N0JPBFO6<4T7MM18QaG0B>M644
OVAD0b`^:@B@V904W:RT9in]ZAGoool001CooolDWjfY0ina[@BOZZHKWjfY1:>b/PCojmX4aj^=15iL
D@>JTX04WiJ019nLO`BTQgl4W8Ml19nRQ0BRTG`3WgiZ181SD@BJRWT4Wi^=19nIRPBOTX@3Wi^=19n=
Q@BQRW/4VXAa19^3LPBDOVL4Tg]Q0h=iG0B>O684UX1X1:64JPB?L6@4Le=40h=]E`BGP6X4UWaS191g
G@B8LE`4SWAQ17iTE0</;RT4T9R@19bXY2NO[JTEoooo000Doooo59n]Z@>O/Jd4WjZV6in]Z@BS/[84
on_J1<N[S@ANG543VY:019nFP0BOW7l4Y8Mo19b7O0BOXX@4XY5l0imnJPB0He44VXYi19nKS@BOVHX4
Wi:40inKS@BOSHD4XHYk19Z4L@BKPg84U7iW19=kH@>3NE`4SWaR19J0J0BQQ6X4Sg1T17=CA0>3KEL4
Uh1Z19IlH`B@Med4R75L18idH@AnI5@3;2hY192HT0BLZ:@WWjfY5Oooo`005?ooocJO[JT4[ZjD19NE
SPBTYYL4WY>20iF<N0BJUH44Wi>319nRS0BOTX/4WiV<1:FMR@>NRg<4RVAC18]cH0BJTH04Win@19nI
RP>OUHL4WjR?1:6?O0BGN6<4UgYS18iiG@B7L5`3OVY@189OC0B2ID`4PV9<18IYC0B5Kf83RWIQ19Aj
J@BCM5l4Rf]K18E`F0B7L5/4E3P/0bPd=0B:T9D[WjfY5Oooo`005?ooocJO[JT4[ZjD19NESPBTYYL4
WY>20iF<N0BJUH44Wi>319nRS0BOTX/4WiV<1:FMR@>NRg<4RVAC18]cH0BJTH04Win@19nIRP>OUHL4
WjR?1:6?O0BGN6<4UgYS18iiG@B7L5`3OVY@189OC0B2ID`4PV9<18IYC0B5Kf83RWIQ19AjJ@BCM5l4
Rf]K18E`F0B7L5/4E3P/0bPd=0B:T9D[WjfY5Oooo`005?ooocJO[JT4[ZjD19NESPBTYYL4WY>20iF<
N0BJUH44Wi>319nRS0BOTX/4WiV<1:FMR@>NRg<4RVAC18]cH0BJTH04Win@19nIRP>OUHL4WjR?1:6?
O0BGN6<4UgYS18iiG@B7L5`3OVY@189OC0B2ID`4PV9<18IYC0B5Kf83RWIQ19AjJ@BCM5l4Rf]K18E`
F0B7L5/4E3P/0bPd=0B:T9D[WjfY5Oooo`005?ooocJO[JT4[ZjD19NESPBTYYL4WY>20iF<N0BJUH44
Wi>319nRS0BOTX/4WiV<1:FMR@>NRg<4RVAC18]cH0BJTH04Win@19nIRP>OUHL4WjR?1:6?O0BGN6<4
UgYS18iiG@B7L5`3OVY@189OC0B2ID`4PV9<18IYC0B5Kf83RWIQ19AjJ@BCM5l4Rf]K18E`F0B7L5/4
E3P/0bPd=0B:T9D[WjfY5Oooo`005?oooc:O[JT4W:JR19ZVWPBLSWH4UGaS18j5N`>=S884W92019nI
R@BOWHh4WiV;19nOT0BTU8`3Xhen19j1JPB?Je`4Uh=b19nGR@BOSh@3W89e19ZDP@BNT7P4Uh9]18iS
D@B>KE`4SVUB0h9VD0B4JU<4QfY@18Q]CPB4HTX4Q6MC0i9fHPBAMV84TW=O18U]FPB9KUh4S7MR13TT
8@<65Q44PHF4:in]ZAGoool001CooolbWjfY19bVXPBJYYh4W8if19ElH`B>QG/3SHb219b@P0BOVHT4
Wif>19nIR`BOWi04Y9B<0j>=OPBNPFX4Sf]L19N3LPBOUhT4Whn40ib2M@BJU844WY1h19N2K@B>He44
SVeL18iYDP>2IU04Q6YC18MZD0B8KDh4Q69:18AWD`>BMV84TGIR199cG`B9KEX4RFiN18agHP@i9243
1QHA1865Q2^O[JTEoooo000Doooo<Yn]Z@BLYZ84VZJN19b>MPBEO6<4SXEk0hf<PPBLT804WiV919nM
SPBOVH/4Win@1:BDS0>SSGh4WX5Z18m[G0BGPg84WiN919n?Q0>LPWD4VYB119j@N0BGPVd4SV=A18i]
G0B>JE83PVI@18AZD`B7JU04R6e>18ARBPB4Ie<3TWIR195fHPBBLel4RFeJ18U^GPB<Mf84>B@Q0`HF
4@B1QH@[WjfY5Oooo`005?oooc:O[JT4W:JR19ZVWPBLSWH4UGaS18j5N`>=S884W92019nIR@BOWHh4
WiV;19nOT0BTU8`3Xhen19j1JPB?Je`4Uh=b19nGR@BOSh@3W89e19ZDP@BNT7P4Uh9]18iSD@B>KE`4
SVUB0h9VD0B4JU<4QfY@18Q]CPB4HTX4Q6MC0i9fHPBAMV84TW=O18U]FPB9KUh4S7MR13TT8@<65Q44
PHF4:in]ZAGoool001CooolbWjfY1:BVU0BLVXh4WXah19=nJ`BLOV83ShIo19n7O0BOUHL<Wi^=19nX
S`>TTh04X8ib191`FPBBMfL4WiF719nXT`>TTh/4W9>71:FHR@BIQG<4VXA]191^F`B>KUP3Q5m>18AU
D@B3JE/4T71L19IjI`B=MV83TGQS195eH@BCMf84SG1L18U^F0B5L5/4DBlR0aDG5@@g>cP4WjRT9in]
ZAGoool001CooolbWjfY1:BVU0BLVXh4WXah19=nJ`BLOV83ShIo19n7O0BOUHL<Wi^=19nXS`>TTh04
X8ib191`FPBBMfL4WiF719nXT`>TTh/4W9>71:FHR@BIQG<4VXA]191^F`B>KUP3Q5m>18AUD@B3JE/4
T71L19IjI`B=MV83TGQS195eH@BCMf84SG1L18U^F0B5L5/4DBlR0aDG5@@g>cP4WjRT9in]ZAGoool0
01CooolbWjfY1:BVU0BLVXh4WXah19=nJ`BLOV83ShIo19n7O0BOUHL<Wi^=19nXS`>TTh04X8ib191`
FPBBMfL4WiF719nXT`>TTh/4W9>71:FHR@BIQG<4VXA]191^F`B>KUP3Q5m>18AUD@B3JE/4T71L19Ij
I`B=MV83TGQS195eH@BCMf84SG1L18U^F0B5L5/4DBlR0aDG5@@g>cP4WjRT9in]ZAGoool001Cooolb
WjfY1:BVU0BLVXh4WXah19=nJ`BLOV83ShIo19n7O0BOUHL<Wi^=19nXS`>TTh04X8ib191`FPBBMfL4
WiF719nXT`>TTh/4W9>71:FHR@BIQG<4VXA]191^F`B>KUP3Q5m>18AUD@B3JE/4T71L19IjI`B=MV83
TGQS195eH@BCMf84SG1L18U^F0B5L5/4DBlR0aDG5@@g>cP4WjRT9in]ZAGoool001CooolbWjfY19n^
Y0BLTWX4TgII18ijI`BGP7D3W9=o19n?P0BOUHL4WinD19nPU0BOVhd4Wi^@0inMR`BRT7/4U8EZ18if
H0BJSWd4WiR50inIQ`BOVHX4XIV419QnJPBAMV84Rg=O191gHP>;L584R6A<18=VE0B;MFH4U7e]19V0
K0>FQG04SWeY18]fHPB;Mf84RG5Q18akIPC?TV83J3`Y128H4`A5BDLWWjfY5Oooo`005?oooc:O[JT4
WjjT19bBNPBCMUT4SWYW19N0M@>LTgl4Whn019nEQ`BOWi@4Wj2D19nKS@BOVi03Wif;1::@N`BDQFX4
SWIP19Z>O@BOV8D3WiV719nIRPBQVH@4V7iZ195fHPB;Lel4T7MR0h]`DPB8I4`4PfID18]eIPBDOFd4
VH1/0iJ5L0B>OFT4RgIR18]gHPB9LF44S7]V1<nBHP=X?2T48QPC14E9AbNO[JTEoooo000Doooo<Yn]
Z@BO[Z@4W99j19=fF@B>NVL4Uh1e0ibCO`BOSh04WiF719nOU0BOX9@4Wi^=19nKT0>OWH/4XY1k19B5
JPB>MV04VXim19nHQ@>OVHL4WiV:1:6IQ0BHOVX4TGIR18]cG`B@Mf83Rg1B18QTC0B3IU@4RgEV19Am
K@BIP6`3UXE`18imJ@B;MV84RgMR18UaH@B<NfH4ci9R0fPl:@@R61<4ADU79in]ZAGoool001Coool^
WjfY19nNTPBIPg<4SU=519E]G`AjIUX4R9Qo0in?O`BOUH44WiF719nGQPBOWI04Wi^=19nKS0>LTX84
XIV219bBP0BJSGP4W9=l19b:N`>JQG@4Wh]m19j2L0BHNV84Rf]I18QWE0B5K4l3Of1<17iRC0B5K5X4
RWUT199mK0BKPfl3UWYV18ifHPBCMF44SG=K18a_F@B<LF04V81]0k27JPBoZ9L4KWYg9in]ZAGoool0
01Coool^WjfY19nNTPBIPg<4SU=519E]G`AjIUX4R9Qo0in?O`BOUH44WiF719nGQPBOWI04Wi^=19nK
S0>LTX84XIV219bBP0BJSGP4W9=l19b:N`>JQG@4Wh]m19j2L0BHNV84Rf]I18QWE0B5K4l3Of1<17iR
C0B5K5X4RWUT199mK0BKPfl3UWYV18ifHPBCMF44SG=K18a_F@B<LF04V81]0k27JPBoZ9L4KWYg9in]
ZAGoool001Coool^WjfY19nNTPBIPg<4SU=519E]G`AjIUX4R9Qo0in?O`BOUH44WiF719nGQPBOWI04
Wi^=19nKS0>LTX84XIV219bBP0BJSGP4W9=l19b:N`>JQG@4Wh]m19j2L0BHNV84Rf]I18QWE0B5K4l3
Of1<17iRC0B5K5X4RWUT199mK0BKPfl3UWYV18ifHPBCMF44SG=K18a_F@B<LF04V81]0k27JPBoZ9L4
KWYg9in]ZAGoool001Coool^WjfY19nNTPBIPg<4SU=519E]G`AjIUX4R9Qo0in?O`BOUH44WiF719nG
QPBOWI04Wi^=19nKS0>LTX84XIV219bBP0BJSGP4W9=l19b:N`>JQG@4Wh]m19j2L0BHNV84Rf]I18QW
E0B5K4l3Of1<17iRC0B5K5X4RWUT199mK0BKPfl3UWYV18ifHPBCMF44SG=K18a_F@B<LF04V81]0k27
JPBoZ9L4KWYg9in]ZAGoool001Coool^WjfY19nOW0BRNfl4UfED18UMDPBBM684Shj00inIS@BOVHT4
WiF729nKS@BOV8T4WiR50j6FPPBLT7X4WXYg19N@P0BOVHd4Y:JC0ib?Q@BOVGl4XXMg19=jH`B8JED4
PfA@17UNC`>;JeD4QGAQ18efH`BBP6d4TX9_19^3K`>FOVT4SWQS18i_G`BCJf84RFmL18Y_HPB<L5H3
QFMC185PC@BT/JdWWjfY5Oooo`005?ooobjO[JT4WinL1:9kK`BGIE@4REeB199dHPB?SX03WiV=19nI
R@BOUHL8Wi^=19nHR@BOV8D3XIJ219b@NPBNRWL4Ui2019nIS@BTYY<3W8n519nIO`BRQgL4TgYS18QY
E@B3I504NEi?0h][E@B5M644SGIS19:0K@BBPVl4Vh=_0iInJ@B>N6<4SVmO19=[HPB9Ke`4RVmR18a`
EP>5Ie<4PF1=1:Ba[BNO[JTEoooo000Doooo;Yn]Z@BOWi`4XW]_19MUE0B9GE84TWAR18n>P0>OVHd4
WiV919nEQ`ROVhd4WiR919nHQ@>QUX84W91j19j:M`BGT804WiV=1:BVT`>LShD4WiUo1::7M`BCNV<4
R6UE18=TD0AiGTl3Rf]E18EdH@B=MV<4TX1]19:2K`BKPfl3UWiY18ihH`B>Kel4Tf]R18U_G0B:Kf84
S71F0hEWD`B1H4d4Y;6]9in]ZAGoool001Coool^WjfY19nOW0BRNfl4UfED18UMDPBBM684Shj00inI
S@BOVHT4WiF729nKS@BOV8T4WiR50j6FPPBLT7X4WXYg19N@P0BOVHd4Y:JC0ib?Q@BOVGl4XXMg19=j
H`B8JED4PfA@17UNC`>;JeD4QGAQ18efH`BBP6d4TX9_19^3K`>FOVT4SWQS18i_G`BCJf84RFmL18Y_
HPB<L5H3QFMC185PC@BT/JdWWjfY5Oooo`005?ooob^O[JT3Wj:F19nYTPBRSW@4Tg1C18QUE0B:NFT4
W9>00inEQ`BOWi04WiF719nDQ@BLT7d4VYAn19n:O`>QQWT4UHQc19b3L0BGS7T4Wi:019nHQ@>OUHL4
Wi291:9mK0BGMF04RV]G18QZEPB3KEX3P75J18EaG0B<NFH4Ugm/19B0K0BGO6P3UWYV18icG`B>KeT4
RfeI18]aF`B8LUl4Uh1_0h]^FPAdF4P4SIBA9in]ZAGoool001Coool[WjfY0inRUPBOZI84XXid19=`
D`B8IE@4RWUY19bCP0>OUHL4Win@19nEQ`BOU8D4W91m19ZDOPBORWl3XHIi19F8L`BLPg04Uhai19nB
P0BOV8D3WiF719n@R@BROF`4UgEP18Y[E`B8JUH4PfeJ0h1aFPB5LE`4S7UV19MoK0BDP6`4UgaX0iIj
IPB>Lel4SVmI18]]F@B;LE/4R79O19N0K`>;KUX4M5Q818fDTBNO[JTEoooo000Doooo:in]Z@>OXYH4
WjVB1::>M0BCL5<4R6ED18YiJ@BLTh03WiF719nOT0BOUHL4WiB519b@O@BJU7h4WhYo0j66N@BER7<4
W8=`19N<N@BOTX04WiR50inEQ`BOT8T4XWe/19MeH0B:JeL4R6YF18=]FP>0LEX4QG5L18aiIPBGOf`4
U81/19MlJ0>FNVH4SW=O18i_F@B;KET4Rg5K18QbG`BGP6l3RfiJ17AHB0B=U94WWjfY5Oooo`005?oo
ob^O[JT3Wj:F19nYTPBRSW@4Tg1C18QUE0B:NFT4W9>00inEQ`BOWi04WiF719nDQ@BLT7d4VYAn19n:
O`>QQWT4UHQc19b3L0BGS7T4Wi:019nHQ@>OUHL4Wi291:9mK0BGMF04RV]G18QZEPB3KEX3P75J18Ea
G0B<NFH4Ugm/19B0K0BGO6P3UWYV18icG`B>KeT4RfeI18]aF`B8LUl4Uh1_0h]^FPAdF4P4SIBA9in]
ZAGoool001Coool[WjfY0iVGPPB7Ie84KE4l16UC@`AeI5D4SGm_19nEP@>OTX@4WiB519nHQ@BOTW/4
XI9o19F4M@BERW83Uh1e19Z>O@BJSg/4Uhig19nEQ`BOUHD3WiF719bNQ@BNS7L4UgEP18Y[E`B4Ie@4
RfUF0hE^GPB;M6@4TWUY191kI`BGQ744U8E`0iIlI`B>OfX4RgQS18]`G0B9JUh4R75R18QPA@>:IE<4
SF17181RERNO[JTEoooo000Doooo:in]Z@>IUh84QfMB16eA?0AYDd<4MFAE18eoK`BOUH43Wi:419nD
Q@BOV8D4Wi9k1:6BO`BEQ7D4UHYb0iN0M@BJSWd4VXmk19N>M`BOUHL4WiF50inEQ`BLWXD4WXag19Me
H0B:JeL4Q6MD18]YEP>5KUh4RgAT199iJ@B@NfL4UhAa19B5L0>FO6L4SWmZ18]hH`B;L5`4RFYN18Qa
HPB8H4D3RVEC18ePA`B0HUHWWjfY5Oooo`005?ooob^O[JT3VIN218MWDPA]DC`4JE=317ETE@B=Ofl4
WiF10inBQ0BOU8D4WiR519nBN`BQTWl4UHAe19F:LP>GP7D4VXim19Z?N`BGSWL4WiF719nEQ@>OUHL4
W9j519j<M`BGMF04RV]G18AWE0B;JEH3QFiN18]dI0BBNFT4T7]W19N4L@BDQG03UWaW18ioJPB;N6<4
Rg1L18UZGPB8LF84R6150hYUD`B=H4L4P69F9in]ZAGoool001Coool[WjfY0iVGPPB7Ie84KE4l16UC
@`AeI5D4SGm_19nEP@>OTX@4WiB519nHQ@BOTW/4XI9o19F4M@BERW83Uh1e19Z>O@BJSg/4Uhig19nE
Q`BOUHD3WiF719bNQ@BNS7L4UgEP18Y[E`B4Ie@4RfUF0hE^GPB;M6@4TWUY191kI`BGQ744U8E`0iIl
I`B>OfX4RgQS18]`G0B9JUh4R75R18QPA@>:IE<4SF17181RERNO[JTEoooo000Doooo:in]Z@>OSgL4
GcPP15Ll;`A3<BX4@dA21923MPBOUHD3WiF319nEO`BOUHL4WiV<1:BGR`BQX8h4Xhn20iAlK0B?Kf44
T7e[19F8M@BJTWh4WiF70inEP`BQSGh4V85]18mZG`B6IU<4PF==17iVE0><LV04Qg=M18abH@B?MfP4
TG1O18afH`>>MV84Qg9N18]eH@B9LUd4RFeL18EXF0B9N5L3N5@l18M[F0B0DD<WWjfY5Oooo`005?oo
ob^O[JT3Whmg15lh80AG?2l4@c4Z14=4@PB@PgH4WiF50inEP`BOUGl4WiF719nIS0BTUh/4XJ2>1:>?
PP>DO6`4SfmQ191mJ`BER7D4VY9n19nEQ`>OUH<4XHen19R1K@B?JUl4QVIC185SC@AnIU@3S79P18Mc
G@B<LV44SgMX195`G`B<MV<3SWIR18MbGPB;MF44RG9M18U]G0B5J5P4RGQG0gQD?0B7JeP4P5539in]
ZAGoool001Coool[WjfY0in?M`AO>204Ec`_14<a:PA3A484T8=f19nEQ@>OUH<4WiEo19nEQ`BOVH`4
Y9N;1:6PSPBSSh83U7a/18m_H@B@OF/4UHQe19ZBOPBOUHL3WiF31:6=OPBHPFd4SfYO18IVD`B1Hdd4
OVID0habH0B7Led4S79Q18mgJ0BAL5l4S7IS0hifHPB7LUh4RgEQ18UbG@B9KE`4QFQH18UhE`=hE3`4
Qf]H181A@bNO[JTEoooo000Doooo9in]Z@BOYYh3YjRN1;5`EPAD=bL4C3D/12li?0B@Pfl4W99k0iZB
Q0BOUHD4UXE]18QhI0AoJ5<4M5e:17QUEP=lHUT4R6QM18EXE`B=M6@4TXMe19nEQ`>OUH/4XIB219f1
KPB@Le<4Q69<18EWD@AjHe03NfAC17U]FPAoKE/4QGUT18ikI`B:M643TgaW18efHPB9Lel4RG9M18U]
G0B9KUl4NU8n0f0e90A[CCL4Nddi9in]ZAGoool001CooolWWjfY19nVWP>WZ9h4/G1F15@g9`A<=B`4
;cTl1923K`BLTW/3VY:419nEQ@BFQFd4R7QT17mXD`AdGDX4N6EF0gaRF@B8J5d4QFQG18edI0BBQgD4
WiF70inER`BQU884WH5^191cD`B4HT`4QFMA17YSD0=kI5<4NFeJ17m]F`B5NF@4SW]W18YdH@>CO6L4
SGIR18UcG`B9LUd4RFeL18U^G`AjDSh3H3DT16]==`AkCCTWWjfY5Oooo`005?ooobNO[JT4WjJN0jNX
WPBaL5H4E3LW14`e;0@_>C`4T8=_19bBN`>JTX@4WiF519J5K@B8N6@4OfQC17AMBPAhIEH3O69I18QX
G@B5J5L4SGAT19:7M@BOUHL3WiF;1:6DPPBMPFh4T7=C18ARC0B5Ie44NV=@0g]TD`AiKEX4OfeK18Ei
I0B>NfL4RWAQ0i=lI`B=MV84RG=O18UbG@B9KE`4RFiO17YB?P=P=B@4Jddg17]=>BNO[JTEoooo000D
oooo9in]Z@BOYYh3YjRN1;5`EPAD=bL4C3D/12li?0B@Pfl4W99k0iZBQ0BOUHD4UXE]18QhI0AoJ5<4
M5e:17QUEP=lHUT4R6QM18EXE`B=M6@4TXMe19nEQ`>OUH/4XIB219f1KPB@Le<4Q69<18EWD@AjHe03
NfAC17U]FPAoKE/4QGUT18ikI`B:M643TgaW18efHPB9Lel4RG9M18U]G0B9KUl4NU8n0f0e90A[CCL4
Nddi9in]ZAGoool001CooolWWjfY19bMS@>NSW/4?aP?12XK5@@/91h46c8g19:4LPBOTWd3W91h19nE
P`B[WHD4SGMR17YVD@ABAcd4>C8[0c`c8`AB@CD4J3h/164b90A/DD@4VXim0inEQ`BQVH@4WHA^191`
F0B1KU04OF1717aZF0>BMf<4U7aW18adH@B9JE/4QFiM17m`G`>>NFD4T7QS18=_F`AkKe/4PG5L18Ua
G`B=HTP3L4Da16Q1=0Ah@BdWWjfY5Oooo`005?ooobNO[JT4W9f=0ij>N`@o60l4:Q/E12`T7P@K<SL4
TXAb19nBO@>LT7P4WiF31:^MQ@B=Mf84NVIA1597?@@i<R/3?3<S1591=@AX?R`4HC8T16aAA0BJSWd3
WiF71:6IQ0BMQ6h4T71H185^D0AmH4L4O6YH0i9gH`BDO6L4S7AQ18UYF`B5KUd4Og1O0hiiI@B@N6<4
PfmK17]_F`B1LE`4RG5O18eRB0=`AC44J44d17Q1;BNO[JTEoooo000Doooo9in]Z@BLWHd3WXik13lH
3`@Z6aD4;2@N11/b=`BBQ784Wi9m0ib@N0BOUH<4Zif518egHPAjIU44DTLm13Tb:`<l<b<4DT4e16Pn
;0AQ<R@4K55419Z>O@>OUHL4XIV419f4KPB@L5P4PFi@17ePA`AlJUP3TWMS19AlI`B<M644RFUK18E^
G@AoL5l3SWUU191hH`B3Ke/4NfmK185aG0B9LEl4SF980g15<@AX@C@4N44]9in]ZAGoool001CooolW
WjfY19bMS@>NSW/4?aP?12XK5@@/91h46c8g19:4LPBOTWd3W91h19nEP`B[WHD4SGMR17YVD@ABAcd4
>C8[0c`c8`AB@CD4J3h/164b90A/DD@4VXim0inEQ`BQVH@4WHA^191`F0B1KU04OF1717aZF0>BMf<4
U7aW18adH@B9JE/4QFiM17m`G`>>NFD4T7QS18=_F`AkKe/4PG5L18UaG`B=HTP3L4Da16Q1=0Ah@BdW
WjfY5Oooo`005?ooob>O[JT4XK2/1:R_XP>LOFD4QU94130N60@b81X442H^19bAOPBJU7l3VY1l19nE
P@BTWH`4[YEn1:V>O@B0GDP4?RPO0c8T6`@f=2l4GEA318A^F`AkI5P4Ui5n0inQU@BQXI84WHUa18UV
DPAiEd<4FR8B150i<@=gFd44LeU2165;>0AYFTL4PfYI17Q[E@>7LU`4RgEQ18]]F0AoJUL4O6YL18=W
EPAdCch3I4Xi16aGBPAoBS`4Y;6]8in]ZAGoool001CooolSWjfY1:6`[0BX[j83W7eU18IBA0@`7QP4
<R0J110V;PBLTGh4VYAo0iZ@O0BOUH44Y9f<1:jEOPBYSWd4P5e813hX7`<b91/4=S@_15eD@`B4KU/4
NfAH19NAOP>OXID4XJ6B19f9L@B9IU84NEM315XR4PA@>C43Me]117=I@PAQBcP4JEY718=ZF@AhJeD3
Qg9L18]eH@B;KEP4OfYG17aZG0B3IeH4M4ln0fA:>@A/EdX4OdXl1:Ba[B>O[JTEoooo000Doooo8in]
Z@BQ/:`4Z:nR0iamI@B6DT@4<1hH138P6P@@9Rh4W95n19ZDO`>JT7`4WiF11:BMS0B^UGh4ZHim181M
B0@n:1l3<R@K13Hd;`AME4<4Q6iK17]TF0BGTGh3Wj6E1:6QTPBMRG44RFIB17UG@`AJ8Q84D3Ta0gMK
@@AcFD84HD/h16UJA`B3JUT4N6]E0hMbG0B;MF44RfeH17mZE`AlJU`4PfMF17A??P=TBST4K5M:17m:
?0BT/JdSWjfY5Oooo`005?ooob>O[JT4XK2/1:R_XP>LOFD4QU94130N60@b81X442H^19bAOPBJU7l3
VY1l19nEP@BTWH`4[YEn1:V>O@B0GDP4?RPO0c8T6`@f=2l4GEA318A^F`AkI5P4Ui5n0inQU@BQXI84
WHUa18UVDPAiEd<4FR8B150i<@=gFd44LeU2165;>0AYFTL4PfYI17Q[E@>7LU`4RgEQ18]]F0AoJUL4
O6YL18=WEPAdCch3I4Xi16aGBPAoBS`4Y;6]8in]ZAGoool001Coool4WjFQ19nXY0BOZJD4WjRT4in]
Z@A37QD4?TM50ij6L0B@FdD4>BT/12@L5`@57BH4UHah19nEP@>JT7/4Uhij19ZBOPB[YI84TXA/1<BG
N`BgTW@3TfmB185J?`AcKEH4P6eI18mdH`BGRgP3WiN61:6IR@BMQg04VG1D185NB`B>I4P4ET@n0e18
A0@E30/4=2dV148j<@@k;B44@3`e0ea:=@A]ESl4QfaG17m[F@AlKEP4Of9?15a1;`=3=2X4De95185L
BPBV/jlSWjfY5Oooo`005?ooo`BOYJ44WjRT19nYY@BOZ:@CWjfY14<N5@@nAdD3WXI`191KA@@i:B`4
91`G10DM9PBES7P4WiF10iZ@N`BGSWX4VY9n1:^UTPBBQ6`4a9Mk1;NBM0>CKe84PEXo17=]EPB0KET4
SgAS19N;N0>OUhH4XIV919f7L0BIL5@4PEi;18iTB0AFA3h3D4Q411D<2`@d;BH4@SXa13/]8@A0?3D3
G4Xe16eF?`B7K5L4Of]I17a]F0AoHTl4G44_0d<d:PACDTD4PEa:1:Jc[b>O[JTEoooo000Doooo19nU
X@BOZ:@4WjVU19nXY1>O[JT4@ahE13i7A@>NQW04T5]513TY;0@T71L41AdV19F<N0BOUH43VY1k19N>
NPBJTWh4ZjFB19:4K0C4Ug/4]i9d0i=_DPB1FSl4LfeF181]F@B?M6<4Uh]h0inGQPBQVHT4WHM`19U`
E0B1GT/4SVA815I4?P=@B4@45@`;13@]9PA2>S44>bdQ140l=@=LBSD4KEHo18M/E`AoJeT4O6eH17mR
C`AL@Bl3@c@Z15=BA@B1G4X4Y[>_8in]ZAGoool001Coool4WjFQ19nXY0BOZJD4WjRT4in]Z@A37QD4
?TM50ij6L0B@FdD4>BT/12@L5`@57BH4UHah19nEP@>JT7/4Uhij19ZBOPB[YI84TXA/1<BGN`BgTW@3
TfmB185J?`AcKEH4P6eI18mdH`BGRgP3WiN61:6IR@BMQg04VG1D185NB`B>I4P4ET@n0e18A0@E30/4
=2dV148j<@@k;B44@3`e0ea:=@A]ESl4QfaG17m[F@AlKEP4Of9?15a1;`=3=2X4De95185LBPBV/jlS
WjfY5Oooo`005?ooo`BOYj<4WjJR19na[@BOZZH?WjfY14/]9@A6;bH44`L30c8R7@@e8RH4:AhG12lR
70@67RP4VY1k19N@P0>JNV`4RVaM18f0KPBTWI84YZNH1:ZGR0BJO6T3WXA`19MlJ0B<M5l4TX9Z19N0
KPBGRGL3Wi^=1:6FR0BMS7P4T7QM18U`C`B<L504Tf]B0j9eG0@f8Ql48AhH148`:PA1<b`4?ST]0faG
B0AbIU<4S6UB18=ZE`AlLEX4Hd0e14Pc9@<o;204>C8Y17U6=0BQ[j/SWjfY5Oooo`005?ooo`BOYj<4
WjJR19na[@BOZZH?WjfY14/]9@A6;bH44`L30c8R7@@e8RH4:AhG12lR70@67RP4VY1k19N@P0>JNV`4
RVaM18f0KPBTWI84YZNH1:ZGR0BJO6T3WXA`19MlJ0B<M5l4TX9Z19N0KPBGRGL3Wi^=1:6FR0BMS7P4
T7QM18U`C`B<L504Tf]B0j9eG0@f8Ql48AhH148`:PA1<b`4?ST]0faGB0AbIU<4S6UB18=ZE`AlLEX4
Hd0e14Pc9@<o;204>C8Y17U6=0BQ[j/SWjfY5Oooo`005?ooo`BOYj<4WjJR19na[@BOZZH?WjfY14/]
9@A6;bH44`L30c8R7@@e8RH4:AhG12lR70@67RP4VY1k19N@P0>JNV`4RVaM18f0KPBTWI84YZNH1:ZG
R0BJO6T3WXA`19MlJ0B<M5l4TX9Z19N0KPBGRGL3Wi^=1:6FR0BMS7P4T7QM18U`C`B<L504Tf]B0j9e
G0@f8Ql48AhH148`:PA1<b`4?ST]0faGB0AbIU<4S6UB18=ZE`AlLEX4Hd0e14Pc9@<o;204>C8Y17U6
=0BQ[j/SWjfY5Oooo`005?ooo`BOYj<4WjJR19na[@BOZZH?WjfY14/]9@A6;bH44`L30c8R7@@e8RH4
:AhG12lR70@67RP4VY1k19N@P0>JNV`4RVaM18f0KPBTWI84YZNH1:ZGR0BJO6T3WXA`19MlJ0B<M5l4
TX9Z19N0KPBGRGL3Wi^=1:6FR0BMS7P4T7QM18U`C`B<L504Tf]B0j9eG0@f8Ql48AhH148`:PA1<b`4
?ST]0faGB0AbIU<4S6UB18=ZE`AlLEX4Hd0e14Pc9@<o;204>C8Y17U6=0BQ[j/SWjfY5Oooo`005?oo
o`BO[j/4WjZV5in]Z@A]@cL4?b`Q13dW7`<Y81`47Q<A12hO6`@d8A/4424Y19b<N0BJS7D3ZJjH19b:
N0AeFD@4KeE416iJB0APDD84E3ld0dlj;0AH@c84GT0a16eMC@B@Q784UhYg0inDP@BQUWh4WH=`191h
H`B8H4`4Ofe>17i[C`>BOF@4fj1k18mgH@B1FD84Q5Q216eLC@>2JDh4O6EA18EfG0B?Led4OfeL1652
;0@f8ad3?B/P13`b9PA^;QhWWjfY5Oooo`005?ooo`BO[j/4WjZV5in]Z@A]@cL4?b`Q13dW7`<Y81`4
7Q<A12hO6`@d8A/4424Y19b<N0BJS7D3ZJjH19b:N0AeFD@4KeE416iJB0APDD84E3ld0dlj;0AH@c84
GT0a16eMC@B@Q784UhYg0inDP@BQUWh4WH=`191hH`B8H4`4Ofe>17i[C`>BOF@4fj1k18mgH@B1FD84
Q5Q216eLC@>2JDh4O6EA18EfG0B?Led4OfeL1652;0@f8ad3?B/P13`b9PA^;QhWWjfY5Oooo`005?oo
o`BO[j/4WjZV5in]Z@A]@cL4?b`Q13dW7`<Y81`47Q<A12hO6`@d8A/4424Y19b<N0BJS7D3ZJjH19b:
N0AeFD@4KeE416iJB0APDD84E3ld0dlj;0AH@c84GT0a16eMC@B@Q784UhYg0inDP@BQUWh4WH=`191h
H`B8H4`4Ofe>17i[C`>BOF@4fj1k18mgH@B1FD84Q5Q216eLC@>2JDh4O6EA18EfG0B?Led4OfeL1652
;0@f8ad3?B/P13`b9PA^;QhWWjfY5Oooo`005?oooanO[JT4N4hg12XG40@R71D39Q/E12hO5`@O6aD4
=30Z11/_<`B=PW04Y9=o0ibCP0B^YYT4][2J19QmK0B2J604RG=U19QbG0>8JeP4OV=>18IaGPB5L644
Uhen19bCP`>ORX84XHio19f7LPB@LfL4KTDd15df:@ARDSh3PG1C18UcF@BENV84WX=W18agH0AiK5H3
PFmM18U]F`AoJU`4PG1H17mTC@@g:1h48QdF0dA;@@AUAS84GbLH9in]ZAGoool001CooolOWjfY17Q>
=`@Z5a048Q`E0bHK5@@^7aL47a/E13@`:P@K;c<4SH9`1:BCO`>LTh04[ZJI1;J`VPBHOF`4PVQP18Uc
I@BHLU`3R6]H17iSCPB6LEh4QG1Q19N=OPBLTh<3WhZ21:6>O`BMQg84T7=W16i5=0AM=RT4HU8n0h5`
D`B9LeT4UGYR19j3I`B<Mf04NFaF0h5_G@B9KE/4OfYL185`F0AoI4d4=bPN128M5P=4Bd44IDHb15lW
62NO[JTEoooo000Doooo7in]Z@AhCSL4:QL@128L5@<V6aD4;QlG11lK5@@d<2X46blc18f2L0BTTgl3
W9>01:jVV@Bf/9X4V7e/189XH0B9LfD4V79L0hQ[F0AnHdh4QW5N18E`H@BGSGh4W9>30in:PPBQSWl4
WHMb191cI`A^AC@4GCHY169B?P>1L5<4RG=I19EjHPBNPfL4S7MP17U/EP>1Ked4RFeK17mZG0B1L5P4
OfA=13LX7P@R7AH3A4]116E6<PAO9aPWWjfY5Oooo`005?oooanO[JT4N4hg12XG40@R71D39Q/E12hO
5`@O6aD4=30Z11/_<`B=PW04Y9=o0ibCP0B^YYT4][2J19QmK0B2J604RG=U19QbG0>8JeP4OV=>18Ia
GPB5L644Uhen19bCP`>ORX84XHio19f7LPB@LfL4KTDd15df:@ARDSh3PG1C18UcF@BENV84WX=W18ag
H0AiK5H3PFmM18U]F`AoJU`4PG1H17mTC@@g:1h48QdF0dA;@@AUAS84GbLH9in]ZAGoool001Coool8
WjfY19nYY@BOZ:@?WjfY18IRC0@i6a84:a/E0b8L5P@C2`/491XE130[9P@Y>3L4Mg1Q19Z<N@>OUH44
WiV;1:BQUPB`^:@4`K>N19ZWV@Bb/jD3[:^L1;:eY@BKW8X4VHYf19NCO`BLUX83UiYo19b<NPBPSGP4
X9Mj1:jCO0AeCT<4@2XS0c<W7@A8@3D4M6=B18]cG@BBMeX4OfeJ0hIZE@AdHT`4P6MJ18EZG0AS?bh4
>b@K138/9@<R<2T4L48/13LK50A:D4hSWjfY5Oooo`005?ooo`RO[JT4WjVU19nXY0nO[JT4QV9<13TK
4P@[6aD38Q`F11<;2`@T6QD4<2/V12Th=`AgL644VXai0inEP@BOVH/4Y:6F1;2hY0C1/ih4VZNI1;:c
Y@>/Zi`4/[FU19^LRPBIRWH4Ui=o19bFPP>GVWl4W8aj1:2=N0BPUgX4[Y=l17E>@`A0:R<3<bLM14Q0
=@AdHe84Rg=M199gFPAoKEX3QVYE17ARC0B0IeX4QFYL16<o;P@k91/4<R`U0b8`:@A`@R`4=a/D14Y@
CR>O[JTEoooo000Doooo29n]Z@BOZJD4WjRT3in]Z@B6HT`4>A/B12/K5@<R71H44`/;12@J5@@`:bH4
:CPg17M`H@BJS7T3WiF119nIR`BTXIH4/;RT1<6cWPBJYiT4/[>U0jb[W0Bb]JD4Vib:19V:MPBGTgl4
W9J20iNJO`BLS7X4X8eh1:2GNPB^Tg`4MDi3140Z8`<c9ad4B40e17ASDPB;Led4TWMJ17m]FP>6JUD4
M69<181WFPB5JU`4Hcl^13/T6`@b;2D38S0Y1712;0@g6a@4BU1>8in]ZAGoool001Coool8WjfY19nY
Y@BOZ:@?WjfY18IRC0@i6a84:a/E0b8L5P@C2`/491XE130[9P@Y>3L4Mg1Q19Z<N@>OUH44WiV;1:BQ
UPB`^:@4`K>N19ZWV@Bb/jD3[:^L1;:eY@BKW8X4VHYf19NCO`BLUX83UiYo19b<NPBPSGP4X9Mj1:jC
O0AeCT<4@2XS0c<W7@A8@3D4M6=B18]cG@BBMeX4OfeJ0hIZE@AdHT`4P6MJ18EZG0AS?bh4>b@K138/
9@<R<2T4L48/13LK50A:D4hSWjfY5Oooo`005?ooo`RO[JT4Wk6]19nZYPnO[JT4LF1E13/^9P@/7AL3
:Q`F128I4@@S6QD4<B/V13@o>`AdJU`4UhYg0inEP@BOUHL4Wi^=19nOU0ROY9/4Wj2D0inOU0BOX9@4
WinD1:BMR`BLT7P4Y9^80ij@NPBJR7<4WXYf19b<M`BVTX44_ZB<1:n7M`>7HU84?c4V134U6`@o<R/4
BT0f15I6=@=IAcD4NV1C181ZE`B6JEH4Dc0U12lO60@Z7ah37a@?13dP5PAE=bh48BDR8in]ZAGoool0
01Coool8WjfY19na[@BOZZH?WjfY175PE@@k;RH4;1dG0bXL5P@R6A448aXE134[9P@d?c/4M6YL19N:
M`>OUH44WiF719nKS@BOWi@8WjBK19nPU0>OWi@4Wj2D19nOU0BTWH/4W91h1:BKR0>NT7X4VXQc19j:
MPBLS7L4YY:11;jTS0B_QgL3Qf9B13la9P@a9A/4?c8[14Y0=PAFASD3FDLe17YPD`B0JUL4QVUF15<`
9@@_7aP4:QlN0alD3`@m81H4ECL^124U8R>O[JTEoooo000Doooo29n]Z@BO/Jd4WjZV3in]Z@AaH5D4
>bhV12`M5`<Z71H48QTA12<J5@@a:bH4=3lk17AZG0BGRWL3WiF119nEQ`BOVhd4WinD29nTV`BOX9@3
WinD19nPU0BOWi@4Y9f;19b@N0BTVhP3WY1j19Z8L`BNRWH4W8ag1:JBP@BnY8`4[hMg0hMRDP@o<BH4
<BDK13lb:`A:@3H4ETHe0eU7=@AjH5<4P6YG18IYEPAC<2D4;alH12XO7P<O50l4?B0F15Dg;P@Q9B8S
WjfY5Oooo`005?ooo`RO[JT4Wk6]19nZYPnO[JT4LF1E13/^9P@/7AL3:Q`F128I4@@S6QD4<B/V13@o
>`AdJU`4UhYg0inEP@BOUHL4Wi^=19nOU0ROY9/4Wj2D0inOU0BOX9@4WinD1:BMR`BLT7P4Y9^80ij@
NPBJR7<4WXYf19b<M`BVTX44_ZB<1:n7M`>7HU84?c4V134U6`@o<R/4BT0f15I6=@=IAcD4NV1C181Z
E`B6JEH4Dc0U12lO60@Z7ah37a@?13dP5PAE=bh48BDR8in]ZAGoool001CooolOWjfY18IYG@A??CD4
:b4J0bLL5P@[7AL4:b4P13</:0@c?CL4Hea?18f1L0>OUGd4Wi:019nGR@BOUhH4Wif@19nQV0BOYYl3
WinD19nRU`BOVhd4WinD19nIR0BOUH43XIEo19Z>N@BJQ744VXIc19Z:MPBPQgD4V8ad0jb:L0BTQF`4
T7=K16]F@@AaCc`4LUm=0hQ_G0A^G504OfMK17QWD`AD<RH4;1dG128K5@<L614491lJ140b;0@S9bDS
WjfY5Oooo`005?oooanO[JT4QVUM14lm=@@[8AX39a`F12/M5`@[8B04<b`X13<m=`ASG4l4SH5`0inE
O@BOTX04WiN919nGQPBOWI04Wj6H19nVW`>OWi@4Wj:G19nKS@BOWi@4WiV819nEP@>QUGl4VXii19Z4
L@BJQW<4VXYf1:27M@BHS7@3[8Y`1:B5K0B@Le/4JeI1175??0AbGdd3R6mL16iLD0AoIe/4N6MC15@b
9P@/7AL48Q/E0a`H4@@T7aX4@38/12<W9B>O[JTEoooo000Doooo7in]Z@B6JEd4Ccde12/Q6P<W71H4
:adG12/Q80@c;2P4<cdg16=LC`B=PG03WiEm19nBP0BOUhT4WiN619nMT0BOXIP4WjJO0inOU0BOXYL4
Wi^=19nOU0BOVHP4WiF10j6EO`BJSWT4VXAa19Z6L`BJRWH4X8Me19R<M0>/RW04Y8E/191cF`A[ET44
LDll179OC@>8Ke`4KUa@17mWF`AhIe<4E38V12`M5`@R6aD371PA12@O6PA0<R`48bLU8in]ZAGoool0
01CooolOWjfY18IYG@A??CD4:b4J0bLL5P@[7AL4:b4P13</:0@c?CL4Hea?18f1L0>OUGd4Wi:019nG
R@BOUhH4Wif@19nQV0BOYYl3WinD19nRU`BOVhd4WinD19nIR0BOUH43XIEo19Z>N@BJQ744VXIc19Z:
MPBPQgD4V8ad0jb:L0BTQF`4T7=K16]F@@AaCc`4LUm=0hQ_G0A^G504OfMK17QWD`AD<RH4;1dG128K
5@<L614491lJ140b;0@S9bDSWjfY5Oooo`005?oooanO[JT4PUi8140^8@@o;2@3:QhG12dG40@a81T4
=RTN13Hc;0A>CT@4PG=T0iZBOPBOUH44WiF719nOU0BOVhd4Wif@1inQV0BOXYL4Wi^=19nHQ@BOV8T4
Wi:10j6=N0BJQW<4VXii19Z4L@BJQVl4Vh1]19UlJ0>HOVT4UWYT19UoJPBNQ6d4UGaW18A^F`>=JU/4
RG=L18aVE@AaCCP4BbdR12`M5`@c8A/39ahG12<K5@@`9A`48B4L1863PQnO[JTEoooo000Doooo7in]
Z@B2GTP4@2hQ13l/90<Z7QL4;AL@134P6@@f:Ah4=S</14i>A0B1Lf@3VY9n19nEP@BOUHL4WinD19nK
S@BOWI07Wj6H19nRU`BOVhd4WiR519nHR@BOTX43XHeh19Z6L`BJSWT4VXAa19Z6K`BKP6d4VGaX0iQn
J@BFNV@4VGmZ19j4K@BEO6L4Q6iK0heZF`B9Le`4S6IE175=>0A;;B84;1dG13<Q6`<W7QL48a/E130U
70@Q8A`4PH>27in]ZAGoool001CooolOWjfY189NB0A0;R44?b`T0bXN5`@]5a04<B0I13HY7P@f<b`4
CTi4185cI0>JTWh4WiF119nEQ`BOWi@4Wi^=19nMT0NOXIP4Wj:G19nKS@BOV8D4WiR919nBP@>QSGP4
VXIc19Z>N@BJQ744VXI_19^0K@BIO6P3V7iY19IjI0BIOfX4WXA]19ElI`B4KU/3SFYK18UcG0B<IUD4
LDdh14/]8P@/7AL4<b4K0bLN5`@S6aD4<2DL124Q70B1Ph8OWjfY5Oooo`005?oooanO[JT4LEI014@h
<@@j:b@3=R@M11lH4@PT6QD4<bTP13Xf:@AVFT/3Uhai19nEP@BOUHL4WiZ<19nVW`BOVhd;Wif@19nK
S@BOVh/4WiEm19bBOP>LT7X4VXAa19Z2K`BJQW84VXAa19^3K`BAOVT3TGUU19>0K0B9MV84SWEQ18ec
G`B3LUd3NfeH17]]F`AdHTh4BcT_12DJ4P@[8B047ALG0ahG40@B2`X491`H12`]9`AMEe<OWjfY5Ooo
o`005?oooanO[JT4LEI014@h<@@j:b@3=R@M11lH4@PT6QD4<bTP13Xf:@AVFT/3Uhai19nEP@BOUHL4
WiZ<19nVW`BOVhd;Wif@19nKS@BOVh/4WiEm19bBOP>LT7X4VXAa19Z2K`BJQW84VXAa19^3K`BAOVT3
TGUU19>0K0B9MV84SWEQ18ecG`B3LUd3NfeH17]]F`AdHTh4BcT_12DJ4P@[8B047ALG0ahG40@B2`X4
91`H12`]9`AMEe<OWjfY5Oooo`005?oooanO[JT4LEI014@h<@@j:b@3=R@M11lH4@PT6QD4<bTP13Xf
:@AVFT/3Uhai19nEP@BOUHL4WiZ<19nVW`BOVhd;Wif@19nKS@BOVh/4WiEm19bBOP>LT7X4VXAa19Z2
K`BJQW84VXAa19^3K`BAOVT3TGUU19>0K0B9MV84SWEQ18ecG`B3LUd3NfeH17]]F`AdHTh4BcT_12DJ
4P@[8B047ALG0ahG40@B2`X491`H12`]9`AMEe<OWjfY5Oooo`005?oooanO[JT4LEI014@h<@@j:b@3
=R@M11lH4@PT6QD4<bTP13Xf:@AVFT/3Uhai19nEP@BOUHL4WiZ<19nVW`BOVhd;Wif@19nKS@BOVh/4
WiEm19bBOP>LT7X4VXAa19Z2K`BJQW84VXAa19^3K`BAOVT3TGUU19>0K0B9MV84SWEQ18ecG`B3LUd3
NfeH17]]F`AdHTh4BcT_12DJ4P@[8B047ALG0ahG40@B2`X491`H12`]9`AMEe<OWjfY5Oooo`005?oo
oanO[JT4QV5;140a:@A3=c03=R/T13TU7P@Y7AH4<BHP13Db;P@n>c@4@dHm0hekJPBOTWh4Wi:419nC
PPBOWI04WjJO19nOU0>OXYL8Wi^=19nKT0BLTX44W99l1iZ6LPBJQ744UhAa19:0K0BGP6`4UWiY0hii
I@B>MV84TgiY18UfHPB;Lel4Rg9M0hE]FPB6JED4K4lo14LZ8@@j:R<46A4@11hG5P<C2`/47ALF120J
5@@]<Rl4B4I17in]ZAGoool001CooolOWjfY18IQB`A0<BT4@cL`0cH[90@i9Ah4:AdF134V80@e<Rh4
?S/d14=6?@>=NfX4Wi9n19nBQ0BOTh84Wif@19nVW`BOWi@3Wj:G29nKS@BOVi04W9:119bBO0NJQW84
VXAa19N4L@BBP6`4Uh1/19InJ@>>NFD4SWIR19=nJ@B9MV84Rg=O18]bG@>5KEX4QVUE16a??`A7:R44
>RXS11TA40@N5aH34`/;11dG5P@P6QD4;C8_14Q6@AnO[JTEoooo000Doooo7in]Z@B6HD/4@34Y14<g
<0<f:b@4>BDN12TM5P@a9R04=C8^13hk=0A3ASd3SG]Z19nBOPBOTX@4Wi>219nMT0BOYYl4WinD0inR
U`ROVhd4Wi^@19bBP@BLTW`7VXIb19Z4L@BGQ744TX1/19N0K0BFOVT3SWUU18ifHPBCOVT4RGIR18]c
G`B;LUd3QFeJ18IYE@A/Ccl4AbXQ13XZ8`@I4A047QLF0a<;2`@M5aH481XE12db;`A8AT4OWjfY5Ooo
o`005?oooanO[JT4QV5;140a:@A3=c03=R/T13TU7P@Y7AH4<BHP13Db;P@n>c@4@dHm0hekJPBOTWh4
Wi:419nCPPBOWI04WjJO19nOU0>OXYL8Wi^=19nKT0BLTX44W99l1iZ6LPBJQ744UhAa19:0K0BGP6`4
UWiY0hiiI@B>MV84TgiY18UfHPB;Lel4Rg9M0hE]FPB6JED4K4lo14LZ8@@j:R<46A4@11hG5P<C2`/4
7ALF120J5@@]<Rl4B4I17in]ZAGoool001CooolOWjfY17YYGPA6>S84A3Xc0d@h<0@f9Ah48APA12XO
6@@l;284DT4c14i6=`=lIeH4VXae19nEP`BOTX@4Wi>219nMT0BOXIP3WjJO19nPU0BOVhd4Wi^<1:BI
RPBNTgd3UhYe19:0K0BEOFd4Vge/19AlJ0BDMfP4UWYY0hiiI@B>MF44Rg9N18]eH@B6JUH4SFaI0gmT
D0A_E4D4FSd]140X7`@O5a0481PG11P@40<N5a4471HE12`P6`@kAdL4OXR47in]ZAGoool001CooolO
WjfY17YYGPA6>S84A3Xc0d@h<0@f9Ah48APA12XO6@@l;284DT4c14i6=`=lIeH4VXae19nEP`BOTX@4
Wi>219nMT0BOXIP3WjJO19nPU0BOVhd4Wi^<1:BIRPBNTgd3UhYe19:0K0BEOFd4Vge/19AlJ0BDMfP4
UWYY0hiiI@B>MF44Rg9N18]eH@B6JUH4SFaI0gmTD0A_E4D4FSd]140X7`@O5a0481PG11P@40<N5a44
71HE12`P6`@kAdL4OXR47in]ZAGoool001CooolOWjfY17YYGPA6>S84A3Xc0d@h<0@f9Ah48APA12XO
6@@l;284DT4c14i6=`=lIeH4VXae19nEP`BOTX@4Wi>219nMT0BOXIP3WjJO19nPU0BOVhd4Wi^<1:BI
RPBNTgd3UhYe19:0K0BEOFd4Vge/19AlJ0BDMfP4UWYY0hiiI@B>MF44Rg9N18]eH@B6JUH4SFaI0gmT
D0A_E4D4FSd]140X7`@O5a0481PG11P@40<N5a4471HE12`P6`@kAdL4OXR47in]ZAGoool001CooolO
WjfY17YYGPA6>S84A3Xc0d@h<0@f9Ah48APA12XO6@@l;284DT4c14i6=`=lIeH4VXae19nEP`BOTX@4
Wi>219nMT0BOXIP3WjJO19nPU0BOVhd4Wi^<1:BIRPBNTgd3UhYe19:0K0BEOFd4Vge/19AlJ0BDMfP4
UWYY0hiiI@B>MF44Rg9N18]eH@B6JUH4SFaI0gmTD0A_E4D4FSd]140X7`@O5a0481PG11P@40<N5a44
71HE12`P6`@kAdL4OXR47in]ZAGoool001CooolGWjfY19nYY@BLXYh4LE]@13dc;0A1=c43@CD^12hP
6@@f:284;bLQ130Z9@A1?344Fe940gEPD@BBQG@4WiF129nIR`BOVX`7Wj6H19nRU`BOVhd4W9R419Z>
O0BQSGP3WXIb19b7M0BDPVX4Ugi/19AnJ@BAOFH4TGaY0h]`H@B7LF44Rg=O18UcG`B=MF04PF]I0gaU
D0AjF444DSPW13XU7@@Y7QP48adF12@M5`<N5a048Q`E12XP6`@20P84Y;6]7in]ZAGoool001CooolG
WjfY19nYY@BLXYh4LE]@13dc;0A1=c43@CD^12hP6@@f:284;bLQ130Z9@A1?344Fe940gEPD@BBQG@4
WiF129nIR`BOVX`7Wj6H19nRU`BOVhd4W9R419Z>O0BQSGP3WXIb19b7M0BDPVX4Ugi/19AnJ@BAOFH4
TGaY0h]`H@B7LF44Rg=O18UcG`B=MF04PF]I0gaUD0AjF444DSPW13XU7@@Y7QP48adF12@M5`<N5a04
8Q`E12XP6`@20P84Y;6]7in]ZAGoool001CooolGWjfY19nYY@BLXYh4LE]@13dc;0A1=c43@CD^12hP
6@@f:284;bLQ130Z9@A1?344Fe940gEPD@BBQG@4WiF129nIR`BOVX`7Wj6H19nRU`BOVhd4W9R419Z>
O0BQSGP3WXIb19b7M0BDPVX4Ugi/19AnJ@BAOFH4TGaY0h]`H@B7LF44Rg=O18UcG`B=MF04PF]I0gaU
D0AjF444DSPW13XU7@@Y7QP48adF12@M5`<N5a048Q`E12XP6`@20P84Y;6]7in]ZAGoool001CooolG
WjfY19nYY@BLXYh4LE]@13dc;0A1=c43@CD^12hP6@@f:284;bLQ130Z9@A1?344Fe940gEPD@BBQG@4
WiF129nIR`BOVX`7Wj6H19nRU`BOVhd4W9R419Z>O0BQSGP3WXIb19b7M0BDPVX4Ugi/19AnJ@BAOFH4
TGaY0h]`H@B7LF44Rg=O18UcG`B=MF04PF]I0gaUD0AjF444DSPW13XU7@@Y7QP48adF12@M5`<N5a04
8Q`E12XP6`@20P84Y;6]7in]ZAGoool001CooolGWjfY19na[@BT/jl4JeE814<b9PA0<RX3@cTb14Pj
<P@d:B84=bdV13`]8@@l?cP4D4Ti0f=CA@B8MFD4VY9n19nBQ0BOUhT4WiN61inIR@BOVX`4W91m19b@
O0BES7P4W8mi0iN0J0BBOFH4Uh1X19AnJ0BDPVd4UWUU18ijIP>CNf<4SG5O18U_F`B9JeT4PfmK17aT
D0=`F4<4DSP`13lW7`@V7AL47aL@11dF5@@H41033@/;11D?3`@d;2P450d=1:6_ZanO[JTEoooo000D
oooo5in]Z@BO/Jd4Y;>_16]EB0A3<RH4@38Z0d<i<PA8>S84=2TR13L]9P@l;B44?3lh1519>@=SDdD4
R7EU19ZBOPBOTX@4WiN919nGQPNOVHT4WiZ<19b@O@BLT7`4UHah19b?N@>GP6P4TWeV19N0J0BDOVP4
U89]19IiI@B>NVH3Tg]S18eaG`B9Ke/4RF]I18=_F`AlI503L5Q3158h<0@o9al49QdG11lG40@M5QD4
610@0`d;2`@E3`l4=2`X11@=3@BQ[j/OWjfY5Oooo`005?oooaNO[JT4Wk6]1:Bc[`A[EDP4@c8V140b
:P=3>C84B3Xb13@Y8P@g;BH4?2dQ13`o>0A@BCT3He=518QeI@BJTWh4Wi:419nGR@BOUhH7WiV919nJ
S0BLT7d4W91l19F<N0BLSgT3Uh1X199mIPBGP6P4U7iX19B2K@BFNFD4SWYV0i=kH`B=LEl4RFmK18U[
F@B3Ke/4O6A@0g1H@`AB>304?bLO12HM5`@O5a047AHE11P@40<=2`/45@l?13@/:0@D3@d4XJn[7in]
ZAGoool001CooolOWjfY18U[GP@m;b<4A3L^0d8h<P@l<2T4=R@M13X[7`@m<b`4?CP_14Li;P=:@cT4
O6MJ19N@N0BOUGl4Wi:019nDP@NOU7h4WiR51:BIRPBNTgd4VX=_19N0JP>GNFP4U7MV19AkK@BDOVT4
U7IR19IgI0N>MF44T7=O18UbG@B6JED4Of9>171F@@=B>C04Ac8S12lO60@U7AH4:AdG11lG5P@I4A43
6Q4@12`P6PA7GUl4N7mk8in]ZAGoool001CooolOWjfY18U[GP@m;b<4A3L^0d8h<P@l<2T4=R@M13X[
7`@m<b`4?CP_14Li;P=:@cT4O6MJ19N@N0BOUGl4Wi:019nDP@NOU7h4WiR51:BIRPBNTgd4VX=_19N0
JP>GNFP4U7MV19AkK@BDOVT4U7IR19IgI0N>MF44T7=O18UbG@B6JED4Of9>171F@@=B>C04Ac8S12lO
60@U7AH4:AdG11lG5P@I4A436Q4@12`P6PA7GUl4N7mk8in]ZAGoool001CooolOWjfY18U[GP@m;b<4
A3L^0d8h<P@l<2T4=R@M13X[7`@m<b`4?CP_14Li;P=:@cT4O6MJ19N@N0BOUGl4Wi:019nDP@NOU7h4
WiR51:BIRPBNTgd4VX=_19N0JP>GNFP4U7MV19AkK@BDOVT4U7IR19IgI0N>MF44T7=O18UbG@B6JED4
Of9>171F@@=B>C04Ac8S12lO60@U7AH4:AdG11lG5P@I4A436Q4@12`P6PA7GUl4N7mk8in]ZAGoool0
01CooolOWjfY18U[GP@m;b<4A3L^0d8h<P@l<2T4=R@M13X[7`@m<b`4?CP_14Li;P=:@cT4O6MJ19N@
N0BOUGl4Wi:019nDP@NOU7h4WiR51:BIRPBNTgd4VX=_19N0JP>GNFP4U7MV19AkK@BDOVT4U7IR19Ig
I0N>MF44T7=O18UbG@B6JED4Of9>171F@@=B>C04Ac8S12lO60@U7AH4:AdG11lG5P@I4A436Q4@12`P
6PA7GUl4N7mk8in]ZAGoool001CooolOWjfY19Z=P@A:?3D4?34Z0dDg<@A5<B@4?30X134W8@@j<2T4
=2/U13Xh<@<m?C<4GT`n18IiI@BGSWX4VY9j19nEP`BOUH43W99m19N>M`BJTX04XI1k19MnJ@BGP6P3
TGQQ18afH0B<MV@4SgMT195iI0BAL5d4SW1Q0h]`G`B;Le/4QVeF18=YE@AmHDd4Gd8c0d/c8`@]7QL4
81PA11dF5@@U6aH481PF11@;2`<G41049QhI100000BQ[j/SWjfY5Oooo`005?oooanO[JT4VXf114Xl
=@@l<BX3ACLa14Da90@l<2P4<BLQ13X`:@@d:bD4>SPa0cdm<`ANC3h4QWUU19N>NPBJTWX4WiF319nE
P@>LTWd4Uhig19ZBP0BQT7/4UgiY19N0J0>AN644S7IP18afI0B?Mf@4TGUT195`G@B>L643Rg1O18]c
F`B6KEH4PfUE17eQC@AO@S<3Bc<S12dN5`@P61447AHE12DK5P@P61H450/;0aL@40@V7QT400001:6_
Zb>O[JTEoooo000Doooo7in]Z@BJSH44BS`e13`a:P=5=c44AC4T13``:0@a9b44>S0Y13@[9@@j>343
?Cdc15i<?PB6NFD4Uhij19ZBNPBOUH<4WiF10ibBO@BGSWL4VY:01:6@N`BGOVT4Uh1X0i5hH@B<MV04
S7IT18mgI0BANF@4TG1M18i`H@>;L5l4Rg=K18I]EPB3JED4OF5=15m2<`=;<b<4;AhG120H4@@M5QD4
9A/F120H5P@D2`/35a0@12HN6@@00004XJn[8in]ZAGoool001CooolOWjfY19Z=P@A:?3D4?34Z0dDg
<@A5<B@4?30X134W8@@j<2T4=2/U13Xh<@<m?C<4GT`n18IiI@BGSWX4VY9j19nEP`BOUH43W99m19N>
M`BJTX04XI1k19MnJ@BGP6P3TGQQ18afH0B<MV@4SgMT195iI0BAL5d4SW1Q0h]`G`B;Le/4QVeF18=Y
E@AmHDd4Gd8c0d/c8`@]7QL481PA11dF5@@U6aH481PF11@;2`<G41049QhI100000BQ[j/SWjfY5Ooo
o`005?oooanO[JT4THAa15=4>PA4>S<3?3<]140e<0@b9284<RLQ13<[90A2>384?BhQ0c@/8`A2?SH4
IUM818UcH@B@OF/4UhMc19N:M`>LTWd4VXah19F5LPBISGP4TgiX18a_GP>AMV44SVaI18i^G0B9LUh4
TGEQ18]_F`B7KeT3R6ID17mUE0AhIU04Je<o16U<>0A==bH3;QhG12HM5`@O6144614?11H@40@>2`X4
3@/;0bXO6P@f9A/43`P49in]ZAGoool001CooolOWjfY1964L@ACA3X4A3Xc0c`c;@A0=C04<R@R138W
8@@c:b@4@SPb13d^8@<d;2<4@Shf16IGB0B9Lf44T7e[19N7L`BGRWL3W99m19Z<N0BEQG84VHeh19=n
J0B<Keh3TGIQ18i/F@B>KU`4RG9N195eH@B;Ke/4QfmI0hQVE0AoIE@4N6I@16]C?`AYC3P4CCLV0bhN
5`@V7AL47aPA11PA3`@F41043P/:10d;2`<Z7aX4=RDK10l812NO[JTEoooo000Doooo7in]Z@BAQ744
Dd@j14@j<`<l<bd4@3D`138T8P@b9b44<b/T148h<P@m;R43=2`S148n=PAVEdP4RG=Q191mJ`BGQg<4
UhYg0ibBO@BJS7P4UHEb19V=N0BCOVP4S6mN0i5fH@B>K5T4SViL18UbGPBAMF44RfmK18M_F@>8IU@4
OfED17QVD0A[Dcl4JD`h14dg9P<^7QL49QdG11lH4@@H4@l45Q0@10h;2P@=2`/3:QlJ13HU6`@?20@W
WjfY5Oooo`005?oooanO[JT4THAa15=4>PA4>S<3?3<]140e<0@b9284<RLQ13<[90A2>384?BhQ0c@/
8`A2?SH4IUM818UcH@B@OF/4UhMc19N:M`>LTWd4VXah19F5LPBISGP4TgiX18a_GP>AMV44SVaI18i^
G0B9LUh4TGEQ18]_F`B7KeT3R6ID17mUE0AhIU04Je<o16U<>0A==bH3;QhG12HM5`@O6144614?11H@
40@>2`X43@/;0bXO6P@f9A/43`P49in]ZAGoool001CooolOWjfY1<G9d0AXD4P4ACTb0d4e;PA6?CH4
B3DU13DS70@m<bh4>2hW144i<`<c:B<4<C4[13dj<0A@ACP4LEe?18M`G@B6LF@3RWU^18YmK0B=Of`4
T7YU17aUD0A^EdD3N5]518=YE0B7JUP4Qf=?18MVE0B;Ke44QVUA0h=TD0AmG4T4Mea916=7>0A;;b84
?RDM0bhN5`@O5a046A4@11PA40@C2`/43P/;11L@40<N6A@4E6MY16U/J2NO[JTEoooo000Doooo7in]
Z@C5bM04J51814Di<P=1=Bh4ASdf14Pe9@@e8a`4?C<^13P^9`A1>C<3<bTS134a:`@m>S04D4Dh175M
C`B7L5d4QW5T0hYiKPB:OF`4SGm/191jI@AlIE04KUM50gQKA@B3JE@4QfYH18MSC`B7IU@4RfmA18IY
D@>3I504OEa917MLB@ASAcP4BblR13hU7@<^7QL47aL@11TA40@H4A044`/;10h;2`@G41037QTD15AW
J@AYK6PWWjfY5Oooo`005?oooanO[JT4aLW@16Q@B0A5>C83@CD^14Hm=PA8=BD4=B<L13dc;P@h;RL4
@CTc0c<Y8`@a<B/4?CX`1515>0AaGDl4Qg1M18IaI0>:NFh4RWe/18eoK0B@NVD4O6E@16iGA@=hFdD4
PfUD18MZF0B7Hdl4QfID18]_D@B6JE43PfA@17eLB@AgG4T4HdLh14/_8P@n9Ad3;QhG11lG40@I4A04
614@11<;2`@>2`/45a0@0ahI50ADIfT4JFaX9in]ZAGoool001CooolOWjfY1<G9d0AXD4P4ACTb0d4e
;PA6?CH4B3DU13DS70@m<bh4>2hW144i<`<c:B<4<C4[13dj<0A@ACP4LEe?18M`G@B6LF@3RWU^18Ym
K0B=Of`4T7YU17aUD0A^EdD3N5]518=YE0B7JUP4Qf=?18MVE0B;Ke44QVUA0h=TD0AmG4T4Mea916=7
>0A;;b84?RDM0bhN5`@O5a046A4@11PA40@C2`/43P/;11L@40<N6A@4E6MY16U/J2NO[JTEoooo000D
oooo7in]Z@BhcL84RgeY140c:P<m<b`4>S4Z13Ha:P@`9B<4=2LN144d;0A2>S@3C3lg13P_:PA0>SD4
@Cde14Tk;PAGBD04CDHl0eA8>0ATDd@4IeU716IDA@AVCS`4F4<a0eM8=0ATBCD4L5<n17URB0AkF4@4
KDm016e=>@=bDT44JE5315a0=0AA<b@4?R@M12hM5`<O5a046A4@11<;2`@=2`X43@/;10d;2P@M6QD3
;20K10@;2PBLZ:@WWjfY5Oooo`005?oooanO[JT4^<g218]mJ@A0<bX3?C</13Xa:P@f<BX4<2DS13@W
7PA1=2`4@SXd0d`o=`@h;bX4@3Xe144m=@A9>bh4EdU014e6?0=DB3P4I5=416MIA`AVE4D4IThl15Q3
<@=GB3@4I4Te171C?PAiHTP4NeQ416e?@0A]CCT3LU9116UA@`AL@3@4DC<T13hT7@@^7AL37aL@11TA
40@C2`/43@/:10d;2`@=2`X47AXE0b`P6`@42`X4W:RT9in]ZAGoool001CooolOWjfY1;S=`PB;OFT4
@3<Z0cdc;0@j<BX4=S4Z130U8`@d9ah4@C@/148j=0=<?cL4>2lZ140j=@A1?CD4BC/^15M9@0A=AS`3
E4Ph16ACA0AWFDL4IUA516I>?0AH@c43EdPd16A9=@A`Dch4NF9817]HA0A]Cd04KDdi0g9B@@AYDD<4
G40d154c90@n91d4;QdG0alG40@I4A044`/;10d;2P@=2`/43@/:11dJ5@</81/410/:19bXY2NO[JTE
oooo000Doooo7in]Z@BhcL84RgeY140c:P<m<b`4>S4Z13Ha:P@`9B<4=2LN144d;0A2>S@3C3lg13P_
:PA0>SD4@Cde14Tk;PAGBD04CDHl0eA8>0ATDd@4IeU716IDA@AVCS`4F4<a0eM8=0ATBCD4L5<n17UR
B0AkF4@4KDm016e=>@=bDT44JE5315a0=0AA<b@4?R@M12hM5`<O5a046A4@11<;2`@=2`X43@/;10d;
2P@M6QD3;20K10@;2PBLZ:@WWjfY5Oooo`005?ooob>O[JT4/:ng15I5?P=1=c44@3Xc148f;`@X81P4
;BTT14<j<`A6?CH3CdHn1599@0A@BC`4CTXn14U5>@A8>2l4AS4W0ch`:PA4<2P4D3db14hl<`A3>3<4
CCP^0d`d9PA9=RT4Dclc15M6=@AMA344H4Xg15I0;@=B?c<4EcX]14`f:0@i9Ah4=BPQ128H4@<N5a04
6A4@11@;2`@>2`X43@/:12DK5@@M5QD3ATa913`g=2^O[JTEoooo000Doooo8in]Z@B`[kL4ETDn0d4g
<@A0>S<4@SH_12PP60@]:B@4@cXc14Hm=P=?ASh4DTU01519?0A>BSh4BDDi14Ph;`A6<BL3?S0Z14@`
:0A@?C84CS`c14<h<`A=>2h3C3@V14Tf:@AC?c<4EdHe15e4<@APBSL4ET0]0e8o<`AG>Rd4C3HX13TU
7P@e:2448QPA0ahG40@I4A0450/;10h;2P@=2`X49A/E11dF5@=6C4T4?3Ld:in]ZAGoool001CooolS
WjfY1;2_]`AFACh3@CLa140j<`A2=Rl4:20H12dY90A3>S<4ASdf0dm6?PABBD04D4Tl14i:?PA9ACT4
B3P_14Ha9`<n<2X4A30X150m<PA>?3<4@cPc14dh;P=<=2H4BCHY15<o<`AGASD4GD@a161:=`AF@2d3
DSlc15Lj;@A<=RP4>BDN13DX8@@R61437QL@11TA40@D2`/43P/:10d;2P@U6aD47AHE0dI<B@@l=c@[
WjfY5Oooo`005?ooob>O[JT4`lo:17ILE0=0<bd4?c</13hd;@A8>C44?SH`148j=0A<A3`3A3Xc144g
<@A2<B`4CSD[14dc9`A1=2/4<bTS0cPa:P@`8Qd4=2`W13ld;@@g;RL4;R8L0bhU80@^8A/4;AdI13DX
7`@i;204=RXO13LS70<c7aT4<B4K138Q6`@W7QL471H@11XA4@<G4104614@10h;2`@=2`X49A/O12DK
5`@n<RX3<DU;18J=RB^O[JTEoooo000Doooo8in]Z@C3clX4MUaD0d0c;@@o<b`4?S@]14Pi<@@n=S04
@SXd14a4?0=4>S<4@CLa148a;0A>=B/4CC<W144d:`@c:B<3>34Z130R7@@d;2L4?c@]13L^9`@^8Q`3
;RDP12hQ6`@]7AT4=BPO13T/80@f:Ql4=b<L0c<O6@@a8A/4<R4K12LN5`@L5Q046Q4A0aL@40@H4A04
3P/;10d;2P@U6al49A/G13hb:P<aBD/4QXf9:in]ZAGoool001CooolSWjfY1<??bPAfG5@3@3<]13lc
;0@n=2d4B3Ta13hf<0A2>S@4C4@l0d@j<`A1=c44@S4/14he:`A=<bL4@C@[13<Y8`<h<BX4<28M13@/
9`@o=2d4=bhW12hR70<^9B04;R4K12dM6@@e:1l4>B`P13HZ7`@g8a`3<alI134Q6`@b8A/49ahG11`F
40@J4A435a0@11PA40@>2`/43@/:12DK7`@U6aL4?S8Z0c59B`B6SHT[WjfY5Oooo`005?ooob>O[JT4
`lo:17ILE0=0<bd4?c</13hd;@A8>C44?SH`148j=0A<A3`3A3Xc144g<@A2<B`4CSD[14dc9`A1=2/4
<bTS0cPa:P@`8Qd4=2`W13ld;@@g;RL4;R8L0bhU80@^8A/4;AdI13DX7`@i;204=RXO13LS70<c7aT4
<B4K138Q6`@W7QL471H@11XA4@<G4104614@10h;2`@=2`X49A/O12DK5`@n<RX3<DU;18J=RB^O[JTE
oooo000Doooo8in]Z@BX^k44^[bi0eA3>`@n<bd4@SPb140e;PA7@3T4?30Y13lh<P<n<RX4?cH`14a5
>0A4>c@4@3D_140c;0@m<BT3@CD_13HW9@@^:B<4<B8L13<Q6`@Z7AL38Q/E12HL5P@^8A/4<20K12PL
5P@V6aH49adF0blQ6`@Z7AH49a`F120G40@N5a046A4@0aP@40P=2`/45a0@12LR7@@d8ad4FF=Q0fij
MbnO[JTEoooo000Doooo8in]Z@BX^k44^[bi0eA3>`@n<bd4@SPb140e;PA7@3T4?30Y13lh<P<n<RX4
?cH`14a5>0A4>c@4@3D_140c;0@m<BT3@CD_13HW9@@^:B<4<B8L13<Q6`@Z7AL38Q/E12HL5P@^8A/4
<20K12PL5P@V6aH49adF0blQ6`@Z7AH49a`F120G40@N5a046A4@0aP@40P=2`/45a0@12LR7@@d8ad4
FF=Q0fijMbnO[JTEoooo000Doooo8in]Z@BX^k44^[bi0eA3>`@n<bd4@SPb140e;PA7@3T4?30Y13lh
<P<n<RX4?cH`14a5>0A4>c@4@3D_140c;0@m<BT3@CD_13HW9@@^:B<4<B8L13<Q6`@Z7AL38Q/E12HL
5P@^8A/4<20K12PL5P@V6aH49adF0blQ6`@Z7AH49a`F120G40@N5a046A4@0aP@40P=2`/45a0@12LR
7@@d8ad4FF=Q0fijMbnO[JTEoooo000Doooo8in]Z@BX^k44^[bi0eA3>`@n<bd4@SPb140e;PA7@3T4
?30Y13lh<P<n<RX4?cH`14a5>0A4>c@4@3D_140c;0@m<BT3@CD_13HW9@@^:B<4<B8L13<Q6`@Z7AL3
8Q/E12HL5P@^8A/4<20K12PL5P@V6aH49adF0blQ6`@Z7AH49a`F120G40@N5a046A4@0aP@40P=2`/4
5a0@12LR7@@d8ad4FF=Q0fijMbnO[JTEoooo000Doooo9in]Z@Bj`;l3ME5914Hh<PA2>384@CD^130[
90A7@3P4B44j0dQ0>0@f;RL4>blU13XY8@@f;2H4=bdV12/S9`<Z:B@4<bHS130P6`@Z7B448Q`G12<M
5P<N5a0481/E120K5P@Q71H47QL@11P@40@K5Q038a/E11lG40@H41047AH@11dG5P@I4A033@/;11P@
40@R71H4<2LP12hP6`AXMG84J7=`<Yn]ZAGoool001CooolWWjfY1;[0_`=eDDT4ASPb148h<PA1=Bh4
<2/T14M0>0A8@CX3B40h13H^9`@k;bD4>RTQ13H/9P@g;BH4:b<W0bXY90@c9R<4<20K12XM8@@R71L4
8adF0ahG40@P6aD481/F124L5P@N5a04610@11/F40<S6aD47aL@11P@40@M5Q047ALF11TA40<=2`/4
610@128L5P@`9b04;R0K16QeLPAXLg0bWjfY5Oooo`005?ooobNO[JT4^/2o0gEAB@A6>384@SPb144e
;P@`:b@4Ad0h14Q1>P=8@3P4=RhW13/_9@@j:B44=R`V13L]9P@[8bL3:RTT13<V8`@`81/4:QdQ128L
5`@S7AH37QL@120K5@@P6aH48A`F11hG40@H41046aH@0b<K5@@O5a04610@11dF40@M5aH46A4@0`d;
2`@H41048Q`F130W80@^81/4J7Eb16QcL3:O[JTEoooo000Doooo9in]Z@Bj`;l3ME5914Hh<PA2>384
@CD^130[90A7@3P4B44j0dQ0>0@f;RL4>blU13XY8@@f;2H4=bdV12/S9`<Z:B@4<bHS130P6`@Z7B44
8Q`G12<M5P<N5a0481/E120K5P@Q71H47QL@11P@40@K5Q038a/E11lG40@H41047AH@11dG5P@I4A03
3@/;11P@40@R71H4<2LP12hP6`AXMG84J7=`<Yn]ZAGoool001CooolWWjfY1:k4^P>MTXL4BSXb144g
<@A1=Bh4ASXc13Xf<0@n=c03?S0Y13DY8P@]9R44;AhG138Y8`@_8b44<B<Q0bLK5P@X7B047ALG11PA
40@L5QH47AHF0aTA4@@K5AD4610@11`F5@@I4A447ALF124K5P<L5aH46A4A10h;2`P<2PX43@/:0adF
5P@L5a045a0?124D3`ANJVL4I6YX=Yn]ZAGoool001CooolWWjfY1:k4^P>MTXL4BSXb144g<@A1=Bh4
ASXc13Xf<0@n=c03?S0Y13DY8P@]9R44;AhG138Y8`@_8b44<B<Q0bLK5P@X7B047ALG11PA40@L5QH4
7AHF0aTA4@@K5AD4610@11`F5@@I4A447ALF124K5P<L5aH46A4A10h;2`P<2PX43@/:0adF5P@L5a04
5a0?124D3`ANJVL4I6YX=Yn]ZAGoool001CooolWWjfY1:k4^P>MTXL4BSXb144g<@A1=Bh4ASXc13Xf
<0@n=c03?S0Y13DY8P@]9R44;AhG138Y8`@_8b44<B<Q0bLK5P@X7B047ALG11PA40@L5QH47AHF0aTA
4@@K5AD4610@11`F5@@I4A447ALF124K5P<L5aH46A4A10h;2`P<2PX43@/:0adF5P@L5a045a0?124D
3`ANJVL4I6YX=Yn]ZAGoool001CooolWWjfY1:k4^P>MTXL4BSXb144g<@A1=Bh4ASXc13Xf<0@n=c03
?S0Y13DY8P@]9R44;AhG138Y8`@_8b44<B<Q0bLK5P@X7B047ALG11PA40@L5QH47AHF0aTA4@@K5AD4
610@11`F5@@I4A447ALF124K5P<L5aH46A4A10h;2`P<2PX43@/:0adF5P@L5a045a0?124D3`ANJVL4
I6YX=Yn]ZAGoool001Coool[WjfY0m_bkPBDQW/4@SD/13dc;0@l=c04?cTb14@n=`=5>3H4=bDN13<V
80@V7QP48aXD12@M5P@V71H36Q4A11L@3`@M5QH47QLG11P@40@L5QD36A4A11`F5@@I4A44;AlJ110<
2`@J5AD48A/F0alH5P@>2`/43@/;118;2P@M5QD47QLG0a/F5@@_8A`4@BlQ15]<>`@f;B44W:RT=Yn]
ZAGoool001Coool[WjfY0m_bkPBDQW/4@SD/13dc;0@l=c04?cTb14@n=`=5>3H4=bDN13<V80@V7QP4
8aXD12@M5P@V71H36Q4A11L@3`@M5QH47QLG11P@40@L5QD36A4A11`F5@@I4A44;AlJ110<2`@J5AD4
8A/F0alH5P@>2`/43@/;118;2P@M5QD47QLG0a/F5@@_8A`4@BlQ15]<>`@f;B44W:RT=Yn]ZAGoool0
01Coool[WjfY0m_bkPBDQW/4@SD/13dc;0@l=c04?cTb14@n=`=5>3H4=bDN13<V80@V7QP48aXD12@M
5P@V71H36Q4A11L@3`@M5QH47QLG11P@40@L5QD36A4A11`F5@@I4A44;AlJ110<2`@J5AD48A/F0alH
5P@>2`/43@/;118;2P@M5QD47QLG0a/F5@@_8A`4@BlQ15]<>`@f;B44W:RT=Yn]ZAGoool001Coool^
WjfY1=_bkPBGP7D4BClg13T^9`A3>S@4AShg0de2>@@k=Bd4=bhV12lO90@N5aL49a/F11hG5P<T7AL4
8adF11hG5PPH4A045a0?0aPA40@G40l48Q`F11XF5@@m>D44>C`m12`P9@<J4A447aLG22<M5`@M5aD4
<b/U0cLZ8`@_8Q`4B3L^15mZJPB4QWhjWjfY5Oooo`005?ooobjO[JT4fo;^19N0M@A9?cL4>BhW14<j
=0A6?SL3CD8i13/e;@@g;RH4;alT11hG5`@W6aH47QLF0b@M5`@S7AH47QLF21PA40@G40l3614@11L@
3`@R71H46QHE13di@@@i?3d4;20U0aXA4@@O5aL88adG11dG5@@c:bD3=bXS12lR70A8=bh4GfYZ18B6
OSZO[JTEoooo000Doooo;Yn]Z@CKl^h4Uh1e14To=`@i;RL4@cXd14Hn=`==@ST4>cD]13L^9P@_7b@4
7QLG12LK5P@N5aH391dG12<M5P@N5aH8614@11L@3`<H4A045a0?128L5P@J5QD4?CU113Tl?@@/82D3
6Q4A11lG5`PS7AL47ALE13<[9@<g:R<4;b8L14Pg;PAOJVX4Q8In>Yn]ZAGoool001Coool^WjfY1=_b
kPBGP7D4BClg13T^9`A3>S@4AShg0de2>@@k=Bd4=bhV12lO90@N5aL49a/F11hG5P<T7AL48adF11hG
5PPH4A045a0?0aPA40@G40l48Q`F11XF5@@m>D44>C`m12`P9@<J4A447aLG22<M5`@M5aD4<b/U0cLZ
8`@_8Q`4B3L^15mZJPB4QWhjWjfY5Oooo`005?oooc:O[JT4goch19MmLPAFB404>2hW13Xe;`=7@S/4
E4Dm148a90@j:b44:1hH11`G5P@I4A036aD@11dF5@@I4A04614@11dF5P@I4A037AHF11TA40@F3`l4
<S<b12lV;0A6?Cd4FE140ddm>`A;@3X4@3<[12LO60@b9b04;BDO0d4g<@AC?C04I6e[17ajMCjO[JTE
oooo000Doooo<Yn]Z@COo?P4Ugeb15I8@0@h;RL4>SD_0dM2>`ADACd4@S4T13X[8@@X7QP471LF11TA
40<K5A047AHE11TA40@H4A047AHF11TA40<M5QH46A4@11H?3`@b<c84;bH/14Hm?@AID4@3CCdk14]0
>PA0<b/49alH138W80@]9Al3@CLa15<m<0ATKF/4O7Ye?Yn]ZAGoool001CooolbWjfY1=oln0BGOG84
ETQ013P^9`@j=Bl3Ad8k15A5?@A2<B@4>R/Q12PN60@L5aH46A4@0a/E40@M5QD46A4@11PA40@M5QH4
6A4@0adF5P@I4A045Pl?138c<P@_9R`4ASdm15U@A0==?C/4Bd0j140c:`@W7aP4<RLP12dU7`=1=c44
Dcd`16A]J`AlNWDnWjfY5Oooo`005?oooc:O[JT4goch19MmLPAFB404>2hW13Xe;`=7@S/4E4Dm148a
90@j:b44:1hH11`G5P@I4A036aD@11dF5@@I4A04614@11dF5P@I4A037AHF11TA40@F3`l4<S<b12lV
;0A6?Cd4FE140ddm>`A;@3X4@3<[12LO60@b9b04;BDO0d4g<@AC?C04I6e[17ajMCjO[JTEoooo000D
oooo<Yn]Z@BJZ:@4gOWe18QZE`AKBd44Ac/c0dDo>0A@Acl4E4]413d]9@@h:R<4@3D]13/c:P<[7QP4
91dF11lH5`@N5aH4610@11PA40<P6al47aPH128L5P@I4a84;B/S138/:@@O5aL381/E11dI50@M5aH4
:AdG12dT7`@l;B43DD0`17UmN0AZJVX4WjZV?Yn]ZAGoool001CooolbWjfY19ZXY0CMnOD4R6YG15];
@@A7>c<3AClh1517?`ADBd@4?BdU13PZ8`A0=Bd4>c<Z0b/N60@T7AH47aPG11hG5P@H4104614@0b0K
7`@O61P48Q`F11TC4P@]:b<4<R`Y11lG5`<P6aD47ATD11dG5P@Y7AL4;B@O13`]8@=A@304NGeh16YZ
JPBOZZHnWjfY5Oooo`005?oooc:O[JT4VZRT1=gim@B8JUL4Fd]114Lk<`=5?cP4D4Lo15A;A0@m;BD4
>2XS140e;@@k<bX3:ahH12@M5P@O61L47QLF11P@40@H4A0381/O11lH60@R71H46A<B12d[8`@b;2T4
7aLG0b0K5@@M6A@47ALF12TM5`@]91l4?2dQ0e50<0AiOGP4JVYZ19nZYSjO[JTEoooo000Doooo<Yn]
Z@BJZ:@4gOWe18QZE`AKBd44Ac/c0dDo>0A@Acl4E4]413d]9@@h:R<4@3D]13/c:P<[7QP491dF11lH
5`@N5aH4610@11PA40<P6al47aPH128L5P@I4a84;B/S138/:@@O5aL381/E11dI50@M5aH4:AdG12dT
7`@l;B43DD0`17UmN0AZJVX4WjZV?Yn]ZAGoool001CoooljWjfY1>3oo`B3MF<4@cD/0cXc;@A@BD<4
FeM?15mDBP@k;BD4:b0O13<Q70<o=2d4>C4Y128I60@H4A049b4U12XS:0<`;2D4;BDY13df<`@Z8B@4
>SPf144g=@A:>S83@CD_13da:@A2=Rh4BdDi14<h;`AGBS`3M7]e192FR@BGXJ12WjfY5Oooo`005?oo
ocZO[JT4h?oo18=eH`A3=B`3>S<]1519@`AKEdl4GeA:13/]9@@[81l4<b4L0cld;@@i<BT48QTH11PA
40@W8BD4:R<X0c0/9@@]9BT4?CHc12XQ90@j>3H4@CLe14Xj<P=1=Bl4?C4Y148f;PA;ACT4@cP_15M:
?0=dNgD4T9J919NQX4:O[JTEoooo000Doooo>Yn]Z@CPool4PgES14<e;0<j<bd4D4U315]GC`AOE4X4
>bdU12/P7`@c8A`3?c@]13Ta:@@R6AP4614@12LQ9@@Z8bP3<2`U12dU:@@m=S<4:R4T13Xh=PA1=cD4
BSXb0d4e;`@m<BT4@SH^14]5>@A3>2l4EdXl0gAkM@B@UXT4Uj6P@Yn]ZAGoool001CoooljWjfY1>3o
o`B3MF<4@cD/0cXc;@A@BD<4FeM?15mDBP@k;BD4:b0O13<Q70<o=2d4>C4Y128I60@H4A049b4U12XS
:0<`;2D4;BDY13df<`@Z8B@4>SPf144g=@A:>S83@CD_13da:@A2=Rh4BdDi14<h;`AGBS`3M7]e192F
R@BGXJ12WjfY5Oooo`005?ooocjO[JT4h?Og1<O8a`=XFe<4?cH`14<i<`A>Ce44I5eH16EIC`APGEH3
ASTg13dj>@ACDEP4I61L14Pk=`@l=Cd3>c<f155;C`A1>ST4Bc/a13Td<0A>?SD4BSD^0dXc9`A9>S84
Cd<g15i;>`AL?2/4D6=V0hB;PPBOZZI6WjfY5Oooo`005?ooocjO[JT4h?Og1<O8a`=XFe<4?cH`14<i
<`A>Ce44I5eH16EIC`APGEH3ASTg13dj>@ACDEP4I61L14Pk=`@l=Cd3>c<f155;C`A1>ST4Bc/a13Td
<0A>?SD4BSD^0dXc9`A9>S84Cd<g15i;>`AL?2/4D6=V0hB;PPBOZZI6WjfY5Oooo`005?ooocjO[JT4
h?Og1<O8a`=XFe<4?cH`14<i<`A>Ce44I5eH16EIC`APGEH3ASTg13dj>@ACDEP4I61L14Pk=`@l=Cd3
>c<f155;C`A1>ST4Bc/a13Td<0A>?SD4BSD^0dXc9`A9>S84Cd<g15i;>`AL?2/4D6=V0hB;PPBOZZI6
WjfY5Oooo`005?ooocjO[JT4h?Og1<O8a`=XFe<4?cH`14<i<`A>Ce44I5eH16EIC`APGEH3ASTg13dj
>@ACDEP4I61L14Pk=`@l=Cd3>c<f155;C`A1>ST4Bc/a13Td<0A>?SD4BSD^0dXc9`A9>S84Cd<g15i;
>`AL?2/4D6=V0hB;PPBOZZI6WjfY5Oooo`005?oood:O[JT4/lRn0moal0B6NGd4DTU314A0?PA@F5d4
HV5P15]GD@=WHeP4IUmK15aGC0AHCd/4F4Y01556>P=2>3H4=2TR13dd;PA7?SL4@SPb14hj;PAJ?c83
GDHi16M?@0AG?304E4e<1::WY@AcNWE=WjfY5Oooo`005?oood:O[JT4/lRn0moal0B6NGd4DTU314A0
?PA@F5d4HV5P15]GD@=WHeP4IUmK15aGC0AHCd/4F4Y01556>P=2>3H4=2TR13dd;PA7?SL4@SPb14hj
;PAJ?c83GDHi16M?@0AG?304E4e<1::WY@AcNWE=WjfY5Oooo`005?oood:O[JT4/lRn0moal0B6NGd4
DTU314A0?PA@F5d4HV5P15]GD@=WHeP4IUmK15aGC0AHCd/4F4Y01556>P=2>3H4=2TR13dd;PA7?SL4
@SPb14hj;PAJ?c83GDHi16M?@0AG?304E4e<1::WY@AcNWE=WjfY5Oooo`005?ooo`BOYJ44WjRT@In]
Z@CPmnX4amWI1<;5_PA/JGD4If=V189nQ`>3Ngl4LF9I16AJDPAQF504LF=P16mOF@=aHUL4LVAL16II
B`AMET`4Kf9I15iIC@AGDTD3C3de15eOH0B^_/44Zkfd18B;RE6O[JTEoooo000Doooo19nUX@BOZ:A1
WjfY1>3gjPC7fMT4`/Fn16aYM@AWHfH4PWj70h=kO`AaHUT4I5YB165HD0AaHf04KemI0g5RE`AbI5`4
IUU;15eFC0A_HUT4GUU=15MBA@=<?CD4GEmP1:jn`@B[_K@4Q8^9DIn]ZAGoool001Coool4WjFQ19nX
Y46O[JT4h?OZ1<OIf@C2aKh4K6Ue16MSIPB2OXL3Pg]o175RF@ATFU84HEQ@175SH0A_GeT3LF9G179T
G0AVFD/4GEI<16mRF@ANFDd4Ee950d`m=@AMGf04[[k11:^m]0B4RhUAWjfY5Oooo`005?ooo`BOYJ44
WjRT@In]Z@CPmnX4amWI1<;5_PA/JGD4If=V189nQ`>3Ngl4LF9I16AJDPAQF504LF=P16mOF@=aHUL4
LVAL16IIB`AMET`4Kf9I15iIC@AGDTD3C3de15eOH0B^_/44Zkfd18B;RE6O[JTEoooo000Doooo19n_
Z`BOZZI9WjfY1:Rk/@CJjmd4Z<2o1:BeY`>`_/L4/L381:n_]@AkMh@4GV5[15iIF@=QEdl4F5=<16AI
D`AID4P4CT@h15M:?@AgP7T3c=kG18bQV0BAVIUIWjfY5Oooo`005?ooo`BO[j/4WjZVBIn]Z@BX^k44
f^_M1:S0_`BT]JL3/;k71;70b0B_[kD4NgN415iQJ`ANFET3HEM?15QCC0ATFE<4FE1814i4>0AGBSd4
Mh1i0lcNe`B<XIP4TIVIFIn]ZAGoool001Coool4Wjn[19nZYTVO[JT4Z;^a1=[[g@BX`;l4Y;FW0k2n
a`Ba`<P4[jne17]gQ0ANHF/4GUUI0f5GC`AHDd`4I5UC15U@B0A>A3P4EdXm17N0N@?<g]L4S:6H196I
VEVO[JTEoooo000Doooo19n_Z`BOZZI9WjfY1:Rk/@CJjmd4Z<2o1:BeY`>`_/L4/L381:n_]@AkMh@4
GV5[15iIF@=QEdl4F5=<16AID`AID4P4CT@h15M:?@AgP7T3c=kG18bQV0BAVIUIWjfY5Oooo`005?oo
of6O[JT3Z;^]19ZZZ`Bca[P4bm[?1;S9`0BmdmD3^/W51;[9aPBjc/X4_m;>1<7If@Bod<h4NHR20inZ
YV6O[JTEoooo000DooooHIn]Z@>X^jd4VZZ[1;?6^0C;f/l4^<W01;gCe@>jbLD4^/W61;[>bPBod/h4
`MWI1;o@cPAiR883WjZVHIn]ZAGoool001CooomQWjfY0jRk[@BJZZ/4/lJh1<_Jc`BhbL04_M?E0k[9
a@BjbLH4^/k:1;oBcPC1fMT4_m3>17V8PP>OZZIQWjfY5Oooo`005?ooof6O[JT3Z;^]19ZZZ`Bca[P4
bm[?1;S9`0BmdmD3^/W51;[9aPBjc/X4_m;>1<7If@Bod<h4NHR20inZYV6O[JTEoooo003ooooo8Ooo
o`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Ooo
o`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo002Ioooo0`00
08Coool009coool00`000?ooooooo`21oooo001koooo100000;oool400000oooo`800004oooo1000
00;oool300000oooo`<00003oooo0P0007koool007_oool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`040000oooooooo00000_ooo`040000oooooooo00000_ooo`030000oooooooo00?oool0
10000?ooooooo`0008?oool007coool00`000?ooooooo`03oooo00<0003oooooool01Oooo`040000
oooooooo00000_ooo`030000oooooooo00@00002oooo00@0003oooooool00023oooo001moooo00<0
003oooooool00oooo`030000oooooooo00;oool200001?ooo`<00003oooo0P0000Coool40000P_oo
o`00Noooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo00Goool0
0`000?ooooooo`2=oooo001loooo0P0000Coool200001?ooo`<00004oooo0P0008ooool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(248) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1C1C5BA
B6A48FBFAA95BFAA9BBFB1A1BFAA9BBFB1A1BFB1A1BFB1A1BFB1A1BFAA9AC1AB93B9A48D
BB9C84B3907AB58F79AC8A74AC8A74AC8A74AC8A74AC8972AE846CA6846AA6846CA6846A
9A755FBFC5C1BFC5C1BFC5C1BFC5C1BFC6C2BFBDBABFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC3BFBFC1BEBFC5C1BFC3BFBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC3BFBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1C3C9BF
BAA694BFAA94BFAA98BFB1A1BFAA9BBFB1A1BFAE9BBEA993BAA993BAA38FBC9F88B29881
B2947CAD8B75AF8A73A98872AC8A74AC8A74AC8770AC8770AE8470A6846BA6846CA68F7A
9A8271BFC5C1BFC5C1BFC5C1BFC5C1BFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC8C4BFBEBBBFC1BEBFC8C4BFC0BDBFC5C1BFC3BFBFC1BEBFC3BFBFC1BEBFC5C1
BFC5C1BFC5C1BFC5C1BFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BEC3B8
BBA88FBFAA9BBFA895BFB1A1BFAA9BBFAC9CBEAC9AB8A591AD9C87B49581B6907AB1917C
AC937CAC8F7AAF8E78A6846EA7856FA7856FA78770A7846AAA846CA6846EA68470A98870
A9A8A2BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC3BFBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC6C2BFBDBABFC5C1BFC5C1BFC5C1BFC8C4BFC0BDBFC8C4BFC0BDBFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1C3C5BA
BAA491BFAA97BFAA9BBFA899BFAE9FBFAA98C3AD9EC9AC99B0A997B8A18EBE9282B18A74
B18B79B18B7AB08675AE8470A6846EA6846EA6846EA68470A7876FA98670A6846E9A755F
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC9BF
BFA68EBFAA95BFAA98BFAA9BBFAA9BBFAA9EBFAD9ABFB0A0C3B0A3B9AC93C19E91B79884
B7947EB68E7DB89582B68373AB7E6EAB8778A98873A7846EA7826CAE8770A78A759E7B65
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC6BD
BFAA94BFAA97BFAA94BFAA98BFAA9BBFAD9EBFAA9BBFAC9CBFB1A1C3B0A3BDAF98BCA28E
B99987BC9C86B38D7ABC9781B08875AC7E6AAF9081A68873A7846EAA846EA58D7EAB9280
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC3BFBFC1BEBFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BBAC9FB3AFA5
BFAA97BFAA94BFAA98BFAA95BFAD9EBFAA9BBFB1A1BFB0A0BFAD9EBFB1A1BFAA9EC3AD98
BDA38ABC9986BC9984B6927DB78A79B08972AA7F69AA8A76A7846EA9846E9E826FB6ABA5
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC8C4BFC0BDBFC5C1BFC5C1BFC3BF
BFC0BCBFC1BEBFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1957F6E99A296AB9788
BFAA95BFAA9EBFAA9ABFAA97BFAA9BBFB1A1BFA896BFAE9CBFAE9FBFAE9FBFAA98BFAD9A
BEA38FBE9B86B99481BB967CB18973B18A74AF8670A9846EA48A75AF8B75A17E68BABBB9
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC8C4
BFC3C0BFC0BDBFC5C1BFC5C1
BFC5C1BFC5C1BFC3BFBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1B8B4B47A453A334346BAA693
BFAD97BFAD9EBFAD9EBFAD9EBFA899BFB1A1BFB0A3BFAA97BFAE9BBFA292BE9A8BB99780
BA9F86B99784B89981B68F7EB38F76B08772AA896EAA846CA37F6BA788719F7963BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC8C4BFBEBBBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC6C37D5740ADA69A555652BFAA9B
BFA895BFAE9FBFA899BFAE9FBFAA9BBFA899BFAE9FBFB1A1BEA897BAA78EBE9789BB9680
AF8E78B4917BB89178B5937AA88770B1856FAF8772AB846BA9846EA787729E7964BBB7B2
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC3BFBFC5C1BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C174503CC4C2B8626662BAA693BFAA95
BFAA9BBFAA9BBFAA98BFAA98BFAA9BBFAD9EBFAA9BBFAE9FC18F83B98074B8726AB87166
B36E63B3806FB18873B1886FAC836CAA8168A9846CAC846EAE846AA47E67A37761AA9183
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC3BF
BFC1BEBFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1B8B4B0F2E8E35B5E5ABFAE9FBFAA9ABFAA95
BFAA9BBFA895BFA592BFA58CBFA896BFA899BFA598BF9A90C19789B86E61B66050AF645B
B16558AF5F59B37364A77967A7846AAA7D68A4816AAC846EAF8470A78269AF816D9D725B
B3A79CBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC8C4
BFC0BDBFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1735649666F6CB6A896BFAA95BFAA98BFAA95
BFAA98BEA893BA9C85BBA18CBFA691BFA591BE8F7EB97264B78475AC644EA77C6AA97D6C
B35F4EA35040B15D51A9685CA67A6AA68260A37E63A9846CAC846EAC8670AC7E6AAC8872
A37D68BFBEB8BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC3BFBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1AC9D9AD5B49D45504FBAA694BEA590BBA795BFAD9A
BFA594C09E82B28A70AE8578BC7D6F8C2E1B8E7665B88072B8796DC2ABA2AA6859A8725C
A57F5F996D5D8F533F964E3FA46456A37E62A77A5FA7846DAD8C73B08870AC8772AC846E
A17862B39C8CBFBEB8BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC3BFBFC1BEBFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C18264586771729B8B7CBFAA94C1A691B69784BFAE9F
BFAA98C18B6EAF7B6083291E947D77DBBDB57B6864BCBAB0B8A19DBA9D95C5D4BEC4978C
BEA89FA48C7C915F4E5C39238046379B705EA47F63AD816EAD8D7AB79578B0866EAC8770
AC8570A18271B2ACABBBBEBBBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BBBBBD79493E193139B6A48CBFAA98C3B39BBA9E8ABFAA9B
BC9B85B787629E543A912E1A572C2AA28173BA9988BBA295BFB7A6BFAD9CC0A493B29281
BCA18CC9AA99C5A890A27D6F593A2B7545369C735EA67F6AB4967FB69580B59278AC826C
AC7F6BAA83689F9894A59F9EB3B7BBBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1957F6E59362BA68D84404449BAA691BFA58EBFA08ABFA58DBFAA95
C3A38AC1917FB2A386CBA68E7B6A5FB78279B8907EB17D6EB78980B78173B77965AA5646
B06A5DA37060BC8C72AE7465AC7A6A561E0F754940A17A69B09178BB9C80B58C73AA8972
A9836FAF826DB1A494ABA29B9F9EACBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC3BFBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BBB8B74A30243F271F1634399F8A7FBFA891BFA493BE9D8DBBA08BBFA291
C3A18BAD765BA58373BAA999BFB69FC3A99EC1AA9CBCA798B8AD97C49685B69C87B59078
B5826CAB6C5DB17C6DB06150AA523D973C2A59271D8B5B54AC8973BB9A80B58E72AE806A
A47F6BAC8671764632908E82A9A3A9BBBEBBBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1C5C9C9FFE5DA938776484D4ABBA896BFAB93BFAC91C39990BA9E8FBFB396
C3A08DBC8D7699715DBBA291BFB1A1BFAD9EBFA899BFB1A1BFA499C1A28EB99781BB9682
B38F76B38B70A3856AAF826CB0816BAF7D6798695E845648A28069B8947CB58E72AE866C
A4806AAC85709A705F3C3832B3B3ADBABBB9BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1CAC6B1AFAAAAC3B6A4BCA18EB5A18CBBAA94BFA694BFB39CBFA099BFAD9C
C5B099BA9980A97663AD8D78BBA796BFB4A4BFAD9EBFAA9BBFBAA2C19E8DB88D76B88F76
AF8C6FAB836C9E7C5FA1715CA1785CA1735CA4795C9F7A6FA4836AB38D79B3886EAA7E6A
A38166A7826B6E4435373F3AA29F9FBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BEC0BDBBC1B8BEA58BB9977DB5A195AEA193BAA491BFAD9ABFB0A0BFAD9EBFB4A4
C3A99EC09F8DBA8F77AA7C6BB69B87BFAE9FBFA89ABE9D8EBBAC99C0A58BB8957DAF7661
AF836DAA7A609B775FA0785FA1775CA37A5AA070569C7760AD8872B18A73B3856EA67D68
A67E6BA7876F4B2B27152321A19FA4BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1C3C0B1BAB3AAC0A38CB6947EB79073A69B95BF9E8FBFAA9BBFB1A1BFB1A1BFB1A1
BFBAA2C3A291BF9D81AF826AB28D7BBFAA9BBFBAA6C3A199BAA696C5AC99B69580B89279
AB7A66AA7E65A06E5AA0745D9E7867AB7F66AA846FA37F6AB18972B18770AF8670A97F69
A67E66A3826B6637282823215F605BBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC6BDBEA88FB98E6EAC8D79AF9081BAA691BF9E91BFAA9BBFB3A6BFB4A6BFB1A1
BFB1A4BFB09BC3A18AB39578AC8670BBA594BFAE9BBFAD9BBFAD9EC1AD98B9917CB18A73
AA846EAE866FA57B5DA372599E7662A58372AE8877B68F7AB5957EAC8B75AA8670AA8670
A6806DA78A72DD986A6A3E2D3928227A7B79BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFBBB0BCA391B56F5BB78874977363AAAA91BF9E91BFAA95BFAA9BBFAE9CBFB5A9BFB1A1
BFB1A1BEA897C1AD94B79E8BB49A83BAA68EBEA291BB9F8BBFA595C09C86BA9075AA7E68
A87A64A37E5F9F715A9E73599F7866A48670B08D7CBB9680B58D77AC8A73AF8770A9846A
A78068A7826FB4907ABE8B6DAA82735E615FBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFBAB6C39383B67561A6685CA9816FA6A091BFAD9DBFAD9ABFAA9BBFB1A1BFB1A1BFAE9F
BFAE9BC1AB97BAA48DBC9E89B6A491BFAD9DC3B6A1BA9E93BFAD92C39989B38C71A87963
A2755F986F5CA87B60997C69A37F6CAD907BB0937EBB9680B58F79AC8972AC806EAF7E70
A68069A97F6FAC8365A37863996B56C3C8C4BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFBEB4
BFC3AFC39C85B47C60A46F5FA18776BAA691BFAA9BBFB4A4BFAA9BBFAC9CBEA996BBAC96
BFA295C1A08EB59E87BE9883B6A18CBFA896BFAE9CBFAA9BBFA69CC3927DB68870A77B65
A378629D79649A7C659F7E68A98B76B4917CB3947EB8907AB58D77AC856EAC8068AA7D68
AA806AA4816DB3907DA57A64956E5CB5B6B3BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BCB39E
B0856C986A4F946853927260A78D7CBFAA95BFA899BFAC9CBFAE9BBFA892C1A895B59C89
B9A288BA9489B9A08DB99F8AB6A089BFAA9BBFAA97BFAA9BBEB099C09C88B6846DA77B65
A07661A578639D7E6BA58570AD8B78AF8E78B89781B3957EB58C76AC8F78AA856FAA7F69
A67A6BA4826FA87254A97764A974599A7E75BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1C1A88D
82482A7B4D3D5E3D34615751AD9586BFAA97BFAA98BFAA95BFAA9BBFAD9CC3A999BDAF9B
C09E90B3907EB28777B19782B59F89BBA892BFAA9BBFAA98C1A493B99880B07D6EA47760
9E725B9B7662A7816DA3846CAD8673AF8B79B18671AD8C76AF8A73A7856FAA8770A6826C
A67D6AA37A69A98865966148A77F6A9A5D4BBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC0BAC7BFB3
C8795C643D2D633E35394145AD9581BEA892BBA899BFAA97BB9E84B0957FAA856DA17D67
A48371A57A6FAA7E6FA57E69B08E7AB29E8ABFAA9BBFAA9EC1A994BD937FAF8262A0705A
A1765D95725D9C76639D806BA17F6BA58B74AF8B76A98570AF8C76A98670A6846EA6826C
A67D6AA67E6E9B634A82462F8D6248965946BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BEB9AAC0A895
591F1444251D422D25273B40B09783BFA891BAA48CBFAA98C9B096AD8A729D7A6174584B
5B42386446317A574990523B8A4A35927262BBA594BFAA9BC1AD98BD967FAF80659E7C5C
9B6E53967965A9826EA88873A1826DA67C6BA6836F9D826EAC8A74AE8972A2806A9C806A
9F806AA6806EAA7053864E387D4B3C914E36BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC6C3C6C7B9BD9277
A05C4D3C221B40261F122B35BAA28DB9A790BBA48FBFAA94C3B09CCAA48BB59583936550
502F26462D225141397C604C936E5C876257B6A28DBFB2A5C1B3A2BD9B81A97760986950
792C18735144997152986F5689604991705AA27A68937C64A7856DAA8770A87E679A7A66
967A6AA27A65955E4A7F5642815E50944C3BC3C8C4BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC0BCBFC1BEBFC3BFBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1642B1F797A72C09A82
AB664E482E3233211B0D222DB5A18CBFAA94B9A48EBAA58FBBA892C9B6A2AD927ADCA388
AD89718767507E5A43766F5D917360AA8472B6A08CBFAE9CC1B2A1BD9C82B57F61996B56
A46C4E67474072584F2811105A3F34604A3E5C3D2C695549846045916D53A57E679A7A65
967D669F735D7A4D385F3F336D5E50996251C8CCC9BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFBEBBBFBDBABFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C16D3E33674034290B06633C30
522E323C261D3D282205212CB9A48EB6A491BE9481AF8976AE9885C3B0A3C1B5A3C3A291
B28A75B5907BA6826C9D7C66A98F75B48F7CB69C88BFB1A1C1AC9DBD9E88AF8669A47B5A
A0785A9F7059AB7C654227242E241C593B34553D344F43367F6352836E59A6765C9D7A66
968068824E40623F2E5435274E4136985E49C4C9C6BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC3C0BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1884E404E33264A2C233A2621
2E18163C2621402720122731BAA18CB9A189C7BCA8B692819A6F579E77629C7C648E6D5B
8156467A513D825B44885743957864B19683B69D89BFAC99C1AD94BD9682AF8971A37157
9A7D5A9B785BAC8A72E09D7D77685B805944885C48675C508C6F5595725DA3866AA88069
9A7D697C4D35492B234F33264E3C2E893A28BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C19359403A1C1433231B37211A
3C241C2B1F1A44363024353AAE9884C3A691BAA691CAB6A8C8B39DA882709D766A9A7D6D
A077628E6C5B8A68539174618F6F62AF9A89BAA694BFA297C1A592BD9982AF85758F543F
824935846A4F9F8163A68468AE8870B18A6F9C7A648B735D9E7C69A67D669A7A699F8166
9F765C4C312533231B474D456F4A37762C1BBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC3BFBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1A37057481F163820192F211B
1F0F0E33201A3E322C384442988674BBA18CBFAA95BFAD9EC3B2A6C9C0ABCCAC9B9E9E95
C0ACA0B6A192BAAB9BA59585B29380B6A691BEAB97BAAE95BE9C8DBFA089B8A286C09481
8753475D362C563929755B49957863AA846CAC86689A7D68A47C6392735C9F786A9D7A69
824E39502C213E312A2C39318F4F36572E247D8380BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC8C4BFC0BDBFC5C1BFC5C1BFC5C1BFC5C18E6E624D342B39221B37211B
2D1D152E1F1940322C4149458C7A6BB69D89BFAA95BFAA9BBFB1A1BFB3A6BFB6ABBFB6AB
BFB4A6BFB3A6BFB4A6BFB4A7C3B09BBAA48CC3B19DBCA48DB99E87BC9E88B79D87BFA18D
CDA68FAC7F738B625351392C5234266B4A3C7257477E5C457C5B45977162937763A47965
6D3A2D40251D382524331B145E2A1C6E4237262725BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1A3786B5D443C38261E35211B
38221B37262442332E454841826F5FAE9784BFAA92BFA896BFAE9FBFAE9CBFB5A8BFB8AE
BFBBB3BFB3A6BFB9AEBFB1A1BFB4A7BFAD99BFAA94C1AA92B9A18AB99781B99B86B99D88
BF9986B39A83C1927AA9856F8F6F5A7158458057447B67569473607E65589F786A9A7760
6C3A2D3B231C30211A2A1D1537251F563A332B2C2ABFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1A06D5453372850342B36221B
3A1C143F261F4530254A3F376A61549F8876BBA892BFAA95BFAA9BBFB3A6BFB1A1BFB5A8
BFB8AEBFB8AEBFB9AEBFB1A1BFAE9BBFAE9FBFA894C1A48CB99B86B9A18AB99781B99B82
BB9480B7907AB38F79B08871AC8A75AA89739E7E69917461A37766A08169A673638E5E45
62362A3B231C40272033221B30201A412D23373631A8A7A5BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C18E634B5740384A3229452A23
2C1D1533201935211A483328544736877261B6A18CBFAA95BFAA9BBFB0A1BFBBB3BFB1A1
BFB5A8BFB5A9BFB5A9BFB1A1BFB1A0BFAA92BEA893BEA48DB99781B99882B99B84B99781
BB9680B18F79B18A74AF8F7AA68670AC8770A9846EA2826C9C7D669C7D6A97735C684538
3721173B27262B1C1B2D1C141E0E0E34231E403B34796C6ABFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1A36F56503930543F37453029
472A2235211A3F2C2543383353443B5E574AAE937FBFA892BFA899BFAB9ABFB5A8BFBBB3
BFB3A6BFB9AEBFB1A1BFB1A1BFB1A4BEA894BEA890B99B84B99B84B99781B89781B4947E
B8947EB58F79AC8A74AC8872AF8F79A68670AA846EA8826C9D7D68A079638A5F4C5D3428
4931292515142C1C1B1E0E0E291B1A2C1E193E3B385B514CBFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C197786C59413954413A543F37
452B232F1D1539251F4C3529614B3C5E54449B7D6BBBA18ABFAA98BFA899BFAB9ABFB5A8
BFB8AEBFBBB3BFB4A6BFB1A1BFB1A1C3AD9DBCA78FB89D86B4947EB5917FBB917EB3907A
B38B79B58D79AC8A74AC8770AA856FAA8770A47C65A97E689A755F926654784A37542F26
2D1C142E1D1C2314142A1C14271A193825202A31317E7D7ABFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC3BFBEBEBA8E6B5E4F3C3553413A523E36
3E261E452E273B2C2541312B564639715E4E926F5EB29A87BFAA95BFAD9EBFAD9EBFB0A1
BFB8AEBFB8AEBFB9AEBFB1A1BEAE9ABBA592C1A48CBC9B84B79984B3937AB8907EB38F79
B18D76B18C79AA8370A78470AA846EA6846EA9846D9E7A659D745D97664D67412F4C2C23
36231C2F211A30221B291B142E2119372520010000C3C8C4BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC8C4C3C6C3856153543B2E503B3355423B
574038412E2746342C4A34274C47406B5543826656A88C7ABBA892BFA899BFAE9FBFAE9C
BFB2A4BFB2A4BFB3A6BEA996BEA994B5A18CBEA38BB8947AB49179B8947AB39079B3937C
B58A74AC8D77AF8B72A9806EA6806AA67E68A2806A9D755F8F68506F463A56302635241C
2D1C14291B1A241514180E0E21131340332E120B0AC4C9C6BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1A5796C4D3629573F36534039
4E3930472B244932264D3A335041376046386755479B7B6BB6A48CBFAA95BFA896BFAC99
BFAC96BFAC96BFAE9CC3AD9DBCA78FB99882B8977FB88E7AB38B76B38E7CB39078B38A73
B58B75AC8770AC8770AE846EA6826CA479639F735D8F674F6F473B603D2B41261D34221B
35221B2B1C1A25151424141436241F25383C6D6462BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1B89E915B433B4D393157413A
56392B4B372E412D274C383046342D51433B56483D7F6250AA947EBAA58FBBA88FBFAA98
BFAA94BEA891BAA58CBBA896C1A68EB8947CB8947AB18970AD8871AD8875AF8B75B18C75
B1826CAC8370AA816EAA846AA47E65A279639B70597B4F3D633E2B3E251D301E152B1B1A
32211B2D1C1B1F0E0E22141333231E020101C4C9C6BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1B29883674E4454413A4D3C34
533E37422A28432F2843322B5340394D35284A372C6351448B705CAD8F79B29782BAA08A
BAA38DBEA891B9A18BB59C86BCA48CB69179AD826FB18A70AC7E68AC826DA8856FB18770
AA806AA78068A877649F78649A785F8D634C895D4667422E41251D35241C2C1C14241413
221414190E0E170E0E35231E402A1F0E0704BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1E0D8DD78564D57423B523E36
56453E573B2B4328224C3B3548352D53423B443028493E355F4C3E7B5E4C997866AD8A73
AB8B7AAF9483AF9681B09580B49078A27B62956D579C7157A47C65A77A66A7765FA77965
AA8061A47960A2755F9B6D57956D577F5543673B2B552E253E241C2C1C14251514241414
1E0E0E180E0E2114132A1D184750525B514BBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1D2DCD4A38774523A314F3C35
4C3A33493A32412B28442F24533D3552423B5C463E47373156463F594A3F6C4D3C816154
765D4E80614D8D6E5C8F725C8F6B598A614A78533D795941885B4394684F9A73589D6952
91634E91614793654F8961507B4F3F6D3F2D542C243F241C2D1C142615141E0E0E170E0D
170E0E170E0D281F1938251F000606BABBB9BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1CEC1C7674C43503F38
50413A523D3636251D3D302B54423A56453E604F47614F475E4F43605347614F42624539
603F31583E36633F337050416C4B3F5E453E68443765412E674433734F3E79564181553D
805943734C37724E3E7548376642324F2D24482F27301D152B1C142515141E0E0E170E0D
160E0D2F1F19271A19474C49312826BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1DDDEDA89645C503C34
513C354F3D35573F38493B3552423B5E4D4557433C56433B583D36644235623F30553F35
47312A4D3A31442A234D3730573F364B372F432A23452E28452A21452721513528553829
513627512C234B2821482B23482A2238251C2B1B14271615231414241414180E0E170E0D
2F1F232F1F1A4937301B30348F8783BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1C6CFC7D2C5C562483F
4F3C34534039503D355748414E393054433D513B325240395D4D4057433B563E36533C33
4D38304F3C35462D2B3E302A432A234429223A241C31211A36221B3E27204126203A231B
38221B39231B4027203A221B37221B2E1C142A1C14251514231414170E0E170E0E211413
3227224128234144445E615FBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1D6D3D28A5B52
564039534039523E3642342C5C4A4256484059484047352D4F392D4E332949362E49362E
3C2B2E3C322C452D2A3F262139242831221C32221B2B1C142D211A2E211A30221B2D1C14
241514291B1432201A2D1C142415142B1B14291B1A251514170E0E2314142C201A382A24
39251F535856535352BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1CAD5CEB69C93
5B403853413A523E3656413A493E3752413A513A3146312A3F2E273E251C42312A3F2A28
402A2735211C3823272B1C1C2615142A1B1B291B1B251514281A19241514291B1A251514
291B1A2D201A281B1A261514180E0E160D0D170E0D170E0E281A1A271A132214132F1A13
4F5552504D4BBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1EDF6F3
9D857A513B324F3C354D3F3851423B54473F56403D462B24422D2635241D32201933231C
35221B2715152414132B1B1B2A1C1B231414281B1A251514271A1925151438241F1A0F0E
2619192D201B2B1C1B180E0E170E0E1C0E0D271A19281B1A261A193B26214A3326554A3D
261C13BABBB9BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
EDF6F3A0807556443C4A362E54443D56473F5E4B424B3B3346342C3D25292A1C1B35211B
2A1C1B31221B2E211A291B1A2414142414142214132414142214132E211B261A1A4A3E44
3F3C3D3723292615152B1C1B2D201A2D211A281A193E302A412E273B2721543D34535350
89796CBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1EFFCFAA07C72634E4648352D4E40395B4C44644D454F382A49322834231D281B1B
261514281A14291B1A251514241414281A1A241414281A1A2414142213133F39373B2B32
54474864554B563F3E4F403B48352F33231C3E2D253A2A25503F385D4135505250796760
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BBC1BEF2FEFA946C5A6A534955413A56494263514864534B4C332A4630284A3931
44352E36221C30211A2B1C1B291B1A2314142414142C1F242B1C1C2E201A2518173F352D
433532301F1E34241D2F211B2F1E1D39231C3A2B244A342759473873716B685956BFC0BD
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1F1FFFF8F7362563E344E3E3763554E6C5F576F5A5048322A3B2726
4429234D3B3445352D2D1D1C24141433262A35272C3B302A39292E463A37352528433C3B
4F3D3A5840384A383347352D4C3A3251453C4E3B335D4E4163615A8F8171AFADAFBFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1F1F9F9BCB1AD6F5A535240395B4840655D5D73635C6A5950
655A55523D3B4D41405D54586259574E3C39483A4348383B5B50524D3F3D5A4238443A38
61473E5A3D365A3C2E5841395B493D6751426C4533475153897C6FBFC0BDBFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1CED8D1E3E3E68D7678624F49574B49636469756A67
70625B796C626F605E645C546A5A586C554B5F4C43513F3F46332B523F3B59473F534039
60433769483B6B4C40735446654437685854A1908869615ABFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC0BCBFC1BEBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1F1F9F0B3B4B9AEA69F766C777C7173
8C83888D7F80806C6379676076645C806B6778645E7D675D76645E6D5A4D68595178655D
6A5C516B584B63463C6C6460A6A09F9A948A898383BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC3C0BFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1C6CFC7E6E8E19CA5AD
A6A69EBCBCC7B3B3BAB2A4A58A7B84746C727867657B655C6F61597D675F6E5C52675245
71594B75766EB7B7AF7C8079A49FA2BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1C6CFC4B4B9C0CED3C9D4D3D2AEB2B2B2B9C2ADAEAAADACA8ADAFABB0B2AEAFB4B4
AAA7A374776FBFC0BDBFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1BFC5C1
BFC5C1BFC5C1BFC5C1BFC5C1
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?oooeVoaL44`LFj1;JTS`>oZYD4_jZK1;naX@BoZY/?_k6Q1;nZ
VPC1Zi<4^JB=1;^LQ0BcT7X3]Hmi4:b:M0B/RG83[XA/1:J4JPBVQ6`4YXAZ19YeG`noaL44_lK21;nm
^R>oaL4Eoooo000DooooFKo5`@C1aKX4]ZB?0knZU@BoZY/4_k6Q1;nZV`no/J44_jZJ1<6[T`BiY8d4
^ib41;>@NP>eSgT@[8Yd1:b9LP>^Q6`4YXAZ1:J4K0BVQ6X4VWEO3ko5`@Boa/84_kfj8ko5`AGoool0
01CooomI_lG11<75^PBfY8l3_jZE1;nZV`Bo/J44_jZK3knaX@BoZYX4`J^C1;VTS@BkW8@4/i1j0kF?
NA2/RW@4[8Ub0jj4K0BVQ6X4YXA/1:J4JPBJMEl?_lG11;o6`PBo_KXS_lG15Oooo`005?ooo`BoaL44
_l>o1;o1_PBoaL44_l>o0ko1_R>oaL44_l>o1;o1_QNoaL44`lVo1;ZVU0>oZY@4_jZH1;naX@BoZY/4
_k6Q1;n^V`>nZI<4^ZVC1;ZSS`BlWhP4/YR11;:DO0B]RgD3[hYc1:V8LPR/RW@8[8M`0jj4L0BVQ6/4
YXA/1:J?NPBJPW4?_lG11;o8a0Bo`;dS_lG15Oooo`005?ooo`BoaL44_l>o1;o1_PBoaL44_l>o0ko1
_R>oaL44_l>o1;o1_QNoaL44`lVo1;ZVU0>oZY@4_jZH1;naX@BoZY/4_k6Q1;n^V`>nZI<4^ZVC1;ZS
S`BlWhP4/YR11;:DO0B]RgD3[hYc1:V8LPR/RW@8[8M`0jj4L0BVQ6/4YXA/1:J?NPBJPW4?_lG11;o8
a0Bo`;dS_lG15Oooo`005?ooo`BoaL44_l>o1;o1_PBoaL44_l>o0ko1_R>oaL44_l>o1;o1_QNoaL44
`lVo1;ZVU0>oZY@4_jZH1;naX@BoZY/4_k6Q1;n^V`>nZI<4^ZVC1;ZSS`BlWhP4/YR11;:DO0B]RgD3
[hYc1:V8LPR/RW@8[8M`0jj4L0BVQ6/4YXA/1:J?NPBJPW4?_lG11;o8a0Bo`;dS_lG15Oooo`005?oo
o`BoaL44_l>o1;o1_PBoaL44_l>o0ko1_R>oaL44_l>o1;o1_QNoaL44`lVo1;ZVU0>oZY@4_jZH1;na
X@BoZY/4_k6Q1;n^V`>nZI<4^ZVC1;ZSS`BlWhP4/YR11;:DO0B]RgD3[hYc1:V8LPR/RW@8[8M`0jj4
L0BVQ6/4YXA/1:J?NPBJPW4?_lG11;o8a0Bo`;dS_lG15Oooo`005?ooo`BoaL44_lS41;nn^`Bo`Kh4
_lS40ko0_@BoaL44_l>o1;o1_PBo`kl4_l6n3ko5`@Bob<@4_l2m5ko5`@Bn`kP4^jR?0knZV`BoZ9D4
_k6Q1;nZV`Bo[9`4_ZbJ0kRUT@B]W8L4]9F11;J@NPBaTG`4[9=l1:b?NP>_SWP4YXA^2:N5K`BWQg04
YhAZ0jZ4K0BVQ6h4YXA`1:V8L0BYZ:8C_lG11;o3_`Bo`KhO_lG15Oooo`005?ooo`BoaL44_lS41;nn
^`Bo`Kh4_lS40ko0_@BoaL44_l>o1;o1_PBo`kl4_l6n3ko5`@Bob<@4_l2m5ko5`@Bn`kP4^jR?0knZ
V`BoZ9D4_k6Q1;nZV`Bo[9`4_ZbJ0kRUT@B]W8L4]9F11;J@NPBaTG`4[9=l1:b?NP>_SWP4YXA^2:N5
K`BWQg04YhAZ0jZ4K0BVQ6h4YXA`1:V8L0BYZ:8C_lG11;o3_`Bo`KhO_lG15Oooo`005?ooo`BoaL44
_lS41;nn^`Bo`Kh4_lS40ko0_@BoaL44_l>o1;o1_PBo`kl4_l6n3ko5`@Bob<@4_l2m5ko5`@Bn`kP4
^jR?0knZV`BoZ9D4_k6Q1;nZV`Bo[9`4_ZbJ0kRUT@B]W8L4]9F11;J@NPBaTG`4[9=l1:b?NP>_SWP4
YXA^2:N5K`BWQg04YhAZ0jZ4K0BVQ6h4YXA`1:V8L0BYZ:8C_lG11;o3_`Bo`KhO_lG15Oooo`005?oo
o`BoaL44_lS41;nn^`Bo`Kh4_lS40ko0_@BoaL44_l>o1;o1_PBo`kl4_l6n3ko5`@Bob<@4_l2m5ko5
`@Bn`kP4^jR?0knZV`BoZ9D4_k6Q1;nZV`Bo[9`4_ZbJ0kRUT@B]W8L4]9F11;J@NPBaTG`4[9=l1:b?
NP>_SWP4YXA^2:N5K`BWQg04YhAZ0jZ4K0BVQ6h4YXA`1:V8L0BYZ:8C_lG11;o3_`Bo`KhO_lG15Ooo
o`005?ooo`RoaL44_lK21;nm^P^oaL44_lS41;o0_@Bob<@4_l2m;[o5`@C3aKX4^ZBA0knZU`BoZY/4
_jRI1;n^W`BoZYP4`jfN0lV/V@B`ZIL4^:6>1;jBPPBaRW@4/H]i1;6;NP>`QWD4[XA`3:J4KPBVQ703
YhM_1:V6L0BVQ6h4VWEO5ko5`@Bob<@4_l2m7ko5`AGoool001Coool8_lG11;o6`PBo_KX;_lG11;o8
a0Bo`;d4_lS41;o0_BjoaL44`lFj1;ZTT@>oZYL4_jZK1;nXV@Bo[Yl4_jZH1<>]WP?9[9T4/:VG1;RQ
SPBnTX84/HYd1;6;N@BaRgX3/8Ie1:j4L0bVQ6h4YXA`0jN7K`BYQW04YXA^19YeGaNoaL44_lS41;o0
_AnoaL4Eoooo000Doooo2;o5`@Boa/84_kfj2ko5`@Bob<@4_l2m1;o8a0Bo`;d^_lG11<?5^PBjY943
_jZG1;nZV`BoZ9T4_jjO1;nZV0C3[Ih3bJbI1;2YU`BhXHh4_Y:21;6:M0BaRgT4/H]j0k26M@B^Q70<
YXA^1:J4L0>WQfl4ZHI`1:J4KPBJMElG_lG11;o8a0Bo`;dO_lG15Oooo`005?ooo`RoaL44_lK21;nm
^P^oaL44_lS41;o0_@Bob<@4_l2m;[o5`@C3aKX4^ZBA0knZU`BoZY/4_jRI1;n^W`BoZYP4`jfN0lV/
V@B`ZIL4^:6>1;jBPPBaRW@4/H]i1;6;NP>`QWD4[XA`3:J4KPBVQ703YhM_1:V6L0BVQ6h4VWEO5ko5
`@Bob<@4_l2m7ko5`AGoool001Coool8_lG11;o8a0Bo`;e9_lG11;o9_`BoYXh3_jZE1;nZV0RoZY/4
_jZN1;n]VP>o/:04`k2S1;V/T`C1WY44]iR41;NDOPBfSWd3^9F21;J3L`B[OVh4ZhMh1:V8L`BWQ6h3
Yh9/1:j7L0BWRWD4WW]U?[o5`AGoool001Coool8_lG11;o8a0Bo`;e9_lG11;o9_`BoYXh3_jZE1;nZ
V0RoZY/4_jZN1;n]VP>o/:04`k2S1;V/T`C1WY44]iR41;NDOPBfSWd3^9F21;J3L`B[OVh4ZhMh1:V8
L`BWQ6h3Yh9/1:j7L0BWRWD4WW]U?[o5`AGoool001Coool8_lG11;o8a0Bo`;e9_lG11;o9_`BoYXh3
_jZE1;nZV0RoZY/4_jZN1;n]VP>o/:04`k2S1;V/T`C1WY44]iR41;NDOPBfSWd3^9F21;J3L`B[OVh4
ZhMh1:V8L`BWQ6h3Yh9/1:j7L0BWRWD4WW]U?[o5`AGoool001Coool8_lG11;o8a0Bo`;e9_lG11;o9
_`BoYXh3_jZE1;nZV0RoZY/4_jZN1;n]VP>o/:04`k2S1;V/T`C1WY44]iR41;NDOPBfSWd3^9F21;J3
L`B[OVh4ZhMh1:V8L`BWQ6h3Yh9/1:j7L0BWRWD4WW]U?[o5`AGoool001CooomI_lG11;o6_@BoZY@3
_jZG1;nZU0BoZYP4_jZK1;n]WPBoZY/3_jbL1;naX@C3/:<4_JnH1;bRSPBiVHL4_9b60k>=NPBlUh44
/8Qe1:anJPB_T844YXQc0jN4KPBZQ6h4YHen1:^BP1^oaL44_l>o1;o1_Q^oaL4Eoooo000DooooFKo5
`@Boa[d4_jZD0knZU`BoZY@4_jZH1;nZV`Bo[Ih4_jZK0kn/W0Bo/J44`k2S1;f_V0BlXXh4^IV71;bL
QP>cSGX4_9N11;28M@B/OVX4[i211:J8L`>WQ6h4ZXA^1:F=OPB[TX0K_lG11;o3_`Bo`KhK_lG15Ooo
o`005?oooeVoaL44_lJm1;nZU0>oZYL4_jZD1;nZV0BoZY/4_jfN1;nZV`>o[9`4_k6Q1<>`X`Bm[iP4
_::>1;VIQ`BlW8H3/hej1;bGP@B`R7D4[7iZ1:n@P@BVR7<3YhA^1:Z4KPBUSGh4Zi:06ko5`@Bo`kl4
_l6n6ko5`AGoool001CooomE_lG11;^/W`Bc[jD4_jZG0knZU0BoZYP4_jZE1;n]WPBoZY/4_k6Q0kn`
X0Bo[Ih4_k6Q1;nZWPC3[IP4_J>:1;bIQP>lVH@4]Y9m1;N:N@B`RG84ZWmY1:Z:MP>WQ6h4ZHA^19j2
K`BfZjDK_lG11;o8a0Bo`;d7_lG11;o3_`Bo`;`4_l6n2;o5`AGoool001CooomE_lG11;^/W`Bc[jD4
_jZG0knZU0BoZYP4_jZE1;n]WPBoZY/4_k6Q0kn`X0Bo[Ih4_k6Q1;nZWPC3[IP4_J>:1;bIQP>lVH@4
]Y9m1;N:N@B`RG84ZWmY1:Z:MP>WQ6h4ZHA^19j2K`BfZjDK_lG11;o8a0Bo`;d7_lG11;o3_`Bo`;`4
_l6n2;o5`AGoool001CooomE_lG11;^/W`Bc[jD4_jZG0knZU0BoZYP4_jZE1;n]WPBoZY/4_k6Q0kn`
X0Bo[Ih4_k6Q1;nZWPC3[IP4_J>:1;bIQP>lVH@4]Y9m1;N:N@B`RG84ZWmY1:Z:MP>WQ6h4ZHA^19j2
K`BfZjDK_lG11;o8a0Bo`;d7_lG11;o3_`Bo`;`4_l6n2;o5`AGoool001CooomE_lG11;^/W`Bc[jD4
_jZG0knZU0BoZYP4_jZE1;n]WPBoZY/4_k6Q0kn`X0Bo[Ih4_k6Q1;nZWPC3[IP4_J>:1;bIQP>lVH@4
]Y9m1;N:N@B`RG84ZWmY1:Z:MP>WQ6h4ZHA^19j2K`BfZjDK_lG11;o8a0Bo`;d7_lG11;o3_`Bo`;`4
_l6n2;o5`AGoool001CooomA_lG119EoKPBIXYH4ZiN81;nZU@>oZYh4_jZJ1;nZU`BoZY/4_k6Q1;nX
UP>o[Y`8_jjO1;nZV0Bo[IX4_Z>?1;jKQP>iU844^iIl1;69L`BaRW@4[hI`1:V4KP>TRWD4[h]e1:5n
J0Bj^kTZ_lG11;o8a0Bo`l04_l2m2;o5`AGoool001CooomA_lG119EoKPBIXYH4ZiN81;nZU@>oZYh4
_jZJ1;nZU`BoZY/4_k6Q1;nXUP>o[Y`8_jjO1;nZV0Bo[IX4_Z>?1;jKQP>iU844^iIl1;69L`BaRW@4
[hI`1:V4KP>TRWD4[h]e1:5nJ0Bj^kTZ_lG11;o8a0Bo`l04_l2m2;o5`AGoool001CooomA_lG119Eo
KPBIXYH4ZiN81;nZU@>oZYh4_jZJ1;nZU`BoZY/4_k6Q1;nXUP>o[Y`8_jjO1;nZV0Bo[IX4_Z>?1;jK
QP>iU844^iIl1;69L`BaRW@4[hI`1:V4KP>TRWD4[h]e1:5nJ0Bj^kTZ_lG11;o8a0Bo`l04_l2m2;o5
`AGoool001CooomA_lG119EoKPBIXYH4ZiN81;nZU@>oZYh4_jZJ1;nZU`BoZY/4_k6Q1;nXUP>o[Y`8
_jjO1;nZV0Bo[IX4_Z>?1;jKQP>iU844^iIl1;69L`BaRW@4[hI`1:V4KP>TRWD4[h]e1:5nJ0Bj^kTZ
_lG11;o8a0Bo`l04_l2m2;o5`AGoool001Coool8_lG11;o3_`Bo`Khm_lG11;Rd]0AjACX4<d=61;ZV
T`Bo[IL;_jfN1;nXV@Bo/J44_k2S0knZU`Bo[Y/4_j:B1;jJR`BiUh04^Yn61;VGQ0>hVH44]Xmn1;>?
MPB`Qg84ZXU^1:Z4K0>SOf/4YhQa19miHd:oaL4Eoooo000Doooo2;o5`@Bo`kl4_l6n?Ko5`@Bh];@4
NTDj13=3APBjYY<4_jfG2kn]WPBoZ9T4_k6Q1;n`X`>oZYL4_jjK1;nRTPBnVX/4^IN01;ZOQPBiUh@3
^9V11;J?OPBcSgH4/8Mb1:Z9KPBZQ6`3Xgm[1:N8L@BONF=2_lG15Oooo`005?ooo`RoaL44_l>o1;o1
_SfoaL44^;Bd17Y5>P@c@dH4^ZJC1;n]U`^o[Ih4_jRI1;naX@Bo/:<3_jZG1;n^V`BoXY84_YZ;1;VG
P0BjWhH4^IN40kRIP@BfSgh4/hmf1;27LPBZRFh4ZXA/0j=oJ`BWR744WgUS@[o5`AGoool001Coool8
_lG11;o3_`Bo`Khm_lG11;Rd]0AjACX4<d=61;ZVT`Bo[IL;_jfN1;nXV@Bo/J44_k2S0knZU`Bo[Y/4
_j:B1;jJR`BiUh04^Yn61;VGQ0>hVH44]Xmn1;>?MPB`Qg84ZXU^1:Z4K0>SOf/4YhQa19miHd:oaL4E
oooo000Doooo2;o5`@Bob<@4_kjk1;o1_SFoaL44_lK317eG@0B]YYX4EEIB1;nZV`BoZ9D3_jjO1;nX
V@Bo[Yl4_jZK1;nXV@Bo[Yl3_k6Q1;jXU`BjYhh4_YN91;^FP0B_SWP4]95k0kRAN0BeTgX4Z8M`1;65
K`B_Qg84ZhA[0jV4KPBWQg84WWUT1;^g/SjoaL4Eoooo000Doooo2;o5`@Bob<@4_kjk1;o1_SFoaL44
_lK317eG@0B]YYX4EEIB1;nZV`BoZ9D3_jjO1;nXV@Bo[Yl4_jZK1;nXV@Bo[Yl3_k6Q1;jXU`BjYhh4
_YN91;^FP0B_SWP4]95k0kRAN0BeTgX4Z8M`1;65K`B_Qg84ZhA[0jV4KPBWQg84WWUT1;^g/SjoaL4E
oooo000Doooo2;o5`@Bob<@4_kjk1;o1_SFoaL44_lK317eG@0B]YYX4EEIB1;nZV`BoZ9D3_jjO1;nX
V@Bo[Yl4_jZK1;nXV@Bo[Yl3_k6Q1;jXU`BjYhh4_YN91;^FP0B_SWP4]95k0kRAN0BeTgX4Z8M`1;65
K`B_Qg84ZhA[0jV4KPBWQg84WWUT1;^g/SjoaL4Eoooo000Doooo2;o5`@Bob<@4_kjk1;o1_SFoaL44
_lK317eG@0B]YYX4EEIB1;nZV`BoZ9D3_jjO1;nXV@Bo[Yl4_jZK1;nXV@Bo[Yl3_k6Q1;jXU`BjYhh4
_YN91;^FP0B_SWP4]95k0kRAN0BeTgX4Z8M`1;65K`B_Qg84ZhA[0jV4KPBWQg84WWUT1;^g/SjoaL4E
oooo000Doooo2;o5`@Bo`kl4_lG11;o0_CFoaL44M50l1<C2^0ARIV84^ZJC1;nZU@NoZY/8_jZH1;nZ
V`Bo[Ih4_jZK0kn^W`C1Sh<4^H1d1;QbJPBhLFH4/fiS1;>0K`>aR7<4/HQ_1:b3K0BZPFP4ZHA/1:b4
KP>^Q6X4Y7iW1:=gH@BZTH<Z_lG11;o3_`Bo`Kh<_lG15Oooo`005?ooo`RoaL44_l>o1;o5`@Bo`;de
_lG117A@?0C4`[P4HVIR1;ZVT`BoZYD7_jZK2;nZV0BoZY/4_jfN1;nZV`>o[Yl4`Hn31;V0M0BhLVX4
^75V1;=^H`BcP6l3/HQc1;68K`B/Pf`4ZX5X1:V4K0B/Q6h3[XAZ1:AnI`BSMf44ZY63:[o5`@Bo`kl4
_l6n3;o5`AGoool001Coool8_lG11;o3_`BoaL44_l2m=Ko5`@AdD3`4a<:h169VHPBjYY<4_jZE1knZ
V`RoZYP4_jZK1;n]WPBoZY/3_jjO1<6?P`BiP7@4^79Z1;QaIPBcKV<4/h1_0k68L`BaR6l4[8=/1:Z1
J0BYQ6`4[8A^0jj4JPBTOVL4XgMQ1:ZAPbZoaL44_l>o1;o1_PboaL4Eoooo000Doooo2;o5`@Bo`kl4
_lG11;o0_CFoaL44M50l1<C2^0ARIV84^ZJC1;nZU@NoZY/8_jZH1;nZV`Bo[Ih4_jZK0kn^W`C1Sh<4
^H1d1;QbJPBhLFH4/fiS1;>0K`>aR7<4/HQ_1:b3K0BZPFP4ZHA/1:b4KP>^Q6X4Y7iW1:=gH@BZTH<Z
_lG11;o3_`Bo`Kh<_lG15Oooo`005?ooo`RoaL44_lS41;o0_CJoaL43^;B`1?;Xh`AKGUX4_jjO1;nZ
VPBoZYD4_jZK0knXU@BoYI84_jF<1;nXUPBoZ9T4_jFH0knJT0C1UhT4^6iQ1;IPD0B_I5/4/FEH1:mO
F@>cLf@4YgUW1:N4JPBZOFP4Y85Z1:b4KP>_Q704Yh9Y1:n1K@BMLU/4/jNL9[o5`@Bob<@4_l2m3;o5
`AGoool001Coool8_lG11;o8a0Bo`;df_lG10kRd/0Cbj><4FeiJ1;n^W`BoZYX4_jZE1;nZV`>oZ9D4
_jFB1;nUS0BoZ9H4_jRI1;nUV0>oVY04`IN91;Q^H@BfH504[fAK1;5UF0B_GeT3/g=T1:MiI`BWQ6X4
ZWeX1:B1JPB/Q6h3[hA`1:N2J@B_PFd4WG9K1;>WW2JoaL44_lS41;o0_@boaL4Eoooo000Doooo2;o5
`@Bob<@4_l2m=[o5`@>h];04l^SS15]NFPBo[Yl4_jZJ1;nZU@BoZY/3_jRE1;nUTPBoYH`4_jRF1;nX
V@BoYIP3_iZ@1<6GR@BhKV44]V1@1:mTF`BaIEP4[emI0k=cI0BWNFL4YhAZ1:YmJ0BTPFX4[8A^0jn4
L0BWPVT4[h5]19ebF`BcYi`V_lG11;o8a0Bo`;d<_lG15Oooo`005?ooodJoaL43LeI916I_K0BfZ9H4
_jZE1;nZV0BoZYD4_jZH0kjXT`BjW8D4^j6<1;nVT@BoYI44_Xmn0kUbI0BgQ7D4[6A>1:MlJPBYOF`4
/em>1:=@@0>aGE44ZFQL1:IjJPBVPV04XgiS1:V4K0>/Q6h4[8I`1:anJPB/R784XgeX1;nn^3JoaL4E
oooo000DooooA[o5`@=cETT4IVm/1;JXUPBoZYD4_jZH1;nZU@BoZYP3_ZRC1;ZLQ@BkXH`4_jJA1;nU
T@BnSgh3^G9T1;N4M@B/I4h4YgaZ1:UmK0BcGdh4Xe100k5MD@BYJ5`4YWYZ1:J2H0BSOV<4ZHA/0jb4
KPB/QW04[7iZ1:b8LPBSOFP4_kjh=[o5`AGoool001Cooom6_lG10g=FB@AVKf`4]ZRF1;nZU@BoZYP4
_jZE1;nZV0>nZ9<4^Yb51;^QS0BoYY44_jFA1;j?OP>iLV@4]hAe1:aTCPBWO6X4ZGe/1;=OCPBSD403
/EeA1:UXG0BVNVX4YX9P1:=nH`BYQ6`3[8A^1:b6L0B/OVX4[8Qb1:=mJ0Bo_[Pf_lG15Oooo`005?oo
odJoaL43LeI916I_K0BfZ9H4_jZE1;nZV0BoZYD4_jZH0kjXT`BjW8D4^j6<1;nVT@BoYI44_Xmn0kUb
I0BgQ7D4[6A>1:MlJPBYOF`4/em>1:=@@0>aGE44ZFQL1:IjJPBVPV04XgiS1:V4K0>/Q6h4[8I`1:an
JPB/R784XgeX1;nn^3JoaL4Eoooo000Doooo4;o5`@Bo`kl3_l6n:ko5`@B/WIX3eKBM14E@C`BjYY@4
_ZF@1;^WU@Bo[IX4_jFD0l2NPPBbRW04[XEh1;amK`B<;Q/4SWIU0kR0LPBhNFd4`Z^R1:YXF@BXLU`4
YGmO19U]G@>?Dcl4UTho1:ATEPBSOV84YgYO1:N4K@>]S7<4/8Q`1:b7LPB/Q6h4XGQR1;>LS0Bo_[Pb
_lG15Oooo`005?oooa2oaL44_l>o0ko1_R^oaL44[9fJ0mFdW@A5D4l4^ZJD1;jUT0BkYiD4_jfJ1;nU
U0?0WX84/XY`1:j5N0BlOFl4S2hK18ifI@>hP784^7U]1<:[XPBZJ5T4Z79L1:EoG`BIKEd3Se<o19I>
?`BTI5H4XgiR1:MjG`BWQ6d3[Hac1;28L0B/Qg84[8A^1:5hHPBcW8`4_kjh<[o5`AGoool001Coool@
_lG11;o3_`>o`Kh[_lG11:bMVP?E]9d4AE1?1;ZVU0BnYI04^jNE1;n]VPBoYI@3`9j21;::L0B^QGP4
_7e_18`^6`B>MVD3^81b1;QiK@C2Zj84ZVQI1:QbG0BUOel4VFeM0hmC?`BFCSl4Y6AF1:=nHPBWNUl4
YhA]0jf<L`B`R704[8Mb1:b4KPBQN684/ib<1;nn^3:oaL4Eoooo000Doooo4;o5`@Bo`kl3_l6n:ko5
`@B/WIX3eKBM14E@C`BjYY@4_ZF@1;^WU@Bo[IX4_jFD0l2NPPBbRW04[XEh1;amK`B<;Q/4SWIU0kR0
LPBhNFd4`Z^R1:YXF@BXLU`4YGmO19U]G@>?Dcl4UTho1:ATEPBSOV84YgYO1:N4K@>]S7<4/8Q`1:b7
LPB/Q6h4XGQR1;>LS0Bo_[Pb_lG15Oooo`005?ooo`RoaL44_l>o1;o1_PBob<@3_l2m:ko5`@B2I5P3
Ig5b19^;O0BoZY@4`JJA1;JGQ0Bo[Yl4_jZH0l6;KPB_Nf04PbTN19AmM`CK_KD4NfQT0kbj/0BhXId4
^YfE1<GD_PC4Uh`4_ZRO1:B<O0>AGdh4G3TS1816=`BKL5h4Y7mS1:f1KP>]SGX4]iEh1;26KPB/Qg04
[8E`1:62L@Bb[:/3^kjk;ko5`AGoool001Coool8_lG11;o3_`Bo`Kh4_lS40ko0_B^oaL44PVAH0fMa
LPBKRg`4_jZD1<6VT@BfUh@4_jjO1;nZV0?1Rfh4[g]P18<Y7PBDOGL4fkfe17]XI0>l^[04^:6M1;ZM
U@C5e;h4a9N<1;jXW`BTS7`3TEm>15`i8`B0ASL4Vg1N1:AoH`B]PFh3[Hej1;NEN0B`QVh4[8M`1:b5
L0BQPW44/Zb[0k^n^bnoaL4Eoooo000Doooo2;o5`@Bo`kl4_l6n1;o8a0>o`;d[_lG1189TF0=WLG84
Vh]l1;nZU0C1YY44]YN41;n^W`BoZYP3`H]^1:mkH0B3:Ah4U7eg1=^m]@AkJ6@3_;Z`1;RQW@BjWID4
aMBn1<BGS0BnZ9l4Y8al0i5OCPAL>B<4P4Hg19]`GPBTOf<4[H5^0jf=NPBgUGP4/8I^1:b7L0B/QG04
XH9a1;:/Z`>k_[/__lG15Oooo`005?ooo`RoaL44_l>o1;o1_PBob<@3_l2m:ko5`@B2I5P3Ig5b19^;
O0BoZY@4`JJA1;JGQ0Bo[Yl4_jZH0l6;KPB_Nf04PbTN19AmM`CK_KD4NfQT0kbj/0BhXId4^YfE1<GD
_PC4Uh`4_ZRO1:B<O0>AGdh4G3TS1816=`BKL5h4Y7mS1:f1KP>]SGX4]iEh1;26KPB/Qg04[8E`1:62
L@Bb[:/3^kjk;ko5`AGoool001Coool8_lG11;o8a0Bo`;d^_lG11;^k_@AiBCh36C4i1;JTS0BoZYP4
`k>K1;ZNRPBoZY/4_9^50kN7HPBNE3X4TBhJ15L/:PBRPG<4^YV80k^RU@Bo]jH4_jfL1<2TT`BbTX44
_:6<1<VZV@?5Z904XWe_15Tj:`AeACH4W7=N1:IoJP>dUWl4]YF01;FBN0B/PV`4[7m[1:Z3J0BOV9@3
YInN1;>g^b^oaL4Eoooo000Doooo2;o5`@Bob<@4_l2m;[o5`@Bk^kd4NDTn0aTa>@BfY8`4_jZH1<>c
V`BjWXX4_jZK1;bKQ@>gQf84WU@j194^6PAG;2X4XX5c1;ZIR0>kXYD4_kNV1;n]W0C0Y9<4/Y:11;bQ
S0C9ZYT3aJR@1:9mK`AI>R/4MDDf19acGPBVOfX3]9Io1;JEP0BeTWP4[89/1:aoJ`BZPfP4WiRD0jFO
WPBc]k/[_lG15Oooo`005?ooo`RoaL44_lS41;o0_BjoaL44^k^m17U9?P<I<CT4]ZB<1;nZV0C3/i/4
^Yj:1;nZV`BlVhD3]hMR19iD>PBA;QX4Eb`Z1::1L`BjVHP3^j:E1;ngYPBo[I`4`:BC1;:BP@BlXH`4
bJZI0lFXT0BROFl4FCX[17E5=PBLLeh4YWmZ0kBFO`BfUH04]I9h1:b2K0B/Of/4ZX=X19nHU0>UWih4
/kNk:ko5`AGoool001Coool8_lG11;o8a0Bo`;d^_lG11;^k_@AiBCh36C4i1;JTS0BoZYP4`k>K1;ZN
RPBoZY/4_9^50kN7HPBNE3X4TBhJ15L/:PBRPG<4^YV80k^RU@Bo]jH4_jfL1<2TT`BbTX44_:6<1<VZ
V@?5Z904XWe_15Tj:`AeACH4W7=N1:IoJP>dUWl4]YF01;FBN0B/PV`4[7m[1:Z3J0BOV9@3YInN1;>g
^b^oaL4Eoooo000Doooo>[o5`@BEOfh4FCH[1:J=Q0=0A4T4^ZJA1;nUSPBoX8X4_jF=1;nZU@C3XhX3
`I5o1;:SQPC;YXh4NfYO1;N2N@BhT7h3/Ge^1;N9P0BgPG<4]gUU1:YFAPB`JUd4Xg1P0kb<LPB^M6D4
[7YZ15HN3`AeBD04XGYY0k2AN0BkW804]Hac1:Z9LPBYPfl4[h9]1;6TU0>[XY/4Wij/:ko5`AGoool0
01Cooolj_lG119EoKPAI=R/4YXf40d14B@BjYY44_jF>1;nPRPBoYHd4_jZE1<>SRP?1TGl4/Z>61<^V
SPAkJUl4]h9i1;R@OP>aOFh4]hV01;N1L`BgNFD4ZUI61;1ZG@BSL603_8ab1:idI@B/NVX4EQh?17E9
@0BQNVT3/95h1;^LP0BeS7<4ZXUb1:V3K`B_PVd4/JBD0j^RV`BOWZ`[_lG15Oooo`005?ooocZoaL44
UGm^15Tf:`BVSH@3@4A91;ZVT@BoYHh4_j2:1;nUS@BoZYD4`j>:0l6AO`BbXhH4bjJ>17]ZG`BgPWT4
^91n0k5mKPBgRH04]h5c1;MiI@BZETH4/6YM1:=`H0>lS784[WAU1:ajJPAF7Pl4MDU01:5jJ@>`TGP4
^ib01;F<L`BZRG84ZH=_1:n2K@BaY9@3Zj:K19nN[2^oaL4Eoooo000Doooo5;o5`@>o`kl4_l6n6ko5
`@Bk^;L4BS0T13lW7`@F=3T3WhYo1;nXT@BoY9<4_Yf=1;^PR`BoXY44`j6;0jefF`BUPg<4^ZVI1;nf
W`C3ZIh4`JZL0kbWV0Bh[IL4a9J51;JLQ`BeT7P4]H9/1:]/G@>aO6d4/65@1:YB?@BG?2X4FBLM18]K
E0>/RG<4^iZ01;F>LPB^P6X4Y7m[1:b6L@AfAS83T8j21:VSZ@Bk_[/W_lG15Oooo`005?oooaBoaL43
_l>o1;o1_Q^oaL44^kRg14X`90@o9al45S@i0in:O`BoZ944_jBC1;jMS@BkX8/4_j:A1<>QR`>]MU/4
YH=c1;ZYV@Bo]Yl4`jVN1<6ZW0>lYiP4^:fG1<BFQ@BfW8L4]I1h1;F2K0B[K5d3/Ga]1;1QD0BZDSd4
Uc`Z15TW7@B;Fe@3[8Uc1;^JP0BeSW84[X1Z1:AoJ`B/QW44MTHb0i2>PPBYXjT4^kjk9ko5`AGoool0
01CooolD_lG10ko3_`Bo`KhK_lG11;^h]`A:<2@4?bLO11Hd>@>ORWl4_jRA1;nTT`BnWHd4^j2;1;nR
T@C3XH/3[GIK1:F3L`BjZIT4_kJO1<>YWPC1ZY`3_:NH1;R]U`C4UXD4]Yb71;F@N0BePV`4ZfaM0k5l
K@B`HE04ZU8m19Ll:PAI9ad4Re]D0jb9L`BkVX04]Hib1:j0JPBTOf/4[8Ia17I6<P>@SX84ZJ>Y1;^n
^bNoaL4Eoooo000Doooo5;o5`@>o`kl4_l6n6ko5`@Bk^;L4BS0T13lW7`@F=3T3WhYo1;nXT@BoY9<4
_Yf=1;^PR`BoXY44`j6;0jefF`BUPg<4^ZVI1;nfW`C3ZIh4`JZL0kbWV0Bh[IL4a9J51;JLQ`BeT7P4
]H9/1:]/G@>aO6d4/65@1:YB?@BG?2X4FBLM18]KE0>/RG<4^iZ01;F>LPB^P6X4Y7m[1:b6L@AfAS83
T8j21:VSZ@Bk_[/W_lG15Oooo`005?oooaBoaL43_lS41;o0_A^oaL44aLW91?oUfPBCQgH4B4e:0k^X
UPBoZi<4_jbA1<>IT0BjWXl4_k>F1<>PS@>lSGH4VG5M1;^RT@Bo/J44_jfN1;nXV@>o/J44_jBI1<6R
SPBiUh44^iJ21;>?MPBcRg03XhEZ1:n2K0B`PF/4[geW19QYGPB4ETP3XX1Y1;RDO0BeSW84[XI/1:B0
JPB/QG04VW1O0c`h<PBc/jd4^[^i9ko5`AGoool001CooolD_lG10ko8a0Bo`;dK_lG11<G9b@CoiMX4
ThMf14Q=BP>kZ9H4_j^C1;n/T@C3VI04^Yj?1;ncUPC3X8d3_8ef19UaG@BkXY44_k6Q1;n]WPBoZ9T3
_k6Q1;nTV@C1XXh4^IN11;^FPPBcSgH4/h]`0j>5JPB_PV`4/85[1:mmI`BHJEh4Q5I80j:0J@BhU7`4
]Hib1:j6K0BTP6X4[8E`19Y`G`<l>384/k>]1;Zk^BNoaL4Eoooo000Doooo5;o5`@>ob<@4_l2m6ko5
`@C5bLT4onGJ19>7MPA8CDX3^jRF1;n[T`Bo[944`iV@1;ZNS`Bo/iH4`j2=0kb=MPBILEd4^j:A1;na
X@Bo[Ih4_jRI0knaX@BoY9T4`J:>1;VGP@BkUX84/hmf1;>;L0>SQFX4[h9/1;21J`B_OFL4V6UN18AF
B0>RP6T4^9Al1;F>LPB^QV`4Y81Z1:b5L0BJL5l3?3Pb1;>c[@Bj^kTW_lG15Oooo`005?oooaBoaL43
_lS41;o0_A^oaL44aLW91?oUfPBCQgH4B4e:0k^XUPBoZi<4_jbA1<>IT0BjWXl4_k>F1<>PS@>lSGH4
VG5M1;^RT@Bo/J44_jfN1;nXV@>o/J44_jBI1<6RSPBiUh44^iJ21;>?MPBcRg03XhEZ1:n2K0B`PF/4
[geW19QYGPB4ETP3XX1Y1;RDO0BeSW84[XI/1:B0JPB/QG04VW1O0c`h<PBc/jd4^[^i9ko5`AGoool0
01Cooolf_lG11<[6/@B_ZZX4`kJT1;bQSP>eXH`4^jZD1;nVU0Bo/i`4_j2I1;n]W0C5/9T3^YV01:Uf
H`B]SGP4^jNF1;ndY0Bo[Ih3_jZK1;njXPC1WXd4^8ef1;R?MPB_S6l4Zh=/0iilG`BQLE`4XGQL1:5c
G0BTNE`4WgY_0jB3JPBcSGT4/hQ^1:YnJPBSPFH4Yh9[16i4=@<g?cX4XYnO:ko5`AGoool001Cooolf
_lG11<[6/@B_ZZX4`kJT1;bQSP>eXH`4^jZD1;nVU0Bo/i`4_j2I1;n]W0C5/9T3^YV01:UfH`B]SGP4
^jNF1;ndY0Bo[Ih3_jZK1;njXPC1WXd4^8ef1;R?MPB_S6l4Zh=/0iilG`BQLE`4XGQL1:5cG0BTNE`4
WgY_0jB3JPBcSGT4/hQ^1:YnJPBSPFH4Yh9[16i4=@<g?cX4XYnO:ko5`AGoool001Cooolf_lG11<[6
/@B_ZZX4`kJT1;bQSP>eXH`4^jZD1;nVU0Bo/i`4_j2I1;n]W0C5/9T3^YV01:UfH`B]SGP4^jNF1;nd
Y0Bo[Ih3_jZK1;njXPC1WXd4^8ef1;R?MPB_S6l4Zh=/0iilG`BQLE`4XGQL1:5cG0BTNE`4WgY_0jB3
JPBcSGT4/hQ^1:YnJPBSPFH4Yh9[16i4=@<g?cX4XYnO:ko5`AGoool001Cooolf_lG11<[6/@B_ZZX4
`kJT1;bQSP>eXH`4^jZD1;nVU0Bo/i`4_j2I1;n]W0C5/9T3^YV01:UfH`B]SGP4^jNF1;ndY0Bo[Ih3
_jZK1;njXPC1WXd4^8ef1;R?MPB_S6l4Zh=/0iilG`BQLE`4XGQL1:5cG0BTNE`4WgY_0jB3JPBcSGT4
/hQ^1:YnJPBSPFH4Yh9[16i4=@<g?cX4XYnO:ko5`AGoool001Cooolb_lG11;k0_@Bk`KP4_ZF;1;VG
O@BeXID3[Z6C1;ZTT@Bo[IX4_k2P1;n]WPBo]:@4`jVN0l2OS@BjSgL4ZWa[1;JKQ`Bo[Yl4_jRJ0kjM
SPBk[9T4`:F;1;REO@B_MV44[h=]1:YjH0>KMel4X7QO1:5gG0BSNUX4X71F19agH0>]R784/HYc1;>5
KPBVOFP4YWi[1:N7K`A;:bL35B<Q1:6OY2^oaL4Eoooo000Doooo<[o5`@Bn`;d4^l6h1;jUR`BiUgd4
]J6E0jjQT`BjY944_jfJ1;n`X0Bo[Ih4_kBT1<>YWP?0Whd4^Xmg1:YlJ`BfVhL4_jjO1;nXVP>nWHh4
^jbI1<2UR`BhUGd4[gIQ1:n3K@BZNV03VgMO1:1hG`BQMe`4XgYJ1:1`EPBLMf03[HQb1;6:L`BcQFh4
YWeX1:InJ`BWQfl4Bb/W0aDS8@BQWj@[_lG15Oooo`005?oooc:oaL44_/2m1;_1^0BnYH/4^IMm1;FQ
U@>^XI<4^ZBA1;n]VPBo/:04_jfN1;ndY0C3ZIh3`9n=1;Z?M`BZO6/4]Y^71;n^W`BoZ9X3_Yf>1;^/
V@C0YH/4^9Em1:mfH@B_Pfd4ZWYP0i]gG`BPN5l4XGML1:=jFPBPL5H4W7MP0jf8LPBaRW<4/hE^1:Im
J0BVOV/4YhM_14/[9`<E8b44XInT:ko5`AGoool001Cooolb_lG11;k0_@Bk`KP4_ZF;1;VGO@BeXID3
[Z6C1;ZTT@Bo[IX4_k2P1;n]WPBo]:@4`jVN0l2OS@BjSgL4ZWa[1;JKQ`Bo[Yl4_jRJ0kjMSPBk[9T4
`:F;1;REO@B_MV44[h=]1:YjH0>KMel4X7QO1:5gG0BSNUX4X71F19agH0>]R784/HYc1;>5KPBVOFP4
YWi[1:N7K`A;:bL35B<Q1:6OY2^oaL4Eoooo000Doooo<[o5`@C3`;44^[>Z1<2SS0BfU7h4]i1c0jJK
U@BoWXl4_jZK3;naX@Bo^Z83`j:A1;nMP@B_PVX4/Xek1;nZV`Bo^ZH3`j6I1;ZVUPC5[9T4]YF01;RB
N@B[NVH4ZWiU0j1^FPBPM5d4WWQW1:]oIPBZQ6l4XgmZ0k69LPBaQg04[hI`1:UoJ@BVOVH4Xh9[16Hg
:0<X8b44Gf1K1;o1_RNoaL4Eoooo000Doooo<[o5`@C3`;44^[>Z1<2SS0BfU7h4]i1c0jJKU@BoWXl4
_jZK3;naX@Bo^Z83`j:A1;nMP@B_PVX4/Xek1;nZV`Bo^ZH3`j6I1;ZVUPC5[9T4]YF01;RBN@B[NVH4
ZWiU0j1^FPBPM5d4WWQW1:]oIPBZQ6l4XgmZ0k69LPBaQg04[hI`1:UoJ@BVOVH4Xh9[16Hg:0<X8b44
Gf1K1;o1_RNoaL4Eoooo000Doooo<[o5`@C3`;44^[>Z1<2SS0BfU7h4]i1c0jJKU@BoWXl4_jZK3;na
X@Bo^Z83`j:A1;nMP@B_PVX4/Xek1;nZV`Bo^ZH3`j6I1;ZVUPC5[9T4]YF01;RBN@B[NVH4ZWiU0j1^
FPBPM5d4WWQW1:]oIPBZQ6l4XgmZ0k69LPBaQg04[hI`1:UoJ@BVOVH4Xh9[16Hg:0<X8b44Gf1K1;o1
_RNoaL4Eoooo000Doooo<[o5`@C3`;44^[>Z1<2SS0BfU7h4]i1c0jJKU@BoWXl4_jZK3;naX@Bo^Z83
`j:A1;nMP@B_PVX4/Xek1;nZV`Bo^ZH3`j6I1;ZVUPC5[9T4]YF01;RBN@B[NVH4ZWiU0j1^FPBPM5d4
WWQW1:]oIPBZQ6l4XgmZ0k69LPBaQg04[hI`1:UoJ@BVOVH4Xh9[16Hg:0<X8b44Gf1K1;o1_RNoaL4E
oooo000Doooo<[o5`@Boa[d4_ZR?1;V>KPB/SGT4[i210kZVT@BoWY44_jZK1;ncYPBo]:H4_k6Q1;na
Y0>o/9/4`j6:1;>EN0B/QW04^jFD1;n^V`>o[I/4_jfN1<6]V0BiTG`4/HYc1:Z4KPB^QVl3YG]M1:=b
F@BNMV84YH=b1:j8M`BfSgX3]IEn1:b;M@RZQW04YX1]1:N:LPCMV6X3JSh]13TX8PAjNgTW_lG15Ooo
o`005?oooc:oaL44_lJm1;jXS`BiSVh4[8ei1:n@P@>jYY44_ijA1;nZV`Bo/jH4_kBV1;naX@Bo/J@3
_k2K1<>QRPBcUGP4[8I`1;^UU0Bo[Y/3_jfK1;n]WPC1[IP4^I5l1;6:L`BZQ6h4[XI_0jEkG@BSLUT4
WWIR1:F3LPB^R7L4]Xmj0kFEOPB/RgD8ZXI`1:J0K@BWRW84gIQZ0fXn;@@i:284NW]i9ko5`AGoool0
01Cooolb_lG11;o6_@BnZ8l4^Hi^1:b=N@B_T843^ZJA1;nNT@BoZY/4_k>V1;ndYPBo/J44_k6T0kn`
V`C3XHX4/iEh1:b6L0BkYI@4_jjK0kn]V`Bo[Ih4`JfH1;VAO0BaRW<4ZXA^1:j6K`>UNed4Xg9I19if
HPBUPg84[XQg1;J?NP>eUGh4[8]e2:Z6L0BVP6d4YhYb1=fHJP=Z?Rd4>BPR17YkNBNoaL4Eoooo000D
oooo;[o5`@Bo^k04_:>A1;E_F`BgR7@4Ug=S1:ZZT@>oWY44_jZE1;nZV`Bo[Y`4_kFY2;naX@>nZ9L4
`JfD1;NNR`BdVX<4^ZJ>1;jRT@>kWh/4_jFE1<2LQPBjT7D4ZWiX1:QjI0BSOUl3Wg5J19icF@BON6H4
Y8I`1;2=O0BkUX03]Heg1:b:L`B_Qg04ZHAZ1:N0J0BWPVl4]91j0kj;K@BZPW<4GV5O9ko5`AGoool0
01Coool^_lG11;nk/0BlXi44]FmK1;N8M0BGLf<4ZZZA0knNT@BoZYD4_jZK1;n^W0Bo]JT8_k6Q0kjX
U`C1[I@4]ij;1;BJP`BjYXh4_Z:A0k^OR`BoYID4`9b61;Z@M@BZOVP4Z7YT1:=nG`>OLEX4WW=I19mh
IPBTQW04/8el1;^FP0>eSGL4[8Yc1:n7L0BYQ6X4Yh1X1:N2K`BdT7X3_X]]1:Z2L`ANHElW_lG15Ooo
o`005?ooobjoaL44_k^`1;bST@BeKe/4]hQd19McH`BZZY43_ijA1;nZU@BoZY/4_jjL1;neZ@Ro/J43
_ZRG1<6]U0BgWX/4]9Z31;ZVSPBnXY43^in;1;nUU@C0W8H4^Y1e1:YnJ0BXNV@4XgiO0imaFPBNLeT4
WgQV1:B6L0B`SG`4^iJ00kF=M`B/RW<4[hM`1:V4JPBWP6P4Yh9_1;B@NP>nRfd4ZX9c15iQGbNoaL4E
oooo000Doooo;[o5`@Bo^k04_:>A1;E_F`BgR7@4Ug=S1:ZZT@>oWY44_jZE1;nZV`Bo[Y`4_kFY2;na
X@>nZ9L4`JfD1;NNR`BdVX<4^ZJ>1;jRT@>kWh/4_jFE1<2LQPBjT7D4ZWiX1:QjI0BSOUl3Wg5J19ic
F@BON6H4Y8I`1;2=O0BkUX03]Heg1:b:L`B_Qg04ZHAZ1:N0J0BWPVl4]91j0kj;K@BZPW<4GV5O9ko5
`AGoool001Coool^_lG11;nj]PC3Th<4]WEQ1:IXG0BYPFl4YZ2A0kn]W@Bo[IX4_jZK2;naX@Bo[Yl4
_jjK0l6[U`BjY8d4_9j91;JTT@Bo[Id4`kJQ0kZNT`Bo[I84`iV91;><L@BXNF<4XWEO19Q_G0>XNf04
VGaY1:=oK0B]T7/4/9=n1;^FP0>eSgT4[8Ub1:b0KPB_OW04YX1Y1:UoK`B/PfD3XgQS19U[EPC3b<@W
_lG15Oooo`005?ooobjoaL44_kZf1<>CP`BfMF44YVQL1:V1K`BVX943_jfM1;n]VPBoZY/8_k6Q1;n^
W`Bo[Y/3`J^G1;ZTS@BlWXT4]ZBA1;n]W@C3]Z43^YjC1;n]TPC3VHT4/haa1:QiH`BRMEl4V6mL0jQk
H0BIO6T4Xgm/1:f@N`B`Tgh4^iJ00kF?N@B/RG84[81^1:mnL0BVP6T4ZGm_1:b3I@>SN6<4VF]F1<?8
a2NoaL4Eoooo000Doooo;[o5`@Bo^[H4`i>31;IeH@BVJ5`4ZH5_1:JPT@>o[Id4_jfJ1;nZV`Ro/J44
_jjO1;n^V`?1ZiL4^ZB=1;bNR@BfY944_jfM1<>fX@>jWY<4_jfB1<>IR@BcS744Z7US1:9eG`BHKe`3
Z7]P19UlJ@BSOf`4[I1k1;2COPBkUX03]Hmi1:b9LPB/P6h4[gi`1:J0J@BYOfl4[8=U0j=hH`BIJeH4
`lS49ko5`AGoool001Coool^_lG11;nj]PC3Th<4]WEQ1:IXG0BYPFl4YZ2A0kn]W@Bo[IX4_jZK2;na
X@Bo[Yl4_jjK0l6[U`BjY8d4_9j91;JTT@Bo[Id4`kJQ0kZNT`Bo[I84`iV91;><L@BXNF<4XWEO19Q_
G0>XNf04VGaY1:=oK0B]T7/4/9=n1;^FP0>eSgT4[8Ub1:b0KPB_OW04YX1Y1:UoK`B/PfD3XgQS19U[
EPC3b<@W_lG15Oooo`005?ooob^oaL43_kjd1;o3[`C3W8D4]7aP1:A_G`BQQgH4^ZJA0knZV`Bo]:@4
_jZK1;n/W0BnZIH4^jbF1;nRU@?1X8h4]Ij71;jHP`BfXH`4_jRF1;n^W0>oZY/4_jJL1<>BO@BfR704
Yg]U1:=hHPBMNF@3VWaU19mnJ0BYRgH4]95l1;>DOPBhT7X3]Heg1:b5KPB/P6P4ZWeX1:Z0JPBTPFd4
/i1m0jEjI0BEKU`4]KJc9ko5`AGoool001Coool[_lG10knn]0Bo`jl4`ib51;AlH0BTKel4XHMf1;ZV
T@>oZY/4_kBT1;nZV`Bo[9`4_ZVF1;^/UPBoXYD3`J2>1;FNQ`BnV8<4]Z6<1;nXUPBo[Y`3_jZK1;nV
W0C3TWd4]XQ`1:MkI@BSN684WGUT0iYlI@BOOVP4ZH]f1;BAO0BcU7h4^91j0kF=M`B/QFh4[81X1:Ym
J0BZP6X4Y85]1;>@O@>UNV@4UFiL1;Ff/bNoaL4Eoooo000Doooo:ko5`@>o_[@4_l>_1<>LQ@BdO604
Y6mO1:67MPBjYY43_jZK1;ndY0BoZY/4_jbL1;jYUPBk[9H4_j:E0l6PSPBeWXL4_YR31;JQS0BoZ9H4
_jjL0knZV`BoYY`4`i9m1;J8L0BWNfD4XgQR19eiI0>JO6D4WgiX1:V;MPBdTG`4/iAn1;R@NP>eSGL4
[8E^1:b0J0BZOFP4ZX1Z1:B1K@BcT7d3YGYT19E^G0Be][<W_lG15Oooo`005?ooob^oaL43_kjd1;o3
[`C3W8D4]7aP1:A_G`BQQgH4^ZJA0knZV`Bo]:@4_jZK1;n/W0BnZIH4^jbF1;nRU@?1X8h4]Ij71;jH
P`BfXH`4_jRF1;n^W0>oZY/4_jJL1<>BO@BfR704Yg]U1:=hHPBMNF@3VWaU19mnJ0BYRgH4]95l1;>D
OPBhT7X3]Heg1:b5KPB/P6P4ZWeX1:Z0JPBTPFd4/i1m0jEjI0BEKU`4]KJc9ko5`AGoool001Coool[
_lG10kbcWPB`QF`4V6Y?19AXD`BBLV04Yhel1;nZU@>oZ9T4_jbL1;n^V`BoZ984`JRE1;FLR@BiXXP3
^YB91;VPS@BiWhX4]Z291;nZV`BoZYL3_jZK1;j`V@C0W8P4]XA]1:MkI@BPMV44YGQS0ienJ`BUQG04
[H]h1:n>N0BhUh44/iEn0kF<MPB/SgP4ZXE_1:YoJ@BVNV/4Y89_1:QbE0>YMf@4ZGAI19YnMBNoaL4E
oooo000Doooo:ko5`@>l/ih4/8E/19QZC`BDJ5<4TW9P1:N=O0BoZYD3_jRI1;n/W0Bo[Y/4_jRB1<6X
U@BeW8T4^J:80kZDR@BiX8d4^In:1;JPR@BoZY/4_jZG0knZV`Bn/9T4`9b81;J4K@BWNfD4X7IQ1:Eh
H`>MOV/4YHE`1:f;N0B_SWP4^9N11;>EOP>eS7H4[8mh1:Z5K`BZOfT4YWY[1:B2K`BXLU@3ZGMT1:Ud
F@BJOWDW_lG15Oooo`005?ooob^oaL43_;>N1;25K0BHJTl4U6QC199bH0BWSG`4_jZE0knXV@Bo[9`4
_jjK1;nXTPC1Z9D4]Ib91;VRR0>jU8T4^J2=1;VORPBfX8T4_jZK1;nZU`>oZY/4_[2I1<2LR0BfQ6d4
Yg]U1:1fH@BUN6<3WGi[1:F5L0B]RgP4[hih1;RGP@BcUGh3]Haf1:b?N0BZQFl4ZWmY1:IjJ`BTPVl4
Z79D0jUgI0BYM5T4VWie9ko5`AGoool001Coool[_lG10kbcWPB`QF`4V6Y?19AXD`BBLV04Yhel1;nZ
U@>oZ9T4_jbL1;n^V`BoZ984`JRE1;FLR@BiXXP3^YB91;VPS@BiWhX4]Z291;nZV`BoZYL3_jZK1;j`
V@C0W8P4]XA]1:MkI@BPMV44YGQS0ienJ`BUQG04[H]h1:n>N0BhUh44/iEn0kF<MPB/SgP4ZXE_1:Yo
J@BVNV/4Y89_1:QbE0>YMf@4ZGAI19YnMBNoaL4Eoooo000Doooo:ko5`@?1Z8d4PTPZ17]=?@AN?C@4
HEMA1:fEQPBoZYL3_jZH1;nZU@BoZY/4_jfL1<>YV@Bm[i/4`9j@0k>@OPBbQgL4/IN21;FOR@BkZ984
_jZK0knZV0C1Y9<4^IR01;1mKPBTMf04WW9K19]fHP>WPFd4XhA/1:f6L`B_RgT4/HIa1:f<MP>_RW<4
YhE_1:Z7L0BVPV`4YWeZ1:=jJ@BYR6D3UV581:MoJPBJGD/W_lG15Oooo`005?ooob^oaL43`JR=1898
:PAkCCd4GSdd165GD@B]UHH4_jZG0knZV0BoZYD4_jZK1;n]W0C3ZIT4_JnK1<2NT0>cT7h4/XMg1;6G
PPBeWhT4^jRB1;nZV`>oZYP4`JBC1;VHP0B`OFh4Y7MP19ibF`BKMV83Yh5]1:>4K0B]QW<4[h]i1;66
L@B]S7H3[hYc1:N5K`BZQg04YX9/1:ImJPBSNVT4ZHQU0iIQB0BWOfX4VUe;9ko5`AGoool001Coool[
_lG10l6XS@B2B2X4Nddm15hm=0AQEe44[IF61;nZU`>oZYP4_jZE1;nZV`Bo[I`4`jVI1;f_V`C0WY03
/i1n1;:7M`BaUh84]In91;^XTPBoZY/3_jZH1<6TT`BiV804/7e^1:AgH0BNLU/4VgIR0jN1K@BSQ6`4
[HIc1:n;N@BaQW44[Haf0jn:L`BWQFl4ZXM`1:J2K0BVOFX4XgYY1:V8I@>FHDP4YgmZ19YMBbNoaL4E
oooo000Doooo9ko5`@Bo`;X3aknc1<QiG0AT?Bd4Hche13U1A@B]UH44_ZRB0k^XV@BoZYL4^ij41;2E
O`BZQFd4XGeW1:B3L@>UNVl4ZWi_1:EnJ@B`SWX4/Yj:1;nZV`>oZYh4`JVD1;fCO`B_PV84X71J1:5f
G@BELUd3W7IS19f0J`BQOf/4YH]d1:n;MPBYQG03[haf1:V6L0BVQ6h4YX9/1:ImJPBVOVh4Vf=:0h96
;`B=HTP4UUU69ko5`AGoool001CooolW_lG11;o0^P?7_k<4b7UL16@m;@AS?SD4>D551:fEP@BnZ983
^jRI1;nZU`BkWX@4/9Eo1:Z5K@BQOFL4Y8=a0jEjK`BZOVl4YGiY1;2>NPBbWXX4_jZK0knZWPC1ZI@4
_I=o1:n2HPBPL5X4XGIM19EbG@>LMV<4WH1[1:5oJ`BURg@4[h]f1:V5L0>_S7H4ZHI`1:J4KPBVPV`4
YWeZ1:InKPBKHdX3PTH_18eRB0BFFDHW_lG15Oooo`005?ooobNoaL44_l2j0lNo/`C8NE`4I3d]16<n
=@@i@DD4[IF11;jXTP>kZ9T4_jZG1;^NQ0B`UGl4ZXE]1:5mI`BTPg43YGY_1:YnK`BUOVT4/8ij1;:N
RPBoZY/3_jZN1<6YU0BmTgl4[h9R1:1`FPBQMUd4UG9M0iafH`BMP6/4XGm[1:F;M0B_RgH4ZHE`0jn<
MPBYQW04YXA^1:J2K0BVOFX4YWi^19]SBP>2ARl4SF9819IIARNoaL4Eoooo000Doooo9ko5`@Bo`;X3
aknc1<QiG0AT?Bd4Hche13U1A@B]UH44_ZRB0k^XV@BoZYL4^ij41;2EO`BZQFd4XGeW1:B3L@>UNVl4
ZWi_1:EnJ@B`SWX4/Yj:1;nZV`>oZYh4`JVD1;fCO`B_PV84X71J1:5fG@BELUd3W7IS19f0J`BQOf/4
YH]d1:n;MPBYQG03[haf1:V6L0BVQ6h4YX9/1:ImJPBVOVh4Vf=:0h96;`B=HTP4UUU69ko5`AGoool0
01CooolW_lG11;jiZP?0Z9D4FAlD14@U7@A2;BD49c]01;2GP`BoZ943^ZB<1;nZV0C9/9H4[HYb19ej
H@AdF4/4Fd8h0fA6<@AjEdT4T58k18Y:=@BBLV84^jFD0knZV`C1[IP4_IIo1:n0I@BNO5`4VfiC19Ii
I@>YPVh4Z8Qc1:62K@BVO6/4YX=_19f2KP>/RW@4[XUb1::0JPBLP6X4Wh1Z1:J0KPBZL5<3QThh17e;
?0BACSHW_lG15Oooo`005?ooobNoaL44_[VZ0l2XU@AI7a@4A2DM148]9@@W>d04/9N31;nXT@>jY8`4
_jZH1<V`UPB]RW84WGYQ17AHB`AK@SP3I4Ha17YGB@B@DS/4RTXe199bHPBkYI@3_jZK1<6]V0BmUWl4
[h1U19ilG0BKKU<4UWUU0jV2KPBXR7<4XH9]1:IlJ`BVPfl4WH9^0jb:M0B^RG84XX1Z19b0JPBOP6X4
YX1^1:Y`D`>6CSP4OD/l195>=RNoaL4Eoooo000Doooo9ko5`@Bn^JX3`:RE15TO50A49Ad4@RdU12Lk
@0B`Uh<4_jRA0kZTS0BoZYP4bK2F1:f:LPBMNV44M5Q;15]2>0=TAS44NUM9191B>`B:BSD4TW9R1;^U
U0>oZY/4`JfH1;fFO`B_P6D4WWaL19]^D`BFNFD3ZH9^1:R8L`BQPVd4YWa[1:J3K`BMPVh3[8Yd1:j9
LPBRP6X4W81Z19n0JPBVP6h4ZW1C0hI>>0AmBc`4TDhf9ko5`AGoool001CooolW_lG11;jiZP?0Z9D4
FAlD14@U7@A2;BD49c]01;2GP`BoZ943^ZB<1;nZV0C9/9H4[HYb19ejH@AdF4/4Fd8h0fA6<@AjEdT4
T58k18Y:=@BBLV84^jFD0knZV`C1[IP4_IIo1:n0I@BNO5`4VfiC19IiI@>YPVh4Z8Qc1:62K@BVO6/4
YX=_19f2KP>/RW@4[XUb1::0JPBLP6X4Wh1Z1:J0KPBZL5<3QThh17e;?0BACSHW_lG15Oooo`005?oo
ob>oaL44_lK31<K7^@>mTWL4X5a=13`R6`A09Ql44R/e1;ZRS@BiYi03^jB?1;nZU0C3/9`4bZB;1;FE
P`BCIE04D2lV0dH]8PAA@CT4O61<19=^G0B7HUL4]Z:=0knbY@C1/j84_I^11:UgH0BHJE04NB`H17=A
A0>ILE84V6mF18UPB@BAL5X4XWYX19=lI0>WQFd4ZXM`1:QnI`BJNVH4UWYZ1:9jI@BEGTX3OeI2185N
D0BDC3/4`lS48ko5`AGoool001CooolS_lG11;o6``C6akT3_I9g1:1LC@@l8Q/4@2HO118[=@BjXXd4
^JN@0k^TS`BoZY@4`k2L1<ZTR`BeUH<4TfE@150_9P=6;B84DD4i17aPC0BCKU`4Qf9G1;JRS@>o/ZD4
`K>R1;fKP@BYMf04V6U@17T/60AcDD@3VG5B19Q_EPB9H4T4TG1J1:9jJ0BCO6@3YhE]1:Z7L0BXOVL4
VWYV19IjJPBRNVD4UEi:0gmF@PB1GU04U4`k1<?8a2>oaL4Eoooo000Doooo8ko5`@Boa/<4a/Ni0kfB
M`BPG4d4?28K140V7`@B:cD4^Z:=1;VWT0>kY8l4_jZD1<>`W0C:Y8/4]IF319=UD0A@;bH3ARdR1551
>@AlH4`4TfiL18MRE`BfXXd3_k:U1<6cXPBmVh44ZGMP19QYD0Ai;1P4Le540iUaDPBHKeH4RF19195`
FPBRNVP4TgaT0jN5K@BZQg04Z7iW19YjIPBFNVX4XWYU19ENBP=oET84PEi@19A<>`C3b<@S_lG15Ooo
o`005?ooob>oaL44_lK31<K7^@>mTWL4X5a=13`R6`A09Ql44R/e1;ZRS@BiYi03^jB?1;nZU0C3/9`4
bZB;1;FEP`BCIE04D2lV0dH]8PAA@CT4O61<19=^G0B7HUL4]Z:=0knbY@C1/j84_I^11:UgH0BHJE04
NB`H17=AA0>ILE84V6mF18UPB@BAL5X4XWYX19=lI0>WQFd4ZXM`1:QnI`BJNVH4UWYZ1:9jI@BEGTX3
OeI2185ND0BDC3/4`lS48ko5`AGoool001Coool4_l2l1;o1_PBo`kl4_l6n4ko5`@AT:al4NGYb0l2J
PPB[ITh4B2hb13<Q6`@=8Rd4]J6<1;nZU0>iY8h4^ZF?1;^XTPC9]Z84[I9j1=bSR0B]RG43QfM@17iJ
@`AfKed4TG=P1:Z4LPBfX8`3_jjL1<6bX@BmW884]GmQ19U[EPBTK4h4IdM00g9HC`@X4A04FSld161:
?PAL?B`4JEE90hAPA@BAKE<4YGiW19YjI@BFOFH4Wg=M17Y=>0=O?c<4KEi@19URD@C8c<TS_lG15Ooo
o`005?ooo`Bo`;`4_l6n1;o3_`Bo`KhC_lG116@[7`AiNW83`9Z21:]VCPA8;S84<b4K10dR;@BeXH`4
_jZD0kVTSPBjYHl4^jRB1<VfXPB]TWX4g:>81:f9L@>7Ie04OUY317I_G@BALf04ZXAb1;JPS0>o[Y`4
`K:Q1;fLPPBeOf44VF]F1:A/CPAWAd03LUQ?12PA40AJ?c@4H4Xn15`m;0AYEDT3Q615195]D`BUOVL4
VWYU19ImIPBOLed4NTdh0elo<`A]GU04VF9A1<S<bB>oaL4Eoooo000Doooo1;o0_0Bo`Kh4_l>o1;o1
_Q>oaL44I2/O17UjLP?0VX84ZfI>14P^<P@c8A/43B8]1;FQS0BoZY@3^JB>1;ZUS`BkZ984bKJR1:fB
NPCLXhP4[HUa0hMWD0AnFT<4MVmM195cH0BZQ784]Z2<0kn^W0C1/Z44_Ib21;EoH@BIJeH4Y6a>16M7
@0=bF4l4:14@15Xo=0APBSh4G3d/16UEB@>4H4D4TFeC1:EnI`BJNVD4UWeV19mcG@AjCCP3Gclc16eN
D0BIHU44b<c98ko5`AGoool001Coool4_l2l1;o1_PBo`kl4_l6n4ko5`@AT:al4NGYb0l2JPPB[ITh4
B2hb13<Q6`@=8Rd4]J6<1;nZU0>iY8h4^ZF?1;^XTPC9]Z84[I9j1=bSR0B]RG43QfM@17iJ@`AfKed4
TG=P1:Z4LPBfX8`3_jjL1<6bX@BmW884]GmQ19U[EPBTK4h4IdM00g9HC`@X4A04FSld161:?PAL?B`4
JEE90hAPA@BAKE<4YGiW19YjI@BFOFH4Wg=M17Y=>0=O?c<4KEi@19URD@C8c<TS_lG15Oooo`005?oo
o`Bo_[/4_kfj1;o8a0Bo`;d?_lG116dn<`AW@3@4:@/60f<l<0AB;S84?2HM13dX8P@58B`4^JB>1;JT
T@>nU844[hUf1:jHQ@C3/:<4`KFS1<>RT@BbRWD3]I1k1:J2K0BMO6H4ZHme1;B?O0BfW8P3_k6Q1<6/
W@BmWXP4[hIY1:AkFPBPN5X4Wg1I0j]lI@A29b@4;R@L15Tk=0AE?C@4Cd<f0gmSDPB3KUT4YWIL19ej
IPBFP6P4PTi0168o;P=D=BL4CT4f19QNB@C4bLHS_lG15Oooo`005?ooo`Bo_[/4_kfj1;o8a0Bo`;d?
_lG116dn<`AW@3@4:@/60f<l<0AB;S84?2HM13dX8P@58B`4^JB>1;JTT@>nU844[hUf1:jHQ@C3/:<4
`KFS1<>RT@BbRWD3]I1k1:J2K0BMO6H4ZHme1;B?O0BfW8P3_k6Q1<6/W@BmWXP4[hIY1:AkFPBPN5X4
Wg1I0j]lI@A29b@4;R@L15Tk=0AE?C@4Cd<f0gmSDPB3KUT4YWIL19ejIPBFP6P4PTi0168o;P=D=BL4
CT4f19QNB@C4bLHS_lG15Oooo`005?ooo`Bo_[/4_kfj1;o8a0Bo`;d?_lG116dn<`AW@3@4:@/60f<l
<0AB;S84?2HM13dX8P@58B`4^JB>1;JTT@>nU844[hUf1:jHQ@C3/:<4`KFS1<>RT@BbRWD3]I1k1:J2
K0BMO6H4ZHme1;B?O0BfW8P3_k6Q1<6/W@BmWXP4[hIY1:AkFPBPN5X4Wg1I0j]lI@A29b@4;R@L15Tk
=0AE?C@4Cd<f0gmSDPB3KUT4YWIL19ejIPBFP6P4PTi0168o;P=D=BL4CT4f19QNB@C4bLHS_lG15Ooo
o`005?ooo`Bo_[/4_kfj1;o8a0Bo`;d?_lG116dn<`AW@3@4:@/60f<l<0AB;S84?2HM13dX8P@58B`4
^JB>1;JTT@>nU844[hUf1:jHQ@C3/:<4`KFS1<>RT@BbRWD3]I1k1:J2K0BMO6H4ZHme1;B?O0BfW8P3
_k6Q1<6/W@BmWXP4[hIY1:AkFPBPN5X4Wg1I0j]lI@A29b@4;R@L15Tk=0AE?C@4Cd<f0gmSDPB3KUT4
YWIL19ejIPBFP6P4PTi0168o;P=D=BL4CT4f19QNB@C4bLHS_lG15Oooo`005?ooo`Bo`l04_l2m5ko5
`@B8CT04CS<V14X/8`<j9R44;QPF13`V8@A09b044RLa1;ZQS0BiXHT3akbX1;JBP@BJKeL4WWMR19al
I0B>KE/4PEI60gYA?@B2Fd@4R5M319EhI0BaUX<4]Yf90kn/V@C1[I@4_IJ21:n9L@BSLEL4VWeJ19]h
F`>/RW84h9em17MXF`B0FD@4R5a816MLD0><KeD4UG9M1:>6JPBXP6T4VWeY17a==@A9:b<3Cc<V14hl
;PB9>RPW_lG15Oooo`005?ooo`Bo`l04_l2m5ko5`@B8CT04CS<V14X/8`<j9R44;QPF13`V8@A09b04
4RLa1;ZQS0BiXHT3akbX1;JBP@BJKeL4WWMR19alI0B>KE/4PEI60gYA?@B2Fd@4R5M319EhI0BaUX<4
]Yf90kn/V@C1[I@4_IJ21:n9L@BSLEL4VWeJ19]hF`>/RW84h9em17MXF`B0FD@4R5a816MLD0><KeD4
UG9M1:>6JPBXP6T4VWeY17a==@A9:b<3Cc<V14hl;PB9>RPW_lG15Oooo`005?ooo`Bo`l04_l2m5ko5
`@B8CT04CS<V14X/8`<j9R44;QPF13`V8@A09b044RLa1;ZQS0BiXHT3akbX1;JBP@BJKeL4WWMR19al
I0B>KE/4PEI60gYA?@B2Fd@4R5M319EhI0BaUX<4]Yf90kn/V@C1[I@4_IJ21:n9L@BSLEL4VWeJ19]h
F`>/RW84h9em17MXF`B0FD@4R5a816MLD0><KeD4UG9M1:>6JPBXP6T4VWeY17a==@A9:b<3Cc<V14hl
;PB9>RPW_lG15Oooo`005?oooanoaL44TeU013XL50@c8a/3=b4J13`T70@[7aX4A3H`12@e>PB^V8@4
`jJA0kZVT@C:]ZP4b;>M1:R2L0BMMVX4VWe]1:1gHP>>K5/4RVQC195dH@B?Kf84[iZ91;ZVU0>oXYL4
`JFB1;fIPPB_QGD4Se@o1899=@B4JTl3Wh5S1:J4J0B^R704/HY_19ajI0B;Led3WWaY1:ImIPBJNVT4
Wh5V19mfG0A<<BD4<b<K0dM=A@A_BSL4MR`K9ko5`AGoool001CooolO_lG119=I@0@j71@4<b<K0cLQ
6P@l91`4:alJ14@f<0@T=CX4[YR41<>VT@>jYY44b[JX1<RcW@BXPW04WGIZ19YmK@BPMf83SVaK18YX
D`BAM644SfmR1:nJR@BjYY@3_j:G1<6UTPBmVH84[hEe18mD?`B2BCD4Q6Y?0in1H`BVQ6P4[XQ`1;6:
K`BLNV@4Rg=M0iilJ@BVOFH4VWYY19n1IPBOMU`4C34U13<S6`=7CDD4KdXg17H/6bNoaL4Eoooo000D
oooo7ko5`@BCFD04>Q`D13<S6`<g8AX4?2@L12/O6PA4=S0493Dj1:jHQ0C3YY43^ZJA1<ZfZ0C8/id4
Z89`19efJPBJOFd4X7MR0hi/F`B:J5<4TGAQ18m_HPB_VXT4^ZJD0knRU`C1YI84_IV21:n5M@B?E3l4
PTTe18AZC`>OPF<4YXAX1:j8L0BaRVl4W7YT18]cG@>NO6T4YWeV19YjJ@BOPFH4WgIL14`a9@@c8a/3
Ade516m:=`Af;1/W_lG15Oooo`005?oooanoaL44TeU013XL50@c8a/3=b4J13`T70@[7aX4A3H`12@e
>PB^V8@4`jJA0kZVT@C:]ZP4b;>M1:R2L0BMMVX4VWe]1:1gHP>>K5/4RVQC195dH@B?Kf84[iZ91;ZV
U0>oXYL4`JFB1;fIPPB_QGD4Se@o1899=@B4JTl3Wh5S1:J4J0B^R704/HY_19ajI0B;Led3WWaY1:Im
IPBJNVT4Wh5V19mfG0A<<BD4<b<K0dM=A@A_BSL4MR`K9ko5`AGoool001Coool8_lG11;o3_`Bo`Kh?
_lG11:=`E`A87aH4>20I0blQ6`@O3`h4<b0J13hb;0@hA484V8Id1;^QS0>oZYD4_jfN1<>bYPC9`:/4
c:bK19jNU@C0[:03]Z6B1;Z[V`BUUHD4/Y>01;JVT@BnZiL3^ZjE1;jLS@BoX8T4^::61<2DP@B7DdL4
GCH/0eHi:@AeFdT4UGQS1:Z4K0B/QVP4VWeX0jAlH`BBLe`4WgQZ19ejJ@B2CST4D2`Q13ha:P</>C44
Sdlf15L^90AmPh0S_lG15Oooo`005?ooo`RoaL44_l>o1;o1_PnoaL44Xg1G14PO5P@h81T3;b4K11l?
3P@c81X4?S8/13Q4@PBHQW@4^j6<0knZU@Bo[Ih4`k:V1<W0Z`C<[9/4WYjE1<2/X0>fXI84^Z^K1:FE
Q@BbTh04]ZJA1;j[U`>j[YD4_Yb=1;nPR@BhXXH4`9B118MCA`AM=R`3ESTY17EKB@BEN6<4ZXA/1:b6
J0BJOFP3Y7aS199cG0BON6X4WGYY189>>@A@;244?S4Z0b`i<@B?CcH4EbhT17f3P2>oaL4Eoooo000D
oooo2;o5`@Bo`kl4_l6n3ko5`@BSL5L4B1lF13PP6@<_8A/47`l>13<P6P@n<R`4>4A219R6M0BkXH`3
_jZE1;n]WPC3/ZH4bL2[1<b/V`BNWYD4`:bP0kJQTPBjZi/4YIF51;:CP0BfYY44_Z^G0kZ^U@BnW8d4
_j291;RRQPC0U844Qe=715df;0=F>BT4ME]919EhH`BZQ6`4[8IX19YmJ0>TO6<4TW=L19mhJPBMNVT4
PThi150/8@@n<BX3;3Ta18m?=PAG;R@4OH>08ko5`AGoool001Coool8_lG11;o3_`Bo`Kh?_lG11:=`
E`A87aH4>20I0blQ6`@O3`h4<b0J13hb;0@hA484V8Id1;^QS0>oZYD4_jfN1<>bYPC9`:/4c:bK19jN
U@C0[:03]Z6B1;Z[V`BUUHD4/Y>01;JVT@BnZiL3^ZjE1;jLS@BoX8T4^::61<2DP@B7DdL4GCH/0eHi
:@AeFdT4UGQS1:Z4K0B/QVP4VWeX0jAlH`BBLe`4WgQZ19ejJ@B2CST4D2`Q13ha:P</>C44Sdlf15L^
90AmPh0S_lG15Oooo`005?ooo`RoaL44_lS41;o0_@noaL44SViR14dd:`@i8Q/3=b4K12dM5@@^7aT4
@38/1459A@B<NV/4]Yf90knZU@BoZY/4_k6Q1;ncYPRo]Z/4_kBV0kncYPBo]:H4_kBW1<>`V`BjY8`4
`k6M0kbTS@BiWXL4_9j81;NMQ`BoXHd4cJJ?1:aoL`>;HU<4DCT/158d9PA[BS`4LUM717iLA@=lFdD4
Ug5R19=gH`BTNFD4KCX]140U7@@h9B@3<a/D15hZ70A^@SL49RLU8ko5`AGoool001Coool8_lG11;o8
a0Bo`;d?_lG118i^HPA==2/4>B8K0cLQ6`@]7AD4;QlI140b;0A1BDD4S7Y[1;JMR@>oZYD4_jZK1;na
X@Bo/jH8_kJ[1;ndYP>o/jH4_kBV1;ndY`C3/9/4^ZB<1<>aW@>lY8d4^Ij71;bNR0BgWHL4_j6=1<fV
S`B/Og<3Rf9C154i;0AB=2H4JdXl179GA`AnG4D3O5]519MaHPBCMf<4Y7UU16dj;@A09Ad4>2DT0c<K
50AN:Q`4KT8g12HW9B>oaL4Eoooo000Doooo2;o5`@Bob<@4_l2m3ko5`@B>KV84CC@[13TR6`<g8A/4
;AdE12hO6@A0<R`4@DU518ajJ`BfWHT3_jZE1;nZV`Bo/J44_k>V2;nfZ`Bo]:H3_k>V1;ndYPBo]:L4
`k2K1;ZTS0C3/Id3_:B=1;VNQ`BlWXP4]if71;nQS@C=YXl4[7mc0h]RD`AA>B`4DS@V16]:?0AbEdL4
OUa50gaKA@BGLF84TgMS1:AiI@A]>Rd4@2DM13PU90<c6a@4GRXL16i2=`@V9bDS_lG15Oooo`005?oo
o`RoaL44_lS41;o0_@noaL44SViR14dd:`@i8Q/3=b4K12dM5@@^7aT4@38/1459A@B<NV/4]Yf90knZ
U@BoZY/4_k6Q1;ncYPRo]Z/4_kBV0kncYPBo]:H4_kBW1<>`V`BjY8`4`k6M0kbTS@BiWXL4_9j81;NM
Q`BoXHd4cJJ?1:aoL`>;HU<4DCT/158d9PA[BS`4LUM717iLA@=lFdD4Ug5R19=gH`BTNFD4KCX]140U
7@@h9B@3<a/D15hZ70A^@SL49RLU8ko5`AGoool001CooolO_lG11:=hJ`AMA3`4>2HN0cDQ6`@h8Q/4
=bHT148c;PA5B444PVmO1:jGQ0>oZY84_jRF1;n^W`Bo[Y`4_kFX1;nh[PBo^k<3_k>V1;ni[PBo/J44
_kBW1;n]V@BoZY@3`JZB1;VQRPBiUh44^I^61;VMR0BoVHH4/iZ30l6BNPBYQFl4SfmJ175HA@B0Ed@4
NfMF0iAcH0AnIEP4WgQZ19YgH0A/>Rd4>b<L130Q6P<Z7AD4=bDO15Hj<`@[;2XS_lG15Oooo`005?oo
oanoaL44XgQ[15e4?0@h9Qh3=B4K13PR6`@g9R@4@S<^14E8@@B2Kel4[YN40knZTPBoZ9H4_jjO1;n^
W0Bo]JP4_kR^1;nk/`>o/jH4_kV^1;naX@Bo]:L4_jfI1;nZU0?1ZY84^J6:1;VGP@BiVhH4^If81;nI
QPBcVX<3`I9j1:V5K`B?KeX4LEQ5181GA0AkIeH3U7=P17iUF0BON6X4VWMP16`j;@@k8a`4<24J0bXM
5@@g9Al4ESXc12//:R>oaL4Eoooo000Doooo7ko5`@BSN6/4GD@l13PV7P<e8A/4>28K13LV90A2<bh4
ADQ1189_G`B^Uh@3_jZB1;nXUPBo[Yl4_jjL1;neZ0Bo^:h4_k^c0kncYPBo^Jh4_k6Q1;ndY`Bo[IT4
_jZD0l6ZTPBiXHX4^IN11;VKQPBiWHP4_iV61;>JP`?1TWX4ZHE_18m_FPAaF4D4P5M417]WEP>DLf04
OVEH19mhJPBJMf04K3X]13/S70@`8AX3:QdE13LU7`AF>S<4:b`Z8ko5`AGoool001CooolO_lG11:=h
J`AMA3`4>2HN0cDQ6`@h8Q/4=bHT148c;PA5B444PVmO1:jGQ0>oZY84_jRF1;n^W`Bo[Y`4_kFX1;nh
[PBo^k<3_k>V1;ni[PBo/J44_kBW1;n]V@BoZY@3`JZB1;VQRPBiUh44^I^61;VMR0BoVHH4/iZ30l6B
NPBYQFl4SfmJ175HA@B0Ed@4NfMF0iAcH0AnIEP4WgQZ19YgH0A/>Rd4>b<L130Q6P<Z7AD4=bDO15Hj
<`@[;2XS_lG15Oooo`005?oooanoaL44X6eD15<g:0A@=2/3=R8K13XL50@o9Ql4AC0U14Xo=`AZHE@4
WhQf0k^XTPBoZYD4_jZK1;ncYPBo/J44_kFX1knh[PBo^Jh4_k6Q1;n^V`Bo[Yl4_jRD0l6TS0BiVhH4
^J6:1;VGP@BiVh84^iB01;N@NP>cSgT4/8Qa1:b:M@BZRG<4WWiY195dH@>SMfH4X85Y1:IcH`B>GTD4
HSHZ13/S70A09b03<b8K130P6PA1;B<4=cHa1:RWYAnoaL4Eoooo000Doooo7ko5`@BPKE@4DcLX150d
:`<f8Q/4>Q`D13lV7`A5<2D4BSlg16YQE0BOR7H3^jRB1;nZU@BoZY/4_k>V1;naX@Bo]JP7_kR^1;ni
[PBo/J44_jjK1;n^W`BoZ9@3`JB<1;VKQPBiXHX4^IN11;VKPPBkU804]i1j0k>?N@B`R744[8Ye1:Z9
L`BNOVT4TGAQ0j=gIPBPPFT4YW=S18iNA@AR=RX4>b<L140W80<c8Q/4<20J144]8`@g=S44Z:NU7ko5
`AGoool001CooolO_lG11:1]E0AC=bP4D3@[0cHR6`@j71@4?bHO14D`9@A:?cL4JV5D19n8MP>kZ984
_jZE1;nZV`Bo/jH4_k6Q1;neZ0No^:h4_kV^1;naX@Bo[Y/4_jjO1;nXU0?1Y8`4^I^61;VQRPBiUh44
^I^21;^DP0BgT7X3/hmi1;28L@B/RWD4ZXUc19inJ@BAM643XgMV1:21J@BVLf<4SUi5168f:P@k8a`4
@2LP0c<R6`@`81X4@BdS13Lf<@BXYjDO_lG15Oooo`005?oooanoaL44SV=;15M0>0A:<RT3ABXS12`M
5@@c81T4=B4J14Pc:0ADAcH4Qg9Q0kJQS0BoZYD4_jZK1;n`X@Bo^k<4_k6Q1;neZ0No]JT4_k6Q1;na
X0BoZY84_ZRC0kjTS@BiUh44^IR21;VKQ0BiUh44^iJ01;6?N@>aRW@4[hmj1:J6L0B/Qg04ZHA^1::2
K0>LOFH4W7eZ19McG0AXACP4=b4G13/W9P@[71/3;A`D11h>3P@d8ah4@3/d17U/JQnoaL4Eoooo000D
oooo7ko5`@B>Hd/4Ed0h14Xb:@=5:R<4;1dE13<P6@@e8AX4B3<X15A7=PB7LV43]Z6<1;nZU@BoZY/4
_k2Q1;nk/`Bo/J44_kFX1kneZ@Bo/J44_k6P1;nZTPBnZ9<3_ZB=1;VGP@BiV884^I^41;VGP@BkUX04
/Hmi0k6:M0B_SgX4YXI`1:b7L0BYQ6h4XX9/0iamIPBLOFX4Ug=L16Q5>0@g8AL4>bLV12/L6`<]71@4
7Ph>13@S7PA0>c@4NFaZ7ko5`AGoool001CooolO_lG118iSB`AG@3P4BS8Y0dDZ8`@/7AD4<b0I13DQ
6PA8<bP4E4Lf18MbH@>fXH`4_jZE1;nZV`Bo/:44_k^c1;naX@Bo]JP7_kFY1;naX@Bo/J04_jZB1;jX
T`>nY8d4^IN11;VHPPBiVh@4^IN11;^FP0BaSgT3/HYd1:n?NPBVQW04[8M`1:V4KPBRPV`3W7eV19am
JPBGLe`4J4Dh13LQ5`@k9bH4:a`K0bdL50@N3Ph4=2<N140k=0AiK6XO_lG15Oooo`005?oooanoaL44
SV=;15M0>0A:<RT3ABXS12`M5@@c81T4=B4J14Pc:0ADAcH4Qg9Q0kJQS0BoZYD4_jZK1;n`X@Bo^k<4
_k6Q1;neZ0No]JT4_k6Q1;naX0BoZY84_ZRC0kjTS@BiUh44^IR21;VKQ0BiUh44^iJ01;6?N@>aRW@4
[hmj1:J6L0B/Qg04ZHA^1::2K0>LOFH4W7eZ19McG0AXACP4=b4G13/W9P@[71/3;A`D11h>3P@d8ah4
@3/d17U/JQnoaL4Eoooo000Doooo7ko5`@BSKeH4D3T`15@o=`=5<2T4AbXR13DQ6P@o;2D4@cPc15=4
>`ANEdX3[Y=o1;nXTPBoZ9T4_j^J1;neZ0Bo^k<4_k>V0kni[PRo/J44_k6T1;jXU0BnZ907^I^41;VG
P@BhUh44]9An1;RDOPBeSgT3[8Yd1:b8LPB_SgT4YXI`1:Z4KPBXPV`3WGeX1:1iH`B:Gd`4GC@X14Ta
:@@U5A@4;1`K0ah>3P@Y6aX4;1hI13hk>0AKDD`O_lG15Oooo`005?oooanoaL44XfmF150i<0AD?cL3
AC0Y14LZ8P@e8AX4?b`U14<h<`ACA3/4GUM:0jjCO`BoZ984_jRI1;n[VPBo]JP4_k^c1;ncYP>o^Jh8
_k6Q1;naY0BnZ9@4_ZR@1kVKQ0BiUh44^9N11;BDOPBhU7h4]Hmi0jb:M0B/R784[hmi1:J6L0BZQ6h4
Z89/0iemJ0BPNF<4RUm<15dd:0A9<BT49ADD12`L6`<N3Ph4:A/J12`N6@@n>cP4Fe5<7ko5`AGoool0
01CooolO_lG11:=_EPA@>C04E3lg0dD`:@A7:R84=B4J13l/9@A3>3<4Dd@k15iGBP>^Tgl4_jRB1;nX
V@BoZiX4_kFX1;nk/`Bo/jH3_kV^2;naX@Bo/J@4_ZRD1;jXT0NiVh@4^IN11;RGP@BdU7h4^9An1;F?
N@>/RW@4[8Qb1:n?N@BVQW04ZXA^1:R2K0>MOFP4X7US18YOC0AM=2P4BC4Y12DE50@/71/37Ph>12TK
6P@/7QT4?S/h15]AC1noaL4Eoooo000Doooo7ko5`@BSKeH4D3T`15@o=`=5<2T4AbXR13DQ6P@o;2D4
@cPc15=4>`ANEdX3[Y=o1;nXTPBoZ9T4_j^J1;neZ0Bo^k<4_k>V0kni[PRo/J44_k6T1;jXU0BnZ907
^I^41;VGP@BhUh44]9An1;RDOPBeSgT3[8Yd1:b8LPB_SgT4YXI`1:Z4KPBXPV`3WGeX1:1iH`B:Gd`4
GC@X14Ta:@@U5A@4;1`K0ah>3P@Y6aX4;1hI13hk>0AKDD`O_lG15Oooo`005?oooanoaL44UgQ/15U1
>@AD@CX3E3lg14D[8`@_7AD4>BDO14`e:@AQBc`4GUA40i]mJ`BkXHX4_jZH1;nXV@BoZiX4_kFX1;nh
[P>o^k<4_kBV2;naX@C3[Id4_:N?0kRMQPBdU7h4]I5o1;^AOPBcT7X4/h]i1;F=N@>/RW@4[8M`1:Z5
K`BZQg04Y7aU1:UnJ0>JMEl4TVID17Q:=`AD;bH4;A`D12hM70@S51@3:Q`D12LJ6@@h9B04:S4a17im
NQnoaL4Eoooo000Doooo7ko5`@BGN6`4FD4i15A1>P=D?cL4AB/S12lM5@@i9Al4C3DY165;?0ANE4@3
Vge[1;^QRPBoZYP4_jRI1;n[VPBo]JP4_kR^0knk/`Bo]:H8_k6Q1<>]W@BlYhl3^9f61;BDOPBeTGl4
^i5n1;>@NPBcRgT4]Hei0jb:M0B/Qg04ZXE_1:Z7L0BTO6D4ZGiX0iYeG`BBIU@4N4Xg15@_9P@]71@4
;QdL12<D50<Z71@49aXI13PU80@Z<C44OWej7ko5`AGoool001CooolO_lG119MhK0AI@CT4E44j0e@o
=`A5:b<4;adE13TU7`A<=BT4HD/l15iDA0>KOF/4^j6:1;nZV0BoZ9T4_j^J1;neZ0Bo^:h3_k^c1;nd
YPRo/J44`jfM1;bWS`>hWHH4]9An1;FAO`BkTGh4/i1j1;>;N@BeSGT3[8Yd1:b7L0BZQFl4ZXM`1:Al
I@BYOVP3VWEO199VE0AhBSL4E2lV12dL50@^7A`48a@D0bXL50@W6QT4>2DP12Xa<@AnOGXO_lG15Ooo
o`005?oooanoaL44UgQ/15U1>@AD@CX3E3lg14D[8`@_7AD4>BDO14`e:@AQBc`4GUA40i]mJ`BkXHX4
_jZH1;nXV@BoZiX4_kFX1;nh[P>o^k<4_kBV2;naX@C3[Id4_:N?0kRMQPBdU7h4]I5o1;^AOPBcT7X4
/h]i1;F=N@>/RW@4[8M`1:Z5K`BZQg04Y7aU1:UnJ0>JMEl4TVID17Q:=`AD;bH4;A`D12hM70@S51@3
:Q`D12LJ6@@h9B04:S4a17imNQnoaL4Eoooo000Doooo5ko5`@Bo`kl4_[jj18i[GPA??3D4Dd4j0e8n
=P@n9Qh4ABhW13//9@A1<B/4ETHi175NCP>BKeh4/YZ71;nZU@Ro[Ih4_k2Q1knh[PBo^Jh4_k6Q1;j^
VPBkYI84`JB<0kbKQ0BgVH@4/i=j1;R@OPBcSgT4/Hef1;6<N@>ZPg04YhA`1:Z4KPBVQ6h4ZHA]19ij
I@>MM5d4UfI=16M1;`A<;2<4=R<L12lQ6P@`8Q/3:A/D12hQ6@@g9B040@001<?8a1noaL4Eoooo000D
oooo5ko5`@Bo`kl4_[jj18i[GPA??3D4Dd4j0e8n=P@n9Qh4ABhW13//9@A1<B/4ETHi175NCP>BKeh4
/YZ71;nZU@Ro[Ih4_k2Q1knh[PBo^Jh4_k6Q1;j^VPBkYI84`JB<0kbKQ0BgVH@4/i=j1;R@OPBcSgT4
/Hef1;6<N@>ZPg04YhA`1:Z4KPBVQ6h4ZHA]19ijI@>MM5d4UfI=16M1;`A<;2<4=R<L12lQ6P@`8Q/3
:A/D12hQ6@@g9B040@001<?8a1noaL4Eoooo000Doooo5ko5`@Bo`kl4_[jj18i[GPA??3D4Dd4j0e8n
=P@n9Qh4ABhW13//9@A1<B/4ETHi175NCP>BKeh4/YZ71;nZU@Ro[Ih4_k2Q1knh[PBo^Jh4_k6Q1;j^
VPBkYI84`JB<0kbKQ0BgVH@4/i=j1;R@OPBcSgT4/Hef1;6<N@>ZPg04YhA`1:Z4KPBVQ6h4ZHA]19ij
I@>MM5d4UfI=16M1;`A<;2<4=R<L12lQ6P@`8Q/3:A/D12hQ6@@g9B040@001<?8a1noaL4Eoooo000D
oooo5ko5`@Bo`kl4_[jj18i[GPA??3D4Dd4j0e8n=P@n9Qh4ABhW13//9@A1<B/4ETHi175NCP>BKeh4
/YZ71;nZU@Ro[Ih4_k2Q1knh[PBo^Jh4_k6Q1;j^VPBkYI84`JB<0kbKQ0BgVH@4/i=j1;R@OPBcSgT4
/Hef1;6<N@>ZPg04YhA`1:Z4KPBVQ6h4ZHA]19ijI@>MM5d4UfI=16M1;`A<;2<4=R<L12lQ6P@`8Q/3
:A/D12hQ6@@g9B040@001<?8a1noaL4Eoooo000Doooo5ko5`@Bob<@4`lK318EQD`AD>bh4D3/c0eE2
>`AG@3P4@BhW14Hd;0A:=2L4C4M016]E@`>2IUH4Z8aj1;^XTPBoZ9T4_jjO1;n^W0No/Z@4_k>V1;jY
UPBnZI@4]J6<1;jSR`>hU7X4]95i1;RDNPBcT7T4/i=l1;F:M0B/SGL3[h]b1:V0KPBVP6X4YWiX1::0
JPBMMEl3SfQ@16m6>PAF<2H4=B@L12dL50@Y6aX491DD0aP>3P@Q4a<4@3<^118;2PC4bLHO_lG15Ooo
o`005?oooaNoaL44_lS41<?6``B5HE<4E3/^150k<`=E@S/4Ed0h144^9`A6=2`4BS@W14a7@0A[ED<3
PVIF1:R<NPBkZ984_jRI1;n^W`Bo[Y`7_k:T1;ncYPBnZIH4_ZVD1;FQS0BnXh/3^9Aj1;BAN@BhU7X4
/i1i1;>CO0BeRW@4[8eg0jn;LPBYP6h4YX1Z1:InJ0BRP6X4WGEO0hmXD0A_ASX4ES0V13DT70@]71@4
:A/J12@E50<H3Ph48A<C140c;P@B2`X4a<W67ko5`AGoool001CooolG_lG11;o8a0C3a/<4QF5C15@k
;PA@>c<3ED8k15M0>0A1;RL4AS@/14Xd9`A<Ad04JeE30h9VEPBXS7X4^jRB1;nXV@Bo[Yl4_jjL1knb
Y0Bo/jH4_ZVF1;jYU0BeXH`4_Z>;0kRDNPBdTGT4^9Aj1;>@N@BcTg`4]HYd1:b=M`>_Rg84ZH1^1:J0
JPBVOVP4XX1Z19eeG`>?J504KdHj15H`9P@e91`4;A`D12TK6P@T5A@360h>124C4`A0<bh44P/:1<C9
aQnoaL4Eoooo000Doooo7ko5`@BUNF`4CCHY15Lo=P=C@3T4CST`14L[90A9<RH4CCXc1511=`APASP3
IeE719]kJ`BfY8`4_jZE1;nXUPBo[9T7_jbF1;n^W0C3[Id4_:N?1;VHPPBhUgl3^8ij1;>;MPBcSW`4
/i1h1;>:L`BeRgD7[8M`1:j4KPBVPV`4Y7US19mcG@B?Idl3KdLk160m:`A19Qd4=28K13DR6`@[71X4
9ADD0b@D50@f91l49CPl16eTHR>oaL4Eoooo000Doooo7ko5`@BUNF`4CCHY15Lo=P=C@3T4CST`14L[
90A9<RH4CCXc1511=`APASP3IeE719]kJ`BfY8`4_jZE1;nXUPBo[9T7_jbF1;n^W0C3[Id4_:N?1;VH
PPBhUgl3^8ij1;>;MPBcSW`4/i1h1;>:L`BeRgD7[8M`1:j4KPBVPV`4Y7US19mcG@B?Idl3KdLk160m
:`A19Qd4=28K13DR6`@[71X49ADD0b@D50@f91l49CPl16eTHR>oaL4Eoooo000Doooo7ko5`@BUNF`4
CCHY15Lo=P=C@3T4CST`14L[90A9<RH4CCXc1511=`APASP3IeE719]kJ`BfY8`4_jZE1;nXUPBo[9T7
_jbF1;n^W0C3[Id4_:N?1;VHPPBhUgl3^8ij1;>;MPBcSW`4/i1h1;>:L`BeRgD7[8M`1:j4KPBVPV`4
Y7US19mcG@B?Idl3KdLk160m:`A19Qd4=28K13DR6`@[71X49ADD0b@D50@f91l49CPl16eTHR>oaL4E
oooo000Doooo7ko5`@BUNF`4CCHY15Lo=P=C@3T4CST`14L[90A9<RH4CCXc1511=`APASP3IeE719]k
J`BfY8`4_jZE1;nXUPBo[9T7_jbF1;n^W0C3[Id4_:N?1;VHPPBhUgl3^8ij1;>;MPBcSW`4/i1h1;>:
L`BeRgD7[8M`1:j4KPBVPV`4Y7US19mcG@B?Idl3KdLk160m:`A19Qd4=28K13DR6`@[71X49ADD0b@D
50@f91l49CPl16eTHR>oaL4Eoooo000Doooo7ko5`@BhWY44Fd<k14di<@=G@CX4EST[14/g;PA1;BL4
C3P`14Hd;@AA@c/3ETPm17mRD0BZU7h4^ZF?1;^XS`BoZYP4_jZD0kjXT@BjYH`4^jRF1<6VSPBhU7`4
^9Aj0k69L0B]R744[HQe1:n;M@BaS7D4/H9/1:b3L0>ZPFh4ZXAZ1:AnI@BRNF<4Vg1I17]??@=S?R/4
?RDM130N5@@[6aX4<R4K12dL6`@O3Ph38Q@C13<S7P@20@44a<W68ko5`AGoool001CooolO_lG11;RN
T@AK@c/4CCTa0eM1>PAF>B/4BcL^144]9`A<>304AS@]1553>`=FB3d4Of9@1:ZDOPBjYHl4^jR?1;nZ
V0BoZY@3_ZRA1;ZUS0BkZ9H4`JJ>1;RDO0BhU7X3/HU`1:f8L@B]R7D4[h]e1;6<M@BaPV`4[8=`0jZ1
KPBZQ6X4Y7iU1:9iH`BKL5T4Ndlm0f<n:`@n9Ad4<1hE12/K6P@b8A/4;A`K11l>3P<R51<4<b<N1081
0@C4bLHS_lG15Oooo`005?oooanoaL44^9jA15]3>`A=>C43Ed4j15Hi:`A;=bh4@BdW14`h<0A6=2d4
DD<k0eI8?@AoHU04ZYAn1;ZUS`BkZ8l4_jZH1;nZU0>nZ944^ZF<1;^XUPC1YXh4^9Al1;RDNP>aRG04
[HQa1:f8M@B_RgD4/Hae1;62K0B/Pg03ZX5^1:Z4JPBTOVD4XWUS19]`F@AkCcd3Hch[13hU7@@`7QD4
:a/J138Q6`@]71/47`h>0b8D4`@c8ah40P411<C9aR>oaL4Eoooo000Doooo7ko5`@BhWY44Fd<k14di
<@=G@CX4EST[14/g;PA1;BL4C3P`14Hd;@AA@c/3ETPm17mRD0BZU7h4^ZF?1;^XS`BoZYP4_jZD0kjX
T@BjYH`4^jRF1<6VSPBhU7`4^9Aj0k69L0B]R744[HQe1:n;M@BaS7D4/H9/1:b3L0>ZPFh4ZXAZ1:An
I@BRNF<4Vg1I17]??@=S?R/4?RDM130N5@@[6aX4<R4K12dL6`@O3Ph38Q@C13<S7P@20@44a<W68ko5
`AGoool001CooolO_lG11;:HP`AWCT@4E44j0ddl=0AC?SL4@RXX14<_:0A3<R/4Dd0i14de:0=:=b`4
He5418]`G0B]SgT4/YN21;ZPRPBjXhd3_ZRA1;VQR`BeW8H4_:B<1;JAN@B]PVl3/HY`1:anJ0B/PVd4
Z8E_1;67L0BZP6X4Yh1X0jQgI0BON6@4VWQO18eSC0B9GDH4Id8^0d4U7@@e91`4;1`D12@D4`@R51@4
6@h>11L>3P<e8ah4@2XO10h712NoaL4Eoooo000Doooo7ko5`@BbV8<4Idi415A1>P==?3@4Dchg148Z
:0A3;bP4@c8[15=0>@A==BP3BSL/16=AA0B;L5`4[Hmi1;:GPPBjX8X4^Z>=0kjXT@BiXH/4]Ib61;bT
S0BfTGT4[H9_0k6:L0B/OVP4[89]1:R5K`BaQg04ZX1Z1:N0J0>XMf@4WgQT19YhG`B=Hd`4REe616M2
;P=19Ad4=B@L12`L50@T51<48Q@D11T>3P@G3Ph3=B<N140Z7`@>1`@W_lG15Oooo`005?oooanoaL44
/YR316M>A0AD@CX3CC`d15<n=`A2:RP4@blX14<b:`AC@3T4CCDX0dXg;0ASDD@4Rg1L1:f?N@BbUh84
^Z2:1;ZSS@>nZ944^J6;1;FLQPBlY8`4]Y5i1:f2K`>aRW04[7iX1:b2K@BXQFl4/HM`1:Z0JPBWP6P3
Z7MT19mhI0BJN5l4SF=<18UMAPAW@Rh3@BDM13DT70@/71@491@C128D50@I3Ph45`h>0cDS7PA0:Ql4
3PL49ko5`AGoool001CooolO_lG11;:HP`AWCT@4E44j0ddl=0AC?SL4@RXX14<_:0A3<R/4Dd0i14de
:0=:=b`4He5418]`G0B]SgT4/YN21;ZPRPBjXhd3_ZRA1;VQR`BeW8H4_:B<1;JAN@B]PVl3/HY`1:an
J0B/PVd4Z8E_1;67L0BZP6X4Yh1X0jQgI0BON6@4VWQO18eSC0B9GDH4Id8^0d4U7@@e91`4;1`D12@D
4`@R51@46@h>11L>3P<e8ah4@2XO10h712NoaL4Eoooo000Doooo7ko5`@CPf=d4N5I=15M2>`=B?SH4
ETDn15Lk:`A3:284C3/e14Pe;@AC@S/3A30X14Tn=@AOC3h4Nei<19UhIPB]RW<4Zh]j0jnDP`B_UX44
/9F01;B@N0BRNf84UFeG0iaaE`BTO6D4YgYV1:MfG`BWNFD4ZX1Q1:AiH0>RMEl4VfeG19E]E`AoED<4
Ic/[15D^9@<n91`4;1`D12DE50@T51@47Ph>11P>3P@Q51<3:QdH14M@DPAKDD/W_lG15Oooo`005?oo
oanoaL44h=SM17QFC@AG@S/3DShf15I5?PAG>b/4@bPR14`k=@A8=Bd4Dd8k0d@`:0A9?SD4Gd`n17]N
C0BIN6H4[HYc1:^;NP>_U8<4[iJ11;2EP0BdT7P4XW]R19E]E`>LLEL4Y7aU1:MjIPBWMUl4YgUU1:Z0
H@BTNF03XWEO19]]E`BEKEL4OeE316Lk:`AE;RD3?R@L12`L50@U5A@491@D11h>3P@H3Ph48A@C0bXM
60A7D584Fe5;9ko5`AGoool001CooolO_lG11>3Hg@AhETd4Ed8k0e8n=PAFACh4Ec/[14<X8PA<>cD4
B3D]15=2>`=4<2P4BChe15m<?PAkGT`4VGQV1:f:L`B[RgX3[iB31:nFP@B`UH04]91h1:9kHPBEKEL3
W75G1:AlI@BWNVH4YgIO1:MiI@BZP644Y7UP0j9eG`BKKEL4UFeG17mE@`AW>b/4EBhU0chT70@/71@4
9ADD12@D50@N3Ph460h>124D4`<Z7AP4Ae1B15]ABbNoaL4Eoooo000Doooo7ko5`@CPf=d4N5I=15M2
>`=B?SH4ETDn15Lk:`A3:284C3/e14Pe;@AC@S/3A30X14Tn=@AOC3h4Nei<19UhIPB]RW<4Zh]j0jnD
P`B_UX44/9F01;B@N0BRNf84UFeG0iaaE`BTO6D4YgYV1:MfG`BWNFD4ZX1Q1:AiH0>RMEl4VfeG19E]
E`AoED<4Ic/[15D^9@<n91`4;1`D12DE50@T51@47Ph>11P>3P@Q51<3:QdH14M@DPAKDD/W_lG15Ooo
o`005?oooanoaL44d]cD1:>7M0AB>S43Cc`e14`j<`A9>S84@B/X14@_90AC?CD4DT8k0ea6?PA7=c44
ETHo15U:?`A/CC`4PF5D17IMCP>0HDd4SFiL18mbG0B?JeT4RV5:17QC?@=iFD44R5]319AXC`BJLeP4
WFUB195SCPBAHDL3TfE?18UQD0AkCcl4KCl]15@/90@o91`3;A`D12HE50@N3Ph45`h=11L>3P@G3Pd4
:1lI0cPU7`@01PH4^[^i9ko5`AGoool001CooolO_lG11=;Le0BSQg@4DSXa0dll=@A<>S<4BCXb144[
:0A4;b@4Dcde1592>`=LASh4AcLa15I6?`AIBSl4K4dl185QE0AfGDh3P65=18e^G0B?LU`4Sf]I18YQ
BPAhDcd3NEU118QK@`BDJ4l4VW=H19eYDPBAHdh4TF570i=UC`B9HE04Ndlo16do;@AD;2@4?b@L0bdL
50@V5A@47Ph>11L>3@@G3Ph45`h=12PO6@<h9Al400H61;Zk^BNoaL4Eoooo000Doooo7ko5`@CBg=@4
XhMd158j<@=??3D4C3Xc14Tj<PA1:bP4A2lT15<m=@AB@S/3G4Hn14Lg<@AFASl4FDXo16a=?0B1HE@4
MUe>0h1QC@B=KU`4Sg9L18m[F@B:HDX4N5<m0gUI@@B8Fd<4U6Q?19YcF0BMJE84TF=>195QA`>CIDl4
RF5@17]??`A]?bd4E2`T13lT70<]71@49QDD11h>3P@G3Pd45`h>11L>3@@X7aT3>2DO10061PBj^kTW
_lG15Oooo`005?oooanoaL44d]cD1:>7M0AB>S43Cc`e14`j<`A9>S84@B/X14@_90AC?CD4DT8k0ea6
?PA7=c44ETHo15U:?`A/CC`4PF5D17IMCP>0HDd4SFiL18mbG0B?JeT4RV5:17QC?@=iFD44R5]319AX
C`BJLeP4WFUB195SCPBAHDL3TfE?18UQD0AkCcl4KCl]15@/90@o91`3;A`D12HE50@N3Ph45`h=11L>
3P@G3Pd4:1lI0cPU7`@01PH4^[^i9ko5`AGoool001CooolS_lG11<k1a`AWC4<3D3lh1511>PAB?CH4
=RDM13d`:`AD@SX4ETDn0f1?A`AQCdL4GTm3161CA`AQCd84HTDi160o<@=H?SH4Hclc171@@@A/Bcl4
GTDn16Q4=`=U@Bh4Id@c17=??PAiET44PEDm181I@`AcC3L3LThn17E8=`AV@S84CbdT14P_9`@`7AD3
:a`D12DE50@N3Ph45`h=11H>3@@_7aT49aXI0dM<B@@a:2H[_lG15Oooo`005?ooob>oaL44c/7716M<
@`=@?cP4D44j158m=P@f9Ad4?C0[15A2>PAFACh3H4m7165?A`ANCd<4H5=7165?@PARACT4H3la0ePn
=PAS?c<4L51116a;?`ANACh4J4@g0fE1;PAWA3<4Ldln17UF@@B1ECd4P5U317=<=`=bCSh4MDPg16I2
<PA?;B@4B2lW130M5@<[71@49ADD11h>3P@G3Pd45Ph=12lO6@@W6QT3Ada9134X9R^oaL4Eoooo000D
oooo8ko5`@C>`LL4Ida30e0o>0A@@CX4DSdf13HU7@@m<2/4E48j15I5?P=PCdL4HDm715i?@`APDdL4
HDm21695>@AP?c43F3hf16<o<`A`D444K4/o15i5?PAXA3L3ID4^16M4<`AcCch4NEI1185E?@B0FD<4
Ld`g0g9>?PAeB3L4IT8b14l]90A8;bL4<1dE0b/L50@U5A@47Ph>11L>3@@F3Pd4;alI12LJ6@=7C4T4
<BPV:ko5`AGoool001CooolS_lG11=gNfPB9I5`3D3`d154l=@A??CD4Eclh14Tk=@AB@S/4GTe50eM3
?0AF@c/4F3df16A2=@AR?c04ECle14La:P==>S44A2XS14dg<0AG?cH4BcL_14<Z8`=5;RP4ABXQ14DW
8@AA=BP4ECPY154f9`AA;2<3BbPQ14P[8`A8:R84>2DL12/K50@W5QD38a@D12@D50@H3Ph45`h=12lO
8`@_7aX4BCL`0a/`=0B?Qh<[_lG15Oooo`005?ooob>oaL44gMkJ18UTG0=@?3@4DC`e14lm=@AG?cP4
BC/e1592>`ANCDD3Ed<l15I3>`AH?CH4I48e168o<0AE?cD4Ac4Z0ddj<@A4:R<4CCL`15Lo=PA;=bl4
@bXS0dD^:0A5:R44ABLQ154e:0AE>2T4DCHW154/8`=;:244B2/S14PZ8P@h9A`4:a/D12LF5@<S51@4
91@D11P>3P@G3Pd4;alS12lO6PA9=c036c0d18n7Pb^oaL4Eoooo000Doooo8ko5`@CMg]X4RFAL0e0l
=0AA?3D4Ccde15Lo>0A9>cD4DT8k15i=A@=G@c`4ET<k15Pm=PAT@SD4HSl`15Do=@A7<BX3CCXa14@Z
8`A==c04Eclf14/g;`A3:R<3ABhX14DZ8@A59b44DCDX15Dh:@AA=RL4DB`S0d/X8@A8:b<4B2XR13PU
70@[6a@49aHE0b<D50@T51@460h>11L>3@@_7b<4;alJ14Tg<0<K<3@4ShN3:ko5`AGoool001CooolS
_lG11=gNfPB9I5`3D3`d154l=@A??CD4Eclh14Tk=@AB@S/4GTe50eM3?0AF@c/4F3df16A2=@AR?c04
ECle14La:P==>S44A2XS14dg<0AG?cH4BcL_14<Z8`=5;RP4ABXQ14DW8@AA=BP4ECPY154f9`AA;2<3
BbPQ14P[8`A8:R84>2DL12/K50@W5QD38a@D12@D50@H3Ph45`h=12lO8`@_7aX4BCL`0a/`=0B?Qh<[
_lG15Oooo`005?ooob>oaL44a/o71=;5a@=RB3l4Cc`d15=0>@A@?CD4EdQ114hi<0AD@cd3DC/b1590
>@AMCD04Ed<k15Hn=PAC?3<4CCP`0dll=@A6;B/4?S0Z14<Z8`A4:B84>R@L0c4Q6P@f8Q/4?RLP144V
80@j8a/4>28K13TS6`=09b04>R8K13LR6`@^71@4:Q`D12DE50<S51@85`h>124D4`@b9b84@BPS1454
A0=NHEl__lG15Oooo`005?ooob>oaL44a/o71=;5a@=RB3l4Cc`d15=0>@A@?CD4EdQ114hi<0AD@cd3
DC/b1590>@AMCD04Ed<k15Hn=PAC?3<4CCP`0dll=@A6;B/4?S0Z14<Z8`A4:B84>R@L0c4Q6P@f8Q/4
?RLP144V80@j8a/4>28K13TS6`=09b04>R8K13LR6`@^71@4:Q`D12DE50<S51@85`h>124D4`@b9b84
@BPS1454A0=NHEl__lG15Oooo`005?ooob>oaL44a/o71=;5a@=RB3l4Cc`d15=0>@A@?CD4EdQ114hi
<0AD@cd3DC/b1590>@AMCD04Ed<k15Hn=PAC?3<4CCP`0dll=@A6;B/4?S0Z14<Z8`A4:B84>R@L0c4Q
6P@f8Q/4?RLP144V80@j8a/4>28K13TS6`=09b04>R8K13LR6`@^71@4:Q`D12DE50<S51@85`h>124D
4`@b9b84@BPS1454A0=NHEl__lG15Oooo`005?ooob>oaL44a/o71=;5a@=RB3l4Cc`d15=0>@A@?CD4
EdQ114hi<0AD@cd3DC/b1590>@AMCD04Ed<k15Hn=PAC?3<4CCP`0dll=@A6;B/4?S0Z14<Z8`A4:B84
>R@L0c4Q6P@f8Q/4?RLP144V80@j8a/4>28K13TS6`=09b04>R8K13LR6`@^71@4:Q`D12DE50<S51@8
5`h>124D4`@b9b84@BPS1454A0=NHEl__lG15Oooo`005?ooobNoaL44e]?B0hYKDPAF@3T4Dd0i158n
=PA2=2`4G4Y215I8@0=IB404AcD]14li;@A><bT8BCH^13`[;P<l<R`4ABdZ13lV8@@i92P4<B8L138R
6`<[71@4;B4J12hQ6P@`8Q/4;A`D12@E50@Y6a@3<R0J12dL50@T5A@4:a/D12TK6P@U5A@35`h>12<D
50@/81X4>2XT13TU7`ACF5H4De=B<[o5`AGoool001CooolW_lG11=KCdP>:Fe84ET0i15=0>@AB?SH4
@S@/15a:@PAFB403FDQ014Le;@A?>Bd4CS<Y24Tf;P@l:bh3?38/14D]:P@o9R44>B@X134R70@b8Q/3
:a`D12dQ6P@^8AX4<28K12dL50@T5A@4:A/D0c8P6P@]71@491DD12/K50@Y6aX49ADD0aL>3P@S51@4
;20J13PZ90@i9Al4DeQF15=CDS:oaL4Eoooo000Doooo9ko5`@CFdm83RU]B15I0>@AC@3T4DShf148d
;0ALBT84ETQ00eU8@0A7=Bd4CcT]14hc:@Q9=Rh4?2/^0c`b;0A5;BX4?bHQ13TT:0@a8Q`4<R8K0b/L
50@]8AX4;R4J130R6`@]71@491DD12TK50<b81X4;A`D12@E50@[6a@4:A/J12DE50<G3Ph48a@D12`P
6P@h:R@4>BDO15=HEPACDe8b_lG15Oooo`005?ooobNoaL44e]?B0hYKDPAF@3T4Dd0i158n=PA2=2`4
G4Y215I8@0=IB404AcD]14li;@A><bT8BCH^13`[;P<l<R`4ABdZ13lV8@@i92P4<B8L138R6`<[71@4
;B4J12hQ6P@`8Q/4;A`D12@E50@Y6a@3<R0J12dL50@T5A@4:a/D12TK6P@U5A@35`h>12<D50@/81X4
>2XT13TU7`ACF5H4De=B<[o5`AGoool001CooolW_lG11<[EcP>fW9<4Fd0h15=1>PAB?SH4ET4j14Tn
=`AB@CX3DCXa14Ha:P@o;RL4?RDL148a:P@o:RP4@2XW0cDQ70@h8bL4:a`L12HE50@Z6a/4:A/K0bDE
50@X6QT491DD12TK6P@U5A@4:A/J12dP6P<X6aX49QDD11P>3P@F3@d45`h=11L>3P<X6QX49aXC128D
4`@_6Q<4CeEB151=BcJoaL4Eoooo000Doooo9ko5`@C:eLh3]YbC15]0>0AC@CX4DShf15I1>PA9?SL4
DT4j0e4j<@A6<BX4?bhW13hU70A2<BX4?bXX140Z9`<e8A`4>2<W12/L70@V5A@4:Q/K12TK6`<U5A@4
:1XI12@E50@Y6aX49ADD12TK6P@]81X3:1/J12HE50@H3Ph45Pd=11L>3@@G3Ph3:1XJ12LJ4`@R51<4
;aXC14mEDPA@CD/f_lG15Oooo`005?ooobNoaL44b]G>0kJLT`AK@3P4Dd4j158n=PAF@CX4BChg1591
>P=A>S44AS4Z13l^9`@n9A`4@S4Z13lZ:0A0:RL3=B4L13PS9`@[71`49QDD12XK6`@Y6a/39ADD12PJ
6@@T5A@4:A/J12DE50@Y6aX4;B0J0bPK6P@V5A@460h>11H=3@@G3Pd45`h>0bPJ6P@W6Q<48Q@C12lJ
4`A?EE84D4e;=[o5`AGoool001CooolW_lG11<[EcP>fW9<4Fd0h15=1>PAB?SH4ET4j14Tn=`AB@CX3
DCXa14Ha:P@o;RL4?RDL148a:P@o:RP4@2XW0cDQ70@h8bL4:a`L12HE50@Z6a/4:A/K0bDE50@X6QT4
91DD12TK6P@U5A@4:A/J12dP6P<X6aX49QDD11P>3P@F3@d45`h=11L>3P<X6QX49aXC128D4`@_6Q<4
CeEB151=BcJoaL4Eoooo000Doooo:ko5`@?]m_<4WHEj154k<PA??3D4CClh1552>`ADAcl3ET0m14H[
90A2;BH4=B@M138P6@@c8a`4=B8K0bLE5@@T51<4:a/K12XL6`@S51@4:1/J0bDE50@W6QT49ADD13PT
7`@J3`h49QTI12dP6`<[71/460h>11L>3P@L3Pd49aXI12PK6P<V6QT4>bHQ14Xc9PAEBSd49Q`C1;Zk
^CJoaL4Eoooo000Doooo:ko5`@?]m_<4WHEj154k<PA??3D4CClh1552>`ADAcl3ET0m14H[90A2;BH4
=B@M138P6@@c8a`4=B8K0bLE5@@T51<4:a/K12XL6`@S51@4:1/J0bDE50@W6QT49ADD13PT7`@J3`h4
9QTI12dP6`<[71/460h>11L>3P@L3Pd49aXI12PK6P<V6QT4>bHQ14Xc9PAEBSd49Q`C1;Zk^CJoaL4E
oooo000Doooo:ko5`@?]m_<4WHEj154k<PA??3D4CClh1552>`ADAcl3ET0m14H[90A2;BH4=B@M138P
6@@c8a`4=B8K0bLE5@@T51<4:a/K12XL6`@S51@4:1/J0bDE50@W6QT49ADD13PT7`@J3`h49QTI12dP
6`<[71/460h>11L>3P@L3Pd49aXI12PK6P<V6QT4>bHQ14Xc9PAEBSd49Q`C1;Zk^CJoaL4Eoooo000D
oooo;[o5`@C]m_<4X81e15I4?0A:=Rh4E4@m15I7?`=NBd84Bc/c14Hd;0@m9BT4:Q`K13DQ6`@Z71/3
<B8K12hQ6P@Y6aX891@D128D4`<T51@48Q@C12hQ6`@V6QX4BSi413ll?@@g8bT39QDE12/L6`@]81X4
;B4J12PJ6@@n<2X3@BhW13/W8@AD?C@4De=@18UiK3ZoaL4Eoooo000Doooo;[o5`@C]m_<4X81e15I4
?0A:=Rh4E4@m15I7?`=NBd84Bc/c14Hd;0@m9BT4:Q`K13DQ6`@Z71/3<B8K12hQ6P@Y6aX891@D128D
4`<T51@48Q@C12hQ6`@V6QX4BSi413ll?@@g8bT39QDE12/L6`@]81X4;B4J12PJ6@@n<2X3@BhW13/W
8@AD?C@4De=@18UiK3ZoaL4Eoooo000Doooo;[o5`@C]m_<4X81e15I4?0A:=Rh4E4@m15I7?`=NBd84
Bc/c14Hd;0@m9BT4:Q`K13DQ6`@Z71/3<B8K12hQ6P@Y6aX891@D128D4`<T51@48Q@C12hQ6`@V6QX4
BSi413ll?@@g8bT39QDE12/L6`@]81X4;B4J12PJ6@@n<2X3@BhW13/W8@AD?C@4De=@18UiK3ZoaL4E
oooo000Doooo;[o5`@C]m_<4X81e15I4?0A:=Rh4E4@m15I7?`=NBd84Bc/c14Hd;0@m9BT4:Q`K13DQ
6`@Z71/3<B8K12hQ6P@Y6aX891@D128D4`<T51@48Q@C12hQ6`@V6QX4BSi413ll?@@g8bT39QDE12/L
6`@]81X4;B4J12PJ6@@n<2X3@BhW13/W8@AD?C@4De=@18UiK3ZoaL4Eoooo000Doooo<[o5`@C_o?X4
X7ab16=>APA8=Bd4CT0i0e]<A0ATCDD4CcPZ14Tb:0@d8ad4:1/K12HE50<X6Q@4:A/J12DE50@T51@4
:1XJ12@D50<X6QX491@D128C4`@o>CL4>b/b15A7B0ATED/3ESln14m0>`A8=Bl4<b<L13h]9@@j:RD3
D3lh15e1=@A@DU04NFMP?[o5`AGoool001Cooolb_lG11>olnPBPO784Hdi614Pe;@A>@3T3Fda416A=
A@A?>2X4BC8X13@S7@@X6a/49QDD0bPJ50@Y6aX49ADD12@D50@X6QX491@D0bPJ6P@T51@48Q<C13li
=`@k:c84E4M816AEB`=F?ch4Cd0k14Pe;`@c8a`4?RdU13XZ9@=@?cP4GD4e151BD0AiIf0n_lG15Ooo
o`005?oooc:oaL44kocj1:1lLPASCTH4B3D]14i0>@=KC4@4I4e514lh:PA9<RP4=2<M12PK6`@V5A@3
:1XD12TK6P@U5A@491@D12PJ6P@T51@3:1XJ12@D50@R4a<4?cTg13/[<PADAdP4I5E;0eHo?PA?@3/4
B3D_13<S70@n;BD4>RXU0e0o>0AM@CD4D59@17UWH3joaL4Eoooo000Doooo<[o5`@C_o?X4X7ab16=>
APA8=Bd4CT0i0e]<A0ATCDD4CcPZ14Tb:0@d8ad4:1/K12HE50<X6Q@4:A/J12DE50@T51@4:1XJ12@D
50<X6QX491@D128C4`@o>CL4>b/b15A7B0ATED/3ESln14m0>`A8=Bl4<b<L13h]9@@j:RD3D3lh15e1
=@A@DU04NFMP?[o5`AGoool001Cooolb_lG11;_1_PCbo_X4U6aJ16YCB@AE@CX3ETU216=AB0ATDd/4
C3<Z14H`:0A:>C44A3D^0cHR70@`8AX4:a`K12TK6P@S51@491@D0b`O90@[71`4;R0J12DH5`@o=Bd4
@cDb130O7P<d91d4;b4K12lN7@@i8a`4>R/T14Xd9`=IAcP4Lg5[16QIEPBo`;dn_lG15Oooo`005?oo
oc:oaL44^l6n1?;nnPBDK5X4JU=915E1>P=FBD84He5816ACB`A<<bX4AS0X14Xi<@A4=Bh3=R8L130Q
6P@[71/4:A/J12<D50@T51@3;1lT12/L70@^81X49APG13le;@A3=C84<1lN0c@T7@@_8A/4;ahM13TS
70@j:b@4BS@W0eU7>0AcLF/4J5UF1;o0_CjoaL4Eoooo000Doooo<[o5`@Bk`Kh4l_kj19A/FPAZDdT4
ED4j0eI9@PASDDP4I5=;14`c:PA6<2P4BSTa14@e;P<f8Q`4<24J12/L6`@Y6aX48a@D12@D50</7b@4
:a`L12hP6P@U61L4?cD]14<e<P@`7ah3=2@M12lQ6`@_7Qd4>B<L13X[90A:=2L3FDLh17=aJ`AXFEH4
_l2m?[o5`AGoool001Cooolb_lG11;_1_PCbo_X4U6aJ16YCB@AE@CX3ETU216=AB0ATDd/4C3<Z14H`
:0A:>C44A3D^0cHR70@`8AX4:a`K12TK6P@S51@491@D0b`O90@[71`4;R0J12DH5`@o=Bd4@cDb130O
7P<d91d4;b4K12lN7@@i8a`4>R/T14Xd9`=IAcP4Lg5[16QIEPBo`;dn_lG15Oooo`005?ooocZoaL44
lOoo18mcHPAF?S@3CShg16=ECPA/GeL4KeY@14Pb:P@k9bH4A2TS0ddk=0A5=Bd4;AdL12@D50@c9RX4
=BL/0c/`:P@i:Bh4ASXg13DU:0A3?3/4Ccdj15Q0>0=:>3<4AcD]14`j<PAAAC`4CS/c15e>@@=SHEX4
Sh5a1:n][d:oaL4Eoooo000Doooo>[o5`@Caool4Sg=R15Hn=0=>?SL4HeE>16aOE`A_FU04B38Z13/W
9PA4:B<3CC/d14De;@@]7A`491@D13<V:P@e9b`3>c0Z13TY;PA6>SL4=BDX14<l>`A??CX4F40h0dXh
<`A7=Bd4C3Xb1555?0A>>c<4GDi10f=QFPB?PG44[jf_@[o5`AGoool001Cooolj_lG11?7oo`B?Lf84
EShd0dhn=`ASEDh4K5mG16mJD0A8<RX4>bLV14@Y8`==>c@4ACD]12dM70@T51@4<bHZ13DW;0<k<2X4
>BT^14Hj=`@e9BP4@c`k14lm>PAH@3P3BSPc14Le;@A<>S84DDDl14hk<`AMCT43Hf5J18n1L@B_[Jm2
_lG15Oooo`005?ooocZoaL44lOoo18mcHPAF?S@3CShg16=ECPA/GeL4KeY@14Pb:P@k9bH4A2TS0ddk
=0A5=Bd4;AdL12@D50@c9RX4=BL/0c/`:P@i:Bh4ASXg13DU:0A3?3/4Ccdj15Q0>0=:>3<4AcD]14`j
<PAAAC`4CS/c15e>@@=SHEX4Sh5a1:n][d:oaL4Eoooo000Doooo?[o5`@CanOT4_;6]0fmJD`AB@3T4
FdQ016EMG@AcHe`4JUU@16EJE@=B?C/4CD5015eDF0ARFEL4CS`i14Pj@`=8>3/4Fe1B14do?@AJ@SP4
A3Xh1657?PAJ?CH3FS`^15Q1>@AKBCd4Ie5216a5<`A7DE<3RGa_1;o0_DJoaL4Eoooo000Doooo?[o5
`@CanOT4_;6]0fmJD`AB@3T4FdQ016EMG@AcHe`4JUU@16EJE@=B?C/4CD5015eDF0ARFEL4CS`i14Pj
@`=8>3/4Fe1B14do?@AJ@SP4A3Xh1657?PAJ?CH3FS`^15Q1>@AKBCd4Ie5216a5<`A7DE<3RGa_1;o0
_DJoaL4Eoooo000Doooo?[o5`@CanOT4_;6]0fmJD`AB@3T4FdQ016EMG@AcHe`4JUU@16EJE@=B?C/4
CD5015eDF0ARFEL4CS`i14Pj@`=8>3/4Fe1B14do?@AJ@SP4A3Xh1657?PAJ?CH3FS`^15Q1>@AKBCd4
Ie5216a5<`A7DE<3RGa_1;o0_DJoaL4Eoooo000Doooo?[o5`@CanOT4_;6]0fmJD`AB@3T4FdQ016EM
G@AcHe`4JUU@16EJE@=B?C/4CD5015eDF0ARFEL4CS`i14Pj@`=8>3/4Fe1B14do?@AJ@SP4A3Xh1657
?PAJ?CH3FS`^15Q1>@AKBCd4Ie5216a5<`A7DE<3RGa_1;o0_DJoaL4Eoooo000Doooo@[o5`@C>f=43
hn?V18efN0ARCdT4Ed]916=TJ@AeJVL4L69K0gU/HPA_H5h4I5aD16YJF0A/ED/4Gda30e4o?`A6<b/4
DSlk15U7?`AC@3T4H4<g16U8>`=[C404LeA616E4=`AXF5@4XI2816UQFTfoaL4Eoooo000Doooo@[o5
`@C>f=43hn?V18efN0ARCdT4Ed]916=TJ@AeJVL4L69K0gU/HPA_H5h4I5aD16YJF0A/ED/4Gda30e4o
?`A6<b/4DSlk15U7?`AC@3T4H4<g16U8>`=[C404LeA616E4=`AXF5@4XI2816UQFTfoaL4Eoooo000D
oooo@[o5`@C>f=43hn?V18efN0ARCdT4Ed]916=TJ@AeJVL4L69K0gU/HPA_H5h4I5aD16YJF0A/ED/4
Gda30e4o?`A6<b/4DSlk15U7?`AC@3T4H4<g16U8>`=[C404LeA616E4=`AXF5@4XI2816UQFTfoaL4E
oooo000Doooo1;o0_0Bo`Ki1_lG11?7il0Bc];T4[ZJO17I/M`AlLG<4S8>80heoP0B0K6<4NFMP17IT
G0B0JfL4N6AN0geWG@AfI5h4KEY=16QID@AhIEd4JUaA16]HB`=SAS`4K6AP1:JPW`BJU8X4RH>3DKo5
`AGoool001Coool4_l2l1;o1_T6oaL44lOW`1;>d^@B^YYl4MVag17aaL`B<PhP3SGn0181/H`AiIf04
MVAL181[I`AhI5h3OFMM17ITGPA]FTd4J5UA17QUG@AZG544JeQ;0f=6?0A/I604YZ2O19ZDRPB9Ph=A
_lG15Oooo`005?ooo`Bo`;`4_l6n@Ko5`@CanO04/kBi1:jVW`AfK7L4O75c18b3R0>=Oh04P6aS17UW
H0AfI5`4P6]W17QTGP=mIed4MVAN16eJC@AXFE44N6EM16YLD@A[F4/3HdHl16aTH0BVX9l4VYB:18V3
Pe6oaL4Eoooo000Doooo1;o0_0Bo`Ki1_lG11?7il0Bc];T4[ZJO17I/M`AlLG<4S8>80heoP0B0K6<4
NFMP17ITG0B0JfL4N6AN0geWG@AfI5h4KEY=16QID@AhIEd4JUaA16]HB`=SAS`4K6AP1:JPW`BJU8X4
RH>3DKo5`AGoool001Coool4_l?01;o0_DVoaL44a/o71>KXh@BLYJd4YZJN0kbla`Bc/kX4/ZBU18Yk
Q0AdK784N6MU0g]UG0A_HET4OFMO16iLDPAWDTD4LEU;17EfKP>g]jl4O81i1:BOXUVoaL4Eoooo000D
oooo1;o3`0Bo`;e9_lG11<K?a`CVj>44W:F]1:JVWP>l_<L4/k>j1;:TY@B:Nh@4M6ab17QWI@=kIE`4
Kf5I17eWG`A^G584Ie95175IB`AeMVh3]kN_17b0N@BTWj9I_lG15Oooo`005?ooo`Bo`l04_l2mBKo5
`@C6clL4i^SQ19bU[@BVYYh3_;c71;>c^PBbY:D4RW^417A/LPAhIfD3NfEL16mQF@AmIel4KUaB16MB
A@AaFD/4MGI^0kNg[`AlP7T4Y9nRFKo5`AGoool001Coool4_l?01;o0_DVoaL44a/o71>KXh@BLYJd4
YZJN0kbla`Bc/kX4/ZBU18YkQ0AdK784N6MU0g]UG0A_HET4OFMO16iLDPAWDTD4LEU;17EfKP>g]jl4
O81i1:BOXUVoaL4Eoooo000DooooHKo5`@?6cl@4];W01<kCb@CDdm84[[:b1;:i`P>][ZX4[JbX1:f_
Z`B`/Zh4[kBd1:ZWX`AdMfl3_l2mHKo5`AGoool001CooomQ_lG10lK?a0Bd^L04c]?91=CCdPB^/[84
/[W20jf^ZPB][:P4[Jn[1;2b[PB_];@4ZZNS17AgK`>o`;eQ_lG15Oooo`005?ooof6oaL43a/o41;Bi
`0C>dlT4e=?B1:jb/PBb^L83[JjZ1:f/Z0B][j/4/;:^1:nd]0BZYj<4M7M_0ko0_F6oaL4Eoooo000D
ooooHKo5`@?6cl@4];W01<kCb@CDdm84[[:b1;:i`P>][ZX4[JbX1:f_Z`B`/Zh4[kBd1:ZWX`AdMfl3
_l2mHKo5`AGoool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Ooo
o`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Ooo
o`00ooooob7oool009Woool30000Q?ooo`00W?ooo`030000oooooooo087oool007_oool400001?oo
o`<00002oooo0P0000Coool400000_ooo`<00003oooo0`0000?oool20000O_ooo`00Noooo`030000
oooooooo00Koool010000?ooooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`00
00Goool010000?ooooooo`0008?oool007coool00`000?ooooooo`02oooo1@000005oooo0000oooo
oooo000000;oool010000?ooooooo`0000;oool400000_ooo`040000oooooooo0000Poooo`00OOoo
o`050000oooooooooooo000000;oool010000?ooooooooooo`800004oooo0`0000?oool200001?oo
o`@00022oooo001koooo00@0003oooooool00003oooo00<0003oool000000_ooo`040000oooooooo
00001Oooo`030000oooooooo08goool007coool200001Oooo`800003oooo0P0000Goool20000Sooo
o`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Ooo
o`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(270) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E2DDD4
D7B8A3E1C0ABE1C0B3E1C7B9E1C0B3E1C8BAE1C8BAE1C8BAE1C7B9E1C0B1E2BFA8D9B7A0
DAAD96D1A08BD29E88C89883C89883C89883C89883C89680C89079C09077C09079C09077
B78771E1E0E0E1E0E0E1E0E0E1E0E0E1E1E1E1D7D8E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1DFDFE1DEDFE1E0E0E1DFDFE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1DFDFE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E2E0D9
D8BAA6E1C0AAE1C0B1E1C7B9E1C0B3E1C8BAE1C6B5E1C3B0DFC3B0DFBBA9E0B8A0D6AF97
D5A890CE9C86CF9A83C69782C89883C89883C89580C89580C8907CC09078C09079C09983
B78D7AE1E0E0E1E0E0E1E0E0E1E0E0E1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E1E2E1D8D9E1DEDFE1E1E2E1D9D9E1E0E0E1DFDFE1DEDFE1DFDFE1DEDFE1E0E0
E1E0E0E1E0E0E1E0E0E1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1DCD3
DFBFA7E1C0B2E1BFABE1C8BAE1C0B2E1C5B7E1C4B3DDBCA7D3B29CD7AC97D7A68FD0A48F
C8A18CC89C87C99A85C0907CC5947FC5947FC59580C59078C7907BC0907CC0907CBF9075
BFB4AEE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1DFDFE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E1E1E1D7D8E1E0E0E1E0E0E1E0E0E1E1E2E1D9D9E1E1E2E1D9D9E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E2DDD4
D8B8A5E1C0ACE1C0B2E1BFB1E1C6B8E1C0B0E2C1B3E0BCA9C4B6A6D2AC9BD69D8ECA9883
CA9C8ACA9C8BCA9684C89480C0907CC0907CC0907CC0907CC0937BC1917CC0907CB78771
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0D9
E1BAA3E1C0AEE1C0B1E1C0B2E1C0B2E1C0B3E1C1ADE1C3B5E2C3B6D9BCA4E2ABA3D3A491
D39F8AD29A8CD39F90CD8A7EC28C7CC29485C1927EC0907CC08F7BC89580C09582B98A74
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1DFD8
E1C0AAE1C0ACE1C0AAE1C0B1E1C0B2E1C1B4E1C0B2E1C5B7E1C8BAE2C3B6DABEA8DAAE9E
D9A997DAAA95D19B8BDAA591CA9081C88A7AC9A093C0927EC5907CC7907CBE9788C59F8B
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1DFDFE1DEDFE1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0DFCBC2DBD4CD
E1C0ACE1C0AAE1C0B0E1C0ABE1C1B4E1C0B2E1C8BAE1C3B5E1C1B4E1C7B9E1C0B3E2C1AA
DAB39CDAA999DAA994D29F8CD39888CA9680C78E79C79A88C0907CC1907CBA907DD7BFBA
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E2E1D9D9E1E0E0E1E0E0E1DFDF
E1DEDEE1DEDFE1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0B49788CECDC3C5A599
E1C0ABE1C0B3E1C0ADE1C0ACE1C0B3E1C7B9E1BFAFE1C6B7E1C6B8E1C6B8E1C0B0E1C1B1
E1B6A1E1AE99D9A593DAA68DD09683D09883C9917CC1907CBF9582C99581BB8C75D8D2D2
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E2
E1DADBE1D9D9E1E0E0E1E0E0
E1E0E0E1E0E0E1DFDFE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0DDD4D784463F515A5AD8BAA6
E1C1ACE1C1B3E1C1B4E1C1B3E1BFB1E1C8BAE1C3B6E1C0ACE1C6B5E1B9ACE1B5A5DEB29A
DFB89FD9A898D8A993D79E8ED19E84CA937FC7967CC7907BBE8E7AC59983C08E78E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E1E2E1D8D9E1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E0E0E18D5F4AC2B5B33F3E46E1C0B2
E1BFABE1C6B8E1BFB1E1C6B8E1C0B2E1BFB1E1C6B9E1C7B9E1BEAEDFBBA4E1A89DDAA691
CF9F8AD7A48FD8A48BD2A38CC69580D0947FC99580C29078C1907CC0937FBA8E7CDFDAD9
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1DFDFE1E0E0E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0895B48E9E2DD4C4F4FD8BAA6E1C0AB
E1C0B2E1C0B2E1C0B0E1C0B1E1C0B2E1C1B4E1C0B2E1C6B8E2A49AD99B8CD8887FD8877B
D18377D19784D09983D0997FC8917CC78F77C6907BC8907CC89078BF8C76C38E78D1B3AA
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1DFDF
E1DEDFE1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0DDD4D4FAEFED484B4BE1C6B8E1C0B1E1C0AB
E1C0B2E1BEADE1BDACE1BDA5E1BFB0E1BFB1E1BEB2E1B5ABE2A89CD8786ED7685CCF6E69
D06C63CF6B68D08675C58A76C59078C78874BF8F77C8907CC9907CC08E75C98C7ABB8A75
DBD2CFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E2
E1D9D9E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0815E559F9B9AD7BFB3E1C0AEE1C0B0E1C0AB
E1C0B0E1BDABDFB29BDFB7A2E1BAA5E1BCAAE1A497DE887BDD998DD06A57CB8073C6756A
D06054C3574AD06860C1756AC08877C08E6CBE8A72C6907BC8907CC8927CC88A77C89782
C19380E1DDDCE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1DFDFE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0D0BBBCE8C6B237454CD8BAA6E1BCA5DFBFABE1C1AD
E1BCABE2B698D69F85D3A091E09587AA301CC99A87D8847CD37F75D19E96B76558C58871
C6886BB8695FAC5241BD5649BE7467BE8C6FC0876BC0927AC89680CA927CC8937FC8907C
C3907BDBC4B9E1DDDCE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1DFDFE1DEDFE1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E08F6C6489868AAD9183E1C0AAE2BBA8D7AE9BE1C6B8
E1BEADE29D7DCF8C70A12821CB9C98E398966F3B3AD4AEA3D2958DD8A69EE4DCCBD8817A
C5968AB08776A160516D3823AC4E40B5806DBF896CC88D7CC89B87D3A285CA917CC89580
C8927EC39782DBCBC7DFDDDDE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0DFDADE7D48412C3D48D7B8A2E1C0B0E2C4ADD8AC9AE1C0B2
E0B09AD99870BE5B41A02817683537BCA296DFBBADDFC6BDE1D3C9E1CAC1E2BEB0D5B09E
E0BDA9E0C0B5C5A594986E655C33279D5040BB876FC48C78D1A48FD2A28DD29F85C88E79
C88E7AC79782C1B4BBCFC4C6DBDADDE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0B497886D4038C3A3A22F3642D8BAA4E1BCA4E1BAA2E1BDA6E1C0AE
E3B49DD89986BA957ABE7A6D6F4B46D38A82D8A290D59688DDA8A0DDA18FDD8F7ACC6B5B
D48476C98D7BDEA087C38375B17D6F5A15099E5A50BD8A78CFA289DAAD92D29B83C79680
C68D7BC9927EC3B3A4BEAEAAC0B9CDE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1DFDFE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0DFD7DA472C233E231E1A2E38AF8D85E1BEA7E1BAA8E1B19EDFB29EE1B9A7
E3B59DCD8468C99C8BD8BBA9E1C5AFE2B2ABDCADA2D4A89CD2AB9CDE948ACC9A8CCC8576
CC776AC26F64CA8A7BC56A5ABB58459B382A64241EB3736ACD9E86DAAC92D29C80C88D78
BF8E7AC896828D513ECAC2BEC0B3C2DFDDDDE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E4E0E3EFD7D64555542C3940DFBFAFE1BFA8E1BCA4E2A9A3D8B6A3E1C4AB
E3AB9DD59680B37E6BDFBCAEE1C8BAE1C1B3E1BFB1E1C8BAE1BAAFE2B9A3D9A893DAA691
D19E84D0977DC38C75CF8273C5796BB56E5E975752915249C3917CD8A58DD29C80C89279
BF8B77C8927EA3726550423FDBD3D2D8D2D2E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E6DFD2C7C0C9E2C5B2DAAE9BD7B7A1DFC0AAE1BAA6E1C4AEE1ADA9E1C1AE
E4C1A9D4A38CC68572D3A995DFBFB0E1C9BBE1C1B3E1C0B3E1CBB8E2AB9FD89F88D8A38A
CF9B7FCB917CBB896BBD7F6ABD876ABD7F6ABE846AB7827BBF8E73D19D88D0977CC78C78
BE8F73C58F7A7243394D4D45BBAFADE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1DEDEDFDCD6E1BCA3DEB29ADBBEB3D3B7A4D8B8A5E1C1ADE1C3B5E1C1B4E1C9BB
E2BCB1DCB09CD49983C68B7BD7B4A1E1C6B9E1C0B3E1B9AADFC5B4E2B99FD8A48ECF846E
CF977EC2866CB1836BB88168B97F65B98264B87860B5846EC89782D09A83D0927CC08874
C08A78C0937B4323262B3234C7BFCEE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E2DCD2D8CDC9E2B89FD7A891D3A287BDAEADE1B6A4E1C0B3E1C8BAE1C8BAE1C8BA
E1CBB8E2AEA2DCAA8FCF8F7AD5A593E1C0B3E1CBBBE2AEA9D8BAA8E4BEA9D2A28DD39A84
C2816FC28870B87764B87F68B78271C2896EBC8B75B98570D09680D09580C9927CC18975
C08A73BE8F7A6030272C2528958E8AE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1DFD8E1BEA6DCA081CDA08DC79D8DD8BAA4E1ACA5E1C0B3E1C9BCE1C9BCE1C8BA
E1C7BAE1C3ADE3B098D1A285CD9482DFBDAFE1C6B5E1C1B3E1C1B3E2C0ADD9A18DD09A83
C7907CC8907ABA8066B97964B7816EBF8D7EC89181D29C87D2A28CC89581C7917CC7927C
C08B79C0957ED9946C56332A422F2EBFB9BAE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1DAD4E0C2B1DB8671D7A18AB47F6DD1BBA4E1ACA4E1C0ABE1C0B3E1C6B7E1CFC5E1C8BA
E1C7B9E1BEAEE2C0A7D3A896D0A68FD8BAA3E1B9AADFBBA5E1BEB1E2B49ED9A188C78C77
C58872BE8C6DBA7C66BB7F64B78170BF8F7DCF9C8DDAA691D29D87C89A83C99580C19078
C08D77C0927FCC9B85C2886C8654484A4444E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1D4D2E3A696D27E6BC06E65C08E7EBDB2A5E1C1AFE1C1ADE1C0B3E1C8BAE1C8BAE1C6B8
E1C6B5E2BFAED8B7A0DAB19CD7B8A5E1C1AFE2C5B1D8ACA2E1C0A6E3A89BD0997EC58470
BD806BB37B67C08569A97F6FB98574C89D89CFA28EDAA691D29E88C89680C88D7CC98C7C
C08D75C68C7DC79071BE8672B67B66E2E1E2E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1DCD7
E1DCCFE3A695D08168BF756BBB9585D8BAA5E1C0B3E1C9BBE1C0B2E1C5B7E1C3B1DFC5B3
E1B9ADE2B9A4D7B39CE1AE99D7B7A3E1BFAFE1C6B6E1C0B2E1BBB0E3A58ED29780C08570
B9816CB1806DB0826DB78775C69A85D1A18DD1A590D8A28CD29D87C8927CC88D77C78877
C78B78BF8D7CCB9B89BA816CB88574E1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E0CFBB
D79F86BD7D60BC7762B07F6CC39C8BE1C0ABE1BFB1E1C5B7E1C6B5E1BEACE2BEADD7B29F
DEB9A0DFA69FD9B29ED9AD99D7B29DE1C0B2E1C0ACE1C0B2E1C2AFE2A899D28F79C08570
B8806CBA826FB28A78BF927DC89A86CF9F8AD8A893D1A28DD29984C89A85C78D79C78975
C08778BF927DC57E5FC68977C1836BB7A09FE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E2BDA1
964C2E9755466C3F39886A62CDA898E1C0ACE1C0B0E1C0AEE1C0B2E1C1AEE2BBA9DABEAA
DCAB9FD1A290D69E8DD5B19BD7B6A0DFBFAAE1C0B2E1C0B0E2BAABD9AB92CE8A7CBE836C
B67C67B5816EC08C7ABE907BCE9686CF9C8AD09883CEA08ACF9A83C5947FC79580C08E79
C08877BE8879C59270B36A52C58E7AB76C59E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1DEDCE5D2C8
D1775C61372B693C3849484FCDA895E1BEACDFBFB1E1C0ABDFB69CD9B19DD3A088CF9C85
D09F8ECD8F85CD9182C4917CD5A893D5B6A2E1C0B2E1C0B3E2BCA7DBA28FC88C6FB87866
B88068AE7B67BA8572BF907BC28E7AC49A85CF9785C6927EC99984C1917CC0907CC08E79
C08877C08A7CB36A519F4E34AE7256B66B5CE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1D6CAE2C0B1
5C161048221D432A263D444CCFA996E1BEA7D8B8A2E1C0B0E6C1A8C69881BA8970886156
6E494185503AA2685BB35D45B05A43C09886DFBDAFE1C0B2E2C0ADDBA38FC88B70B68465
B4755CAE8472BC8A77B7907DB38C79C08B7AC3957FBB917DC89883C89680BD8D78BA8D78
BC8B77C08B7CBC745A924C398F4F40AD6045E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E0E0E1E4DCD1DBA289
A55A502F17163A1E1D1D323ED8B39FD9B9A3DFB8A3E1C0AAE2C3AEE1AF97BB9787926351
4C2A26482A2260453F9664519C665A945C55D7B39FE1C4B7E2C3B3DBA990C3826BB2765A
8B2916986758B88161B98168AA6F56B9846EBD8777AD8973C5947EC79580C08A74B08773
AE8777BD8873AA6351935846955E53AD513FE2E1E2E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1DEDEE1DEDFE1DFDFE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0732A21C4B2A5E2AC95
B464513E26312A18171F2937D7B7A1E1C0AAD9B8A2DFBDA6DFBFAAE6C4B3C89D87E9A993
9177696753486C5042716B629F7464C69483D7B7A3E1C6B7E2CBBBDBAD93CC886BAA715D
AD694F6E413E875F5620070C79493C7353476F423190695BA77151B58065BE8C76B08370
AE8873B77D6A874E3C6F40378A665AB66C5EEBE9E9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1D8D9E1D7D8E1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E07E433C74443D2C0000904F40
582D38361F1C3620210B2433D9B8A2D7B8A5E0AA95D4A790D3B39FE2C3B6DCC0ADD8A997
C5937FC79783B0826CAA806BC09880D19D8BD7B09DE1C8BAE2C2B3DBAE98C88E72B98062
AE795FA46F5EA57B6B311B202A1D1A613D39553B355744398B675A91715DBB7D65B18773
AE8B749050466B4030593227644A3FBC7C67E9E7E7E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1DADBE1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E08B4A424A2C25432220361E1E
230D12351E20381E1D1D2E3AD8B7A1D9B7A0E5C8B8CD9587BC8169CD9A83C89B83B88573
A66555A0624BAA6D54AF6952C2957DD5A996D7B19DE1C5B4E2C2ADDBA695C8957DB97B60
B08864B58066C3947DD2927A4B4E4E6F4D407B564A585550906E58A87967BE9175BC8773
B08875834C374724225230265D3D30AA4C39E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E09858423212102B1B19311918
321B191E1516433130323840D3AE9AE2BAA4D8BAA5E6C5B8D5B29EB28171AE7E72A68273
9B726389655A8D6553977162986C62C7A695D8BAA6E1B9AEE2BCA6DBA891C89182A65B44
A0543DA57F5FBC8F72C09077C4937DBB8C75A376659A7362B68472C0886FB08775BC8F73
B78169482B242B1C194647456F4334953625E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1DFDFE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0AB715C3F14112D1716231817
0F01082A1717392D2D484D4DBD9D8ADFB7A2E1C0ABE1C1B4E2C4B8E0C6B1D0A0959D908E
CAA097BA9284BC9B8CAB897CCA9B89D7B9A5E1BFAEDFC1ADE1ABA0DCB09ACDA992C88E82
8B4D456B392E6C422FA4715BB88B74C79079C39274B08874BE8970AA7F6ABC867AB28775
90523E4D2720342A29313934A5523A6A3832C1C2C2E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E1E2E1D9D9E1E0E0E1E0E0E1E0E0E1E0E0957069492D292F17162C1817
1E12102214153C2D2D4D4F4DA78B7CD7B19DE1C0ABE1C0B3E1C8BAE1C9BCE1CABFE1CABF
E1C9BCE1C9BCE1C9BCE1C9BCE2C3ADD8B8A2E2C7B6DAB7A0D9B39CDAB09BD3AB97D6AC9A
D3A38F9B6F6A7C564D53362C653A2C925A4A916956A26B519A6851B47F70A37F6CBE8473
6F362E3A1D1A301E2334131175281C76433C342F2EE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0AB7C74593F3D2B1C1A2B1817
2D18172C1D223D2E2E524D49A48171D3AE9BE1C0A9E1BFB0E1C6B9E1C6B7E1CFC6E1D0C9
E1D2CBE1C9BCE1D0C8E1C8BAE1C9BCE1C1ACE1C0AAE2BEA6D9B29CD9A893D9AF9AD9AF9B
DCA999CBA492CD9381A07B6D7E60546850428356487B685B9570608A675CBB8678B6816C
6D352C311A182518171F1311361C1C5D37353C3635E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0AA705A53342A4A2E2B2A1917
31110F361E1D412B2553433D8A7264C19E8CDFBFA9E1C0ABE1C0B3E1C9BCE1C8BAE1CFC6
E1D0C9E1D0C9E1D0C8E1C8BAE1C6B5E1C6B8E1BEA8E2BAA2D9AF9AD9B29CD9A893D9AE97
DAA594D3A28CCB9E88C4937DB8917EAE89759E7968987363B57F6FB38A75BB7C70A0664D
62322A311A18371E1D251918261716412A23514D4CD5D2D3E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E095644F583E39442B273D2220
1F12102C16162E19184E332A695140B08B7BD7B7A2E1C0ABE1C0B3E1C7BAE1D2CBE1C8BA
E1CFC6E1CFC5E1CFC5E1C8BAE1C7B7E1C0A9E1BDABE1B8A0D9A893D9AD97D9AE98D9A893
DAA691D09E88D09883C99C87C0917CC89580C1907CBD8E79BA8873BA8878B37D6771463C
2F19133520241E11172112100E0108311D1D5044409C888BE1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0AB715B4E3631523B393D2927
3E211F2817163624233F33335D453E7D6758D3AC98E1BFAAE1BFB1E1C5B6E1CFC6E1D2CB
E1C9BCE1D0C8E1C8BAE1C8BAE1C7BAE1BEA8E1BDA5D9AE98D9AE98D9A893D8A893D7A590
D8A590D29E88C89883C89782C99E88C0917CC7907CC08E79B28874B384709B66545E3029
412A2815090F2012190D01081B1016211415483E3F76625EE1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0A07C74593E3A523E3C4F3A37
3D2220221310341E1D4A322B644C416C5C4EBF9583DFB7A1E1C0B1E1BFB1E1C5B6E1CFC6
E1D0C9E1D2CBE1C9BCE1C8BAE1C7B9E2C1B2DAB9A1D8AF99D7A590D7A492DAA490D1A28C
D19C8AD29D88C89883C89580C7947FC79580BE8973C18C77B0806BAB7060864D3B522A25
22121022131913080F1B1110180E152F1D1D19191B7C706EE1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1DFDFE1DDDD956F674F3A38543F3D513B38
361E1B3D26253123223E2B2A62483D846455B07E6BD5AF9CE1C0ABE1C1B4E1C1B4E1C7BA
E1D0C9E1D0C9E1D0C8E1C8BAE1C5B3DFBDACE2BAA2DAAE98D3A994D1A18BD8A090D19E88
D09B85D09988C79180C59480C7907CC0907CC18F79B68370B77E67A96C55693E30482521
2B1A182117162217171A100F2117162F1D1D0B0304E2E1E2E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E2E2DCDC88615854382F4E383555403E
513A38382524412E2C462E26514844805A49A47868CBA492DFBFAAE1BFB1E1C6B9E1C6B7
E1CDC3E1CDC3E1CDC3E1C3B1E1C2AFD7B7A1E1B69ED8A58CD7A48ED8A58CD1A08AD1A18C
D29883C89D87C99780C18B7CC08D78C08C77BD8D78B7806BA5725A7C4840592C262D1C19
2212101C111715090F05010813080E3D2E2E180D0EE9E7E7E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0AC7C74493128583D38513E3C
4B3531422522452D2649363454413A6D493D846354BF8F80D7B8A2E1C0AEE1BFB0E1C5B4
E1C5B3E1C5B3E1C6B6E2C1B2DAB9A1D9AD97D8AD94D8A18CD19C85D19F8CD1A086D19A83
D29C86C89580C89580C8907CC08E79BE8470B97F6AA5715A7C4A41683C2D3A1E1B291918
2A18171C111615091014080F281A1B000D165C4646E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0C5A59E573D3B4C3632583F3D
52352B45312E3B26254B353145312F58443F6A4D43A37664D1B19BDFBDA6DFBFA7E1C0B0
E1C0AAE1BEA7DFBDA5DFBFAFE2BBA3D8A890D8A58CD09680CE9782CE9786CF9C86D09B84
D08F7BC89180C78F7CC79078BE8A73BD8470B17963895242693D2D391D1B2514111E1117
2818171F12170D010813080F2B1B1C110809E9E7E7E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0C2A392674C48523E3C4C3836
533B393C23263E29283F2D2B513E3C49302852382F815F51B38770D3AB94D5B19BDFBAA2
DFBCA5E1BEA7D9B69FD7B49EE0BAA2D7A18ACE937FD09A80C88C77C8937EC6947FD09580
C78D78C58D77C58372BB8772B6856BA86D57A067506D41313E1E1B2D1C191F121014080E
13080F0601080401082A1A1B35211C160B0BE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0EFE2E973504B56403E513B38
55424151342A3A202049373644302E54403E412A2756423B795749A7735EC49480D2A189
D2A693D4AD9BD4AE97D5AB96D6A48CC38C72B97D66BF8166C48B75C58773C5846EC58A75
C78D6EBE846EBD806BB47762AA77628F5949733B2D562A24361C191F110F16090F14080F
0C000804000810070E1E141536353748322CE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0EAEBE9A6857A4F35324F3A38
4B37354737333B2427432B24513A38503F3E58423F4433325D4944694E448A5846A37368
976F5FA97660B48673B58871B17D6AA76D558D5A4596644AA9674FB4785EBA7F65B9735E
B06F59B26E52AF715CA06A5A9054467840305627233A1C1922121017090F0D0108030007
0300080300071A14152D1B1C040507D8D2D2E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0DECCD56246414D3B39
4E3E3C4E39372A1D1A3A2B2B543F3B554241624E4B5F4C495D4C4664524B6B50466E463E
6A413763413C784639875B4C7A50476C484477463A7243307A48388E5746945F499D5D45
97614B864F3B885446874B3D6F43364F2824462A262413101E110F15090F0C0008030007
020007201415160E153F4446271A1BE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0F0EBEB865F5E4E3836
503A384D3A38513A38403434503F3E614D4A5842405A44415E3E3B6C453B664034573E39
462D2B5037334524225538345C3E394C3431442523492B284925204D24215E372A60392B
5C36295929245225214C28244A2522311D1A2012101A0B1114080F14080F040008030007
20142020141641302F06131C95807DE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E4E5E3DAC7CD5B3F3D
4D3836513E3C4E39365847454B3531594543513935533F3D5F4B43583F3C5A3B37533834
4933304C38373E262A3A2B2A402422412422321C1A2819182F1A193A201E3D1F1E341B19
331B19331C193D201E3219182F19182212101D110F15090F13080F04000804000810070E
261E20381F202422234A4444E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0ECE4E6895854
533E3C513E3C513B3840312E604B4754454256444143302E5538304D302B49333046322F
35242F3B2F2D41262B391F20301C282819182819181E110F221817241817271918211210
16090F1D110F2A181722121016090F1E110F1B101615090F04000813080F1C1515292021
2E1B1C383535382E2FE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E6E8E6BD9D9B
573A38543F3D513B38533E3C453B3956413F513834422D2A3C2927391D1A3F2D2B392328
3923272B191A301C271F1219190A101E11191C11171609101A101615090F1C1117160910
1B10161F16161A1016170910040108030007040107040108190F16160F0E13080E27110F
3A3B3C372B2CE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0F7F7F7
9278734B34314F3A384C3D3B50403E544543523C3F4024223C27262A1B192A17172A1C19
2D1919180A1116090F1E11191B111713080F1B1017150910190F161509102D1B1C050108
180F162117171D12170501080400080A0007160E15170F16160E15311D1E3C2A223F3D3A
170A07D8D2D2E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
F7F7F793736E4E3E3B47322F5444425545435F4946443433412D2B321B271D11172B1817
1D11172518172016161A101614080F14080F13070E14080F13070E211717180F16433742
2F2F362918251609101C11171C15161C1516180F15352829342424311D1E523935443933
8D6959E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0F8F9FA936F6A5B484644302E51413E5F4D4A614A47483228412B282719191A1017
17090F1A100F1C111716090F14080F190F1613080F190F1613080F12070E373337312332
53484F5B4F4D47333B3F3537392B2B2519183425233022234D3B39563A3437313274514A
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0DFDEDFFFFFFF8C625666504C503C3A57494766514D63504D452B283E28273F312F
352B2B2717172217161C11171A101613080F14080F1F15221C1118201616180E153C3331
42323629181D30201D2A1C1B27171C321C1A322423462E2655433A635F5B664640E1D9D9
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0F9FBFD86665A533A35523E3C6A58556E5E5C6B55513F2928352126
4124224736343A2C2A1E121814080F271D29271C282F27272B202D3C3234261A253C373A
48373A513A383C2F303B2C2A3F3130433B394332305648414C433C8A6856C7BBC4E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0F9F8FA9D8F88604D4B533F3D654D4A6D6268715E5C5D4D4B
574D4F4A3438493E42554C544C474B3C2F343E334340323B544A5144383C553D393F363A
62464257393857382F543E3C58453E634F456841343E3D3E8D6B5AE1D9D9E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E8E9E7DBCFD87E676D604C4A584C516C6A737B6B6C
7765627B6C6767595C5E58586D5D636D55515B49474B3A4345312F554042594543513E3C
64423A6A463E6B4942705047634139735D5B9874665A443CE1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1DEDEE1DEDFE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0F9F8F6908591887D766C6475897B80
8D83898A7C7D836E6A806D6C7F6865836B6C735F5E78625E6B5A5C61504B63545273605E
67565071544B69433F786560957C767E61588D797DE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1DADBE1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E4E5E3E9E0E5848395
A09393BFB6C6ACA0A7A892908A777F7F7077876C6E886C677B6764896C6976605A73584E
7F6156726B6292867D635855B7A5AEE1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E4E5E2D0CBDBE8E2DFD4C8D49994A29B97A99289879286849287859489878E8584
86756D6B645AE1D9D9E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0
E1E0E0E1E0E0E1E0E0E1E0E0
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?oooeWQh>04h]gD1=NhX`?Q`:/4hL2c1>77^@CQ`;<;hLRj1>77
^@CQ`;44h[nX1=VgX0CJ[IH4dJ2;0m:NR138V8<4b9J00lR@N@C0T7L4`91i1<2@M`BgQg4?hN3P1>7Q
h@CQemPShN3P5Oooo`005?oooeWQh>04h]gD1=NhX`?Q`:/4hL2c1>77^@CQ`;<;hLRj1>77^@CQ`;44
h[nX1=VgX0CJ[IH4dJ2;0m:NR138V8<4b9J00lR@N@C0T7L4`91i1<2@M`BgQg4?hN3P1>7Qh@CQemPS
hN3P5Oooo`005?oooeWQh>04h]gD1=NhX`?Q`:/4hL2c1>77^@CQ`;<;hLRj1>77^@CQ`;44h[nX1=Vg
X0CJ[IH4dJ2;0m:NR138V8<4b9J00lR@N@C0T7L4`91i1<2@M`BgQg4?hN3P1>7Qh@CQemPShN3P5Ooo
o`005?ooo`CQh>04hMoO1>7Ng`CQh>04hMoO0n7Ngb?Qh>04hMoO1>7NgaOQh>04h^3I1=RjYP?Q`:X4
hL2a1>77^@CQ`;<4hLRj1>76]@?Q`k04gl>`1=nkZ@CP^:04eZnG1=FXT0C>W8H3ciZ31<JGPPS8V8<8
b9F00lR@O0C0T7P4`91i1<2IP`BgSGX?hN3P1>7QhPCQfMTShN3P5Oooo`005?ooo`CQh>04hMoO1>7N
g`CQh>04hMoO0n7Ngb?Qh>04hMoO1>7NgaOQh>04h^3I1=RjYP?Q`:X4hL2a1>77^@CQ`;<4hLRj1>76
]@?Q`k04gl>`1=nkZ@CP^:04eZnG1=FXT0C>W8H3ciZ31<JGPPS8V8<8b9F00lR@O0C0T7P4`91i1<2I
P`BgSGX?hN3P1>7QhPCQfMTShN3P5Oooo`005?ooo`CQh>04hMoO1>7Ng`CQh>04hMoO0n7Ngb?Qh>04
hMoO1>7NgaOQh>04h^3I1=RjYP?Q`:X4hL2a1>77^@CQ`;<4hLRj1>76]@?Q`k04gl>`1=nkZ@CP^:04
eZnG1=FXT0C>W8H3ciZ31<JGPPS8V8<8b9F00lR@O0C0T7P4`91i1<2IP`BgSGX?hN3P1>7QhPCQfMTS
hN3P5Oooo`005?ooo`CQh>04hMoO1>7Ng`CQh>04hMoO0n7Ngb?Qh>04hMoO1>7NgaOQh>04h^3I1=Rj
YP?Q`:X4hL2a1>77^@CQ`;<4hLRj1>76]@?Q`k04gl>`1=nkZ@CP^:04eZnG1=FXT0C>W8H3ciZ31<JG
PPS8V8<8b9F00lR@O0C0T7P4`91i1<2IP`BgSGX?hN3P1>7QhPCQfMTShN3P5Oooo`005?ooo`CQh>04
hN7R1>7Hf@CQg]l4hN7R0n7If@CQh>04hMoO1>7Ng`CQgml4hMkO3n7Ph0CQhN84hMWI5n7Ph0CQg=<4
gknW0n70/PCQ_j/4hLRj1>70/PCQaKL4hLBc0mflY`CC/Y`4ejbG1=NVS`C@Y8l4b:6<1<RLQ`?9VXD4
`91l2<FDO`C5UH04aI1h0lN@N`S0T7`4_i1e1;nd[Q?Qh>04hMoO1>7NgaoQh>0Eoooo000Doooo1>7P
h0CQhN84hMSI1>7Ng`CQhN83hMWI1>7Ph0CQgml4hMkO1>7Og`CQg]l?hN3P1>7QhPCQfMTGhN3P1>7L
d`CO_jL3hL2b1>6oZ`CQb;X4hL2b1>75]`CQa;<3gKbW1=>bW0CG[9L4ejJ?1=2TS`C8XH`4b9b70lVJ
Q@C0T7`8aIAo1<FEP0C5T7P3ai1k2<2@O0BoT7D4_kB^4n7Ph0CQgml4hMkO7n7Ph1Goool001Coool4
hN3P1>7QhPCQf=T4hMkO1>7QhP?QfMT4hN3P1>7Og`CQg]l4hMoO1>7Ng`oQh>04hN7R1>7IfAOQh>04
hMcC1=noY`?Q`;84hKn[1>78^PCQ`;84hLFg1>74/`?M_:L4dk:L1=N/U`CGYXl4d:B?1<RQS0C8W8L3
bIZ51<2@O0S5U7l4aIF01<F@N0?7T7/8`91l1;n@M@Bo]:hChN3P1>7Og`CQg]lOhN3P5Oooo`005?oo
o`CQh>04hN7R1>7Hf@CQg]l4hN7R0n7If@CQh>04hMoO1>7Ng`CQgml4hMkO3n7Ph0CQhN84hMWI5n7P
h0CQg=<4gknW0n70/PCQ_j/4hLRj1>70/PCQaKL4hLBc0mflY`CC/Y`4ejbG1=NVS`C@Y8l4b:6<1<RL
Q`?9VXD4`91l2<FDO`C5UH04aI1h0lN@N`S0T7`4_i1e1;nd[Q?Qh>04hMoO1>7NgaoQh>0Eoooo000D
oooo2>7Ph0CQhN44hMOH2n7Ph0CQhN84hMWI1>7QhPCQfMT^hN3P1>;Me0CH^:D3hL2/1>70/PCQ_k44
hLJh1>70/0CR`K<3h;bY1<BfYPCB[9/4eYf>1<ZHP`C:W8X4bYb;0lZFQ0C8U80@`91l0l2CN`C1TG`4
`91l1;N7LAOQh>04hN7R1>7IfAoQh>0Eoooo000Doooo2>7Ph0CQhN44hMOH2n7Ph0CQhN84hMWI1>7Q
hPCQfMT^hN3P1>;Me0CH^:D3hL2/1>70/PCQ_k44hLJh1>70/0CR`K<3h;bY1<BfYPCB[9/4eYf>1<ZH
P`C:W8X4bYb;0lZFQ0C8U80@`91l0l2CN`C1TG`4`91l1;N7LAOQh>04hN7R1>7IfAoQh>0Eoooo000D
oooo2>7Ph0CQhN44hMOH2n7Ph0CQhN84hMWI1>7QhPCQfMT^hN3P1>;Me0CH^:D3hL2/1>70/PCQ_k44
hLJh1>70/0CR`K<3h;bY1<BfYPCB[9/4eYf>1<ZHP`C:W8X4bYb;0lZFQ0C8U80@`91l0l2CN`C1TG`4
`91l1;N7LAOQh>04hN7R1>7IfAoQh>0Eoooo000Doooo2>7Ph0CQhN44hMOH2n7Ph0CQhN84hMWI1>7Q
hPCQfMT^hN3P1>;Me0CH^:D3hL2/1>70/PCQ_k44hLJh1>70/0CR`K<3h;bY1<BfYPCB[9/4eYf>1<ZH
P`C:W8X4bYb;0lZFQ0C8U80@`91l0l2CN`C1TG`4`91l1;N7LAOQh>04hN7R1>7IfAoQh>0Eoooo000D
oooo2>7Ph0CQhN84hMWIBN7Ph0CQh=T4hKZS0n70[PCQ`;48hL2b1>70/`CQ`Jd3hL>e1>;3]PCI_:@4
hZ^S1=>TT@CCWhX4dYZ<0m>OT0C=RWh4`Xal1<:DQ@C1TWh4`91l0l2?N`C8UH04`9F21;V:M3kQh>0E
oooo000Doooo2>7Ph0CQhN84hMWIBN7Ph0CQh=T4hKZS0n70[PCQ`;48hL2b1>70/`CQ`Jd3hL>e1>;3
]PCI_:@4hZ^S1=>TT@CCWhX4dYZ<0m>OT0C=RWh4`Xal1<:DQ@C1TWh4`91l0l2?N`C8UH04`9F21;V:
M3kQh>0Eoooo000Doooo2>7Ph0CQhN84hMWIBN7Ph0CQh=T4hKZS0n70[PCQ`;48hL2b1>70/`CQ`Jd3
hL>e1>;3]PCI_:@4hZ^S1=>TT@CCWhX4dYZ<0m>OT0C=RWh4`Xal1<:DQ@C1TWh4`91l0l2?N`C8UH04
`9F21;V:M3kQh>0Eoooo000Doooo2>7Ph0CQhN84hMWIBN7Ph0CQh=T4hKZS0n70[PCQ`;48hL2b1>70
/`CQ`Jd3hL>e1>;3]PCI_:@4hZ^S1=>TT@CCWhX4dYZ<0m>OT0C=RWh4`Xal1<:DQ@C1TWh4`91l0l2?
N`C8UH04`9F21;V:M3kQh>0Eoooo000DooooFN7Ph0CQgmP4hL2Z0n70[0CQ`:X4hL2a1>70/PCQ`K@4
hL2b0n75]`CQb;X4h/>f1=ZnZ0CJ[Yh4fJVG1=ZZU@?AVh/4fZFA1<Z@P@C8RWX4bJ2C1<2BOP?5T7`4
ai1l1;jGR0C5Wh/KhN3P1>7Og`CQg]lKhN3P5Oooo`005?oooeWQh>04hMoH1>70ZP?Q`:`4hL2Z1>70
/@CQ`;84hL6d1>70/P?QaKL4hLRj1>;3]PCJ_ZP4fZjN1=VYU`CJZYD3dI^;1=ZUT@C:T844b8Yj1<VP
T`C0TWh3aI1l1<N@O0BnUhP4aIn;6n7Ph0CQgml4hMkO6n7Ph1Goool001CooomIhN3P1>7Of0CQ`:X3
hL2/1>70ZPCQ`;44hL2b1>71]0CQ`;83hLFg1>78^PCR`kH4f[jX1=Z^WPCIZIL4fZZE0m6KR`CJYI44
bY211<R:NPC9X9<4`99n0lF@O0C7T7`4_YN81<FORa_Qh>04hMoO1>7Nga_Qh>0Eoooo000DooooEN7P
h0CObl84fmC=1>70[0?Q`:X4hL2`1>70Z`CQ`K@4hL2b1>78^P?Q`kD4hL6d1>77^@CQ`;<4h/6Z1=Zc
W0CJZIT3fZVD1=:OS0CCV8P4bYJ01<N>N@C7VXP3`91l1<6@O0BjT7d4eknj6n7Ph0CQhN84hMWI1n7P
h0CQgml4hMkN1>7Ng`SQh>0Eoooo000DooooEN7Ph0CObl84fmC=1>70[0?Q`:X4hL2`1>70Z`CQ`K@4
hL2b1>78^P?Q`kD4hL6d1>77^@CQ`;<4h/6Z1=ZcW0CJZIT3fZVD1=:OS0CCV8P4bYJ01<N>N@C7VXP3
`91l1<6@O0BjT7d4eknj6n7Ph0CQhN84hMWI1n7Ph0CQgml4hMkN1>7Ng`SQh>0Eoooo000DooooEN7P
h0CObl84fmC=1>70[0?Q`:X4hL2`1>70Z`CQ`K@4hL2b1>78^P?Q`kD4hL6d1>77^@CQ`;<4h/6Z1=Zc
W0CJZIT3fZVD1=:OS0CCV8P4bYJ01<N>N@C7VXP3`91l1<6@O0BjT7d4eknj6n7Ph0CQhN84hMWI1n7P
h0CQgml4hMkN1>7Ng`SQh>0Eoooo000DooooEN7Ph0CObl84fmC=1>70[0?Q`:X4hL2`1>70Z`CQ`K@4
hL2b1>78^P?Q`kD4hL6d1>77^@CQ`;<4h/6Z1=ZcW0CJZIT3fZVD1=:OS0CCV8P4bYJ01<N>N@C7VXP3
`91l1<6@O0BjT7d4eknj6n7Ph0CQhN84hMWI1n7Ph0CQgml4hMkN1>7Ng`SQh>0Eoooo000DooooDN7P
h0BdUhP4c/g31<FUV@CQ`:/3hL2c1>70[@CQ`:`4hL2c1>77^@CQ_jl3hLJg2>76^0CQ`;04hL6a1>6f
X@CQ[YT3fJFC1=ZVS@C@UX<4d9R31<VAO0C1T7`3_iF21<VEP@BkS7D4f=;B:^7Ph0CQhN84hM[K1>7I
f@SQh>0Eoooo000DooooDN7Ph0BdUhP4c/g31<FUV@CQ`:/3hL2c1>70[@CQ`:`4hL2c1>77^@CQ_jl3
hLJg2>76^0CQ`;04hL6a1>6fX@CQ[YT3fJFC1=ZVS@C@UX<4d9R31<VAO0C1T7`3_iF21<VEP@BkS7D4
f=;B:^7Ph0CQhN84hM[K1>7If@SQh>0Eoooo000DooooDN7Ph0BdUhP4c/g31<FUV@CQ`:/3hL2c1>70
[@CQ`:`4hL2c1>77^@CQ_jl3hLJg2>76^0CQ`;04hL6a1>6fX@CQ[YT3fJFC1=ZVS@C@UX<4d9R31<VA
O0C1T7`3_iF21<VEP@BkS7D4f=;B:^7Ph0CQhN84hM[K1>7If@SQh>0Eoooo000DooooDN7Ph0BdUhP4
c/g31<FUV@CQ`:/3hL2c1>70[@CQ`:`4hL2c1>77^@CQ_jl3hLJg2>76^0CQ`;04hL6a1>6fX@CQ[YT3
fJFC1=ZVS@C@UX<4d9R31<VAO0C1T7`3_iF21<VEP@BkS7D4f=;B:^7Ph0CQhN84hM[K1>7If@SQh>0E
oooo000Doooo2>7Ph0CQgml4hMkO?N7Ph0CMe=L4Q4Ho155JFPCH^ZH4hL6/0n71/`CQ`K@4hL6c1>6o
/@CQb;X4hL>f0n70[0CQa[D4hKV/1>6eY@CN/YX4gkRO1=VXV0?HZI<4eij>1=6NQ0C:Tgl4aiIl1<N@
N`>nSWX4aIV31<2>N4;Qh>0Eoooo000Doooo2>7Ph0CQgml4hMkO?N7Ph0CMe=L4Q4Ho155JFPCH^ZH4
hL6/0n71/`CQ`K@4hL6c1>6o/@CQb;X4hL>f0n70[0CQa[D4hKV/1>6eY@CN/YX4gkRO1=VXV0?HZI<4
eij>1=6NQ0C:Tgl4aiIl1<N@N`>nSWX4aIV31<2>N4;Qh>0Eoooo000Doooo2>7Ph0CQgml4hMkO?N7P
h0CMe=L4Q4Ho155JFPCH^ZH4hL6/0n71/`CQ`K@4hL6c1>6o/@CQb;X4hL>f0n70[0CQa[D4hKV/1>6e
Y@CN/YX4gkRO1=VXV0?HZI<4eij>1=6NQ0C:Tgl4aiIl1<N@N`>nSWX4aIV31<2>N4;Qh>0Eoooo000D
oooo2>7Ph0CQgml4hMkO?N7Ph0CMe=L4Q4Ho155JFPCH^ZH4hL6/0n71/`CQ`K@4hL6c1>6o/@CQb;X4
hL>f0n70[0CQa[D4hKV/1>6eY@CN/YX4gkRO1=VXV0?HZI<4eij>1=6NQ0C:Tgl4aiIl1<N@N`>nSWX4
aIV31<2>N4;Qh>0Eoooo000Doooo2>7Ph0CQhN84hMSI1>7NgcGQh>04h>3Q18eOBPC2]K<4?ci61>70
/PCQ_j/3hLJh1>6o/@CQa[P4hL2b1>6o/@CQa[T3hLNi1>6n[PCO^j@4hJRM1=ZVT@C?WhX4ejB?0mRT
R`CBXh`4aYF01=2DO`C9UH04`Y1h0l6@O0C0Tgl4^Xil1=oJfCkQh>0Eoooo000Doooo2>7Ph0CQhN84
hMSI1>7NgcGQh>04h>3Q18eOBPC2]K<4?ci61>70/PCQ_j/3hLJh1>6o/@CQa[P4hL2b1>6o/@CQa[T3
hLNi1>6n[PCO^j@4hJRM1=ZVT@C?WhX4ejB?0mRTR`CBXh`4aYF01=2DO`C9UH04`Y1h0l6@O0C0Tgl4
^Xil1=oJfCkQh>0Eoooo000Doooo2>7Ph0CQhN84hMSI1>7NgcGQh>04h>3Q18eOBPC2]K<4?ci61>70
/PCQ_j/3hLJh1>6o/@CQa[P4hL2b1>6o/@CQa[T3hLNi1>6n[PCO^j@4hJRM1=ZVT@C?WhX4ejB?0mRT
R`CBXh`4aYF01=2DO`C9UH04`Y1h0l6@O0C0Tgl4^Xil1=oJfCkQh>0Eoooo000Doooo2>7Ph0CQhN84
hMSI1>7NgcGQh>04h>3Q18eOBPC2]K<4?ci61>70/PCQ_j/3hLJh1>6o/@CQa[P4hL2b1>6o/@CQa[T3
hLNi1>6n[PCO^j@4hJRM1=ZVT@C?WhX4ejB?0mRTR`CBXh`4aYF01=2DO`C9UH04`Y1h0l6@O0C0Tgl4
^Xil1=oJfCkQh>0Eoooo000Doooo2>7Ph0CQgml4hN3P1>7IfCGQh>04RE]81>WRg@A<Cdl4f;ZV1>70
Z`OQ`;84hL2`1>70/@CQ`;84hL6d1>70/P?Qa[P4hZBJ1=VKS0CHR7l4f8Mk1=63M`CAUh@3d9V31=2I
O`C8TG`4ahmg1<J@N`C8T7`3b91h1;n<MPC3SWP4dK>Z:^7Ph0CQgml4hMkO3>7Ph1Goool001Coool8
hN3P1>7Og`CQh>04hMWI=N7Ph0B9FdP4jN;M14a?C`CH^ZH4hL2[1n70/PCQ`;04hL2a1>70/PCQ`K@4
hL2b0n76^0CRY9X4fI^<1=R8O`CHQg/4dH=g1=6GQ0?@VH<4d9Uo1<RAO0C7SgL4aY1k1<R@O0?8T7P4
_haf1<>>N0CA/jXZhN3P1>7Og`CQg]l<hN3P5Oooo`005?ooo`SQh>04hMoO1>7Ph0CQfMTehN3P18UK
B0CYh]d4C4m?1=RjYPCQ`:/7hL2b1>70/0CQ`;44hL2b1>71]0CQ`;83hLJh1>:TVPCIVh`4f8Qo1=R7
N`CAPgL4dIN40m2IP`C@VGl4b95l1<N?M`C6T7/4b91l0lR@N0BoS7H4`hih1=6cZR[Qh>04hMoO1>7N
g`cQh>0Eoooo000Doooo2>7Ph0CQgml4hN3P1>7IfCGQh>04RE]81>WRg@A<Cdl4f;ZV1>70Z`OQ`;84
hL2`1>70/@CQ`;84hL6d1>70/P?Qa[P4hZBJ1=VKS0CHR7l4f8Mk1=63M`CAUh@3d9V31=2IO`C8TG`4
ahmg1<J@N`C8T7`3b91h1;n<MPC3SWP4dK>Z:^7Ph0CQgml4hMkO3>7Ph1Goool001Coool8hN3P1>7Q
hPCQfMTfhN3P0mgDe0Cjknd4B4];1>76^0CQ`;44hL2[1>70/P?Q_Zd4hKf/1>6mY@CQ_k04hKna1>6n
/P?Q]J/4hZRL1=QhKPCGJ5`4cfiY1=1/H`C?JfP3d8Ie1<F:MPC5T7P4ahQd1;n?M`C8T7`3bI1l1<2>
M@C9S7X4^hYe1=_BcbKQh>04hN7R1>7If@cQh>0Eoooo000Doooo2>7Ph0CQhN84hMWI=^7Ph0?Me=@4
n^o]14Q;B`CQa[P4hL2a1>70Z`CQ`;83hKj]1>6m[0CQ_JD4hKn`1>6o/@CQ_[83hKF[1>:XW0CHN6h4
efQL1<m^J@C@K6<4cf]X0m26M@C5RWH4aI1h1<N8M0BoSgL4b91l0lV@O0C0SWD4bHaj1;^:M@CKd/lV
hN3P1>7QhPCQfMT<hN3P5Oooo`005?ooo`SQh>04hN7R1>7IfCKQh>03gMCD1?[_k@A8Bd/4hLJh1>70
/@CQ`:/4hL2b0n6n[@CQ_J`4hKfU1>6o/0CQ_k44hKjb0n6eZ`CRZ9`4f7Q^1=MXG0C?KVT4d6aS1<m[
J0?@QWD4aHYf1<F@N0C7R7@4_hmg1<R@O0?9T7`4`8ie1<V<NPBkRWD4fm;?9^7Ph0CQhN84hMWI3>7P
h1Goool001Cooom6hN3P0h5NE@BOViX4eknc1>70[PCQ`;04hL2[1>70/0?Q_J/4gk:K1=ngXPCQ^ZD4
hKbZ1>6TU`?NR7/4gIV=1=1ZE`C;P7<4aWEZ1=1PE0C3EdX3d6QP1<5eJPC0R7L4`8i/1;j:LPC6T7/3
b91l1<RBO0C8RWL4b9N21<6CP0CQgM`fhN3P5Oooo`005?ooodKQh>03PEiE19nKVPCG_k<4hL2^1>70
/0CQ`:/4hL2`0n6mZ`CO/Y/4gkNR1>6jY@CQ_:X4hJBG0mj8N`CMVHd4d6YG1<^0L`C6MFX4d61D1<=G
BP?@J604`GEZ1<28M`C0SV`4_XYb1<J@N`?8T7`4b99l1<R:M`C8Uh84`I>01>7Mg3KQh>0Eoooo000D
ooooA^7Ph0>1GUD4Wi^J1=No/`CQ`:h4hL2`1>70Z`CQ`;03hKf[1=nbV`CO]j84hKZU1>6lZPCQY9L3
gXQk1=fIS@C@JUL4bh1c1<IeJPC@H5@4`eM:0m1XH0C1MFX4`8Qg1<2>K0BnRW84aY1k0lR@O0C8TW`4
b8Yg1<RGPPC1Th04hMgL=^7Ph1Goool001Cooom6hN3P0h5NE@BOViX4eknc1>70[PCQ`;04hL2[1>70
/0?Q_J/4gk:K1=ngXPCQ^ZD4hKbZ1>6TU`?NR7/4gIV=1=1ZE`C;P7<4aWEZ1=1PE0C3EdX3d6QP1<5e
JPC0R7L4`8i/1;j:LPC6T7/3b91l1<RBO0C8RWL4b9N21<6CP0CQgM`fhN3P5Oooo`005?oooa3Qh>04
hMoO0n7Ngb_Qh>04d;^l0nS6/P@gAD`4f;ZV1>6lY@CO_j/4hL6]1>6lZ`?R]YP4eYn51=>PT@CPUHL4
ZS0L1<VJQ`?HQ7`4dgme1=6NUPBgIEP4aHQa1<J8J`BhJEl3[5911;eFB@BnM6L4_Xa_1<27J`C0TWX3
b9J01<ZBO0C8Tgl4b91l1<>@N`CKa;T4hMgL<^7Ph1Goool001Coool@hN3P1>7Og`?Qg]l[hN3P1=2k
_0?Xa[84=dE<1=RjYPCQ_:D4gkn[1>71[@CQ_:/3h[JH1=JOQ@CCX944h9F71:X`70C9VXL3f8Al1==o
M@CAWYH4]fEH1<F8L@C6R6/4^6UO0jaB@@BmETT4_WAW1;j<K`C0Qf/4`99j0lRFP0C:TW`4b9=o1<R@
O0C3T7/4flBi1>7Mg3;Qh>0Eoooo000Doooo4>7Ph0CQgml3hMkO:n7Ph0C@^k`3j<Jb13M5C0CH^ZH4
hKbU1=noZ`CQ`Jd4hKb[0n:fV0CFWhD4dj2A1>2EQ`BZ<1`4bIZ70mR4O0CCOgD4dIjF1;MUF0C5R744
aXQ[1;QYG`>/DT44_EI91;idI`BnS6l4`8M[1<2BNP?8UX04bY9l1<RCO`C8T7`4`i1k1=_4^@CQgM`b
hN3P5Oooo`005?oooa3Qh>04hMoO0n7Ngb_Qh>04d;^l0nS6/P@gAD`4f;ZV1>6lY@CO_j/4hL6]1>6l
Z`?R]YP4eYn51=>PT@CPUHL4ZS0L1<VJQ`?HQ7`4dgme1=6NUPBgIEP4aHQa1<J8J`BhJEl3[5911;eF
B@BnM6L4_Xa_1<27J`C0TWX3b9J01<ZBO0C8Tgl4b91l1<>@N`CKa;T4hMgL<^7Ph1Goool001Coool8
hN3P1>7Og`CQg]l4hN7R0n7IfB_Qh>04SfaT0hV6RPB]TH<4hL2Z1>:kZ0CG[Y/4hLJh1>6n[@?RWGd4
cha`1:4X8@C;W9P4hiRF16lk>P?D[Z<4dYF=1=RVWPCTg</4f85j1<FFRPB`QgH3XF1A16dh8`B/CT04
]H1]1;n9K0C8SG`3b9^71=>RQ@C:TG`4b9F01<RBOPC3Uh84fl_70moMgBoQh>0Eoooo000Doooo2>7P
h0CQgml4hMkO1>7QhP?QfMT[hN3P18m/I0>9QXX4[I631>70ZPCR^jP4ejjK1>76^0CQ_Zd3hYem1<n<
L0BQ:244bibH1>>HUPA_>cX3e:jS1=:ES@CHYYh4i=c;1=R1NPC5UXX4/8Mf0j5PD@A]>2<4[4i01;F0
K@BoRF`4b8el0lRKQ`CCXXD4bY5l1<REP0C8TWh4`iN21=_;a`?OgMd_hN3P5Oooo`005?ooo`SQh>04
hMoO1>7Ng`CQhN83hMWI:n7Ph0B?K6@3RHJ:1:fAP`CQ`:X4h[^X1=N^V`CQa[P4hKj]0n:MO@C?S704
XBPQ1<^LV0CSV9H4Kc/j0mB^X`CBUHd4f:JN1>CLb`CHPGX4aIJ:1;27MP>QH544KCPS1:a>@0BeP6d4
_hU/1<R=O0?8VhL4dj:51<ZAO0C8UH04b99n1<>GPPCKblL3gmgM;n7Ph1Goool001Coool8hN3P1>7O
g`CQg]l4hN7R0n7IfB_Qh>04SfaT0hV6RPB]TH<4hL2Z1>:kZ0CG[Y/4hLJh1>6n[@?RWGd4cha`1:4X
8@C;W9P4hiRF16lk>P?D[Z<4dYF=1=RVWPCTg</4f85j1<FFRPB`QgH3XF1A16dh8`B/CT04]H1]1;n9
K0C8SG`3b9^71=>RQ@C:TG`4b9F01<RBOPC3Uh84fl_70moMgBoQh>0Eoooo000Doooo2>7Ph0CQhN84
hMWI;^7Ph0COf]h4ODQ10b`mB0CG^:84hL2`1>;4[@CH[9X4hL2b1>2`VP?IV704_U]11:0X5`AX=CL4
_::F1=nk[@?Oa[d4hM?91>7:`@CR_[04eK2N1>2mZ@CP`;D3aJFD19Q^I@AL<bL4WE101;^7K`C4S7P3
dJB?1=:RS@CBWhD4b8ii1<R>NPC7Uh84`KBk0lo4aPCKf]d[hN3P5Oooo`005?ooo`SQh>04hN7R1>7I
fBkQh>04gm[N17e8@@</?DP4ekRR1>70/0CRa:d4f:bJ1>70/PCP/9X3fIQ`1;iK@@BP:1L4J3Dg1;bR
UPCO^jd3glJm1>7Cb@CQb/44h[j`1=F`WPCP_JT4h<2e0lFUU0BHKVD4G3<W19e@@0BkQfl4a8ah0m6T
S`CBXXd4dYn51<R>N@C8SWX4aiN21<6d^`??a<H4fm[M:n7Ph1Goool001Coool8hN3P1>7QhPCQfMT^
hN3P1=oJgPAmB443;3e81=NhXPCQ`;04h/B]1=R/VPCQ`;84h;2J0mVHL0BnFd44X2PG16Pe=`BlXYH4
gk^]0mo6_@CQdlT4hL[11>:n/0CE/9h4h;fY1>30]@?5YI@4V6iU15`c9`BMD404^hM_1<B<N0?AY8l4
dZ:=1=:OQ@C8SWT4b8ij1<NGPPC1];/3clC61=_JgB_Qh>0Eoooo000Doooo2>7Ph0CQhN84hMWI;^7P
h0COf]h4ODQ10b`mB0CG^:84hL2`1>;4[@CH[9X4hL2b1>2`VP?IV704_U]11:0X5`AX=CL4_::F1=nk
[@?Oa[d4hM?91>7:`@CR_[04eK2N1>2mZ@CP`;D3aJFD19Q^I@AL<bL4WE101;^7K`C4S7P3dJB?1=:R
S@CBWhD4b8ii1<R>NPC7Uh84`KBk0lo4aPCKf]d[hN3P5Oooo`005?oooc[Qh>04]9N816e0>0C3Xj83
;cI21=RjY0CQ_:@4hKZR1>6mYPCQ`:h4hkBM0mRIQPBjUGX4_WY]16m;APCCRX84f::@0mFFR0CMZ:04
gJ6?1=f?NPC<Je/4e8Af1<V=N`?NX8L4`h=e1;5mK`AJ5@T4WUY@1;f:N0??XXT4fZfB1=:KP`C7UX04
aXek1<VBOPC3/j@3_ZjZ1<2icB_Qh>0Eoooo000Doooo>^7Ph0BdUhP4KD0h1<>SXP<_=T84f;ZT1>6l
Y0CQ^Z84hKfV1>70[PCS]9d3f9V61;ZENPBnNVd4Kd]61=>:PPCHXY03eIJ81=fXX0CMXHl4gHmj1<a[
F`CDQ7H4bHek0mjPQ`C3PgD4/Ge_15XE2@BNFU04_HYh0lnRR@CJ[I84dY^31<NFP0C6SG/4bI9n1<>c
Y0>n[ZX4`;W=:n7Ph1Goool001CoooljhN3P1;BGR0A]@3P4`j>R0blf@PCH^Z@4hKbT1>6jXPCQ_JH4
hL2^1>>dW@?HVHH4^YEj1;ijK@A_BdH4dhZ21=RRT0?EUXP4gJRP1=fQS`CMSgX4c6]K1=B4MPC9SG/3
gZ271<>3M@BaOFl4FQD919iJD0BmRWP3cj:91=Z]TPCBVh<4aiJ01<J=N`C9TWh4`k>T0kj^ZPC0^Ld[
hN3P5Oooo`005?oooaCQh>03hMoO1>7Nga_Qh>04gmOJ14L/8`@n8ah46Rhh0jn=Q@CQ_ZL4hKZX1>6a
WPCO/Yh4hKVW1>>eW@?=Q6P4bIb;1=RkZ@CQaJl4h[:[1=b]XP?DZ9`4dZ^L1=jDRPC<VX`4c8Ef1<ag
JPC2Kf@3bXYk1<EZFPBkF4D4VcPZ16@T7PBcLfX3cIj61=Z/TPCBW804b8eh1;n>NPC8UX84SE4n0l[2
_PC0/l84gmgM9n7Ph1Goool001CooolDhN3P0n7Og`CQg]lKhN3P1=oGfPA7;2<4?R<N11X^>0>_SHD4
hKjW1>6jZ0CQ/Ih4gk:N1>6iY`CS]Id3cHAX1<VLR`CH^jT4hLF_1>:bZ`CL[J83e:RL1=:[W0CNU8X4
c9Z<1<b5MPC<MfX4`VmT0lZ:N`C5JUX4^eQ519/h:PAT91h4/g=Z0lfNQPCJ[984dYb01<R=N0BoSWX4
b9J218eA?P?:`[h4`;?21=oMgBOQh>0Eoooo000Doooo5>7Ph0?Qgml4hMkO6n7Ph0COemX4Ab`S13hS
7P@J;SP3[hf51>6nY`CQ^ZP4hK6N1=nbWPCQ^JL4hkFM0lf4J0C9W8/4f;^Y1>75[`CR/Z/4g:fR0mBX
W0CBZi`4gYB:1<bJS0C<QGH4c7MZ1<9_I0?:RW/4aFYJ1;]HA@BK>2X4I2@N1;=cJP?=WXH4fZbB1=:L
P0C8SGP4_hij1<RFPPB=DCh3b/:n1<2c`PCOgMdWhN3P5Oooo`005?oooaCQh>03hMoO1>7Nga_Qh>04
gmOJ14L/8`@n8ah46Rhh0jn=Q@CQ_ZL4hKZX1>6aWPCO/Yh4hKVW1>>eW@?=Q6P4bIb;1=RkZ@CQaJl4
h[:[1=b]XP?DZ9`4dZ^L1=jDRPC<VX`4c8Ef1<agJPC2Kf@3bXYk1<EZFPBkF4D4VcPZ16@T7PBcLfX3
cIj61=Z/TPCBW804b8eh1;n>NPC8UX84SE4n0l[2_PC0/l84gmgM9n7Ph1Goool001CooolDhN3P0n7Q
hPCQfMTKhN3P1>CPh`C_emH4AEED12`i@0?O_jl4hKnX1>6lY0CRZJ<4f;JS1>74Z`CSZid3eIJ01;=n
J`CO_:h4hLRj1>71/`CQ_k43hLRj1>6j[`CR^J<4fJRC1=ZVT@CAWX@4d9Mm0l><M@C?PW<4aGU[1;E^
GPBGEe84TE990l>AO0CHYHd4dYb01<RBN@BoRgL4b99n1:=bI@=@@Sl4fm?B1=SBdROQh>0Eoooo000D
oooo5>7Ph0?QhN84hMWI6n7Ph0CTh><4kmOF14EEE0@/>D03gkn_1>6oZ0CQ_:@4hZVS1=RfX`CQa:/4
hj^M0mFFP0BcOV/4gkb^1>78^PCQ`K<4hKna0n78^PCQ^Zl4h[VS1=VXT`CJYY44dIj41=2GO@?3S7D4
ch9c1<EiJ`BeKUh4UeMB195BB@?3TG`4f:F=1=:LP0C8TWT4_h]g1<RBOPBSLVD3D48o1=_CdPCHd]8W
hN3P5Oooo`005?oooaCQh>03hN7R1>7IfA_Qh>04i>3S1>oGePA5EE@4;3U00mno[`CQ_jP4hKbT1>:Y
X`CH]Z<4hLB[1>>[W@?EUX04/gi[1=nl[PCQb;X4hL6c1>6o/@?Qb;X4hKZ_1>:iX`CIZ9<4fZJA1=6N
Q0C@Ugd3`hae1<n2L`C5NF/4]FiN19MGDPBADTT3`i5l1=RUS@CBW804b99i1;n;M`C8TWh4Xg9U0e12
?`CKdm84f=;B9n7Ph1Goool001CooolDhN3P0n7QhPCQfMTKhN3P1>CPh`C_emH4AEED12`i@0?O_jl4
hKnX1>6lY0CRZJ<4f;JS1>74Z`CSZid3eIJ01;=nJ`CO_:h4hLRj1>71/`CQ_k43hLRj1>6j[`CR^J<4
fJRC1=ZVT@CAWX@4d9Mm0l><M@C?PW<4aGU[1;E^GPBGEe84TE990l>AO0CHYHd4dYb01<RBN@BoRgL4
b99n1:=bI@=@@Sl4fm?B1=SBdROQh>0Eoooo000Doooo=^7Ph0CVgm84al391>;5/PCJ[Y/3ekNQ1=o0
ZPCQ^ZH4hLB^1>6]Z@CQ`Jh4i<6Y0mBSS0C6QG84djVE1=no/0CQbK/4hL6c0n70/`CQbkP4hZ^O1=RO
R0CHXhX4ci]o1<^AO0>kRF/4_GmZ1;f7JPBmOfX4_XAZ1;N2N`>oSW<4dIf81=2GO0C7S7P4_Xmc1<F?
NPAb@cT3CDe51;^_[B_Qh>0Eoooo000Doooo=^7Ph0CVgm84al391>;5/PCJ[Y/3ekNQ1=o0ZPCQ^ZH4
hLB^1>6]Z@CQ`Jh4i<6Y0mBSS0C6QG84djVE1=no/0CQbK/4hL6c0n70/`CQbkP4hZ^O1=ROR0CHXhX4
ci]o1<^AO0>kRF/4_GmZ1;f7JPBmOfX4_XAZ1;N2N`>oSW<4dIf81=2GO0C7S7P4_Xmc1<F?NPAb@cT3
CDe51;^_[B_Qh>0Eoooo000Doooo=^7Ph0CVgm84al391>;5/PCJ[Y/3ekNQ1=o0ZPCQ^ZH4hLB^1>6]
Z@CQ`Jh4i<6Y0mBSS0C6QG84djVE1=no/0CQbK/4hL6c0n70/`CQbkP4hZ^O1=ROR0CHXhX4ci]o1<^A
O0>kRF/4_GmZ1;f7JPBmOfX4_XAZ1;N2N`>oSW<4dIf81=2GO0C7S7P4_Xmc1<F?NPAb@cT3CDe51;^_
[B_Qh>0Eoooo000Doooo=^7Ph0CVgm84al391>;5/PCJ[Y/3ekNQ1=o0ZPCQ^ZH4hLB^1>6]Z@CQ`Jh4
i<6Y0mBSS0C6QG84djVE1=no/0CQbK/4hL6c0n70/`CQbkP4hZ^O1=ROR0CHXhX4ci]o1<^AO0>kRF/4
_GmZ1;f7JPBmOfX4_XAZ1;N2N`>oSW<4dIf81=2GO0C7S7P4_Xmc1<F?NPAb@cT3CDe51;^_[B_Qh>0E
oooo000Doooo<^7Ph0CQg]h4gmcF1>6lX`CN/YX4fkjc0m>gY0CH^:D4hL6]1>73]@CQ`K@4hLVk1>:l
/@?L/9`4e9V31<J;N`CG]:44hLJi1>70/`?Q^JX4glFd1>:iW`CHY8h4chA^1<nGOPC2QV`3/H=[1;R1
J0BiOfD4^H9T1;QhH0BeQ6h3b9N21=2JP`C@TW`4`8Qd1<2:N0C0Tg/4@b<V0b/b=0C7_lh[hN3P5Ooo
o`005?oooc;Qh>04hMkN1=oLePCQ_:<4g[:J1=^n/`?C]j@4f;RU1>71[@CQ`kD4hL6d1>79^`CR_;43
g;2L1=BIP`C6Rg/4ekBQ1>76^@CQ`;<3hKVZ1=o5]0CR^Il4f:B>1<n4KPC?Ugh4`XI/0k63J`BhPFP4
^GmU1;V2I0BhN604]HA^0lRGPPC@VX<4d99l1<28M0C0RWP4`9=k14<S9P<[<S@4ako>:n7Ph1Goool0
01CooolbhN3P1>7NgPCOg=H4hKbS1=jbVPCK_[<3dkNT1=RhY@CQ`Jd4hL>e1>71]0CQbK/4h[ba0mb`
W0CDVH<4aX]k1=NdX@CQa[T4hL2c0n6iZPCOaK@4h[VO1=RTSPC?Q6h4ciMn1<:6K0>aPf/4^85X1;Uo
I@BiPV@4^7QP1;F4KP?8Uh84d9Z31=2BO0C0R7@4`8Yh1<2CN`A38bH3:c8d1<NocR_Qh>0Eoooo000D
oooo<^7Ph0CQg]h4gmcF1>6lX`CN/YX4fkjc0m>gY0CH^:D4hL6]1>73]@CQ`K@4hLVk1>:l/@?L/9`4
e9V31<J;N`CG]:44hLJi1>70/`?Q^JX4glFd1>:iW`CHY8h4chA^1<nGOPC2QV`3/H=[1;R1J0BiOfD4
^H9T1;QhH0BeQ6h3b9N21=2JP`C@TW`4`8Qd1<2:N0C0Tg/4@b<V0b/b=0C7_lh[hN3P5Oooo`005?oo
oc;Qh>04h]cB1=S=b@CR^9l4ejRA1=>RQ`>m[Zd4hKJT1>70/`cQb;X4hL^h0n:^XPCLZXl4chmj1=FU
T`CQ`;<4hL^k0n:^Z@CH^ZP4i;jY1=:RS@CCVX@4`X5_1<:8L0>hMf@4^7mX1;N2L@C2RFh4_8]e1;V5
L0?@UX04d9F01<VBO0C1RGD4`8Yc1;j?NPAP<2L3;2DX19F>RPCQg]lWhN3P5Oooo`005?oooc;Qh>04
h]cB1=S=b@CR^9l4ejRA1=>RQ`>m[Zd4hKJT1>70/`cQb;X4hL^h0n:^XPCLZXl4chmj1=FUT`CQ`;<4
hL^k0n:^Z@CH^ZP4i;jY1=:RS@CCVX@4`X5_1<:8L0>hMf@4^7mX1;N2L@C2RFh4_8]e1;V5L0?@UX04
d9F01<VBO0C1RGD4`8Yc1;j?NPAP<2L3;2DX19F>RPCQg]lWhN3P5Oooo`005?oooc;Qh>04h]cB1=S=
b@CR^9l4ejRA1=>RQ`>m[Zd4hKJT1>70/`cQb;X4hL^h0n:^XPCLZXl4chmj1=FUT`CQ`;<4hL^k0n:^
Z@CH^ZP4i;jY1=:RS@CCVX@4`X5_1<:8L0>hMf@4^7mX1;N2L@C2RFh4_8]e1;V5L0?@UX04d9F01<VB
O0C1RGD4`8Yc1;j?NPAP<2L3;2DX19F>RPCQg]lWhN3P5Oooo`005?oooc;Qh>04h]cB1=S=b@CR^9l4
ejRA1=>RQ`>m[Zd4hKJT1>70/`cQb;X4hL^h0n:^XPCLZXl4chmj1=FUT`CQ`;<4hL^k0n:^Z@CH^ZP4
i;jY1=:RS@CCVX@4`X5_1<:8L0>hMf@4^7mX1;N2L@C2RFh4_8]e1;V5L0?@UX04d9F01<VBO0C1RGD4
`8Yc1;j?NPAP<2L3;2DX19F>RPCQg]lWhN3P5Oooo`005?oooc;Qh>04hMoH1>6nYPCLX844cJ2=1<NM
S@?H^Z@4hJbU1>70/`SQbK`4hLRj1>77^P?Q`jd4hk2H1=6RQ@C=U884gkf_1>76]@OQ`K<4h/2]1=VQ
S@C@VX<4ai1l1<R@NP>jP6H4^GUT1;N1KPBoSGh4b9611=:LQ`?BXX`4b9F11<NAO0C7TW`4`8]i1<2E
OPCIU6`3ES<Z148_;PBo^KXWhN3P5Oooo`005?oooc;Qh>04hMoH1>6nYPCLX844cJ2=1<NMS@?H^Z@4
hJbU1>70/`SQbK`4hLRj1>77^P?Q`jd4hk2H1=6RQ@C=U884gkf_1>76]@OQ`K<4h/2]1=VQS@C@VX<4
ai1l1<R@NP>jP6H4^GUT1;N1KPBoSGh4b9611=:LQ`?BXX`4b9F11<NAO0C7TW`4`8]i1<2EOPCIU6`3
ES<Z148_;PBo^KXWhN3P5Oooo`005?oooc;Qh>04hMoH1>6nYPCLX844cJ2=1<NMS@?H^Z@4hJbU1>70
/`SQbK`4hLRj1>77^P?Q`jd4hk2H1=6RQ@C=U884gkf_1>76]@OQ`K<4h/2]1=VQS@C@VX<4ai1l1<R@
NP>jP6H4^GUT1;N1KPBoSGh4b9611=:LQ`?BXX`4b9F11<NAO0C7TW`4`8]i1<2EOPCIU6`3ES<Z148_
;PBo^KXWhN3P5Oooo`005?ooobkQh>04hM[D1>32/@CKQW44ej6:1;AoK@CA^j@3hJbT1>70Z`CQ`;<4
hLJg1>7?a@CQb;X4hLNi0n6n[PCR`:L4djRF1=2VS`CH^Z<4hKVZ0mnkY@CQ_[44h[BN1=VQR0C7S7L4
aHQb1;j<K@>jO6H4^gmT1;N1L0BoSgd4cib=1=ZVT@?BWHL4b9Z31<VEP0C1T7P4`8eg1<2BO`C<VhD3
`XQ/18IDB0A:A4@WhN3P5Oooo`005?ooobkQh>04hM[D1>32/@CKQW44ej6:1;AoK@CA^j@3hJbT1>70
Z`CQ`;<4hLJg1>7?a@CQb;X4hLNi0n6n[PCR`:L4djRF1=2VS`CH^Z<4hKVZ0mnkY@CQ_[44h[BN1=VQ
R0C7S7L4aHQb1;j<K@>jO6H4^gmT1;N1L0BoSgd4cib=1=ZVT@?BWHL4b9Z31<VEP0C1T7P4`8eg1<2B
O`C<VhD3`XQ/18IDB0A:A4@WhN3P5Oooo`005?ooobkQh>04hM[D1>32/@CKQW44ej6:1;AoK@CA^j@3
hJbT1>70Z`CQ`;<4hLJg1>7?a@CQb;X4hLNi0n6n[PCR`:L4djRF1=2VS`CH^Z<4hKVZ0mnkY@CQ_[44
h[BN1=VQR0C7S7L4aHQb1;j<K@>jO6H4^gmT1;N1L0BoSgd4cib=1=ZVT@?BWHL4b9Z31<VEP0C1T7P4
`8eg1<2BO`C<VhD3`XQ/18IDB0A:A4@WhN3P5Oooo`005?ooobkQh>04hM[D1>32/@CKQW44ej6:1;Ao
K@CA^j@3hJbT1>70Z`CQ`;<4hLJg1>7?a@CQb;X4hLNi0n6n[PCR`:L4djRF1=2VS`CH^Z<4hKVZ0mnk
Y@CQ_[44h[BN1=VQR0C7S7L4aHQb1;j<K@>jO6H4^gmT1;N1L0BoSgd4cib=1=ZVT@?BWHL4b9Z31<VE
P0C1T7P4`8eg1<2BO`C<VhD3`XQ/18IDB0A:A4@WhN3P5Oooo`005?ooobkQh>04hMCB1>>VUPCBOV/4
`6iU1<2>OPBm/ZD3hL6_1>71[@CQ`;<8hLRj1>76^0CQa[D3h[n^1=RgX0CJ/I`4ekRU1>71[`CRaK43
f:bR1>70YPCSZ9/4d9Un1<F4L0BmP6/4/g]W0l25J@BYOfl4^HEd1<RMR@C?XXh4fZJA0m:NR0C8UX04
b8el1<V<O0C0SGD4aXam1<N@L@>nQW84]W]V1>;QhROQh>0Eoooo000Doooo;^7Ph0CQe=84hjJF1=9n
J`C0KVD4`8in1;fbY@?Q`Jl4hL6]1>70/`SQb;X4hLJh1>76]@?R_jh4f;NP1=ZaW0CG^:D4hL6_1>;5
/@?H[:84hL2V1>>XV`C@VGh4aHA`1;f0J`BcNfL3`8EY1:UoK`BiQG@4b9f91<nRSPCJYY43dYj81<RF
P0C8SG`4bHal1<2=M@C6S7d4ai1a0kj6LPBfNfH4h^7R9n7Ph1Goool001Coool^hN3P1>7DdPCSYYH4
dWi[1<1^I@C0SWh4_K:U0n71[`CQ`Jd4hL2c2>78^PCQa[P4hLJe0n:o[PCH]j04f[6L1=NhY@CQ`Jl4
h/Fa0mR/XPCQ`:H4hjRK1=2IOPC5Q704_H1[1;=kI`?0QFT4ZGm_1;V5M0C8WHT4cj:>1=ZVT@?BWXP4
b9J01<R=O0C9S7`4`8ee1<J<O@C7T743_XIb1;IkIPCRhN8WhN3P5Oooo`005?ooobkQh>04hMCB1>>V
UPCBOV/4`6iU1<2>OPBm/ZD3hL6_1>71[@CQ`;<8hLRj1>76^0CQa[D3h[n^1=RgX0CJ/I`4ekRU1>71
[`CRaK43f:bR1>70YPCSZ9/4d9Un1<F4L0BmP6/4/g]W0l25J@BYOfl4^HEd1<RMR@C?XXh4fZJA0m:N
R0C8UX04b8el1<V<O0C0SGD4aXam1<N@L@>nQW84]W]V1>;QhROQh>0Eoooo000Doooo:n7Ph0?Qg=L4
hMc?1>>VU@C@PFP4_gE[1;^EQ@CH^ZD3hL2c1>79^`CQ`;84hLFg1>73/@COaK<4hKV]0n:iY0CG/i`4
hJjI1=NgX`CQ_jl4hLJf0n70/PCQ^k04hjF>1=:GP0C0QG04^H5/1;60K@>`PVd4]hMe1<JJQ@CAXHd4
dJF@1=RRS0?BWHL4b99l1<R=M`C7R7L4ah]h1;n=O0C;VhT3^X5/1;R5M0CQg]lWhN3P5Oooo`005?oo
ob_Qh>03hMcG1>7Lc`CSYYD4d85X1;meJ`BkUHD4f;ZU0n70/`CQbK/4hL2b1>75]`CQ`k44glFc1>6i
[@?R^J@4ek>L1>6^V@CG]j<4hKn_1>76]P?Q`;84hK^`1>>USPCBUh04`8E`1;V1K0BaP6d3/89]1;N7
M@C6VXD4dJ6=1=6UT0CHXX`3dYf71<RBO0C8SGL4ahQg1<N;N0BoSG`4bi^90kZ1K0BhQG@4hMkO9n7P
h1Goool001Coool[hN3P0n7Le`CQg<l4hjJE1=21J0BoMF/4^iF51=RjY@?Q`;<4hLVk1>70/PCQaKL4
hL>a1=o5/`CQ^Jd3h[VT1=NcW0CQ[YT4ekNS1>6o[`CQa[H3hL2b1>6k/0CSYHh4dYN01<25L0BiPF`4
/H1]0k22K@BgQgD4aYZ51=6QS@CAYI04f::<0m:MQ`C8TW`4b8eg1<N8M`C7RgP4_hel1<^KR@>jPF`4
^8Ed1>7NgbOQh>0Eoooo000Doooo:n7Ph0?Qg=L4hMc?1>>VU@C@PFP4_gE[1;^EQ@CH^ZD3hL2c1>79
^`CQ`;84hLFg1>73/@COaK<4hKV]0n:iY0CG/i`4hJjI1=NgX`CQ_jl4hLJf0n70/PCQ^k04hjF>1=:G
P0C0QG04^H5/1;60K@>`PVd4]hMe1<JJQ@CAXHd4dJF@1=RRS0?BWHL4b99l1<R=M`C7R7L4ah]h1;n=
O0C;VhT3^X5/1;R5M0CQg]lWhN3P5Oooo`005?ooob_Qh>03h<nk1=NOQPBmOF04_7MR1;1oK0C3W8/4
hL2[0n6o/@CQaKL4hLJe1>6n[0CR_Zd4ek:O1=jiX0?OYYl4fK:N1=V]V@CG/Yd4hL2b1>70[0?Q`;84
hL:_1>:XV@CBSgT4`8E`1;R0K0BjPVl3/XYh1;nBO@C8VXH4cin:1=RXT`CAXXd3dYV41<RJQ@C7SGT4
ahUe1<27N0BoTWd4aGiO0lJ9M`C1Pf/4]j2O9n7Ph1Goool001Coool[hN3P0n3?^`CGWhH4_GeP1;ag
HPB`Of`4`ib;1>70Z`?Q_k44hLFg1>76]@CQ_Z`4h[j]1=NbW`CN^J03gjJO1=VbWPCI[IT4ek:M1>70
/PCQ`:`3hL2b1>72[`CRZ9T4dXmi1<25L0BhP6`4^X9_0k::N0BoTWd4b9Z61<nORPCHZ9<4dJ:=0m:I
Q0C8VXD4ahei1<N9M@C0QgP4_i9m1<EnG`?6RGL4`H=[1;NPWbOQh>0Eoooo000Doooo:n7Ph0?Pck/4
ein61;emH0BlMf84/7m/1<>LR`CQ`:/3hKna1>75]`CQa[D4hKj/1>:n[@CG/Yl4g[VP0mnVW`CI/Yh4
fJfI1=NbW@CQ`;84hL2/0n70/PCQ`Zl4hZRI1=:?N@C0QG04^81/1;Z2K`>bRWP4_i9m1<RJQPC?WhX4
f:RC1=6RS@?BVH@4b9Z51<N=N@C7RGD4`8Mh1;nBO@C5OUl3aXUg1<63J`BgX9lWhN3P5Oooo`005?oo
ob_Qh>03h<nk1=NOQPBmOF04_7MR1;1oK0C3W8/4hL2[0n6o/@CQaKL4hLJe1>6n[0CR_Zd4ek:O1=ji
X0?OYYl4fK:N1=V]V@CG/Yd4hL2b1>70[0?Q`;84hL:_1>:XV@CBSgT4`8E`1;R0K0BjPVl3/XYh1;nB
O@C8VXH4cin:1=RXT`CAXXd3dYV41<RJQ@C7SGT4ahUe1<27N0BoTWd4aGiO0lJ9M`C1Pf/4]j2O9n7P
h1Goool001Coool[hN3P0n:mX@BFC2h4UeE616`o>@B8JV84cJRH1>70[0?Q`;04hL2^1>70/PCQ`Jh4
h[^Y1=ZnZPCLZil3dJ:@1=JNS@CE/I/4ekJP1=noZPCQ`;83hL2`1>:jZ`CIZi84cXYl1;j3K0BfO6L4
]H5^0l2<NPBnT7/4cYJ61<nLRPC@V8<4cZ2:0lnJP`C5U7l4aiF01<2>N@C0R7L4_XQi1<FBL0>cJU84
aHij1;M/FBOQh>0Eoooo000Doooo:n7Ph0?R_J44UT`^19MEAPA/?cT4R6YR1<fXV0CQ`:`3hL2`1>70
[PCQ`;84hL6^1>:kZ@CJ_ZX4g:^O0m6RT0CFWXd4eK6K1=NfX0CO_jX4hL2b0n70/0CR^Z/4fJ^B1<j:
O0BnPf`4]WaW1;F1KP?0S7X4_Y1k1<jFQPC?W8X4d9R31<jPRP??VX<4aIAo1<NEP0C0SWT4`8Qg1;j8
N@C5TW03/fYB1<F>NPBgK5TWhN3P5Oooo`005?ooob_Qh>03h[fQ19I<;PBGEDH4K3li18QZHPC=Z9P4
hL2/0n70/0CQ`:h4hL2b1>71[PCR^jT4f[jZ1=b[W`?AXY04eYj=1=FaV`CG]Z04gknZ1>70/P?Q`;04
h[Z[1=V[TPC>RW`4_X=/1;IlI`BePFh3`8aj1;j@N`C>UXH4cib:1=2HP`C>X8X3ciZ31<FDO`C7UH04
`8ii1<28M`BnR7T4aI9`0k=ZDPC5SWX4]faI9n7Ph1Goool001CooolWhN3P1>7Ng0?Ud/P4dGML164g
:`AY?3P4BDQ?1<fXU@CQ_Z`3gkna1>70Z`CO]Y`4fK6M1=>PR0C?W8D4d9n>0lf?Q@C=TH84a95l1=FX
T`CE]Z84hL2b0n70/`CR_:L4fj:?1<R<K`BhN6H4^81X1:ikI`>jQG84_i1k1<:>NPC4VXD4ciN51<JB
OP?9VH@4`I5l1<2@O0C0SWT4`8Qg1<2:O0BcJU43Wdhd1:ibEPBfJe`WhN3P5Oooo`005?ooobOQh>04
hMkL0nGBb0CAMe`4HCL[16Tl>0A9B4l4cJRE1>6n[0?O_k44hL2[1=nfW0CI/Id4dj281<nLQ@C@Whh3
cHn51<fAPPC4TG`4eJRC1=FfXPCQ`;83hL2c1>:lY`CKXXl4b8a_1;QhIPBhP6P4[W]W0kZ5LPBoT7/4
`Xij1<BJQ@C?UhD4aY9n0lVIQ0C1TG`4`91l1<2>N@C0R7L4`8Yl1;=ZD@>OCS@4[W9F1;I[G2OQh>0E
oooo000Doooo9n7Ph0CQg]`3iM;81=5gG0AQ=b/4JC`h14U8C`C=Z9D4hKj/0mno/@CQ`:/4gkJL1=Va
W@CCX8P4cib51=2OSP?=ShD4cI621<BAO0CEZ9<4eKJR1>70/P?Q`;<4h[bW1=^RS`C8S6l4^7QV1;R0
J0B^NfL3^XEb1;n@N`C2SWX4a9Z51<nGQ@C6TWh3bIV41<6AO0C0T7`4`8ii1<28M`C0RW`4/fYA0im>
=0B^LUH4]V]L9n7Ph1Goool001CooolWhN3P1>7Ng0?Ud/P4dGML164g:`AY?3P4BDQ?1<fXU@CQ_Z`3
gkna1>70Z`CO]Y`4fK6M1=>PR0C?W8D4d9n>0lf?Q@C=TH84a95l1=FXT`CE]Z84hL2b0n70/`CR_:L4
fj:?1<R<K`BhN6H4^81X1:ikI`>jQG84_i1k1<:>NPC4VXD4ciN51<JBOP?9VH@4`I5l1<2@O0C0SWT4
`8Qg1<2:O0BcJU43Wdhd1:ibEPBfJe`WhN3P5Oooo`005?ooobOQh>04hMK:0n;0/@AL5Q04B28M14<Z
9P@mA4`4cjVF1>6nY`?H^:84hL2`1>K1Z0C6V844^XU`18QQEPA^BD43QE0j1:9XF`BcGDD4/5Y31<2H
QPCO_Jl3hL2b1>;0[@CKXhl4b8]`1;J4I@BdME`4[XAb0kb:M`BgT7d4/hai1<2;NPC3UGl4^i5m0lRH
P`C8UX04_Heh1;Z=N0BlRgL4`8]l1;adFP>BC3T4Sdm01:ePABOQh>0Eoooo000Doooo9n7Ph0CQe/X3
h/2a15`F40A88Qd4@bXV13e4C0C?ZIH4hKjW0mRhXPCQ`;04i/6X1<JHP@BjRG04R65F16i9@@>5D3X4
XVQK1;=MA@B`FT<4`9R61=nm[`?Q`;84h/2]1=^SS`C8Rg04]XAU1;AeG0B^Q783_8Yg1;N@O@BcS7T4
`8]j1<>EO`BkTGd3b9R31<RFP0BmSGP4^Xeh1;b;M`C0Rg`4_7AJ0i9<>@B?Cd04[F159n7Ph1Goool0
01CooolWhN3P1>7FbP?R`;44G1H@14PR7@A3:RH4?DA<1<nYUPCQ_ZL3f;RR1>70/0CV`JP4aYR11;Z9
L0B8HEH4KTU10hE@>PBRJ5/4/ee51;1J@`C0V8H4gkf_0n70/PCR`:d4fj>?1<R;L0BfQ6D4]7EL1:j4
LP>lRWL4]i1m1;><N@C0RgX4`iEo1;^AO@?8V8<4b9J01;f=N0BjSGP4_8]g1<2;O0BlM5X3TT`i18m?
@0B]H4DWhN3P5Oooo`005?ooobOQh>04hMK:0n;0/@AL5Q04B28M14<Z9P@mA4`4cjVF1>6nY`?H^:84
hL2`1>K1Z0C6V844^XU`18QQEPA^BD43QE0j1:9XF`BcGDD4/5Y31<2HQPCO_Jl3hL2b1>;0[@CKXhl4
b8]`1;J4I@BdME`4[XAb0kb:M`BgT7d4/hai1<2;NPC3UGl4^i5m0lRHP`C8UX04_Heh1;Z=N0BlRgL4
`8]l1;adFP>BC3T4Sdm01:ePABOQh>0Eoooo000Doooo8n7Ph0CPh>44i=cA0m^RR@BUFU04;aLF13XN
7@@M<Sh4f;>O1=ViX`?O^:<4hL2Z1>;3[PCQ[iL4^iN7199SD@A<:RH3B2XR1615?`BFI544W6IJ19AL
E@CG/il3hLBg1>;3/`CKZI04`h9[1;9fFPB;:AH4V6MH0kR1H@BiPFP4ZVmF1;V4KPBmQgL4[HUc0lFD
OPC7UH04`8Yd1;27L`B^QgL4_HQc1:YSD@>CF4H4UEiC1:eA?`CRhN8ShN3P5Oooo`005?ooob?Qh>04
h>3Q1>CLd@?KXXT4YEY@12lG5P@j7Qd47C8n1=RcW`CI^J<3gkRS1>70ZPCR`jh4hJnG1;^GQ`BBHe44
C2XV0dPZ8PAPACl4UVAA19aVFPBDG5D4ek>O0n74]`CR`k<4fjV@1<>2J`BbMUX4RbTF19QWF0>hPF44
^H5X1:Y_EPBiQ6h4_HMg1:f9L`?5U7h4aiF01<2:M0B`Qg<4[XMg1;f8L`BZHe43TeQ619END`B]DCl4
h^7R8n7Ph1Goool001CooolShN3P1>3Ph@CTg=43fj:91:EJD0@_5aH4>QhM11db?PCH/il4fKVS0mnh
X`CQ`:X4h/>^1>6_U`BkUhL4TV=A14`Z9P=8:R84H4Do19ITD@BLIUX4U5aE1=NcW`?Qa;L4h/>c1=^Y
T0C3PV/4/WIJ18/Y5PBHIeP3^85Q1;V1J0BZKeH4^HA^1;f7M`B]RG<3aIAn1<NEP0C0RW@4/8Mc1:j7
M`BmR7<4ZV=A0i=HAPBEGU<4[E4o1>;QhR?Qh>0Eoooo000Doooo8n7Ph0CPh>44i=cA0m^RR@BUFU04
;aLF13XN7@@M<Sh4f;>O1=ViX`?O^:<4hL2Z1>;3[PCQ[iL4^iN7199SD@A<:RH3B2XR1615?`BFI544
W6IJ19ALE@CG/il3hLBg1>;3/`CKZI04`h9[1;9fFPB;:AH4V6MH0kR1H@BiPFP4ZVmF1;V4KPBmQgL4
[HUc0lFDOPC7UH04`8Yd1;27L`B^QgL4_HQc1:YSD@>CF4H4UEiC1:eA?`CRhN8ShN3P5Oooo`005?oo
o`CQg]h4hMkO1>7Og`CQg]lChN3P17<Z8@C4/ZD3hZbE1;ATD@@n9S44:QPG11lY=`CG]j44hL2Z0mVh
XPCO_JH4gknZ1>K4/`C8WHL4jJVC195gJ@=WDdP4K512175[HPBOM6@4aYB31=NgX`?Qa[L4h/^k1=^]
T`C<R6/4ZW5M1:eYC`A^@Ch3QemF120730AiBC`4Le=716m2<@B@JE/3Yg5A1;F0I@BnS7H4/8=`1:j8
L`BgOFX4Qdhl0fm0=`B:IUX4]VaN1>_YjB?Qh>0Eoooo000Doooo1>7NgPCQg]l4hMoO1>7Nga?Qh>04
LbXQ1<BbY@?R[9D4]6AA13hV<@@Z61L47bTg1=NgX@CQ`:X3fKRR1=nmYPCO_jX4i/Bc1<RMQ`CYZI<4
TGMY0fMCB0A/D484LF]R19mdI0C6U8<4ekNS0n76]`CRbk/4fjfC1<b8J`BZLEd4[FU?16i1?P>7GeH4
80L<17U9?0AcDdL4Kd8a191YF`>WLE44]H1U1;j<MPB`Pg04[XQc1;MmJPB7CS`3Kd0g18YVFPBfK5h4
jnWY8n7Ph1Goool001Coool4hMkN1>7Ng`CQgml4hMkO4n7Ph0Ac:R44a;:U0n:/U@BdI544?RHa12XH
5`@O:CL4ekNQ1>70ZP?I^:84gkfV1=noZPCVa;<4b9f71>VYT`BAMfT3Ie=816a@@PAaJf84WgAT1<JD
P`CG]j<3hLJg1>;;^`CK[I<4c8Q[1:YaG@B]JDl4KT4n0hMOEP@P1``4NDTl17=CA`A_@S44T6UK0jMa
D@BeP6D4_Xaf1;23L0B^R7<4]geZ18M>?0=_@3L4RVIJ1;I/GPC[jNTShN3P5Oooo`005?ooo`CQg]h4
hMkO1>7Og`CQg]lChN3P17<Z8@C4/ZD3hZbE1;ATD@@n9S44:QPG11lY=`CG]j44hL2Z0mVhXPCO_JH4
gknZ1>K4/`C8WHL4jJVC195gJ@=WDdP4K512175[HPBOM6@4aYB31=NgX`?Qa[L4h/^k1=^]T`C<R6/4
ZW5M1:eYC`A^@Ch3QemF120730AiBC`4Le=716m2<@B@JE/3Yg5A1;F0I@BnS7H4/8=`1:j8L`BgOFX4
Qdhl0fm0=`B:IUX4]VaN1>_YjB?Qh>0Eoooo000Doooo1>7Hf@CQemP4hN7R1>7If@oQh>04OT<l17A4
?@@/0003T4m015P]>0@f7a`4=R0Q10/T<`CI^:84ekRU0n2ZU@CDYi04dk>O1>;3]PCL`:d4f:VG1<FC
O`?7Uh<4/89/1:Z0J`C0V804dIf;1=N`W@?Qb;X4h/:c1=^^V0C8SW84^H1R1:iiG`BTKeh3YG][134K
80@Z7AX4HCdi15Dk=@AGA3T3RfMJ195aG@BkOFD4/HMc1:j;M0B@D4H4Jd0`0eTb9`ATBSl4_7aW1>WW
ib?Qh>0Eoooo000Doooo1>7Hf@CQemP4hN7R1>7If@oQh>04OT<l17A4?@@/0003T4m015P]>0@f7a`4
=R0Q10/T<`CI^:84ekRU0n2ZU@CDYi04dk>O1>;3]PCL`:d4f:VG1<FCO`?7Uh<4/89/1:Z0J`C0V804
dIf;1=N`W@?Qb;X4h/:c1=^^V0C8SW84^H1R1:iiG`BTKeh3YG][134K80@Z7AX4HCdi15Dk=@AGA3T3
RfMJ195aG@BkOFD4/HMc1:j;M0B@D4H4Jd0`0eTb9`ATBSl4_7aW1>WWib?Qh>0Eoooo000Doooo1>7H
f@CQemP4hN7R1>7If@oQh>04OT<l17A4?@@/0003T4m015P]>0@f7a`4=R0Q10/T<`CI^:84ekRU0n2Z
U@CDYi04dk>O1>;3]PCL`:d4f:VG1<FCO`?7Uh<4/89/1:Z0J`C0V804dIf;1=N`W@?Qb;X4h/:c1=^^
V0C8SW84^H1R1:iiG`BTKeh3YG][134K80@Z7AX4HCdi15Dk=@AGA3T3RfMJ195aG@BkOFD4/HMc1:j;
M0B@D4H4Jd0`0eTb9`ATBSl4_7aW1>WWib?Qh>0Eoooo000Doooo1>7Hf@CQemP4hN7R1>7If@oQh>04
OT<l17A4?@@/0003T4m015P]>0@f7a`4=R0Q10/T<`CI^:84ekRU0n2ZU@CDYi04dk>O1>;3]PCL`:d4
f:VG1<FCO`?7Uh<4/89/1:Z0J`C0V804dIf;1=N`W@?Qb;X4h/:c1=^^V0C8SW84^H1R1:iiG`BTKeh3
YG][134K80@Z7AX4HCdi15Dk=@AGA3T3RfMJ195aG@BkOFD4/HMc1:j;M0B@D4H4Jd0`0eTb9`ATBSl4
_7aW1>WWib?Qh>0Eoooo000Doooo1>7Jf`CQfMTGhN3P18]:@PA:;2D4@b8P0cHN7P@S3A84=AhP13PN
7@@M;SX4f;NQ1=VgX0?Ub;P4cIF71;b1J@C=VX<4b9^31;R5L`BVIED3X69;1:Y]E0B_JE84`YEm1=FY
UPCG/Id3hLFd1>;2[@CKYYD4b9Em1;UkH0B`R6@4]H1V0l>DO@CBTWX4Bdi>16m=@0AkETX4F5E@0i1^
F0BXNFL4_Y5e1;b7L`B`R7D4Pd`g14LT8P=B<2H4GCd`1:Y<>BOQh>0Eoooo000Doooo1>7Jf`CQfMTG
hN3P18]:@PA:;2D4@b8P0cHN7P@S3A84=AhP13PN7@@M;SX4f;NQ1=VgX0?Ub;P4cIF71;b1J@C=VX<4
b9^31;R5L`BVIED3X69;1:Y]E0B_JE84`YEm1=FYUPCG/Id3hLFd1>;2[@CKYYD4b9Em1;UkH0B`R6@4
]H1V0l>DO@CBTWX4Bdi>16m=@0AkETX4F5E@0i1^F0BXNFL4_Y5e1;b7L`B`R7D4Pd`g14LT8P=B<2H4
GCd`1:Y<>BOQh>0Eoooo000Doooo1>7Jf`CQfMTGhN3P18]:@PA:;2D4@b8P0cHN7P@S3A84=AhP13PN
7@@M;SX4f;NQ1=VgX0?Ub;P4cIF71;b1J@C=VX<4b9^31;R5L`BVIED3X69;1:Y]E0B_JE84`YEm1=FY
UPCG/Id3hLFd1>;2[@CKYYD4b9Em1;UkH0B`R6@4]H1V0l>DO@CBTWX4Bdi>16m=@0AkETX4F5E@0i1^
F0BXNFL4_Y5e1;b7L`B`R7D4Pd`g14LT8P=B<2H4GCd`1:Y<>BOQh>0Eoooo000Doooo7n7Ph0BHF484
<Q8@12/K6@<a6AP4<Q/I11hE5PA3<C04<SQ01=>^VPCR^Z@3f;ZU1>K5^0CE/Yh4/X5a1:inLPBVPW<4
Vg9S0hUUFPB=IE<4Ug5R19Q/HPC7YYD4f;ZV0n6i[PCR_:H4fjRA1<RAPPBVFd@4X5@m1:EoG`>lSg84
`91g1<BCO@BkS7D4XgIU19YcHP>fQ784`8Q_1;27M@BlSg<4]h5Y14P[90@[71T3ATM516m3=0BE=RDW
hN3P5Oooo`005?oooaoQh>04V5Q2138B40@[6aT3<ATH138K6@@N5AH4@c4`138h@0CC[YX4h[ZT0mRj
Y@CVaKP4eK:N1;:1L@B^OW84YX9c19]bH`>9IEX4SFEC19MaHPBHK684ajJE1=RjYP?Q^Jh4h[bV1=^X
T@C8TH84YU]41:1D?@BUOel3_8mb1<2@M`C4Tgd4^hae1:=fI@BJLf83]XAb1<28K`B`QgD4_8mc1;N1
J@A8:b@4:a`I0dI7A@A_@c@4UCHU9n7Ph1Goool001CooolOhN3P19QH@P@b4Q04:a/I0c4I60@b6aT4
7QDF14<a<0@b>404djjJ1>:jY0?H^ZD4i/Fh1=FbWPBbPG44[Wib1:J2L`BKLV<3RFEJ18eUD`BGLF84
V6aR1<NVU@CH^ZH3hKV^1>:lYPCKZ944b9621:IKA0BPE3d4YGmO0kb?LPC0T7L4a9=m1;^<M@BSMVD4
VW=R0kJ4LPC0R6l4/8Me1;b?L`BgPFT4B2/T12/L6@=6AdD4Kd<d19Df9BOQh>0Eoooo000Doooo7n7P
h0BHF484<Q8@12/K6@<a6AP4<Q/I11hE5PA3<C04<SQ01=>^VPCR^Z@3f;ZU1>K5^0CE/Yh4/X5a1:in
LPBVPW<4Vg9S0hUUFPB=IE<4Ug5R19Q/HPC7YYD4f;ZV0n6i[PCR_:H4fjRA1<RAPPBVFd@4X5@m1:Eo
G`>lSg84`91g1<BCO@BkS7D4XgIU19YcHP>fQ784`8Q_1;27M@BlSg<4]h5Y14P[90@[71T3ATM516m3
=0BE=RDWhN3P5Oooo`005?ooo`SQh>04hMoO1>7Ng`oQh>04Zg5L13lD4@@]5aH38aPG10l120@Z5aL4
>Bd]14Q=C@BmWHX4gkNR0n70Z`CQ`K@4h/Bh1>36/@C@X9D4WI2>1<ZPU`>jTX@4_9^<1:^9O0C:VhT4
ekVU1>6o[P?O`Jd4hJ^P1=b`VPC=ZI84b8j218]=A@A[>Bh3K48_1:AaF`BhRg@4ai1i1<>BM0B`R7@3
_XU`1:YoJPBlQWX4/XMe191B?PA=9b04=2XY0c4i=0BUDSX4JSPb1<72`R?Qh>0Eoooo000Doooo2>7P
h0CQgml4hMkO3n7Ph0B[LE`4?a@A12dG5P<S61L43`4812XG5`@i;Bd4B4e=1;fMRPCO]j83hL2[1>71
]0CRa;P4h<Ja1=2PU@BMT8h4bZ2G0kZBQ0BlVh`4ZhUl1<ZKR@CG^JD4hKn^0mo1[@CQZj04g;2J1<fY
TPC8SX84Rde516/i;P=/@Rl4Y75K1;R;M0C7T7T4`i9d1;28M0>nRG04ZWmZ1;b6NPBbQgD4T58n14dW
80@d:RT3<CTd1:EB>PAZ>384`L;28n7Ph1Goool001Coool8hN3P1>7Og`CQg]l?hN3P1:]aG0@o5144
;ALF0b<H5`@?0@P4:QLG13T];@A8CDd4_If:1=ngXP?Q`:/4hL6d1>;4^0CPa[44d:2E19f@SPC:X9L3
^Y:41;bKS0B[RG`4bY^91=NiY@CQ_jh3gl6]1>6[X0CL/9X4cJVB1<R>PPB;CDD4JcT^0fa2;`BTLE/4
^8]d1<N@N@C3TW@4/8Qd0kj9L0BZOfX4_8Ij1;:7M@B@DSh4CBLP13@Z:@<a>C@4YE8j16Xh<PC1`/8S
hN3P5Oooo`005?ooo`SQh>04hMoO1>7Ng`oQh>04Zg5L13lD4@@]5aH38aPG10l120@Z5aL4>Bd]14Q=
C@BmWHX4gkNR0n70Z`CQ`K@4h/Bh1>36/@C@X9D4WI2>1<ZPU`>jTX@4_9^<1:^9O0C:VhT4ekVU1>6o
[P?O`Jd4hJ^P1=b`VPC=ZI84b8j218]=A@A[>Bh3K48_1:AaF`BhRg@4ai1i1<>BM0B`R7@3_XU`1:Yo
JPBlQWX4/XMe191B?PA=9b04=2XY0c4i=0BUDSX4JSPb1<72`R?Qh>0Eoooo000Doooo2>7Ph0CQhN84
hMWI3n7Ph0BEL6T4BBdY12lG5P</61L47Q8@128D5@@l;Bd4CDm=1:N;O0CG/Id3hL2[1>70/`CQb;X4
hLVl2>7:_`oQbK`4h/>]1=RhXPCRakH3f[NP1=VcW0CJ/9/4dj^G1=J/VPCCXhl4VfmZ0gaFC@AC=R`4
ICX/199JBPBAJEH4XV]A0iYXD@BdOg04Xgm/1;j4L`A_=Rh4>QdJ130N8`<d4a44MBPL17I3?0@d;bhS
hN3P5Oooo`005?ooo`SQh>04hN7R1>7If@oQh>04UG1Y14T]:@@_5aH3;1PG11hB40@R51D4?2d]14e?
C@BWRg`4ek6M0n70Z`CQ`;<4hLRj1>79_0SQb[l?hLVl1>;3[@CH^:84h/Nf0mZgX0CI/i`4f[2K1=>[
U`CF[9X4dj>?19]_JP=lETd4DcH/16Dj;0BBFTX4TFUF1:9[D@>JJ544]7m`1:=oK0BnQ7<4KcH^13XM
6P@`7R<3=1<A17DX70Af@c`4=2l^8n7Ph1Goool001Coool8hN3P1>7QhPCQfMT?hN3P19E`J@A9;BT4
;aLF0b`H5`@N4Q048Q@E13`];@A=Cdd4Yh]l1=NaW@?Q`:/4hL2c1>78^PCQbK`8hLZo3n79_0CR`jd4
f;RR1>;7]P?J]j04fK>L1=Z`V`CCZiL4eZbJ1=>SS`BKKfX3O5I=15<f;0AU>R`4TUY:195YEPBRJe43
VVQA1;AoL0BSOf`4_XAc16lf;P@j7AX4<1hS0c@C4@Ae:1`4MT<l13@_;R?Qh>0Eoooo000Doooo2>7P
h0CQhN84hMWI3n7Ph0BEL6T4BBdY12lG5P</61L47Q8@128D5@@l;Bd4CDm=1:N;O0CG/Id3hL2[1>70
/`CQb;X4hLVl2>7:_`oQbK`4h/>]1=RhXPCRakH3f[NP1=VcW0CJ/9/4dj^G1=J/VPCCXhl4VfmZ0gaF
C@AC=R`4ICX/199JBPBAJEH4XV]A0iYXD@BdOg04Xgm/1;j4L`A_=Rh4>QdJ130N8`<d4a44MBPL17I3
?0@d;bhShN3P5Oooo`005?oooaoQh>04Zgad15To?@@[71X3:aPG12dH5`@/7B84?Bh^159=B@BTPG44
djjK0n70Z@CQ_k04hLJi1>76]`CQclH4hM391>7Bb`?QbK`4hM381>78^PCQbK`4hL6/1>70ZP?R_ZH4
fK:L1=VXT`CI[iX4fJnK1=bYV@C;Y983cI>11:1kK@AnH5@4J51218=FB0AkJ5/3UG1P18YWG0BkQWP4
]X5/16de;0@a6QP49APG0alC4@@f71`4GCLe13`f=B?Qh>0Eoooo000Doooo7n7Ph0B[O7@4FClm12/L
6P<[61L4;APG12`M8P@m;Rh4DTe91:B1L@CC[Y/3hL2Y1>6o/0CQa[T4hLJg1>7?aPCQd<T4hM;;0n79
_0CQd<P4hLRj1>79_0CQ`J`4hL2Z0n:nYPCI/Y`4fJRC1=V_VPCI[i/4g:VI1<^TTP?=Th44X7]]17iP
E0AXD484PeI817]XF`>EL604RVML1;^6N0BfPF`4KCD/134J60@U61L37a<A13HL70AM=cD4?3He8n7P
h1Goool001CooolOhN3P1:]lM0AI?cd4:a`J0b/H5`@]61L4;1dR13d^;PABCDT4Y85a1=>^V`?Q`:T4
hKn`1>76^@CQa[L4hLo61>7@b@CQd//3hLVl1>7@b0CQb;X4hLVl1>71[0CQ`:X3h[jV1=VbW0CIZ9<4
fJnJ1=V_V`CLZIT4bjBB0lfCP@BPNfd4OV1D16Q@@PB3ETP4NfQK0iE`H0B:Ie`4^hIh1;J1K0A]=B`4
<AXH12DH5`<O4a44=Q`L15dg=@@l=SDShN3P5Oooo`005?oooaoQh>04Zgad15To?@@[71X3:aPG12dH
5`@/7B84?Bh^159=B@BTPG44djjK0n70Z@CQ_k04hLJi1>76]`CQclH4hM391>7Bb`?QbK`4hM381>78
^PCQbK`4hL6/1>70ZP?R_ZH4fK:L1=VXT`CI[iX4fJnK1=bYV@C;Y983cI>11:1kK@AnH5@4J51218=F
B0AkJ5/3UG1P18YWG0BkQWP4]X5/16de;0@a6QP49APG0alC4@@f71`4GCLe13`f=B?Qh>0Eoooo000D
oooo7n7Ph0BZL5X4Dc@Z14X^:`<Z6AL4<A4?13HN7@A1:bD4Dd<m18YbI0C1WX`3gknY1>70Z`CQ`;<4
hLVl1>78^PCQclH7hM391>7@b0CQb;X4hLJe1>76^0CQ_ZP3h[ZR1=V_VPCI/Y`4fJRC1=V^U`CJYI@4
dj:<0l^NR0C4Tgd4^95n1:j9M@BNNFP4V7=S0kEoK`BcRWD4^ga`1:1VC@AR<RX4<AXH13LN7@<U6AP4
9QLF144Z8`AACD`4eM;C7n7Ph1Goool001CooolOhN3P1:Y`FPAC=2X4BRh[0bXI5`@a4@l4=QhM144[
9@AC@cd4RW9T1<6NS0?O_jT4hL2[1>70/`CQbK`4hLRj1>7?aPOQd<T4hM381>78^PCQa[D4hLJh1>6n
Z0?R^Z84fJnJ1=VbW0CIZ9<4fJjG1=ZUU0CCXX`3bij81<BCO@BhTGh4[XUe19iiJ0BHLf<3]Gm_1;>:
M@BkO704X6I=168b:P@a6QP4=ahM0bDI60@V5aH4@BXS155=C0CEd]<OhN3P5Oooo`005?oooaoQh>04
ZW1J15<d:PA:;R/3:QTG134A3`@f7Qd4@B/U15=3?@B:LV@4`Ij<0mnoZ@CQ`:/4hL2c1>79_0CQb;X4
hLo61n7@b@CQd<P4hLRj1>76]@CQa[P4hKjX0n:jXPCI[iX4fK:L1=VXT`CI[YL4fZFD1=>RS0?;WXP4
a9=m1;RAOPB^RGD4WWUX19QcH`>eOfl4/hYe1;]lL0BPITd4HS8Z134J60@g7Qd39ATH12HG5PA1:R<4
DDe<1=GBdaoQh>0Eoooo000Doooo7n7Ph0BEI4l4F3hi14@[9`<m8R047a8@12`F5P@^6AP4CS<Z16UA
@0B`Rg/3ekNR1>70Z`CQ`;<4hLNj1>7Bb`CQb;X4hLo61n7?a@CQb;X4hLNg1>70Z@CQ_J/3hKRP1=VX
T`CI[IL4fJjH1=VXT`CJYY44d9j80m2HP`C9W8L4`95l1<REP0C1T7`4_Hii0kZ8L`BjR7P4/geW1756
?0@_6A<4=B0T11hA5`<Q4Q043P48134M7@A@A404W8R;7n7Ph1Goool001CooolOhN3P19ETC`AH?ST4
A2/W0cdR80@O4Q04;1HF12hI60A><bX4JE501;2;N`?G]j84hL2[1>70/`CQakX4hM;;1>78^PCQclH7
hLo51>78^PCQakL4hL2Y1>6mZ`?Q^:04fJRC1=V]U`CI[YP4fJRC1=ZVT@C@WXP3d9R31<VLQ`C0TG`4
b9F01<6@O0BmSWT3^XQc1;Z8N0BcOFL4LDHl12lI4`@e82@47Q4G0b4B40@>0@P4<AdM1514@0BLR8/O
hN3P5Oooo`005?oooaoQh>04UFA?15Pn>@A4:bL3?B8P11lB40@/5QH4;QTH14hc:PAYDD04/8]k0mNg
XPCQ`:/4hL2c1>77^PCQd//4hLRj1>7?aPOQclD4hLRj1>77]`CQ`:T4hKf[0n6hX0CIZ9<4fJfG1=V^
V0CIZ9<4fZJA1=2NR0?@V8<4bIb71<2AO0C8UH04`I1l1;f>N@>jR7<4^XQh1;=mI`AaAS`4;aTC13DP
90@N4AL38A8@10h120@a7Ad4D4A019b8RaoQh>0Eoooo000Doooo7n7Ph0BEI4l4F3hi14@[9`<m8R04
7a8@12`F5P@^6AP4CS<Z16UA@0B`Rg/3ekNR1>70Z`CQ`;<4hLNj1>7Bb`CQb;X4hLo61n7?a@CQb;X4
hLNg1>70Z@CQ_J/3hKRP1=VXT`CI[IL4fJjH1=VXT`CJYY44d9j80m2HP`C9W8L4`95l1<REP0C1T7`4
_Hii0kZ8L`BjR7P4/geW1756?0@_6A<4=B0T11hA5`<Q4Q043P48134M7@A@A404W8R;7n7Ph1Goool0
01CooolOhN3P1:]aF`A>=S44DS/i0cdY9`@n8Al4:1LF13HT8`@o<c<4GDDn17eWF0?C[9P4hKnZ1>6o
/@CQaKH4hLo61>7Bb`CQbK`3hM382>78^PCQakX4hKjX1>6mY@OI[YP4fJRC1=RXT`CGYI04f:F@1=:N
R0?8V8<4b9N21<VNR0C0TG`4ai1l1<2>N@>bR7@4/hA`19]VE0AN<2T4@BXX11D93`@P4QT33@4811/@
5P@Q51D4B3ho17IRGQoQh>0Eoooo000Doooo7n7Ph0B[LE/4CSHa158k>@<m:BL4?R4O12PG5P@f92<4
?c<c15e5?PAmIeP3djbH1>6oZPCQ_k44hLFf1>7?aPCQd//4hLVl0n7@b0SQb;X4hLNj1>6nZ0CQ_JD7
fJjH1=VXT`CHZ9<4ejF@1=RUT0CBWXP3b9R31<RGPPC9WXP4`95l1<N@O0C0SWT3/XQd1;>4L0BKIU@4
GS0Y144Z:0@E2@l4818I0`d120@K41H48A@E14Pn?`AfHUhOhN3P5Oooo`005?oooaoQh>04Zg5K14hf
<@AB>cT3?BTW13hQ7`@X5aH4=R@S13lc<`AMACh4OFMH0m>/V0CQ_jX4hKna1>75]PCQclH4hM;;1>79
_0?Qd<P8hLRj1>77^PCQ_ZP4hKfU1mV^V0CIZ9<4f:RC1=NUT0CHYI04dYj80lRHP`C8Uh84bIj81<2A
O0C7T7`4`8ii0k:8M0BcQ704VfID15h`:@A1:RP45@T?120B6@<=0@P46a0F124D5@A8?Sl4MV9N7n7P
h1Goool001CooolOhN3P1:]aF`A>=S44DS/i0cdY9`@n8Al4:1LF13HT8`@o<c<4GDDn17eWF0?C[9P4
hKnZ1>6o/@CQaKH4hLo61>7Bb`CQbK`3hM382>78^PCQakX4hKjX1>6mY@OI[YP4fJRC1=RXT`CGYI04
f:F@1=:NR0?8V8<4b9N21<VNR0C0TG`4ai1l1<2>N@>bR7@4/hA`19]VE0AN<2T4@BXX11D93`@P4QT3
3@4811/@5P@Q51D4B3ho17IRGQoQh>0Eoooo000Doooo7n7Ph0BPO7@4FChj158n?0=?>SL4?B8P128C
40@d7Qd4BS8[16A<@@A/G4h3_iF31=ngX@CQ`;44hKna1>75]PCQclH4hM390n7Bb`CQbK`4hLRj1>77
^@CR`K84f[VQ0mR_V@CGYI04ejBB1=ZTT0CAXX`4dIb:1=:MR0?8V8<4b9F01<NDO`C7UH04_XUc1<6<
M`>`P6/4Zg1P18I=>`AB:RD48Q8@128C6@@C20l36a4@11P>5@@_7Ad46ATK17a`KQoQh>0Eoooo000D
oooo7n7Ph0BPO7@4FChj158n?0=?>SL4?B8P128C40@d7Qd4BS8[16A<@@A/G4h3_iF31=ngX@CQ`;44
hKna1>75]PCQclH4hM390n7Bb`CQbK`4hLRj1>77^@CR`K84f[VQ0mR_V@CGYI04ejBB1=ZTT0CAXX`4
dIb:1=:MR0?8V8<4b9F01<NDO`C7UH04_XUc1<6<M`>`P6/4Zg1P18I=>`AB:RD48Q8@128C6@@C20l3
6a4@11P>5@@_7Ad46ATK17a`KQoQh>0Eoooo000Doooo7n7Ph0BPO7@4FChj158n?0=?>SL4?B8P128C
40@d7Qd4BS8[16A<@@A/G4h3_iF31=ngX@CQ`;44hKna1>75]PCQclH4hM390n7Bb`CQbK`4hLRj1>77
^@CR`K84f[VQ0mR_V@CGYI04ejBB1=ZTT0CAXX`4dIb:1=:MR0?8V8<4b9F01<NDO`C7UH04_XUc1<6<
M`>`P6/4Zg1P18I=>`AB:RD48Q8@128C6@@C20l36a4@11P>5@@_7Ad46ATK17a`KQoQh>0Eoooo000D
oooo7n7Ph0BPO7@4FChj158n?0=?>SL4?B8P128C40@d7Qd4BS8[16A<@@A/G4h3_iF31=ngX@CQ`;44
hKna1>75]PCQclH4hM390n7Bb`CQbK`4hLRj1>77^@CR`K84f[VQ0mR_V@CGYI04ejBB1=ZTT0CAXX`4
dIb:1=:MR0?8V8<4b9F01<NDO`C7UH04_XUc1<6<M`>`P6/4Zg1P18I=>`AB:RD48Q8@128C6@@C20l3
6a4@11P>5@@_7Ad46ATK17a`KQoQh>0Eoooo000Doooo5n7Ph0CQgml4hMgM19E_I`A?>SP4E3lm0e4k
>0@f7Q/4?BHU134S8P@n:bX4HTPm18ATE@>`OV/4eJnL1>70Z`SQ`K@4hLNj1n7@b@CQd<P4hLRj1>75
/`CO_J`4h[ZR0mZ^V0CCZI@4dJ6;1=RPT0CAWXP4d9^51=2IR0?7TH04aIB01<N@O0C0T7`4`Hmi1;J3
L0>gOVL4ZFaE16Tn<0A89B44:aXH124G5P@R5aL36Q0?124G5P@_7Ad42`<41>;QhQoQh>0Eoooo000D
oooo5n7Ph0CQgml4hMgM19E_I`A?>SP4E3lm0e4k>0@f7Q/4?BHU134S8P@n:bX4HTPm18ATE@>`OV/4
eJnL1>70Z`SQ`K@4hLNj1n7@b@CQd<P4hLRj1>75/`CO_J`4h[ZR0mZ^V0CCZI@4dJ6;1=RPT0CAWXP4
d9^51=2IR0?7TH04aIB01<N@O0C0T7`4`Hmi1;J3L0>gOVL4ZFaE16Tn<0A89B44:aXH124G5P@R5aL3
6Q0?124G5P@_7Ad42`<41>;QhQoQh>0Eoooo000Doooo5n7Ph0CQgml4hMgM19E_I`A?>SP4E3lm0e4k
>0@f7Q/4?BHU134S8P@n:bX4HTPm18ATE@>`OV/4eJnL1>70Z`SQ`K@4hLNj1n7@b@CQd<P4hLRj1>75
/`CO_J`4h[ZR0mZ^V0CCZI@4dJ6;1=RPT0CAWXP4d9^51=2IR0?7TH04aIB01<N@O0C0T7`4`Hmi1;J3
L0>gOVL4ZFaE16Tn<0A89B44:aXH124G5P@R5aL36Q0?124G5P@_7Ad42`<41>;QhQoQh>0Eoooo000D
oooo5n7Ph0CQgml4hMgM19E_I`A?>SP4E3lm0e4k>0@f7Q/4?BHU134S8P@n:bX4HTPm18ATE@>`OV/4
eJnL1>70Z`SQ`K@4hLNj1n7@b@CQd<P4hLRj1>75/`CO_J`4h[ZR0mZ^V0CCZI@4dJ6;1=RPT0CAWXP4
d9^51=2IR0?7TH04aIB01<N@O0C0T7`4`Hmi1;J3L0>gOVL4ZFaE16Tn<0A89B44:aXH124G5P@R5aL3
6Q0?124G5P@_7Ad42`<41>;QhQoQh>0Eoooo000Doooo5n7Ph0CQhN84h]cL18QQF0AD>2l4CSPe0eE0
?PAA>SP4>2DT144^;0A6;RH4DDQ4181JB@>TN6P4bjBB1=noZPCQ_k44hLJi1>76]`_QcL<4hL>a1>72
[`CG]j44hKJN0mRUS0CGY8h4f:F<1=6PRPCAXH`4dYR31<RMQ`?9Uh04`H]l1<2=N0C0S7L4_Heh1;N0
J`>ULUX4O4Q015T/9P@]71T48Q8@11`A5`@E2@l31@4811<83P@m;Rh460d>1>WWiaoQh>0Eoooo000D
oooo5n7Ph0CQhN84h]cL18QQF0AD>2l4CSPe0eE0?PAA>SP4>2DT144^;0A6;RH4DDQ4181JB@>TN6P4
bjBB1=noZPCQ_k44hLJi1>76]`_QcL<4hL>a1>72[`CG]j44hKJN0mRUS0CGY8h4f:F<1=6PRPCAXH`4
dYR31<RMQ`?9Uh04`H]l1<2=N0C0S7L4_Heh1;N0J`>ULUX4O4Q015T/9P@]71T48Q8@11`A5`@E2@l3
1@4811<83P@m;Rh460d>1>WWiaoQh>0Eoooo000Doooo5n7Ph0CQhN84h]cL18QQF0AD>2l4CSPe0eE0
?PAA>SP4>2DT144^;0A6;RH4DDQ4181JB@>TN6P4bjBB1=noZPCQ_k44hLJi1>76]`_QcL<4hL>a1>72
[`CG]j44hKJN0mRUS0CGY8h4f:F<1=6PRPCAXH`4dYR31<RMQ`?9Uh04`H]l1<2=N0C0S7L4_Heh1;N0
J`>ULUX4O4Q015T/9P@]71T48Q8@11`A5`@E2@l31@4811<83P@m;Rh460d>1>WWiaoQh>0Eoooo000D
oooo7n7Ph0B/O7@4BC4X15Pm>0=A?S`4BcDa148U8PA5;BH4BCHd15A1>PA]BCd3Q6=D1;n?P0CG^:84
hL2^1>6o/0CQaK@7hLFc1>76]PCR`K84f[VQ1=V]U`CH[I@3f:6<1=6LQ@CAWh`4dJ261=6JP`CBW8H7
b9F01<R@O0C0SWT4_XA`1;UoJPBULEX3O4Y116Pl;@@j7Q/4:ATH12XH5`@L4AH45@T@0a@83`@X6Q/4
00dF15a6AR?Qh>0Eoooo000Doooo7n7Ph0B/O7@4BC4X15Pm>0=A?S`4BcDa148U8PA5;BH4BCHd15A1
>PA]BCd3Q6=D1;n?P0CG^:84hL2^1>6o/0CQaK@7hLFc1>76]PCR`K84f[VQ1=V]U`CH[I@3f:6<1=6L
Q@CAWh`4dJ261=6JP`CBW8H7b9F01<R@O0C0SWT4_XA`1;UoJPBULEX3O4Y116Pl;@@j7Q/4:ATH12XH
5`@L4AH45@T@0a@83`@X6Q/400dF15a6AR?Qh>0Eoooo000Doooo7n7Ph0B/O7@4BC4X15Pm>0=A?S`4
BcDa148U8PA5;BH4BCHd15A1>PA]BCd3Q6=D1;n?P0CG^:84hL2^1>6o/0CQaK@7hLFc1>76]PCR`K84
f[VQ1=V]U`CH[I@3f:6<1=6LQ@CAWh`4dJ261=6JP`CBW8H7b9F01<R@O0C0SWT4_XA`1;UoJPBULEX3
O4Y116Pl;@@j7Q/4:ATH12XH5`@L4AH45@T@0a@83`@X6Q/400dF15a6AR?Qh>0Eoooo000Doooo7n7P
h0B/O7@4BC4X15Pm>0=A?S`4BcDa148U8PA5;BH4BCHd15A1>PA]BCd3Q6=D1;n?P0CG^:84hL2^1>6o
/0CQaK@7hLFc1>76]PCR`K84f[VQ1=V]U`CH[I@3f:6<1=6LQ@CAWh`4dJ261=6JP`CBW8H7b9F01<R@
O0C0SWT4_XA`1;UoJPBULEX3O4Y116Pl;@@j7Q/4:ATH12XH5`@L4AH45@T@0a@83`@X6Q/400dF15a6
AR?Qh>0Eoooo000Doooo7n7Ph0C5YIh4Ecdk14`f<P=H?cd4DSD[14Da;P@k9RD4BcDa14Da;`AHA3l3
JTe31:=fI0CA/I/4gkfV1=noY`CQ`;04hL2Z0n6nY`CO_JD4gkn_1>:kX`CHZ904f:F<0m2FP0C>Uh84
cYN61<nLQPC@Vh@4d8mk1<RAP0?7Sg`4ai1h1;j:L`BmQ704/GUS18UB@P=Y?Bd4>AdK12DD4@@N4AL4
:1PG11lB5`@=0@P34`P?12/K70@A20T4jNOW8n7Ph1Goool001CooolOhN3P1<FUWPAG?C/4C3Hb0ePo
?@AB=B/4AC4^13/V9@A;=C44AC4_15Q4?`=ZCD<4XgIT1=6aV`CO_JH4gknW1>70/0CQ`:X3hKjW1=nm
Y@CO_jl4h[^S1=RXT0CHYH`3d9J01<jGPPC>UhH4cib61=2KQ0C@Sg/4b9600lN?O0C7T7P4_XYc1;f4
L0BaNF<4RE920fTm;@@i7A/49A@A11hA5`@X61L47a8G10d120<C20l4:a/L11482@CYinLShN3P5Ooo
o`005?oooaoQh>04aJFN15Lm>`A<=S83F3lm158e:`A5<Bh4>bHU14/e<@A5<Bl4F4@o0fY=@`BSMV@4
dK6K1=nmYPCO_jL4hL2`1>70ZP?Q_ZL4gkfU1=no[`CR^j<4f:R@1=RUS0?@UX04cYN21<jGQPC?W8H4
d9^41=2?N`C8TH03ahml1<N@N0BnRW<4_HA`1;5iH`B9DT83JCd]13TM6`@U51447Q4G12PH5`@O4QL4
3@480a<83`@[6a`44@P91>WWib?Qh>0Eoooo000Doooo7n7Ph0C5YIh4Ecdk14`f<P=H?cd4DSD[14Da
;P@k9RD4BcDa14Da;`AHA3l3JTe31:=fI0CA/I/4gkfV1=noY`CQ`;04hL2Z0n6nY`CO_JD4gkn_1>:k
X`CHZ904f:F<0m2FP0C>Uh84cYN61<nLQPC@Vh@4d8mk1<RAP0?7Sg`4ai1h1;j:L`BmQ704/GUS18UB
@P=Y?Bd4>AdK12DD4@@N4AL4:1PG11lB5`@=0@P34`P?12/K70@A20T4jNOW8n7Ph1Goool001CooolO
hN3P1<:STPAWC4P4DShl0d`h=PAC>cT4?2<V13hY:0@o;B/4DChl14T`:0=B>2l4PEmA1;>7L0CCZi@4
eK6K1=njXPCO_:D3hKjW1=VfW`CG]9h4h;ZR1=NQRPC>Tgl3d9Z01<R<M`C8Tgh4aYAo1=2EP0C7SGP4
aHeg0lF3LPBkQg84]XE[1:Q]E`BPIe04KD4a0chN6`@]71T47a8@11@83P@C20l41P4810@120<Z6Q/4
=B4L11H;2bOQh>0Eoooo000Doooo7n7Ph0C2Xi84Ida8158n?0=<>3H4Dc/i13`S9P@n:BP4?bd[154n
?0A9<2P3DSP_185OD@BcQg04dj^D1=FaV`CO^Z84gkbU0n6nY`CI]Yl4ekBN1>2jXPCGXHX4cY=o0m2J
P0C8S7L4b9=n1<JDO`C@UH04aheh1<F=M`?5Pg84^hMb1;J5J`BXKEL4X6M@16e1<@<n7Q/4;A`I11lB
40@D20h44`P?10H120@40@P3:QXK13DQ70@F2`/WhN3P5Oooo`005?oooaoQh>04`Z>B16M<B0AB?S`3
C3Pf15<k>@@l8bH4?RTX13l]:`AA?S`4BC0X0e8h;`B1Ge44/hM`1=>[U0CE/I/4gkZR1=nlY@?Q_ZL4
fKJO1=NdWPCP^Z84ej6:1<jCO`?@VX04b8ag1<RCOPC6U7l4d9F01<N=N0C5SGL3aH=b1;^7LPBfQF/4
Z6eG1:1WD0A]@C43?QhK12dL6@@O4Q0450P>11<83`@60@P410480bXJ6`@e8A`45P/;9n7Ph1Goool0
01CooolOhN3P1<:STPAWC4P4DShl0d`h=PAC>cT4?2<V13hY:0@o;B/4DChl14T`:0=B>2l4PEmA1;>7
L0CCZi@4eK6K1=njXPCO_:D3hKjW1=VfW`CG]9h4h;ZR1=NQRPC>Tgl3d9Z01<R<M`C8Tgh4aYAo1=2E
P0C7SGP4aHeg0lF3LPBkQg84]XE[1:Q]E`BPIe04KD4a0chN6`@]71T47a8@11@83P@C20l41P4810@1
20<Z6Q/4=B4L11H;2bOQh>0Eoooo000Doooo7n7Ph0C_h^T4Le1;15I0?P=A>cP4ED91154d:P@j8204
BCLf14@`;PAD@3h3@BXW15I2>`AiEdT4Yg=N1<BDP0CBXHT4dZJC0mB]V`CD[YL4eJ^F1=JTS0C3S784
^GeV0kn1IPC4RgD4aHMc1<F4KPC5RWD4ahe^1;j4KP>mP6/4]7MR1:YgHPB?FDT4Lc/]15HZ90<f71T4
7a4?11H93`@D20l4300810@020@@1`h37Q@E13He=`A8<R`WhN3P5Oooo`005?oooaoQh>04kn;Y17=@
B`AF@3h3DC/h15E2@@AA=2X4>R0P14Tg=PA4<2h4E40n0d4Z9`AF@S/4NEM91:McGPC4U804dZ691=:V
T`?D[I/4e:jG1=F[UPCFY8`4`hab1;UmIP>oPFH4a8]e1<F7L`C5Q6h4aHYe1<N=KPBnQ6h3_H1[1;Ag
HPBZMf84SeU917<k;@AF:R@3=Q`I11lA3`@F2@l450P?10`020@400P440L>0ahD5@@f=CL4B38/9n7P
h1Goool001CooolOhN3P1>oRj@AcD4/4ET0n0e4k>0AE@T44DC@Z13XP80A9=cH4A30^15A0?P=1:RL4
ET8k17UGB@BWLeh4a9B01=:QR@CBYY<3e:fK1=B^U`CEZiH4eZB<1<><LPBiOFH3_h5V1<B;M@C5Qg<4
aHA^1<F:M@C7SFh4_XA^0kf0J`BdMf84ZWMR18mIB@Ac>bd4ERXT0cHL6@@O4@l45PT?11@83`@<00P4
100811073P<N51D4=SDg14Pb;2OQh>0Eoooo000Doooo7n7Ph0C_h^T4Le1;15I0?P=A>cP4ED91154d
:P@j8204BCLf14@`;PAD@3h3@BXW15I2>`AiEdT4Yg=N1<BDP0CBXHT4dZJC0mB]V`CD[YL4eJ^F1=JT
S0C3S784^GeV0kn1IPC4RgD4aHMc1<F4KPC5RWD4ahe^1;j4KP>mP6/4]7MR1:YgHPB?FDT4Lc/]15HZ
90<f71T47a4?11H93`@D20l4300810@020@@1`h37Q@E13He=`A8<R`WhN3P5Oooo`005?oooaoQh>04
j^_Y1:J5NPA?=C83CcXh14/g=@A7=c<4>b@W14<[90AA>SP4D3ln0eQ2?`A4<c84GDU416U>A0B:F4H4
Xg=X19M_G`>YMV04]8Ic1;F8L@BaOFX4YfeE18eJA@>FI4X4ZFM?1;AhGPBjOfD4^G=N1;1_F@BbKU83
[g5L1:1ZFPB@E4H4N40`15HW8`@j71T38Q8@11L93`@=0@P40`0710<020@300L46Q@E0bdK70@41@L4
f=;B9n7Ph1Goool001CooolOhN3P1>[[j@BVQGX4CcDb0dlj>0A;=cD4AcLc13/T9`A3:b@4DCXh150o
?P=H@Sl4A3<b15e9A0AYCT@4RUQ61:=cJ0BGKel3ZGIP1;B6L`BeR744/GeZ1:M]E@B=FTD3UVA:1:UW
C`BdN5h4^WmU1;UcGPB`KeT4/ViB0jmaG0BPJUX4T5A617Q0<0AF9b<4>Q`I0b8B40@G2@l43@4810<0
1`@300P40`0711XD5@<]6a`410D71=SBdROQh>0Eoooo000Doooo7n7Ph0CZjnT4YXEj14le<P=?>SP4
BcLe14Lg<`@k92L4@b/T154j>0A@?ch3F48o14@c<PAMBD@4JDi418YHAPBSLfP4UfmO0jUfH0BdQW<4
]HQa1;5mJPBWKED4SEY50iITBPBYIdl4]7QN1;YoI@BiLeh4/6mI1;9^DP>_LE`4X6YJ191DAPAh@304
ERLS13XL6@<R4Q045`T?10d120@300L40`0810<01`@J51D3;A/L10@51`CHd]8WhN3P5Oooo`005?oo
oaoQh>04j^_Y1:J5NPA?=C83CcXh14/g=@A7=c<4>b@W14<[90AA>SP4D3ln0eQ2?`A4<c84GDU416U>
A0B:F4H4Xg=X19M_G`>YMV04]8Ic1;F8L@BaOFX4YfeE18eJA@>FI4X4ZFM?1;AhGPBjOfD4^G=N1;1_
F@BbKU83[g5L1:1ZFPB@E4H4N40`15HW8`@j71T38Q8@11L93`@=0@P40`0710<020@300L46Q@E0bdK
70@41@L4f=;B9n7Ph1Goool001CooolShN3P1=k<e@ARAT43CC/i14hn?0A>>CL4:QdJ13X[:`AD?c/4
ED910f9>B`AOC4T4GDa616ABB`A[D4H4KTHn16Y1=`=S@C`4N4Hi18MKC0AjD4L4K4Q417M6>P=b@c04
NTPh18iGAPBDGdT4WEe519MQB`B6Cc/3R5A618M;?@A_@cH4CbPT14HZ9P@T4a037Q4?11D93`@<00P4
0`0710801`@P51D45PhE0cm4AP@W6Q/[hN3P5Oooo`005?ooob?Qh>04g/cE1696@@==>cT4CShl14hi
=`@Z7AX4>R/[15@o>`AE@T43HTi;15m<B@AMC4H4I59;16]@APA^ASh4JT4g0f=1?0AhAST4Qe]<17Y@
A`A/B4@4MdHj0g93<0AjB3P4SUM619AOB@BMGDD4Uf5;18I?>`>8E4H4Qd/m16m3=PA?:2@4ARXV12@C
40<N4@l45@T?10`020@300L40P07120D5@@F3QD3?dA612LJ6b_Qh>0Eoooo000Doooo8n7Ph0CNc=D4
HTI10ddk>@A>?S`4CSTg12XM6P@j:b/4E3lk15E2@@=RCT/4Gda915e<APATDT/4Je1616i6?PAZ@CL3
Hd4l17Q6>@B7Fd`4NU1716a8A0AgASX3LT<`17Y8>0B>EdH4U5m919eMA@BGHD/4QTlk0hQDAPB7Bcd4
Kd<f14lX90A6:RH491<@0ahA3`@E2@l4300810<01`@200L481@E11H>5@<oA4H49aXK:n7Ph1Goool0
01CooolShN3P1?3[j`B6Geh3CSPf150j>0A=>SP4DCXh140d=0A@?ch4HDe:0eQ2@0AJA444GShk16a5
>`AV@3@4Echi14H]:`=@=c<4AB@R15Dh=0AL?ST4C3@a14@U8`=9:bP4BBDP14dT8@AN=bX4H3T[15`f
:@AI:B@3DRDQ14`X90A:9B84<AdJ120B40@J2a4750P?10@020@300L481@P120D5PA1<2l31Q<L19F0
OB_Qh>0Eoooo000Doooo8n7Ph0C`jn/4QUmN0dhh=PA@>SP4CCXh154j>0A0=3@4D3ln165=BP=H@T04
FTA115hn>`A/AC/4IT0d15Ln>@A6;B/3D3Lc14DT8PAE>3@4G3hi14`d<@A49B<3BB/X14TU80A=9244
GSLZ160i:`AL=RT4FBTT0e8U8@A<:2@4BRDR134M6P@P4Q046P/A1a@83`@400P40`07120D80@P51H4
@C0_0`HC70BEP7d[hN3P5Oooo`005?ooob?Qh>04l>_[18IOGP=>>3H4D3Xh14dj>0AA>SP4@3@d150o
?PAQCDX3F49015Y4@@AN?S/4K4Dk16I0=0AG?ST4ARd[0e0g<`A59284ECPd15`n>@A<=344A2DS0dT[
:0A99B04CB@Q15hg:PAP>B/4G3HY15TY90=B9B44C2PT14XU8P@a7AX4818@11X;4@LD20l4100810<0
1`@P520481@F144`;`<64a`4UH1m:n7Ph1Goool001CooolShN3P1?3[j`B6Geh3CSPf150j>0A=>SP4
DCXh140d=0A@?ch4HDe:0eQ2@0AJA444GShk16a5>`AV@3@4Echi14H]:`=@=c<4AB@R15Dh=0AL?ST4
C3@a14@U8`=9:bP4BBDP14dT8@AN=bX4H3T[15`f:@AI:B@3DRDQ14`X90A:9B84<AdJ120B40@J2a47
50P?10@020@300L481@P120D5PA1<2l31Q<L19F0OB_Qh>0Eoooo000Doooo8n7Ph0CTiN<4f/O=0e/o
?@A=>3H4DChl14hi=PAHAdD4BcDa15U5@`=A>CD4Dclm15m;@`AH?c`4FS/g15<h=0A9<c03C3Pg13hV
:P@j:bX4@2@R144T8P@b71X3:1TH12lJ6@@j81h4?AlN13@K6@@c6aT4<a`I0cdP7P@b6AP4;aTH128B
40@M4@l45@T?0a<83`P400P440L>12HN80@h7b04928S0dY4A2oQh>0Eoooo000Doooo8n7Ph0CTiN<4
f/O=0e/o?@A=>3H4DChl14hi=PAHAdD4BcDa15U5@`=A>CD4Dclm15m;@`AH?c`4FS/g15<h=0A9<c03
C3Pg13hV:P@j:bX4@2@R144T8P@b71X3:1TH12lJ6@@j81h4?AlN13@K6@@c6aT4<a`I0cdP7P@b6AP4
;aTH128B40@M4@l45@T?0a<83`P400P440L>12HN80@h7b04928S0dY4A2oQh>0Eoooo000Doooo8n7P
h0CTiN<4f/O=0e/o?@A=>3H4DChl14hi=PAHAdD4BcDa15U5@`=A>CD4Dclm15m;@`AH?c`4FS/g15<h
=0A9<c03C3Pg13hV:P@j:bX4@2@R144T8P@b71X3:1TH12lJ6@@j81h4?AlN13@K6@@c6aT4<a`I0cdP
7P@b6AP4;aTH128B40@M4@l45@T?0a<83`P400P440L>12HN80@h7b04928S0dY4A2oQh>0Eoooo000D
oooo8n7Ph0CTiN<4f/O=0e/o?@A=>3H4DChl14hi=PAHAdD4BcDa15U5@`=A>CD4Dclm15m;@`AH?c`4
FS/g15<h=0A9<c03C3Pg13hV:P@j:bX4@2@R144T8P@b71X3:1TH12lJ6@@j81h4?AlN13@K6@@c6aT4
<a`I0cdP7P@b6AP4;aTH128B40@M4@l45@T?0a<83`P400P440L>12HN80@h7b04928S0dY4A2oQh>0E
oooo000Doooo9n7Ph0C/i>H3REQD15<n?0AA?S`4DC/h140a;PAPBdL4E4E20eI4@@A3<2h4ECP`14d`
:`A9<c04AS8_13DT;`<k;bd4@BH[13TO80@`72P8:1TH0ahA3`@R61L491PG12LI60@Q4Q045PT?11dA
3`<Z61L48Q8@11H93`@N4@l46a0F11D93`<400P44`P?11`E5@@Y8244;Q/L13Pe=@@h;RlbhN3P5Ooo
o`005?ooobOQh>04k>CV0hUHE0AC?S`4DChl154k>0A0<Bh4H4]715A5@P=FA444@c0^15Dh<0A=<2/4
BC<`14Hb;`@e92l3>bl]144V:`@i7b04<1`X22PI60<N4@l48QPG12@H5`@W6AP48A8@11H93`@M4@l3
:QPG128B40@F2@l47Q4?11/@5P@E2@l3100811<83`@L5AD4:B0Q12hK70@h=CD4>2h_<^7Ph1Goool0
01CooolWhN3P1>cTiP>9F5@4Dchl154n?0AA>cP4@34^161;A`ADAD83ETA114<`;PAE>304CC0[14Tc
<0A6<Rl4=B@_0c/_;@A19R/4>AlP130L:0PX6AP37Q4?128H5`@T61L49aTH124B40@F2@l47A4?0bXH
5`@R4Q045PT?11hA3`@K41H45@T?0`@020@C20l471DE12TP8@@^6a`4>3De13P^;c;Qh>0Eoooo000D
oooo9n7Ph0C/i>H3REQD15<n?0AA?S`4DC/h140a;PAPBdL4E4E20eI4@@A3<2h4ECP`14d`:`A9<c04
AS8_13DT;`<k;bd4@BH[13TO80@`72P8:1TH0ahA3`@R61L491PG12LI60@Q4Q045PT?11dA3`<Z61L4
8Q8@11H93`@N4@l46a0F11D93`<400P44`P?11`E5@@Y8244;Q/L13Pe=@@h;RlbhN3P5Oooo`005?oo
obOQh>04i^SV0kfMV`AG>SP4E3lm154k>0AC?S`4AC/i15I1?`=A>3@4@RdZ13`Y9`@i7AX4?bd[13TS
:0@i8bL3:aTJ130L9`@O4QT46@X@11hA6@@L4AL35PT@11X@5P@E2@l4714G11H940@K41H47aHF0aX@
5P@G2A04104810<01`@40@L410480aT?5P@F3`h44`P>12LA3`@j>c`4=b//=^7Ph1Goool001CooolW
hN3P1>KXiP>mWI/4EcXh15@o?@AA>cP4Dchl14Dk>@AF@Cl3DCPd148]:P@l:BL4>AdJ13l]:`@i8bP4
>B<W0b/I6P@`72L47a8I11T:40@N4AT4714G0aH940@J41H45@T?11`A5`@F2A046a0F11lF5P<J41H4
5`T@10@120@300L4104710@120<I3aH45Pl>11<83P@W4@l4>S/l13L[;3KQh>0Eoooo000Doooo9n7P
h0CVj>H3_IfK15Lj>0AD?cd4DC/h15<n?0A5>cT4ET4o0e4h=0A2;BX4?2TW13TM6P@o;B/4>B<X13TS
9`<[6AX4<1`W11lB6@@I2Q047Q4I11`A5`<F2A046Q0F11D93`@L4AL45PT@11/@5P@O5QH36Q0F11L9
40@40@P40`0710@11`@40@P36@lF11H?3P@C20h49a4?13Xk?0@g:b`fhN3P5Oooo`005?ooobOQh>04
i^SV0kfMV`AG>SP4E3lm154k>0AC?S`4AC/i15I1?`=A>3@4@RdZ13`Y9`@i7AX4?bd[13TS:0@i8bL3
:aTJ130L9`@O4QT46@X@11hA6@@L4AL35PT@11X@5P@E2@l4714G11H940@K41H47aHF0aX@5P@G2A04
104810<01`@40@L410480aT?5P@F3`h44`P>12LA3`@j>c`4=b//=^7Ph1Goool001Coool[hN3P0oOg
m`BBN7<4Bc@a14lj>0A<?C/4D40n15A5@`=B?3l4@2@R13`W9P@Z6aT4:QLG12XL6@@]6AT360XA11H9
3`@N4AT46a4G11<83`@K41L35@T@11T?5P@E2A04;A/L10D120@H3aH48ALG0adB5`@50@P4100810X0
1`@F3QD45`lF0aH>5@@a7Ah4?2XR13lm>P@G2PL4f=;B=^7Ph1Goool001Coool[hN3P0oOgm`BBN7<4
Bc@a14lj>0A<?C/4D40n15A5@`=B?3l4@2@R13`W9P@Z6aT4:QLG12XL6@@]6AT360XA11H93`@N4AT4
6a4G11<83`@K41L35@T@11T?5P@E2A04;A/L10D120@H3aH48ALG0adB5`@50@P4100810X01`@F3QD4
5`lF0aH>5@@a7Ah4?2XR13lm>P@G2PL4f=;B=^7Ph1Goool001Coool[hN3P0oOgm`BBN7<4Bc@a14lj
>0A<?C/4D40n15A5@`=B?3l4@2@R13`W9P@Z6aT4:QLG12XL6@@]6AT360XA11H93`@N4AT46a4G11<8
3`@K41L35@T@11T?5P@E2A04;A/L10D120@H3aH48ALG0adB5`@50@P4100810X01`@F3QD45`lF0aH>
5@@a7Ah4?2XR13lm>P@G2PL4f=;B=^7Ph1Goool001Coool^hN3P1?Ogm`BCLfh4CShk14Lb;`ADA484
EDE30em9APA4=3<4@Bd[138K9`@M4AL4:aPG11dA5`<U61L481HF11X@5PPD20l44`L>0a@83`@C1`h4
8ALG11P?5PA3=d84;blf12TH9@<F2A04714G21`E5P@H3aD4=BPY0c@T90@a7Ah4DSTe14@i<`B=JETj
hN3P5Oooo`005?ooobkQh>04moOg19=cKPA>?S/4Ac8_15A4@PAEAD<3GdU614@d<`A1;B/4<Q/W11dA
5`@[61L47A4G0bDH5`@P5QH46Q0F21@83`@C1`h350P?11<73P@Q5aL460lF14<g@P@_;cH4:APU0aH9
40@L4AL871DF11P?5@@e:2T3=2@T134M7PAB>CD4A3Tc18eYFC[Qh>0Eoooo000Doooo;^7Ph0CgmoL4
Tg=^14hn>`A7<Rl4E4A215E5@`=OBDH4A3@c144]:`@b6bL47A4G12/H5`@M4AL39APG120F5P@J41H8
50P?11<73P<D20l44`L>124G5`@H3aH4@cM212l_=P@Y62D35PT@11`A5`PL5AH460lE13DX:@<d92@4
<AdN158i=@A4>C<4SFUI>^7Ph1Goool001Coool^hN3P1?Ogm`BCLfh4CShk14Lb;`ADA484EDE30em9
APA4=3<4@Bd[138K9`@M4AL4:aPG11dA5`<U61L481HF11X@5PPD20l44`L>0a@83`@C1`h48ALG11P?
5PA3=d84;blf12TH9@<F2A04714G21`E5P@H3aD4=BPY0c@T90@a7Ah4DSTe14@i<`B=JETjhN3P5Ooo
o`005?oooc;Qh>04n?Wj19=_JPAKB4H4A30^1551?P=OCDX4HDY714Pb:0A1:bP49aTI11X@5`@G2@l3
6Q0?11`A5`@F2@l450P?11T?5P@C20l36@lF11<83`@B1`h4=c<g134S<PACB4l4Fdm=0dLc>`@o=CL4
>B/[12DI60@d9B<4<28S0ddk>@AF>S@4=c4b17AABSkQh>0Eoooo000Doooo<^7Ph0ChnOX4TfmZ15]8
APA4<2h4DD4n0em=BPAQBTL4B38X144[:0@W6AT46Q0G11L93`<J40l4714G11H93`@D20l46@lF11<8
3`<I3aH44`P?11873P@g<cL4<B<b15=8C`AKCdd3Ac<k13le=`@i:b/49ATH13@U8`@`8R<3CC/i15Hj
=0@g<C84M55:?^7Ph1Goool001CooolbhN3P1?SinPBCKfX4FdQ614@`;PAA@Ch3Gde:165:A`A8<RP4
@B/X12LI6@@J41L45`T?0aX@3`@L4AL45PT?11@83`@I3aH44`P?0aT?5P@C20l44PL>13Lc=`@a8c84
DdQ?15]?C@=7<c/4?cDg13T[:`@U6AP4=2DS130R8`==>cT4ESXd13La<PAdDDXnhN3P5Oooo`005?oo
oc;Qh>04n?Wj19=_JPAKB4H4A30^1551?P=OCDX4HDY714Pb:0A1:bP49aTI11X@5`@G2@l36Q0?11`A
5`@F2@l450P?11T?5P@C20l36@lF11<83`@B1`h4=c<g134S<PACB4l4Fdm=0dLc>`@o=CL4>B/[12DI
60@d9B<4<28S0ddk>@AF>S@4=c4b17AABSkQh>0Eoooo000Doooo<^7Ph0COg]l4oooo18aREPAVD4`4
D3`j0eM9A`AVDDd4He1=14D[:0@n:2L4?c4_13D[:`<W5aL48QLF11`A5`@J41H44`P?11@83`<O5B84
714H120F5P@H3QD4?3<a148b=P@Y61d3<20M12XL6`@W5a`4<Q`J138T8`A6;RH3ED<j16=OF`AVAT04
hMWI?^7Ph1Goool001CooolbhN3P1=oNg`Coool4S69F16I@C0A@?3X3EdU716IAC@ASD4d4AB/X13hX
9`@o<Bl4=B/[0bLG5`@R5aH4714G11X@5P@C20l450P?0alE8P@L4AP481HF11P>5@@l<c44@S8f12TH
7@<`81d4:Q`K12LG70@b71X4<R@S14H^9P=E@cX4HemK16I6@0CQfMTnhN3P5Oooo`005?oooc;Qh>04
gmkO1?ooo`B<HUH4IU1<150l>P=GBDL4IU5=16=@C@A5:bP4?RPW13la;`@e:b/39aLG128G5P@L4AL4
6Q0F11<83`@D20l37aDR11`A60@P5QH460hE13`c<@A2<SH4:APM0c0P7@@Z71/49aLL138L6P@b92<4
ARhV0eE3>PASGe/4ITI01>7IfCkQh>0Eoooo000Doooo<^7Ph0COg]l4oooo18aREPAVD4`4D3`j0eM9
A`AVDDd4He1=14D[:0@n:2L4?c4_13D[:`<W5aL48QLF11`A5`@J41H44`P?11@83`<O5B84714H120F
5P@H3QD4?3<a148b=P@Y61d3<20M12XL6`@W5a`4<Q`J138T8`A6;RH3ED<j16=OF`AVAT04hMWI?^7P
h1Goool001CoooljhN3P1?Wko@B6IUX4DcXe0e8n?0AZF5D4KUiL16]ED@@o:BP4=B4V144T8P=7=S@4
>R`Z11hB60@D20l49adY12LL:0<_9bL4:b0]13`b=0@V6RD4?3Lj14Pg>PAA>SP3?2l`13//:P@o<C04
@c/i14<b<0AFB443C4<l18YXEPC7^lA2hN3P5Oooo`005?oooc[Qh>04nO_m18IVFPAC>SD3DShl16YH
E@A^GU`4JeEA13lY:0@e8BH4@B@R0dLf=0@j;2X47Q8H11@83`@W7BT49a`X0blW9`@[82d4?38d12HJ
9@@l=cX4B3Lj154j>0<l;c04>b`Z13la<0A3>cT4@c8`15I8@@=<@c`4RVQF1<Nka4;Qh>0Eoooo000D
oooo>^7Ph0Cinod4QVIJ15<j=@=B?S`4JUQE16iNG0A[EE44?bTX13DQ9PA19283AcHd13X/:P@N4QP4
50P?12LM:@@W72P3;bLW12/P;@@l<S@49QXU13`g>PA8=cX4DCXh0c`_<0@k;2X4?c4`14<k>@A3<S04
ETQ10da3?0B:J5H4ak_4@^7Ph1Goool001CoooljhN3P1?Wko@B6IUX4DcXe0e8n?0AZF5D4KUiL16]E
D@@o:BP4=B4V144T8P=7=S@4>R`Z11hB60@D20l49adY12LL:0<_9bL4:b0]13`b=0@V6RD4?3Lj14Pg
>PAA>SP3?2l`13//:P@o<C04@c/i14<b<0AFB443C4<l18YXEPC7^lA2hN3P5Oooo`005?ooockQh>04
nOSj19f?R0=PCD/4Dclm16E=BPA]HVP4LEiL15e=B`AGCDl3BS@h14Tn@PAEC5@4C4M;13`_=0@n<d<3
@38k15A:D@A4>3`4ECdi13lf>PARAT84EcTh0eLh;`AD?S`4F4Dn16=?A@AX@C@4?Sdn0he[FPCQfMU6
hN3P5Oooo`005?ooockQh>04nOSj19f?R0=PCD/4Dclm16E=BPA]HVP4LEiL15e=B`AGCDl3BS@h14Tn
@PAEC5@4C4M;13`_=0@n<d<3@38k15A:D@A4>3`4ECdi13lf>PARAT84EcTh0eLh;`AD?S`4F4Dn16=?
A@AX@C@4?Sdn0he[FPCQfMU6hN3P5Oooo`005?ooockQh>04nOSj19f?R0=PCD/4Dclm16E=BPA]HVP4
LEiL15e=B`AGCDl3BS@h14Tn@PAEC5@4C4M;13`_=0@n<d<3@38k15A:D@A4>3`4ECdi13lf>PARAT84
EcTh0eLh;`AD?S`4F4Dn16=?A@AX@C@4?Sdn0he[FPCQfMU6hN3P5Oooo`005?ooockQh>04nOSj19f?
R0=PCD/4Dclm16E=BPA]HVP4LEiL15e=B`AGCDl3BS@h14Tn@PAEC5@4C4M;13`_=0@n<d<3@38k15A:
D@A4>3`4ECdi13lf>PARAT84EcTh0eLh;`AD?S`4F4Dn16=?A@AX@C@4?Sdn0he[FPCQfMU6hN3P5Ooo
o`005?oood;Qh>04j>WW0m_?f0AnIfd4H4a:15Q<D@A/JW<4Nf]/17MUHP=kK6L4IeUL15iHF0A]GF<4
KEEA15]9A`=;>T<4AC4_15E0@PAIAD<4DChl16A2>PAZASh3JdU2171@A`AS@CT4LeeK19QdIPAJA3a=
hN3P5Oooo`005?oood;Qh>04j>WW0m_?f0AnIfd4H4a:15Q<D@A/JW<4Nf]/17MUHP=kK6L4IeUL15iH
F0A]GF<4KEEA15]9A`=;>T<4AC4_15E0@PAIAD<4DChl16A2>PAZASh3JdU2171@A`AS@CT4LeeK19Qd
IPAJA3a=hN3P5Oooo`005?oood;Qh>04j>WW0m_?f0AnIfd4H4a:15Q<D@A/JW<4Nf]/17MUHP=kK6L4
IeUL15iHF0A]GF<4KEEA15]9A`=;>T<4AC4_15E0@PAIAD<4DChl16A2>PAZASh3JdU2171@A`AS@CT4
LeeK19QdIPAJA3a=hN3P5Oooo`005?ooo`CQg]h4hMkO@N7Ph0Cin?H4T8FA18QmMPA/I7D4RG^018f3
R@>:O7d4PfiZ181]K0AoJ6D4Pf]/17=OGP=hHUh4JeYL165@B`ASE584Lf1N16MFD0AaE4/3JD<o17QU
H0BEO7H4OV5H18eiOE7Qh>0Eoooo000Doooo1>7NgPCQg]m1hN3P1?WhmPB@QI44R7ef16aTM@B9Nh04
SH>90hYlO@B3KVX4P6e/17mXI@B3Jf`4LemN0gQRGPA[FU`4HE1;16=DDPAcH5h4IeI@175DB`=Y@cl4
N6EP19ElMPAnHEP4SGUmDN7Ph1Goool001Coool4hMkN1>7Ngd7Qh>04nOSf1925T@B8OGH4K6Ae18Uk
P0B=PhT3RWam18=^JPB0KF`4OfQU18=[K0AcGeh3N69N16]JG0AQD4/4HeAB17=PGPAWEU04LEA;0fU3
?`AhIF04UGaf17iQF0B=NGeAhN3P5Oooo`005?ooo`CQg]h4hMkO@N7Ph0Cin?H4T8FA18QmMPA/I7D4
RG^018f3R@>:O7d4PfiZ181]K0AoJ6D4Pf]/17=OGP=hHUh4JeYL165@B`ASE584Lf1N16MFD0AaE4/3
JD<o17QUH0BEO7H4OV5H18eiOE7Qh>0Eoooo000Doooo1>7Jf`CQfMU9hN3P1>CUh`CYh>D4Q8>E1:2C
T`>o]/H4[:2W1:RBT0B:Mgl4Og1g18M/KP>8K6L4NfMT18U/J@AfH5X4LeQ>17mQEPAbJf83TXIm16=H
E@BgYJiIhN3P5Oooo`005?ooo`CQf]/4hMWIBN7Ph0CTiN<4jN3U18B3U@BPTi<3_kK61:bPY`BXTY04
RWMo17m`M`B7K6h3R6aW17]WI0B9K6T4MV1J17=HCPAoHEH4LV]R0i:6O@ASF5D4]jF^FN7Ph1Goool0
01Coool4hM[K1>7IfDWQh>04i>GS1>WPi@B4PiD4X9>C0knfaPB/X:L4Z9:@18YgO`AoL7L4Qfa^0hQ/
I`AkIf@4RFaY17IPFPAcF4h4Of5F179[HP>BQWd4HeQE1;NU[UWQh>0Eoooo000Doooo1>7Jf`CQfMU9
hN3P1>CUh`CYh>D4Q8>E1:2CT`>o]/H4[:2W1:RBT0B:Mgl4Og1g18M/KP>8K6L4NfMT18U/J@AfH5X4
LeQ>17mQEPAbJf83TXIm16=HE@BgYJiIhN3P5Oooo`005?ooof7Qh>03i>GR1=3;f`CXh]l4e<SD19VD
XPBKUjT3TXV719:6Q0BBQhD4U8V718j5Q0B6MFd4JfAJ0n7IfF7Qh>0Eoooo000DooooHN7Ph0?TiN84
d<_K1>SRg`CDb=@4VIBR19^GZ@>BRHL4TXJ419:7Q@BDRHL4SXF418IeK@A[I5X3hMWIHN7Ph1Goool0
01CooomQhN3P0nCUhPC@bm/4j>;O1=C8e0BIU:84ViNY0i:9Q`BBQX@4TXN519B9Q`B>QH@4QWE]16]T
FP?QfMUQhN3P5Oooo`005?ooof7Qh>03i>GR1=3;f`CXh]l4e<SD19VDXPBKUjT3TXV719:6Q0BBQhD4
U8V718j5Q0B6MFd4JfAJ0n7IfF7Qh>0Eoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo002Ioooo0`0008Coool009coool00`000?ooooooo`21
oooo001koooo100000Coool00`000?ooooooo`02oooo0P0000Coool400000_ooo`<00003oooo0`00
00?oool20000O_ooo`00Noooo`030000oooooooo00Goool01@000?ooooooooooo`000002oooo00@0
003oooooool00002oooo00@0003oooooool00005oooo00@0003oooooool00023oooo001loooo00<0
003oooooool01?ooo`050000oooooooooooo000000;oool010000?ooooooo`0000;oool00`000?oo
ooooo`0400000_ooo`040000oooooooo0000Poooo`00OOooo`030000oooooooo00Coool010000?oo
ooooo`0000;oool010000?ooooooooooo`<00003oooo0P0000Coool40000P_ooo`00Noooo`040000
oooooooo00000_ooo`040000oooooooo00000_ooo`040000oooooooo00001Oooo`030000oooooooo
08goool007coool200000oooo`@00003oooo0P0000Goool20000Soooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(292) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE4EAE1
DCCBB5E3D1BCE3D2C3E3D8C9E3D2C3E3D9CAE3D9CAE3D9CAE3D8C9E3D1C1E4D0B9DCC9B1
DDBFA7D5B39DD5B19ACDAC95CDAC95CDAC95CDAC95CDAA93CDA58BC6A58AC6A58BC6A58A
C4A289E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3E8E7E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3F0F0E3F0F0E3EFEFE3F0F0E3F0F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3F0F0E3F0F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE2ECE4
DBCAB4E3D1BAE3D2C4E3D8C9E3D2C3E3D9CAE3D8C8E5D9C8E6D9C8E6D1BFE6CFB6DFC7AE
DFBEA5D7B29BD6B098CEAC96CDAC95CDAC95CDAA93CDAA93CDA58EC6A589C6A58BC6A78E
C49E85E3EFEFE3EFEFE3EFEFE3EFEFE3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EEEEE3E8E8E3F0F0E3EEEEE3E7E6E3EFEFE3F0F0E3F0F0E3F0F0E3F0F0E3EFEF
E3EFEFE3EFEFE3EFEFE3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE5EBE2
E4D2BCE3D1C3E3D2BCE3D9CAE3D1C3E3D9CAE5D8C6E5D0B9E0C9B0DEC5AEDEBFA6D6BAA3
CDB39CCDAC97CDAB95C6A58ECFAB93CFAB93CFAA93CFA58BCEA58FC6A58EC6A58EC09D7B
C0BCB2E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3F0F0E3F0F0E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3E8E7E3EFEFE3EFEFE3EFEFE3EEEEE3E7E6E3EEEEE3E7E6E3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE2EAE1
DBCBB5E3D1BBE3D1C3E3D2C3E3D8C9E3D1C2E2D1C2D7C9B3C0C1B1D1B8A5D3AC9BCBAC95
CBB29DCBB29DCDAD97CDAB93C6A58EC6A58EC6A58EC6A58EC6A68BC6A48EC6A58EC4A289
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3ECE4
E3CAB5E3D1C2E3D1C3E3D1C3E3D1C3E3D1C2E3D1BBE3D0C2E2D0C1DCC8B2E4B9B0D3B39D
D3AC98D4AB9CD3AC9DCB9B8DC5A38EC5A893C6A48DC6A58EC6A58FCDAA93C6A792C3A088
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3ECE5
E3D1BAE3D1BBE3D1BAE3D1C3E3D1C3E3D1C3E3D1C3E3D9CAE3D9CAE2D0C1DAC8B2DBB9AA
DCBAA6DBB9A4D5AD9DDCB6A2CD9E90CD9F8FCDB3A5C6A48DCFA58ECEA58EC3A692C9AD94
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3F0F0E3F0F0E3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE6E6DEE6F2EB
E3D1BBE3D1BAE3D1C2E3D1BCE3D1C3E3D1C3E3D9CAE3D0C2E3D1C3E3D8C9E3D1C2E2D0B8
DAC1ABDBBAAADBBAA4D4B19CD4AC9ACDAA93CEA690CEB09DC6A58EC6A58EC5A58DDCCEC6
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EEEEE3E7E6E3EFEFE3EFEFE3F0F0
E3F1F0E3F0F0E3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFC7B7A7EEF3EAC9B4A8
E3D1BCE3D1C2E3D1BAE3D1BBE3D2C3E3D8C9E3D2C2E3D9CBE3D8C9E3D8C9E3D1C2E3D1C1
E5C7B1E5C2AADCB9A5DDB9A0D6AA98D6AC95CDA48EC6A58EC7A792CDA590C29F87DBDEDE
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EEEE
E3E6E6E3E7E6E3EFEFE3EFEF
E3EFEFE3EFEFE3F0F0E3F0F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE5ECEE94635781857BDBCAB3
E3D1BCE3D1C2E3D1C3E3D1C2E3D2C3E3D9CAE3D0C1E3D1BBE3D8C8E3CFC1E5D0BCE6CEB4
E6CFB7DCBAAADDBAA5DEB19FD5B195CDA690CEAA90CEA58FC7A68FCFB098CCAA92E3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EEEEE3E8E8E3F0F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE2EEEDA07C64C1C2C63B3C45E3D1C3
E3D2BCE3D8C9E3D2C3E3D8C9E3D1C3E3D2C3E3D9CAE3D8C9E5D1C0E6CDB8E5BAAFDDB9A2
D6B49DDEBAA3DDBAA1D5B7A0CEAA93D6AB93CDAA93C5A589C6A58EC6A690C5AB98E4F2F3
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3F0F0E3EFEFE3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFA27D65ECF8F4424A44DBCAB3E3D1BC
E3D1C3E3D1C3E3D1C2E3D1C3E3D1C3E3D1C3E3D1C3E3D8C9E4BEB0DCBCA8DDA99ADDA996
D5A592D5B59CD6B098D6B093CDA890CEA58CCEA58FCDA58ECDA58BC7A38CD0AE97DFD5CE
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3F0F0
E3F0F0E3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE5ECECD8E4E2444C46E3D8C9E3D1C1E3D1BC
E3D1C3E3D1C0E3D2C1E3D2BBE3D2C4E3D2C3E3D5C6E3D0C1E4BCAEDD9084DE8274D68880
D68378D68981D5A38DCFA48CCFA58BCE9C87C7A58ACDA58ECDA58EC6A287CDA08CC8AB96
E6F7F8E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EEEE
E3E7E6E3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF967C70D3CFCBDCD2C9E3D1C2E3D1C2E3D1BC
E3D1C2E5CFBEE6C9B0E4CBB5E3CAB5E3D0BEE5BEB1E6A99AE7B3A8DD816DD98E82CD786F
D57466D07464D68579C69080C6A08AC6A280C79F88CEA58FCDA58ECDA48ECD9F8ACDAC96
CBAF9BE3F1F1E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3F0F0E3F0F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFDED9D9DAD3C23E4F55DBCAB4E5D0B7E4D2BCE3D1BA
E3D0BEE5CDAFDFB99FDEBFABE6B6A2C25338F1C6AFDD9389D38E82C49084B17462CEA98E
D49B80C9756AC16854D37464C79482C7A383C69D7EC6A78CCCA690CDA48ECDA690CDA58E
D0B09AE6E8E1E3F1F1E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3F0F0E3F0F0E3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF9E857CABA5A5AF9D8CE3D1BAE4CDBBDCC6B1E3D8C9
E3CFBDE4B493D6A788BA493CEEC2BBC9716D652119D09D8BD18A79DBB0A2E3D7CBCE7167
B38671AD8972AB74628C543BCF705CC19C84C79C7ECCA18ECCAD97D4B295CDA48ECDAA93
CDA791D0B196E8E4D9E4F1F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE6EFF08961565C6465DCCBB5E3D1C2E2CFB9DBBBA8E3D1C3
E6C6AFE2AF87CD7759AB442E825B58C4C8BBE6DDD0E4E6DFE3E8E3E3E2DEE5D6C8DECFB9
E6D6C4D7D1CBAEA296866B62704939C2745DC9A58ACEA28DD4B4A0D4B29BD5B195CDA28B
CDA68FCEB2A0D0D1DDE2E6E6E6F2F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFC7B7A791665BCDBFBE364148DBCAB4E3D0B8E3D1B9E3D3BCE3D1C2
E4C4AED2A590AD896E98534D653F37D39A8DDDB8A3DFB6A7E7CCC1E7C7AEE7AF96D8927E
DFAA98DAB49DE5B99FC49E8DA78C7C713120C1816FC6A38DD5B69BDDBFA4D5AF98CEAA93
CE9F8BCDA994BEBFAFBCB9B3CCD2E1E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3F0F0E3F0F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE6EEEF5E493B5B4137404547AE958CE3D1B9E3CEB9E5C4ADE4C3AEE3CFB9
E4C8ADD69D80D6B9A5DBC9B3E3CEB9E2B8B2D9AEA3D0A89CD1A69CDA9590C99B90CA8177
CA776EC58275CBA18FC48470BB745E9A513F7C4437CD9B8AD6B79BDDC0A4D5AF93CDA28B
C7A68FCDAD96A7755DEFF4F6C2C1D1E4F1F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3ECEDB4BBBF013138283C44E4D2C2E3D0B9E3C9B4E2BAB3DBCCB5E3CFBA
E4B6ABD4A58DBD9780E4D3C5E3D9CAE3D1C2E3D2C3E3D9CAE3CEBFE4CFB5DCBAA5DDB9A2
D5B195D5A98FD09A87D68B80C47D71A96B5D8E58509A6358CFA995DDB9A0D5AF93CDA48B
C79E8ACDA791A6847476665CE6EAEBDBDEDEE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE1ECE8C8D1DEE2CFB8DBBAA5DDCBB4E4D1BAE3CAB4E3CFBAE3B9B3E3D1BA
E3CDB5D4AF98CE9E88DFC8B2E4D2C5E3D8C9E3D1C2E3D2C3E3D6C6E4B9AEDDB59DDDBAA1
D6AF94D5A890C8A080C79881C7A181C79881C79A81BF948BC5A182D5B29AD5AC90CEA38B
C7A587CFA58F815D5076715EC2BEB3E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE5F0F0E4EEE6E5D0B8E6CEB7E6D9CCDECBB2DBCBB5E3D1BBE3D0C2E3D1C3E3D8C9
E2CDBEDBC0A8D4A891CCA390DCCDB8E3D9CAE3D4C6E5D4C2E4D9C9E5CBB1DDB79FD69D84
D6B194C59C80B89B80BF957BBF9277BF9478BF8E74BE9C83CCAC96D6B098D6A790C69C87
C69F89C6A68B563E3B615F5DD7DBEDE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE2EEE8DBE1DEE5CBB1DEBEA5D3B69EC1C2C0E3CCB6E3D2C3E3D9CAE3D9CAE3D9CA
E3D6C6E2B9B0DCB79ED6A58FDDBFABE3D2C3E3D6C7E2BAB3DBCAB4E3CCB5D4B29BD4A891
C5937FC59B83BF8E78BF967BC09882C59C7DBA987FBC947CD6AA93D6AA93CDA48EC69C87
C69F87C7A58F6C493C524946C8C6BEE3F0F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3ECE5E5D1BAE4B899D6B7A3C8AE9ADBCAB4E3BBB5E3D2C3E3D8C9E3D8C9E3D9CA
E3D8C8E3D0B9E4BEA5D5B295D6A997E4D3C5E3D8C8E3D1C4E3D1C2E4CEBDDDB4A1D6B098
CEA58ECDA18ABE9177BF8D78C09883C59F8DCBA08DD4AC97D5B29CCDA590CEA48ECEA48E
C69E89C6A78DB8957652463D675750F5F8F8E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFECE6DECDE6A990DDBFA3C1967EDFC9B4E3BBB4E3D1BCE3D2C3E3D9CBE3E1D8E3D9CA
E3D8C9E5D1C0E4CEB6D3B39ED2B39ADBCAB5E5CFBEE4D4BDE3D5C7E5CDB4DDB79DCEA38C
CEA088C7A384C5947CC89878BF9582C5A08DD5AE9FDDB9A2D5B29ACDB098CDAA93C6A58B
C6A28CC6A994CCAA91AF8D715A3222433A32E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3E6E2E4BDAAD5937EC68477C2A191C1C3B5E3D1BAE3D1BAE3D2C3E3D9CAE3D9CAE3D8C9
E3D8C8E4D0C0DBC9B1DBC4AEDCCBB5E3D1BAE2CEB9DBBBADE3CEB7E4B8ACD5AB8FCE9A84
C69780C1947CC69A7AAD8D7BBC9482CCAE99D5B49FDDB9A2D5B19ACDAA93CDA28ECDA38E
C6A287CEA28FCDA585C79D88C1957DE2EEEEE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3F0EE
E3EBE4E4B2A4D4907AC7897EC2A896DBCAB5E3D2C3E3D8C9E3D1C3E3D9CAE5D9C7E4D9C9
E3CFC0E4D1B8DDC8B0E5C4ADDCCBB6E3D2C2E3D8CAE3D1C3E3CDBEE4BBA0D5AC94C69A83
BF957EB8917DB8937DBF9A87CDAE98D4B59FD5B9A3DDB8A0D5B29ACDA790CDA28CCE9C8C
CE9E8BC7A190CCAA96BE937BCBA794F0FCFCE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE6E4D1
E6C0A5D39E7DD5967BC1977FCAAE9BE3D1BCE3D2C3E3D9CAE3D8C8E3D1C1E4D1C0DDC9B2
E6CFB6E6BBB2DCC3ADDCBAA6DCC3AFE3D1C3E3D1BBE3D1C3E5CFBFE5B5A8D5A18BC69A83
BF957FBE9882B79F89C5A78DCCAE97D6B49DDDBAA5D5B29CD5AB95CDAB95CE9D89CE9C87
C69D89C7A98FCE9676CEA490C69E86C4C7C8E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE4CFB3
A96B47B17561865D51AF8E7DD4BDA9E3D1BBE3D1C2E3D1C2E3D1C3E3D1BAE2C9B3DAC8B2
DBB9AAD5B8A3DFBAA7DECCB4DDCBB4E4D2BCE3D1C3E3D1C2E4CEBEDDC0A5D5A190C79B80
BF937CC19883C6A08CC7A58FD7AD9BD6B29DD6B198D7B9A1D6B098CFAB93CEAA93C6A28B
C69C8AC7A090CCA383C2836ACFA690C48A71E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3F0F0E3DCD2
C082676D4F3F7C574E6D6766D4BDAAE5D1C1E4D2C3E3D1BAE6CDB3E8CFBBE5C1A8E7C2A9
E7C1AEE0AC9FD8AC99CFAC95DFC5ADDDCCB7E3D1C3E3D1C2E4CDB6DCB4A0CC9E83BF8E7C
BF957BBA917BC89E88CFA890D0A68FCFAE98D6A997CEA791CDAB95C6A48EC6A58EC6A28B
C69C8AC69F8EBE8366B66F4EC49372C48B7CE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE5EBE0E5D5C7
73332767423660473E6B6566D5BCA8E3D1B9DBCBB5E3D1C2E2CDB5CCAC94C8A286A07E6E
906B5CAB7257C58B7ACB7F61CC8163DCC5AFE4D3C5E3D1C3E4CEBDDCB3A0CC9F83BF9777
BF8B71B99A85BC9985B49E8BB59E89C6A38FCDAE94C8A791CDAC95CDAA93C6A28BC8A28B
C89E8AC69E8EBD876C9C634D9E6956BC8463E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE2EEEDE2E7DDDCB79D
A16D6243302B513A34495458DBC3AEDCC9B3E4CBB5E3D1BAE2D0BAD9BAA1AC9D8B8F7360
60453D644739806457AE7B649D6F6199675EDCC3AEE3CFC1E4CEBDDCB9A0CA987EBF9170
9F482FB99079C89F7CCC9F85C48F72D3A38AC69D8CBA9F88CFAB94CEAA93C59F87B89D87
B99D8AC6A088B57C66A4705AA37162B86A50E2EEEEE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3F1F0E3F0F0E3F0F0E3F0F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF8E4B3CFFEEDAE5C0A7
B07662503F4545342D544E53DDCBB4E3D1BADCCAB3E6D2BAE4D2BCE2CEBDCCAC97D4B09E
6C6F664E534D605B5170756FA48172CCAA96DCCCB7E3D9CBE4DDCEDCBFA5CB9B7EAF8670
A9775D7F554DA17A6A402624A26D599073608F634CB9907AC3926CCBA082C5A38CB89782
B99C87C0947F9868528B5D4EA6806FC18373EBF7F6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3E8E8E3E8E7E3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEF9764598D6458531F18C17B64
744C52513C334D3B3839474CDCCAB3DCCBB5E5C2AAE0C8ACDECDB8E2D0C1D9C6B1D0B09C
C3A38CC2A48EAA8B73AA8E76C2A78ED4AE9ADCC4B0E3D9CAE4D3C2DCBFA6CC9D82BE9173
AE866F9C7C6D938579423434493A317A5B5269564B715F50967E6D9A826BBE9077B89D87
B99E879F6B5D815D48714D3E876C5BCEA78FECF8F7E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3E6E6E3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF9160555D463A553A34513934
3E2A2A4D3A364C3933495255DBCBB4DCCBB4E1CDBFCB9D8FCE9F85E8C4ABE2C2A7D6AA95
C68873C28869CA9173CD8D70DDB99CDEBDA8DCC4B0E3D9C9E4D3C0DCB9A7CCA88EBF9374
B89C78C1947AC5A38DA78A7A2D474B64584D70655A55615C8E7B67B18D7AC7A487BD9884
B89C878F644C5E4039694B3C7B5948BE755CE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF9A6C554B2F274838304C362F
48363039312C5C4A455C5757DEC5AFE2CAB4DBCAB5E1CEBFC4AD9AAB8978B39281A6907E
8D7B6D816E638C7260947A6B977569C8B39FDBCAB4E3CFC0E4D0B7DCB8A2CCA493B6775B
B97658BEA17BC8A588C6A58CC4A48EB3957F9F7E6DA1816FBF9781C69C7FB89D87C8A587
C0997F5E473B483830595954765545AD5A43E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3F0F0E3F0F0E3EFEFE3EFEFE3EFEFE3EFEFAA826C522F2744332C3C342E
2C1F1F45342E5148436E6D67D0B8A3E4CBB5E3D1BCE3D1C3E2D0C1D7C4AFB7938A908684
BA9389A98574A88B7AA28274CAA693DCCAB5E5D0C0E6D0C0E5BAB1DCC0A9CAB09CB78D84
8E5E5287594691664BCD997ACBA78CCEA58BC5A487B89C87C7A084B89881C89D8FB79D87
9F6E5561433849443D54554BB36D518B6156F4FFFFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EEEEE3E7E6E3EFEFE3EFEFE3EFEFE3EFEF9B83795D463D46322C44342E
362D263B302B5548436C6C64B6A391DCC4AFE3D1BCE3D2C3E3D9CAE3D8C9E3D7C8E3D7C8
E3D8C9E3D8C9E3D8C9E3D8C8E2D0B9DBCBB5E2D8C7DBC9B1DCC8B0DBC3ACD3BAA6D1B8A4
BCA08E7E6A666F5F546950418A5D48BA816AB28D73C08C6DB4886CC19986A8927EC79A88
7E5044523931493A39563229964835885F525B524AE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFAA8D8466564F41362F45342E
44342D433837544843726A60BD9F8BDEC6B0E3D1BBE3D2C4E3D9CAE3D9CBE3E2DAE3E1D8
E3E0D7E3D8C9E3E0D6E3D9CAE3D8C8E3D1B9E3D1BAE4CFB7DCC2ABDCBAA5DCC3ADDCC1AC
DCBAAACCB1A1C09A8B8B7C706D6258695D50876B5B7E7A6B907A69947A6CC79D8BC49780
7B4E4249352F3F342E3B2F2855383275524A645A52E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFAB836D684F425D484141342D
492E264D3A3457463D706156A9937FCEB8A4E4D2BBE3D1BCE3D2C3E3D8C9E3D9CAE3E2DA
E3E1D8E3E1D8E3E0D6E3D9CAE3D8C8E3D8C9E3D1B9E4CEB5DCC3ADDCC2ABDCBAA5DCC2AB
DDB9A8D4B8A0CCB19AC4A48DB39E8AA28F7C947E6E97806EB6927FB79B87BE9084AB8065
734D4149352F4C39333C342D40332C5C473B7E7C77E9F7F6E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF9B79616C564D58443C523C36
392D2648332D4A362F6B51428B745DCBAE9BDCCBB5E3D1BCE3D2C3E3D9CBE3E0D7E3D9CA
E3E2DAE3E1D8E3E1D8E3D9CAE3D8C7E3D1BBE5CFBEE5C9B1DCBAA5DCC2ABDCC2AADCBAA5
DDB9A2D6B19AD6AC95CDAC97C6A48ECDAA93C6A58EC6A28BC89C87C89C8BC2947B866152
4A362A4F3B3B392E2D3D2F272B1F1F4F3A3475685FB8ADAEE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFAA836D61504764544D52423C
513B343F322C4D3F39574B46785F51A18871DEC6B0E3D2BCE3D2C3E3DACCE3E2DAE3E0D7
E3D8C9E3E0D6E3D9CAE3D9CAE3D8C8E5D1B9E5CFB7DCC2AADCC2AADCBAA5DDBAA5DEB9A3
DDB9A3D5B19ACDAC95CDAC96CDB19AC6A48ECEA58EC5A28BB79C87B79A84A7806B714C40
54443D3025253B2F302A1E1F352D2C3C302B695C5896837AE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFA38D836C564D64565060514B
523C363C2F274E3A34604E42736658837968CFB39FE4CBB6E3D1C3E3D2C3E3DACCE3E2DA
E3E1D8E3E0D7E3D8C9E3D9CAE3D8C9E2D1C0DBC8B1DDC1AADEB9A3DDBAA5DDBAA3D5B8A0
D5B29DD5B29ACDAC95CDAA93CEAB93CEAA93C7A088C6A38CB89780BB8C7798695366453C
3D2F273C30302E2425352C26322A2B473833271F16786D65E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3F0F0E5F1F19B847A65554E69595364544D
4D393252403A473C375846407C6352997C69C19880DDC5AFE3D1BCE3D1C3E3D1C3E3D9CB
E3E1D8E3E1D8E3E0D6E3D9CAE5D7C6E4D2C1E4CEB5DBC2AAD3BAA4D5B39DDDB3A3D5B19A
D6AD98D6AB9ACEA893CFAB93CEA58EC6A58EC6A18BBF9782C4937BB1836A7857465E4037
42352E3A322C3A322D342B253A322C4838343D2C24E2EEEEE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EEEEE2E5E58E746968524661524C685953
5F514A4C3E385648415A483C6A615999745FBD9884D7BFAAE4D2BCE3D2C3E3D9CAE3D9CB
E3E2D9E3E2D9E3E1D7E5D9C7E5D7C4DDCBB4E5C7AFDDB9A0DEBAA4DDB9A0D5B39DD5B39C
D5AC95CDB29ACDA993C69E8EC6A28BC6A38CC6A28BC49780B38B7191645770493D473830
3D2F27372E2E312626231F1F30262654484341322AECF8F7E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFA98D835D4A3D6C574E655650
604F475840395A493C5D4F496C5C4F866555A4846FCFAC99DCCBB5E3D1C2E3D2C4E3D9C9
E3D9C9E3D9C9E3D8CAE2D1C0DBC8B1DCC2ABDDC4AADDB8A0D5B298D5B49CD5B397D5B098
D5B29BCDAA93CDAA93CDA58EC6A28BC79A84C39880B38B719167597E584552393242352F
42342D352C2C3025262E24253E3430000000543931E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFBEB0A966534C6250476C5953
644F41594A4353403A6250475E4D467260558B6A59BF9982E0CEB7E6D2BAE4D2BCE3D1C2
E3D1BAE5D1B9E6D2BBE4D2C2E4CDB5DDBEA5DDB9A0D6AA93D7AC96D7AC9BD6B29BD6AF97
D6A58FCDA893CEA58ECEA58BC79F88C69A84BA8F779A6D597D5845533A32403128392E2E
42342E392E2E2A1E1F2F242645363245342CECF8F7E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFC0B1A276635C64565062524B
68544D533F3C56453E5749426556505D4B3E6F5648A4826CCDAA8EE0C9B0DECCB4E6D1B9
E6D2BAE5D1B9DCC9B2DDCBB3E6CEB5DEB49CD7AB93D6B093CDA38CCDAB94CEAB93D6AA93
CEA28BCFA28CCE9B88C7A188C49D80BA886EB18369805C48573B32473830392E26302526
302526241F1F221E1F413431483A3242332CE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFDADFE077615768595364544D
675A545F4C3F4F3B365D514B594B4369595259443C7761539C7964CC987DDCB79FE0BDA3
E1C3ADE0C8B1E0C8AEDFC3ABDEBCA2D2A78BCF9B81D19F81D0A38DCF9D87CF9D84CFA48D
CEA284C79A84C69780BF9078B590789E735F8959456C473C4D3830392E26312626302525
291E1F211E1F2B24253A302B3C3028442A19E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFDFEAEAA18E84624E4765554E
62524C5E5149543E3C5C473B64544E6358516758525B4D4775655A856A5AAB7A62C09685
B8937DCB9A80CFAA93CEA98EC99C86BD8B6EA4775EB18164C18569C89679C9987CC68C75
C38C71C68D6CBF8D74B18470A5715D8D5D486D443B5238303D2F273326262A1E1F211E1F
211E1F201D1E35302B443632322A22DBDEDEE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFD1D0D46C5A4F60544D
61565061514B42383155464268584F675A5472655E6C605A6B615875685E81695A856256
8160507F6055966753A27C67926E6086655B8E62508A6048946651A9765EAE7D61B47B5E
AC7C639B6A52A1715E9C6855855F4E67433A5F453C3E2F27392E26302525281E1F201D1E
1F1D1E38302B302A2B4D54503A2B23E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFDEE8E9866E6A61524B
65554E61544E5F514B514B4663585172655E6C5C55716058755A537F6353785D4C6C5A50
5F48416A524960403972564C745A50644F4860423B6649406642386D433A7D58447C5743
79554275483C6F453A69463C6642394B3A313D2F27362828302525302525211E1F201D1E
38303538302B524742161616937F77E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE2EDEDC6C2C865524B
61524B65565061524B6A5E58604F4771625B66544B695A537061576C565070544B685249
5C4C455F514B52403F5346405940395941394B383143362F4A3730533B35563B354E3830
4F39304F3830563B354B352F49352F3C2F27372E263025252E2425211E1F211E1F2B2425
3F39364C3936221A12433A32E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFDFE7E88A6B63
64565065565064544D594D4674645D655B55675B545A4B436E5548644D436150485D4D46
4E4045574B44584241503B3649383E43352F43352F392E263D342E3F342E43352F3D2F27
3326263A2E2645342E3D2F27332626392E26352D2C302525211E1F2E2425342F2B3D3835
443632312820312018E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE1EBECB3A1A0
66514A69595364544D6456505A544E6D5C5666544B59484157453E533A31574942513F3E
503F3E45363149383E3B2F30362727392E30372E2E312626362D2C312626382E2E312626
352D2C38312C362D2C332626221E1F221E1F221E1F221E1F342B2C302A252F2426432E27
3A3830322219E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFD8E3E2
8276705B4C4565554E625750655953685D57645452553E3752433C42363045342E453831
473530342728332627392E30352C2D2E2425362D2E302526342B2C302526443632221E1F
342C2D3B332E372E2E221E1F211E1F261D1E302A2B2F2A2B302A2B4738334A41373F4947
281B14DBDEDEE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
D8E3E282736C5B524C5D4D45685E58675D576F605A574C4656463F48363C372E2D45342E
372E2E3E342D38312C342B2C3025263025262F24263025262F24263A322E342B2C554D50
3E41413E3238312626352C2D342F2B342F2B322A2B49413D453C38473833635149463422
8B654BE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFD6E0E0826F69645C55594B43695D5673655E6D5F59594A3D54443E3E3330362D2E
332626362D26372E2E312626302526342B2C2E2425342B2C2E24252F25264D4B49473D46
656265615F5D4F454947464447403C3C332D493E39473D3960544D604F46322820704C3B
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE4F0F0E1EBEA82695D6F645D5F534D6A625C76686171645D57443B51423C4E4742
44403D3C302C3A322C352C2D342B2C2E2425302526393137352C2D38312C342C2D57504A
5C4E4E4636364E3F36483A344435354C38314A3F395A483C625A4F5B5C516A4634E3E7E6
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFD7E1DF7D695C65534B6A5A547C70697A716B73665F51413B4F3D3C
594139594F494B433D362D2D3025263F383D3C353B433F3B4139414D48453B3338504E4C
594F4D5F514A4A44414B433D4D47424D4C485146415F5B514238277E5940C8C4CCE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFD7E2E1716F5D5F5650695A537E6B64807B7B786D665E5854
5955555849475C56545E5B5A484B4B4540414F4954534A4C5E5C5C544D4C63534D544F4F
735F5767524D675245635650665A516B6358705849493E358B644AE3E7E6E3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE0EAEBB1ADB57268656C605A6C65667F8084867C77
857A73837C766964656568677A73787A6C64685D5B5C51575E4E486D5D5C6B5D57655650
755C50755D53745D547562576E594D86766C855F44553A28E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3F1F0E3F0F0E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFD7E2E361575E59584A6C6E76969190
8A8C8984837D87807A8B83808C7E77877B77746D68786F69676363625D556B645F746D68
6F655D80665A7C5B52887767785B485E37278B7777E3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3E6E6E3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE2EDEDC6C9D4676476
8E8183ADAAB6948B898F827489807C8F838098837E97837C8E7F7897837B85776D897366
927C6E716B5B605644503C35B7AAB2E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE2EDEED2D4E6E0E2E3B5B1C47675877673836D675E6D62596D61586C605862574D
5A4733675C4AE3E7E6E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEFE3EFEF
E3EFEFE3EFEFE3EFEFE3EFEF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?oooeWSknl4i>[Q1=c;]@?SdK`4hm;31>?Hb@CSd/<;hmW:1>?H
b@CSdL44i=2i1=c9/@CM_jL4eK>M0mFaVQ3=[9D4cJZC0lfUR`C6YHX4aZF;1<JURPC4XXTChno_1>?X
ib?SknlEoooo000DooooFN?_k`CTj^44g<^e0n?A_0CSd/<4hmS91>?B``_SfLX4hmS91>?A`@CTd;T4
g<Va1=foY`CE/id3eK6J4<f/U@C=ZY<3cJF;1<JURPC6YH/4aZF:1<BRRA?Sknl4hnSW8n?_kaGoool0
01CooomIhno_1>CZh@CLbkD3hm6l1>?B``CSf<T4hm;32n?IbPCSf<T4hm711>C@^@CLbK44gKnW1=Fc
W@?E/IX@cJbE1<fZT`?=YH/4aZF:1<JUR`C6YHX4a::94n?_k`CSj>LShno_5Oooo`005?ooo`CSknl8
ho3`1>?_k`OSl?0Shno_2>?`l1OSknl4h^cT1=_:]0?SdKX4hm;41>?Hb@CSd/<4hmW:1>?Hb0?UfLP4
i]W81>KA_`CVckH4glN^1=nnY@CG/Y/3e[2H1<j/UPS=[9D8cJZC0lfUSPC6YHT4aZF;1<JWSPC4WXD?
hno_1>?^kPCSinHShno_5Oooo`005?ooo`CSknl8ho3`1>?_k`OSl?0Shno_2>?`l1OSknl4h^cT1=_:
]0?SdKX4hm;41>?Hb@CSd/<4hmW:1>?Hb0?UfLP4i]W81>KA_`CVckH4glN^1=nnY@CG/Y/3e[2H1<j/
UPS=[9D8cJZC0lfUSPC6YHT4aZF;1<JWSPC4WXD?hno_1>?^kPCSinHShno_5Oooo`005?ooo`CSknl8
ho3`1>?_k`OSl?0Shno_2>?`l1OSknl4h^cT1=_:]0?SdKX4hm;41>?Hb@CSd/<4hmW:1>?Hb0?UfLP4
i]W81>KA_`CVckH4glN^1=nnY@CG/Y/3e[2H1<j/UPS=[9D8cJZC0lfUSPC6YHT4aZF;1<JWSPC4WXD?
hno_1>?^kPCSinHShno_5Oooo`005?ooo`CSknl8ho3`1>?_k`OSl?0Shno_2>?`l1OSknl4h^cT1=_:
]0?SdKX4hm;41>?Hb@CSd/<4hmW:1>?Hb0?UfLP4i]W81>KA_`CVckH4glN^1=nnY@CG/Y/3e[2H1<j/
UPS=[9D8cJZC0lfUSPC6YHT4aZF;1<JWSPC4WXD?hno_1>?^kPCSinHShno_5Oooo`005?ooo`CSknl4
hnk^1>?Xj0CSl?04hnk^0n?WiPCSknl@ho3`3n?_k`CSk^h4hnOV5n?_k`CUjn84i=:l0n?A``CSd[`4
hmW:1>?A``CSfLX4iMS60nG@^@CPbK04g/F^1=joYPCF^Z<4cK>L1<f/U`?=ZiD4aZF>2<n[T`C?ZY<4
cjF;0ljUS`S6YHh4`9ek1<2l/Q?Sknl8ho3`7n?_kaGoool001Coool4hno_1>?^kPCSj>P4ho3`1>?^
kP?SinH4hno_4>?`l0oSknl4hnk^1>?WiQOSknl4iN_R1>CB_0?SdL<4hm:l1>?IbPCSdL<4hmW:1>GH
aP?Ud;T4h<V`1=k5[PCN_jH4e[ZS1<fcW0C=[9L3cJ^E1<JUSPS?Zi<4cjZC1<nUR`?>YHl8aZF>1<2M
N`C0_;8Chno_2>?`l1oSknlEoooo000Doooo1>?_k`CSk^h4hnSX1>?`l0CSk^h3hnOV1>?_ka3Sl?0?
hno_1>?^kPCSinHGhno_1>G[hPCTd[`3hm731>?B_0CSfLX4hm731>?IbPCUf<H3iM2i1>39/0CNaJh4
g[nV1=JjX`C=/i`4cJbG0lf[U@C6YHh8cj^C1<nZT`C?YH/3cZF?2<JUSPC0WG/4`;bb4n?_k`SSl?0O
hno_5Oooo`005?ooo`CSknl4hnk^1>?Xj0CSl?04hnk^0n?WiPCSknl@ho3`3n?_k`CSk^h4hnOV5n?_
k`CUjn84i=:l0n?A``CSd[`4hmW:1>?A``CSfLX4iMS60nG@^@CPbK04g/F^1=joYPCF^Z<4cK>L1<f/
U`?=ZiD4aZF>2<n[T`C?ZY<4cjF;0ljUS`S6YHh4`9ek1<2l/Q?Sknl8ho3`7n?_kaGoool001Coool<
hno_1>?Xi`_Sknl4hnk^1>?WiPCSk^h4hnOV;^?_k`CRj^44fl^e0n?A^`CSdL<4hm;31>?Hb@CSdL84
h]720mO9/`C0`K44dKRU1=>/V`C;[9D8bk:M0lf]U`C=Zi<@aZF>0lJVR`C6Y8h4aZF>1<BRRAOSknl4
hnk^1>?WiQoSknlEoooo000Doooo3>?_k`CSj>L;hno_1>?^kPCSinH4hnk^1>?WiRkSknl4h^[Q1=_;
]@?SdK/4hm731>?B``CSf<T4hm721>;A`P?GbK<4`<6a1=6hY@CC[9/4bjbE2<^bW@?=[IL4cJ^C4<JU
SP?6YX/4aZB>1<JUSPC4XXTGhno_1>?^kPCSinHOhno_5Oooo`005?ooo`cSknl4hnSW2n?_k`CSk^h4
hnOV1>?^kPCSinH^hno_1>;Zh@CKbkD3hm6k1>?A``CSd/<4hmS91>?A`PCRdL83elVc1<31/@CA^:D4
djbK1<^/U@S;/Yd3cJfG1<f[Ta36YHh3aZJ;1<JTSPC6YHh4a::95n?_k`CSk^h4hnOV7n?_kaGoool0
01Coool<hno_1>?Xi`_Sknl4hnk^1>?WiPCSk^h4hnOV;^?_k`CRj^44fl^e0n?A^`CSdL<4hm;31>?H
b@CSdL84h]720mO9/`C0`K44dKRU1=>/V`C;[9D8bk:M0lf]U`C=Zi<@aZF>0lJVR`C6Y8h4aZF>1<BR
RAOSknl4hnk^1>?WiQoSknlEoooo000Doooo2>?_k`CSk^h4hnOVBN?_k`CSk>@4hlZe0n?A`PcSdL<4
hm721>?A^`?Sd<84h]311=c8/PCT^K04dk>M1=>/V0CDZi`3djbM1<^KS@C5Xhh4aJRC1<JTS@C6YHh3
aZF?1<fZT`C6Yi84`j28?^?_kaGoool001Coool8hno_1>?^kPCSinI9hno_1>?/i0CSb[D3hm723>?A
``CSdL84hm6k0n?@`PCRd<44g<Rb1>Bi/0CC/id4djbH1=B[W0?C[9d4bi^=1<FSSPC5Z9<4aZB=1<JU
SP?6YHl4cJZC1<JWTPC3X8Pnhno_5Oooo`005?ooo`SSknl4hnk^1>?WiTWSknl4hncT1>?:]@?SdL8<
hm731>?A`PCSdK/3hm321>;@`@CLb;84i;V`1=>cW@CC[9P4e:^L0m>/W@C;Vhd4aJ>>1<FXT`C6Y8d4
aZF>0lJUS`C=ZY<4aZNB1<>PR3kSknlEoooo000Doooo2>?_k`CSk^h4hnOVBN?_k`CSk>@4hlZe0n?A
`PcSdL<4hm721>?A^`?Sd<84h]311=c8/PCT^K04dk>M1=>/V0CDZi`3djbM1<^KS@C5Xhh4aJRC1<JT
S@C6YHh3aZF?1<fZT`C6Yi84`j28?^?_kaGoool001CooomIhno_1>?/i@CSdKX3hm6k1>?A^Q3SdL<7
hmW:1>;@`@CJb;84fkVZ1=bjYPCK^J@3eJfM1=bfXPC=WY04cIn?1<fcY@C6Y8d3cjF>1<jUSPC3YY84
bJfD6n?_k`SSl?0Khno_5Oooo`005?oooeWSknl4hncU1>?A^P?SdK/4hm6j4>?A``OSfLX4h]311=[8
/PCK^JX4g;ZV1=^iY0?E[Id4g;JR1<fNT0C=Whl4cK>U1<JTS@??YHh4cZF>1<>VTPC9[I@Khno_2>?`
l1_SknlEoooo000DooooFN?_k`CSk>D4hm6j0n?A^`CSdKX@hm731n?IbPCRd<44f/Rb1=^iZPCL^ZH4
fkVT0mF]W@CL]Z84cIj@1<fOS`C=/jD4aZB=0lnUSPC>YHh4`jJB1<V]U1_Sknl8ho3`6n?_kaGoool0
01CooomEhno_1>KVgPCVl^/4hm6k0n?A^PCSdL84hm6l2>?A``CSfLX3hm321>?A``CSf<T4hm721>;@
^0CJ`J/4fkZZ0m^jY0CD/I`4e:bJ1<fZT`C>YY04c[2M1lJUSPC5YHd4g<k66n?_k`CSk^h4hnOV1n?_
k`CSl?04ho7`1>?`l0SSknlEoooo000DooooEN?_k`CVi]h4i_;[1>?A^`?SdKX4hm721>?A_0SSdL<4
hmW:0n?@`PCSdL<4hmS91>?A`PCRd;P4f/6[1=^jZP?K^Z@4e;6L1=B/VPC=ZY<4cZJ@1<j`W@O6YHh4
aJF=1=c>aQ_Sknl4hnk^1>?WiPOSknl4ho3`1>?al0CSl?08hno_5Oooo`005?oooeGSknl4i^KN1>Kb
j`CSdK/3hm6j1>?A`PCSdK`8hm731>?IbP?Sd<84hm731>?Hb@CSdL84h]2h1=[1Z`CK^ZX3fkZT1=Ba
W0CD[9X4cJZC1<jVT0C>/9d7aZF>1<FUS@CLc/HKhno_1>?^kPCSinH7hno_1>?`l0CSlO04ho3`2>?_
kaGoool001CooomEhno_1>KVgPCVl^/4hm6k0n?A^PCSdL84hm6l2>?A``CSfLX3hm321>?A``CSf<T4
hm721>;@^0CJ`J/4fkZZ0m^jY0CD/I`4e:bJ1<fZT`C>YY04c[2M1lJUSPC5YHd4g<k66n?_k`CSk^h4
hnOV1n?_k`CSl?04ho7`1>?`l0SSknlEoooo000DooooDN?_k`C7]jL4k_?Z1<VdZ0CSdK`3hm721>?A
^PCSdK/4hm;31>?Hb@CSd/83hmW;2>?Hb@CSdL84hm711>G7/@CU`ZX3g;VU1=fiX0CFZYP4eZbE1<fT
SPC6YHh3ajNB1<fUT0C2WhL4fmkN:^?_k`CSk^h4hnKV1>?WiPSSknlEoooo000DooooDN?_k`C7]jL4
k_?Z1<VdZ0CSdK`3hm721>?A^PCSdK/4hm;31>?Hb@CSd/83hmW;2>?Hb@CSdL84hm711>G7/@CU`ZX3
g;VU1=fiX0CFZYP4eZbE1<fTSPC6YHh3ajNB1<fUT0C2WhL4fmkN:^?_k`CSk^h4hnKV1>?WiPSSknlE
oooo000DooooDN?_k`C7]jL4k_?Z1<VdZ0CSdK`3hm721>?A^PCSdK/4hm;31>?Hb@CSd/83hmW;2>?H
b@CSdL84hm711>G7/@CU`ZX3g;VU1=fiX0CFZYP4eZbE1<fTSPC6YHh3ajNB1<fUT0C2WhL4fmkN:^?_
k`CSk^h4hnKV1>?WiPSSknlEoooo000DooooDN?_k`C7]jL4k_?Z1<VdZ0CSdK`3hm721>?A^PCSdK/4
hm;31>?Hb@CSd/83hmW;2>?Hb@CSdL84hm711>G7/@CU`ZX3g;VU1=fiX0CFZYP4eZbE1<fTSPC6YHh3
ajNB1<fUT0C2WhL4fmkN:^?_k`CSk^h4hnKV1>?WiPSSknlEoooo000Doooo2>?_k`SSl?0mhno_1>G/
kPBDHeL4PHEk1=_:/`CSdK`3hm721>?A``CSdL84hm;31>?IbPCSd<43hm6k1>?Hb0CScl44iM2l1>K>
]0CVckL4g;ZZ0mfjY@CN/Il4eK6E1<fVT0C>ZY04cZF?0lNVS`C?/9P4c:ZB@^?_kaGoool001Coool8
hno_2>?`l3gSknl4iNc^19ASE`B1QG/4flZc1>?A_0?SdL84hm731>?A`PCSd/<4hmW:1>?@`@?SdK/4
hmS81>??`@CUd;`4i/jd1>K?]`CL^ZX3gKZU1=jaW`CE/ID4cJJ@1<jZT0C>YHl3ajJ?1<n`V0C<ZY92
hno_5Oooo`005?ooo`SSknl8ho3`?N?_k`CUk>h4U6=G1865N`CKb[<4hm6l0n?A`PCSdL<4hm721>?B
``CSfLX4hm310n?A^`CSf<P4hlo11>G@_0CVc[@4i/ng1=bjZP?M^ZD4g[6O1=FaU@C=YY04cZZ@1<jU
S`?7YXl4ck2H1<bZTT;SknlEoooo000Doooo2>?_k`SSl?0mhno_1>G/kPBDHeL4PHEk1=_:/`CSdK`3
hm721>?A``CSdL84hm;31>?IbPCSd<43hm6k1>?Hb0CScl44iM2l1>K>]0CVckL4g;ZZ0mfjY@CN/Il4
eK6E1<fVT0C>ZY04cZF?0lNVS`C?/9P4c:ZB@^?_kaGoool001Coool8hno_1>?^kPCSj>P4ho3`=N?_
k`CRk^d4X7aT1<72aP@k?4D4hm731>?B_0?Sf<T4hm;31>?Hb@CSdL<4hm;31>?IbP?Sf<T4iM701>K=
^0CU^Zl4gKVR1=JdW@CN^Z<3gKZQ1=FgX0C>ZY<4eZ^C1<fZT`C5YHT3aZF>1<JVT0C5ZiP4i?;c?^?_
kaGoool001Coool8hno_1>?^kPCSj>P4ho3`=N?_k`CRk^d4X7aT1<72aP@k?4D4hm731>?B_0?Sf<T4
hm;31>?Hb@CSdL<4hm;31>?IbP?Sf<T4iM701>K=^0CU^Zl4gKVR1=JdW@CN^Z<3gKZQ1=FgX0C>ZY<4
eZ^C1<fZT`C5YHT3aZF>1<JVT0C5ZiP4i?;c?^?_kaGoool001Coool8hno_1>?^kPCSj>P4ho3`=N?_
k`CRk^d4X7aT1<72aP@k?4D4hm731>?B_0?Sf<T4hm;31>?Hb@CSdL<4hm;31>?IbP?Sf<T4iM701>K=
^0CU^Zl4gKVR1=JdW@CN^Z<3gKZQ1=FgX0C>ZY<4eZ^C1<fZT`C5YHT3aZF>1<JVT0C5ZiP4i?;c?^?_
kaGoool001Coool8hno_1>?^kPCSj>P4ho3`=N?_k`CRk^d4X7aT1<72aP@k?4D4hm731>?B_0?Sf<T4
hm;31>?Hb@CSdL<4hm;31>?IbP?Sf<T4iM701>K=^0CU^Zl4gKVR1=JdW@CN^Z<3gKZQ1=FgX0C>ZY<4
eZ^C1<fZT`C5YHT3aZF>1<JVT0C5ZiP4i?;c?^?_kaGoool001Coool8hno_1>?`l0CSknl4hnOV=N?_
k`BROFD4k?Sd149:A0CKb[<4hm6l1n?A``CSdL8@hm730n?Hb@CT_[04g;bX1=fYVPCMZIH4eJFB1=Fe
W0?F/9P4e[2C1<fXT0C>YH`4cZF?1<fUSP?=YH/4aj><1=2^U`COeLhZhno_2>?`l0cSknlEoooo000D
oooo2>?_k`CSl?04hno_1>?WiSGSknl4XWeU1>chm0A2BT@4flZc1>?A_0OSdL<4hm724>?A``?Sf<T4
i;j`1=blZ0CMZIX4gJVF1=FUTPCE]I`3e[2H1=J`T`C=Z904cZF<1<jUS`C=YHh3cJF;1<NSS0C@[YL4
gmG>:^?_k`SSl?0<hno_5Oooo`005?ooo`SSknl4ho3`1>?_k`CSinHehno_1:9mI@C/n?@4@TY41=_:
/`CSdK`7hm731>?A`Q3SdL<3hmS91>Bn/0CL_:P4gJVJ1=fYUPCEYI84eKFL0mJ`V0CF/9<4cJR@1<jU
S0C>YHl4cJF>0lfUR`C7Xh`4d:jG1=oEcR[Sknl8ho3`3>?_kaGoool001Coool8hno_1>?`l0CSknl4
hnOV=N?_k`BROFD4k?Sd149:A0CKb[<4hm6l1n?A``CSdL8@hm730n?Hb@CT_[04g;bX1=fYVPCMZIH4
eJFB1=FeW0?F/9P4e[2C1<fXT0C>YH`4cZF?1<fUSP?=YH/4aj><1=2^U`COeLhZhno_2>?`l0cSknlE
oooo000Doooo2>?_k`CSk^h4hnOV=^?_k`?Uk>`4f>CR14A<APCSf<T4hm711>?A_0CSdL<3hm701>?B
`@CSd[/4hm;41>?B``CSeLH3hm311>Bl[PCMT8@4gX9d1=J8P0CFPgP4eXV10mFSS@C?Y8`4cjF;1<jL
Q`C7YHX7cJF>1<JRQ`C=X8`4b:^F1>Kgn2KSknl4hnk^1>?WiPcSknlEoooo000Doooo2>?_k`CSk^h4
hnOV=^?_k`?Uk>`4f>CR14A<APCSf<T4hm711>?A_0CSdL<3hm701>?B`@CSd[/4hm;41>?B``CSeLH3
hm311>Bl[PCMT8@4gX9d1=J8P0CFPgP4eXV10mFSS@C?Y8`4cjF;1<jLQ`C7YHX7cJF>1<JRQ`C=X8`4
b:^F1>Kgn2KSknl4hnk^1>?WiPcSknlEoooo000Doooo2>?_k`CSk^h4hnOV=^?_k`?Uk>`4f>CR14A<
APCSf<T4hm711>?A_0CSdL<3hm701>?B`@CSd[/4hm;41>?B``CSeLH3hm311>Bl[PCMT8@4gX9d1=J8
P0CFPgP4eXV10mFSS@C?Y8`4cjF;1<jLQ`C7YHX7cJF>1<JRQ`C=X8`4b:^F1>Kgn2KSknl4hnk^1>?W
iPcSknlEoooo000DooooA^?_k`>FO704dlo;1=cBb@SSdL84hm6l1>?A`P?Uckh4i/V`1>C;]@CSb[D4
hm2n1>Fn/@?VZIX4ik>X1=f1K@CISX84cGQ_1=EdIPC@M6@3eXEi1<J@P0C6X8X4aZ:01<NOR0C>YHl3
cJF>1<fTSPC=WhX4cJbF1<^_V`CSlO4fhno_5Oooo`005?ooodKSknl3UWa`1=??b`CLd/T8hm721>?A
_0CSdL83iLnn1>K9/0CTbkD4hlZe1>?@_PCU_[43iZVJ1>NcZ0CMPFd4fHj21<ehK`CEM6H4d7AT0mJ5
N@C6T804aZ2:1<JRP0C7WhP4cZF?0lfUSPC=Y8h4cIn:1<f/UPC;[i/4ho7a=^?_kaGoool001Cooom6
hno_0iIlL0CCcl/4g=;92>?A`PCSdK`4hm720nG?_PCVbK04i<^e1>?:]@CSd;h4iKja0nJYVPCW/jP4
gH5]1=V>PPC=N6l4eGAV1=1dI0?FQGT4aY201<JPRPC6XX04ain81<jUS`?=YHh4cJB>1<fORPC=[9H4
bjnK1>?alCKSknlEoooo000DooooA^?_k`>FO704dlo;1=cBb@SSdL84hm6l1>?A`P?Uckh4i/V`1>C;
]@CSb[D4hm2n1>Fn/@?VZIX4ik>X1=f1K@CISX84cGQ_1=EdIPC@M6@3eXEi1<J@P0C6X8X4aZ:01<NO
R0C>YHl3cJF>1<fTSPC=WhX4cJbF1<^_V`CSlO4fhno_5Oooo`005?oooa3Sknl7ho3`:n?_k`CNfMT3
f]?213i?E@CKb[@4iM2g1>CB_0CSdKX4hm2n0nG=[`CO^Il4g[n[1>JfXPC2DcP4lLJ_0mfCR@CCSX84
a9241;5dHPC>ZHh4e9^01<UeJP?1J5@4dgAT1<NDPPC7Xh<4aYen1<JWS0?<YY04cJB>1<fVT0C=YHh4
d;2J1>KXh@CSlO4bhno_5Oooo`005?oooa3Sknl7ho3`:n?_k`CNfMT3f]?213i?E@CKb[@4iM2g1>CB
_0CSdKX4hm2n0nG=[`CO^Il4g[n[1>JfXPC2DcP4lLJ_0mfCR@CCSX84a9241;5dHPC>ZHh4e9^01<Ue
JP?1J5@4dgAT1<NDPPC7Xh<4aYen1<JWS0?<YY04cJB>1<fVT0C=YHh4d;2J1>KXh@CSlO4bhno_5Ooo
o`005?oooa3Sknl7ho3`:n?_k`CNfMT3f]?213i?E@CKb[@4iM2g1>CB_0CSdKX4hm2n0nG=[`CO^Il4
g[n[1>JfXPC2DcP4lLJ_0mfCR@CCSX84a9241;5dHPC>ZHh4e9^01<UeJP?1J5@4dgAT1<NDPPC7Xh<4
aYen1<JWS0?<YY04cJB>1<fVT0C=YHh4d;2J1>KXh@CSlO4bhno_5Oooo`005?oooa3Sknl7ho3`:n?_
k`CNfMT3f]?213i?E@CKb[@4iM2g1>CB_0CSdKX4hm2n0nG=[`CO^Il4g[n[1>JfXPC2DcP4lLJ_0mfC
R@CCSX84a9241;5dHPC>ZHh4e9^01<UeJP?1J5@4dgAT1<NDPPC7Xh<4aYen1<JWS0?<YY04cJB>1<fV
T0C=YHh4d;2J1>KXh@CSlO4bhno_5Oooo`005?ooo`SSknl8ho3`1>?^kP?SinH[hno_19j5O0>[YJD4
[if<1>?A^PCTcK/4g<Ja1>?Hb@CSckd3i;BC1=JWR0BjBC`4k/:k1<UaK@AU8AT3d9f;1=6:N@CK/:84
hmO;1<iaI`BcQW44[HUb0j]dHPB<E3/4cg1L1<6LQ0C7W7h4c:6>0lb]U`CD/YD4cJB>1<fZT`C=Yi44
d;6F1>STf@?TlO0_hno_5Oooo`005?ooo`SSknl8ho3`1>?^kP?SinH[hno_19j5O0>[YJD4[if<1>?A
^PCTcK/4g<Ja1>?Hb@CSckd3i;BC1=JWR0BjBC`4k/:k1<UaK@AU8AT3d9f;1=6:N@CK/:84hmO;1<ia
I`BcQW44[HUb0j]dHPB<E3/4cg1L1<6LQ0C7W7h4c:6>0lb]U`CD/YD4cJB>1<fZT`C=Yi44d;6F1>ST
f@?TlO0_hno_5Oooo`005?ooo`SSknl8ho3`1>?^kP?SinH[hno_19j5O0>[YJD4[if<1>?A^PCTcK/4
g<Ja1>?Hb@CSckd3i;BC1=JWR0BjBC`4k/:k1<UaK@AU8AT3d9f;1=6:N@CK/:84hmO;1<iaI`BcQW44
[HUb0j]dHPB<E3/4cg1L1<6LQ0C7W7h4c:6>0lb]U`CD/YD4cJB>1<fZT`C=Yi44d;6F1>STf@?TlO0_
hno_5Oooo`005?ooo`SSknl8ho3`1>?^kP?SinH[hno_19j5O0>[YJD4[if<1>?A^PCTcK/4g<Ja1>?H
b@CSckd3i;BC1=JWR0BjBC`4k/:k1<UaK@AU8AT3d9f;1=6:N@CK/:84hmO;1<iaI`BcQW44[HUb0j]d
HPB<E3/4cg1L1<6LQ0C7W7h4c:6>0lb]U`CD/YD4cJB>1<fZT`C=Yi44d;6F1>STf@?TlO0_hno_5Ooo
o`005?ooo`SSknl4hnk^1>?WiRkSknl4i^o`18UQEP=LI6D4g<^e1>?A`PCRckT4fk^X1>?A``CVaZl3
hZn71<egF@B[A2h4PU]H1<C8^`CVgM03i>KO1>?Xh`CSh]h4iMK81=k?^@CVe/@4em7;0jjRUPB6Jf84
L4Ti1<9dG@C9YHX4cZ:=0mBdX0CD/Y/4eK6E1<fRR`C=YXl4c[:P1=3Ag@?Ri^H4i_;`:n?_kaGoool0
01Coool8hno_1>?^kPCSinH^hno_1>K_l0B9HEH3G6AU1=c;]@CSdL84h/ni1=^kZ0CSdL<4i/J_0n:_
Q`C=MeT4Zd@^189KF0C4b;/4i]g@0nCVg`CSj><4hn;N1>GFb0CNckT4i]K41=OAb`>^XYH4QV]R1719
>@C2M5d4bJF:1<jRS@?D]:04e;:K1=FaU@C=XX/4cJJ?1<jbX0C@dMd3h^KV1>Kbl2_SknlEoooo000D
oooo2>?_k`CSk^h4hnOV;^?_k`CVko04RF5F0eaTI@CLbkD4hm721>;?^@CK^jP4hm731>K6[`?R[hL4
cGMI1:]4;PB2FeP4a<Rk1>KMd0?Ti]l4hnSS1>?RgPCUe/P4g/ni1>KFa0CGdL/3[Z:F18I[HPA`BCT4
`WAM1<VURPC>XXd3e;BP1=BbV`CE/ID4cJ:;1<fVS`C>/Z04d=7M0n;ViPCVl_0[hno_5Oooo`005?oo
o`SSknl4hnk^1>?WiRkSknl4i^o`18UQEP=LI6D4g<^e1>?A`PCRckT4fk^X1>?A``CVaZl3hZn71<eg
F@B[A2h4PU]H1<C8^`CVgM03i>KO1>?Xh`CSh]h4iMK81=k?^@CVe/@4em7;0jjRUPB6Jf84L4Ti1<9d
G@C9YHX4cZ:=0mBdX0CD/Y/4eK6E1<fRR`C=YXl4c[:P1=3Ag@?Ri^H4i_;`:n?_kaGoool001Cooolj
hno_1<NgY`BAIU/4cKnn0cI1B0CKb[@4hm2h1>?A^@CSdk`4hm721>C4[P?BYI04[HU^19QCC@AU?cL4
diZ=1=fhX`?O]ZL4ilc11>O7[PCW[iH4f99n1=nZV0CJ]9d3iKVO1<BNS@BWS7`4LC4P1<61K`C6Xhd3
eKJK1=foY0CE[iP4cZZC1<jOR`C=ZI@4_[n_0kbi/`C<d^4[hno_5Oooo`005?oooc[Sknl4akNW195V
F`C=_kh3=T581=_:]0CSd;P4hm6i1>?C_0CSdL84i<B^0m:UT0B]RFh4V5==16Do=`CCVXd4gKRS0mnf
Y`CWc<44ilN^1>N_UPCHTWh4gjZH1=ZdW@?U^Il4a9j=1:N<O0Aa<B04`H5_1<JSS@?E]Y/4gKnT1=F_
V0C>ZY<4cYn;1<fYU0Bn_jl3_;Vc1<cBhB_SknlEoooo000Doooo>^?_k`C7]jL4TFIK1<fo_P<f@DP4
flZd1>?@^0CSdKT4hm>l1>?A`PCTa:h3dZF@1:f9KPBHDdd4IClg1=>JS@CM^:<3gkJW1>O<`@CWajh4
ijnF1=RBOPCOZYP4f[BM0nFiW`C4WXd4Yhal174a80C1PFl4aZ>=0mFfV`CM_j@4eJnH1<jZT`C>Wh/4
cJVD1;jo[`>l^K<4c=;Q:n?_kaGoool001CooolDhno_1n?`l1_Sknl4i^k_15i9>`AK@CL4@4E70jjE
S0CSdKT4hlji1>G4[@CT`jh4hlni1>C8[@?FWH04e[VU1=_9/`CSc[T4h[Rb1=V^X`?@Z9`4dJJL1=ZE
T0C9Vi04bX5g1<YgKPC5PWD3bj6?1<B4L0BkM5h4VU4o17a4=`C=VhX3e[NK1=g0Y0CE[i<4cJ:;1<NV
S`C=[IH4YgEM0nodmPC2`M44i?7`9n?_kaGoool001CooolDhno_1n?`l1_Sknl4i^k_15i9>`AK@CL4
@4E70jjES0CSdKT4hlji1>G4[@CT`jh4hlni1>C8[@?FWH04e[VU1=_9/`CSc[T4h[Rb1=V^X`?@Z9`4
dJJL1=ZET0C9Vi04bX5g1<YgKPC5PWD3bj6?1<B4L0BkM5h4VU4o17a4=`C=VhX3e[NK1=g0Y0CE[i<4
cJ:;1<NVS`C=[IH4YgEM0nodmPC2`M44i?7`9n?_kaGoool001CooolDhno_1n?`l1_Sknl4i^k_15i9
>`AK@CL4@4E70jjES0CSdKT4hlji1>G4[@CT`jh4hlni1>C8[@?FWH04e[VU1=_9/`CSc[T4h[Rb1=V^
X`?@Z9`4dJJL1=ZET0C9Vi04bX5g1<YgKPC5PWD3bj6?1<B4L0BkM5h4VU4o17a4=`C=VhX3e[NK1=g0
Y0CE[i<4cJ:;1<NVS`C=[IH4YgEM0nodmPC2`M44i?7`9n?_kaGoool001CooolDhno_1n?`l1_Sknl4
i^k_15i9>`AK@CL4@4E70jjES0CSdKT4hlji1>G4[@CT`jh4hlni1>C8[@?FWH04e[VU1=_9/`CSc[T4
h[Rb1=V^X`?@Z9`4dJJL1=ZET0C9Vi04bX5g1<YgKPC5PWD3bj6?1<B4L0BkM5h4VU4o17a4=`C=VhX3
e[NK1=g0Y0CE[i<4cJ:;1<NVS`C=[IH4YgEM0nodmPC2`M44i?7`9n?_kaGoool001CooolDhno_0n?^
kPCSinHKhno_1>?/k@Bd^kl40C4h12PlA0?Td/84hm2i1>?9]0CR^[<4flbe1>??^PCT]Z/3e:F=1;fG
P0CTdlD4hmW:1>?A`PCSd/<3hmW:1>?>_`CTckD4g;ZU1=fiXPCE/ID4eJV?0m2JQ`CFRh04a7ea1:U[
G@B>F504VV=H0lnYU@CM^J04eJnC1<fTR`C7WXX4cJNA1:J4M0=fIU`4i^[[1=_NgROSknlEoooo000D
oooo5>?_k`?Sk^h4hnOV6n?_k`CSk>d4];^o104a>0@X?4@3i=;21>?@^@CSbK@4h[Zc1=_<]@CSckX4
i;J[0mBUS@BmUh04i=?51>?IbPCSdL84hm;30n?IbPCSc[l4i<ne1=bjY@CM^J84eK6E1=FYS`?@VXL4
eX^01<AmL@BYJed4SUQ@19YSF0??ZID4gKVP1=F_T`C=Y8/4aij:1<fWT@BVQ7@3MVIL1>KZj`CKg]hW
hno_5Oooo`005?oooaCSknl3hnk^1>?WiQ_Sknl4hnc]1;Bk_`@1<CP4:3a40nCB`PCSd;T4hlVd1>:j
/`CKc;D4hlnj1>BfZ`?DYHd4_IN01>CCa@CSfLX4hm721>?B``?SfLX4hljo1>C?]@CL^ZD4gKVR1=Fa
U@CEZHl3d9Z71=J;P0C4OG44ZF]M18iHD0BJHeP3cjVE1=fiX0CE[i<4cJB;1<NNRPC=Yi44YXAd0gIV
G0CVj^/4fmkN9n?_kaGoool001CooolDhno_0n?^kPCSinHKhno_1>?/k@Bd^kl40C4h12PlA0?Td/84
hm2i1>?9]0CR^[<4flbe1>??^PCT]Z/3e:F=1;fGP0CTdlD4hmW:1>?A`PCSd/<3hmW:1>?>_`CTckD4
g;ZU1=fiXPCE/ID4eJV?0m2JQ`CFRh04a7ea1:U[G@B>F504VV=H0lnYU@CM^J04eJnC1<fTR`C7WXX4
cJNA1:J4M0=fIU`4i^[[1=_NgROSknlEoooo000Doooo=^?_k`CQk>P4b=7N1>;?^0CK^ZD3gL^d1>CA
^PCSb[@4hlnj1>>i/`CSdKX4hlfe0mB_V0C>WXP4glRb1>CBa@CSf<T4hm720n?B``CSe/H4i;V^1=fe
W@CM^Z44eZnD1=FXT0?8X804aiR11<NQP@C7V844aiZ11;nDR`?5XH84eK:J1=F/T0C>Xh/4ajF71<nU
S`B1GE03MW5N1<:n/b_SknlEoooo000Doooo=^?_k`CQk>P4b=7N1>;?^0CK^ZD3gL^d1>CA^PCSb[@4
hlnj1>>i/`CSdKX4hlfe0mB_V0C>WXP4glRb1>CBa@CSf<T4hm720n?B``CSe/H4i;V^1=feW@CM^Z44
eZnD1=FXT0?8X804aiR11<NQP@C7V844aiZ11;nDR`?5XH84eK:J1=F/T0C>Xh/4ajF71<nUS`B1GE03
MW5N1<:n/b_SknlEoooo000Doooo=^?_k`CQk>P4b=7N1>;?^0CK^ZD3gL^d1>CA^PCSb[@4hlnj1>>i
/`CSdKX4hlfe0mB_V0C>WXP4glRb1>CBa@CSf<T4hm720n?B``CSe/H4i;V^1=feW@CM^Z44eZnD1=FX
T0?8X804aiR11<NQP@C7V844aiZ11;nDR`?5XH84eK:J1=F/T0C>Xh/4ajF71<nUS`B1GE03MW5N1<:n
/b_SknlEoooo000Doooo=^?_k`CQk>P4b=7N1>;?^0CK^ZD3gL^d1>CA^PCSb[@4hlnj1>>i/`CSdKX4
hlfe0mB_V0C>WXP4glRb1>CBa@CSf<T4hm720n?B``CSe/H4i;V^1=feW@CM^Z44eZnD1=FXT0?8X804
aiR11<NQP@C7V844aiZ11;nDR`?5XH84eK:J1=F/T0C>Xh/4ajF71<nUS`B1GE03MW5N1<:n/b_SknlE
oooo000Doooo<^?_k`CUl?04i>kV1>G@^0CVc[L4i]W<0mk;/PCKbkD4hm6k1>?@`PCSdL<4hmS91>;=
_P?K`:P4e:RA1<bST0CLcKP4hmW:1>?DaP?Ue<84i=W91>G;/@CM]il4eYf41=JaU0C5W803^9^01;nE
N`BoTWL4_iAh1;n>M0BnW8<3c:bF1=J`V0CFYi04aYb71<JOR@C6YX/4EShk0f5OG@CGfnd[hno_5Ooo
o`005?oooc;Sknl4iO3`1>C^iPCUd;P4i/jg1>KIc0?Nbk84fl^e1>?A^`CSd<84hm731>?Hb@CRcKh3
fl2X1=BXT@C<Xi04g<fh1>?IbPCSe<H3iMC21>CIb@CUbk44gKNO1=JMQ0CF/I@4aIb00kRKP0BoUG/4
_i9g1;nDN0BoSW@4_Yb30lb/UPCF/9P4eZN@1<JLQ`C6WhT4aZJ;15Hn>`=QGed4em_]:n?_kaGoool0
01Cooolbhno_1>G`l0CTk^H4iM2h1>K>]`CVfL`3g/^b1=_;]@CSdK/4hm321>?A``CSf<T4h/fn0m_0
Z0CDZ944c:>@1=c=^0CSfLX4hmC60nGD`PCTfLT4iL^a1=fgW`CFWH@4e[6D1<FLP0>hVh04_iEk1;nB
M`BoU7P4_hid1;jLP`?<[9H4e[2H1=JWT0C6W8L4aYn91<JVR`AF?S/3HEmM1=OKkB_SknlEoooo000D
oooo<^?_k`CUl?04i>kV1>G@^0CVc[L4i]W<0mk;/PCKbkD4hm6k1>?@`PCSdL<4hmS91>;=_P?K`:P4
e:RA1<bST0CLcKP4hmW:1>?DaP?Ue<84i=W91>G;/@CM]il4eYf41=JaU0C5W803^9^01;nEN`BoTWL4
_iAh1;n>M0BnW8<3c:bF1=J`V0CFYi04aYb71<JOR@C6YX/4EShk0f5OG@CGfnd[hno_5Oooo`005?oo
oc;Sknl4h^kX1=_QgPCUbk44g[jU1=>fWP?1`/04hlbf1>?B``cSfLX4hmK60n:i/0CL]ih4eZF?1=fo
Z`CSd/<4hmK70n:j/`CKb[@4hlbe1=BbV`CDZ944aI=o1<FKP`>oSWP4_iIk1<2HPPC5W7d4^YQo1;bD
O0OFZY<4cJB>1<JLQ`C6WhL4ajF?16a9?0=BBDH4b<Jn1>?`l2OSknlEoooo000Doooo<^?_k`CRk^P4
fn7N1>G;/@CN_ZD4dkJN0l72`0CSc;H4hm;33>?IbPCSe/H3h[V`1=bgWPCFYHl4gKn[1>?B``CSe/L3
h[Zc1=_:]0CSc;D4e;:K1=BXT@C5Tgl4aI^30kn>N0BoUW/4`9R21<FLO@BjV7l4_9Al1mJZT`C=Y8h4
aYb71<JOQ`C7YHl4K4Tl0e99APC8a[h4ho3`9n?_kaGoool001Cooolbhno_1>;^j0CKhMh4iL^a1=jn
Y@CC]Yh3`L;01>?<]PCSd/<<hmW:1>?FaP?R^K04g;NN1=JUS`CM_j/4hm;31>?Fa`?R^[<4flZd1>?<
]@CD/Y/4e:RA1<FCO`C5Vh<3_hih1;nFN`C0V884aIam1;ZHO`BlU7`7eZZC1<fTSPC6W8L4aYn71<NU
S`A/BC`3DTU61<S6_PCSl?0Whno_5Oooo`005?oooc;Sknl4h^kX1=_QgPCUbk44g[jU1=>fWP?1`/04
hlbf1>?B``cSfLX4hmK60n:i/0CL]ih4eZF?1=foZ`CSd/<4hmK70n:j/`CKb[@4hlbe1=BbV`CDZ944
aI=o1<FKP`>oSWP4_iIk1<2HPPC5W7d4^YQo1;bDO0OFZY<4cJB>1<JLQ`C6WhL4ajF?16a9?0=BBDH4
b<Jn1>?`l2OSknlEoooo000Doooo<^?_k`CSk>D4iM6j1>BhV@CF]j<4b:jJ0m_:]0CS^kD4hm;32>?H
b@CSfLX4hmS80n?@^@CT_ZD4eK:E1=JYU`CTdlD4hmS80n?Aa0CSdL84i<jm1=fdX@CF/9P4cZF>1<fQ
RP>nTGL4_heh1<2HP`C5Whd4bj2=1=B/U`?E/Y`4cJF@2<jTSPC6WXT4aZN=1;REMP=BASd4IeM@1?Gh
n2OSknlEoooo000Doooo<^?_k`CSk>D4iM6j1>BhV@CF]j<4b:jJ0m_:]0CS^kD4hm;32>?Hb@CSfLX4
hmS80n?@^@CT_ZD4eK:E1=JYU`CTdlD4hmS80n?Aa0CSdL84i<jm1=fdX@CF/9P4cZF>1<fQRP>nTGL4
_heh1<2HP`C5Whd4bj2=1=B/U`?E/Y`4cJF@2<jTSPC6WXT4aZN=1;REMP=BASd4IeM@1?Ghn2OSknlE
oooo000Doooo<^?_k`CSk>D4iM6j1>BhV@CF]j<4b:jJ0m_:]0CS^kD4hm;32>?Hb@CSfLX4hmS80n?@
^@CT_ZD4eK:E1=JYU`CTdlD4hmS80n?Aa0CSdL84i<jm1=fdX@CF/9P4cZF>1<fQRP>nTGL4_heh1<2H
P`C5Whd4bj2=1=B/U`?E/Y`4cJF@2<jTSPC6WXT4aZN=1;REMP=BASd4IeM@1?Ghn2OSknlEoooo000D
oooo;^?_k`CSkn`4i]k=1>JYT0CM_j<4`IIn1=o9]0?S^k@4hm6l1>?B``CSfL/4hn7H1>?IbPCSf<T3
iM701>C>]PCC/ih4d[>J1=_:]@CUckh3i=Bm1>?Ea`CUcK@4gKNM1<jSS0C>X8P4aj>40lFDO0C8V7P4
_iF21<FPS@CE[Yl4gKVR0mFbVPC=/9P4cJZC1<JUR`C6XX`4aZVD1<bZT@>_SG44FS8R14<j<ROSknlE
oooo000Doooo;^?_k`CSkn`4i]k=1>JYT0CM_j<4`IIn1=o9]0?S^k@4hm6l1>?B``CSfL/4hn7H1>?I
bPCSf<T3iM701>C>]PCC/ih4d[>J1=_:]@CUckh3i=Bm1>?Ea`CUcK@4gKNM1<jSS0C>X8P4aj>40lFD
O0C8V7P4_iF21<FPS@CE[Yl4gKVR0mFbVPC=/9P4cJZC1<JUR`C6XX`4aZVD1<bZT@>_SG44FS8R14<j
<ROSknlEoooo000Doooo;^?_k`CSkn`4i]k=1>JYT0CM_j<4`IIn1=o9]0?S^k@4hm6l1>?B``CSfL/4
hn7H1>?IbPCSf<T3iM701>C>]PCC/ih4d[>J1=_:]@CUckh3i=Bm1>?Ea`CUcK@4gKNM1<jSS0C>X8P4
aj>40lFDO0C8V7P4_iF21<FPS@CE[Yl4gKVR0mFbVPC=/9P4cJZC1<JUR`C6XX`4aZVD1<bZT@>_SG44
FS8R14<j<ROSknlEoooo000Doooo;^?_k`CSkn`4i]k=1>JYT0CM_j<4`IIn1=o9]0?S^k@4hm6l1>?B
``CSfL/4hn7H1>?IbPCSf<T3iM701>C>]PCC/ih4d[>J1=_:]@CUckh3i=Bm1>?Ea`CUcK@4gKNM1<jS
S0C>X8P4aj>40lFDO0C8V7P4_iF21<FPS@CE[Yl4gKVR0mFbVPC=/9P4cJZC1<JUR`C6XX`4aZVD1<bZ
T@>_SG44FS8R14<j<ROSknlEoooo000Doooo;^?_k`CSi^84i;fZ1=FCOPC6Q7L4`Z6A1<73]@OSdKX4
hm;32>?IbPCSf<T4hmS80nC@`0CKbK44flB^1=c;]@CSdKX4h/ji0m^k[@CSc[L4i;R/1=F[S`C>VX@4
aYN01<6DO0?6VWX4[Hek1;bDPPC<[YT4eKBO1=fiXP?E/IX4cJZC1<fRSPC=Xhh4aZ:71<jRS`C=YHD3
aif81<6EO@CRk^hWhno_5Oooo`005?ooobkSknl4hnKR1>BmZPCETgh4aXAg1<:QT@C1`kD7hm6j1>?B
``SSfLX4hmS91>?Hb0?Td<04flVa1=_4[PCLbkD4hm6j1>;>^@?K^jd4hljg1>Bh[0CEZhl4cYZ41<JG
P0C1U7`3aYYj1:f=N`BlU884c:jI1=FdW`CM^J83eK6J1<fZT`C=XXh4cJ>>1<JRQ`C>XXl4cJF50lNM
R0C1UGd4h^k^9n?_kaGoool001Coool^hno_1>?VhPCT_JX4eI=n1<J4M`C2XI44`L>e1n?A^PCSd/<8
hmW:1>?Hb@CSf<P3i=301=_9/@CKa:h4g<^e1>?A^PCRc[T3fk^]1>?>]`CT^:`4eJ^?1<jJQ0C6Uh04
`IAl0lJJNPB]SG/4_9B21<b^V@CE]9l4gKVR0mFaVPC=ZY<4cJ:>1<fSSPC6XXL4cZ:?1<fUQ@?7WHP4
`IEm1>;^kROSknlEoooo000Doooo;^?_k`CSi^84i;fZ1=FCOPC6Q7L4`Z6A1<73]@OSdKX4hm;32>?I
bPCSf<T4hmS80nC@`0CKbK44flB^1=c;]@CSdKX4h/ji0m^k[@CSc[L4i;R/1=F[S`C>VX@4aYN01<6D
O0?6VWX4[Hek1;bDPPC<[YT4eKBO1=fiXP?E/IX4cJZC1<fRSPC=Xhh4aZ:71<jRS`C=YHD3aif81<6E
O@CRk^hWhno_5Oooo`005?ooob_Sknl3ho3^1>?[i0CT/Z@4e91j1<N9OPC2Z9H4flZe0n?B``CSf<T4
hm731>?IbPCUfLL4i=W91>??`0?TdKP4gLR`1>G4[@CLbkH4hm;21>?HbP?SdL<4hlfn1>BkX0CE[9@4
aYZ31;nEOPBhTGd3^9=m1;nJQ`C=[YP4e;FO1=FiX`CM^:03eK:J1<fWT0C=XX`4cYb<1<jNR`C7XI04
c:ZF0kjCN`C;Yi@4l?cl9n?_kaGoool001Coool[hno_0n?`kPCSjn@4i;:T1=B@NPC7RGh4`ZRF1=_:
]@?Sd/<4hmS91>?A``CSfLX4iMW71>CIb@CScl03i=6h1=g8/0CUa:d4g<^f1>?B`PCSf<X3hm731>?=
_PCT^j04eJbD1<JJP`BoUGh4^95m0kRCO@BoVXL4cJjH1=BeW`CE^J<4gKRP0mFbVPC=Yi04cJ:<1<jL
S0C>WX/4aj6@1<bZUP>nTg/4bjND1?3lo2OSknlEoooo000Doooo:n?_k`?Sl>h4hn_T1>BbY0CDT7X4
ahUn1<:XUPCKb[D3hm;31>?Hb@CSdL<4hmW:1>GIa`CTfLT4hlo00nCA^0CMb;04iLB]1=c;]PCSd/84
hmS:0n?A``CScKh4i;^P1=F/U0C6VX<4_iEn1;RAO@>hTgd4_iZ71<f^V0CD]Il4eKVS1=fhX0?E/YX4
cJN@1<fRS0C>W8`4cYj;1<NQT0C<ZYH3_Y=k1<^WU0C`o?`Whno_5Oooo`005?ooob_Sknl3ho3^1>?[
i0CT/Z@4e91j1<N9OPC2Z9H4flZe0n?B``CSf<T4hm731>?IbPCUfLL4i=W91>??`0?TdKP4gLR`1>G4
[@CLbkH4hm;21>?HbP?SdL<4hlfn1>BkX0CE[9@4aYZ31;nEOPBhTGd3^9=m1;nJQ`C=[YP4e;FO1=Fi
X`CM^:03eK:J1<fWT0C=XX`4cYb<1<jNR`C7XI04c:ZF0kjCN`C;Yi@4l?cl9n?_kaGoool001Coool[
hno_0nKTd@CV`:D4diim1=FFN`C1Ugl4bZjK1>?A_0?Sd/<4hmW:1>?Hb0CSdL44i=701=g9/PCVckH3
i[^b1=c3[@CL^ZH4g<>_1>?A``CSdK/3hm731>G?_`CU]JP4eJ6;1<JJP`BoUGl4_YR20kNOR@C5Yhd4
c:jG1=JdW@CM^ZD4eK:L0mF[U@C=ZiD4cYf91<jLQ`C6WHT4ajV?1<jFMP?>Y904aYj61<C7b2OSknlE
oooo000Doooo:n?_k`?Vi=44i/2U1=>NO@CEUW/4`IMo1<Z^V`CSdK`3hm;31>?IbPCSf<P4hm711>CA
`0CMbK84i/nf0nJk/PCL`jd4g;ZV1=c3[`CSdL<4hm6k0n?A``CUckl4iKFX1=FQR`C6VX<4_iEo1;jH
PP>gWhT4aJN=1<b^U`CF]9d4gKZU1=FbW0?EZiD4cJ^E1<jMR@C>W8L4aYf91<NYS`C>UWH3cZB@1<JN
QPC4alPWhno_5Oooo`005?ooob_Sknl3i^CA1>K0Y@CCWWd4eIIk1<6GO`C:[Y/4hm6l0n?B``CSfLX4
hmS81>?A`@CTdL04gLVb1>K?]P?V^k84g<>]1=bjYPCL`jl4hm731>?A^`?SdL<4iLno1>FeZ0CEXH/4
aYZ31;nEO`BnV883]in91<FWS@C<[YL4e[BM1=fjY@CE/Y`3eJ^E1<f[U@C>WHT4cYb71<JMR@C7ZHl4
cYIf0ljTT0C6WXH4a<O89n?_kaGoool001Coool[hno_0nKTd@CV`:D4diim1=FFN`C1Ugl4bZjK1>?A
_0?Sd/<4hmW:1>?Hb0CSdL44i=701=g9/PCVckH3i[^b1=c3[@CL^ZH4g<>_1>?A``CSdK/3hm731>G?
_`CU]JP4eJ6;1<JJP`BoUGl4_YR20kNOR@C5Yhd4c:jG1=JdW@CM^ZD4eK:L0mF[U@C=ZiD4cYf91<jL
Q`C6WHT4ajV?1<jFMP?>Y904aYj61<C7b2OSknlEoooo000Doooo:n?_k`?Tck<4ZF]71;5eH@B6GE44
[him1=BmZ@CSdK/7hm721>?A``CSdKX4h/Vc1=[8/PCK^JX3eKRS1=njY`CNc;@4gL^d1>CB_0CSdL<3
hm721>C>_PCM`:D4eJ6@1<NKP0BoTg`4`IR30lJPS0C7YHl4ejfK1=JbW@CF/IP4ekVQ0mJ`V0C?Zi<4
cZZC1<JRR`C6W8X4aj2@1<bSP`?2PfX4cjJ@1<B:LBOSknlEoooo000Doooo:n?_k`?Tck<4ZF]71;5e
H@B6GE44[him1=BmZ@CSdK/7hm721>?A``CSdKX4h/Vc1=[8/PCK^JX3eKRS1=njY`CNc;@4gL^d1>CB
_0CSdL<3hm721>C>_PCM`:D4eJ6@1<NKP0BoTg`4`IR30lJPS0C7YHl4ejfK1=JbW@CF/IP4ekVQ0mJ`
V0C?Zi<4cZZC1<JRR`C6W8X4aj2@1<bSP`?2PfX4cjJ@1<B:LBOSknlEoooo000Doooo:n?_k`?Tck<4
ZF]71;5eH@B6GE44[him1=BmZ@CSdK/7hm721>?A``CSdKX4h/Vc1=[8/PCK^JX3eKRS1=njY`CNc;@4
gL^d1>CB_0CSdL<3hm721>C>_PCM`:D4eJ6@1<NKP0BoTg`4`IR30lJPS0C7YHl4ejfK1=JbW@CF/IP4
ekVQ0mJ`V0C?Zi<4cZZC1<JRR`C6W8X4aj2@1<bSP`?2PfX4cjJ@1<B:LBOSknlEoooo000Doooo9n?_
k`CSl?03hmcB1<22I`A]Ccl4O5M>16eWIPCD_JX4iM710nCB``CSdKX4i/fc1>S?^`CU`JP4il:Y1>O1
[P?P[9l4f:bI1<n/U@COaJd4gLbg1>?A``?SdL84i<ff1=bdX0C<WX<4_hil1;nEN`BjTG/3b9j81<nX
T0C@YXl4cjjH1=JYU`C>Yi43cJ^E1<JTSPC6YHh4aZ:;1<JLRPC6Whh4_X=V0kI_CPC4Tg84a8]l9n?_
kaGoool001CooolWhno_1>?`l0?Sg=84`89W16e??`AlEdh4KFMV1=BmZPCUdL43i=;31>?A^PCVcK<4
j<nk1>G1Z0CW`ZT4il6^0n2/W`CH[9T4cjbE1=o5[@CMc;L4hm730n?A`PCTcKH4g;BP1<bNP`BoSW`4
_iEk1;ZAN`?8WXP4cjR@1=2VS`C?[YP4eZVG1<jWT@?=ZiD4aZB>1<JUSPC6XX/4aYb:1<JOSPBnPfH3
]Vm>1<BCLPC4Rg`Whno_5Oooo`005?ooobOSknl4ho3`0n?LdPC0PVL4KDlo17aGCPA]IfH4e;fZ1>GA
`@?Td/<4hm6j1>K=/`CXck/4iL6X1>O2Z@CW`Jh3h:bO1=R/V@C?[9D4glF]1=g<]`CSdL<3hm721>C=
]PCL]:04c9j31;n>O0BoUG/4^Y5k0lRNR0C?Z904d:J?1<n^V0CFZIL4cZNA0lf[U@C6Y8h4aZF>1<JR
R`C6W8X4aYn>1;j3IP>fKdh4a9=b1<B;O2OSknlEoooo000Doooo9n?_k`CSl?03hmcB1<22I`A]Ccl4
O5M>16eWIPCD_JX4iM710nCB``CSdKX4i/fc1>S?^`CU`JP4il:Y1>O1[P?P[9l4f:bI1<n/U@COaJd4
gLbg1>?A``?SdL84i<ff1=bdX0C<WX<4_hil1;nEN`BjTG/3b9j81<nXT0C@YXl4cjjH1=JYU`C>Yi43
cJ^E1<JTSPC6YHh4aZ:;1<JLRPC6Whh4_X=V0kI_CPC4Tg84a8]l9n?_kaGoool001CooolWhno_1>G[
h0?UeLL4Lc<W16M2=PAPAch4JfEV1=FlZ0CSdKT3fl^e1>?A`PCRcKD4c:bD1<RRQPBPOVh4T6]L0j]b
E`C5RgX4bgmQ1<b1H`CLaJl4i=?50n?A``CTc[d4g;>P1<bOP`BoUgL4_h]a1;VJQ@>lVHD4]9j;1;FN
R@C6Xhl4cJjD1<RWT@?=[9D4cJZC1<JRR`C8XX/4b9j:1<JNSPBmQf`3W6==19iYEPBlQ6<Whno_5Ooo
o`005?ooobOSknl4iN_P0nGEa`Ac<bL4Id8f1617?PA[IFH4eKbX1>?A^@?KbkD4hm721>;=]@C<[9@4
b::61:1nKPB@Je`3Zg9G1<F;NPC;Of44c85S1=c5[`CTdlD3hm731>C>_@CL/j04c9n31;nGM`BoRg44
^IZ50kbIQ@BdWX/4]Ij91<JSS`C=[Y@4b:NA0lf/U@C=ZY<4aZ:;1<RRR`C8WXX4aYj>1;f7K0>LHdd4
WVUF1;b4HbOSknlEoooo000Doooo9n?_k`CUjn03iMG717<c9`AW@SH4H4Ln16]UIPCE_:P4hm6i0m_;
]@CSdL84h/fe1<b/U0C8XXH4X7i^191[G0>[LUL4aH]j1<]oH@C<PF<4g<F_1>CCa@?SdL<4i<jm1=bc
X0C<Wh<4_iMg1;n;L@BiVXD3_9V51;BNR`BeWXT4aZ>?1<f^U0C8Yi43cJbE1<fZT`C6XX/4b::;1<RN
RPC6WXh4_HM/0iaSC@BNJEH4_8AS9n?_kaGoool001CooolWhno_1>G[h0?UeLL4Lc<W16M2=PAPAch4
JfEV1=FlZ0CSdKT3fl^e1>?A`PCRcKD4c:bD1<RRQPBPOVh4T6]L0j]bE`C5RgX4bgmQ1<b1H`CLaJl4
i=?50n?A``CTc[d4g;>P1<bOP`BoUgL4_h]a1;VJQ@>lVHD4]9j;1;FNR@C6Xhl4cJjD1<RWT@?=[9D4
cJZC1<JRR`C8XX/4b9j:1<JNSPBmQf`3W6==19iYEPBlQ6<Whno_5Oooo`005?ooob?Sknl4h^k]1>;W
g@?L]id4XFeR14<`:`AA>S@4BEAH1=_3[PCLbK<3i<^e1>?A^PCRd;X4fKZQ1:bMR`B?Lf04H4Dm0fA7
>@B0I5L4[W]T19e_H@BIIeh4g<>^0n??`@CTc[d4g;VP1<ZHOPBoTG04WdP_1;V@N@?8Wg`4c9n51<B?
LPCCXhX4aYf<1;ZOR0??Zi@4cZZC1<FOQ`BhWHL4^If:1<JPR0BeO6H3Y71J1:=aHPBhJU04h^k^8n?_
kaGoool001CooolShno_1>;^k@CRimd3g;NM1:5]HPA3<2/4DCXd14UDF0CK`jh4g<Vc0nC;]@CSdKX4
h]2j1=VjX@B/WH/4Sg=P1615?@=TAcT4P6AG1:ikI0BMKf44VFMN1=c3[P?Scl44i<jm1=biX0C:V7h4
_i5`19m8;`BiT7T3b9ml1<bOQ@C4Sg84dj>:1<JMS0BjWhP3cj^D1<jZT`C5WhL4^9f71;VMRPC6X8P4
]GaV0jA`FPBSLF84^6Y@1>;^kR?SknlEoooo000Doooo8n?_k`CRk^d4h^OM0mbgW@BQKF84@c0[154j
=0A9E5P4fl>^1=c9/`?TbkD4hm6j1>;@^PCI^Z44[9f;18mcH0APACd3I4Li181TE`B^Nf@4WFmQ19UW
GPCL`jh3hlo11>C>_@CL^J04bYQn1;nAL0BOB2l4^I1i0lROO0C<WhD4a8mb1=>SRPC6WH`4^Yn80ln[
U0C>ZY<4aIn71;RMQ`BiWHX4aZ281;ElIP>TL5X4Xg5R1;QZD0CRk^hShno_5Oooo`005?ooob?Sknl4
h^k]1>;Wg@?L]id4XFeR14<`:`AA>S@4BEAH1=_3[PCLbK<3i<^e1>?A^PCRd;X4fKZQ1:bMR`B?Lf04
H4Dm0fA7>@B0I5L4[W]T19e_H@BIIeh4g<>^0n??`@CTc[d4g;VP1<ZHOPBoTG04WdP_1;V@N@?8Wg`4
c9n51<B?LPCCXhX4aYf<1;ZOR0??Zi@4cZZC1<FOQ`BhWHL4^If:1<JPR0BeO6H3Y71J1:=aHPBhJU04
h^k^8n?_kaGoool001Coool4ho7`3>?`l1?Sknl4ST/l1?o^fP?U`:L4/7IR150oA@A5=2d4E4iC1=g;
]0CSdKX3g<Zc1>KB^PCTd[`4h/jm1<b/U`CD/9h4K6mV0diCC@APFe44L7E_1:B1LPC<ZYH4g<bg0n?I
b`CTgLh4g;nU1<^KOPB_QW04ZGMM17mEC@>QNVX4@2HT1:9]F@B@Lf04Sf=<1;V@NP?3TV`4bj221<FS
S0BhUh84^Ib71<2DO`BHJ583Ree>1:J0K`C1Pg<4joOf8n?_kaGoool001Coool4ho7`3>?`l1?Sknl4
ST/l1?o^fP?U`:L4/7IR150oA@A5=2d4E4iC1=g;]0CSdKX3g<Zc1>KB^PCTd[`4h/jm1<b/U`CD/9h4
K6mV0diCC@APFe44L7E_1:B1LPC<ZYH4g<bg0n?Ib`CTgLh4g;nU1<^KOPB_QW04ZGMM17mEC@>QNVX4
@2HT1:9]F@B@Lf04Sf=<1;V@NP?3TV`4bj221<FSS0BhUh84^Ib71<2DO`BHJ583Ree>1:J0K`C1Pg<4
joOf8n?_kaGoool001Coool4ho7`3>?`l1?Sknl4ST/l1?o^fP?U`:L4/7IR150oA@A5=2d4E4iC1=g;
]0CSdKX3g<Zc1>KB^PCTd[`4h/jm1<b/U`CD/9h4K6mV0diCC@APFe44L7E_1:B1LPC<ZYH4g<bg0n?I
b`CTgLh4g;nU1<^KOPB_QW04ZGMM17mEC@>QNVX4@2HT1:9]F@B@Lf04Sf=<1;V@NP?3TV`4bj221<FS
S0BhUh84^Ib71<2DO`BHJ583Ree>1:J0K`C1Pg<4joOf8n?_kaGoool001Coool4ho7`3>?`l1?Sknl4
ST/l1?o^fP?U`:L4/7IR150oA@A5=2d4E4iC1=g;]0CSdKX3g<Zc1>KB^PCTd[`4h/jm1<b/U`CD/9h4
K6mV0diCC@APFe44L7E_1:B1LPC<ZYH4g<bg0n?Ib`CTgLh4g;nU1<^KOPB_QW04ZGMM17mEC@>QNVX4
@2HT1:9]F@B@Lf04Sf=<1;V@NP?3TV`4bj221<FSS0BhUh84^Ib71<2DO`BHJ583Ree>1:J0K`C1Pg<4
joOf8n?_kaGoool001Coool4hnSX1>?Xi`CSk^h4hnOV3n?_k`BGI5T4SFAH15<O60?1Nf@4M4aB154l
<`A=>cP4>DM<1=c:/`CLbkD3iL:Z1>38[0CNcKP4h]311=W6/@C@/9`4`j><0l:TSPBZRg<4ZXif1<:W
SPCD[YX4g<B`0n?IbPCTdl84g;nV1<bMPPBnTG<4[XI_19alK@>CQGT4@S@d14Tj<@AjFe84JEI;175O
D0>FOVd4VX9[1;j@M`BhWHL4^Ij719m[G@B1GDP3LDdn18M/F`C>Yhl4k?Sg8n?_kaGoool001Coool4
hnSX1>?Xi`CSk^h4hnOV3n?_k`BGI5T4SFAH15<O60?1Nf@4M4aB154l<`A=>cP4>DM<1=c:/`CLbkD3
iL:Z1>38[0CNcKP4h]311=W6/@C@/9`4`j><0l:TSPBZRg<4ZXif1<:WSPCD[YX4g<B`0n?IbPCTdl84
g;nV1<bMPPBnTG<4[XI_19alK@>CQGT4@S@d14Tj<@AjFe84JEI;175OD0>FOVd4VX9[1;j@M`BhWHL4
^Ij719m[G@B1GDP3LDdn18M/F`C>Yhl4k?Sg8n?_kaGoool001Coool4hnSX1>?Xi`CSk^h4hnOV3n?_
k`BGI5T4SFAH15<O60?1Nf@4M4aB154l<`A=>cP4>DM<1=c:/`CLbkD3iL:Z1>38[0CNcKP4h]311=W6
/@C@/9`4`j><0l:TSPBZRg<4ZXif1<:WSPCD[YX4g<B`0n?IbPCTdl84g;nV1<bMPPBnTG<4[XI_19al
K@>CQGT4@S@d14Tj<@AjFe84JEI;175OD0>FOVd4VX9[1;j@M`BhWHL4^Ij719m[G@B1GDP3LDdn18M/
F`C>Yhl4k?Sg8n?_kaGoool001Coool4hnSX1>?Xi`CSk^h4hnOV3n?_k`BGI5T4SFAH15<O60?1Nf@4
M4aB154l<`A=>cP4>DM<1=c:/`CLbkD3iL:Z1>38[0CNcKP4h]311=W6/@C@/9`4`j><0l:TSPBZRg<4
ZXif1<:WSPCD[YX4g<B`0n?IbPCTdl84g;nV1<bMPPBnTG<4[XI_19alK@>CQGT4@S@d14Tj<@AjFe84
JEI;175OD0>FOVd4VX9[1;j@M`BhWHL4^Ij719m[G@B1GDP3LDdn18M/F`C>Yhl4k?Sg8n?_kaGoool0
01Coool4hnKV1>?WiQOSknl4TF1E15e6>PAE>S@3DCTd13hZ:PA=>SH4C3Tc14UBE@CKbk@4g<^d0n7=
_`C;WHl4cYn51>S4Z`CR`ZL4eZZE1<J8L`?2R6T4bY5c1<f=L0CM^I`4g[fX1=c4/0?SfLT4i=?01=bi
Y`C<Z8h4_i=d1;RLN0C1U7X3aJ>=1:N:NP@]Ad/4I5Q=171UFPAEHE`3SW]W1;6=NPC7Y8L4_IR41;RL
Q`B?I4`4GT0i0fU;?0AkFDP4_WEL9n?_kaGoool001Coool4hnKV1>?WiQOSknl4TF1E15e6>PAE>S@3
DCTd13hZ:PA=>SH4C3Tc14UBE@CKbk@4g<^d0n7=_`C;WHl4cYn51>S4Z`CR`ZL4eZZE1<J8L`?2R6T4
bY5c1<f=L0CM^I`4g[fX1=c4/0?SfLT4i=?01=biY`C<Z8h4_i=d1;RLN0C1U7X3aJ>=1:N:NP@]Ad/4
I5Q=171UFPAEHE`3SW]W1;6=NPC7Y8L4_IR41;RLQ`B?I4`4GT0i0fU;?0AkFDP4_WEL9n?_kaGoool0
01Coool4hnKV1>?WiQOSknl4TF1E15e6>PAE>S@3DCTd13hZ:PA=>SH4C3Tc14UBE@CKbk@4g<^d0n7=
_`C;WHl4cYn51>S4Z`CR`ZL4eZZE1<J8L`?2R6T4bY5c1<f=L0CM^I`4g[fX1=c4/0?SfLT4i=?01=bi
Y`C<Z8h4_i=d1;RLN0C1U7X3aJ>=1:N:NP@]Ad/4I5Q=171UFPAEHE`3SW]W1;6=NPC7Y8L4_IR41;RL
Q`B?I4`4GT0i0fU;?0AkFDP4_WEL9n?_kaGoool001CooolOhno_19Y/E@A;;bL4B3P`0d`f;`A8=S04
>C4/15a:A@ALEeL4g/F_1>;:]0?Kb[D4hLjo1<B]VPB[RGP4/i:11:J@OPB=Nfd3PFiS18abH0BDNV/4
UgEY1<RcW`CKb[@3hlo01>C@]`CL^:84c:BC1;IgF`BiMUP4_Z5k0lRUR0C6YH`4a:B>1;>EO`BOOVd4
XH5_0knGP@C6W7l4^9f71<RUQ`C0VGl4GTLk14Ph<0=IFE@4MUE51:eJ@bOSknlEoooo000Doooo7n?_
k`BJK5D4BblW14Ph<0=<=Rl4B3H`13Ta;0ALBTD4G5MG1=k5[`CRb[@3flZe1>7>_`C4[IX4ZhUh1;>B
P@BVT7h4SG]]0h5^H`B<LV04U7Y[19MeJ@C8/il4flZd0n??`0CTd;L4g;RR1<bTT`BfMe/4^GIH1;jQ
N`?8YHP4aZF<1<BTSPBcUGl4Wgi]1:61K`>oUh44aYao1;RMQ`C8YHL4`9Uo15i7>`A8>303FEUD17IE
A@B]FT<Whno_5Oooo`005?oooaoSknl4VVaE14/_9`A8>303C3H_14Pf<0@i<B`4G4Y515aGE`CNaJl4
h/Zd0m_:]@CQc[l4a:fJ1:^9N0BcTX44YY1n18ekK@>1KV<4S79P19AjJ`BGMFT4b;>O1=_:]0?Scl04
i=2g1=bhXPC<Y9<4]WMK1;UfF0BnXG/3b:F81<JUS0C4Y8h4/iEo19mnK@BQPFl3_iN11<JLO`BhWHL4
b:F71<2IO`ANAc/4B3P`0eUIE0AfEDD4[EY39n?_kaGoool001CooolOhno_19Y/E@A;;bL4B3P`0d`f
;`A8=S04>C4/15a:A@ALEeL4g/F_1>;:]0?Kb[D4hLjo1<B]VPB[RGP4/i:11:J@OPB=Nfd3PFiS18ab
H0BDNV/4UgEY1<RcW`CKb[@3hlo01>C@]`CL^:84c:BC1;IgF`BiMUP4_Z5k0lRUR0C6YH`4a:B>1;>E
O`BOOVd4XH5_0knGP@C6W7l4^9f71<RUQ`C0VGl4GTLk14Ph<0=IFE@4MUE51:eJ@bOSknlEoooo000D
oooo2>?_k`SSl?0?hno_1:Z2K0AB;bL4A3</0c`d;P@/7al4AC@^1558@`A^KFL4d;RS1>C;]@?SdK`4
hm731>;@`@CGa:l4]i>:1926Q0BjThT3ZHEd1:R;NPBRPW@4bZJC1=c:]@CUd<03i]301>Fj/@CL`:T4
b[2L1;N=Q0B>GU84QeU60i5VB`C=VGX4bjN<1<jUR`C5Y8L4^9b70lNPQ0BhV844b9f?1;NMQ`BOKUD4
HD<h14U4?@=DED/4/feA18]QEPCdoolShno_5Oooo`005?ooo`SSknl8ho3`3n?_k`BZPV`4DRlW14@c
;0<l=2h4;1lO14Dd;PAAB4<4KVeW1=2hX`CTbkD3hm6l1>?A``CRd<44elB_1;NCRPB@QX@4^Y>90jV5
M0BXRgX4XX9d1<ZVT`CLb[D4iM300nK@`0CU^[44g<2Y1<Z`W0BgSH@4SUiB18MIAP>AIT/4cIUj1<^W
S0C>YH/4aJB71;RLQ`?7X8@4^9R11<RMS`BgWHL4WfiE1653>0A9A3d3E5E;1;=]D@B;HEH4m?oo8n?_
kaGoool001Coool8hno_2>?`l0oSknl4ZX9/158_9`A4<b`3?3@^12`O7`A5=2h4DDQ316i]I`C@^:<4
i<^e0n?A_0CSdL<4h]311=O4[`BgThX4T8J41;ZCR@>YQG@4Z8]j1::2M0C:YY<4g<Ze1>G@`0?Vd<04
iKZa1=c0Z@C:/9`4]hf418iNDPB7FDH3TFI;1<fINPC;Yh`4cZF;1<FTQ`BhW8L3aj241;RHP@C8WHl4
]if719m^E@AQ@cP4BD@m0eAEB`BcKE44Rf5F1?Coob?SknlEoooo000Doooo2>?_k`SSl?0?hno_1:Z2
K0AB;bL4A3</0c`d;P@/7al4AC@^1558@`A^KFL4d;RS1>C;]@?SdK`4hm731>;@`@CGa:l4]i>:1926
Q0BjThT3ZHEd1:R;NPBRPW@4bZJC1=c:]@CUd<03i]301>Fj/@CL`:T4b[2L1;N=Q0B>GU84QeU60i5V
B`C=VGX4bjN<1<jUR`C5Y8L4^9b70lNPQ0BhV844b9f?1;NMQ`BOKUD4HD<h14U4?@=DED/4/feA18]Q
EPCdoolShno_5Oooo`005?ooo`SSknl4hnk^1>?WiPoSknl4Vh=i15e6?@A6<R`3A3@^13H]9P@k<2/4
EDQ316a/I0BfXi44g<B_0n?A_0CSd/<4hmW:1>?Hb@SSelP;hmS91>?Hb0CRd;T4fl^e1>;Ha`?KbK44
g<R`1=_3[0CC^ZH4dKRT1;bPSPAnJVH3KemD16U@@@B:GDP4^X5Z1;:=L`C0S6d3]8Q/1<6IQPBXTWh4
aiZ817i@A0AB>C44BCXi0eHb:@BFB3D4R5mB15]BBR?SknlEoooo000Doooo2>?_k`CSk^h4hnOV3n?_
k`BKPgT4GDHm14Hb;0=4=2h4=RdV13/`:`AEB4<4K6aT1;JST@CLa:l3hm6l1>?B``CSfLX4hmS92>?G
b0_Sf<T4hmS81>;@^@CKbkD4h]S70m_9/@CLb;04fl>/1=>jYPCA^:@4_:2>17iZIP=_Ge@4JE1118YM
B0BjPFX4/Xec1<2<K@>dR6`4`IV61:RBOPC7VXP4OU14158i<@A9>ST3ES8Y19I8=@B8Ge84Fe9:8n?_
kaGoool001Coool8hno_1>?^kPCSinH?hno_19^3N@AMASd4AS8/0d@d;P@f;BH4>c0[15E8@`A/K6@4
]Z>A1=c4[`?SdK`4hm;31>?IbPCSf<T8hmO82n?Hb@CSf<P4h]2i1=_;]@CRf<L3flVa1=c8/0CK`j`4
dkZV1=6hY0BlX8h4OVYV0fmOE0AYD444RUe81;Z1JPBbSG<4`8a]0kB8K0C1VHH4Z99n1<NJR0AnD4@4
DSTa14Tj>@=F<RT4UTPe18QODPAKDTXShno_5Oooo`005?ooo`SSknl4hnk^1>?WiPoSknl4Vh=i15e6
?@A6<R`3A3@^13H]9P@k<2/4EDQ316a/I0BfXi44g<B_0n?A_0CSd/<4hmW:1>?Hb@SSelP;hmS91>?H
b0CRd;T4fl^e1>;Ha`?KbK44g<R`1=_3[0CC^ZH4dKRT1;bPSPAnJVH3KemD16U@@@B:GDP4^X5Z1;:=
L`C0S6d3]8Q/1<6IQPBXTWh4aiZ817i@A0AB>C44BCXi0eHb:@BFB3D4R5mB15]BBR?SknlEoooo000D
oooo7n?_k`BZSH@4IUI?144f;`=5=2h4A3@]14<h=`ADB4<4LVYP1;fOR`CNa[03hm6k1>?Ba0CSfLX4
hmW;1>?RfPCShMP4hn3G0n?Hb@CSh=H4hmW:1>?Hb0CSdKT4hm6j0nC?]`CL`Z/4g;ZU1=c3[@CL`J`4
g;ZZ1<baX@?0VX/4Rga`16eRF0AYGE04Qf]K17ijJ`>@NVT4U7Y/1<NMR`C4Uh04Ndi214Te;`@o=2h3
>blX15Dh<PAeDTX4I5YB8n?_kaGoool001CooolOhno_1:Z=Q0AVETl4@CH_0dDd;PA4=2d4@cPg15A8
@`AbJV04_In;1=k6/0?SdK/4hm;41>?IbPCSfL/4hn;J1>?Qf0CSh=L3hmS91>?PePCSfLX4hmS81>?A
^@CSdKX3i<ng1=c2Z`CL^ZD4g<>]1=c1[0CL^ZX4c;6Q0l2JR`B;O704KF9H16UMD0B7Je/4OWY[0i1j
J@BDNV`4aif;1<BGP0AkCT84BCD_13ld;P<k;bP4ECPb17EBBPATFU8Shno_5Oooo`005?oooaoSknl4
ZXf416IFC`A1=Rl3AC@^14@d;@A3>3L4E4Q3179ZH0BmWh/4g/J`0n?A^`CSd/@4hmW:1>?Ib`CSh]X4
hn7H1>?Pe`?Sf<T4hn3F1>?IbPCSf<P4hm6i1>?A^P?TckL4g<:[1=bjY@CL`jd4g<6/1=bjZPC</J43
`9Z;18]lL0A]HUP4JEe@18M[F`AnNV/3T7YY19AjK0C7WH/4a9N017]>@PA9=Bl4?c@^0c/_:0AE>384
ME9:16AJDR?SknlEoooo000Doooo7n?_k`BZSH@4IUI?144f;`=5=2h4A3@]14<h=`ADB4<4LVYP1;fO
R`CNa[03hm6k1>?Ba0CSfLX4hmW;1>?RfPCShMP4hn3G0n?Hb@CSh=H4hmW:1>?Hb0CSdKT4hm6j0nC?
]`CL`Z/4g;ZU1=c3[@CL`J`4g;ZZ1<baX@?0VX/4Rga`16eRF0AYGE04Qf]K17ijJ`>@NVT4U7Y/1<NM
R`C4Uh04Ndi214Te;`@o=2h3>blX15Dh<PAeDTX4I5YB8n?_kaGoool001CooolOhno_1:^3K@AXCd84
GDQ10d4d;@A9;RH4CCXd15M6?@A`HEH4ZI=o1<jhY0?Td[/4hm6l1>?B``CSf<T4hmW:1>?RfPOShMP4
hn3F1>?IbPCSf<P4hmS91>?A^@?Tc[D4g<>]1=c2Z`CL^ZD4g<:[1=fiZ0CD^:03c;6J1<BTS@BcWXX4
XXml19AnKPBGP6h3]Y9o1;NKQ`BnT8@4Zh1U17==@@A9=Bl4C3Tc0c`d;@A0<b`4G4Lk17ilM`CYmoHO
hno_5Oooo`005?oooaoSknl4Zh=]16Q?@PAMB443@C@]14T^9PA=>S@4EdHm171QEPBYTgl4c[RT0nCB
^`CSdK`4hm;31>?Hb@CSfLX4hn;J1n?Qf0CSh=H4hmW:1>?Hb0CSf<T4hm6i0nC>]@CL`jd4g<:[1=bj
Y@CL`Z/4gKVX1=BhX0?</IX4a:B=1;>NRPBRSg`4U7i^19N0KP>fTWl4]i^71;j@Q0B[P6D4Lde114Te
;`A<>C<3?3@]140c;0ALAc/4OWag1>WgmQoSknlEoooo000Doooo7n?_k`B[Pfd4J4m215e8@@=1=2d4
BBhV14dj=0AGASd4L65F1:VCO`C>^:@3i=:k1>?A_0CSd/<4hmS91>?IbPCSh]X7hn7H1>?PePCSfLX4
hmS81>?Hb@CSdKT3i<je1=c3[@CL`Z/4g;ZU1=c2Z`CM^JP4e;RP0lbaVPC4Y8d4/ij:1::?O0BDOVh4
Uh1^0kJBO`BgVhL4_Y241:^0I@AcCD44BCD_14`i<`<l=2d4@3</15a7>`AnO7L4jOOf7n?_kaGoool0
01CooolOhno_19]iH@A/ETd4F4@l0e8l=P@i;BH4B3<]14Xf;`A[DD84RgAM1<^^V`?LbkD4hm6l1>?B
``CSfL/4hn3G1>?IbPCSh]X7hn7H1>?IbPCSf<L4hm6k1>G?_P?UbK44g;ZU1=c2Z`CL`ZX4g;ZU1=fi
XPCF/IX3eZbE1<f/U`C6Y8h4cJZC1<JUSPC6XX/3b9b71<RLR`C2U7/4QV5B14Xf:PA?>c/4>Bh]0cd_
9`@[7al4CcXd17EXG`Bh[JhOhno_5Oooo`005?oooaoSknl4VgUQ16aFC@AHA3`3DS`f13T]9PA8<bd4
BSH_16]A@PB;M5d4bjjK0mc;]@CSdK`4hm;31>?Ib`CSh=L4hmW:1>?RfPOShMP4hmW:1>?Ha`CSdK/4
iLnn0nG9/@CL^ZD4g<:[1=c2ZPCL^ZD4gKVR1=JaVP?F[9D4cJbG1<JTSPC=ZY<4aZF>1<JRR`?8W8L4
b9b;1<:DN`B6HE84BSHZ14lk>`@i;Rd3?BlW12/O7`A?>S@4MFQO1;R][QoSknlEoooo000Doooo7n?_
k`BKNF44K5I=15Q4?0=B?3H4>BdV14Pc;@A:=Rl4Je5218]dG@C;[Y/3g<^e1>?A_0CSd/<4hmW;1>?P
e`CSfLX4hn;J1n?Qf0CSfLX4hmS71>?A^`CUckh3iLVa1=bjY@CL`Z/4g<:Z1=bjY@CM^J84e[6J0mJ/
U@C=[9L4aZB>1<fZT`C6YHh4aZ:;0lRLQ`C8W8/4`YAk18IQDPA:=RX4Cc/k13T^;@<m;bL4:alO14lj
=0AeJ5l4^:f^7n?_kaGoool001CooolOhno_19]iH@A/ETd4F4@l0e8l=P@i;BH4B3<]14Xf;`A[DD84
RgAM1<^^V`?LbkD4hm6l1>?B``CSfL/4hn3G1>?IbPCSh]X7hn7H1>?IbPCSf<L4hm6k1>G?_P?UbK44
g;ZU1=c2Z`CL`ZX4g;ZU1=fiXPCF/IX3eZbE1<f/U`C6Y8h4cJZC1<JUSPC6XX/3b9b71<RLR`C2U7/4
QV5B14Xf:PA?>c/4>Bh]0cd_9`@[7al4CcXd17EXG`Bh[JhOhno_5Oooo`005?oooaoSknl4ZX=]165@
A`ATE4d3DT8l154k=0@o<R`4CCli15M;APAhGe44XHQa0mk6/0CSd[`4hm;31>?Jc0CSh]X4hn3G1>?H
b@?Sh=H8hmW:1>?Hb0CUdKT4iLng1mc2ZPCL^ZD4gKZU1=jiX`CM^J<4eK6J0lf/U@C=[9H4cK6J1<JT
SPC>YHh4aJ:;0kNLQ`BgVX@4Yh1[175<@0ADA3d4<2DU13/_<0<Z7Ql4=Bd/13``:`AYG5P4UX=j7n?_
kaGoool001CooolOhno_1:Z3K@AQD4L4I5A=0e92?0AA>c@4?c8/14do>@AGBdH4N5mA1:68L@?Na[04
hm:l1>?B``CSf/`4hn;J1>?Pe`CSf<T3hn3F2>?IbPCSf<P4iM6i1>G?]`OL`ZX4g;ZU1=fjY@CN^J<4
gKVS1=FaVP?=[9D4cJbF1<faVPC6Y8h4cZF>1<FRR`>gW8L4]iZ41:N0J`AaC404E4@m130U9@@k;c03
:QhO13D];0@l<2/4JEaH19J3NQoSknlEoooo000Doooo7n?_k`BZPfd4HE1716ADC@=B@S`4DC/d13lb
;0A=?cT4Ed]617QOD@BQR743g/J`1>?B_0CSd/<4hm[<1>?RfPCSh=L4hmS90n?PePSSfLX4hmS81>GA
^@CUckL7g<:Z1=bjY@CM^ZD4g[VS1=fiX`CE/IX3cJbE1<f/UPC=/IX4aZB>1<jUSPC5XX/3]ib71;NJ
Q0BWP6/4LDa015A4?@@`9BD4>bl`0bXN7`@e;B`4?30[16ULF0BFPgXOhno_5Oooo`005?oooaoSknl4
ZX=]165@A`ATE4d3DT8l154k=0@o<R`4CCli15M;APAhGe44XHQa0mk6/0CSd[`4hm;31>?Jc0CSh]X4
hn3G1>?Hb@?Sh=H8hmW:1>?Hb0CUdKT4iLng1mc2ZPCL^ZD4gKZU1=jiX`CM^J<4eK6J0lf/U@C=[9H4
cK6J1<JTSPC>YHh4aJ:;0kNLQ`BgVX@4Yh1[175<@0ADA3d4<2DU13/_<0<Z7Ql4=Bd/13``:`AYG5P4
UX=j7n?_kaGoool001CooolOhno_1:>=P`A/ETd4I5I@0f1AB`AB?3H4?2lW14hj=0APCT84LfIH18=i
J0??/il4i<^f1>?A``CSd/<4hm[<1>?RfPCShMP3hn3G1>?Hb@CSfLX4hmS91>;A`0CKb;43gL6Z1=ji
X`CM^ZD4gKZS1=FhX0CE/Yd4eK:J0lf/U@C=ZY<4cZ^C1<jZT`C7X8P4aZ><0kRGP0BkS7L4V6UC16I5
?0@m;bL4?30`12hT9@<e;2H4<RX[14Lh<`@W7aH4N6eU7n?_kaGoool001CooolOhno_1:>=P`A/ETd4
I5I@0f1AB`AB?3H4?2lW14hj=0APCT84LfIH18=iJ0??/il4i<^f1>?A``CSd/<4hm[<1>?RfPCShMP3
hn3G1>?Hb@CSfLX4hmS91>;A`0CKb;43gL6Z1=jiX`CM^ZD4gKZS1=FhX0CE/Yd4eK:J0lf/U@C=ZY<4
cZ^C1<jZT`C7X8P4aZ><0kRGP0BkS7L4V6UC16I5?0@m;bL4?30`12hT9@<e;2H4<RX[14Lh<`@W7aH4
N6eU7n?_kaGoool001CooolOhno_1:>=P`A/ETd4I5I@0f1AB`AB?3H4?2lW14hj=0APCT84LfIH18=i
J0??/il4i<^f1>?A``CSd/<4hm[<1>?RfPCShMP3hn3G1>?Hb@CSfLX4hmS91>;A`0CKb;43gL6Z1=ji
X`CM^ZD4gKZS1=FhX0CE/Yd4eK:J0lf/U@C=ZY<4cZ^C1<jZT`C7X8P4aZ><0kRGP0BkS7L4V6UC16I5
?0@m;bL4?30`12hT9@<e;2H4<RX[14Lh<`@W7aH4N6eU7n?_kaGoool001CooolOhno_1:>=P`A/ETd4
I5I@0f1AB`AB?3H4?2lW14hj=0APCT84LfIH18=iJ0??/il4i<^f1>?A``CSd/<4hm[<1>?RfPCShMP3
hn3G1>?Hb@CSfLX4hmS91>;A`0CKb;43gL6Z1=jiX`CM^ZD4gKZS1=FhX0CE/Yd4eK:J0lf/U@C=ZY<4
cZ^C1<jZT`C7X8P4aZ><0kRGP0BkS7L4V6UC16I5?0@m;bL4?30`12hT9@<e;2H4<RX[14Lh<`@W7aH4
N6eU7n?_kaGoool001CooolGhno_1>?`l0CUlO44VhAj16EECPAYFE<3I5A=14di<PAB@3X4Ac`g15Q6
@0AlHe84VGaY0l6HP0CMaJl4hm6l2>?A``CSfL/7hn7H1>?PePCSfLX4iMO61>CB`@CTc[D3fl:Z1=>j
Y0CE/id4gK>S1=FaVPCF[IP4eZ^J0ljXT`C?Zi<4cZF>1<JUSPC6XH/4_iN20lBCN`BaPfX4N5M615i0
=`A2=Bh4>S8/13Xb;@<d:bD4>S8/14Ph=0@m;2@4h^k^7n?_kaGoool001CooolGhno_1>?`l0CUlO44
VhAj16EECPAYFE<3I5A=14di<PAB@3X4Ac`g15Q6@0AlHe84VGaY0l6HP0CMaJl4hm6l2>?A``CSfL/7
hn7H1>?PePCSfLX4iMO61>CB`@CTc[D3fl:Z1=>jY0CE/id4gK>S1=FaVPCF[IP4eZ^J0ljXT`C?Zi<4
cZF>1<JUSPC6XH/4_iN20lBCN`BaPfX4N5M615i0=`A2=Bh4>S8/13Xb;@<d:bD4>S8/14Ph=0@m;2@4
h^k^7n?_kaGoool001CooolGhno_1>?`l0CUlO44VhAj16EECPAYFE<3I5A=14di<PAB@3X4Ac`g15Q6
@0AlHe84VGaY0l6HP0CMaJl4hm6l2>?A``CSfL/7hn7H1>?PePCSfLX4iMO61>CB`@CTc[D3fl:Z1=>j
Y0CE/id4gK>S1=FaVPCF[IP4eZ^J0ljXT`C?Zi<4cZF>1<JUSPC6XH/4_iN20lBCN`BaPfX4N5M615i0
=`A2=Bh4>S8/13Xb;@<d:bD4>S8/14Ph=0@m;2@4h^k^7n?_kaGoool001CooolGhno_1>?`l0CUlO44
VhAj16EECPAYFE<3I5A=14di<PAB@3X4Ac`g15Q6@0AlHe84VGaY0l6HP0CMaJl4hm6l2>?A``CSfL/7
hn7H1>?PePCSfLX4iMO61>CB`@CTc[D3fl:Z1=>jY0CE/id4gK>S1=FaVPCF[IP4eZ^J0ljXT`C?Zi<4
cZF>1<JUSPC6XH/4_iN20lBCN`BaPfX4N5M615i0=`A2=Bh4>S8/13Xb;@<d:bD4>S8/14Ph=0@m;2@4
h^k^7n?_kaGoool001CooolGhno_1>?^kPCRiND4SWAY16QBAPAQDT`3J5UC15mABPA<?SP4ETQ115Y8
?0AZHET4VGAO0kfHQ0CG_jX4i=:l1>?B``CSfLX4hmW;1n?Rf@CShML4iMW71>GGa0CMbk@4iLN_0mfi
X0CN^Z@4gKVP1=FcW@CE/i`4eJbE1<fbVP?=ZI<4aYj>1<JRR`C6Xh`4aZ:;1<BGP0>cRg44TFAG1719
?@A7>304?BlW13L^;P@a9RH38alO130V9PADB4<4@C8Z1>chmaoSknlEoooo000Doooo5n?_k`CSk^h4
h^GU18idJ@AXDTH4HE9<0fQID`AODDX4C3hh15I8@@AJB3`4JV5I19UdG`>mV8@4eknZ1>CB_0CSd/<4
hmW:1>?Ib`OSh]T4hn7G1>GIa`CUel@4gL^d1>G7[`?M^J04g[ZT1=fiX0CE/id4eK>L1=F/U@C=/YX3
cJVC1<JNSPC6XX/4aZ><1<JRR`C4Uh03/h]a195TE`A`BCd4AcP`13d_9`@g;Rh4<BHV0b<O7`@`9RH4
E4Q3144b:PC/n?LOhno_5Oooo`005?oooaOSknl4hnk^1>;Ui@B>M6T4J596165BC0=XFE<4Ge5:14`n
>0AFB444FTPl16YQF@BIM5l3_IR41=NoZPCTd[`4hm;31>?IbPCSfL/7hn;I1>?Qe`CUfLL4iMO41=g;
]0CUajl3gKVP1=jjY0CM^J04eK>M1=FcW0CE[9D4cK:J0lfYT`C6WXh4aZ:;1<JSS0C6XX/4a9N00k>;
L@BAI5L4L4Tm14Lh<0@m;bL4=bh^134V9P<S7al4<2HV15A8@`A1<RX4k?Sg7n?_kaGoool001CooolO
hno_1:V=P`AMBSd4K5M>0fEFD0APCdL4F40i15Y9?0AMCdT4K5a?18IUE@>TQ6l4cjbI1=c;]@CSdL84
hm;42n?Ib@CSf<X4h]701=_8/@CL`Z/4gLBZ0mfhX0CE/YP4eKBL1=FcU`CE/9P4eK:K1lfZT`C=YHh4
aZ:;1<NJQ0C3V804/h]a0i5WF@AnF4D4DSTb148e;`A2=2d4=B`/130U9P<^92D4?S@`100000AD>C4S
hno_5Oooo`005?oooaoSknl4ZHf315e:?@A/Edh3IEI@161?A`AH@3T4FTTl15e?B@A/G4l4QVEE0jB4
K`C?[9T4g<^e1>?A`PCSd/@;hmW91>?HbPCRdL04flRa1=c2Z`CMa:X3gKRP1=FbV0CE]9`4eK>G1=F`
V0CE/Y/7cJZC1<fUSPC6XX/4aiZ41<>HP0BcRg43TFMI17iHA@AB>C84@SD_148d;@@e;2`4<2DV0bhT
9@@n=304000015@i<B?SknlEoooo000Doooo7n?_k`BYSH<4GDXm16aGCP=UEU04H4m715Q0>@AJBC`4
GDm916aLC`B6IED3Y8A_1<n/V@CLbkD4hm721>?Ba0_SfLT4hmS:1>;A`0CKb;44g<:[1=g4ZP?M^:04
eK:H1=FdW0CE/iL4eK2H1=FbV`O=ZY<4cJF>1<JRR`C7VX@4`iR01;>;L@>AIeT4OUQ5158i<PA2=Bl4
@S@]13D/;0@`9BH3;R@U13hd<0@00004E3Ta8n?_kaGoool001CooolOhno_1:V=P`AMBSd4K5M>0fEF
D0APCdL4F40i15Y9?0AMCdT4K5a?18IUE@>TQ6l4cjbI1=c;]@CSdL84hm;42n?Ib@CSf<X4h]701=_8
/@CL`Z/4gLBZ0mfhX0CE/YP4eKBL1=FcU`CE/9P4eK:K1lfZT`C=YHh4aZ:;1<NJQ0C3V804/h]a0i5W
F@AnF4D4DSTb148e;`A2=2d4=B`/130U9P<^92D4?S@`100000AD>C4Shno_5Oooo`005?oooaoSknl4
_[2Y16ICC0ARD4L3K5UC16A?@@AIBT<4Dd0j169@A`ANCDH4LV1E0h]ZF@BoVH84h<jg1>KB^PCTd[`4
hm721>?A^P?UdKT4i]:k1>CB`PCTcKD4gKjU1=fiX0?FZY<4ejbF1=N/V`CF/Y/4eZnG1=JUS`C=Z9<3
cZF>1<jUR`C7WhP4aYZ41;Z?M`BJKET3OEQ515<j<PA0<BP4>Bh^148d;P@i;Rh4:QhO0blT9PA5=S84
AC@/1>chmb?SknlEoooo000Doooo7n?_k`Bn/:T4IU=<169@A`=/FE<4I4m115U:@`AC@3X4HU1715i=
APAbH5D3RfYI1;nIPPCPc[L4i]:j1>CB_0CSdL84hm6j0nGA^@CVd[/4i=;21>C=]@CM_ZD4gKVP0mJZ
T`CG[9H4ejbK1=JbV`CF[iL4eZF?1<fXT`?>YHh4cZF;1<NOR0C6VX@4^Xmg19Y]F@=mF4D4DcXb140a
:0@i;Rh4@S@^13T^;P@Z7Ql3;b@V14Df<PA5=2`4k?Sg8n?_kaGoool001CooolOhno_1;j`Z@AVDd`4
HU170faID`ATCd44FDY315=0>PARD4L4GTe6179PE@>;JUT4_iV21>3>]`CVd[X4i=:l1>?A`PCSdKX3
iM6i1>KB^`CTd/84i<fe1=fnY@CM^J03eZZC1=N/UPCG[9/4e[:K1=J_U`CFYHl4cJRC0ljUSPC>YH/4
ain81<JJQ0BjSgL4VVeI0geHA@AC>S84@34X13T^;PA2=2h4>Bh^12XN7`<_92H4ACHb14Dd;0C/n?LS
hno_5Oooo`005?oooaoSknl4_[2Y16ICC0ARD4L3K5UC16A?@@AIBT<4Dd0j169@A`ANCDH4LV1E0h]Z
F@BoVH84h<jg1>KB^PCTd[`4hm721>?A^P?UdKT4i]:k1>CB`PCTcKD4gKjU1=fiX0?FZY<4ejbF1=N/
V`CF/Y/4eZnG1=JUS`C=Z9<3cZF>1<jUR`C7WhP4aYZ41;Z?M`BJKET3OEQ515<j<PA0<BP4>Bh^148d
;P@i;Rh4:QhO0blT9PA5=S84AC@/1>chmb?SknlEoooo000Doooo7n?_k`C0/J84MV=L16AFD0=RDT/4
J5A=15<o?0AFACh4EdU216EFD0AMBch3KeI81:B2K0C=ZXh4h<V`1=k<]0CVdKT4i]:j0nGA^@CLbK84
gL^c1>K>]@CN]9`4ej^C0mJ`T`C=Xh`4cJ^D1<j[T`CFZY<4cZ:;1<nRS0?>VhP4aj681<BMP0BjR6h4
/H=Y181LB0=G>c84AcP`13T^9PP`9BH491lO128N7`=1=344B3Xb148c;2OSknlEoooo000Doooo7n?_
k`C0/J84MV=L16AFD0=RDT/4J5A=15<o?0AFACh4EdU216EFD0AMBch3KeI81:B2K0C=ZXh4h<V`1=k<
]0CVdKT4i]:j0nGA^@CLbK84gL^c1>K>]@CN]9`4ej^C0mJ`T`C=Xh`4cJ^D1<j[T`CFZY<4cZ:;1<nR
S0?>VhP4aj681<BMP0BjR6h4/H=Y181LB0=G>c84AcP`13T^9PP`9BH491lO128N7`=1=344B3Xb148c
;2OSknlEoooo000Doooo7n?_k`C0/J84MV=L16AFD0=RDT/4J5A=15<o?0AFACh4EdU216EFD0AMBch3
KeI81:B2K0C=ZXh4h<V`1=k<]0CVdKT4i]:j0nGA^@CLbK84gL^c1>K>]@CN]9`4ej^C0mJ`T`C=Xh`4
cJ^D1<j[T`CFZY<4cZ:;1<nRS0?>VhP4aj681<BMP0BjR6h4/H=Y181LB0=G>c84AcP`13T^9PP`9BH4
91lO128N7`=1=344B3Xb148c;2OSknlEoooo000Doooo7n?_k`C0/J84MV=L16AFD0=RDT/4J5A=15<o
?0AFACh4EdU216EFD0AMBch3KeI81:B2K0C=ZXh4h<V`1=k<]0CVdKT4i]:j0nGA^@CLbK84gL^c1>K>
]@CN]9`4ej^C0mJ`T`C=Xh`4cJ^D1<j[T`CFZY<4cZ:;1<nRS0?>VhP4aj681<BMP0BjR6h4/H=Y181L
B0=G>c84AcP`13T^9PP`9BH491lO128N7`=1=344B3Xb148c;2OSknlEoooo000Doooo7n?_k`CJgn04
Mf5G16QID`=TE4d4IeYD15m<?`A?>cH4GE5;15U;@`AYFE83FD@l17MQD`BLNF@4c9Qm1=bgW`CP_J<4
hL>]0n38/@CPb:h4gl>[1=jlXPCBYh/4ci^10m6OP@C@Xhd4cif71<nMQ0C?Y8d4cZ:41<NJQ0?6Uh04
_i1h1;F@N0BNLel4REU516a7?0==>304>BhV134V9P@`9BD4:AhO124N7`@[92D3>S0[13``:0A4:QTW
hno_5Oooo`005?oooaoSknl4f]oP17MQE`AXFE<3I5A=16MJE0AOC3l4Cc/f15eAB`AIBd<4JEUB0eU4
?0AgHE<4W7UT1<bHO@CL]il4h;fS1>73[@?Pb;44h<R^1=o3Z`CN_:84dZN;1<nKP@?AWh44d:>=1<nM
Q`C?WH@4cjB=1<jRQ0C7VX@3aYN01;n@N0BeT7P4WW=O18UIA@A/Ac`3CCP`13T^9P@a9RH4<2DU12TN
7`@Q7Ql4:b@U0cX`:`@l<2P4A2XI9n?_kaGoool001CooolOhno_1=[Oh0AgHEL4J5UC0fADC@AWFU@4
Gd`o14lk=PAMDD/4FD]316UIDP=IA3`4Mf5C19aiI0C<V7d4g;NO1>2mX`CQ`jd3h<Ra1>38[PCO`j/4
g[bR1=:WR`C?Vh43dIn11=2SS@C?WHL4cif41<nTS@C>XX@4aiZ40lJGP0BoT7P4]I1h19icG`B9FDD4
K4Ll0ddh<0@i;RH4<BHV130U9@@Y7Ql48AhO12/T9@<j<2/4?30X14@Z6BOSknlEoooo000Doooo7n?_
k`CJgn04Mf5G16QID`=TE4d4IeYD15m<?`A?>cH4GE5;15U;@`AYFE83FD@l17MQD`BLNF@4c9Qm1=bg
W`CP_J<4hL>]0n38/@CPb:h4gl>[1=jlXPCBYh/4ci^10m6OP@C@Xhd4cif71<nMQ0C?Y8d4cZ:41<NJ
Q0?6Uh04_i1h1;F@N0BNLel4REU516a7?0==>304>BhV134V9P@`9BD4:AhO124N7`@[92D3>S0[13``
:0A4:QTWhno_5Oooo`005?oooaoSknl4gn[Z1:6>Q0ARCTL3IEE>169BC0ANDDT4E3hl15a7>`ATE4h4
HeQA0fMHDPAKCDL4MFEJ18EZFPB[NV84`9J51;RCO@?;VX04cjZC1<jYSPC9W8H4_H]^1:AgGP>aPF@4
`HEY1<RFN@C9V7`4aXae1<><L@C6SF`3_hed1;64L0BULEd4SEe816e4>`AB>303?BlW13<V9P@Z7Ql8
8AhO120M7P@e<2/3A3Hb138Z8PCKg]hWhno_5Oooo`005?oooaoSknl4gn[Z1:6>Q0ARCTL3IEE>169B
C0ANDDT4E3hl15a7>`ATE4h4HeQA0fMHDPAKCDL4MFEJ18EZFPB[NV84`9J51;RCO@?;VX04cjZC1<jY
SPC9W8H4_H]^1:AgGP>aPF@4`HEY1<RFN@C9V7`4aXae1<><L@C6SF`3_hed1;64L0BULEd4SEe816e4
>`AB>303?BlW13<V9P@Z7Ql88AhO120M7P@e<2/3A3Hb138Z8PCKg]hWhno_5Oooo`005?oooaoSknl4
gn[Z1:6>Q0ARCTL3IEE>169BC0ANDDT4E3hl15a7>`ATE4h4HeQA0fMHDPAKCDL4MFEJ18EZFPB[NV84
`9J51;RCO@?;VX04cjZC1<jYSPC9W8H4_H]^1:AgGP>aPF@4`HEY1<RFN@C9V7`4aXae1<><L@C6SF`3
_hed1;64L0BULEd4SEe816e4>`AB>303?BlW13<V9P@Z7Ql88AhO120M7P@e<2/3A3Hb138Z8PCKg]hW
hno_5Oooo`005?oooaoSknl4gn[Z1:6>Q0ARCTL3IEE>169BC0ANDDT4E3hl15a7>`ATE4h4HeQA0fMH
DPAKCDL4MFEJ18EZFPB[NV84`9J51;RCO@?;VX04cjZC1<jYSPC9W8H4_H]^1:AgGP>aPF@4`HEY1<RF
N@C9V7`4aXae1<><L@C6SF`3_hed1;64L0BULEd4SEe816e4>`AB>303?BlW13<V9P@Z7Ql88AhO120M
7P@e<2/3A3Hb138Z8PCKg]hWhno_5Oooo`005?ooob?Sknl4dM3D16aJC`=PE4d4HEI@165AB`A2>344
EDI216QHC`AWFU@3LVEN16aPFPA[HEP4MFQN185YFPB5HUH4PF1@0gmPE@BFIe<4XWaW199^H0B6IE/4
SV9@0hYPB0BDIU44ZGIN1:imH@BdNeh4[7aS19]ZDP>QLEh4W6QE18EOCPAW@cX4GdDl13h_9`<i;RH4
<2DU12PN7`@P7Ah47adN13P`:`@`:R/3CEA@13X[8b_SknlEoooo000Doooo8n?_k`CAd=@4K5Y?0f1D
C@AQEU04HE5;148h<@AEAT84J5Q?16MJE0=bIEh4K61J16]QF0AeJ5h4PFUJ18EREPB1H503Of1E19IW
D`BRO6L4TViP18IUF`B>HU03RV1819AVD@BYMUh4[WeQ1;AkGPB/O6<4VfYB0j5aGPBLJ5D4QEm>16M3
>PAOAC`4?RlW0cT^9P@`9BD4:1hO120M7P@O7Ah4>30[130Z:`==E504>R/S:n?_kaGoool001CooolS
hno_1=7@e0A/FTl3H5A=165FD0AQDD/4@SPa15E6@PAXF4l4IeYD0g9UGPA/H5X4Jf5H17EXGPB1JEX4
QF9F185PD0=oH5D4UVMC1:9lI`BBKV04QVEK18iRD0>:H4P4U6IA1:UfGPB^OF44]7]N1:alH`BKJU83
XG5N19aXE@B5Gdh4Id<j15m5?0@n;bL3>BhV130U9@@X7Ql481dN11lM7P@h<2/4<2X[0deDD0@j:b<[
hno_5Oooo`005?ooob?Sknl4g^SY18I^JP=QDT/4IEE>165DCPAODD/4DD]616=HD@AbIEh3K5aE175P
F0AeFU<4Of=C17QMC0A/FU04GdQ10fYBB@AP@3T4LUI<17AJD0ATCdP4H48k0fI9@0AV@SP4KD<j17eH
A0AlEd<4NEE217E8?0=_ACX4JDHl16I2>@A;>S44?BlW13HX:0L`9BD48AhO120M7P@h<3D4>30[1597
@P<F5QH4Tgmg:n?_kaGoool001CooolShno_1=kXj@B6KVX3HE9;16EECPAQE4h4Ge5;155;APASF544
LVEN0faLE@AaH5P4MEYC17mSD`AhGD`4K5Y@15m8@@=ZDTT4H40i179FC0AdFU04I4m81612>`=VBD04
IT8h16e3>PAmF4@4O5M317UE@PAeB3`3KdDj16U6?0AV@ST4BcXa13d_9`@f:2P7<2DU124N7`@P7Ah4
>30e13P`:`ABAd835QHF19=oMb_SknlEoooo000Doooo8n?_k`CNj>T4QViZ0f5BB`AUEDh4HEA>15mA
B`AABdH4HeQA179UGP=/G5D4LF1H17EJD`AoHe<4N5e<16aJD0AOB443JU991610>@AbET`4M5Y@16A?
B0AP@S/3ITU016I2>0A]@cX4OEQ417aG@`AiED84MDPl0fm5>PAYAS`4IT8i14/j<@@m;bL4=RPX1c0U
9@@Q7Ql481dN13P`=@@h<2/4DTM20aHF5PBCOgL[hno_5Oooo`005?ooob?Sknl4g^SY18I^JP=QDT/4
IEE>165DCPAODD/4DD]616=HD@AbIEh3K5aE175PF0AeFU<4Of=C17QMC0A/FU04GdQ10fYBB@AP@3T4
LUI<17AJD0ATCdP4H48k0fI9@0AV@SP4KD<j17eHA0AlEd<4NEE217E8?0=_ACX4JDHl16I2>@A;>S44
?BlW13HX:0L`9BD48AhO120M7P@h<3D4>30[1597@P<F5QH4Tgmg:n?_kaGoool001CooolShno_1>;]
k@C6`/P3IE9;165BB`AUEU04HE9;16YNF0APCdL4LF9K0fIDB`AYFU<4L65G16aFD0A`E4/4J59915a<
A@=ODD/4DT0o15=6@0AI@3T4FD4i14/h<@=3=Rl4BSL`15<k=@AF>cD4CSP`14li<0A?>303ES/e14/e
;`A9=Bl4?2lW13L^9P@`9BD3;R@U224N7`@[92D4?cTf14`i=P@R6Q83@cXb;n?_kaGoool001CooolS
hno_1>;]k@C6`/P3IE9;165BB`AUEU04HE9;16YNF0APCdL4LF9K0fIDB`AYFU<4L65G16aFD0A`E4/4
J59915a<A@=ODD/4DT0o15=6@0AI@3T4FD4i14/h<@=3=Rl4BSL`15<k=@AF>cD4CSP`14li<0A?>303
ES/e14/e;`A9=Bl4?2lW13L^9P@`9BD3;R@U224N7`@[92D4?cTf14`i=P@R6Q83@cXb;n?_kaGoool0
01CooolShno_1>;]k@C6`/P3IE9;165BB`AUEU04HE9;16YNF0APCdL4LF9K0fIDB`AYFU<4L65G16aF
D0A`E4/4J59915a<A@=ODD/4DT0o15=6@0AI@3T4FD4i14/h<@=3=Rl4BSL`15<k=@AF>cD4CSP`14li
<0A?>303ES/e14/e;`A9=Bl4?2lW13L^9P@`9BD3;R@U224N7`@[92D4?cTf14`i=P@R6Q83@cXb;n?_
kaGoool001CooolShno_1>;]k@C6`/P3IE9;165BB`AUEU04HE9;16YNF0APCdL4LF9K0fIDB`AYFU<4
L65G16aFD0A`E4/4J59915a<A@=ODD/4DT0o15=6@0AI@3T4FD4i14/h<@=3=Rl4BSL`15<k=@AF>cD4
CSP`14li<0A?>303ES/e14/e;`A9=Bl4?2lW13L^9P@`9BD3;R@U224N7`@[92D4?cTf14`i=P@R6Q83
@cXb;n?_kaGoool001CooolWhno_1=oWj0>:Jf<4I5I@16EFD0ATE4d4FDe617ATG@AUFeD3Ie]D15Y;
@`A^EDP4I4e3165@B0AMCDH4CT150eM;A0AH@T44D3/f14Th?PQ3=Bl3>BhV13dd;P@o=2h4@cD_13d_
9`@c9RH4>RhV0dDd;P@m;bL4<bHV13T^9P@e;B`4<2DU0b4N7`@^92D4=2l[13dh=@A4=S84<BPP134P
63;SknlEoooo000Doooo9n?_k`COinP3RV]S16AFD0AUEU04I5A=15U=APAdI5d4IE]E0fMKE0AJBd<4
KUE816A=@`AQD4P4GDe614i0A@=GBd@4F491150k=PA9>3h8@cD_0cT^9P@m=2h4?c@^14<e;`@m;bL4
<bHV13X^9P=5=2h4?BlW13<V9P@i;RH4=Bd/130U9@<Q7Ql4;R@U13@_:`@m>3D4A3Hb134X80@a81Pb
hno_5Oooo`005?ooobOSknl4gnOX0hY[H`ATEU04IEI@16ADC@AICDH4M6AM16EKE@=WFe@4FT]316iE
B0ATCD<4HE1815e=APA>@4D3Ed]415Q2@@A@>cH4BCPn24<e;`<i;RH4?C@^13ld;PA3=Bl4?BlW13<V
9P@j;RH3AC@^13d_9`@c9RH4>BhV13D];0@`9BD38AhO12hT9@@d;b/4?CPe14@f<P@a:204<B0H<^?_
kaGoool001CooolWhno_1=oWj0>:Jf<4I5I@16EFD0ATE4d4FDe617ATG@AUFeD3Ie]D15Y;@`A^EDP4
I4e3165@B0AMCDH4CT150eM;A0AH@T44D3/f14Th?PQ3=Bl3>BhV13dd;P@o=2h4@cD_13d_9`@c9RH4
>RhV0dDd;P@m;bL4<bHV13T^9P@e;B`4<2DU0b4N7`@^92D4=2l[13dh=@A4=S84<BPP134P63;SknlE
oooo000Doooo9n?_k`CQjn`3/j6P16IABPAYFE<4I5A=16AFD0AJE4h4KEaF0fIDB`AIB444EdDn15<j
<@AGBD84DCln150o?P=5=S44BCPn13/_<0@f9bL4>Bh`13L^;P<a9RH4=Rd/134V9P@h;Rh4<BHV13D]
;0@h<B`3=Rd/13<V9Q0R7Ql3=2//130Z9@@_92H4@bhW13Xh<0@b8QTfhno_5Oooo`005?ooobOSknl4
hN_/0k>QX0AVDDX4JEUC16ADC@ATEU04FUA>16eLEP=VE4/4FDQ115M5?PAC>S44EdU2154o?PA@?ch3
ACHa14Th?P@k;c04=RLW13T^<0@g;Rh3<BHV13H];0@a9RH4>2h^134V9P@e;B`4>34/0cH];0@c9RH@
8QhO0c@[;0@`:RD4;b@V14<^9`@j>304<R8I=^?_kaGoool001CooolWhno_1>7[k0>cXJ04IU5:16UI
D`ATE4d4I5I@15YDCPA]G5H3IUA;15U8@@AGACh4DcXa15M9@PAA?ch4D3ln0dDf<@A9>3h4>bl`13HW
9`@i;S04=bh^0c4V9P@f;B`4<BHV13P^;P@a9RH4=Bd/13Pa;0<f;B`4<bHV428N7`<d:b`4<2XU12lT
9PA3;RL4>SP`138R6CKSknlEoooo000Doooo9n?_k`CQjn`3/j6P16IABPAYFE<4I5A=16AFD0AJE4h4
KEaF0fIDB`AIB444EdDn15<j<@AGBD84DCln150o?P=5=S44BCPn13/_<0@f9bL4>Bh`13L^;P<a9RH4
=Rd/134V9P@h;Rh4<BHV13D];0@h<B`3=Rd/13<V9Q0R7Ql3=2//130Z9@@_92H4@bhW13Xh<0@b8QTf
hno_5Oooo`005?ooob_Sknl3f>?R189fL0AKC4D4IEE>169GD0AUFE<4J5eG0fADDPAE?SL4DT<l148f
<0A5=2h4ACPa14Le<0<d9bP4<bHW13T^<0@e;2d4;R@U13H];P<`9BH4=2//130U9PA4=S848QhO13@/
;@@k<bh3=bh^128N7`@Q7Ql49QdN130Z:`@_:R/3<2X[14Lh<`A:@CL4?dU712PK50CKg]hfhno_5Ooo
o`005?ooob_Sknl3f>?R189fL0AKC4D4IEE>169GD0AUFE<4J5eG0fADDPAE?SL4DT<l148f<0A5=2h4
ACPa14Le<0<d9bP4<bHW13T^<0@e;2d4;R@U13H];P<`9BH4=2//130U9PA4=S848QhO13@/;@@k<bh3
=bh^128N7`@Q7Ql49QdN130Z:`@_:R/3<2X[14Lh<`A:@CL4?dU712PK50CKg]hfhno_5Oooo`005?oo
ob_Sknl3f>?R189fL0AKC4D4IEE>169GD0AUFE<4J5eG0fADDPAE?SL4DT<l148f<0A5=2h4ACPa14Le
<0<d9bP4<bHW13T^<0@e;2d4;R@U13H];P<`9BH4=2//130U9PA4=S848QhO13@/;@@k<bh3=bh^128N
7`@Q7Ql49QdN130Z:`@_:R/3<2X[14Lh<`A:@CL4?dU712PK50CKg]hfhno_5Oooo`005?ooobkSknl4
f>?R189cK0AKDT`4GDe516QNF0AWGEL3Kf1J15M<APAFASl4B3Hl13L^;@A5=2h4=bh^0chd;@@h<B`4
=2//230U9P@_92H3<2DV12lT9P@j<Rh4=2//15E=D0@n@D44?S8h0c4V9P@e;2d8=2l[138Z:`A9@Cd3
AC`h14Lh<`ASDDT4AS@R18]UBc[SknlEoooo000Doooo;^?_k`CHhn84PW=/15]BC0AMCDD4J5iH16MM
E`=_H5X4Eda615I6?`A8=S`4=bh]14Dd;P@g;Rh3?S@]13Pa;0@d:b`8<2DV12lT9P<`9BH4;b@V13Xb
;P@d:b`4EDe@13i1@@@n<SP3<BHV13D/;@Pd;b/4<RX[14U1?@=5?3P4AcPc16=AB@A6=284RfE;>^?_
kaGoool001Coool^hno_1=SShPB2Lf`4Fe9<15e=A@AXGUP4IeeG0fmPFPAGC4H4ETHo14Pf?0@g;Rd4
AC@^13L^;P<n=2d4>34/13@[;0P`9BH4;b@V0c0U9P@_92H4>S8^13@[;0AECE04?T5113hb>0<a9RH4
=B`]23@_:`@b:R/4BD4m0dDl>0A7>3<4He5914Hd8PB;ID/jhno_5Oooo`005?ooobkSknl4f>?R189c
K0AKDT`4GDe516QNF0AWGEL3Kf1J15M<APAFASl4B3Hl13L^;@A5=2h4=bh^0chd;@@h<B`4=2//230U
9P@_92H3<2DV12lT9P@j<Rh4=2//15E=D0@n@D44?S8h0c4V9P@e;2d8=2l[138Z:`A9@Cd3AC`h14Lh
<`ASDDT4AS@R18]UBc[SknlEoooo000Doooo<^?_k`CFh>04PVmY16ALE@AIBd<4JEeF0g=UGPA]GeT4
FDXm15A4?P@n<c04=Rd^13<V9P<f;BH4=bh^134V9P@`9BH4=2//12hT9@<d:b`4;R@U12lU9PA=BdT4
Ace616ERI@AQGed3CdE914M6A0A7@3`4?3<]14Tn>@A7?CT3H5A=161?AP@b:204L4`k?^?_kaGoool0
01Cooolbhno_1=KPh0B2KfT4I5aE15U;@`AYGEH3LfEN16eOF@AIBSd4E4@n13hc<0@f;Bh4<bHV0cH]
9P@g;Rh4<BHV130U9P@d:b`4;R@U0c@[;0@^92D4;bDV14e;B@A7?DH4IF9U165OG@=?ADT4AdI414M0
?0@l<bd4BChi14Lm>@=PE4d4H4m6138X80A`C3/nhno_5Oooo`005?oooc;Sknl4e^3P189_J@ATG5D4
FD]316UMEP=cIEh4KEmI15U:?@ADA3h4?S<`13H];P@c9RH3=RdV13L^;P@a9RH4<2DV13@[;0@^92D3
=2//12hT9@@_9BH4CD]914LmAPAUHVD4HEmM0dm5B@A7AT@4Ad0l13`c;@A9?ST4Acdi0f1DC@APCdH4
<RPP171<>ckSknlEoooo000Doooo<^?_k`CFh>04PVmY16ALE@AIBd<4JEeF0g=UGPA]GeT4FDXm15A4
?P@n<c04=Rd^13<V9P<f;BH4=bh^134V9P@`9BH4=2//12hT9@<d:b`4;R@U12lU9PA=BdT4Ace616ER
I@AQGed3CdE914M6A0A7@3`4?3<]14Tn>@A7?CT3H5A=161?AP@b:204L4`k?^?_kaGoool001Cooolb
hno_1>C`l0CQjnX4PVUM16mTG@AODdd3JV9L17IXH@AaI5d4Ed@k1552?0A>Ad84A40m0c``;0@j<R`4
=B`]13@[;0@^92D4<2DV0cTa=`@e;2d4>34/13@/;@AGD4X4G4i>14Hf=P=>?cH4B3Xd14@e=@A<>344
BSli15Y8?0=RFTl4FeaA16Y6=0CSinHnhno_5Oooo`005?oooc;Sknl4i?3`1>7[jPB2JEd4KfAM15mC
C@=ZHU`4MVQQ175TG@AGA3/4DD8l14i7@PA4@3d3?30/13Xb;0@e;2d4=2//12hT9@@`9BH3>C4g13D/
;@@h<B`4=2`]15M@BPALCTh4ASHf0dho=PA8>S@4A3De14`h<@A:?cT4FTPl0f9JC`AKG544JTHd1>?W
iSkSknlEoooo000Doooo<^?_k`CTl?04hN_Z189YG@A_I5d4Ge==0fYRG0AfJ644LFAM15M4>`AA@S`4
CTM214A0?@<l<2`4>S8/13D/;@@d:b`4;R@U130U9P<i<CL4=B`]13Pa;0@d;2d4Ee1:15a>CPA6=SH3
CSlf14Pj=0A4=CD4C3Pa14Xo>@AJB3`3HUY?15]LD@AZAS@4hnOV?^?_kaGoool001Cooolbhno_1>C`
l0CQjnX4PVUM16mTG@AODdd3JV9L17IXH@AaI5d4Ed@k1552?0A>Ad84A40m0c``;0@j<R`4=B`]13@[
;0@^92D4<2DV0cTa=`@e;2d4>34/13@/;@AGD4X4G4i>14Hf=P=>?cH4B3Xd14@e=@A<>344BSli15Y8
?0=RFTl4FeaA16Y6=0CSinHnhno_5Oooo`005?oooc[Sknl4en7O17eYG0AUDd/3JUYD17a`J@AjLF/4
LfIO1551>`A??C`4FD4i0eU?B@A;@cd4=Rd]130U9P@o>3d4?3Dk0d<o>`A1>D44CDQ513/c>0A@CT`4
FDm=15mABP=:A444Bd<m14e7@PA=C4P4DDI115mKD@=2>2L4OUU01<S4c4;SknlEoooo000Doooo>^?_
k`CGhMl4OFUL16ECB`=ZFU@4O71Y17YaJ`AcIUl4DD4k14lm?0AI@CT3FDm914]3?@@f;Bd4<2DV13lh
?@@l=C/3@clk144i@@A=B4D4>c<h151>C0AICdd4Ge5:0dY4@@A;@cd4CDM214e<B0AAAT44Ge]A0d8h
9`AnFD04b<C<@^?_kaGoool001Coooljhno_1=OQg`AmJE`4IE=;0fYJE0AlL6T4NW5[17=VG`AA@C/4
Ccdl15U1>@=ICdT4Bd<m13H];@@`9BH4?cPm13`e>`=3?c/4@CU114e8A@@k<cP4D4i<15U?C@AODDX3
BTA114]3?@A=Ad84CDa81556@@AOFe43@SPW17iI@0C8a<a2hno_5Oooo`005?oooc[Sknl4en7O17eY
G0AUDd/3JUYD17a`J@AjLF/4LfIO1551>`A??C`4FD4i0eU?B@A;@cd4=Rd]130U9P@o>3d4?3Dk0d<o
>`A1>D44CDQ513/c>0A@CT`4FDm=15mABP=:A444Bd<m14e7@PA=C4P4DDI115mKD@=2>2L4OUU01<S4
c4;SknlEoooo000Doooo?^?_k`CGh^44LFmM0emFD0AYFU<4OV]T181kN`AhKFH4GUQD15UEE@=HBDL4
G5ID15iKFPA8Bd/4AD1114m9E0=CBT`4GUaL15A=C0ASDdd4E4m?17=OE`AWDTd3Ie9516=FD0AVFU44
Jf=H171HB@A9?SD3RfA:1>?WiTKSknlEoooo000Doooo?^?_k`CGh^44LFmM0emFD0AYFU<4OV]T181k
N`AhKFH4GUQD15UEE@=HBDL4G5ID15iKFPA8Bd/4AD1114m9E0=CBT`4GUaL15A=C0ASDdd4E4m?17=O
E`AWDTd3Ie9516=FD0AVFU44Jf=H171HB@A9?SD3RfA:1>?WiTKSknlEoooo000Doooo?^?_k`CGh^44
LFmM0emFD0AYFU<4OV]T181kN`AhKFH4GUQD15UEE@=HBDL4G5ID15iKFPA8Bd/4AD1114m9E0=CBT`4
GUaL15A=C0ASDdd4E4m?17=OE`AWDTd3Ie9516=FD0AVFU44Jf=H171HB@A9?SD3RfA:1>?WiTKSknlE
oooo000Doooo?^?_k`CGh^44LFmM0emFD0AYFU<4OV]T181kN`AhKFH4GUQD15UEE@=HBDL4G5ID15iK
FPA8Bd/4AD1114m9E0=CBT`4GUaL15A=C0ASDdd4E4m?17=OE`AWDTd3Ie9516=FD0AVFU44Jf=H171H
B@A9?SD3RfA:1>?WiTKSknlEoooo000Doooo@^?_k`CPj^/3/Jfe179XI@A/H5X4K6EV17n0Q0B6O7L4
QGYc0h=lMPAYI6D4IFQW17YcN0AjK6@4J5eK0eaAE`ANCTP4KEeL16]ME`AUEU04MEa@17EMD`=dGE@4
MF9G16iIC@B6MV`4QEm415Dj:4gSknlEoooo000Doooo@^?_k`CPj^/3/Jfe179XI@A/H5X4K6EV17n0
Q0B6O7L4QGYc0h=lMPAYI6D4IFQW17YcN0AjK6@4J5eK0eaAE`ANCTP4KEeL16]ME`AUEU04MEa@17EM
D`=dGE@4MF9G16iIC@B6MV`4QEm415Dj:4gSknlEoooo000Doooo@^?_k`CPj^/3/Jfe179XI@A/H5X4
K6EV17n0Q0B6O7L4QGYc0h=lMPAYI6D4IFQW17YcN0AjK6@4J5eK0eaAE`ANCTP4KEeL16]ME`AUEU04
MEa@17EMD`=dGE@4MF9G16iIC@B6MV`4QEm415Dj:4gSknlEoooo000Doooo1>?al0CSl?11hno_1=OR
h`AQEeh4FEQ:16a^MPBFTI04RXb90hB3O@B7P7X4Rh>018anM`B7NgL4M6eX0gQ_J@AWHf<4HUeE16]T
G`AdKFP4KfEM181VFP=lFe84R7MW17QKB0AN=bL4RgMgDN?_kaGoool001Coool4ho7`1>?`l47Sknl4
en;S165GGPAIF4X4K6if19JAT0B:S8T3Q8=m18N0NPB;Ph04S7ig18MkM`AdKFP3N6mY16MSH`ARGED4
JfAO17A]J0A_IEd4P6IJ0gaKDPB8MfL4N5]815hg9`B;MgMAhno_5Oooo`005?ooo`CSlO04ho3`@N?_
k`CGh^<4HEMN15UHBPA/KWH4UY6@18Z<R@>4Pgd4Qh1j18^3P0B<OWL4Qg]g17A]J0=hKfT4If=S169M
E@A[I5l4M6eX16mUG@B0IUX3O5]B18QgI`AhFdP4GSLW18]gMe7SknlEoooo000Doooo1>?al0CSl?11
hno_1=ORh`AQEeh4FEQ:16a^MPBFTI04RXb90hB3O@B7P7X4Rh>018anM`B7NgL4M6eX0gQ_J@AWHf<4
HUeE16]TG`AdKFP4KfEM181VFP=lFe84R7MW17QKB0AN=bL4RgMgDN?_kaGoool001Coool4hnKV1>?W
iTWSknl4h^g]1<K9e0AWI7H4SX630jfZ]PBDRhT4Sh9d18V0O0B?Ph04V8=n0iN3O0B>OgP4Uh=k18Eg
K@B9LfH4TWa^175[F`=PET@4D3`e1;NZ/UWSknlEoooo000Doooo1>?ViPCSinI9hno_1>;]k@C6bM@4
IfAf18j1P`>]Z[H4U8^918n2M0B9P7`4Sh>019R3OP>GPg`4SWmh19N3N`B5Mfd4RG=V199lKPAaJe/3
H5I4150l=@BgZ[9Ihno_5Oooo`005?ooo`CSi^H4hnOVBN?_k`CRkNd4a/WD16MTMPB>PH<3[JZf19B;
R@B?PW@4RH1l18n3P0BHPgh3Uh=l18ioN0BGPg/4QGM]18UcIPBBO6h4LF]K0f1FA0A@?3D4]jZbFN?_
kaGoool001Coool4hnKV1>?WiTWSknl4h^g]1<K9e0AWI7H4SX630jfZ]PBDRhT4Sh9d18V0O0B?Ph04
V8=n0iN3O0B>OgP4Uh=k18EgK@B9LfH4TWa^175[F`=PET@4D3`e1;NZ/UWSknlEoooo000DooooHN?_
k`?RkNh4d]CV1>3Rh`Be/L@4MWF717IcP`=]Ieh4KF9I16eQF0A/H5P4HUM=15Y7<`AWG4X3hnOVHN?_
kaGoool001CooomQhno_0n;]kPCBe>H4h>;S1;Faa0AfMHL4MW>30feWGPA]HUT4KF5H16aPF0AREdd4
FTLc16MLBP?SinIQhno_5Oooo`005?ooof7Sknl3h^g^1=;DiPCPh^<4]K7417IeQ`AfLh<3KFMN16eR
F@A]HEP4K61H169GC@AJAc<4Iea:0n?WiV7SknlEoooo000DooooHN?_k`?RkNh4d]CV1>3Rh`Be/L@4
MWF717IcP`=]Ieh4KF9I16eQF0A/H5P4HUM=15Y7<`AWG4X3hnOVHN?_kaGoool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool009Woool30000Q?oo
o`00W?ooo`030000oooooooo087oool007_oool400000_ooo`<00003oooo100000?oool400000_oo
o`<00003oooo0`0000?oool20000O_ooo`00Noooo`030000oooooooo00Goool01@000?oooooooooo
o`000005oooo00@0003oooooool00002oooo00<0003oooooool00oooo`040000oooooooo0000Pooo
o`00O?ooo`030000oooooooo00?oool300000oooo`030000oooooooo00;oool010000?ooooooo`00
00;oool400000_ooo`040000oooooooo0000Poooo`00OOooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool00_ooo`<00003oooo0P0000Coool40000P_ooo`00Nooo
o`040000oooooooo00000_ooo`040000oooooooo00000_ooo`040000oooooooo00001Oooo`030000
oooooooo08goool007coool200001?ooo`<00003oooo0P0000Goool20000Soooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(315) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9BEA393
C09E8AC2A091C2A497C2A295C2A497C2A699C2A699C2A699C2A295C2A08EBE9B87BC9581
B78975B58572B0806DAE7F6CAE7F6CAE7F6CAE7F6CAE7A67A97860A77864A77860A77864
B9A49CC2BBB9C2BBB9C2BBB9C2BBB9C2B6B5C2B8B7C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BAB8C2BEBDC2BBB9C2BAB8C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BAB8C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9BFA596
BD9B8AC2A08CC2A49AC2A295C2A497C2A699C2A595C1A597C4A597C49E8DBF9B86BB957F
BB8B76B68571B1806CB1816EAE7F6CAE7F6CAE7C68AE7C68A97864A77862A77860A78171
B99788C2BBB9C2BBB9C2BBB9C2BBB9C2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2B7B6C2B4B3C2BEBDC2B7B6C2B5B4C2BBB9C2BAB8C2BEBDC2BAB8C2BEBDC2BBB9
C2BBB9C2BBB9C2BBB9C2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C1A695
C5A391C2A093C2A391C2A699C2A093C2A89AC1A38FBA9C8AC39780BD917FB88F78B38C78
AE8370AE7F6CAB7A68A77865AF7E6AAF7E6AAF7C68AF7862AC7867A77865A77864AD907F
AD9992C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BAB8C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2B6B5C2B8B7C2BBB9C2BBB9C2BBB9C2B7B6C2B5B4C2B7B6C2B5B4C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9BFA393
BD9E8CC2A08EC2A093C2A396C2A597C2A091BF9D90B09584A68C7CB58176AC7C6AAD7F6C
AD8574AD8572AB7C6AA97E68A77865A77865A77865A77864A97B65A57664A77865B9A49C
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2A596
C29B8AC2A093C2A096C2A093C2A093C2A090C2A190C29E92BF9A8BBC9181BE847CB4826E
B47E6FB27A70B37E71A56B60A67765A6806EA57460A97865A97A67A97C68A97D6BB69E96
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2A898
C2A08CC2A08EC2A08CC2A096C2A093C2A195C2A093C2A89AC2A699BF9A8BBA9280B98678
BC8979B98774B58172B77F72AB7265AE7669AB8579A77460AF7865AC7865AF8879B59B8C
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BAB8C2BEBDC2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9BDA79ECCC0B1
C2A08EC2A08CC2A091C2A091C2A195C2A093C2A699C29E92C2A195C2A295C2A090BF9882
BA8D7DB9897AB98977B27E70B27F6DAB7A67AC7D6BAC806FA97865A57865B5968CC0ABA4
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2B7B6C2B5B4C2BBB9C2BBB9C2BAB8
C2BDBBC2BEBDC2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9937A6EDFC8BAB58F82
C2A091C2A090C2A08BC2A08EC2A497C2A295C2A393C2A99FC2A597C2A597C2A091C29D8E
C1907FC1907ABC8979B78770B37A6CB37F6CAB7664A57865AC7D6BAB7665B39A92BDB0AE
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2B7B6
C2B2B1C2B5B4C2BBB9C2BBB9
C2BBB9C2BBB9C2BAB8C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9BAAEB05E2E28B59E8BBD9B85
C2A193C29D90C2A195C29D90C2A396C2A699C29E8FC2A08EC2A595C29991C1A18AC29E86
C49B89BC8C7DBA8979B8806EB5806AAB7B68AC7A63AC7867AA7D69AF826DBFAAA2C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2B7B6C2B4B3C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C3BBBA6A4335A98F905E4044C2A093
C2A391C2A597C2A396C2A597C2A093C2A396C2A99CC2A295C19E8BC49387C18C7EB78774
B88874BD8C78BA8C75B08473B17C68B37E6AAB7C67A67862A57865A97B68B59D95C5C8CA
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BAB8C2BBB9C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9724A39C8BBB55E423ABD9B85C2A091
C2A093C2A093C2A091C2A096C2A093C2A195C2A093C2A597BE8478BC8D7DBA7C6EBA7D6D
B57A6AB59177B3826CB3826AAE7865AC7B64B17867AE7865A97862AC7765B28C79CAC6C9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BAB8
C2BEBDC2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9BAAEAE96847E644A42C2A597C2A08EC2A091
C2A093C29E8EC2A190C2A18FC2A398C2A396C29D92C2A193BE7B72BA635AB8554CB9635F
B35950B96960AE7964AF7B66AF7862AC715FAC7B64AE7865AB7864A9725DAB7967B29080
CCDAE1C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2B7B6
C2B5B4C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB963443DE3C8BAC0A39AC2A093C2A091C2A091
C2A091C19989C49782C5A18DC29B8DC29C8BC1837EC27C6EC0847BB35142BC6C62B3514D
AE443BB24F43B36257A56C5DA77B64A77256AA7765B17867AE7865AE7664AE7664AE816E
BCA59DC2C1C3C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BAB8C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9AC99999881736B5A56BD9B8AC19C84C5A795C29D8B
C29C89BC967CBB8572C79E8FBF8172902C18E6AA97BA6059B36F65A26055984639AA8068
AB634FAB4E499B3F30BC5044A57864AA7758A9735DA97D67B07B66AB7464AE7B68AE7865
B79280CCCBCAC2C1C3C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BAB8C2BEBDC2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9674742BC998DA58072C2A08CBE9484C0A293C2A597
C29684B77B5FB1765F91241ED9ACA498312D711D15B26759B56252BD8D80BB8278AB4E47
91503C8958477E3F32722F1CBF5643A87E63AC6F59B07E6CB0816CB28068AB7665AE7C68
AE7D6AB79C94CABBADC5C1C0C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9BDB4B7502A249D8476C09E8DC2A091BF9784BD9184C2A093
BF8A76B17755A84A36771C0F9B655FB2AB9CC4ABA2C5C4C1C2AFA9C2B0ACBC988CC2B0A1
BF9B8AB0A09D7D5953613A35582318B95B43AF826AB6806BB78A79B2806CB07E68AE7360
AE7D69AC9690B2A3ADC6BFC6CCC8C0C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9937A6E6A3E38A7868366524EBD9B88C29C87C2A18BC2A694C2A093
B98170A97561925442731A1B712927B47566BA8676C09487C7978DC09C84C07966B96D5D
B97C6CBF9F88B87D699D72677552475B0F05BF7462B1856BBA8F7BB78972B07D6CAC7967
B17765AB8574A69C979B8689BFB8BCC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BAB8C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9BDB1B3351C153F1D1889645EA2796BC29E8AC29687C1987FC59986C2998A
B98C72AF7057C5A494BD9D88C29486BF857FB77E74B2766CB57069B26460AB655EAA4F49
AA4C48A66155AD6C609F594B9049386D261C792B20C08D76BD927AB78B72B07B67A97562
AC7D69AE83707C4D3CE8E6F1AC9CA5C5C1C0C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9B4A5AA6F5A5900020F514346C5A393C29B87C29588BF8983BDA48AC29789
B97D72AB6E5AB08673C5A99EC2A699C29D90C2A396C2A699C29689BE9980BC8C79B78771
B5806AAE7761B2685DB15E559F4B45863A33762E2C91503EB98778BA8971B07B67A97660
AC7464AE7D6A69473F987D75CCC3C5BDB0AEC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9B9A8A5B2A0A5BF9884B98A76BF9C88C5A08CC29B8AC29788C29288C29D88
BB917BAF7665B17865C5A995C5A79DC2A396C29D90C2A497C2998DBE847ABA836FBA8E76
B17D68AC7865AA7157A86E5AA8755AA86C5AA56E5AA77165AE7B62B5836DAE7A63AC7762
AA7B61AF7A694F2D27A28F88B3A395C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C1B8B7C5AE9DC19C89C29D88BDA9A2C79C81BD9E8CC2A190C29E92C2A195C2A396
BF9184B68B74AF7361B48775C0A797C2A99CC29B90C1AA95C5A897BC8E7ABA826FB1705A
B1876CA06C569D7057A16855A36A509E6652A1644EAC7C68B0816EB3806CAE7663A7715F
A77762A97B652C1316978281C8C2CFC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9BFAEA5BDAAA5BC917AB88B74B49484B0908EC2A48FC2A497C2A699C2A699C2A699
C2998DBF867CB47F6BB87A69C3A394C2A497C2998FBF8E84BD9B87BB8E7BB2806CAD705F
A66D5CA06855A16652A16C57A6705AA66F55A06E58A6705DB37A67B37C68AB7664A56F5D
A77761AA7A69391A16523935E0D9D4C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2A898C19E8CB57B62BD9785B28375BD9B88C2918DC2A497C2A89CC2A394C2A699
C2A292C29A84B9846FB58068BD8D80C5A69BC2A595C2A198C29D90BE9384B57F6EB3806C
AC7865A96E5DA0664F9E6253A67260AE7768B17A68B27F6CB0806EAE7665AC7664AC7664
A77460A97D68734D3C391F1D5C433FFBFDFDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2B4AEBF9E8DBD7764B38D73AB846FCA9888C29188C2A091C2A497C2AA9FC2ACA2C2A699
C2A295C19E8BBE9380B48572B88C77BD9B8AC1998BC5AC96C29D95BC997EB57F6CAC7764
AA745FAA775BA06653AB6C53A77362AE796ABA8677B78774B0836FAE806CAB7C68A57862
A97564A98571A4715B8354434A211E61433EC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2A098B9806EAB5E4FA76A5BAC8879B0998CC2A18DC29D8BC2A497C2A699C2A699C2A597
C2A595BE9B8CBD9581B99884C09E8CC2A18DBF9483BD9182C29382B98476AE7560AA6E5B
A36A57A46B54A26C549A6959A67060B08371BA8775B78774B0806DAE7A67AE7565AB7764
A7755DB18071A76E54AA7565BAA29ABFB7B6C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2B6B0
C2A69FB9736AA95D4DAC6E63B38F7DBD9B8DC2A497C2A396C2A093C2A89AC1A594C5A89A
C2998EBEA187BF9580C19984C0A192C2A393C2A59AC2A093C29487B9856CAB7966A36C59
9E6856986857A16A57A77565B38471B78A77B58976BA8673B0836FAE7663AE7564AC7164
AC7462AC7D73A8715FA06D59B59A94D4D5D3C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9BF9F8A
BD8A75A46B52B36B54B5826CB8907EC2A091C2A396C2A89AC2A595C29E91BE9E8EBF9785
C29986C48F85BC957FBC8D7BC09989C2A093C2A08EC2A093C19589BC7A6FAB705FA36C59
A16A58A0705E9E7762AE7D6AB0846FB88874BA8C79B5806EB07C6AAE7A68AC6F5FAC6F5D
A77362AC8571AA6046B18877A57262B9C6CEC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9B78369
773C248D4E3F6B3931C08E76BE9A89C2A08EC2A091C2A093C2A093C29D88BF9884BA9282
B68476B58676BB907CC2A28CBF9F8AC5A394C2A093C2A091BE9689B5876FAC6F63A57055
9F6756A87260A97967AC7867B68373B98574B3846EB68B76B1806CAF7E6AAC7C68A77260
A77164AA7B6BA5684EA96752AF7263B99E92C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2B8B5B68A7E
8046334F2A205E322E987467BE9A8AC19E91C5A396C2A089BD9682C5A08FBC8E7AC39681
C19082BE7D73B9856FB48570C09E88C3A494C2A093C2A090BE9180B27D6BA56B58A16453
9C6A57A26957A87865AE7B67B47D69B48473B17768B17D6AAB7C6AA57664A77865A77260
A77164A7776591513A99492FB17054BCA1A1C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C1A99BBC938A
470E09482019492722A47B6DBA9582C29E8ABD9E8DC2A091B8917EA277649D6E587B5349
6F443A924D36B26D5CA8553DAC5D44D2B7A1C5A69BC2A093BE9384B27A6BA56D559F6B50
9C5F4DA475639F70609772619D7260A77969A77E68B2806CAE7F6CA97A67A37562A87562
AD7464A774658C4F3C803A2A954D3BB7A295C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C3BBBABC9B8BB27D6A
5E322F2A100E3F1A188F786BBD9684BC9783C59E8AC2A08CBF9A89A77A668F6D605B3D32
411F1C52271C70493F9B513D8E4F43986256C09B8CC2A094BE937FB27C699F66519E694B
762111B27E65AA7656A774609E634BB97E6AA37364A67963AF7E6CAC7C689E6F5C9A7361
A47364A3745E86483A8D49379B5246B58C80BFB7B6C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BDBBC2BEBDC2BAB8C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9612119FFD0B4BC8B77
703C32301A223114119E796CBF9C88C2A08CBC9986C4A18CC5A394B8907FB07C6C956C61
4D3A383B2725523B3471554E996356B48C79C0A696C2AA9FBEA08FB2826E9F664F8E5C4A
7C403174433D7C4F412606088F4D3A7B55456E3D2BA6705CA46949B57A5FA077659A6D5C
A471619565546C392C763B30AD6E5CBA9693C5BDBCC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2B4B3C2B8B7C2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB968352F5F342E480300A85F49
4D242D341A163A1A1A887166BC9986C09E8CBA8874BE9D83C7AA9ABF9E8FB78C79AA7867
A1725E9E715E8F5E4A996C56AC7C6AB78876C0A192C2A699BE9586B28671A5675099664E
905546825B536D514B1E0C11451F17623C364A2E2771463685594991634D9C6553987361
A4745F6E3B355D34255D2B209B5846C5BDB4C8C0BFC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2B2B1C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB952252146251D3D1615401D1B
23090D3B1B193B19178F7568BD9C88BC9C8BBC8E86A56C5EAB745FC69C85BA947DAC796A
9E5C4BA26348AC6950AE684ECA9E84C29683C09C8DC2A897BE9587B28777A5705B9E694C
9A7152A86F5BA271616748432820264E302B553C355C474081574496695AAA765D9E6E5F
9A715D5B3124431E1B582A1F893D2DBEA198C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9592C21330F0C301814361613
2F14122712114A2A2890685CC79E89BF9B88BD9B8DB994859B6F5E8C574B8963568F6354
6D4B406C483F75483B875749926659B28C7CBD9B8AC2998BBE9C82B28471A56C618D4A33
975238AC855EAD7B65A77864A473638E6251815247935F4E9F6B58A7715C9A735DAD7B61
956855361C173017136F463D692E23B99088C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BAB8C2BEBDC2BBB9C2BBB9C2BBB9C2BBB9653A2F350D0A2D1311281411
170105311512442C298C695BC39A85C5A18DC2A091C2A195BF9B8CB08475905F5B855B59
9A5F558F584A8C5749935A4DAE7F6FC0A091C19B8CC4988EC18B81B48B78A7786C8A514C
67302A6C3A2973432DBD795CB5846CAC7860A2765F9A715FA5715B976C5AAD75699E735D
6E3E2E3C1C173523217043358E402C714E47F8FFFFC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2B7B6C2B5B4C2BBB9C2BBB9C2BBB9C2BBB95C3D38401F1C2F12102E1411
200D0A2B1110462C29856052B18C7AC09C88C2A091C2A497C2A699C2A89CC2A496C2A496
C2A394C2A89CC2A394C2A393BF9A84BD9E8DBFA292B99581BC9580B9937FB48B79AD8172
8A5F555E38364B312B562E236F3D2BA05D49916851A06349965F49AB7666956A59A56E5E
4D231E361713361B1E49140E7E2618633E38998A87C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB965433F4C302D271311301411
2D131131181B452B277F5949B78975C7A28EC2A08FC2A398C2A99CC2AA9FC2B1ACC2AEA6
C2AAA0C2A89CC2A99DC2A699C2A393C29D87C2A08CBE9682BC907DBC8C79BC9682BC8E7F
B4897AA87B6F91625866474151353058362E6C463A7555487753468B574FA575629F6855
4A201C3014122A1412260E0C4519165F37329E908CC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9683E324E2C233E22202C1311
340E0B381A1946282068473CAE806ABD9C88C5A38EC2A091C2A497C2A89CC2A699C2B1AC
C2AEA6C2AEA6C2A99DC2A699C2A595C2A597C29E87BE9682BC9682BC907DBC8C79BC907F
B78979B28673A8806D9F7362946F5F825D4E7B534786594A996A5C9C6D5D9C675B80513C
49231E3014123719172513112F13114D2A219C8C8CD5DAD7C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB95C362953332E3C201C3A1A18
230D0A3414123516135E34288B5C43C79F8CC0A18DC2A091C2A497C2ABA2C2AAA0C2A699
C2B1ACC2ACA2C2ACA2C2A699C2A28FC2A08FC19989C19481BC8C79BC937FBC907DBC8C79
B78774B3806DB37F6CAB7F6CA77664AE7C68A57865A37260A87161A871629B65515B332C
2D120D391B1E240E11260F0C170105411D1980615AC2B8B9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9653C30492E2A492E2B3A1E1C
3818162A1210381E1C4A2E2A6B4133B18067C7A38EC2A394C2A396C2ADA1C2B1ACC2AAA0
C2A89CC2A99DC2A699C2A699C2A292C19E87C19985BC907DBC907DBC8C79BA8C79BD8976
BA8976B0806DAE7F6CAE816EAB806DA77664AC78659E72609E715F956E5B7B504149231D
39211E1B060A250F13150005210D112D12106F504BB39F9BC2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB962433E51322D4D322F462B29
3A1917240E0B3D1B19512F266846398E6450C09B88C5A18FC2A096C2A396C2ADA1C2B1AC
C2AEA6C2AAA0C2A394C2A699C2A295BF9D8BB9927FBA8E7ABD8976BF8C7BB78C76B58673
B58574B0836DAE7F6CAE7C68AC7E6AAC7C68A5715EA577649A6A57905E506D3C2D441F1B
250F0C250F131B060A200D0B1F0C10371917654C46816560C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BAB8C1BBBA5C403B4D312E5236334B2F2C
3316133A1F1C351C1A452723774736945F4CB5846EC39F8BC2A091C2A195C2A195C2ABA2
C2AEA6C2AEA6C2A99DC2A699C1A090C5A190BE9682B9907DB48977B58372BA8576B5806D
B38171B37C6DAC7868AF7E68AC7865A77865A5705E9F6D5C9C6350885443512C22411C19
2814112612112512111F0C0A261311381917958480BFB7B6C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2B7B6BFAEAD51332F542F27492F2D503532
432927361D1A41262345261E65483F8B523FB7816DC0A18CC5A394C2A396C2A99CC2AA9F
C2AFA8C2AFA8C2AAA0C1A594C1A08FBF9C88C18F7CBA8973BD8C7ABA8973B58574B58370
B07F6CAE836FAB7767A57465A77562A77764A375629C6A578E5B476B3A334C231C2E1713
250F0C230E121D070B0F01051E080B4C2B278C7E7AC8C0BFC2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB963423E47271E5334304E3330
452A263F1D1A47281F472D2A5D4035703F32A56E58C09985C09E8DC2A093C2A398C2A897
C2A89AC2A89AC2A59ABF9D8BB9927FBC937FBA8F79BA8973B58571B58870B5856FB5806C
B08571AE7C68AE7C68A97865A77260A56E5B9A6C598E5D496B3C345B31243616142B1512
2D1311200D111B060B19060A2F161545282868403BC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9765A56482A274B2E29563633
4829204026243D1F1C4C2F2A482C275C3B3488503EB7866DC8AA97C4A18CC5A391C2A091
C2A08CC19E8AC4A18FC5A393BE9480BA8B76BA8973B37A68B68170B68171B98571B37D6A
B37A67AE7868AC7B65AC7862A56F5EA36E5B91624F74403259302438181428100C240E12
2F1411220E111500051B060B381917998884C8C0BFC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB97C60575337344D322F4B2E2B
4E2F2B391C1D3F231F4328254E333047281F60362B9D6C54BD8D73C39E87C2A28CC4A18B
C4A48EC19E8ABC9783BF9D88BF9682B87F6BB6806AB38068AE7764AE816CB17E6AB37C68
AC7562AF7564AA705FA576609F6E57965C488C59435A31253B18142E1713230E0B1B070B
1D070B1001050F00053316153B1B168F8181C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB995807D4D2E284F35324B2F2C
52373443251E3819194B322E42282452353141211D6C483A865745B8765CC79881BB8E78
C19A88BE9985BE977FC09681B68772A7725DB0715BB4765BB17967AF7361AF705BAF7B67
AC755AA56E5FA36A579C65528F65527945386933244A221C331612230E0B1C070B1B070A
1500040D000419050A2C1311643F37643E34C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9B3A2A563443F4528254D312E
4C302D432C273A1B1D4A291F4B302E5137334B302E482D295F423A77483A975B459C6E62
976D5AAE725AB0846EAE80689F6C5B965E4686503B995D42A6604AA96F55AD6C56A26452
A0624AA663499D64508C594B8149396934264E201B371713250F0C1D070B1500040E0005
0E00040D0004241110341716887975BDB0AEC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9897474462A244B312E
49322F472C2A291513452825543732523734593F3B543A37573E3760433B684337683D36
653B2E673C357E46358558466E443C6B4038743D2E713D287A413290553E92573F90523B
8C54407D4331834D3E79413365382C491F1B44221E250E0B230E0B1B060A1400040D0004
0D00042811101D0C105A413D725F5CC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9A49498513130492E2B
4C312E4A302D432A28412A285137335B403C533733583B375E3731683F325A372B503530
45252153312C471E1B5B363057352F4B2C2849201C4D28224D211B57241D633626603324
60332458241E55241D4E241E4B211C30181427100C1F080C1C070A1B070A0E00040D0004
28111A28110F3E27255D434392716BC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9BCB0B37F6568412522
4A2E2B4E3330492D2A573D39452A265D403C492D295337345E3D3553312E542F2A4E2E2A
4228244E302E371B1E3F2823421E1B411F1C3317142D16133416133F1B18401C18361813
381814371713411B18331512331513250F0C220E0B1B060A1B060A0E00040E000419050A
321C1C36181852373261433EC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9A6959655312D
4B33304E33304B2F2C432C285B3E3A533A3649322F4428245C3429462824492D29462A27
351E26442C263D1D213B1C1932171F2D15122C1512230E0B2914122B14122E1513260F0C
1E070B250F0B321512250F0C1E070B240F0B210D111B060A0E00041B060A21100F2D1919
33171656383356322DC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9B9AAAC704F4F
4829275236334B2F2C4B322F47322F573935492E29402521422420381814442925391D1F
381D20301614331720260F1220080C250F13230E111C070B220E111D070B230F121C070B
210D11251210220D111D070B0E00040F00050F01050F0005200C111D0B0A1B060B32100C
5E4440593934C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB99C8784
5032303F25224D312E4B34314C3532533936482D2F3C1B183C211F2A14123215132D1715
3215141E080C1F080C240F13200D111B060A220E121B060B210D111B060B3418160D0004
220D12271311220E110E00050E00041300041D0C101C0B0F1E0C10351816361F19412C2A
68585BBDB0AEC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
9C87844D2F2C402C29452926543C385239365439373B25234124212E141C220E11301411
220E112813112411101F0C111B070B1B070B1B060B1B070B1B060B261311220D113D2B33
2D1F202910181B070A200D1120100F200F0F1E0B10392221301A1A35171659342C6B4839
8C604FC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB99C837F4E2E2C48322F422824523A365E423D4F363341251D39201F261212220D11
1D070B220E0B230E121C070B1B070B200C111A060A200C111A060A1C070B3C2D2E351D2B
544242483436341E25372525311C1C251210351D1C361E1D4B312E4E2B255939347C5247
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C5BEBDA18986512D27513B39472F2C59413D5C413D563B363A1E1B391F1D3A2524
2D1C1D27100F251211200C111F0C101B060A1B070B26121B200C10241110230F13422E2C
4C2F302D1518361D19331B182C141734171439201D45261E5B3D34624947805749C2B5B4
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9997D76502E27462A27563A36684E49614B47523834371D1B391D1F
411F1B432C2933201D200C101B070B2C182128151C321F1E2A16213E29262210194A3531
422A2B42292736222235201D3824233F2B283B22225B3C325E3E337D4C3FB29EA3C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB999847D49291C3E26235337346448436454575C3F3A473030
462F303F23254232324834383726252F1B2038263440282A4A383E422A28442B2A493334
5637344F2D2C4F2E264A32305438316043384D2F2674554C8C5C4BC2B5B4C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9B6A6A97D5B5E462B2A533A3453434A735E5F6B524F
69524C624C4A533F43554346634D50573E3B51393B442B33482D2C5337385439364E3330
60372E5E38325C39325F3F3957332B7A59527947306C4338C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BDBBC2BEBDC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB99984874C222540231E4F3D44806966
76656468534B6C55516E57567055506C504F5F4742594241543B3C4A353159403F5F4542
583B356840385E35308A665C6A36235719108C6B6BC2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2B2B1C2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9BCB0B38F76835F3C49
7F5B62896B747E584F6B483E654C47775B5A7A58517859547658537758516B50496F4C41
7254497F655B491E125C2D2CA78D92C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9BCB0B6B8A6B1B6A1A78A6C7E634457603D465B352E5B352D5B312A582E27502217
4A1A0A77574BC2B5B4C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9C2BBB9
C2BBB9C2BBB9C2BBB9C2BBB9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?oooeW2^kT4_Z>C1<2NRP?2X944`ZBG1<:RU@C2Y9L;`ZJI1<:R
U@C2X8h4_Y^71;bEP@BgRGD4]HEb0k20KA2^Of`4[WYW0jUhH0BWN6@4YgQP1:MhI0BiY9`?`[^i1<:f
]@C2^;LS`[^i5Oooo`005?oooeW2^kT4_Z>C1<2NRP?2X944`ZBG1<:RU@C2Y9L;`ZJI1<:RU@C2X8h4
_Y^71;bEP@BgRGD4]HEb0k20KA2^Of`4[WYW0jUhH0BWN6@4YgQP1:MhI0BiY9`?`[^i1<:f]@C2^;LS
`[^i5Oooo`005?oooeW2^kT4_Z>C1<2NRP?2X944`ZBG1<:RU@C2Y9L;`ZJI1<:RU@C2X8h4_Y^71;bE
P@BgRGD4]HEb0k20KA2^Of`4[WYW0jUhH0BWN6@4YgQP1:MhI0BiY9`?`[^i1<:f]@C2^;LS`[^i5Ooo
o`005?ooo`C2^kT4`[Zh1<:n_@C2^kT4`[Zh0l:n_B?2^kT4`[Zh1<:n_AO2^kT4_jFF1;fKRP?2X8`4
`ZBJ1<:RU@C2Y9L4`ZJI1<:UU@?1YIL4a:FG1<BNS@BoVhH4^iEo1;^;MPBfQG43/H1/1;61KPR^Of`8
[WaX0jUhI0BWN684YgQP1:N1L@BiUhP?`[^i1<:g]PC2]K@S`[^i5Oooo`005?ooo`C2^kT4`[Zh1<:n
_@C2^kT4`[Zh0l:n_B?2^kT4`[Zh1<:n_AO2^kT4_jFF1;fKRP?2X8`4`ZBJ1<:RU@C2Y9L4`ZJI1<:U
U@?1YIL4a:FG1<BNS@BoVhH4^iEo1;^;MPBfQG43/H1/1;61KPR^Of`8[WaX0jUhI0BWN684YgQP1:N1
L@BiUhP?`[^i1<:g]PC2]K@S`[^i5Oooo`005?ooo`C2^kT4`[Zh1<:n_@C2^kT4`[Zh0l:n_B?2^kT4
`[Zh1<:n_AO2^kT4_jFF1;fKRP?2X8`4`ZBJ1<:RU@C2Y9L4`ZJI1<:UU@?1YIL4a:FG1<BNS@BoVhH4
^iEo1;^;MPBfQG43/H1/1;61KPR^Of`8[WaX0jUhI0BWN684YgQP1:N1L@BiUhP?`[^i1<:g]PC2]K@S
`[^i5Oooo`005?ooo`C2^kT4`[Zh1<:n_@C2^kT4`[Zh0l:n_B?2^kT4`[Zh1<:n_AO2^kT4_jFF1;fK
RP?2X8`4`ZBJ1<:RU@C2Y9L4`ZJI1<:UU@?1YIL4a:FG1<BNS@BoVhH4^iEo1;^;MPBfQG43/H1/1;61
KPR^Of`8[WaX0jUhI0BWN684YgQP1:N1L@BiUhP?`[^i1<:g]PC2]K@S`[^i5Oooo`005?ooo`C2^kT4
`[Nf1<:d/`C2_[d4`[Nf0l:e]0C2^kT4`[Zh1<:n_@C2^[P4`[jm3l:k^@C2]kH4`[Fd5l:k^@C1YYD4
aJ>A0l:PT`C2Xi44`ZJI1<:PT`C2Z9X4`J>?0kZLRPC3Uh04_I5o1;R?N0BcS7P4[X=`1:ioK0>[NVP4
YgQU2:mnJPB_O6P4[gQR0jahI`BWN6D4YgQT1:f@O`B]VI8C`[^i1<:j^0C2_[dO`[^i5Oooo`005?oo
o`C2^kT4`[Nf1<:d/`C2_[d4`[Nf0l:e]0C2^kT4`[Zh1<:n_@C2^[P4`[jm3l:k^@C2]kH4`[Fd5l:k
^@C1YYD4aJ>A0l:PT`C2Xi44`ZJI1<:PT`C2Z9X4`J>?0kZLRPC3Uh04_I5o1;R?N0BcS7P4[X=`1:io
K0>[NVP4YgQU2:mnJPB_O6P4[gQR0jahI`BWN6D4YgQT1:f@O`B]VI8C`[^i1<:j^0C2_[dO`[^i5Ooo
o`005?ooo`C2^kT4`[Nf1<:d/`C2_[d4`[Nf0l:e]0C2^kT4`[Zh1<:n_@C2^[P4`[jm3l:k^@C2]kH4
`[Fd5l:k^@C1YYD4aJ>A0l:PT`C2Xi44`ZJI1<:PT`C2Z9X4`J>?0kZLRPC3Uh04_I5o1;R?N0BcS7P4
[X=`1:ioK0>[NVP4YgQU2:mnJPB_O6P4[gQR0jahI`BWN6D4YgQT1:f@O`B]VI8C`[^i1<:j^0C2_[dO
`[^i5Oooo`005?ooo`C2^kT4`[Nf1<:d/`C2_[d4`[Nf0l:e]0C2^kT4`[Zh1<:n_@C2^[P4`[jm3l:k
^@C2]kH4`[Fd5l:k^@C1YYD4aJ>A0l:PT`C2Xi44`ZJI1<:PT`C2Z9X4`J>?0kZLRPC3Uh04_I5o1;R?
N0BcS7P4[X=`1:ioK0>[NVP4YgQU2:mnJPB_O6P4[gQR0jahI`BWN6D4YgQT1:f@O`B]VI8C`[^i1<:j
^0C2_[dO`[^i5Oooo`005?ooo`S2^kT4`[Je1<:h]`_2^kT4`[Nf1<:e]0C2]kH4`[Fd;/:k^@BoXi<4
_Ij<0l:PSPC2X9<4`Z>F1<:UU`C2X944_if@0k2EQ0BVS7`4]H5f1:alJPB]Of`4[HEd1:f5LP>[O6X4
ZGiX3:MhI@BWN6@3ZG]U1:EfI0BWN6D4^JBL5l:k^@C2]kH4`[Fd7l:k^AGoool001Coool8`[^i1<:f
]@C2^;L;`[^i1<:g]PC2]K@4`[Nf1<:e]2k2^kT4_j>C1;fNS0?2X8h4`Z2C1<:SUPC2YIL4`Z2A1;nM
T0>`UH@4YXal1;F1MPB/O6X4[Gm/1:f5M0B]QG83ZgaZ1:UnJ0bWN6D4YgQT0jUkI@BUMV@4YgQU1;VT
W1O2^kT4`[Nf1<:e]1o2^kTEoooo000Doooo2<:k^@C2][D4`[Rg2l:k^@C2]kH4`[Fd1<:g]PC2]K@^
`[^i1;nST`BmWX`3`Z2>1<:PT`C2XiH4`ZFG1<:PT@BoWI03/9F41:J<O0BePGH4[7aZ1:eoK0B]QG@4
[HEb0j]lJPBYOVP<YgQU1:MhI0>YNfD4YGIT1:MhI@BiY9`G`[^i1<:g]PC2]K@O`[^i5Oooo`005?oo
o`S2^kT4`[Je1<:h]`_2^kT4`[Nf1<:e]0C2]kH4`[Fd;/:k^@BoXi<4_Ij<0l:PSPC2X9<4`Z>F1<:U
U`C2X944_if@0k2EQ0BVS7`4]H5f1:alJPB]Of`4[HEd1:f5LP>[O6X4ZGiX3:MhI@BWN6@3ZG]U1:Ef
I0BWN6D4^JBL5l:k^@C2]kH4`[Fd7l:k^AGoool001Coool8`[^i1<:g]PC2]KA9`[^i1<:UUPC2VhX3
`Z2C1<:PUPS2X9<4`Z2@1<:QT0?2WY84_iZ;1;bAP@BnQ7`4]89^1;AnK`BbNW03/gia1:E[H0BVMfD4
YX1^1:EdH0BYN6D3ZGYW1:UlJ0BYOF/4]YjF?/:k^AGoool001Coool8`[^i1<:g]PC2]KA9`[^i1<:U
UPC2VhX3`Z2C1<:PUPS2X9<4`Z2@1<:QT0?2WY84_iZ;1;bAP@BnQ7`4]89^1;AnK`BbNW03/gia1:E[
H0BVMfD4YX1^1:EdH0BYN6D3ZGYW1:UlJ0BYOF/4]YjF?/:k^AGoool001Coool8`[^i1<:g]PC2]KA9
`[^i1<:UUPC2VhX3`Z2C1<:PUPS2X9<4`Z2@1<:QT0?2WY84_iZ;1;bAP@BnQ7`4]89^1;AnK`BbNW03
/gia1:E[H0BVMfD4YX1^1:EdH0BYN6D3ZGYW1:UlJ0BYOF/4]YjF?/:k^AGoool001Coool8`[^i1<:g
]PC2]KA9`[^i1<:UUPC2VhX3`Z2C1<:PUPS2X9<4`Z2@1<:QT0?2WY84_iZ;1;bAP@BnQ7`4]89^1;An
K`BbNW03/gia1:E[H0BVMfD4YX1^1:EdH0BYN6D3ZGYW1:UlJ0BYOF/4]YjF?/:k^AGoool001CooomI
`[^i1<:XV0C2X8`3`Z2>1<:PS0C2X9H4`Z2C1<:QU@C2X9<3`ZRJ1<:VV@BoVX/4^Y:01;V6N0BlRGT4
^HMd0kF1LPBgOg84Zg9U1:ifJ@B[QGT4YgAP0jmhI@B/N6D4[hQi1;FKS1_2^kT4`[Zh1<:n_A_2^kTE
oooo000DooooFL:k^@C2Z9P4`Z2<0l:PSPC2X8`4`Z2F1<:PT`C2XID4`Z2C0l:XVPC2YYT4_iZ;1;ZB
P0BiQWP4_8Ui1;V7M0>ePG84]gmb1:]bI@B^MVT4ZhEi1:MdH0>_N6D4[7QU1:n8N@BeVh`K`[^i1<:j
^0C2_[dK`[^i5Oooo`005?oooeW2^kT4`ZRH1<:PS0?2X8h4`Z2<1<:PUPC2X9<4`Z6E1<:PT`?2Z9X4
`ZJI1;nJR`BjTX04^HIh1;b9N@BiQg@3]H5b1;MoLPB[LVD4[WIY1:^5N@BWM603[gQU1:ahI@B_R7T4
]I^<6l:k^@C2^[P4`[jm6l:k^AGoool001CooomE`[^i1;fWWPC<`;44`Z2>0l:PS0S2X944`Z6E1<:P
T`C2YYT3`YjB1<:QU@C2XYD4`Z2@1;nHPPBjSGd4^HUj0kV9M`BbOW04/Wm]1:]jI`B/OF/4[81_0jUh
I@BUN6D4]IJ<1<2[Y1_2^kT4`[Nf1<:e]0O2^kT4`[Zh1<:m^`C2_[d8`[^i5Oooo`005?oooeG2^kT4
_JNN1<c0/@C2X8h3`Z2<2<:PT@C2XID4`Z2C1<:VV@?2WY84`Z6E1<:RU@C2X904_iR21;Z=O@BiRGX3
^HUg1;9nL0BbOfd4ZgYW1:amJ`B/P6l3ZGQU1:EhI@BeUX`4`:^T6l:k^@C2]kH4`[Fd1l:k^@C2^[P4
`[fk1<:n_@S2^kTEoooo000DooooEL:k^@BmYih4c<2a1<:PSP?2X8`8`Z2A1<:QU@C2X9<4`ZJI0l:N
TPC2XID4`Z:E1<:PT0BoV884^Xem1;V9NP>iRGL4/Wi`1;9oK@B[NVL4[7e[1:b0K`>YN6D4YGQU1;FF
S0C0Zj@K`[^i1<:g]PC2]K@7`[^i1<:j^0C2_K/4`[jm2<:k^AGoool001CooomE`[^i1;fWWPC<`;44
`Z2>0l:PS0S2X944`Z6E1<:PT`C2YYT3`YjB1<:QU@C2XYD4`Z2@1;nHPPBjSGd4^HUj0kV9M`BbOW04
/Wm]1:]jI`B/OF/4[81_0jUhI@BUN6D4]IJ<1<2[Y1_2^kT4`[Nf1<:e]0O2^kT4`[Zh1<:m^`C2_[d8
`[^i5Oooo`005?oooe72^kT4TgY^1=o8^PBeSh84`Z2A0l:PT0C2X8/4`Z2>1<:TU`C2XYD4`Z>C0l:Y
W`S2YIL4`Z2A1<:MSPC1T7l4`I1j0kb9N@BgQg04/gY/1;=oK0B[MV@4YGQU0jamJ`B[MVD4/iZB1;f`
[R[2^kT4`[Nf1<:b/@C2]K@8`[^i5Oooo`005?oooe72^kT4TgY^1=o8^PBeSh84`Z2A0l:PT0C2X8/4
`Z2>1<:TU`C2XYD4`Z>C0l:YW`S2YIL4`Z2A1<:MSPC1T7l4`I1j0kb9N@BgQg04/gY/1;=oK0B[MV@4
YGQU0jamJ`B[MVD4/iZB1;f`[R[2^kT4`[Nf1<:b/@C2]K@8`[^i5Oooo`005?oooe72^kT4TgY^1=o8
^PBeSh84`Z2A0l:PT0C2X8/4`Z2>1<:TU`C2XYD4`Z>C0l:YW`S2YIL4`Z2A1<:MSPC1T7l4`I1j0kb9
N@BgQg04/gY/1;=oK0B[MV@4YGQU0jamJ`B[MVD4/iZB1;f`[R[2^kT4`[Nf1<:b/@C2]K@8`[^i5Ooo
o`005?oooe72^kT4TgY^1=o8^PBeSh84`Z2A0l:PT0C2X8/4`Z2>1<:TU`C2XYD4`Z>C0l:YW`S2YIL4
`Z2A1<:MSPC1T7l4`I1j0kb9N@BgQg04/gY/1;=oK0B[MV@4YGQU0jamJ`B[MVD4/iZB1;f`[R[2^kT4
`[Nf1<:b/@C2]K@8`[^i5Oooo`005?ooo`S2^kT4`[Zh1<:n_Cg2^kT4^Zj`15h^:0BeWX/4_I^51<:Q
T`?2WI04`Z6E1<:MT0C2XiH4`ZJI1<:NS`?2X8h4`ZFE1<:IT@C1XHX4`Yj61<BKR@BlS7d3^XUi1;R0
KPBeP6X4Zg]X1:ajH`B/N6L3ZWeY1:n2K@BoZZ92`[^i5Oooo`005?ooo`S2^kT4`[Zh1<:n_Cg2^kT4
^Zj`15h^:0BeWX/4_I^51<:QT`?2WI04`Z6E1<:MT0C2XiH4`ZJI1<:NS`?2X8h4`ZFE1<:IT@C1XHX4
`Yj61<BKR@BlS7d3^XUi1;R0KPBeP6X4Zg]X1:ajH`B/N6L3ZWeY1:n2K@BoZZ92`[^i5Oooo`005?oo
o`S2^kT4`[Zh1<:n_Cg2^kT4^Zj`15h^:0BeWX/4_I^51<:QT`?2WI04`Z6E1<:MT0C2XiH4`ZJI1<:N
S`?2X8h4`ZFE1<:IT@C1XHX4`Yj61<BKR@BlS7d3^XUi1;R0KPBeP6X4Zg]X1:ajH`B/N6L3ZWeY1:n2
K@BoZZ92`[^i5Oooo`005?ooo`S2^kT4`[Zh1<:n_Cg2^kT4^Zj`15h^:0BeWX/4_I^51<:QT`?2WI04
`Z6E1<:MT0C2XiH4`ZJI1<:NS`?2X8h4`ZFE1<:IT@C1XHX4`Yj61<BKR@BlS7d3^XUi1;R0KPBeP6X4
Zg]X1:ajH`B/N6L3ZWeY1:n2K@BoZZ92`[^i5Oooo`005?ooo`S2^kT4`[Nf1<:d/`C2_[de`[^i1<>k
^PAZ@cD4ZHn@15i0A0C2X9<4`Z>A0l:UU`C2XiH4`ZFG1<:PT`C2XiH4`ZVL0l:RU@C1WX/4a9>71<6<
OPBgQg@4^8Qd1;f<N0>jS7D4/8Ac1;5lJ0BcOVX4ZgaW1:IhHP>UN6D4ZG]X1;FMU@C5b<Xn`[^i5Ooo
o`005?ooo`S2^kT4`[Nf1<:d/`C2_[de`[^i1<>k^PAZ@cD4ZHn@15i0A0C2X9<4`Z>A0l:UU`C2XiH4
`ZFG1<:PT`C2XiH4`ZVL0l:RU@C1WX/4a9>71<6<OPBgQg@4^8Qd1;f<N0>jS7D4/8Ac1;5lJ0BcOVX4
ZgaW1:IhHP>UN6D4ZG]X1;FMU@C5b<Xn`[^i5Oooo`005?ooo`S2^kT4`[Nf1<:d/`C2_[de`[^i1<>k
^PAZ@cD4ZHn@15i0A0C2X9<4`Z>A0l:UU`C2XiH4`ZFG1<:PT`C2XiH4`ZVL0l:RU@C1WX/4a9>71<6<
OPBgQg@4^8Qd1;f<N0>jS7D4/8Ac1;5lJ0BcOVX4ZgaW1:IhHP>UN6D4ZG]X1;FMU@C5b<Xn`[^i5Ooo
o`005?ooo`S2^kT4`[Nf1<:d/`C2_[de`[^i1<>k^PAZ@cD4ZHn@15i0A0C2X9<4`Z>A0l:UU`C2XiH4
`ZFG1<:PT`C2XiH4`ZVL0l:RU@C1WX/4a9>71<6<OPBgQg@4^8Qd1;f<N0>jS7D4/8Ac1;5lJ0BcOVX4
ZgaW1:IhHP>UN6D4ZG]X1;FMU@C5b<Xn`[^i5Oooo`005?ooo`S2^kT4`[Zh1<:k^@C2]K@e`[^i179:
>@C8^kD4GT8j1;fKQ@C2X947`Z2C1<:PT@C2X9H4`Z2C1<:QU@C2X9<3`ZFG1;j4N0BlSGd4^Wa^1;Ym
K@BeNVX4]I5g0k>2K0BcPVX4[WQU1:akI0BaN6L4[WQU0jUhHPB/MfD4/Xai1<[6bB[2^kT4`[Zh1<:n
_@c2^kTEoooo000Doooo2<:k^@C2^[P4`[^i1<:e]3G2^kT4LTXi1<Rk]@AN@SX4_I^51<:PT@O2X9<4
`Z2A1<:PUPC2X9<4`Z6E1<:PT`?2YIL4_XAh1;b=O@BjO6h4^We]1;EjJPBeTGL3/h9/1;>2JPB^N6D4
[7]T1;5hI`B^N6D3ZGQR1:agI@BbS7T4b/K9:/:k^@C2^[P4`[jm3<:k^AGoool001Coool8`[^i1<:j
^0C2^kT4`[Fd=L:k^@AbBST4b;^e15i2>PBmVhD4`Z2A1l:PT`C2X944`Z2F1<:PT`C2XID4`Z2C0l:U
U`BnQ7P4_8em1;YlKPBjOFd4]GYZ1;FAM`>cPV`4/h9Z1:ihI@B/Nf@4/GQW1:ihI@>YN684[7MU1;:<
N@C:a/TZ`[^i1<:j^0C2_[d<`[^i5Oooo`005?ooo`S2^kT4`[Zh1<:k^@C2]K@e`[^i179:>@C8^kD4
GT8j1;fKQ@C2X947`Z2C1<:PT@C2X9H4`Z2C1<:QU@C2X9<3`ZFG1;j4N0BlSGd4^Wa^1;YmK@BeNVX4
]I5g0k>2K0BcPVX4[WQU1:akI0BaN6L4[WQU0jUhHPB/MfD4/Xai1<[6bB[2^kT4`[Zh1<:n_@c2^kTE
oooo000Doooo2<:k^@C2]kH4`[Fd=/:k^@>j[Zh4UXAn16A:@PC2YIL4`Z2>1<:PT@C2X9<3`Yj>1<:Q
T0C2XHl4`Z>H1<:SUPC2WI83`Z6C1;ikLPBjHeX4^5E<1;USG`BcFE04^FUP0jiiI0B_NfH4[gQR1:aa
G`B/Nf@4[WQU0j]hI0BYLUd4ZgUW1;:@P0C<f^4V`[^i1<:g]PC2]K@<`[^i5Oooo`005?ooo`S2^kT4
`[Nf1<:e]3K2^kT3^Zj^19J4OPATBT84`ZFG1<:PSPC2X944`Z2C0l:NSPC2XI04`Z6?1<:SV0C2XiH4
`YfB0l:QT`BnNg84^V=J1;QEC0BiHel4/eU@1;UYH0>^NF@4[g]V1:mhHPB/LEl4[7]T1:ihI@>[N6@4
ZG9M1:]iI`BbT804c=[Q9/:k^@C2]kH4`[Fd3<:k^AGoool001Coool8`[^i1<:g]PC2]K@f`[^i0kZ^
[PBFQ7h4I4Y21<:UU`C2X8h4`Z2A1<:PT`?2WXh4`Z6@1<:QS`C2XiP4`Z>F1<:MTP?2XI<4_W]b1;YS
FPBhED`4^F=O1;=ID0BiJF03[WUT1:mkIPB_N684[75O1:akI0B^N6D3ZgQT1:UbG@B[NFL4/Y201<cJ
hBK2^kT4`[Nf1<:e]0c2^kTEoooo000DooooA/:k^@=SA3d4hlRj1<2SVPC2X9<<`Z2A0l6IR@C4Uh84
aJ6=1<:KS@C2W8/4`H=n0l9lKPC0Q7/4/e521;a/HPBcDDd4[T@k1;9?@`>cHUL4YFaM1:MkI0BWLUH4
ZWMU1;5hI`>^N6D8[WIT1:j1KPBlYId4`/73=/:k^AGoool001Cooom6`[^i0f=4?@CSb;X4`:>J1<:P
T`c2X943`IV91<BGPPC5XHd4`Y^=1<:LR`C1Pgh3`Wa^1<24N`BcDD84_6aR1;=AC@B^A3/4/Tm30k=R
E`BUK5d4Yg]T1:MbEPBZMfD4/GQW0jihI@R^MV@4[X5^1;bUW@C2`L<f`[^i5Oooo`005?ooodK2^kT3
Hd@m1>?8^PC0XiX4`Z2C3<:PT@?1VHT4a9N21<FQS@C2Vhd4`Yb;1<63OP?2O6h4`8Ak1;=A@PBlK684
/e5=1:i4>`BbCd<3/f9G1:E/G@BWNf@4Yg9F1:YgI@BaN6L3[WQU2:ifI0B^PFh4_:FM1<;1`cK2^kTE
oooo000DooooA/:k^@=SA3d4hlRj1<2SVPC2X9<<`Z2A0l6IR@C4Uh84aJ6=1<:KS@C2W8/4`H=n0l9l
KPC0Q7/4/e521;a/HPBcDDd4[T@k1;9?@`>cHUL4YFaM1:MkI0BWLUH4ZWMU1;5hI`>^N6D8[WIT1:j1
KPBlYId4`/73=/:k^AGoool001Coool@`[^i1<:j^0?2_[d[`[^i1:bIV@>HPG<4JeYF1;fKRPC1W8@4
aJNE1<:MR`C2W8T3_9Il1;^5LPC7WXl4_h5b190/60CVZYL3^V1I1;=_I@BRH5D4V4Hi1:Z0J0B[Hdl4
Zdi90i/o<0BlD4@4YGQT1:YgF0BYLed4ZGeW0k1kIPB[M6@4[W]X1:ihI@BgTX04c<_:1<;1`c;2^kTE
oooo000Doooo4<:k^@C2^[P3`[jm:l:k^@B/VIT3V85c16]JEPBmVhX4`Ib41<FWU@C2WH/4`Yb90kbF
O0BkQG84aij?1;n1LPB@;1P4iZZG0kYPF@BcKfD4XV1E19Q6>@BZP6P4Zf=?1:]>B@>K?c04_5141:Eh
I0BZMeP4ZG=M1:UmI`>`NfH4ZgAT1:ikJ0B^N6D4]i:01<c;bPC2`L<b`[^i5Oooo`005?oooa32^kT4
`[Zh0l:n_B_2^kT4[9VI0iR1L`A[FUH4_I^:1<6LQ0C5YiD4`Yf;1<:LR@>lUW`4^hEb1<NNS`BoPG84
T2`H1>JZU`>jH5T4/fmU1:9PE@BHAST4ZX1X1:]SC`B[CTT3Vcl`1;a@A0BUN6@4ZWMH1:UcG@BYOFL3
/7]V1:]dI0B^NfP4[WQU1;NBP0C<blX4`/73</:k^AGoool001Coool@`[^i1<:j^0?2_[d[`[^i1:bI
V@>HPG<4JeYF1;fKRPC1W8@4aJNE1<:MR`C2W8T3_9Il1;^5LPC7WXl4_h5b190/60CVZYL3^V1I1;=_
I@BRH5D4V4Hi1:Z0J0B[Hdl4Zdi90i/o<0BlD4@4YGQT1:YgF0BYLed4ZGeW0k1kIPB[M6@4[W]X1:ih
I@BgTX04c<_:1<;1`c;2^kTEoooo000Doooo2<:k^@C2^[P4`[jm1<:g]P?2]K@[`[^i16M7@P>lVHd4
YH1b1<:PS0BnU8@4`::C1<:UU`C2UX@3]g]O1;5fG`BA91h4fJbT19Pa;@Aa7AD3/VMI1;ERDPBmSH04
^h9h1:]>A`BAD3`4REQ70gho<PAb;a`4_eI31:QnH`B/KeT4/7i/0k21K0BbP6P4ZgIU1:ilJ0B^OFX4
]ibD1<Zk[@?5`L0_`[^i5Oooo`005?ooo`S2^kT4`[Zh1<:n_@C2]kH3`[Fd:l:k^@AWAd83_9V=1:F0
LPC2X8`4_YB41<2RT`C2YIL4`YJ40kMkG`BaMUl4TB@N1=V/Y0BH<Bd4LAdE0k9WF@BeHU84_Hf01;^2
N0B[CTL4TE0l18UHA`=n?c84LRlL1;mF@`BXOV<4[6mI1;1nK0>`PF`4/X1X1:]fI@B^O6P4[WeZ1;NL
U0C:^jd3aL70;l:k^AGoool001Coool8`[^i1<:j^0C2_[d4`[Nf0l:e]2_2^kT4IdM20kbIS@BUP784
`Z2<1;jDQ0C0XY<4`ZFG1<:FQ0>gNel4/GIO194T7PCI[:@4V34]174M5@>bIeT4]F9B1;f=P0BkPWP4
Zdi7195@?0B9F4L3OSlb178_70BoET<4Z7iS1:a_F@B`OV`3/85/1;:0J0B[MVD4[WaX1:imJPBgW9@4
b[^]0lG1`2o2^kTEoooo000Doooo2<:k^@C2^[P4`[jm1<:g]P?2]K@[`[^i16M7@P>lVHd4YH1b1<:P
S0BnU8@4`::C1<:UU`C2UX@3]g]O1;5fG`BA91h4fJbT19Pa;@Aa7AD3/VMI1;ERDPBmSH04^h9h1:]>
A`BAD3`4REQ70gho<PAb;a`4_eI31:QnH`B/KeT4/7i/0k21K0BbP6P4ZgIU1:ilJ0B^OFX4]ibD1<Zk
[@?5`L0_`[^i5Oooo`005?ooo`S2^kT4`[Nf1<:e]2k2^kT4_KBg150Z90>MQ7H4`9j=1<:PT@BoUh@4
_I641<:PT`BoRWH3/GME1:Q:=PAg70l4VfEO1;:[W0C4Zj83aLC11<:_Z@C2/:`4_9R<1<:`X@BoVhX4
/:2M0geID`AQ>SD4F2<H1;UK@`B_PVX4]X1[0kN:N@BbP6`4/7iX1:icH0B^OFT4[9J@1;:S[@?6_lH4
c<S0:l:k^AGoool001Coool8`[^i1<:g]PC2]K@^`[^i1;fd]`A@:R@3WHAf1<2NS@C2X944_iN41;fA
Q0C2X9<4_hYf0k5gE@BXBSH4Ma`?19]UG`BbZi`4a:^R0lG4`@C2[jT4`[2/1;bHS0C2/:44_i^:1;2P
W@=mFE<4HCXe15PS60BiFd<4[h9Z1;J0J`>gRWT4/X1/1;1nJ0B^Lf04[WeY1:bFT0BbXjd3a[o61<c8
`2_2^kTEoooo000Doooo2<:k^@C2]kH4`[Fd;/:k^@Bm];L4D2XT0if4MPC0WXd4`Z2A1;nGQ0BmTH@4
`Z2C1;n:MP>aMeD4Z4Xf17LL3`BKIEl4/Z^L1<B[XP?5a<44`ZnY1<:`[0BlV8`4`[2Q1;nKRPB`X9d3
OEUC164j=@AH8aP4^E]31:n2JPBfP6/3]hYi1;:0K0B`OVP4[W=P1:imJ@B/UY04/Z>]0lJoaPC<b<0[
`[^i5Oooo`005?ooo`S2^kT4`[Nf1<:e]2k2^kT4_KBg150Z90>MQ7H4`9j=1<:PT@BoUh@4_I641<:P
T`BoRWH3/GME1:Q:=PAg70l4VfEO1;:[W0C4Zj83aLC11<:_Z@C2/:`4_9R<1<:`X@BoVhX4/:2M0geI
D`AQ>SD4F2<H1;UK@`B_PVX4]X1[0kN:N@BbP6`4/7iX1:icH0B^OFT4[9J@1;:S[@?6_lH4c<S0:l:k
^AGoool001Cooolj`[^i19=jKPAZ?SP4YhJ30fIBCPBmVhP4`Yb71<:QR`C2YY@4`Z2C1;V1L0>YMF44
TUA217<J6`Aa:BL4]7EV1;Z6MP?0U8L4aiN=1<2LQ0C0NFH4^FeM1;UlK0BoWhP3^7eY19ebI`AeDTL4
F`l51;mdHPBaQF/3^Xmk1;N9LPB`OF`4[7UW1;5gI@B[QG@4YYbG0i^6R@Bo^;`[`[^i5Oooo`005?oo
oc[2^kT4TgY^16Xn>0BWQX<3IU9>1;fKR0C2W8L4`Z6;1<:VU0C2X9<4^H5`0jUeH@BBE484LaXK174Y
9`BdMFH4^XIf0l2DQ`C7Uhd4`9b41<1iIPBiKEd4^Ga/1;nOR0>hOFT4WG9W17EBA`AK3`D4_gAR1;65
J`>jSg/4]hUb1;1mK0B/NFL4/GMU1:^5M0BVW9L3VhJ91;nh_2_2^kTEoooo000Doooo>/:k^@BCNVh4
JShh1:N6P`=VDTh4_I^81<:LQ`C2XH/4`ZJD1<:PT`BiPG03ZGEQ199D@PAc6Q/4LBTW1;AeIPBjQWH3
`9B71<NGS@C0W8@4`7UV1;U]G@BiO6`4_in80kQmJ@BMLVL4ME9715/?1@BoM684/HE[0kZ?N`BgRG84
/7e/1:aiI`BaMfD4ZhEd1:JLU`>KQXT4_kRl:l:k^AGoool001CooolD`[^i0l:j^0C2_[dK`[^i1;fa
/`@e71D4?adH18UTGP>RNF/4`Yj:1<:FQ`C1V7l4aIV61<:IRPBiS783[g1G1<FTU0BmWHP4`YB61;n5
O`BgOW@3/WI/1;E`J@BbI604ZfEN1:Y?B@BZC4P4YV5E0je/H0BOFD/4T4Th16dV70Ai:b04`8ef0kfB
NPBgRg84/7]W1:UeHPB/OFT4[X=`17a=?0?Xi_44[9bU1<G1`2O2^kTEoooo000Doooo5<:k^@?2^[P4
`[jm6l:k^@Bm/K<4=A`E13lM60B9I5h3XWU[1<:NRPC2UXL4`IQo1<FIQPC2VHX4^Hab0jm`E`C5Y9@4
_If81<:DQPBoQGl4]gid0k9fK0BeL6T4/VAP1:]UGPBZCdT4ZTa81:IQE@>]K604WeU;1919>0A]9Q`4
NB/P1<2=MP>mTWX4]h]b1;1kI`BYMF84[7eY1:j3L0AlCC`3j>Ka1:bLY@C5`L0W`[^i5Oooo`005?oo
oaC2^kT3`[Zh1<:n_A_2^kT4_K6c13DL5@@o7AP4RFAN0j9iJ`C2WXX4`YJ71<6HO`C5VHH4`YV:1;V<
LP>_L5L4aJBD1;fMR0C2U8H4_hEo1;MnM0>bMV`4]G1Y1;9TH0B[IEh4ZTm91:Y<B0BVHED3[FaP19mI
B`B@BCP4KBHL17T[80C0SGH3_I9j1;N;LPB`NfL4ZGER1:amJ@B^Pg04O4dl0nSVl@B/W:D4aL709l:k
^AGoool001CooolD`[^i0l:j^0C2_[dK`[^i1;fa/`@e71D4?adH18UTGP>RNF/4`Yj:1<:FQ`C1V7l4
aIV61<:IRPBiS783[g1G1<FTU0BmWHP4`YB61;n5O`BgOW@3/WI/1;E`J@BbI604ZfEN1:Y?B@BZC4P4
YV5E0je/H0BOFD/4T4Th16dV70Ai:b04`8ef0kfBNPBgRg84/7]W1:UeHPB/OFT4[X=`17a=?0?Xi_44
[9bU1<G1`2O2^kTEoooo000Doooo5<:k^@?2]kH4`[Fd6l:k^@BdYJX4KeYI10023`AA@dH3aJ>C1<:K
Q`C2UHP4_hV31;fTRPC2UhT4^Geb0j]^FPB`QW<4aJVN1<:VV@C2WI04`Z>F0l:VV@C2UXT4_YV01;b<
N@BgQg44]H1Z1:igH@>bJ5d4/EiE19m;A@B6>S<4MRh/195@?P>iQgP4^XUa1;1kI`BYMV04[7AT1:im
JPAYAcl3V7ee1<c3a@Bm/:hW`[^i5Oooo`005?oooaC2^kT3`[Nf1<:e]1_2^kT4]:FZ16mJF@@00Pl4
DD=60lFST`C2VhL4`YF81;n9P`BmY8X4`YN91;UmLP>[KUX4/8Ic1<FYWPC2YYT4`Yf@1<:SUP?2YYT4
`YJ91;jIP0BlS7T4]hMa1;F0JPB^Mf43/VQM1;5NE@BOBdD4QSXc17H^;0BAD3h3^HMh1;Z9L@B`NfL4
ZGIP1:adI0B^OFX4JDLo0iQmM@C<`lD4_K2^9l:k^AGoool001CooolD`[^i0l:g]PC2]K@K`[^i1;BU
ZPA_FUT4008?1553AP?5Xi<4`Y^71<:ER0BoRH<4_JB:1<:GR@BiOG83ZfiJ1;26L`C5ZIh4`ZJI1<:M
T0C2XiH3`ZJI1<:FR@BnVH04_8ai1;N7L@BeP6X4[WMQ0k9XG@BaGUD4Wd]518Hj<`Af;R`4TE0n0kV7
N0BjRG44/7]W1:UfH0B/M6@4[WeZ16U7?`>HOGD4c<?51;f`[RO2^kTEoooo000Doooo5<:k^@?2]kH4
`[Fd6l:k^@BdYJX4KeYI10023`AA@dH3aJ>C1<:KQ`C2UHP4_hV31;fTRPC2UhT4^Geb0j]^FPB`QW<4
aJVN1<:VV@C2WI04`Z>F0l:VV@C2UXT4_YV01;b<N@BgQg44]H1Z1:igH@>bJ5d4/EiE19m;A@B6>S<4
MRh/195@?P>iQgP4^XUa1;1kI`BYMV04[7AT1:imJPAYAcl3V7ee1<c3a@Bm/:hW`[^i5Oooo`005?oo
ocK2^kT4^JRU1;:PY@BoV8@4^HYf0knLR0C5X8`4`Y^:1<:GR0C2TXP4`Yf81;^AN`>_MVD4/GQU1<FY
U@C5Yid4`Z>F1<:MT0?2Y9L4`YV=1;j4NPBjPfl4^Xif1;5mJ0B/N6D3ZW5G1:Q^FPBXMEX4Z6aJ1:E^
FPBWLFD3[W]R1;F3K@B^NV<4[7MR1:YkH@B_NVT4CbdW0j:?R0BcXiD[`[^i5Oooo`005?ooocK2^kT4
^JRU1;:PY@BoV8@4^HYf0knLR0C5X8`4`Y^:1<:GR0C2TXP4`Yf81;^AN`>_MVD4/GQU1<FYU@C5Yid4
`Z>F1<:MT0?2Y9L4`YV=1;j4NPBjPfl4^Xif1;5mJ0B/N6D3ZW5G1:Q^FPBXMEX4Z6aJ1:E^FPBWLFD3
[W]R1;F3K@B^NV<4[7MR1:YkH@B_NVT4CbdW0j:?R0BcXiD[`[^i5Oooo`005?ooocK2^kT4^JRU1;:P
Y@BoV8@4^HYf0knLR0C5X8`4`Y^:1<:GR0C2TXP4`Yf81;^AN`>_MVD4/GQU1<FYU@C5Yid4`Z>F1<:M
T0?2Y9L4`YV=1;j4NPBjPfl4^Xif1;5mJ0B/N6D3ZW5G1:Q^FPBXMEX4Z6aJ1:E^FPBWLFD3[W]R1;F3
K@B^NV<4[7MR1:YkH@B_NVT4CbdW0j:?R0BcXiD[`[^i5Oooo`005?ooocK2^kT4^JRU1;:PY@BoV8@4
^HYf0knLR0C5X8`4`Y^:1<:GR0C2TXP4`Yf81;^AN`>_MVD4/GQU1<FYU@C5Yid4`Z>F1<:MT0?2Y9L4
`YV=1;j4NPBjPfl4^Xif1;5mJ0B/N6D3ZW5G1:Q^FPBXMEX4Z6aJ1:E^FPBWLFD3[W]R1;F3K@B^NV<4
[7MR1:YkH@B_NVT4CbdW0j:?R0BcXiD[`[^i5Oooo`005?oooc;2^kT4`KRg1<F^W@C1W8T4`Yf81;fY
XP?7W844_Ij<1<:QT0C2WY84`Z6E1<:SUPBoTH@3]X]d1:mcH@BdQgD4`:NG1<:YW0C2Vi03`JZE1<FX
U`BlSWX4^X9_1;5`FPBaQf`4X6aF0ie`E`BQJ5D4XfY@19iVDPBQI4h4[7aX0k21KPBcP6`4[WIS1:Ma
G`BWMf84ZG]U12`C5P>GPX44b<;?:l:k^AGoool001Cooolb`[^i1<6h]`C5[Yd4`Ib91<:MR0BmZJ83
aib11;fNS0C2XI04`YjB1<:QU@C2XiH4_i640kJ;M0B_Lf44]8Me1<2WU`C2ZI`4`Y^@0l6ZU@C5Z9L4
_8ij1;Z2K`BaL5X4/HM/1:1/EP>ML5L4XFQE1:=ZD0BNIU84XFA>1:alJ0>`PFh4/h1/1:ifH`BWLEl4
YgMR1:UkI@@/4aH3Uh:11<S2cb_2^kTEoooo000Doooo</:k^@C1^;L4aJjM1<6LR@C2WHP4_JVR0lNL
P@BmWX`4`Z6@1<:NTPC2XID4`Z>F1;nAQ0>fRg@4[g=Q1;B7M@C0YiL4`ZVL1<:KT0?1ZYD4aJRG1;b>
NPBjPVl4/G1J1;67K0BPK5H3WG1G1:5XE@BSJU04WVIB1:5TCPB/O6P3/85^1;>0K0B^MV<4Yg5O1:Mg
HPBYNfD4;1<F0iN2P@C8`/l[`[^i5Oooo`005?oooc;2^kT4`KRg1<F^W@C1W8T4`Yf81;fYXP?7W844
_Ij<1<:QT0C2WY84`Z6E1<:SUPBoTH@3]X]d1:mcH@BdQgD4`:NG1<:YW0C2Vi03`JZE1<FXU`BlSWX4
^X9_1;5`FPBaQf`4X6aF0ie`E`BQJ5D4XfY@19iVDPBQI4h4[7aX0k21KPBcP6`4[WIS1:MaG`BWMf84
ZG]U12`C5P>GPX44b<;?:l:k^AGoool001Cooolb`[^i1;n^Y@BmZZD4_95j1;R;M0BdU8@3/92>1<:T
S`C2Y9L<`ZJI1<:IS@>oQW`4]7m[1;QjJ@C3Xi@4`ZBG1<:IS`>oSX@4_I^71;^>N`BbP6`4[G1O1:I]
G0BPJ5D3XFIB1:5/E`BVL5X4YVmE1:1^F0BVL5d3/gYW1;=lJ0B[MV@4YFmM1:MgH@BZNVT4>AXF0e8i
=@CPfM@4`[jm9l:k^AGoool001Cooolb`[^i1;n^Y@BmZZD4_95j1;R;M0BdU8@3/92>1<:TS`C2Y9L<
`ZJI1<:IS@>oQW`4]7m[1;QjJ@C3Xi@4`ZBG1<:IS`>oSX@4_I^71;^>N`BbP6`4[G1O1:I]G0BPJ5D3
XFIB1:5/E`BVL5X4YVmE1:1^F0BVL5d3/gYW1;=lJ0B[MV@4YFmM1:MgH@BZNVT4>AXF0e8i=@CPfM@4
`[jm9l:k^AGoool001Cooolb`[^i1;n^Y@BmZZD4_95j1;R;M0BdU8@3/92>1<:TS`C2Y9L<`ZJI1<:I
S@>oQW`4]7m[1;QjJ@C3Xi@4`ZBG1<:IS`>oSX@4_I^71;^>N`BbP6`4[G1O1:I]G0BPJ5D3XFIB1:5/
E`BVL5X4YVmE1:1^F0BVL5d3/gYW1;=lJ0B[MV@4YFmM1:MgH@BZNVT4>AXF0e8i=@CPfM@4`[jm9l:k
^AGoool001Cooolb`[^i1;n^Y@BmZZD4_95j1;R;M0BdU8@3/92>1<:TS`C2Y9L<`ZJI1<:IS@>oQW`4
]7m[1;QjJ@C3Xi@4`ZBG1<:IS`>oSX@4_I^71;^>N`BbP6`4[G1O1:I]G0BPJ5D3XFIB1:5/E`BVL5X4
YVmE1:1^F0BVL5d3/gYW1;=lJ0B[MV@4YFmM1:MgH@BZNVT4>AXF0e8i=@CPfM@4`[jm9l:k^AGoool0
01Cooolb`[^i1<:XV0C1WX`4]G]R1;fGQ@BbPgD3_I^81<:AS@C2Y9L4`ZRL1<:SU0C2YYT4`Z:B0l:J
Q0BiQ6l4]H1X1;f=P0C5YY/4`ZFE0l:QV0C2WI04_Y>41;EoKPBcP6`4[7QU1:U^G@>PITl4WV9C1:Ib
H0B^MfP4/GYX1;9oK0>`P6h4[WIU2:afI0BWM604ZGeX17==?0<i7ad4G4<o1?_moBO2^kTEoooo000D
oooo</:k^@C2Z9P4`Ij<1;EkHPBmUhD4/X=e0kfKR0C2THd4`ZBG1<:XW0C2Xi@4`ZJI1<:RTP?2VX@4
^HA_1;F0J0BmSH04aJJK1<:UU@?2XIP4`Yf@1;jCQ0BeOfh4/h1/1:ahI@BYKUd3X6I?19iRD`BVLV04
[WMX1;5jJ0BbOf`3/81^1:ifI@R/MV@4YgAP1:UmJ0AcCC`3>AlM15a3?`CkoOdW`[^i5Oooo`005?oo
oc;2^kT4`ZRH1<6NS0BeNf84_IN51;:3M@>mVhP4`Y6=1<:TU`C2Z9`4`Z>D1<:VV@C2XY83`YZ41;V4
K`BeP6P4_Hf01<FVV`C2YID3`Z6H1<:MT0BnTh@4]Gm^1;>0K0B/N6D4ZFiM0j1VC`BNHU<4YW9P1:ig
J0BaNVP4/Wm/0k20KPB^MVD8[7IT1:MdH0BYOFP4Lddl0cTO7@AL@cl4nogm9l:k^AGoool001Coool^
`[^i1<:d[PBoWXd4_GMT1;>=L`B[Q6l4bYR80l:AR0C2X944`ZBG1<:ZW`C2[:84`ZJI1<:RU@?1WX/4
_Y>01;B5LPBhS7L4_I^:1<6IR`?5[9H4`YfE1;bIOPBeOf`4[7MT1:YdG`BZMe/3X6IC1:]/D`BWLf84
[WUZ1;Z6M`BgQg@3/8=_1:j0K0B[O6P4YGQR1:UeI0BYQG44Y75K0h=D@`A:8Ah4HD<n9l:k^AGoool0
01Coool^`[^i1<:d[PBoWXd4_GMT1;>=L`B[Q6l4bYR80l:AR0C2X944`ZBG1<:ZW`C2[:84`ZJI1<:R
U@?1WX/4_Y>01;B5LPBhS7L4_I^:1<6IR`?5[9H4`YfE1;bIOPBeOf`4[7MT1:YdG`BZMe/3X6IC1:]/
D`BWLf84[WUZ1;Z6M`BgQg@3/8=_1:j0K0B[O6P4YGQR1:UeI0BYQG44Y75K0h=D@`A:8Ah4HD<n9l:k
^AGoool001Coool^`[^i1<:d[PBoWXd4_GMT1;>=L`B[Q6l4bYR80l:AR0C2X944`ZBG1<:ZW`C2[:84
`ZJI1<:RU@?1WX/4_Y>01;B5LPBhS7L4_I^:1<6IR`?5[9H4`YfE1;bIOPBeOf`4[7MT1:YdG`BZMe/3
X6IC1:]/D`BWLf84[WUZ1;Z6M`BgQg@3/8=_1:j0K0B[O6P4YGQR1:UeI0BYQG44Y75K0h=D@`A:8Ah4
HD<n9l:k^AGoool001Coool^`[^i1<:d[PBoWXd4_GMT1;>=L`B[Q6l4bYR80l:AR0C2X944`ZBG1<:Z
W`C2[:84`ZJI1<:RU@?1WX/4_Y>01;B5LPBhS7L4_I^:1<6IR`?5[9H4`YfE1;bIOPBeOf`4[7MT1:Yd
G`BZMe/3X6IC1:]/D`BWLf84[WUZ1;Z6M`BgQg@3/8=_1:j0K0B[O6P4YGQR1:UeI0BYQG44Y75K0h=D
@`A:8Ah4HD<n9l:k^AGoool001Coool^`[^i1<:PV0BiP6h4Zei?1:MZF`B/R7T4/9V<0l:QS@C2WH/4
`ZBG2<:VV@C2YIL4`ZFE0kjKS0BmUH44^IR41<2NS0C2XHd4_iB30kfAPPC2Th84^HAf1:ieH0BZKU/4
XfYG1:A[E0>RK5@4VVUI1:I`H0B`Pg44^XMe1;N7M0>`P6d4[WYW1:ieI@B[Mf@4YgEM1;60L@BWKU@3
ZWEU1;ZRVPBo]kHW`[^i5Oooo`005?ooobk2^kT4`Z2H1;V0KPB[GTl4YfYK1:b8N@B`VH`3`Z6=1<:M
R`C2Y9L8`ZJI1<:UU`C2YID3_Y^<1;fEP@BiV8@4`9j<1<:QS@BoU8<3_I621<:CPPBiQ7H4[WEP1:Y^
F`BSJUL4Y6]D0j9/E0BJJET4YW1P1;23L@BjQgD4]hMd0k20K@B^NVL4[WEU1:]gI0BWMEd4/H1a1:M^
E0>ZMFD4^Z:J1;ng]RO2^kTEoooo000Doooo;/:k^@C2X9P4^H1^1:]NC`BWJU/4[8Qi1;2IS0?2XHd4
`Yf;1<:TU`S2YYT4`ZFG1<:UU@>nVh`4_IF11;VHQ0C0WX`4`Z6=1;nDP`>mTH84`Y>21;V4MPB^MF04
ZViK1:=ZE`BTJe@3XVaD19YYF@BVL604/8=a1;Z7M@BgQg@3/81]1:ijI`B^MFD4ZgMT1:MeG@BaP744
YfiD0jYeI@BjXYX4_kNf9l:k^AGoool001Coool^`[^i1<:PV0BiP6h4Zei?1:MZF`B/R7T4/9V<0l:Q
S@C2WH/4`ZBG2<:VV@C2YIL4`ZFE0kjKS0BmUH44^IR41<2NS0C2XHd4_iB30kfAPPC2Th84^HAf1:ie
H0BZKU/4XfYG1:A[E0>RK5@4VVUI1:I`H0B`Pg44^XMe1;N7M0>`P6d4[WYW1:ieI@B[Mf@4YgEM1;60
L@BWKU@3ZWEU1;ZRVPBo]kHW`[^i5Oooo`005?ooob_2^kT3`[J`1<:VW`BiLfX4ZEe=1:a^H`BcSgd4
_I^=0l:TU`C2XiH4`Z2C1<:XVPC1YI@4aJRJ1<:ISP>nXHL4_iF01<6IQ0C0XI84`Z>C1<:UVP?2X9<4
`YB71;V5K0B[NFH4XfaI19iXEPBHJ5L3XFYG1:MeI@BcQ744]hYg1;F9MPBjQW<3/8=_1:ifH`B^MF@4
[75T1:adHPB/OG<4Z75O0j1]F@BeVY@4e=GC9l:k^AGoool001Coool[`[^i0l:f/0C2YYl4^G=Z1:UM
C@B/KV<4/hmm1;fKS@?2Y9L4`Z>F1<:PT`C2Z9X4`JFD1<FXVPC2VHh3_Z671;nEP0C1VH@4`:6B1<:S
T`C2YIX3`Z2C1<:DQ`BiQF`4ZgUV1:=/F@BNJ5H4V6QG0j5ZE`BWMFD4/hAa1;N:M`BeRGH4^XIc0k23
K`B^MV<4[WET1:aaI0B/M684[7ec1:QaG`>PKET4]IZD1=CEdbO2^kTEoooo000Doooo:l:k^@?2][04
`ZJO1;UcJPBYGDd4[6iS1;>?O@BmVhd3`ZBG1<:SUPC2X9<4`ZRJ1<6UU0C5Z9X4`YV>0kjQQ`BoUH04
`IV41<2QTPC2Xi<4`ZFJ0l:PT`C2U8L4^HE/1:]iIPBSK5T4WVQF19QXE`>QJUL4YgEU1;>4L@BgRWL4
]HUf1;Z6L`>`Pfl4[WIS1:ieI0B/LF@4[7AR1:amL`BXLEl3X6eI1;FJU0CDeM<W`[^i5Oooo`005?oo
ob_2^kT3`[J`1<:VW`BiLfX4ZEe=1:a^H`BcSgd4_I^=0l:TU`C2XiH4`Z2C1<:XVPC1YI@4aJRJ1<:I
SP>nXHL4_iF01<6IQ0C0XI84`Z>C1<:UVP?2X9<4`YB71;V5K0B[NFH4XfaI19iXEPBHJ5L3XFYG1:Me
I@BcQ744]hYg1;F9MPBjQW<3/8=_1:ifH`B^MF@4[75T1:adHPB/OG<4Z75O0j1]F@BeVY@4e=GC9l:k
^AGoool001Coool[`[^i0knORPBmRWD4Y6]B1;=[E0BePV`4^91n1<:PT@?2XiH4`ZRJ1<:UU@C2WY44
_Yj>1;nGQ@C2VHH3a8n51;bEO`BlSG/4`9V91<:PT`C2X8h3`Z2C1<6ER@BlNVl4Zg1O1:=/F@BQJUP4
X71N0iigHPB^OFX4/8A_1;R8M0BjS7T4]H1^0k1lJPB^NVP4[6mO1:a_G@BWLf84[8Ea1:YPAP>aR7L4
YG9R1;W6cRO2^kTEoooo000Doooo:l:k^@>oWhX4_HYe1:A[DPBcJe@4]H9/1;R@OPC2X943`Z>F1<:X
VPC2YID4`YjA1;jNSPBoUhD4`YV60lB?Q@BlUGl4_8ek1<2IR@C2X9<4`Z2>0l:PT`C1UHT4_7Y_1:]`
G`BSK5T4XFYH1:1`GP>NMf84[WeZ1;24K`BhR7@4^Xai1;F0KP>`O6X4[WYX1:a_G`B/Ked4Yg=R1:b5
L@BZH4H3/HQg1:EbHPBia/hW`[^i5Oooo`005?ooob_2^kT3_in:1;f:M@BTJe84/f]D1;F2K0BhT7h4
`Z2A0l:SUPC2Z9X4`ZFE1<:NT@BnWXh4_iN51<:IQP?4ShD4_9Eo1;b=N`C0VHT4`Z2C1<:PSP?2X9<4
`IF91;ajK`B[L5l4XfaI1:5ZF0BPL5h3WWMR1:imJPB`Q6l4^8Qd1;Z<N@BeP6h3/7aZ1:ijJ0B/Kel4
[6mM1:McHPB/QG44ZV160k68M`BULV84^LK>9l:k^AGoool001Coool[`[^i0knORPBmRWD4Y6]B1;=[
E0BePV`4^91n1<:PT@?2XiH4`ZRJ1<:UU@C2WY44_Yj>1;nGQ@C2VHH3a8n51;bEO`BlSG/4`9V91<:P
T`C2X8h3`Z2C1<6ER@BlNVl4Zg1O1:=/F@BQJUP4X71N0iigHPB^OFX4/8A_1;R8M0BjS7T4]H1^0k1l
JPB^NVP4[6mO1:a_G@BWLf84[8Ea1:YPAP>aR7L4YG9R1;W6cRO2^kTEoooo000Doooo:l:k^@>gPfT4
Mc`T18e>?`A[>C44`8if1;jJR@C2X8h3`Z2A2<:PT`C2WHP4_iR41;ZBPPBfQ7H3]HIf1;^@O0C2XX`4
_in:1<FSU0C2X9<3`Z2A1;jFR@BeQfl4[6mS1:E`E@BOIeH4Z79P0jUiI`B/N6L4]X=c1;V5M0BcQ6h4
]X]f0k60K0B_OVX4[7aX1:MbH0BWLF@4ZW][1:EXCP>YIe84[g9S1;VNTRO2^kTEoooo000Doooo:l:k
^@>gPfT4Mc`T18e>?`A[>C44`8if1;jJR@C2X8h3`Z2A2<:PT`C2WHP4_iR41;ZBPPBfQ7H3]HIf1;^@
O0C2XX`4_in:1<FSU0C2X9<3`Z2A1;jFR@BeQfl4[6mS1:E`E@BOIeH4Z79P0jUiI`B/N6L4]X=c1;V5
M0BcQ6h4]X]f0k60K0B_OVX4[7aX1:MbH0BWLF@4ZW][1:EXCP>YIe84[g9S1;VNTRO2^kTEoooo000D
oooo:l:k^@>gPfT4Mc`T18e>?`A[>C44`8if1;jJR@C2X8h3`Z2A2<:PT`C2WHP4_iR41;ZBPPBfQ7H3
]HIf1;^@O0C2XX`4_in:1<FSU0C2X9<3`Z2A1;jFR@BeQfl4[6mS1:E`E@BOIeH4Z79P0jUiI`B/N6L4
]X=c1;V5M0BcQ6h4]X]f0k60K0B_OVX4[7aX1:MbH0BWLF@4ZW][1:EXCP>YIe84[g9S1;VNTRO2^kTE
oooo000Doooo9l:k^@C2^;D3]XYn1816<`A?:R04GS8^19QdI`BnVXX4`IjA0lFSUPC2X8T4_IJ21<FP
S`BlSWX4`iJ11<6@PP>nOG<4^HE_1;B5L0C0WXP4`jBD1<:PT`?2X904_Y601;9mJ`BUJeP4XFAC19aZ
E`BRJEL3Z7QU1:ikI`BdOFT4]8Ac1;5gJ0BaOFX3ZgaZ1:EfI0BWN6D4Yg9P1:MaI0BWMfD4TE4j0iU9
;`BaL5@4_:6Q9l:k^AGoool001CooolW`[^i1<:h]@>fRWh4P4Hc14lZ80AN<Rh4V7AW1;jJRPC1WY43
aJ>F1<:PR@BmUX84aJ2?1;b>NPC3UX44`I220kimL`BiQFl4]8E`1<2NR0C3Y9@4`Z2C0l:PT0BnTH04
/We[1:E[F0BQI5<4W6YG1:9YE`>XN6D4[W]W1;AmJ@BdQ7<4/GMX1;5mJP>[O6X4YGIT1:MhI@BWLV04
Yg5T1:MgI@BADCX3VDT_1;5`E0BlXJ4W`[^i5Oooo`005?ooobO2^kT4`[Re0kJ:OPB0AS<4CbXP15hb
;PBHM6L4_YZ:1<6NT@?5XiH4`Z291;fFPPC5X8l4_8ij1<>FP@C1T883_Wec1;V5K`BdQG04`9j81<>T
U0C2X9<3`Z2@1;jAP0BbOF/4YF]H1:5TD`BLJUL4XVUG0jQhI@B^NfL4]7eY1;B4L`BaMfP4/GeZ0j]l
JPBUMV@4YgQU1:MbH0BWLF@4YgMU195A>P>IBBl4/G1D1;bQXBO2^kTEoooo000Doooo9l:k^@C2^;D3
]XYn1816<`A?:R04GS8^19QdI`BnVXX4`IjA0lFSUPC2X8T4_IJ21<FPS`BlSWX4`iJ11<6@PP>nOG<4
^HE_1;B5L0C0WXP4`jBD1<:PT`?2X904_Y601;9mJ`BUJeP4XFAC19aZE`BRJEL3Z7QU1:ikI`BdOFT4
]8Ac1;5gJ0BaOFX3ZgaZ1:EfI0BWN6D4Yg9P1:MaI0BWMfD4TE4j0iU9;`BaL5@4_:6Q9l:k^AGoool0
01CooolW`[^i1<6YV`>lThX4A`h914PP6@A99b84Y7]]1;ZEPPC2WXX3_Ij=1<:PT@BhTGh4XWMT19e^
F0AkDdT4Kd@j0i9==PBbKE`4Z5Dm1:aMA0CB]j44aJJK0l:PT`BnTh@4/WY[1:E]E@BOJe04W5m=1:Ae
H`>OL604Ug9Q19ebH0BWNFT4YgiX1;:0K0>^Of`4ZGYW1:=eHPBXMF84[GAT1:MdI@B<Cc`3P3XZ19E=
>`BgXYDW`[^i5Oooo`005?ooobO2^kT4`JVK0kbCRPA73PT4B20I14TW8PBTNfd4^YF21<:NRP>mWXd4
`Z2A1;RAOPBRMf@4WFiH17]CB@A_A3X3TTdf1;9]G0BXECd4[5e41=:gX@C5YY/3`Z2C1;jCQ0BbNV/4
YFeE19m[D0BLGdd4Y7ES0im`H0BGLV44WG9P1:MiJ@BWOVP4/X1/0jioK0BYNVL4XgER1:QeHPB]M6@4
YgAU18a??0>0>RX4UDdk1;NRUBO2^kTEoooo000Doooo9l:k^@C1ZI/3_9>:14L>2@A881T4BBLR1:Ak
K@BjUH84`Yj:0kfNS@C2X944^95n1:9gI0BMKUP4Ne=916m4>P>BCCH4/VeL1:QE?@B/GD@4d[NQ1<FV
V`?2X9<4_Y>41;9jJ`BUKED4Wf]@19aOC@BTMF<3Wg1P19MbH@BMLV04YgUY1:MnJ0BbP6`3[Wm/1:Uj
I`BSMF84Z7ER1:edI0BWM6D4S4ll0h0j:PBECC/4]j:E9l:k^AGoool001CooolW`[^i1<6YV`>lThX4
A`h914PP6@A99b84Y7]]1;ZEPPC2WXX3_Ij=1<:PT@BhTGh4XWMT19e^F0AkDdT4Kd@j0i9==PBbKE`4
Z5Dm1:aMA0CB]j44aJJK0l:PT`BnTh@4/WY[1:E]E@BOJe04W5m=1:AeH`>OL604Ug9Q19ebH0BWNFT4
YgiX1;:0K0>^Of`4ZGYW1:=eHPBXMF84[GAT1:MdI@B<Cc`3P3XZ19E=>`BgXYDW`[^i5Oooo`005?oo
ob?2^kT4`k^j1;bKR`>bOFX4GS8_12X@3P@o6QP4SgQ[1;fFQ0BlUh<3aIj:1<:PS0BoVXT4YgYV18m]
H0AK?C84@AlL0e8W70A`BCl4Ve4m18i?@`BHHUH4`9^<0l:PU0BnTgl4/WaY19mVD@BNJD/4MR4A1;9n
I@>ZMUH4YgAP19iSB`BiOVX4Xg=T1:IiH`>_OV`4[7aX19i_G0BJLf44Y7=T1:=dGPB6B3X3SDTg19]B
APBeS804_kNf8l:k^AGoool001CooolS`[^i1<>k^PBlVh/3/WeZ15hb;`@Z40h4?aXH18mhJ`BmUX@4
_9N30lFNRPC2X8`4_iZ91:MjIPB?KF04Fcdb144O70=B9a`4L4To19]A?@B>Cd<4V69F1<2KS0?2X9@4
_Y=o1;9lJ@BOIU44WVU;17HQ4@BbOVD3ZWIF1:MdH0BNHd/4^GiZ1:=cI0BVNF<3[gi/1:alJ0BNKe`4
VW=Q1:AcI0BSM5h4QTPj0he9=`BKDTH4]Hb01;ng]R?2^kTEoooo000Doooo8l:k^@C3^kX4_9^;0k9m
JPAN<Rl4:Q0>13lJ60B?N6/4_IJ41;bGP`?5WXX4`Z2<1;nJR@BWNVH4SfeP15/m<PA17a`3DRLL1719
?`BKDCd4STm319QREPC0Vh`3`Z2D1;jCO`BbO6T4WfIA19iYB`Af8A44/WiU0jYfEPBWM604WV=;1;Un
JPBSLf@4YWUS0jmnK0B/O6P4WVmL19YcH@BTLf@4XgAN18I8>P>=BCL4Ve961;F<P0Bo]kHS`[^i5Ooo
o`005?ooob?2^kT4`k^j1;bKR`>bOFX4GS8_12X@3P@o6QP4SgQ[1;fFQ0BlUh<3aIj:1<:PS0BoVXT4
YgYV18m]H0AK?C84@AlL0e8W70A`BCl4Ve4m18i?@`BHHUH4`9^<0l:PU0BnTgl4/WaY19mVD@BNJD/4
MR4A1;9nI@>ZMUH4YgAP19iSB`BiOVX4Xg=T1:IiH`>_OV`4[7aX19i_G0BJLf44Y7=T1:=dGPB6B3X3
SDTg19]BAPBeS804_kNf8l:k^AGoool001Coool4`[fk1<:n_@C2^[P4`[jm4l:k^@AQ8AT4om2d0kb;
M`A`?384<1XR134D4@BNNF`4_ib81<:PS0>lVHH4a:6<1<FSU0BhT7l4/7a/19E/H@A=>SP3>bLU158k
=0AaEDh4VF=F1;B<N@C0YYH3`ZZO1;jPS`BbPVh4WfI?18iLBPAl@344M4<m0ga?@@@V1PP4Sddj17]E
A@A^?B/4YW1L0jAYB@BeNUl4X7MU19Y]G0BTLF44UFED16`i;0=f>c04[FiL1;ZFT`C5_K`S`[^i5Ooo
o`005?ooo`C2_K/4`[jm1<:j^0C2_[dC`[^i164Q6@Cod;@3_8]g170l<P@`6R84<A@A19iiK0BoW8P4
`Z2<0kbIQPC4XH`4aJ>D1;R@O`B`O6`4UFaQ14dj>0<k9bD4DS/d175ECPBIHeH4]8ai1<2VUP?2ZYl4
_Z2?1;:2KPBOITl4SUa:17a0<@Ad@cd3O4m112H620B?CCX4NeE516hm:`BVL5`3Y6U91;EjG`BPMfD4
VVeL1:AaH@BEIE@4K3T/0gHk<0B]KU`4^YJC1<Fm_2?2^kTEoooo000Doooo1<:m^`C2_[d4`[Zh1<:n
_A?2^kT4HB4I1?o@]0>lRgL4L3`b130J8P@a5144WWU/1;nLR0C2X8`3_9V61<BQS0C5Xi@4^91o1;1l
K0BEK644CCXh0c/W9@AB>c@4LEE>19USEPBdS7T4`:JF0l:ZW`BnX8l4/X9^19mVC`B>G4X4O40a17A3
?@=lCd449PH818m=>PAkEDD4KSd[1:I`G0>TJDT4]GYO1:1gI@BJKE`4Y75Q19EUE0A/>B`3MS/`1:e^
G0BjUY<4aKfl8l:k^AGoool001Coool4`[fk1<:n_@C2^[P4`[jm4l:k^@AQ8AT4om2d0kb;M`A`?384
<1XR134D4@BNNF`4_ib81<:PS0>lVHH4a:6<1<FSU0BhT7l4/7a/19E/H@A=>SP3>bLU158k=0AaEDh4
VF=F1;B<N@C0YYH3`ZZO1;jPS`BbPVh4WfI?18iLBPAl@344M4<m0ga?@@@V1PP4Sddj17]EA@A^?B/4
YW1L0jAYB@BeNUl4X7MU19Y]G0BTLF44UFED16`i;0=f>c04[FiL1;ZFT`C5_K`S`[^i5Oooo`005?oo
o`C2];<4`[Rg1<:g]PC2]K@?`[^i16Pe;`AO=2h4B0<00jQOB@A=92d4=1XF13XJ6PB8LFH4_9V61<2N
S0>jR7@4_Yf31<NZVPBoWXl4]hai1:YhI`BQLUh3WW5N18mNBPBIK5H4[7aZ1;N8MPC0XI83`ZJI1;jE
QPBbQW44YFM@19UVCPB@EDH4PU]C0feAB`@N3144AAlG168l=PA:;RL4LDHf0hEIB@BAHdd4W6EC19Qc
H@BTM5l4KS/e15dd9@=M:b04VeQ61<Fm]0C8`;lS`[^i5Oooo`005?ooo`C2];<4`[Rg1<:g]PC2]K@?
`[^i16Pe;`AO=2h4B0<00jQOB@A=92d4=1XF13XJ6PB8LFH4_9V61<2NS0>jR7@4_Yf31<NZVPBoWXl4
]hai1:YhI`BQLUh3WW5N18mNBPBIK5H4[7aZ1;N8MPC0XI83`ZJI1;jEQPBbQW44YFM@19UVCPB@EDH4
PU]C0feAB`@N3144AAlG168l=PA:;RL4LDHf0hEIB@BAHdd4W6EC19QcH@BTM5l4KS/e15dd9@=M:b04
VeQ61<Fm]0C8`;lS`[^i5Oooo`005?ooo`C2];<4`[Rg1<:g]PC2]K@?`[^i16Pe;`AO=2h4B0<00jQO
B@A=92d4=1XF13XJ6PB8LFH4_9V61<2NS0>jR7@4_Yf31<NZVPBoWXl4]hai1:YhI`BQLUh3WW5N18mN
BPBIK5H4[7aZ1;N8MPC0XI83`ZJI1;jEQPBbQW44YFM@19UVCPB@EDH4PU]C0feAB`@N3144AAlG168l
=PA:;RL4LDHf0hEIB@BAHdd4W6EC19QcH@BTM5l4KS/e15dd9@=M:b04VeQ61<Fm]0C8`;lS`[^i5Ooo
o`005?ooo`C2];<4`[Rg1<:g]PC2]K@?`[^i16Pe;`AO=2h4B0<00jQOB@A=92d4=1XF13XJ6PB8LFH4
_9V61<2NS0>jR7@4_Yf31<NZVPBoWXl4]hai1:YhI`BQLUh3WW5N18mNBPBIK5H4[7aZ1;N8MPC0XI83
`ZJI1;jEQPBbQW44YFM@19UVCPB@EDH4PU]C0feAB`@N3144AAlG168l=PA:;RL4LDHf0hEIB@BAHdd4
W6EC19QcH@BTM5l4KS/e15dd9@=M:b04VeQ61<Fm]0C8`;lS`[^i5Oooo`005?ooo`C2/[44`[Fd5l:k
^@AB9B44ARDM13dF5@=07A/48`T=13/K6@@k6AL4SgEX1;fLR0BlW8/3_8j61:E/GPB[M5l4aYb51;ZD
O@B/NFX4WUa;0j9SB0B/JE04[VQ>1<ZNQ0C2UX<4`9b=0l:XU`BnUHL4/XMg1:E`F`BNJD`4VW5B1:Q_
F`>RLF44IdQ312PP9PA><2/4EC`e15a7@0>1Ed@4UVUJ1:YfG@BNKUl4VW5M15/a90A37Q/3F2XO18Tm
;@BnXIPW`[^i5Oooo`005?ooo`C2/[44`[Fd5l:k^@AB9B44ARDM13dF5@=07A/48`T=13/K6@@k6AL4
SgEX1;fLR0BlW8/3_8j61:E/GPB[M5l4aYb51;ZDO@B/NFX4WUa;0j9SB0B/JE04[VQ>1<ZNQ0C2UX<4
`9b=0l:XU`BnUHL4/XMg1:E`F`BNJD`4VW5B1:Q_F`>RLF44IdQ312PP9PA><2/4EC`e15a7@0>1Ed@4
UVUJ1:YfG@BNKUl4VW5M15/a90A37Q/3F2XO18Tm;@BnXIPW`[^i5Oooo`005?ooo`C2/[44`[Fd5l:k
^@AB9B44ARDM13dF5@=07A/48`T=13/K6@@k6AL4SgEX1;fLR0BlW8/3_8j61:E/GPB[M5l4aYb51;ZD
O@B/NFX4WUa;0j9SB0B/JE04[VQ>1<ZNQ0C2UX<4`9b=0l:XU`BnUHL4/XMg1:E`F`BNJD`4VW5B1:Q_
F`>RLF44IdQ312PP9PA><2/4EC`e15a7@0>1Ed@4UVUJ1:YfG@BNKUl4VW5M15/a90A37Q/3F2XO18Tm
;@BnXIPW`[^i5Oooo`005?oooao2^kT4FB`Q13<?30@`61@3=QHC12lD4P@W4Q44BRXX191XG0C7WXT4
_i^80kfKS@BiU8D4VfmN18aGB`B9HeH4Sf=D16e;@0=/B3l4MDPk18MGB@BBIUT4/Xal1;fKRP?2VH/4
_Yb21;:4L@BUK644SDXc19MB>0B/QEh3[G]U1:MhI0BTLf<4SV9A185BA`BCGdh3Wf]H1:MaG0BJLed4
[G]Q19EXE@@f71L4<1LC0fm6?@AY;R<4^I289l:k^AGoool001CooolO`[^i15T/8@@c3``4<1PD0cHF
4`@_51849a8A14XZ:0B@J5`4aij91;nKR0>mVhd4^IB519]_GPB<Ed/4RF=F18mSE0A]Bd03K4Po17E8
>`B7EdT4TVII1;:<O0BmVhX3`YV;1;jLPPBbQ744YFaQ18e:<`BGDSP4[8EN0jekI@BWN6@4Y7=S18iR
D@B1DTL4Tem>0im[F0BWLE`4VW=M1:ekH@BEJ5D4=Q`G130G4`=_ASd4JBhS1;V@R2O2^kTEoooo000D
oooo7l:k^@AI;244<`l<130H50<f5Q<4;a@B12LB4@A::RP4T6QL1<NNR@BoVhP3_I^=1;VDQ@BKKeh4
S5M;18USEPB?He@4KD]00fa8?`AeB3/4QeM9199VF@BbS7`4_I^:0l:IR`BnW884/XAa1:E/H@B=BS<4
Ue8h1:b5GP>]NfD4YgQT1:AcH`B>HU44PE9719=OCP>OJeP4Yg5L19YcG@B]Nf44UFQE13HL5`@`5a<3
KdHm16T^8`BiT8PW`[^i5Oooo`005?oooao2^kT4FB`Q13<?30@`61@3=QHC12lD4P@W4Q44BRXX191X
G0C7WXT4_i^80kfKS@BiU8D4VfmN18aGB`B9HeH4Sf=D16e;@0=/B3l4MDPk18MGB@BBIUT4/Xal1;fK
RP?2VH/4_Yb21;:4L@BUK644SDXc19MB>0B/QEh3[G]U1:MhI0BTLf<4SV9A185BA`BCGdh3Wf]H1:Ma
G0BJLed4[G]Q19EXE@@f71L4<1LC0fm6?@AY;R<4^I289l:k^AGoool001Coool8`[^i1<:j^0C2_[d?
`[^i16Dj;`@e3@X4;A<A0bPD4@@G0@D4<ADB14@/:@B<JE/4`iZ51<FQS@?2X944`Z6E1;nKS0B`Q7D4
T5mK18EKF@BJGeD3SeQ:18aGB@BCFTd4[Wm_1<2PT@C1Vh`3a9R>1<6;P@BdRgP4YgQ/18YAC0AW<2X4
K3XY0g=3;@BmNE`4]HA/1:ahH0BRMUl4VW5O0jEaF`BGK5X4[GEY19icG@A^?Rh4?1`G13DS8@=`@cD4
ST0/175>A`ChoolS`[^i5Oooo`005?ooo`S2^kT4`[Zh1<:n_@o2^kT4ICX_13D=2P@]4a43:1@A11L1
1@@a5A84A2`Y18aYF`C3VXD4aJ6=0l:PT@C2XID4_i^<1;24M@B@Ge/4QE]I19YOE@>?F4X4S5M919=J
C@B^Ofl4`:2A1<6KS0?4V8h4`H^11;B;N0BWN6`4RU5<16L`:PA/>RT3Ld<]1;eiG0BeQ6`4[7QP1:9f
G`BJLEl3YG5K19M/FPB]MFT4WW=M16hn;P@l71L4=B<Q0g13=@B>@2`4LDi71?Soob?2^kTEoooo000D
oooo2<:k^@C2^[P4`[jm3l:k^@AU>Rl4=@d:12dC4@<X51445`45134E4PA4;2T4S6UK1<>JQ@C5XHd3
`Z2A1<:QU@BoVh`4/8Ae191OF`B5FeT4VUmE0hmHBPB<EdT4TeY=1:ioK`C0X944`I^<0lBHSPC1Rh44
]8]h1:MhK0B:DD`4Ic0Z16`j:@=c@bd4_GUL1;F4K0B/N604XWIO19YaG`>ULE/4UfaJ1:eeJ@BNLed4
KSh^13`L5`@e8b43L4<e18i0;0AaCTL4n?oo8l:k^AGoool001Coool8`[^i1<:j^0C2_[d?`[^i16Dj
;`@e3@X4;A<A0bPD4@@G0@D4<ADB14@/:@B<JE/4`iZ51<FQS@?2X944`Z6E1;nKS0B`Q7D4T5mK18EK
F@BJGeD3SeQ:18aGB@BCFTd4[Wm_1<2PT@C1Vh`3a9R>1<6;P@BdRgP4YgQ/18YAC0AW<2X4K3XY0g=3
;@BmNE`4]HA/1:ahH0BRMUl4VW5O0jEaF`BGK5X4[GEY19icG@A^?Rh4?1`G13DS8@=`@cD4ST0/175>
A`ChoolS`[^i5Oooo`005?ooo`S2^kT4`[Nf1<:e]0o2^kT4G3dh140O70@_4Q03;Q@A120=2P@[4A04
AR`Y18EPDPBaS7X4`9b80l:PT@C2Y9L4`ZJI1<:XW0S2Y9H4`Z>D0l:XW0C2Xi@4`Z>C1;nJQ0BmWXd4
_j:B0kVEP@BlUH04^I=o1;B;N@B]PG84RUmE15hh=P=;<B/4ERhS16lm:`BPGDT4TFQA1:1SB@>FGdT4
ZgIV19EZF@BUKUh4CB<N13HG4`@f6ah3BA@>17hV60AS?SP4VHZ78l:k^AGoool001Coool8`[^i1<:g
]PC2]K@?`[^i15`m>0A07a`4;a8@0bhD4@@P3@X4:a4@14H/:@B5H584/Haj1<2LR0?2X944`ZBG1<:V
V@C2Z9`8`ZBF1<:SU0?2Z9`4`Z>D1<:ST`BoVX@4_Ij=1;nRTP>iUH44_9F01;VCO`BdRgT4[H5b18YO
E@AN>3H3Bc4[15H^8`A_?B/4X5e9195XD@BPHdT3UUm91:]fIPBEJUT4YFiN14dS7P@f5a<4=Q/N0dTD
3PAn9QP4Hchh19V:Qb?2^kTEoooo000Doooo2<:k^@C2]kH4`[Fd3l:k^@AL?CP4@1lL12lB40<^5144
80d:12/A40A6;2T4QF1B1;6<NPC0W8P3`Z2A1<:TU`C2YYT4`ZRL2<:TUPC2Xi@3`ZRL1<:SU0C2Xi<4
_iZ41;fNS@BoXY83^IF11;bEP0BiTgl4]8]i1:f1LPB:GeD4GSPf0d/a:`AF;R<4Kcd[1:1MB@BAJ544
X6=90iIOB@B[MVH4UFYI1:E^GPA=8ah4=QLC13HK7P=950h4ORHH16<n>0BIRXLS`[^i5Oooo`005?oo
o`S2^kT4`[Nf1<:e]0o2^kT4G3dh140O70@_4Q03;Q@A120=2P@[4A04AR`Y18EPDPBaS7X4`9b80l:P
T@C2Y9L4`ZJI1<:XW0S2Y9H4`Z>D0l:XW0C2Xi@4`Z>C1;nJQ0BmWXd4_j:B0kVEP@BlUH04^I=o1;B;
N@B]PG84RUmE15hh=P=;<B/4ERhS16lm:`BPGDT4TFQA1:1SB@>FGdT4ZgIV19EZF@BUKUh4CB<N13HG
4`@f6ah3BA@>17hV60AS?SP4VHZ78l:k^AGoool001CooolO`[^i16E3?`A<<2d49a<A0c0D4@@]4a44
<APK14D[9`AoFDT4]hUe1<NRSP?2X8l4`Z>H1<:YW0C2ZYl4`[6/1<:^YPC2ZZ03`ZRL1<:YW@C2YYT4
`Z>C1<:MQ`C2X8`3_YJ21;b@O@BlS7T4_9J21;b>O`BdRGX4Z7]_0i5RF0AVAd44DCD`15Pf;PA/ASX4
MEE80gMCAPB;Edl4YGER19mXE@A:81`4<1@B12XD4P<V3P`4AATF15lg<PBNT8`S`[^i5Oooo`005?oo
oao2^kT4ID<o14``;@@W4a43<1@A12dC4@@a61/4AB/W17mIB@BgRGD4aj:>0l:PS`C2XiP4`ZVL1<:Z
W`C2/J`4`ZjV1<:ZX0?2Z9`4`ZVM1<:VV@C2Xi<4`Yf71<:PS0>nUX84_91m1;b<N@BlUX84_8io1;B9
NPBXNfl3TF9H16I7@@AA=C04F3H^16a6>PAeEDP3Me=618]GC`BUMF84WfQE14XP70@`5184:Q@B0bH>
30A56AH4GcLb19j@S2?2^kTEoooo000Doooo7l:k^@AU@cl4C30]12LC4@<`5144;A<A134H6`A5:bL4
OeU91;N9M@C7XXh3`Z2?1<:SV0C2ZI`4`ZZO1<:a[0C2[ZH4`ZZP0l:XW0C2ZId4`ZJI1<:ST`C2WHL4
`Z2<0kjFPPBlT7d4_8ai1;bFPPBlSWl4]8Uj1:QkK`>AHUP4ITM1154e<0AH=Rh4K4Hj17EEB0=gDdH4
ReM?1:EeHPBOJ5D4BR0L130D4P@Z51839Ph<14DI5PAO=c84WY2<8l:k^AGoool001CooolO`[^i16E3
?`A<<2d49a<A0c0D4@@]4a44<APK14D[9`AoFDT4]hUe1<NRSP?2X8l4`Z>H1<:YW0C2ZYl4`[6/1<:^
YPC2ZZ03`ZRL1<:YW@C2YYT4`Z>C1<:MQ`C2X8`3_YJ21;b@O@BlS7T4_9J21;b>O`BdRGX4Z7]_0i5R
F0AVAd44DCD`15Pf;PA/ASX4MEE80gMCAPB;Edl4YGER19mXE@A:81`4<1@B12XD4P<V3P`4AATF15lg
<PBNT8`S`[^i5Oooo`005?oooao2^kT4J3hb14h/8`@n8R03;1<A13@>2`@h6QT4ARPP16Q7?0B^P6X4
_Ib80lFSSPC2X944`ZBG1<:XW0C2YYT4`[6/1l:^YPC2ZId4`ZJI1<:UU@C2YIL4`Yj70kjFPPBlUX84
_91m1;b<N@BlT7l4]hUi1;:6L`>XP6d4Wg=R19A_G`B2GDh4Ne=718IIBP>IJU`4W6eM19aWF`B0DC`4
BB<N130D4P@g6AL39A<A12lC4@A=:R44W8b<1=GJeao2^kTEoooo000Doooo7l:k^@AX?S84CR`S13hR
80</4a44=0h;13PJ6@A6:204J4Ll1:j0JPBmW8P3aJ>>1<:PT@C2Y9L4`ZRL1<:VV@C2/J`7`ZjV1<:Y
W@C2YYT4`ZFE1<:UU`C2WXL3_YJ21;bFPPBlT7d4_8ai1;b@O`BgRGT4/XIc0jR0K@BOLf84U6mO189M
CPAkDdL4QUU:0iUZG0BLKEd4W6MK181A?0A98ah4<1@B13LI5`<U4a44;a<A14dZ8@BLS8`4eM[G7l:k
^AGoool001CooolO`[^i16Pn<PA>;2<4?R8P0b`C4@@d3P/4>1XI14HX80AXAc`4[X1Z1;fLR0?5Xhh4
`Z2A1<:TU`C2Z9`4`ZJI1<:a[0O2[ZH4`ZVM1<:VV@C2YID4`ZFG1<:NQ`>nUX84_9J21;b@O@BlS7T4
_91o1;N9N@BbQW<3Z81]19mcHPBDKel4PUe>17]CA`B6FDX3VFYL19a]G@BLIe/4P54l14TS7P@`5184
=aTG0bDC4@@_4a44CBXQ19b<S0CEf]LO`[^i5Oooo`005?oooao2^kT4G3HY15<c;P@l81`3>QXH12<=
2P@d5184=AHC15hd:0B;G4<4ain<0l2QS@C2X944`ZBG1<:[XPC2ZZ04`ZJI1<:a[0O2[:84`ZJI1<:R
S`C2X8l4`IV90l6DP@BlS7T4_9=o1;b@O@BlS7T4]hMd1;>0K@>cOf`4Zgm/1:MfI0B^O6P4YGQU1:=b
H0>XLF44Z75R19]UD@AK<b`4;A8=13TK7P@T3Q439Pl<11L11@A17AT4P65J1<:h^Ao2^kTEoooo000D
oooo7l:k^@AL=RT4Dc<^13`P70<j6QP48`d:13@D4P@e5Q<4GS@X18]L@`C7Wh`3`:6=1<:PT@C2Y9L4
`Z^R1<:ZX0C2YYT4`[6/1l:/XPC2YYT4`Z:?1<:PS`C1VHT3`IB11;b<N@BlTgl4_91m1;b<N@BgQg@4
/h1]0k=oK0B[Of`4YgIT1:ilJ0BUN6D4Xg9P0jQaH@BXLF84VfEA15/c;0@]4Pd4>A/N12@>4@<V3``4
5`45144M6@B0HEX4`[Ri7l:k^AGoool001CooolO`[^i15`f:@AC<bh4?20L0cXJ60@S3@X4=1@B13DF
4`AN=2P4Rea31<NOS0?0XHd4`Z2A1<:TU`C2Zj84`ZZP1<:VV@C2/J`7`ZbR1<:VV@C2XXl4`Z2?1<6I
R@?1U844_8ai1;bCO`BlT7d4_8ai1;N7M0BcP6d3/gm/1:]oK0BWMV@4[WaX1:EhI@BSLV03Z75Q1:Qa
HPBKIE44Fc</12dB3@@i6ah490hA0bH?30@G0@D4@AdI181QFPC2^;TO`[^i5Oooo`005?oooao2^kT4
G3HY15<c;P@l81`3>QXH12<=2P@d5184=AHC15hd:0B;G4<4ain<0l2QS@C2X944`ZBG1<:[XPC2ZZ04
`ZJI1<:a[0O2[:84`ZJI1<:RS`C2X8l4`IV90l6DP@BlS7T4_9=o1;b@O@BlS7T4]hMd1;>0K@>cOf`4
Zgm/1:MfI0B^O6P4YGQU1:=bH0>XLF44Z75R19]UD@AK<b`4;A8=13TK7P@T3Q439Pl<11L11@A17AT4
P65J1<:h^Ao2^kTEoooo000Doooo7l:k^@AU?304BBhZ14T^:`<j7Q`4>1PF12XB40@h7Q`4BRhZ16]1
<`BaP6L3aj>>1<:SU0C2XiH4`ZfQ1<:a[0C2ZZ04`ZRL0l:YW@S2YYT4`Z:B1<6NQ`C1VHD7_91m1;b<
N@BjS7T4_HUf1;Z9MPB`P6d3[Wm/1:j1KPB[P6d4YgIT1:ahI@BNLV03WW5O19E^F`AkD444BB<M13TQ
7P@K1PX49@lC0aD01@@Q3A44;A8@16m@B`BcWi/O`[^i5Oooo`005?oooao2^kT4IC``14T^:PA9;R/3
>QhL13PH5P@Z4Q04>1hL14X^:PA[@C<4/H1W0lNSSPC2Xi@4`Z>F1<:]X@C2/J`4`ZZP1<:XW0?2ZId8
`ZJI1<:RTPC1WXL4`IV51kb@O@BlS7T4^Xai1;f9MPBjRGH4/81]0jioK0B^PFh4Zh1]1:MfI0B/N6D4
WW9P0iiaG`BEKU/4Ne1114TS7@@i8Ah46`H:12D?4`<E00D48@dA12dB40A_D4/4/inK7l:k^AGoool0
01CooolO`[^i16Dl<0A9;RX4BBh[0cXN70@h61H4:Q8@13PN70A:;RX4Jd4c1;60I`?7Xhh4`Z>D1<:S
UPC2[J44`[6/1<:ZX0C2Z9`3`ZVM2<:VV@C2XY84`Ij71<6IQ@NlT7d4_8ai1;Z<N@BmRGH4^XUf1;20
K@>^Of`4[X5^1:^0K@BWMV@4[7QU19ibH0>NLEl4UFiK17]@@@A98ad4>B4N11/62P@U3a<35@05124=
4@@]4Q04Ke1;1;>OVao2^kTEoooo000Doooo7l:k^@AU?304BBhZ14T^:`<j7Q`4>1PF12XB40@h7Q`4
BRhZ16]1<`BaP6L3aj>>1<:SU0C2XiH4`ZfQ1<:a[0C2ZZ04`ZRL0l:YW@S2YYT4`Z:B1<6NQ`C1VHD7
_91m1;b<N@BjS7T4_HUf1;Z9MPB`P6d3[Wm/1:j1KPB[P6d4YgIT1:ahI@BNLV03WW5O19E^F`AkD444
BB<M13TQ7P@K1PX49@lC0aD01@@Q3A44;A8@16m@B`BcWi/O`[^i5Oooo`005?oooao2^kT4HT<n154b
;@A=<Rl3AR/Y13XI5`@T3P/4?A/I154_9PAXAST4SVA@0l2KR0C5XHl4`Z2F1<:SUPC2[J44`[6/1<:^
YP?2ZZ04`Z>D1<:VV@C2XYD4_if;1;VBO`>jSWX4_HUf1;n<N`BgS7H4]HIc1;F5M0B`Pfd3[Wm/1:il
J0B/OVX4[7aX1:EaGPBUMf@3VVYG191ND0A]?2d4A1lK12D?30@U3a<46`H:0b0=2`@O3104=aTG16E<
APB1IF0O`[^i5Oooo`005?oooao2^kT4HT<n154b;@A=<Rl3AR/Y13XI5`@T3P/4?A/I154_9PAXAST4
SVA@0l2KR0C5XHl4`Z2F1<:SUPC2[J44`[6/1<:^YP?2ZZ04`Z>D1<:VV@C2XYD4_if;1;VBO`>jSWX4
_HUf1;n<N`BgS7H4]HIc1;F5M0B`Pfd3[Wm/1:ilJ0B/OVX4[7aX1:EaGPBUMf@3VVYG191ND0A]?2d4
A1lK12D?30@U3a<46`H:0b0=2`@O3104=aTG16E<APB1IF0O`[^i5Oooo`005?oooao2^kT4HT<n154b
;@A=<Rl3AR/Y13XI5`@T3P/4?A/I154_9PAXAST4SVA@0l2KR0C5XHl4`Z2F1<:SUPC2[J44`[6/1<:^
YP?2ZZ04`Z>D1<:VV@C2XYD4_if;1;VBO`>jSWX4_HUf1;n<N`BgS7H4]HIc1;F5M0B`Pfd3[Wm/1:il
J0B/OVX4[7aX1:EaGPBUMf@3VVYG191ND0A]?2d4A1lK12D?30@U3a<46`H:0b0=2`@O3104=aTG16E<
APB1IF0O`[^i5Oooo`005?oooao2^kT4HT<n154b;@A=<Rl3AR/Y13XI5`@T3P/4?A/I154_9PAXAST4
SVA@0l2KR0C5XHl4`Z2F1<:SUPC2[J44`[6/1<:^YP?2ZZ04`Z>D1<:VV@C2XYD4_if;1;VBO`>jSWX4
_HUf1;n<N`BgS7H4]HIc1;F5M0B`Pfd3[Wm/1:ilJ0B/OVX4[7aX1:EaGPBUMf@3VVYG191ND0A]?2d4
A1lK12D?30@U3a<46`H:0b0=2`@O3104=aTG16E<APB1IF0O`[^i5Oooo`005?oooaO2^kT4`[Zh1<6k
^PAL@3/4CC4^158f<`=;;b`4<aHC13XO70@e71X4ABLS17M7=PBDGd`3]HA^1<>OR`C2X948`Z6E1<:[
XPO2[ZH4`ZVM1<:VV@C1X904aJ6@1;jFPP>iT7d4]8Ug1;F3LPBjQGH4]H1]1;>1L@BcO6d3[7QX1:mn
J0B/N6D4YgQU1:E`GPBOKE`3W6=@18QD@`AA;284@A`I12PD4@@V4Q449A8A0al<2P@V4a44>1TG19F4
P0Bo]kHO`[^i5Oooo`005?oooaO2^kT4`[Zh1<6k^PAL@3/4CC4^158f<`=;;b`4<aHC13XO70@e71X4
ABLS17M7=PBDGd`3]HA^1<>OR`C2X948`Z6E1<:[XPO2[ZH4`ZVM1<:VV@C1X904aJ6@1;jFPP>iT7d4
]8Ug1;F3LPBjQGH4]H1]1;>1L@BcO6d3[7QX1:mnJ0B/N6D4YgQU1:E`GPBOKE`3W6=@18QD@`AA;284
@A`I12PD4@@V4Q449A8A0al<2P@V4a44>1TG19F4P0Bo]kHO`[^i5Oooo`005?oooaO2^kT4`[Zh1<6k
^PAL@3/4CC4^158f<`=;;b`4<aHC13XO70@e71X4ABLS17M7=PBDGd`3]HA^1<>OR`C2X948`Z6E1<:[
XPO2[ZH4`ZVM1<:VV@C1X904aJ6@1;jFPP>iT7d4]8Ug1;F3LPBjQGH4]H1]1;>1L@BcO6d3[7QX1:mn
J0B/N6D4YgQU1:E`GPBOKE`3W6=@18QD@`AA;284@A`I12PD4@@V4Q449A8A0al<2P@V4a44>1TG19F4
P0Bo]kHO`[^i5Oooo`005?oooaO2^kT4`[Zh1<6k^PAL@3/4CC4^158f<`=;;b`4<aHC13XO70@e71X4
ABLS17M7=PBDGd`3]HA^1<>OR`C2X948`Z6E1<:[XPO2[ZH4`ZVM1<:VV@C1X904aJ6@1;jFPP>iT7d4
]8Ug1;F3LPBjQGH4]H1]1;>1L@BcO6d3[7QX1:mnJ0B/N6D4YgQU1:E`GPBOKE`3W6=@18QD@`AA;284
@A`I12PD4@@V4Q449A8A0al<2P@V4a44>1TG19F4P0Bo]kHO`[^i5Oooo`005?oooaO2^kT4`[Nf1;n^
[@AA<bl4E2lW14T_;@=@=C84@bTW13HM6PA19R<4ABHN16E8?`B;DSl3]h5]1<2QS0C5Xi@4`Z>F1<:Y
W0C2ZYl7`ZnX1<:ZX0C1YI@4`J2?1;nLR0C1Sg`3^XUc1;f<NPBjRG<4]HEd1;F3L0B`Of`4[X=_0j]g
I`BUM6D4YgER1:MgI0BSMF84W6YG0hiKA`A[>S<4C2<L12hG4`@U3``48`hB11d72`<?0@D47PP;14`[
9`B<OWX4b<2o7l:k^AGoool001CooolG`[^i1<:g]PBo[Zd4DC<_15@_9`A9;bd3D3Db14<Y9`@f7AX4
@BHS14DV7PAUB3l4Re8o0kN1K@C0XH`4aJ>D1<:SUPC2ZI`4`ZZO1l:_Z0C2ZZ04`JFD1<6PS`BoW8P4
`Hml0kZ9L`BmS7X4^XUc1;F5M0BePg04/7m/1:j3K`>[MfL4YGAU1:MeHPBWMf@4XgER19aZE`>>FdL4
JcXc14`S70@^5a<49@l<12<>4P@M1`/33`4511h82`A<:bL4S7ij1<S0_ao2^kTEoooo000Doooo5l:k
^@C2]kH4_jj]154c;`AD;bL4BBl]0e0e<PA3:BL4=QdJ144V8`A59Qh4IDPo18]B?`>gPFd4`:6<1<FS
U0C2XiH4`ZVL1<:ZW`O2[jP4`ZZP1<6UU0C1X8l4_ib81<6?O0>jRG<4_Haj1;Z9L`BeQG@4]H=`1;1o
K0B^Pfl3ZgMW1:EdI@BWMF84YgMT1:=eHPBLJUL3SU]716/j<`A<8a`4;QLC12D?30@S3Q847@L;0`l1
1@@N20/4C2/W18anNPC8`;lO`[^i5Oooo`005?oooao2^kT4Hd8n14LW7PAC=303CS<`14DZ9P@o7AX4
AbPO14L]:PAM@3D4L3lb0jE^F0C0VHD4`9j=1<:PT`C2XiP4`ZRG1l:XVPC2YIX4_if;1;VBO`BlTgl4
^Xmi0kZ9L`BeQG44]HQ`1;F5K`BeP6`4/8Ea1jilJ0BYN6D4Yg9P1:E^F`BJK5T4SUe90f/l=0AK<B@4
=QHD12/E4P@]4a4480dA11/62`<I1PX4;aHE14DX:0AX@3/S`[^i5Oooo`005?oooao2^kT4Hd8n14LW
7PAC=303CS<`14DZ9P@o7AX4AbPO14L]:PAM@3D4L3lb0jE^F0C0VHD4`9j=1<:PT`C2XiP4`ZRG1l:X
VPC2YIX4_if;1;VBO`BlTgl4^Xmi0kZ9L`BeQG44]HQ`1;F5K`BeP6`4/8Ea1jilJ0BYN6D4Yg9P1:E^
F`BJK5T4SUe90f/l=0AK<B@4=QHD12/E4P@]4a4480dA11/62`<I1PX4;aHE14DX:0AX@3/S`[^i5Ooo
o`005?oooao2^kT4Hd8n14LW7PAC=303CS<`14DZ9P@o7AX4AbPO14L]:PAM@3D4L3lb0jE^F0C0VHD4
`9j=1<:PT`C2XiP4`ZRG1l:XVPC2YIX4_if;1;VBO`BlTgl4^Xmi0kZ9L`BeQG44]HQ`1;F5K`BeP6`4
/8Ea1jilJ0BYN6D4Yg9P1:E^F`BJK5T4SUe90f/l=0AK<B@4=QHD12/E4P@]4a4480dA11/62`<I1PX4
;aHE14DX:0AX@3/S`[^i5Oooo`005?oooao2^kT4Hd8n14LW7PAC=303CS<`14DZ9P@o7AX4AbPO14L]
:PAM@3D4L3lb0jE^F0C0VHD4`9j=1<:PT`C2XiP4`ZRG1l:XVPC2YIX4_if;1;VBO`BlTgl4^Xmi0kZ9
L`BeQG44]HQ`1;F5K`BeP6`4/8Ea1jilJ0BYN6D4Yg9P1:E^F`BJK5T4SUe90f/l=0AK<B@4=QHD12/E
4P@]4a4480dA11/62`<I1PX4;aHE14DX:0AX@3/S`[^i5Oooo`005?oooao2^kT4MUYF14PZ9`A;;RT3
ESHc14PY80A09R@4?AlL14`_:PA8;2L4G3/d0hQ@?PBgQVd4b:ZG1<BQS0C5Xi44`Z2A1<:PS0?1WXX4
a:6?1<FST`BnU804^X]f1;Z9L`>cNVP4]X5`1;J1L@BiQG44/geZ1;=jI`B^N6P3[7]U1:ahHPBUKeh4
XfiK195RC`Ad@383FC0T13PH50@X40`490hB12lD4@@R3Q445@050a/62`@h6AL4VHR41<S0_b?2^kTE
oooo000Doooo7l:k^@AfFUH4B2XW14/^:@=F=S<4B2TP140V90@m7a`4C2lZ14P/9`AL>c@3R50n1;N6
K@C8ZYL4a:6<1<FST@C2X944`Z2<0l6NRPC4XHl4aJ>C1;jDP0BjRgH4^XUc0k=jJ0BfPG04]X5a1;V5
L@BcOFX4/gYW1:ihJ0>/NfD4[7QR1:E_GPBSKU/4TF9?17A0<P=I<2@4>1PD12P@30@T3Q84;a@A128>
4@@E00D36`H;13PI5`BIR8@4b<2o8l:k^AGoool001CooolO`[^i17IJEPA8:RL4BbhY0eHf<`A8:B04
@2HT13dO70A<;bX4B2`W15`k=0>8D3h4]hI]1<RZU`C4XH`4aJ>A1<:PT@C2X8`3`Ij:1<BQS`C5Xi<4
_YB01;Z;MPBjRG<3/gYX1;J1L0BfPG44^HEa1;=mJPBcNVL4[WQX0jakI@B/N684YFmN1:=^F`BAHTl4
M40b0eT`90@h61@4:10<12@>4P@_51448PhA11D01@<K1P/4>1TG19V8Q0C8`;lS`[^i5Oooo`005?oo
oao2^kT4MUYF14PZ9`A;;RT3ESHc14PY80A09R@4?AlL14`_:PA8;2L4G3/d0hQ@?PBgQVd4b:ZG1<BQ
S0C5Xi44`Z2A1<:PS0?1WXX4a:6?1<FST`BnU804^X]f1;Z9L`>cNVP4]X5`1;J1L@BiQG44/geZ1;=j
I`B^N6P3[7]U1:ahHPBUKeh4XfiK195RC`Ad@383FC0T13PH50@X40`490hB12lD4@@R3Q445@050a/6
2`@h6AL4VHR41<S0_b?2^kTEoooo000Doooo7l:k^@AlH5L4DcLd14db;`=;;R/4CRl[13TL7@@o8al4
@bPU14hc<0A7:1l3H3H[19e/E0BmSG<4`ij71<:RS0C4XH/4a:B>0l6NRPBlUh<4_if81;nFPPBhOf/4
]X1Z0k>0J0B^Mf@4[X5/1;5nJPBcO6P4[7ER1:meI0>ZL5l4YGIP19m^E`BFG4P4S5U315Xa9@<k61@4
;QLC12<>2`@K1`/47@L;11011@@?00D3<aHE13/K5PB?PH4W`[^i5Oooo`005?oooao2^kT4O61G15<g
=0A=<Rl3Bbh[14h_:`@i71d4?b<O14<X9@A><c04AbPO0f0f:`BMK5@4_Hec1<>NQ`C2XX`4a:6;1<BT
SP?1WXX4_9N31;nMR0BoUX84^7m[1;J0JP>cP6P4[WMT1:j1K0BaOVX4/gaX1:aeHPB_MF@3ZW1O1:Ef
H0BOKUL4UUa818aI@`AJ<BD3>aPD12hG4`@S3P/46`L;11d72`@@0@D43`050c<F5@@k6aH4Sh619l:k
^AGoool001CooolO`[^i17aPE`AC=c@4CC8_0d/^:`A>;b/4>A`M13lS7`A3:2D4CS<`14LX7`=P=R/4
WFaD1;f=L`C3WXL4`Z:<1<BQR`C4Y8h3`Ij:1;bGP`BoWHP4_iJ21;QoJ`BfP6X3/h1X1:igI0B^PF`4
/GiZ1;=lJ0B/MF84[gET0jY`G`BUMV04WfiG19ILB0B<FD<4FS4U0c/H50@^5a<48`h;11/72`@M1`/4
404510l01@<c5QD4>a/F18n1PBO2^kTEoooo000Doooo7l:k^@AlH5L4DcLd14db;`=;;R/4CRl[13TL
7@@o8al4@bPU14hc<0A7:1l3H3H[19e/E0BmSG<4`ij71<:RS0C4XH/4a:B>0l6NRPBlUh<4_if81;nF
PPBhOf/4]X1Z0k>0J0B^Mf@4[X5/1;5nJPBcO6P4[7ER1:meI0>ZL5l4YGIP19m^E`BFG4P4S5U315Xa
9@<k61@4;QLC12<>2`@K1`/47@L;11011@@?00D3<aHE13/K5PB?PH4W`[^i5Oooo`005?oooao2^kT4
UH1m14d^:0A?=C83Bbl/158g=0A39Ah4>1TI14/b;PA2:2@4DSDa0d4Q7@A/B3X4QUM51;QfG0C7V844
^hih1<6JR0>nVHD4_YMo1<2FP@BfQg84Yg9M1;1aF`>dMU/4/GUW1:mcH@B_L5/4[g]W1:aeFPBUKUl3
XfYG19aUDPB?IE84NDDh16Tc90A:8Q`3<aHB12<>2`@L1`/46`L:11D010@=00@46@D:0b`C4@AT?cL4
I3hd9l:k^AGoool001CooolO`[^i19F0O@A=;RP4CcDb0d/_;0AB=c@4@bDN13PI6@A;<Rh4@RPT158e
<@=18Ad4K4Pj18IGA@BhMU`4aiR11;^>N0C1VXP3_YV51;jGO`C0UX44]XMb1:MbG@B`LE/3]7IK1;5i
I`B_Lf44[g1K1:mkI`B/MEX4YFiO0j=ZE`BLIE84SfEB17U5>0AY<b@4BR8L0c<F4P@S3P/470L;11/7
2P@E00@43@0411T52P</4a44I3lg16@n=2O2^kTEoooo000Doooo7l:k^@BEP7d4CBhX14le<P=;;b`4
DSLd14<U7P@h6AT4Bc8^148X90AB=C43@B4M16a8>PB6EdD4^7IL1<NHP@BkSWP4`IZ80kjIQ@BnUgl4
`9J11;J7LPBWLUd4/75K0kAfF`BaNFL4[g=Q1:m`F`B_NfL4[7EJ1:E^G`>SJUL4W6EB18mUDPAiACP4
JC<T14XR70<c5Q848`h;11`72`@K1`X45@0410d010@I1@X3;1<A16@o=`AT?S@W`[^i5Oooo`005?oo
oao2^kT4UH1m14d^:0A?=C83Bbl/158g=0A39Ah4>1TI14/b;PA2:2@4DSDa0d4Q7@A/B3X4QUM51;Qf
G0C7V844^hih1<6JR0>nVHD4_YMo1<2FP@BfQg84Yg9M1;1aF`>dMU/4/GUW1:mcH@B_L5/4[g]W1:ae
FPBUKUl3XfYG19aUDPB?IE84NDDh16Tc90A:8Q`3<aHB12<>2`@L1`/46`L:11D010@=00@46@D:0b`C
4@AT?cL4I3hd9l:k^AGoool001CooolO`[^i1;>RY@ASA3l4ABPU0dda;PA<<2d4@b`W13XK7@A::Al4
Bc0^154g<`=;<2h4B2dY15m2>PAgB3X4Ue]519a^HPBGKEX3[W9J1;24KPB^P6P4WfaK19INAPB6D3/3
VEe21:IPBPBYKeD4[FaF1:9TDPBPHTX4YV=90ieTD0B<FD/4PDTi16Td9PA>81/4=aLC0bD?30@M1`/4
5@0410h01@@>00@43@0412@A40<d5aH4R7Ue1;f`[RO2^kTEoooo000Doooo7l:k^@BcXZD4Hd@o14DX
9@==<Bh4C30]14</9`@j6ad4BRTO14/`;PAA=c<3Bc0^14P]:@AO@SX4MdPj19MKA@BLKV84UfeJ0jib
FPB`Q6h4[X1X19m/F`BFGTH4QU0k0iUM@PBVH4X4ZFmE1:e/EPBRI584X69:1:ISB@>MI504S5U;1859
>@AY=2H4CR0K13LG4`<U3``47@L;11D010@>00D43P0410d010@T4A03=1LF18QiM@Bm/:hW`[^i5Ooo
o`005?oooao2^kT4/j:U16=4?`A5:2D3CC4^14``;@A3;2L4>Q/M14XY7`A;<2h4DCLc0d/`;PA8;BT4
Gd8j17M8>PBGFdD4W6iR19M]FP>^LUX4/8A^1:j0J0BOK5/4UUi618I@>`>IGD84YV1:1:U_E@B]K5H4
XVAB1:1RBPBVHdT3WFA@18aIB`B1BCT4JC@V14hP6`@g5a<39@l<11d72`@E00@43P0510h010@=00@4
914@0c@G5PB8NGD4_K2^9l:k^AGoool001CooolO`[^i1;>RY@ASA3l4ABPU0dda;PA<<2d4@b`W13XK
7@A::Al4Bc0^154g<`=;<2h4B2dY15m2>PAgB3X4Ue]519a^HPBGKEX3[W9J1;24KPB^P6P4WfaK19IN
APB6D3/3VEe21:IPBPBYKeD4[FaF1:9TDPBPHTX4YV=90ieTD0B<FD/4PDTi16Td9PA>81/4=aLC0bD?
30@M1`/45@0410h01@@>00@43@0412@A40<d5aH4R7Ue1;f`[RO2^kTEoooo000Doooo8l:k^@B9M7@4
ARXT0d/a;PA9<Rl4Ab`Z12TE4`A5:2D4E3Lb158g=0=I?c/4E3Xg15Ln=`AP@c/4J4<g16Pm=PAU>bh3
Ic`e17i6=@B5F4H4KT@l16]0>0Ad?Bh3LCdX17Y1<PB@ECh4TULo191B>`B<E404OD<a0h==?PAi@C<4
ICP/14TO6`A48Qh49@h;0b<>2`@K1PX4500420d010@X4A047@`@0eY1?@AbGe`[`[^i5Oooo`005?oo
ob?2^kT4RGAd14HZ90=;<Bh4BC8_14L/:P@Y5A<4ABPU15@g<PAB=c@3FClk15@j=`AG?SL4H4<k16Q3
=`AX?CH4IC/^0fLl=@AnASD4QEQ616i4?0A[@3P4M3d^0g4m:0Aj@C84T5Dn199G?`B@DS/4S5A017e3
<@>3CCh4ND4c16Dh;0A97a/4A28N12D>2`<S3P/46`H:11@010P=00@4:14@11d<40=J@Cd4LUmL:l:k
^AGoool001CooolS`[^i18UdM0A6:R@3Bc4^14Tb;`A7;2X4:ADC14DX9@AD=c84DSLd0eTo>`AD>SL4
Echg1613>`AX@cL4J3df16Dk;P=W?3D4OTHe18EHAPA^A3`4Jd0h17@m;P=a?BP4NT4b191E?PBBEcl4
T58k18aD@0Am@c43Pddn17U1<`AU>2`4BAlK14@R7P@U3P/38`h;11/62P@D00@83@0412PA40@M3103
FT4m179OG2_2^kTEoooo000Doooo8l:k^@BTU9P4DC4`0dT^:`A<<Bh4BS0]14<Z:0A1:RP4DCLc15]0
?0=C=c<4F3/g15hg<@AX?c84FSL[150e<0A59B43Dc4/14LN6`AK=S04EcD_14//:0A981`3CBPR14dQ
6`AG91d4HcHV260c90AH91h3EB@M14hT7PA;8A`4<1PD12L@30@O20`370L:11/72P@>00@43@0412PA
6P@X4@l4?RLU0ee3@`BBLF/[`[^i5Oooo`005?ooob?2^kT4Y9BH154a<0=9;R/4C34^14X`;@A3:RP4
@BXX154g<`AK@3`3DcLc15Pk=`AN=c44J3lb15Xg:`A@=C04ABDQ0e<a;0A77Q/4FcH`15Le;`A;;2P4
BB0L0ddX8PA=8A/4Eb@M16<f9PQP<b@4F2@N0eDT7@A>91h4Bb4L130H50@W40`47`P<0a`72P@K1`X4
3P0410d010@X4AX4:14?13hW9@=M@d<4TW5[:l:k^AGoool001CooolS`[^i1:BDV0AA<C03BBh[14`a
;PA:<2d4@bXX144Z:0AA=c<4Fd0l0e<g<`AH>cL4GSLa16Po<PAJ=b/4D3D`14DU8@=C<B`4AahK15/f
<0AG=Bl4Bb`X14TP70==:284CB4K15LT7@AS=RH8H3<T15PT7P=E91d4CR@N14/Q70@`61@49a0<11l8
30<L1`X46`L:10h010@=00@4:14J12PA3`@n9bD3GD=3199aJb_2^kTEoooo000Doooo8l:k^@BTU9P4
DC4`0dT^:`A<<Bh4BS0]14<Z:0A1:RP4DCLc15]0?0=C=c<4F3/g15hg<@AX?c84FSL[150e<0A59B43
Dc4/14LN6`AK=S04EcD_14//:0A981`3CBPR14dQ6`AG91d4HcHV260c90AH91h3EB@M14hT7PA;8A`4
<1PD12L@30@O20`370L:11/72P@>00@43@0412PA6P@X4@l4?RLU0ee3@`BBLF/[`[^i5Oooo`005?oo
ob?2^kT4_;2c17mUJ0=19B84BRh[14hc<0A9;BX4Ecdi14DZ9PAM@3`3BBdY15<g=0AN?CD4Dc4^15@_
:PA>;RX4@RPT0dh`;P@g6ah4?bPS148N6`A17a`4<aLD0bdF4`@d5Q<4?a/H140L60@f61<4>1PD13LG
4`=16aP4<aDB13<E4`@U3``48Ph;1a/62PP>00@46@D:138L70@f61P4DSLb0f53?Ro2^kTEoooo000D
oooo8l:k^@Bl/;<4OfEX0d4U8PA:;R/4CS<`14T]:PAG?CT4ABXV15e0?0=9;BT4DcLd15hm=@AC<Bh4
E2lZ14h^:PA2:2@3CS0^13LK7P@o:2<4@QhK144O70@c5a@3;AHC13@F4`@o6aP4@1`H13HH4`@h61@4
=aLC0d4K60@c5A84<aDC12D?30@R3P/76`H:20h010@I1@X4<Q`L13HH60AB=c83HD<n;l:k^AGoool0
01CooolS`[^i1;b`/`AoIFP3@BDR14X^:`A><c04BBdZ15Lm>@A5:RH4GD0l0dT]:@AC=c@4GSde15<a
;PAD;bX4CRhZ148X90=><2h4=a/N13lX8`A27Q/4@AlL13<G50<]5Q<4=1HC13lK60A071P4=QPC13PH
50@g5a<3@A/H13<E4P@c5A<49@l<128>2`LK1PX83P0411T52P@b71`4=QPH158g<P=Q@ch_`[^i5Ooo
o`005?ooob?2^kT4_;2c17mUJ0=19B84BRh[14hc<0A9;BX4Ecdi14DZ9PAM@3`3BBdY15<g=0AN?CD4
Dc4^15@_:PA>;RX4@RPT0dh`;P@g6ah4?bPS148N6`A17a`4<aLD0bdF4`@d5Q<4?a/H140L60@f61<4
>1PD13LG4`=16aP4<aDB13<E4`@U3``48Ph;1a/62PP>00@46@D:138L70@f61P4DSLb0f53?Ro2^kTE
oooo000Doooo9l:k^@BVUIH3EC4]14/c<0A><c04Bbl/14</:0AK?SX4DcXf0dTb;`A4:2@4G3@Y14HX
90A9;BT4ARXW13DN9P=4;2H4?AdQ13/L6@@b5al4;ADB12`E4P<S3P/4:A@B12/D4P@^5A<49Pl<11h7
2`@U3`/3<QDB12D?30@N1`/490l;124=4@@K1PX33P0411/62P@Q40l4;ATI13<G5PAF>3<4ES8]</:k
^AGoool001CooolW`[^i1:JEUP=E<Bd4Bc<`14hc<0A;;b`4@b`X15/n>PAC>SH3BC8_14@X90AL=2T4
ARPT14T]:@A6:RL4=AhV0d@/9P@m7B44>a`I138G7`@]5A84;1DB0b<>2`@Y5184:a@B12hE4`@V3``4
7PL;12D?2`<b5A849@l<11h72`@T3`/48@dA11/62P<>00@46`H:124@3`@]6AT4<aLF15Hh<`AF<Rdb
`[^i5Oooo`005?ooobO2^kT4YYFF0eDa;@A;<c04CS<`14/_;0A3;2P4Fchj15<j=P=9<Rl4A2PT15`d
:@A6:2@4BBdY14HZ9`@e7RH3A2`V13dM8@@k71T4<QLO12dE4P@/5A838`h;12TD4P@[5184;QDC12H?
30@N1`/49@l;0c8E4P@U3``47PL;12@?2`@Q3A446`H:0`h010@K1PX48A0?12dI6@@c5aH4ESPc15Hb
;C;2^kTEoooo000Doooo9l:k^@BVUIH3EC4]14/c<0A><c04Bbl/14</:0AK?SX4DcXf0dTb;`A4:2@4
G3@Y14HX90A9;BT4ARXW13DN9P=4;2H4?AdQ13/L6@@b5al4;ADB12`E4P<S3P/4:A@B12/D4P@^5A<4
9Pl<11h72`@U3`/3<QDB12D?30@N1`/490l;124=4@@K1PX33P0411/62P@Q40l4;ATI13<G5PAF>3<4
ES8]</:k^AGoool001CooolW`[^i1;VZ[0=`Cdl4B2TW158f<`A;;b`4Bc8_14Lb;`AG>CD3BBhY140U
8@A29204>1PD14@Y9@@i7Al4>1dP0c0F50@c5b049PlB120830@U3a<48`hA0a`72`@R3Q447@L;12<?
4P@L1`/48@dA12DB40<R3A447@L;10h010@?00D43`4510l01@<P31447@/:11/62`@b40`4GTA015Ti
=3K2^kTEoooo000Doooo9l:k^@BiZZ`3L4m?14PY9`AB=S<4Bbl/14/b;`A7<Rl4EcTe0dT^:@A09B44
@R@P13PH50A4:BD4>AdO13PM80<`5Q@4<aLP12H?4P@P20`49@lC12<>4@<L1`/48PhA11d72`@S3a84
70L;124=4@@U4Q038PdA11d72`@>00@43`0510l11@@?00D380`A11d;2P@K1P/4<Q0<15i4@0AI>C@f
`[^i5Oooo`005?ooobO2^kT4^JZ/0g1?C`A8:BL4DSHc14/_;0A;<Rl4Ac8_15Li=@=9;RT4@2DQ148T
80@h61@4A2TU13TM7`@h7B03<1HD13<G80@V3a8480P<12D?4`@S3Q4370L;128>4@@M1`/48`lB11`7
2`@Q3A449A8@0b8=4@@M1`/43P0410l01@@?0@D43`050b0<4@@M2`X46`H;138@30ANA404FCTd=/:k
^AGoool001CooolW`[^i1;VZ[0=`Cdl4B2TW158f<`A;;b`4Bc8_14Lb;`AG>CD3BBhY140U8@A29204
>1PD14@Y9@@i7Al4>1dP0c0F50@c5b049PlB120830@U3a<48`hA0a`72`@R3Q447@L;12<?4P@L1`/4
8@dA12DB40<R3A447@L;10h010@?00D43`4510l01@<P31447@/:11/62`@b40`4GTA015Ti=3K2^kTE
oooo000Doooo:l:k^@>LQh@4D38`13lU8PA=<Bh4Bc@a14`e<PAC>CH3B2d_13`K60@l8Al4:Q@B138E
4`@]5aD4<QDD0ah830@O20`490lC120=4@@K1PX48PhB0a/62`@Q3A446`H;13@H5P@=00@48PdB12LC
4@<R3Q443P0510h010@C00@47@`@11`;3`<N3104=APF13HO6@A1;2X4J5QK1;f`[SK2^kTEoooo000D
oooo:l:k^@>LQh@4D38`13lU8PA=<Bh4Bc@a14`e<PAC>CH3B2d_13`K60@l8Al4:Q@B138E4`@]5aD4
<QDD0ah830@O20`490lC120=4@@K1PX48PhB0a/62`@Q3A446`H;13@H5P@=00@48PdB12LC4@<R3Q44
3P0510h010@C00@47@`@11`;3`<N3104=APF13HO6@A1;2X4J5QK1;f`[SK2^kTEoooo000Doooo:l:k
^@>LQh@4D38`13lU8PA=<Bh4Bc@a14`e<PAC>CH3B2d_13`K60@l8Al4:Q@B138E4`@]5aD4<QDD0ah8
30@O20`490lC120=4@@K1PX48PhB0a/62`@Q3A446`H;13@H5P@=00@48PdB12LC4@<R3Q443P0510h0
10@C00@47@`@11`;3`<N3104=APF13HO6@A1;2X4J5QK1;f`[SK2^kTEoooo000Doooo;/:k^@BLQh@4
CBl/140/:@A5:BH4E3`h158i=P=D>CL4>bDS144T8@@^51`48PhA130D4@@R3Q43:1<A12@A40@O3148
6`L;11/62`<K1`/46`H;12HC4@@R3A44?B/c12dO80@Y41P36`L:120=4@@P40l480l?11h;40@i8R43
<1XJ13DG5PAI=2`4JdPi18aPCc[2^kTEoooo000Doooo;/:k^@BLQh@4CBl/140/:@A5:BH4E3`h158i
=P=D>CL4>bDS144T8@@^51`48PhA130D4@@R3Q43:1<A12@A40@O31486`L;11/62`<K1`/46`H;12HC
4@@R3A44?B/c12dO80@Y41P36`L:120=4@@P40l480l?11h;40@i8R43<1XJ13DG5PAI=2`4JdPi18aP
Cc[2^kTEoooo000Doooo;/:k^@BLQh@4CBl/140/:@A5:BH4E3`h158i=P=D>CL4>bDS144T8@@^51`4
8PhA130D4@@R3Q43:1<A12@A40@O31486`L;11/62`<K1`/46`H;12HC4@@R3A44?B/c12dO80@Y41P3
6`L:120=4@@P40l480l?11h;40@i8R43<1XJ13DG5PAI=2`4JdPi18aPCc[2^kTEoooo000Doooo;/:k
^@BLQh@4CBl/140/:@A5:BH4E3`h158i=P=D>CL4>bDS144T8@@^51`48PhA130D4@@R3Q43:1<A12@A
40@O31486`L;11/62`<K1`/46`H;12HC4@@R3A44?B/c12dO80@Y41P36`L:120=4@@P40l480l?11h;
40@i8R43<1XJ13DG5PAI=2`4JdPi18aPCc[2^kTEoooo000Doooo</:k^@BLPgl4CRh/14Pb;`A2:2@4
DSXf0ei2?@A?=S<4@BDM13TP7`@V4Q848PdA11d72`<R3P/48`hB11`72`@K1`/480`A11X62P<P3144
6PH:11`72`@l;Bh4=Ad[15A2@PA8=3H3=1hU13LU9@@a71`49A8@13DM70@f7Qd3Bc4^14h[9@AI>C@4
O597?/:k^AGoool001Cooolb`[^i19b3O`A>;R`4B38_148X90AB>SH3GT8m14lf<`A19Ad4>B0O12HB
4P@R3A447@L;0b8>2`@S3Q8470L;11/72`@P31446PH:0b0<4@@J1PX470L;13`];P@e7B/4E49214Pd
=P<d7RD4=bDU134L70@U4Q04=AdL13HN7@=;<Bh4CR/U15Ti=0AlDTLn`[^i5Oooo`005?oooc;2^kT4
W8=o14h^;0A8<Rl4@RPT158j=P=N@Sd4CcHc144U7@@i81l49Q8B128=4@@M1`/38Ph;12<>4P@L1`/4
6`L;120<4@@J1PX380`A11X62P@L1`/4?2d^13DM:`AD@T84B3@f0c@N9@@g9BD4<A`L12DB40@e7A`4
=QhM0d/a;PA>:bD4FCTd17aBAck2^kTEoooo000Doooo</:k^@BLPgl4CRh/14Pb;`A2:2@4DSXf0ei2
?@A?=S<4@BDM13TP7`@V4Q848PdA11d72`<R3P/48`hB11`72`@K1`/480`A11X62P<P31446PH:11`7
2`@l;Bh4=Ad[15A2@PA8=3H3=1hU13LU9@@a71`49A8@13DM70@f7Qd3Bc4^14h[9@AI>C@4O597?/:k
^AGoool001Cooolb`[^i1<Fn_@BQRHH4DBdW154k>@A7;b`3FD4m15a1?@AF>cH4>QhK13TO7@@j9B@4
;A`M0bL@3`@U4Q4480`A11l<40@K1PX46`L;0bHB6`@P3104914@12<?4`A2;R`4C2l`12dE60<f7AT4
<a/H12`D5`@d5a@4>B0M14DV7P=K?C@4HTU7181GB@C2]K@n`[^i5Oooo`005?oooc;2^kT4aKjm1:69
QPAA;BL4DC/i14L_;0=I@Cd4G44m15Hk=P@j7Q/4>AlM13XU90@]71d39a0?12DB4@@P31447``@11/6
2P@K1`/39Q8K120<40@T4A048`lC148^;0A<;c04;ADH0cHM6@@c6aP4;1@G13@G50@i81d4ABHN0e/m
=0ARBDL4P5M91<:e]3k2^kTEoooo000Doooo</:k^@C5_[d4XHV6154]9`AA>cT4Abl/0eU1?@AL@Cd4
ES/f13XN6`@i7ad4>RDT12dL7@<W40l49A8A120<4@@O31046`H:11/72`<V4Q/480`@12@A40@S3a<4
@Rh/14`_<0@]5AP3=QdI13<K60@/51L4=1LD13TP7@A59Qh3Fcdd1699A`B0EdT4`[Fd?/:k^AGoool0
01Cooolb`[^i1<Fn_@BQRHH4DBdW154k>@A7;b`3FD4m15a1?@AF>cH4>QhK13TO7@@j9B@4;A`M0bL@
3`@U4Q4480`A11l<40@K1PX46`L;0bHB6`@P3104914@12<?4`A2;R`4C2l`12dE60<f7AT4<a/H12`D
5`@d5a@4>B0M14DV7P=K?C@4HTU7181GB@C2]K@n`[^i5Oooo`005?oooc[2^kT4VGef150^9`A6:RL3
ESXf16Q>B@AQBdL4DSPd13LM6`@i7Al4@AlK0d</:@@c81d480`@11/72`@/6244:1DL0c8O7P@Z5R44
?RTV128@6@A:=C44@RX[148Y9`<f8R84=B0M13PT8`@o:bP4>b8R15/l<P=N?S<4OD`o1;:NXd;2^kTE
oooo000Doooo>/:k^@BIOGH4D2hW14HZ9`=F>SH4J4i9165;A`AB>3@4=adK13TM7`A17a/3@b`Y13<P
7@@P31046`L;12`H8@@X5A`3<QlN12XF8@@n:BH48Q0I14Xe<@A2:R/4@RTW0cHR8P@e81d4>2@S13l[
:0@k8R84Fc`b0ehn<`AmC3l4/YjS@/:k^AGoool001Cooolj`[^i19UmMPA@;RL4ARXW0eHj=PAXCTT4
HD]7158h=0@g7A/4>AdO144O6`=3;2T4<b0M120<40@K1`/4;1PQ12PE70<b7ah4:QHQ13hY9P@R41T4
BSDa148Z:`A2:BL3=R8R13DP7@@h92<4?b/X13/R8PAK?383GShc17e<?`BbWZ=2`[^i5Oooo`005?oo
oc[2^kT4VGef150^9`A6:RL3ESXf16Q>B@AQBdL4DSPd13LM6`@i7Al4@AlK0d</:@@c81d480`@11/7
2`@/6244:1DL0c8O7P@Z5R44?RTV128@6@A:=C44@RX[148Y9`<f8R84=B0M13PT8`@o:bP4>b8R15/l
<P=N?S<4OD`o1;:NXd;2^kTEoooo000Doooo?/:k^@BIQ7d4BBTL0chV8`AC=c@4I4Q316ADE`AL?cX4
Ac0`14H_<0<o8bD4@S8b14Pd>0@g9RD4;a/P13PV=0=0:2X4BSPn148Z:0A4:bX4BC<d15Hg=0A?;B`3
CbhV14Xb<0AD>344H4<h14d_9PAdED`3S5a;1<:e]4K2^kTEoooo000Doooo?/:k^@BIQ7d4BBTL0chV
8`AC=c@4I4Q316ADE`AL?cX4Ac0`14H_<0<o8bD4@S8b14Pd>0@g9RD4;a/P13PV=0=0:2X4BSPn148Z
:0A4:bX4BC<d15Hg=0A?;B`3CbhV14Xb<0AD>344H4<h14d_9PAdED`3S5a;1<:e]4K2^kTEoooo000D
oooo?/:k^@BIQ7d4BBTL0chV8`AC=c@4I4Q316ADE`AL?cX4Ac0`14H_<0<o8bD4@S8b14Pd>0@g9RD4
;a/P13PV=0=0:2X4BSPn148Z:0A4:bX4BC<d15Hg=0A?;B`3CbhV14Xb<0AD>344H4<h14d_9PAdED`3
S5a;1<:e]4K2^kTEoooo000Doooo?/:k^@BIQ7d4BBTL0chV8`AC=c@4I4Q316ADE`AL?cX4Ac0`14H_
<0<o8bD4@S8b14Pd>0@g9RD4;a/P13PV=0=0:2X4BSPn148Z:0A4:bX4BC<d15Hg=0A?;B`3CbhV14Xb
<0AD>344H4<h14d_9PAdED`3S5a;1<:e]4K2^kTEoooo000Doooo@/:k^@BfYZT3OE]N14H[:PAC>S@4
Dd=:17=NG`A[DTl4JE9<0f9<BPAC?d<4ED=616==D0AG?S/4DCTk0d@[<`A8;B`4DcLh15@i=PA><c04
H3L^15hh<P=L>C84Gcli15Lc:`AjFE84NDL`16a3>4g2^kTEoooo000Doooo@/:k^@BfYZT3OE]N14H[
:PAC>S@4Dd=:17=NG`A[DTl4JE9<0f9<BPAC?d<4ED=616==D0AG?S/4DCTk0d@[<`A8;B`4DcLh15@i
=PA><c04H3L^15hh<P=L>C84Gcli15Lc:`AjFE84NDL`16a3>4g2^kTEoooo000Doooo@/:k^@BfYZT3
OE]N14H[:PAC>S@4Dd=:17=NG`A[DTl4JE9<0f9<BPAC?d<4ED=616==D0AG?S/4DCTk0d@[<`A8;B`4
DcLh15@i=PA><c04H3L^15hh<P=L>C84Gcli15Lc:`AjFE84NDL`16a3>4g2^kTEoooo000Doooo1<:m
^`C2_[e1`[^i19V4Q`A<8RD4@2<N14lmA0B0JFH4MVET0fQCB`A/EE44KUMF171ED0A/D4l4GdM20eU2
@@AD>c`4BSDa15U0?`AOAD84F3/e16Q0>0=N=C04RVIL16Xf8`AG6A04S6][DL:k^AGoool001Coool4
`[fk1<:n_D72^kT4VHB714`R9@A08ah4Cce4181YIPAfIF@3J5=;16aED@A^EeH4L5E@16a@C`AOAd83
FD9115@k?0A:=C44FD0o15m5@PAH>cD4J40h0ehe<0B:IU`4JSHS15LI40B<Jf]A`[^i5Oooo`005?oo
o`C2_K/4`[jm@L:k^@BIQ8L4C28U140S7PA??D@4P6UV17IUI0=XDd/4K5EA16iGEPA`EE04K51?15m7
@P=I@T44E3/l14Xe<@AI@3l4GdE215Pk=@AX@3P3GSD`18YVG0AZ=R<4EaT@18a[Je72^kTEoooo000D
oooo1<:m^`C2_[e1`[^i19V4Q`A<8RD4@2<N14lmA0B0JFH4MVET0fQCB`A/EE44KUMF171ED0A/D4l4
GdM20eU2@@AD>c`4BSDa15U0?`AOAD84F3/e16Q0>0=N=C04RVIL16Xf8`AG6A04S6][DL:k^AGoool0
01Coool4`[:a1<:e]4W2^kT4_;2c18mfP`AO?4T4Oe]R0hU[M0AnF4l4JdPn16E<A`AgFeX4NUQA0gQI
E0AfF5<4MeQA16]@B@A_C444LUA917mUF`=97Q84G2d/1:N=TUW2^kTEoooo000Doooo1<:b/@C2]KA9
`[^i1;b`/`B?MX<4Gca917mKHP>9Jg@4OUQ?16]8?PAUC4L4Me]J17YHD@=hFE@4MUQC17MHD@A[D4T4
Kda1179DB@AoIE/3BAhB15`];0BWSI9I`[^i5Oooo`005?ooo`C2/[44`[FdBL:k^@Bl/;<4SgJ315ll
B@AoFf83RF]d17iHC`A[B3h4IDa717MKFPAjF543N5UD17IHD`AgF544Je1916m<@@AbE4T4OfEK0dTN
4PAL;B`4YhfBFL:k^AGoool001Coool4`[:a1<:e]4W2^kT4_;2c18mfP`AO?4T4Oe]R0hU[M0AnF4l4
JdPn16E<A`AgFeX4NUQA0gQIE0AfF5<4MeQA16]@B@A_C444LUA917mUF`=97Q84G2d/1:N=TUW2^kTE
oooo000DooooHL:k^@>l/;H4^:Ja1;JQY`B:K7h4HdAG160mAP=K=Bh4FcD]15/a:PAH;RL4D28G14XJ
2PAgEd/3`[FdHL:k^AGoool001CooomQ`[^i0kb`]PBhY[44]Z6W18Y/OPASA5L4H3e60e/e;PAK=Bd4
Fc4Z15P^9`A@8QL4BQX:17MGB`?2]KAQ`[^i5Oooo`005?ooof72^kT3_;2f1;RV/@BfXJL4RVan16=4
E`AP?DH3FcD^15/e;@AK<BX4F2hW150R5`A:6PX4MeM;0l:e]672^kTEoooo000DooooHL:k^@>l/;H4
^:Ja1;JQY`B:K7h4HdAG160mAP=K=Bh4FcD]15/a:PAH;RL4D28G14XJ2PAgEd/3`[FdHL:k^AGoool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
09Woool30000Q?ooo`00W?ooo`030000oooooooo087oool007coool200000oooo`D00002oooo0P00
00Coool400000_ooo`<00003oooo0`0000?oool20000O_ooo`00Noooo`040000oooooooo00001?oo
o`050000oooooooooooo000000;oool010000?ooooooo`0000;oool010000?ooooooo`0000Goool0
10000?ooooooo`0008?oool007goool00`000?ooooooo`03oooo00<0003oooooool01?ooo`040000
oooooooo00000_ooo`030000oooooooo00@00002oooo00@0003oooooool00023oooo001noooo00<0
003oooooool00_ooo`030000oooooooo00;oool200001?ooo`<00003oooo0P0000Coool40000P_oo
o`00Noooo`040000oooooooo00001?ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0
003oooooool0SOooo`00O?ooo`800004oooo0P0000Coool300001?ooo`80002?oooo003ooooo8Ooo
o`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Ooo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(338) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EA88470
B08E7CAF8D81AF9386AF8D80AF9386AF9385AF9385AF9385AF8D80AF8D7AA88875A98370
A27765A379679C73619D74629D74629D74629D74629D6E5C976F58986F5E986F58986F5E
B3ACACAFA29EAFA29EAFA29EAFA29EAF9C98AFA39FAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA19DAFA7A3AFA29EAFA19DAFA7A3AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA19DAFA7A3AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAA8672
AB8A7AAF8D7BAF938AAF8D80AF9386AF9385AF9180AC9285B09285B08D7CAA8976A78470
A87B68A579679E7361A177659D74629D74629D715F9D715F976F5A986F5B986F5898786B
B39A90AFA29EAFA29EAFA29EAFA29EAF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAF9E9AAF9D99AFA7A3AF9E9AAF9F9BAFA29EAFA19DAFA7A3AFA19DAFA7A3AFA29E
AFA29EAFA29EAFA29EAF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAC8873
B39182AF8D80AF9181AF9385AF8D80AF9487AC8E7AA38979B38771AB8170A3826BA07E6C
9D75649D7362996D5D986F5D9E74619E74619E715F9E6F5A9A6F60986F5D986F5AA19188
A18D85AFA29EAFA29EAFA29EAFA29EAFA29EAFA19DAFA7A3AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAF9C98AFA39FAFA29EAFA29EAFA29EAF9E9AAF9F9BAF9E9AAF9F9BAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAA8470
AB8E7EAF8D7DAF8D80AF9184AF9183AF8D7EAA8A7D9A8373977A69A4706797705B9B7462
9B796A9B796799705E97745F986F5D986F5D986F5D986F5A9A715E946C5A986F5DB3ACAC
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAF8672
AF8A7CAF8D82AF8D84AF8D80AF8D80AF8D7CAF8F7FAF8B7FAA8675A97D6FA8736AA27460
A272649F6D64A17164916055966F5D9677659469559A6F5D9A726097715F9A7462AEA3A3
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAF8A75
AF8D7BAF8D7DAF8D7BAF8D84AF8D80AF8F82AF8D80AF9487AF9385AA8675A77E6EA57568
A97A6CA57766A37667A26F6499685A9D6F6299796C9869559E6F5D9A6F5DA38375A9988E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA19DAFA7A3AFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EA68E84BCAA98
AF8D7DAF8D7BAF8D7EAF8D81AF8F82AF8D80AF9385AF8B7FAF8F82AF8D80AF8D7CAA846E
A77C6EA57A6CA57A699F70649F7461996E5C9A75659A73639A6F5D946F5DAC9792B09D95
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAF9E9AAF9F9BAFA29EAFA29EAFA19D
AFA5A1AFA7A3AFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E7D6A5ED7B6A6A98576
AF8D81AF8D7CAF8D79AF8D7DAF9386AF8D80AF9181AF978DAF9183AF9183AF8D7EAF8A7A
AC7D6DAC816CA97B6CA27863A06E61A07462996C5A946F5D9E7462996B5AAA9F9EAB9B97
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAF9E9A
AF9A96AF9F9BAFA29EAFA29E
AFA29EAFA29EAFA19DAFA7A3AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EA395944A2D26D3B49DAB8A74
AF8F83AF8A7DAF8F82AF8A7DAF9184AF9385AF8B7AAF8D7DAF9180AF867FAC9179AE8D78
B08979A97E6FA77A6CA37361A3735F9971609A6E599A6F609B75629E7663B6B0AFAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAF9E9AAF9D99AFA7A3AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EB1A49F573D319A7E7B725351AF8D80
AF9181AF9183AF9184AF9183AF8D80AF9184AF9789AF8D80AC8B78B07F76AC7E6EA27866
A77C6AAB7E6CA77E699C7566A2715FA0746199715C966F5B946F5D9A7160AC9F9BB3B5B5
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA19DAFA29EAF9F9BAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E624637B29F976E4E42AB8A74AF8D81
AF8D80AF8D80AF8D7EAF8D84AF8D80AF8F82AF8D80AF9183A87266A98171A77364A77665
A37463A3896FA07661A076619D6E5C9A725CA16F609D6F5D976F5A9E6E5FA28776BDC2C8
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA19D
AFA7A3AFA29EAFA29EAFA29E
AFA29EAFA29EAF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EA39591705A4F76594DAF9183AF8D7AAF8D81
AF8D80AF8B7BAF8F7FAF8F7FAF9188AF9184AF897EAF9182A8675EA75D53A35248A8615C
A0564CA8695E99715D9E745F9E6F5A9A69589E725E9D6F5D996F5A9A6856997260A68E81
BCCCD5AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAF9E9A
AF9F9BAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E523E37ECCBB8B09188AF8D82AF8D7EAF8D81
AF8D7EAC8576B08774B3937FAF8A7EAF8979AC726EAE7366AA786F9E4C3DAC695EA44C49
994037A25145A0615694695A98755E98684F9B6F60A16F609D6F5D9D6B5A9D6F5E9D7765
B2A7A4AFABACAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA19DAFA7A3AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29E948280756255846E64AB8A7AAC8972B39787AF8A7A
AF8975A6836CA77767B99788AA74667C3320DFA594A7564EA16C618E53468A4334977963
9757479C4C488B3F32B152469578639B6E519A6C599A7560A0705D99695A9D71609D6F5D
A98D7DBCBFC0AFABACAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA19DAFA7A3AF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29E523D37C59C899F7B6DAF8D7BA87F70B0978AAF9183
AF826F9F6B539E6B59812D26CEA99F7C1E16772C219F5446A45846AB8474A45F54964A41
7E412B784D3E6B392D6D3524B95C499C7C609E6654A07866A076629F725D996C5D9D715F
9D7462A99A99B9A999B3ABA7AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EA69A9B3C2720C3A18BB08E7FAF8D7EAA8171AB8479AF8D80
AA776399684B974838622318AA7C72A7A495B09A92B3B7B4AF978FAF9C97A68276B1A79B
AA85759A8D8B64433C51342E55291FB76249A37D67A97B66A67D6F9F725E9C705D9D6958
9D75629A9191A3949AB7B0B7BCB5A7AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29E7D6A5E61423C94756F816B5FAB8A78AF8976AF907CAF9585AF8D82
A26B5C9369548346375D0F0F77302DA26E5DA77969AF8D80B4877BAA9078AB6D5CA96D5D
A57464B09F87A06C5A8A6A615D473B591C12C07E6AA58166AA8573A277639C70619A6E5C
A16E5E997E6E98908F89757AB6AFAAAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA19DAFA7A3AFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EA697962C211A3D2721B283769A7464AF8B79AF8375AC8A70B38B79AF8679
A2775F9B6851BAA193AB8C78AF7D72AA746CA36E639F665BA45E579C575399564F97443E
9746439660539C60558C56497B49395A2A217D392CBA9278AF8974A27B639C6D5C976B5A
9E75629D7A676D4E40E4E0EE9F8F92B3ABA7AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29E9A868A47332B00000A685855B39181AF8875AF8278AA7A73AB977CAF8177
A26A5F945F4DA98977B3998FAF9385AF8A7DAF9184AF9385AF8374A8866DA97E6CA27863
A3735F996B57A25D559E564C8C433D74342E6B2E2A8E5943AD8174A77B649C6D5C976B58
9E6C5E9D7462503C35AE978FBCB1B2AB9B97AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EA18A87A48D8CAA8370A57B67AD8C79B38D7BAF8A7AAF8176AF8678AF8A76
A47A669B6656A17260B6A18EB3978EAF8F81AF8A7DAF9386AF8176A87368A77663A7826C
9E705E976E5C9C6851986856986E569865569566569B6D5EA1745EA37661996D599A6F5A
9B725B9E72623E2E29BCA9A6AA9B8AAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAC9F9BB3927CAC8979AE8D7AA79792B98C6FAB8E7EAF8F7FAF8B7FAF8F82AF8F81
AA7C6EA17A629B6555A68472B09A8DAF9789AF857BAC9B86B39484A67967A772619E6853
9E7D648E624F8F695192615195644C8E5E4E925F4AA27967A07765A073619A6A59986958
986F5B9A715E231A1BB9A2A0BEB8BFAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAA9287AB948CA67D67A37B66A28B80A5817BAF9782AF9386AF9385AF9385AF9385
AF8176AA756A9E6E5BA77262B49C8FAF9386AF8178AA8073AB8A76A478669F725E986252
9667578E5D4C92614E926753986A5496664F9266519A6C59A06E5CA0715F996B5A946656
986F5B9B72622A1E1B5D4942EDE6E3AFA7A3AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAF8A75AC8B7C9C6954AE8F7FA4786CAB8A78AF847EAF9386AF9589AF8E7EAF9385
AF8D7BAF8670A2715DA3725DAE897DB3958BAF9180AF8F86AF8A7DA87E6FA06F60A07361
9A6F5D976353915F498E5C50986C5BA16E60A273609F73619C72619D6B5A9A6C5A9A6B5A
986C599A74604F393034262460514BFEFFFFAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AF9A91AA8774A76E5D9D8066A08573BD8678AF8478AF8D81AF9386AF978DAF968BAF9385
AF8D80AC8B78A87E6CA27764A8816DAB8A7CAC8679B39D89AF8982A6876C9F6F5F9A6F5C
976B599B6E558E5F4E9C65509B705FA17163AA7C6DA278669C76649D736199715F946F5A
9A6B5C9A7E6B8F614D6C483A422927725750AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AF8377A26D5B965447986C5B9F8677A58B7EAF8F7BAF8A7AAF9386AF9385AF9385AF9183
AF9180A88878AB8370A58977B08E7EAF8F7BAA7D6EAB8474AF7E6FA27465996755976655
92635196664F91634F9164559A6C5CA07867AA7B6AA278669C73619D6E5C9D6B5D996F5A
986B56A17B6C94614A9B6F60B5AFAEAA9E9AAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAF9C94
AF8881A260589353469E6E62AA8B79AB8A7EAF9386AF8F81AF8D80AF9487AC9281B39488
AF867BA89176AD8371AC8B77B09286AF9181AF9187AF8D80AF7F71A2755D966D5B916352
8E61508962529664529B6F61A47967A67E6DA37B69A779669C76649D6B599D6B5C9A695C
9A6C5A9E776F95614E916755AB9D9DC4C1BDAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAA846E
A77B698F634DA36651AE836EAD8A78AF8D81AF9184AF9487AF9180AF8B7FA88B7BAD8777
AE8676B08277A98670A97E6EB08B7DAF8D80AF8D7DAF8D80AC8074A6685D966555916352
926453916A59926F5BA17463A07965A77C6AA77E6CA372619C705F9D6D5D9A66569A6656
986C5B9E7E6C97563FA18575946A5EB3C9D3AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E9F684F
653C28805041653F36CA997EB19080AF8D7DAF8D7EAF8D82AF8D80AF8A76AA8773A77E6F
A17364A37969A78571B29580AD907CB39185AF8D80AF8D7EA88376A0755F97645995694F
8F61519C6C5B9A72609F6F60A57A69A8796AA07964A57F6C9E73619E74619A715F986858
98695E9B75659159439D69569E665AB3AFAAAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAF9F999D6A5A
5F3A2B483027573732B18875B19081AC8B7FB39184AF8D77A68373B29181A7806EB28B78
AE8376AC7369A87D66A57D69AF927EB49789AF8D80AF8D7CA87B6C9B6D5B906051925F4E
8C64539664539972609F715EA67562A5796A9E6B5CA1746299705F946C5A986F5D986858
98695E986F5D7D4B378D4C34A86F56B7B4BBAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAC8D7EA67C73
3B1913442A2249302AC5937EAA8A77AF8B79AB8E7FAF8D7E9F7A698D6A598963506E5147
68473D8C503AAC6F5C99543F9F5F47CCB8A2B3958BAF8D80A87E6F9B695B90634C8F644C
8B594B9A705E90685989685890695998716294735EA678659D7462976E5C926B5A996B5A
9F6C5E986C5D744536763C2D935340B4BAB6AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EB1A49FA67B679C6C5D
422C29291C18412622B89882AB8776A98573B38E7CAF8D7BAA86768C65527F615546372E
3B2723523024705145944E3B874F43986E5FB08D81AF8D82A87C679B69588A5C498F6549
67291BB1846A9C6F53966D5C8E5E49AD7966926C5D9D725D9E74649A715F8B65548C6C5B
996C5E926B56724337844A38985549B2A6A1AA9E9AAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA5A1AFA7A3AFA19DAFA7A3AFA29EAFA29EAFA29EAFA29EAFA29E532820FFC6A8A57A69
54342D2B222634201BC89C86AD8C79AF8D7BA98876B08F7CB391859F7867A06F6272574E
3D30303526244F3E3873554C946256A68774B0988CAF978DA888769B6E5D895B477F5747
67392D734E47704E3E2715148C523F775A49664131A1715C986648AB755D8E6E5F8C6756
99695B815D4D5C382D734135B37361B5A7AAAEA19DAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AF9D99AFA39FAF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29E59372F51352E4F150FA1654F
442B3032251F3B2522B69580A98876B08E7EA37664AC9178B99E91AA8B7AA37764956655
8E66538A64528156448F69539F7263A67F6DB09589AF9385A87E6E9B7460905B46885F4A
814D41765B545A48421916184E2D225E433C44332B774E3D7F58478E634D8B5F4F896C5B
996C585B3A3454382A5B3328A9624DBFCDCCB2A6A2AFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AF9A96AF9F9BAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E3A211C442E253B201D422B25
2417183C27223C2520B89580AB8C79A98C7DA5756E9160519B6D5BB6937EA888749A7062
8F594896634AA0664FA2674EC09A82B28A78B08F83AF9484A87E729B786890614E8E6348
8C694E9C6B5A9065584536352A222447322D4B3C35634C427B56438965579B6C558D6659
8C6956482F25402823583326944534BDC0BFAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E3E241C331D1831241E37221E
2F201C2B201C4C332EB0816DB9917EAA8A78AB8A7EA17D6E8459497C4E43765C4F845C4C
5F443964473D6C46398054478F6C5DA48172AB8A7AAF8678A889709B7463905F547C4833
8A553CA5835F9F7260986F5C92685A7B5747734C428D5D4C8F64519869578C6C569F725B
815F4F2E231D31231D7F5043673127BFB5B5AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA19DAFA7A3AFA29EAFA29EAFA29EAFA29E472C23311A152E211C2A201C
1C111234231D483631A17864BC947FB3927FAF8D81AF8F82AA87779A6B5E794F4B7E514C
874F43804D3E7B48398953449E7666B09084AC8878B0837BAC7D709E796893665D72423C
59302A6742306D4834B8795CAB7E689A6F58906B588C69589568558965569F6F62926C56
5B3D2F34241E372D28854F3D7E3F2E6C5A53FAFFFEAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAF9E9AAF9F9BAFA29EAFA29EAFA29EAFA29E432F293C27222F1E1A2F201C
221A162F1F1C493631966C59AE8B78B08F7CAF8D81AF9386AF9385AF9589AF9081AF9081
AF8E7EAF9589AF8E7EAF8F7DAA8670AB8E7FAA8D7DA58370A98371A58371A27C6C997062
6E4B434E312D3E2F2856352A6A4433985F4B8667519561498B5D48A072638C6454956656
3D262134221D3827274D221A79302158453EBCB2AFAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E47322D473430261E1A32201C
2E201B33242347352F8B624FB48975B99784AF8D7FAF9188AF9789AF978DAF9D97AF988F
AF9387AF9589AF9284AF9385AF8F7DAF8A74AF8D7BA88270A97F6EA97E6CA98774A97D71
9E7A6C956B6079534B543D3846322D55383063483C7354476D504388574F956F5A8E604F
3B242030201C2C211D291C174926205C413ABFB5B3AFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E4B30274A332A392A262D1F1B
351C173926224732286C4F42B3846CB39682B3917EAF8D81AF9386AF9589AF9385AF9D97
AF988FAF988FAF9284AF9385AF9180AF9183AF8B75A88370A98774A97F6EA97E6CA98172
A27B6B9F79669573618C68588465557152456F4D417F55478A64578E63568B62556E4D3B
3D282330201C382520261F1B32211C4F352AB1A1A3C9CCC7AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E432B224E3933392823392420
251B1636211D37231E603E30906349C6A18EB0927FAF8D81AF9386AF9991AF9387AF9385
AF9D97AF968BAF968BAF9385AF8D79AF8D7FAC8576AC8270A97E6CA98572A9816FA97E6C
A27866A07361A07462997362986C5A9D715F946F5D92685899695B99695A8A5D4B4E352D
2C1E183A2626271C1B281D171C1212452A238D6F67C6C2C3AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E472E2446353145332E392723
36231E2C1F1B3929244D37316B4838BC896FB99984AF9185AF9184AF9B90AF9D97AF9387
AF9589AF9284AF9385AF9385AF8D7BAC8B75AC8573A9816FA9816FA97E6CA77E6CAB7B69
A77B699C73619D74629D7765997361986C5A9A6F5D8B68589269588666556A4B3E3F2923
3729241F1616271D1D1A1112251B1B32201B795D56C2B5B2AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E47322B4D38314A383242312C
39231F261C173F272253382E684B3D966A54B89886B39283AF8D84AF9184AF9B90AF9D97
AF988FAF9387AF8E7EAF9385AF8D80AA8A77A57F6DA77D6CAB7B69AD7E70A27E69A37966
A3796A9C76619D74629D715F9A74619A715F956856946E5D8C63517E594C5E3C2F3E2722
271D18261C1D1F1616241B16231A1C3A252088726B866C65AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA19DACA39F43332D4A38324F3C36473530
32201C39292437272346312A7B4E3B94614EAE8671B49480AF8D81AF8F82AF8F82AF9991
AF988FAF988FAF9284AF9385AC8B7BB38F7FA88370A5816FA27A69A37567A77969A37361
A07667A070619A6E5F9E745F9A6F5D986F5D9465558F67568B5B497650414630263D2621
281F1B281F1B271E1B231A1629201C3C2521C6BDBAAA9E9AAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAF9E9AAA96923A2A2552372D4637324D3A35
3F2E2A362722402F2A452F266A5044885441B4836FB39985B39185AF9184AF9789AF978D
AF9B92AF9B92AF9489AC9281AC8C7BAD8C79AC7C6BA77B66AB7E6FA77B66A3796AA37564
9C74629D7664996B5C946C5D986B5A986F5C926B5A8B63517E55445F3D35442A232E221D
271C17261C1D21171715121222171752352FB6B1AEB2A6A2AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E45312B462F244E3B354C3934
42312B3C272246322746342F5E483B6C4235A8735CB89884B08E7FAF8D82AF9188AF9484
AF9488AF9488AF9187AA8A77A57F6DA98472A77E6AA77C66A37967A37C64A37965A37361
9C79679D715F9D715F976F5D9868589566558765547E57455F3E3652362933211D2B211C
2E201B231B1B1F16161D151634231F6C4D4A74524CAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E553F39412E2849352F533C36
4330263E2E293D2A244B373147352D5A40378D5743B4896FBA9F8DB08F7CB39182AF8D7E
AF8D7BAC8B79B08F7FB39181A87F6DA77B68A77B66A06E5FA57767A57767A87967A0705E
A072609D6E5F9A725D9A6F5A9565569266557E5B4A673F334F352936231E291D17271C1D
32211C241B1C1A11122016173D2621C8BFBCB2A6A2AFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E5C483E4937344A3832493530
4A352E3826253E2C2643322C4C3934463026623E319E7158B68A72B3917CB19580B0907C
B0937FAC8B79A98674AD8D7AAA8270A3705EA57761A0735F9D6E5C9D7764A27461A0715F
9A6B5A9E6B5C976959956E598E65518758457D56434E342938231E2E221D251B16201617
2217171512121511123823203E2720BAB6B8AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E70594F3F2B234B3A35473530
503D373F2B233724214A3A3441302A4F3A333F2A246F5141825A48B1745CBC937DA8826D
AF8F7EAC8B77AC8870AF8875A07865936754A16B57A66F57A271619E6C5B9E68559E7461
9A6B539566599263518B604E7F604E6B443760382A432A2432211C251C17201617201616
1A11121311121E151632211C7C564C76584EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E99828349322C402E2A4B3832
4B383240322B3925244C3328473632503D3845342F48362F5C463D764C3D915F488E6A5F
8C6A58A26E58A37E69A178638E65558759437C503D915D439B5F4B9C6C53A06551916050
905E479760498F604E7D564975493A5E382B49292335221D271C172116171A1112141112
141112141112291F1B382320B9AEACAB9B97AFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E6551493B2A234A3833
46383244322D29201C47322C523D37503D3754423C4E3C375542395D453C62453861413A
5F4033644139794B3A7C594763463D6544396D41326B432E74453789584189574182523D
8053407345347A4F416E43365C3C30432822422B26261B16261C171F1616191111131112
1311122C1F1B221A1B664B44938885AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E846F703D2925463530
4938324736313E302B42332E503D3857433D4E3B3654403A5A3D35634436543C304B3A34
432D27513831462823593F36523A3348332D482A244B31294B2B23562F265F3E2D5B3A2B
5C3A2B532D25522E264B2D26482B2430231D2A1D18221717201616201616131111141112
2C1F232C1F1A3E2F2C856A6790736DAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EA694955C423F382722
4735304C393446342F55423C42312B5B464045332D513D385B40374E36314F352D4A352F
3F2F294F383334242340322B4128233F292433221D2F221E36221D40262140272136241D
39241E37231D41262133211C34221D261C17251C171F16161F16161411121411121E1516
3828263723206D5650725750AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E87716F402B25
4839344C393447353042352E56413B513F3943353043302A5C3C2F41302A47352E44322D
34282B45352D3A26273C27223222262F221C2E211C261C172C211D2E211C30221D281C17
221717291D1735221D271C17221717271C17251B1B1F16161411121F1616251E1A312422
3623206B4F496B4C45AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EA18B8C513633
412E2A4F3C36473530483832463934543F3945342E3E2D28432E2736231D45332D382726
37272732231E332328281D1C231718281D1D261C1C201616261D1C211717271D1D201616
251B1B291F1B261B1B211616141112151112151212151112241B1B221A16201617351E18
7359546F554EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E795D55
3A241F3A2B264B3832493B35493A35523E394332313A25203C2B262B201C35231E2E231E
34221E211717231718271C1D241B1B1F1616251C1D1F1616251B1C1F1616372420121011
271C1D2A211C241B1C141112141112191112221A1B20191A231A1B37241F36292248342F
8C868CAB9B97AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
795D5537221D3B302C43312B52413C503E394F3C38382B27402D282D1F23251C1B32211C
251C1C2A201B271E1B231A1B20161720161720161720161720161729201C271B1C3B3236
2F28242A1C1F1F1616231B1B241D1A241C1A221A1B3B2C2830242237231F5C3C327F6152
8D695AAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29E7A584F37221D41342F41302A4F403A5B453F4839343F2D24372826271E1C261B1C
211617261D17261C1D201617201617241B1B1E1516241B1B1E15162017173E3634372832
544842423535302427382C2A302522261E1A3728243929254A38334C30296F514B836258
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EB3A7A37D5C543E251F493C3844353058463F56433D503C35372621372824392D2A
2D2523291C19271F1B231A1B231A1B1F16162016172A2024231A1A281E1B271E1F433632
4D38362D21213728223527222D202034231D3B2B26452F265F443A67504E8D6D5EAF9F9B
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29E7550423E251E402F2B55403A65504A5B4A444936313425213A2827
3F292341332E32282422191A2016172F24282A2023342A262B212741322C231C20503F37
3F302F3D2E2A362A27342824382B2940322D392A275F41356D50467C5349A49090AFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E75594C34150635251F513D38604C455E5353543D34423230
43322F3C2A283F38344536373629242E2225372E3640312D473C4042312A3E2F2D4D3D39
503A364C34304C352B463834533D3560473B44322A8D6E628D6456AF9F9BAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29E9D87875E3A3535211C4E3C344E474C725E59624E49
6250485846434D40415344455E4D4C4D3C384D3D3E4131344736324F3C39513E394C3934
5D3B32593C35573D3459423B52372E785C5472483178574CAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA5A1AFA7A3AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E75595940161134181346383879655D
6E5F5B5D4B3E63504A64544F67524C634C4959463E4E3F3C4F3B3844363055424059443E
523B336242395738328E6C6261311A531A108D706DAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AF9A96AF9F9BAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EA694956F525C5B3539
76525876555770493858382C5743397058537154496E564F6F57506B544B644F47694D41
685347876D643C11026235339E8585AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EA6949AA893969D838870515D583844542E2D51291E512B2051271C4C2217451606
4213007F6156AF9F9BAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29EAFA29E
AFA29EAFA29EAFA29EAFA29E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?oooeV_XYh4Z8A`1;2>O0>_SH44[i>61:n=P0B_ThH;[i>51:n=
P0B_SGX4Z8Qe1:V3L0BRMfD4XgUW0iacHA2MM684WFiL0iM_F0BHKeh4V6mH19Q_GPBc[:`?[j:N1:nL
V0B_XilS[j:N5Oooo`005?oooeV_XYh4Z8A`1;2>O0>_SH44[i>61:n=P0B_ThH;[i>51:n=P0B_SGX4
Z8Qe1:V3L0BRMfD4XgUW0iacHA2MM684WFiL0iM_F0BHKeh4V6mH19Q_GPBc[:`?[j:N1:nLV0B_XilS
[j:N5Oooo`005?oooeV_XYh4Z8A`1;2>O0>_SH44[i>61:n=P0B_ThH;[i>51:n=P0B_SGX4Z8Qe1:V3
L0BRMfD4XgUW0iacHA2MM684WFiL0iM_F0BHKeh4V6mH19Q_GPBc[:`?[j:N1:nLV0B_XilS[j:N5Ooo
o`005?ooo`B_XYh4[j6M1:nWX`B_XYh4[j6M0jnWXb>_XYh4[j6M1:nWXaN_XYh4ZXIb1:^:NP>_SG/4
[i>:1:n=P0B_ThH4[i>51:nAP0>/TXD4/9:51;2=O0BZRGH4YhA`1:QkJ0BUNFL3WW=Q1:5gI@RMM688
WG5O0iM_FPBHKe/4V6mH19QhJ`BcVY0?[j:N1:nNVPB_Wi/S[j:N5Oooo`005?ooo`B_XYh4[j6M1:nW
X`B_XYh4[j6M0jnWXb>_XYh4[j6M1:nWXaN_XYh4ZXIb1:^:NP>_SG/4[i>:1:n=P0B_ThH4[i>51:nA
P0>/TXD4/9:51;2=O0BZRGH4YhA`1:QkJ0BUNFL3WW=Q1:5gI@RMM688WG5O0iM_FPBHKe/4V6mH19Qh
J`BcVY0?[j:N1:nNVPB_Wi/S[j:N5Oooo`005?ooo`B_XYh4[j6M1:nWX`B_XYh4[j6M0jnWXb>_XYh4
[j6M1:nWXaN_XYh4ZXIb1:^:NP>_SG/4[i>:1:n=P0B_ThH4[i>51:nAP0>/TXD4/9:51;2=O0BZRGH4
YhA`1:QkJ0BUNFL3WW=Q1:5gI@RMM688WG5O0iM_FPBHKe/4V6mH19QhJ`BcVY0?[j:N1:nNVPB_Wi/S
[j:N5Oooo`005?ooo`B_XYh4[j6M1:nWX`B_XYh4[j6M0jnWXb>_XYh4[j6M1:nWXaN_XYh4ZXIb1:^:
NP>_SG/4[i>:1:n=P0B_ThH4[i>51:nAP0>/TXD4/9:51;2=O0BZRGH4YhA`1:QkJ0BUNFL3WW=Q1:5g
I@RMM688WG5O0iM_FPBHKe/4V6mH19QhJ`BcVY0?[j:N1:nNVPB_Wi/S[j:N5Oooo`005?ooo`B_XYh4
[ijJ1:nMV@B_Yj<4[ijJ0jnOV`B_XYh4[j6M1:nWX`B_XId4[jNS3jnRWPB_WYX4[inK5jnRWPB/R7<4
/i620jn=P0B_TH44[i>51:n=P0B_U8L4[8ij0j>9N@BcQg44Zh5`1:>2J`BPOV`4WGET19ecHP>IKEd4
V6mM29idH@BNLEl4WVmJ0iY_H0BHKed4V6mJ1:6AR0BQSHDC[j:N1:nQW@B_Yj<O[j:N5Oooo`005?oo
o`B_XYh4[ijJ1:nMV@B_Yj<4[ijJ0jnOV`B_XYh4[j6M1:nWX`B_XId4[jNS3jnRWPB_WYX4[inK5jnR
WPB/R7<4/i620jn=P0B_TH44[i>51:n=P0B_U8L4[8ij0j>9N@BcQg44Zh5`1:>2J`BPOV`4WGET19ec
HP>IKEd4V6mM29idH@BNLEl4WVmJ0iY_H0BHKed4V6mJ1:6AR0BQSHDC[j:N1:nQW@B_Yj<O[j:N5Ooo
o`005?ooo`B_XYh4[ijJ1:nMV@B_Yj<4[ijJ0jnOV`B_XYh4[j6M1:nWX`B_XId4[jNS3jnRWPB_WYX4
[inK5jnRWPB/R7<4/i620jn=P0B_TH44[i>51:n=P0B_U8L4[8ij0j>9N@BcQg44Zh5`1:>2J`BPOV`4
WGET19ecHP>IKEd4V6mM29idH@BNLEl4WVmJ0iY_H0BHKed4V6mJ1:6AR0BQSHDC[j:N1:nQW@B_Yj<O
[j:N5Oooo`005?ooo`B_XYh4[ijJ1:nMV@B_Yj<4[ijJ0jnOV`B_XYh4[j6M1:nWX`B_XId4[jNS3jnR
WPB_WYX4[inK5jnRWPB/R7<4/i620jn=P0B_TH44[i>51:n=P0B_U8L4[8ij0j>9N@BcQg44Zh5`1:>2
J`BPOV`4WGET19ecHP>IKEd4V6mM29idH@BNLEl4WVmJ0iY_H0BHKed4V6mJ1:6AR0BQSHDC[j:N1:nQ
W@B_Yj<O[j:N5Oooo`005?ooo`R_XYh4[ibH1:nSW`^_XYh4[ijJ1:nOV`B_WYX4[inK;ZnRWPBZQ704
Zhin0jn=O@B_SH04[i641:nAP`B_SGh4ZXYm0iZ3L`BGNVT4Y71W19M`F`BKM684VgUZ19]iI`>IL5h4
UgAO39Q_G@BHKeX3VW5N19A/FPBHKed4/jb/5jnRWPB_WYX4[inK7jnRWQGoool001Coool8[j:N1:nL
V0B_Xil;[j:N1:nNVPB_Wi/4[ijJ1:nOVbj_XYh4ZXA`1:^>OP>_SGd4[hf01:nAQ0B_TH<4[hen1:Z:
O@>JPg<4UgYY1:A`I`BGL5/4VgAR19]iJPBKNFL3VG1N19MdG`bHKed4V6mJ0iYaGPBDK5X4V6mM1;>/
[1N_XYh4[ijJ1:nOVan_XYhEoooo000Doooo2:nRWPB_W9P4[j>O2jnRWPB_WYX4[inK1:nNVPB_Wi/^
[j:N1:Z4L0B[SWh3[hem1:n=P0B_TH@4[i631:n=OPBZRWd3VX=c19MjJ@BTL6L4Ug1K19]dHPBKNFX4
VgUW0iU`GPBGM5l<V6mM19Q_FP>JLEh4U6aJ19Q_G@Bc[:`G[j:N1:nNVPB_Wi/O[j:N5Oooo`005?oo
o`R_XYh4[ibH1:nSW`^_XYh4[ijJ1:nOV`B_WYX4[inK;ZnRWPBZQ704Zhin0jn=O@B_SH04[i641:nA
P`B_SGh4ZXYm0iZ3L`BGNVT4Y71W19M`F`BKM684VgUZ19]iI`>IL5h4UgAO39Q_G@BHKeX3VW5N19A/
FPBHKed4/jb/5jnRWPB_WYX4[inK7jnRWQGoool001Coool8[j:N1:nNVPB_Wi]9[j:N1:n6LPB_RW`3
[hf21:n=Q0R_SH04[hel1:n?O`>_Rgl4ZXIe1:UmK`BXLfX4XWAP1:9bI0BOKF@3XG5T195PE@BFKed4
UWMU19AYE@BJKed3VW9P19MaG`BJM684[Z>S?ZnRWQGoool001Coool8[j:N1:nNVPB_Wi]9[j:N1:n6
LPB_RW`3[hf21:n=Q0R_SH04[hel1:n?O`>_Rgl4ZXIe1:UmK`BXLfX4XWAP1:9bI0BOKF@3XG5T195P
E@BFKed4UWMU19AYE@BJKed3VW9P19MaG`BJM684[Z>S?ZnRWQGoool001Coool8[j:N1:nNVPB_Wi]9
[j:N1:n6LPB_RW`3[hf21:n=Q0R_SH04[hel1:n?O`>_Rgl4ZXIe1:UmK`BXLfX4XWAP1:9bI0BOKF@3
XG5T195PE@BFKed4UWMU19AYE@BJKed3VW9P19MaG`BJM684[Z>S?ZnRWQGoool001Coool8[j:N1:nN
VPB_Wi]9[j:N1:n6LPB_RW`3[hf21:n=Q0R_SH04[hel1:n?O`>_Rgl4ZXIe1:UmK`BXLfX4XWAP1:9b
I0BOKF@3XG5T195PE@BFKed4UWMU19AYE@BJKed3VW9P19MaG`BJM684[Z>S?ZnRWQGoool001CooomI
[j:N1:n:M@B_SG/3[hem1:n=N`B_SH@4[hf01:n?PPB_SH03[iB71:nCQ@BZQWD4Ygi^1:EeJ0BYNV`4
YGMV0j=fI`BRKf@4VFQJ19e_HPBINF`4V6UE0ii_G@BJKed4Xh=e1:VHSQ^_XYh4[j6M1:nWXa^_XYhE
oooo000DooooFJnRWPB_RWD4[hek0jn=O@B_SG/4[hf41:n=P0B_Sh84[hf00jnDQ`B_ThD4ZXIe1:Mn
KPBUMFP4ZGY/1:EgIP>SMVL4XVmT19UXFPBMKf84VGU/19QYE@>NKed4VVmM1:>3M@BYV8hK[j:N1:nQ
W@B_Yj<K[j:N5Oooo`005?oooeV_XYh4[hYe1:n=N`>_SGd4[hek1:n=Q0B_SH04[hn21:n=P0>_U8L4
[i>51:Z6M@BWOVh4YGEX1:UjK0BUMfH3XgIW1:9_I0BIJ5X4WFmR19UiK0BHJED3WVmM19Y_G@BSPgD4
ZIR>6jnRWPB_XId4[jNS6jnRWQGoool001CooomE[j:N1:J>Q0BlZYP4[hem0jn=N`B_SGh4[hf11:n?
PPB_SH04[i>50jn;O`B_Sh84[hf01:n=O0BZQ6h4Yga^1:EjK0>UNVT4Wg1T19mdH@BIKU`4VWEU19Yc
H`>JKed4U6mM1:bGTPB`WIDK[j:N1:nNVPB_Wi/7[j:N1:nQW@B_YJ44[jNS2:nRWQGoool001CooomE
[j:N1:J>Q0BlZYP4[hem0jn=N`B_SGh4[hf11:n?PPB_SH04[i>50jn;O`B_Sh84[hf01:n=O0BZQ6h4
Yga^1:EjK0>UNVT4Wg1T19mdH@BIKU`4VWEU19YcH`>JKed4U6mM1:bGTPB`WIDK[j:N1:nNVPB_Wi/7
[j:N1:nQW@B_YJ44[jNS2:nRWQGoool001CooomE[j:N1:J>Q0BlZYP4[hem0jn=N`B_SGh4[hf11:n?
PPB_SH04[i>50jn;O`B_Sh84[hf01:n=O0BZQ6h4Yga^1:EjK0>UNVT4Wg1T19mdH@BIKU`4VWEU19Yc
H`>JKed4U6mM1:bGTPB`WIDK[j:N1:nNVPB_Wi/7[j:N1:nQW@B_YJ44[jNS2:nRWQGoool001CooomE
[j:N1:J>Q0BlZYP4[hem0jn=N`B_SGh4[hf11:n?PPB_SH04[i>50jn;O`B_Sh84[hf01:n=O0BZQ6h4
Yga^1:EjK0>UNVT4Wg1T19mdH@BIKU`4VWEU19YcH`>JKed4U6mM1:bGTPB`WIDK[j:N1:nNVPB_Wi/7
[j:N1:nQW@B_YJ44[jNS2:nRWQGoool001CooomA[j:N17eZGPCG]ZH4ZHEf1:n=P@>_SG`4[hei1:n=
O@B_ThH4[hf01:nAP@>_Uhd8[i631:n=OPB_RWX4[7e]1:b1K0>YNf`4XWQS1:1^H@BPM684VFaJ19A_
G@>NM684VF]J1:ZOWPB[ViLZ[j:N1:nNVPB_VYH4[inK2:nRWQGoool001CooomA[j:N17eZGPCG]ZH4
ZHEf1:n=P@>_SG`4[hei1:n=O@B_ThH4[hf01:nAP@>_Uhd8[i631:n=OPB_RWX4[7e]1:b1K0>YNf`4
XWQS1:1^H@BPM684VFaJ19A_G@>NM684VF]J1:ZOWPB[ViLZ[j:N1:nNVPB_VYH4[inK2:nRWQGoool0
01CooomA[j:N17eZGPCG]ZH4ZHEf1:n=P@>_SG`4[hei1:n=O@B_ThH4[hf01:nAP@>_Uhd8[i631:n=
OPB_RWX4[7e]1:b1K0>YNf`4XWQS1:1^H@BPM684VFaJ19A_G@>NM684VF]J1:ZOWPB[ViLZ[j:N1:nN
VPB_VYH4[inK2:nRWQGoool001CooomA[j:N17eZGPCG]ZH4ZHEf1:n=P@>_SG`4[hei1:n=O@B_ThH4
[hf01:nAP@>_Uhd8[i631:n=OPB_RWX4[7e]1:b1K0>YNf`4XWQS1:1^H@BPM684VFaJ19A_G@>NM684
VF]J1:ZOWPB[ViLZ[j:N1:nNVPB_VYH4[inK2:nRWQGoool001Coool8[j:N1:nQW@B_Yj<m[j:N1:>E
U0A:;BH4dkBM1:^:M0B_Sh<3[hYm1:n?PPB_RWd4[i641:nCQ@B_RgX3[hem1:nAP0B_QWl4[95i1:j=
N0B`RGT4ZGi_0jMjK0BSLf44Xg=O19UaH0BJKUT4VVmP0i]eHPBNMV<4][2_@ZnRWQGoool001Coool8
[j:N1:nQW@B_Yj<m[j:N1:>EU0A:;BH4dkBM1:^:M0B_Sh<3[hYm1:n?PPB_RWd4[i641:nCQ@B_RgX3
[hem1:nAP0B_QWl4[95i1:j=N0B`RGT4ZGi_0jMjK0BSLf44Xg=O19UaH0BJKUT4VVmP0i]eHPBNMV<4
][2_@ZnRWQGoool001Coool8[j:N1:nQW@B_Yj<m[j:N1:>EU0A:;BH4dkBM1:^:M0B_Sh<3[hYm1:n?
PPB_RWd4[i641:nCQ@B_RgX3[hem1:nAP0B_QWl4[95i1:j=N0B`RGT4ZGi_0jMjK0BSLf44Xg=O19Ua
H0BJKUT4VVmP0i]eHPBNMV<4][2_@ZnRWQGoool001Coool8[j:N1:nQW@B_Yj<m[j:N1:>EU0A:;BH4
dkBM1:^:M0B_Sh<3[hYm1:n?PPB_RWd4[i641:nCQ@B_RgX3[hem1:nAP0B_QWl4[95i1:j=N0B`RGT4
ZGi_0jMjK0BSLf44Xg=O19UaH0BJKUT4VVmP0i]eHPBNMV<4][2_@ZnRWQGoool001Coool8[j:N1:nN
VPB_WIT4[jNS=JnRWPBaY9l4Ecda19YnN`AbDe44[hf01:nAP@>_TH<4[i641:nAP`B_SH04[i641:nG
R@>_SH04[8]h1;1oMPB/OVh4XWQV1:MlJPB[OV`3YgiY19aeIPBRLEl4X7AQ19UaG0BFKe/3U6mM19Ya
H0B/Wi/4/kFe?ZnRWQGoool001Coool8[j:N1:nNVPB_WIT4[jNS=JnRWPBaY9l4Ecda19YnN`AbDe44
[hf01:nAP@>_TH<4[i641:nAP`B_SH04[i641:nGR@>_SH04[8]h1;1oMPB/OVh4XWQV1:MlJPB[OV`3
YgiY19aeIPBRLEl4X7AQ19UaG0BFKe/3U6mM19YaH0B/Wi/4/kFe?ZnRWQGoool001Coool8[j:N1:nN
VPB_WIT4[jNS=JnRWPBaY9l4Ecda19YnN`AbDe44[hf01:nAP@>_TH<4[i641:nAP`B_SH04[i641:nG
R@>_SH04[8]h1;1oMPB/OVh4XWQV1:MlJPB[OV`3YgiY19aeIPBRLEl4X7AQ19UaG0BFKe/3U6mM19Ya
H0B/Wi/4/kFe?ZnRWQGoool001Coool8[j:N1:nNVPB_WIT4[jNS=JnRWPBaY9l4Ecda19YnN`AbDe44
[hf01:nAP@>_TH<4[i641:nAP`B_SH04[i641:nGR@>_SH04[8]h1;1oMPB/OVh4XWQV1:MlJPB[OV`3
YgiY19aeIPBRLEl4X7AQ19UaG0BFKe/3U6mM19YaH0B/Wi/4/kFe?ZnRWQGoool001Coool8[j:N1:nQ
W@B_XYh4[inK=JnRWPARASL4/YnG16i>@PB[RW@4[hf11jn=P0B_SGh4[hf41:n=P0B_Sh84[hf00jnA
P`BXLVH4ZH5a1:McI0BWMVD4XgAS1:>9K`NPMV44WFiL19YbG0BQKf04WFmM0iM_FPBNKUl4XXMf1;g2
b2Z_XYh4[j6M1:nWX`b_XYhEoooo000Doooo2:nRWPB_XId4[j:N1:nOVcF_XYh4HTHg1;:OU`A^CT84
ZhYd1:n=P@N_SH04[hen1:n=Q0B_SH04[hn21:n=P0>_TH<4Z79V1:V1L@BWLf@4YgIU1:=dH`BSRFl7
X7IQ19e^G0BJLU`4XFmP19e_G@>GKeX4WViO1::7MPBm`/PZ[j:N1:nQW@B_Yj<<[j:N5Oooo`005?oo
o`R_XYh4[j6M1:nRWPB_Wi/e[j:N1696=`BbWiL4KTi21:^:M0B_SH47[hf01:n=OPB_SH@4[hf01:n?
PPB_SH03[i631:QbIPBYPG44Yg=T1:MfI@BSM6<4XhU_1j1fH@BMKU`4VW9L1:5_H0BMKed3UfmJ19i^
G`BRQgH4_L;8:ZnRWPB_XId4[jNS3:nRWQGoool001Coool8[j:N1:nQW@B_XYh4[inK=JnRWPARASL4
/YnG16i>@PB[RW@4[hf11jn=P0B_SGh4[hf41:n=P0B_Sh84[hf00jnAP`BXLVH4ZH5a1:McI0BWMVD4
XgAS1:>9K`NPMV44WFiL19YbG0BQKf04WFmM0iM_FPBNKUl4XXMf1;g2b2Z_XYh4[j6M1:nWX`b_XYhE
oooo000Doooo2:nRWPB_WYX4[inK=ZnRWP>SUI44L5Y?17IIC@B_TH<4[hej1:n=P@B_SH03[h]k2:n?
O`B_THP4[i641:n9OP>_TH84Z6MN1:MMD`BSDTP4Z65L1:1FC0BXJEh3VG5M19idG`BNKeX4VVUH19ib
GPBMKed3VFmJ19YXEPBILV04YXj11;c<eBJ_XYh4[ijJ1:nOV`b_XYhEoooo000Doooo2:nRWPB_WYX4
[inK=ZnRWP>SUI44L5Y?17IIC@B_TH<4[hej1:n=P@B_SH03[h]k2:n?O`B_THP4[i641:n9OP>_TH84
Z6MN1:MMD`BSDTP4Z65L1:1FC0BXJEh3VG5M19idG`BNKeX4VVUH19ibGPBMKed3VFmJ19YXEPBILV04
YXj11;c<eBJ_XYh4[ijJ1:nOV`b_XYhEoooo000Doooo2:nRWPB_WYX4[inK=ZnRWP>SUI44L5Y?17II
C@B_TH<4[hej1:n=P@B_SH03[h]k2:n?O`B_THP4[i641:n9OP>_TH84Z6MN1:MMD`BSDTP4Z65L1:1F
C0BXJEh3VG5M19idG`BNKeX4VVUH19ibGPBMKed3VFmJ19YXEPBILV04YXj11;c<eBJ_XYh4[ijJ1:nO
V`b_XYhEoooo000DooooAZnRWP=B?SL4k<^h1;2AR0B_SH84[hen1:n=P@B_SGh3[8Ef1;27M0BcTgl4
[hYn1:n9N@B/LVh3[W=V1:YhK`BNC3d4[6UN1:A<B@BI@3L4XU550j1QEPBDJEX4V7EN19QXC`BKKf04
XFmP0ie_G@BMJeX4WFmN19egI@BbYj@4[j^/=ZnRWQGoool001Cooom6[j:N0e8n=`C/bkP4/9681:n=
PPB_SGh4[hf11:n=OP>/QGH4/8Md1;>CO`B_RWh4[hUi1:abKP>^LfH4ZWQ_19i<?@B/JEh4Y4a919U0
=`BRDDD3X65F19AYFPBHMEh4V6Q?19]_H0BQKf03WFmM19e[FPBMKeh4WGMU1;:WY0B_Zj`f[j:N5Ooo
o`005?ooodJ_XYh3DShg1>c;^0B`THP4[hf21:n=OPB_SH44[hen0jb5MPB`Qg@4/i=o1:n:OPB_RGT4
[79^0jicIPBZN6l4WT`m1:aYGPBTC4T4VD0g1:9AA@>PHEH4U6UJ19QeGPBHJ4l4VfmP1:5_H0>MKed4
WF]J19e_GPBMMfD4/ZNT1:n[[3J_XYhEoooo000DooooAZnRWP=B?SL4k<^h1;2AR0B_SH84[hen1:n=
P@B_SGh3[8Ef1;27M0BcTgl4[hYn1:n9N@B/LVh3[W=V1:YhK`BNC3d4[6UN1:A<B@BI@3L4XU550j1Q
EPBDJEX4V7EN19QXC`BKKf04XFmP0ie_G@BMJeX4WFmN19egI@BbYj@4[j^/=ZnRWQGoool001Coool@
[j:N1:nQW@>_Yj<[[j:N19B2P0=eHUD4Q6iT1:^:NPB/RG84/iN71:n:NPB_RGD3YX=/1:MgI`BiUhP4
ZWAV17`c80COYI@3YeI>1:5/H@B>DdH4RT<d19MiH`BGEdL4W4a80h/o<PBaDTH4UGQS19]^D@BJK5T4
VWEP0j1`G@BIJEX4WG5P19e_G@BYSGd4_;o01:n[[3:_XYhEoooo000Doooo4:nRWPB_XId3[jNS:jnR
WPBDPX03MF9E18A^I0B[RWX4[8Ub1;>GQ`B_RWX4[hUe0jJ3K0BWMfL4^IN81:YdIPAl<b04gjFD0jMF
CPBQK644SU=618Y3=0BGNF<4UeM719a<B0>;?c84/E9619EhH`BKKU44VVaI19YeH0>PL5d4VFUJ19ea
H0BMKed4ZHem1;bo`0B_Zj`b[j:N5Oooo`005?oooa2_XYh4[j6M0jnWXb^_XYh4U8:00gERE@B4KV@4
ZhYj1:b9LPBcUhL4[hYj1:n9M@>VPf`4YgMW1;VGR0BZM6H4O3<P1=nUU0>WETh4XFaQ18iCAPB:@c@4
UgUS19MGA`BLC4P3Rclb1;5BAPBEN6<4VfiA19Y/F@BJMF03X71M19UYFPBMLF04WFmM1:V=O@Bl_l04
[j^/<ZnRWQGoool001Coool@[j:N1:nQW@>_Yj<[[j:N19B2P0=eHUD4Q6iT1:^:NPB/RG84/iN71:n:
NPB_RGD3YX=/1:MgI`BiUhP4ZWAV17`c80COYI@3YeI>1:5/H@B>DdH4RT<d19MiH`BGEdL4W4a80h/o
<PBaDTH4UGQS19]^D@BJK5T4VWEP0j1`G@BIJEX4WG5P19e_G@BYSGd4_;o01:n[[3:_XYhEoooo000D
oooo2:nRWPB_XId4[jNS1:nNVP>_Wi/[[j:N158m=`?5W8T4Wg]]1:n=N`BXOg04/9N:1:nAP`B_PVl3
Wf]C19i[F@B1;BH4cZVO17`N5PAg;243WeA61:AHAPB[Q7@4Y5mD19I:@@An@B/4N4dn0f/i;@A]=B@4
^Ea919alH0BNIU@4X7QV0j1fHPBOLUd4VFaM19eaG`BMM684ZIZI1;VYV@>cZjL_[j:N5Oooo`005?oo
o`R_XYh4[j6M1:nWX`B_WYX3[inK:jnRWPAB?CL3aIb919mkK@B_SG/4Z7m`1;2GRPB_TH<4[h9_0im[
D`BNJeT4PBdV1<jYW`Al7QH4Mb`Q0imDAPBTF4H4ZhAd1:AOE0BFBT44OT4[17Q=?P=[>Bd4KCDT1;UL
B@BLO604WVID1:1hIP>PMV84Wg9M19U/G@BMLEl4WGAR1:VJV@BiZIT3/j^W;jnRWQGoool001Coool8
[j:N1:nQW@B_Yj<4[ijJ0jnOVb^_XYh4DSdg0lFLR@BONfd4[hek1:QoL0B`UhX4[i631:n2K`>OJe<4
WV]I184]9PC>ZIl4O1hF17L/8@>OE4H4Y5Q61:^4M0BTGe@4UTY117i1:`AhCCh3JcT]16de90BiG4T4
W7aP19iVE0BPN6H3X7IR19mbG@BIK5d4WG5O19edHPBYVYT4^JVI0k>[Ybn_XYhEoooo000Doooo2:nR
WPB_XId4[jNS1:nNVP>_Wi/[[j:N158m=`?5W8T4Wg]]1:n=N`BXOg04/9N:1:nAP`B_PVl3Wf]C19i[
F@B1;BH4cZVO17`N5PAg;243WeA61:AHAPB[Q7@4Y5mD19I:@@An@B/4N4dn0f/i;@A]=B@4^Ea919al
H0BNIU@4X7QV0j1fHPBOLUd4VFaM19eaG`BMM684ZIZI1;VYV@>cZjL_[j:N5Oooo`005?ooo`R_XYh4
[ijJ1:nOVbj_XYh4YYZK13`W80?3XH/4/8io1:n=OPBZPG44ZhAi1:n=P0BZMf<3VFQ;19M8>0AR8aP4
ZWab1:NTU@B`VY83/kNd1:nGS`B_W9L4YX9f1;6WV`BZQGD4VXf;0fA3?0AA=2h4EBTO1;MRB@BSOFL4
ZG]V0jImK`BOLUh4W71M19eYF0BMMF84VY6A1:>DVP>g/;L4_;FW:jnRWQGoool001Coool8[j:N1:nN
VPB_Wi/^[j:N1:JJV`@l9b03`j6;1;2>O`B_SGh4ZX5a1:^4N@B_SH04ZWMS0iUXB`BGB3P4HR<H1:Yl
LPBWY9D4/9ZB0k>g]0B_Uhl4[ibG1:J2MPBaYi/4ZXEe19Z=R`=T@c`4DC@^15DY7`BgHTT4XgeW1:Uk
IP>VOFl4Wg9N19a`G@BMJEP4WGER19ZAT@BSU9X3]k2g1;beYb^_XYhEoooo000Doooo2:nRWPB_WYX4
[inK;ZnRWPBVVY/4?2LP0l>QR`B`SWl4[hen1:Z1L@B[Q7T4[hf01:YgH`>IJ4/4UdPh168S60BZO784
YjBE1;2JTP>c]k@4[iN?1:nLU`BVPWH4/JNK1:Z5M@BJSH/3I4<l154d;PAE:Al4]f991:=mI`BYNfH3
YWe_19mbGPBLL5d4WFUH19eeHPBJTI44XiBJ0kN`]`Bl]JL[[j:N5Oooo`005?ooo`R_XYh4[ijJ1:nO
Vbj_XYh4YYZK13`W80?3XH/4/8io1:n=OPBZPG44ZhAi1:n=P0BZMf<3VFQ;19M8>0AR8aP4ZWab1:NT
U@B`VY83/kNd1:nGS`B_W9L4YX9f1;6WV`BZQGD4VXf;0fA3?0AA=2h4EBTO1;MRB@BSOFL4ZG]V0jIm
K`BOLUh4W71M19eYF0BMMF84VY6A1:>DVP>g/;L4_;FW:jnRWQGoool001Cooolj[j:N17eZGPAQ@S`4
U7E_0h5[G`B[RWP4[hUf1:n@O0B_UHD4[hf21:9[G0>CJE@4PdHg15d?3`Ag<2d4XViM1:MiJ@>_SH04
]8Mk1:Z@N0B[KE`4ZFeM1:EdI0B`WhL3X6aJ18YZH@AMAc/4FA`B1<1nJPBUPFH3ZXEc1:9gH`BLL644
VViL1:5^GPBIOVh4V92?0hUeNPBf[jX[[j:N5Oooo`005?ooocZ_XYh4OFYN1652?0BDMFl3PF]O1:^:
N0B_RGH4[i1l1:nEQ@B_SH84XV]L0i=YE0B3ASL4G@l?17L`;@BRKUd4YgUY0jn=P0BdQg/4ZY1h1:]]
G0BYKEd4YGAT1;2OQ`>PK5X4RVYQ15e7>`AI7184`7iZ1:F1IP>ZQG<4XWMS19a`H@BJKU`4XFiN19Un
KPBHT8l3RGEj1;J_ZR^_XYhEoooo000Doooo>ZnRWPAmJUh4HD8l19AeK`>1Jel4ZhYh1:n9MPB_T7`4
[iF51:n=PPBRJe`3TfUD18=6=`AM3`l4Mc0]1:9^G@BWNFT3[hf01;B7N`BZT7P4ZfeL1:U]G@BUM6@4
/9n70j1/FPB:JV44GDLk15TL4PC0OVX4YH5V0jZ5L`BRMf<4W71Q19Y^G0BQKUh4VGi^19R@S`>9MGX4
]ZnZ:jnRWQGoool001CooolD[j:N0jnQW@B_Yj<K[j:N1:JGUP@/8AX4?BLQ1;:3MP>JM6@4[h]i1:n3
M@B/RW04/h]i1:n6N@BRMel3VfQA1;ZQT`B[S7P4[geb1:YdK0BSKV<3WfIK1:ANE`BLEe<4VEI?19M4
?PBGAT<4UV1C0iaPE@B<ETT4NdTi15XZ8@Am>B`4^Y9h0jn9M0BRNf<4W6eL19M[FPBNMF84WGYW16e>
@0?Th>h4WhnB1;>[YbN_XYhEoooo000Doooo5:nRWP>_XId4[jNS6jnRWPBVUiH4;24J13dW8@BbPgH3
VWAT1:n;N@B_PgD4[8Y`1;>;N@B_QWT4XWMO0i]XD@BjXI<4Zhah1:mmLPBZM6`4XfiS0imVF`BTGUL4
W5MC19UFC`BGA3h4UdI319IPD`>LH5D4S5I917]9>@AJ:R44OCT/1;ZBN0>_RG@4XW]S19a]G0BGJeX4
WWER19ejI`A]CT03i>3^19n?TPBcZjLW[j:N5Oooo`005?oooaB_XYh3[j6M1:nWXa^_XYh4YYNF12`Q
6P@m9b44/X=f0iYdI0B_RgT4[h=e1:b:L0BcRgT4[hIi1:9gG`>KJ544^Z6C1:^<N0B_OG84ZWA/1:=^
H`>OIU/4Y5iG19aGD`BIETl4Ud@n19M6@`BFH5<3W61E18aFB@AkBCT4FRXQ17di;0BjTWP3[hUd1:9k
H`BLKE`4Uf]J19ieHPBMNVL4KDi00nCPkPBOSi84/j^W9jnRWQGoool001CooolD[j:N0jnQW@B_Yj<K
[j:N1:JGUP@/8AX4?BLQ1;:3MP>JM6@4[h]i1:n3M@B/RW04/h]i1:n6N@BRMel3VfQA1;ZQT`B[S7P4
[geb1:YdK0BSKV<3WfIK1:ANE`BLEe<4VEI?19M4?PBGAT<4UV1C0iaPE@B<ETT4NdTi15XZ8@Am>B`4
^Y9h0jn9M0BRNf<4W6eL19M[FPBNMF84WGYW16e>@0?Th>h4WhnB1;>[YbN_XYhEoooo000Doooo5:nR
WP>_WYX4[inK6jnRWPBJQXX4Ac<[10002PAXF5D3/i611:n8M@B_PWP4ZWYc1:^GO0B_PGL4XVYO0iAO
C@BYRGL4/iV?1:nCQ@B_RWd4[i640jnCQ@B_Pg@4Z8I]1:UnK0BRN6<4Xg=O19U[E`>RGED4WUI<18a3
?@Ad=2h4JbhZ18iI@`>]PG@4Yg]T19a]G0BGJeP4WVaN19edHPA@?3D3[YN?1;ba/PB[ViLW[j:N5Ooo
o`005?oooaB_XYh3[ijJ1:nOVa^_XYh4VXJ:14Lc:`@000X4J5QE0k>AP@B_R7D4[h9h1:YjL`B[Ug`4
[h5g1:9ZG`>DGdd4ZHUg1;>IS`B_ThD4[hYm1:nAQ0>_ThD4[h=d1:R6K@BYOV`4XWQS1:=cG`BIJeL3
XUeE19iFC0B<@cd4M3@^16/^:PB>FD<3[H5d1:MkI0BLKE`4Uf]H19i/GPBMM684D3`e0jjGS`Bl/K84
Zi^G9jnRWQGoool001CooolD[j:N0jnNVPB_Wi/K[j:N19Z6RPA7<b/4000:16QHE@>cTH44[hQe1:n2
N0BZNW<4ZiMl1:n1M`BRJUl3U5m=1:V9M`BcVHl4[i>51:n:O@B_TH@3[i>51:n3M0BXQVd4ZGi/1:9h
H`BSLel4VF]G0j9ME@BNET`4S4<m17@d;PA[;RX4SUU30jf1M0BWNf@4W6eL19M[F0BNK5h4WGAR150l
=@>^Uhl4_;6b1:^KUbN_XYhEoooo000Doooo5:nRWP>_WYX4[inK6jnRWPBJQXX4Ac<[10002PAXF5D3
/i611:n8M@B_PWP4ZWYc1:^GO0B_PGL4XVYO0iAOC@BYRGL4/iV?1:nCQ@B_RWd4[i640jnCQ@B_Pg@4
Z8I]1:UnK0BRN6<4Xg=O19U[E`>RGED4WUI<18a3?@Ad=2h4JbhZ18iI@`>]PG@4Yg]T19a]G0BGJeP4
WVaN19edHPA@?3D3[YN?1;ba/PB[ViLW[j:N5Oooo`005?ooocJ_XYh4XHZ71:B=S0BZPg04YG]W0jf<
N@BcSG/4[hYj1:n1MPB_QWP4[hYf1:AjIP>KIUH4XG9P1;JQSPBcUhh4[hn11:n:O@>_ThH4[h5f1:Qc
J0BWMV<4Yh9/19i`GPBGKU`3W6QA19QXEPBHKUH4V6EF19EVEPBKKEh3XGAN1:=fH@BIKET4VVmJ19]b
F`BNLV84?RhY0kbYYPBZVhX[[j:N5Oooo`005?ooocJ_XYh4XHZ71:B=S0BZPg04YG]W0jf<N@BcSG/4
[hYj1:n1MPB_QWP4[hYf1:AjIP>KIUH4XG9P1;JQSPBcUhh4[hn11:n:O@>_ThH4[h5f1:QcJ0BWMV<4
Yh9/19i`GPBGKU`3W6QA19QXEPBHKUH4V6EF19EVEPBKKEh3XGAN1:=fH@BIKET4VVmJ19]bF`BNLV84
?RhY0kbYYPBZVhX[[j:N5Oooo`005?ooocJ_XYh4XHZ71:B=S0BZPg04YG]W0jf<N@BcSG/4[hYj1:n1
MPB_QWP4[hYf1:AjIP>KIUH4XG9P1;JQSPBcUhh4[hn11:n:O@>_ThH4[h5f1:QcJ0BWMV<4Yh9/19i`
GPBGKU`3W6QA19QXEPBHKUH4V6EF19EVEPBKKEh3XGAN1:=fH@BIKET4VVmJ19]bF`BNLV84?RhY0kbY
YPBZVhX[[j:N5Oooo`005?ooocJ_XYh4XHZ71:B=S0BZPg04YG]W0jf<N@BcSG/4[hYj1:n1MPB_QWP4
[hYf1:AjIP>KIUH4XG9P1;JQSPBcUhh4[hn11:n:O@>_ThH4[h5f1:QcJ0BWMV<4Yh9/19i`GPBGKU`3
W6QA19QXEPBHKUH4V6EF19EVEPBKKEh3XGAN1:=fH@BIKET4VVmJ19]bF`BNLV84?RhY0kbYYPBZVhX[
[j:N5Oooo`005?oooc:_XYh4[9nK1;>BO0B/RGT4[Xej1:NGTP>iS6l4Zhin1:n?O`B_Rgl4[hn21:n?
P@BZO6h3XGYR19]UE@BVQ784/9Z=1:nGR@B_QG/3[9^61;>DQ0BVNFL4Yg9Q19iXD`BNOF@4SV9?0hmY
D@BBHE44UFA<18iNCPBBGdX4XWUW0j1gI@BPLf44VVYI19QYF0BHKe/4VW5N12<J6`>iXZ04_[Ro:jnR
WQGoool001Cooolb[j:N1:bOV`BcTW`4[8Ui1:j=NPBWUi83^Ha_1:^>OPB_Sgl4[h]o1:n?PPB_Sh44
ZWa^0j5jHPBKIED4YXAb1;2JS@B_UhT4[hEk0jbKQPBcU8@4YWUW1:MbH@BNJ5<4WWeT18iRC`>?JE44
TV5A19ETC0B>GTh4TUm:1:9iI`>PMfD4X7=Q19YZF@BHJEP4V6mK19YaGP@S6Q/3^J:P1;jh_b^_XYhE
oooo000Doooo<ZnRWPB/Wi/4/i9l1:b9N@B^SGX4YiNB0kV<K`B[SWh4[hmo1:n;O`B_Sh84[hn11:Yl
KP>QNV84VfEE1:J4LPB`VXd4[iN91:n5N`>/VhH4/iB41:IiI`BWLV44WVQC19imI0B>HTl3SfUA199Q
D@BEI4`4SUi>199OBPBRNFL3X7MU1:1cH@BJJUT4V6UH19Q_F`BJLEh48aXK0kVRX0Bn^;l[[j:N5Ooo
o`005?oooc:_XYh4[9nK1;>BO0B/RGT4[Xej1:NGTP>iS6l4Zhin1:n?O`B_Rgl4[hn21:n?P@BZO6h3
XGYR19]UE@BVQ784/9Z=1:nGR@B_QG/3[9^61;>DQ0BVNFL4Yg9Q19iXD`BNOF@4SV9?0hmYD@BBHE44
UFA<18iNCPBBGdX4XWUW0j1gI@BPLf44VVYI19QYF0BHKe/4VW5N12<J6`>iXZ04_[Ro:jnRWQGoool0
01Cooolb[j:N1:ZBQ`B[U8`4YWeW1:=kIPBRRh03YH5k1:nGPPB_ThH<[i>51:n1MP>ZMFX4WViK1:Mb
HPBdW8l4[i>61:n1N0>ZP7<4ZhYf1:AhIPBOLUh4V69B19IWE`B>GD`3TV5>199WD`BHJU@4UVI?199V
D@BJK5T3X6iL1:1aG`BIJeX4U6IF19Q_F`BKLV84:QhK0ee9@PC]i^<4[jNS9jnRWQGoool001Cooolb
[j:N1:ZBQ`B[U8`4YWeW1:=kIPBRRh03YH5k1:nGPPB_ThH<[i>51:n1MP>ZMFX4WViK1:MbHPBdW8l4
[i>61:n1N0>ZP7<4ZhYf1:AhIPBOLUh4V69B19IWE`B>GD`3TV5>199WD`BHJU@4UVI?199VD@BJK5T3
X6iL1:1aG`BIJeX4U6IF19Q_F`BKLV84:QhK0ee9@PC]i^<4[jNS9jnRWQGoool001Cooolb[j:N1:ZB
Q`B[U8`4YWeW1:=kIPBRRh03YH5k1:nGPPB_ThH<[i>51:n1MP>ZMFX4WViK1:MbHPBdW8l4[i>61:n1
N0>ZP7<4ZhYf1:AhIPBOLUh4V69B19IWE`B>GD`3TV5>199WD`BHJU@4UVI?199VD@BJK5T3X6iL1:1a
G`BIJeX4U6IF19Q_F`BKLV84:QhK0ee9@PC]i^<4[jNS9jnRWQGoool001Cooolb[j:N1:ZBQ`B[U8`4
YWeW1:=kIPBRRh03YH5k1:nGPPB_ThH<[i>51:n1MP>ZMFX4WViK1:MbHPBdW8l4[i>61:n1N0>ZP7<4
ZhYf1:AhIPBOLUh4V69B19IWE`B>GD`3TV5>199WD`BHJU@4UVI?199VD@BJK5T3X6iL1:1aG`BIJeX4
U6IF19Q_F`BKLV84:QhK0ee9@PC]i^<4[jNS9jnRWQGoool001Cooolb[j:N1:n:M@B/Rg`4W6UD1:j?
O`BTN6`3ZhYh1:n4OPB_ThH4[iF91:n>OPB_ThD4[hek0jn6L0BRLEd4Xg9M1:j9O@BcUH/4[i600jn?
QPB_RWd4Z7i_1:1_H0BPLf44VVmM19MSD`>AGdT4SUa@19Q/F`BQKV04XW=P19mcH@>LLV44WF]J19Y/
FPBJJeX4V6aI19YdH0A?>C03=2HT161AB`CnoolW[j:N5Oooo`005?oooc:_XYh4[hYe1:b;O0BLJE@4
[Xmo1:AhK0>[RWP4[hAn1:nCQPB_UHT4[hin1:nCQ@B_SG/3[hI`1:9aG@BSLUd4[XUm1;>ER`B_TH03
[hn61:n:O@BXOVl4X6mP1:1cH@BJKed4Uf=C0i5OB@B>G504V6aK1:5^H0BRLf04Wg=Q0iabH@BMJeX4
VVaJ19Y[FPBHK5T4VWAP14li<0<d9R@4H55;1?koobN_XYhEoooo000Doooo<ZnRWPB_RWD4[8]l19aY
E0B^Sgl4Y7Q/0j^:N0B_Q7h4[i>61:nER@B_SWh4[i>51:n=N`>_QW04XW5M1:=bG@B^RGd4/iF;1:nA
P0>_ShH4[hYm1:QnK`BPKf04X7=Q19Y_G@BGHe<3TEm918iLD0BHK5/4XFiP1:9cH0BOLf43W79Q19e[
FPBJK5X4VV]J19Q/F@BJM604CcT`0c@V90APDD/4o_oo9jnRWQGoool001Coool^[j:N1:nJT@BZQg@4
YfiM19f0IPBPQG<4_HIh0jn4N0B_SH44[i>61:nGS@B_UX/4[i>51:n=P0>/RgP4Z7i/1:9gI0BXPFd4
ZhYl1:b6N@>cWHT4[hV21:J7K0BOKel4VVmL19M[F@BKKUD3SUm>19aUD0BKL5l4XG5S1:YlK@BRN6H3
W7IT19ecH@BILEl4U6mJ19Y[G0BJOV/4Sf5=0fa8>PA2:BL4LUM@9jnRWQGoool001Coool^[j:N1:nJ
T@BZQg@4YfiM19f0IPBPQG<4_HIh0jn4N0B_SH44[i>61:nGS@B_UX/4[i>51:n=P0>/RgP4Z7i/1:9g
I0BXPFd4ZhYl1:b6N@>cWHT4[hV21:J7K0BOKel4VVmL19M[F@BKKUD3SUm>19aUD0BKL5l4XG5S1:Yl
K@BRN6H3W7IT19ecH@BILEl4U6mJ19Y[G0BJOV/4Sf5=0fa8>PA2:BL4LUM@9jnRWQGoool001Coool^
[j:N1:nJT@BZQg@4YfiM19f0IPBPQG<4_HIh0jn4N0B_SH44[i>61:nGS@B_UX/4[i>51:n=P0>/RgP4
Z7i/1:9gI0BXPFd4ZhYl1:b6N@>cWHT4[hV21:J7K0BOKel4VVmL19M[F@BKKUD3SUm>19aUD0BKL5l4
XG5S1:YlK@BRN6H3W7IT19ecH@BILEl4U6mJ19Y[G0BJOV/4Sf5=0fa8>PA2:BL4LUM@9jnRWQGoool0
01Coool^[j:N1:nJT@BZQg@4YfiM19f0IPBPQG<4_HIh0jn4N0B_SH44[i>61:nGS@B_UX/4[i>51:n=
P0>/RgP4Z7i/1:9gI0BXPFd4ZhYl1:b6N@>cWHT4[hV21:J7K0BOKel4VVmL19M[F@BKKUD3SUm>19aU
D0BKL5l4XG5S1:YlK@BRN6H3W7IT19ecH@BILEl4U6mJ19Y[G0BJOV/4Sf5=0fa8>PA2:BL4LUM@9jnR
WQGoool001Coool^[j:N1:n3M`BRKE/4UUA719Q/F`BOQWL4YH]n0jn?N`B_RWX4[i>62:nCQ@B_TH<4
[i600jR8N0B[Pg04YHUg1;2>OPB_Sg/4ZWe^0j^4M0B_OVl4XWAU19UWE@BGIUD4TV=A19IVC`>AHdl4
TFAE19Y/G0BPN6L4ZW]Z1:9hIP>LLf44WFiL19e[G@BIKeX4V6]F1:5kK0BDHDX3VfmP1;F_[PBZWYXW
[j:N5Oooo`005?ooobj_XYh4[h=g1:9]F`BFE4L4V6aK19n6M`BURgh3[hmk1:n:NPB_ThH8[i>51:nA
P`B_TH03Z8Qh1:^3L0BURGL4/8in1:n?N`BZOFh3ZhAd1:mnK`BRM6D4VFME19MVE@BBHe44UVI?0i5S
C`BAI5D4VVaL1:1hI`BZNfX4XWQV0iacH@BMKU`4WF]M19U_FPBHJeH4XG]/19AQBP>KKf04]Jn^1:ZN
VRN_XYhEoooo000Doooo;ZnRWPB_PgL4XVeK19IDA`BHK5/4WhIg1:F;OP>_Sg/4[hYj1:nCQPR_ThD4
[i631:nAP0>XR7P4Zh=`1:F9M`B`SWh4[hmk1:YmKP>[Q7@4[gi_1:9dI@BIIeD4UfIE199SD@BFITl3
TF=?195TE@BJK5`4X7QW1:YkJPBRN6H3W7=Q19e^G0BMJed4VFmJ19Q[EPBQNf`4U65:0i]_H0Be[jh4
ZYjJ9jnRWQGoool001Coool^[j:N1:n3M`BRKE/4UUA719Q/F`BOQWL4YH]n0jn?N`B_RWX4[i>62:nC
Q@B_TH<4[i600jR8N0B[Pg04YHUg1;2>OPB_Sg/4ZWe^0j^4M0B_OVl4XWAU19UWE@BGIUD4TV=A19IV
C`>AHdl4TFAE19Y/G0BPN6L4ZW]Z1:9hIP>LLf44WFiL19e[G@BIKeX4V6]F1:5kK0BDHDX3VfmP1;F_
[PBZWYXW[j:N5Oooo`005?ooob^_XYh3[ibD1:n8P@BRH5P4Te=619i^HPBZRgT4ZhYn0jnCQPB_Sh44
[hf01:nDQ`B/TX44/iB81:n6N`>XTGH4[H=a1:b;M`B`TXH4[i611:nAQ`>_SH04[gma1:9eG@BFKE/4
TF=B18iQD0B9HU83UVAB19]_H@BTNFL4YWi]1:=kJ@BWNFH3W7IT19e[F@BMJe`4VVUL19Y/FPBNMfl4
UF5>0i5WE@B[WId4a<6m9jnRWQGoool001Coool[[j:N0jnLU0B_R844XV1H19=CAPBNKV84ZX]i1:^:
OP>_ThH4[hn11:n=P0B_U8L4[9:11;>DR0B_QW/3Z95f1:f3L@B/RgL4/9:61:nAP@B_THL3[hf01:mo
L@BRMEd4UVeK195SDPB>HE04RF9B0iITDPBKKf44Y7UW1:InK@BSNfT4YgUV0iafI0BMJeT4WF]L19YY
G0BJK5X4WWM_19EQCP>AIeD4ZifM1<C1_BN_XYhEoooo000Doooo:jnRWP>_W9@4[hR11:9PF0BCDdH4
WViR1:Z;N@B[RWh3[i>61:n?P@B_SH04[iB71:bBP@BcU8P4[hIk0jRAMPB]Pg44[8]g1;2BQPB_TH44
[i670jn=P0B_Og44XWEM19I]F`BAHe84SV5@18URDP>FI584VfmQ1:AiI`BVOVd4Xg]Y1:MiIP>LMV@4
WF]I19e[G0BJJE`4VVaJ19igK`BEHDh3TFME1:^MW@C4`KdW[j:N5Oooo`005?ooob^_XYh3[ibD1:n8
P@BRH5P4Te=619i^HPBZRgT4ZhYn0jnCQPB_Sh44[hf01:nDQ`B/TX44/iB81:n6N`>XTGH4[H=a1:b;
M`B`TXH4[i611:nAQ`>_SH04[gma1:9eG@BFKE/4TF=B18iQD0B9HU83UVAB19]_H@BTNFL4YWi]1:=k
J@BWNFH3W7IT19e[F@BMJe`4VVUL19Y/FPBNMfl4UF5>0i5WE@B[WId4a<6m9jnRWQGoool001Coool[
[j:N0jZ4KPBWNfT4Sf==1:=VD@B^Pfh4[HYh1:n=P@>_TH@4[iB71:nAP0B_Rgl4Z8]k1:f7M`B^QWH3
/89g1:V6L0BYOVh4/8]m1:n=P0B_SGd3[hf01:b0M0BVJ5d4UVEE195SDPBBI5<4TFYI0i9_F`BQM6<4
X7UU1:MlJPBWOV`4Xg9Q0ia`G`BMKEd8VVIF19Q/F`BNOV`4UeHo0j65M@BDJUh4/lWC9jnRWQGoool0
01Coool[[j:N0jZ4KPBWNfT4Sf==1:=VD@B^Pfh4[HYh1:n=P@>_TH@4[iB71:nAP0B_Rgl4Z8]k1:f7
M`B^QWH3/89g1:V6L0BYOVh4/8]m1:n=P0B_SGd3[hf01:b0M0BVJ5d4UVEE195SDPBBI5<4TFYI0i9_
F`BQM6<4X7UU1:MlJPBWOV`4Xg9Q0ia`G`BMKEd8VVIF19Q/F`BNOV`4UeHo0j65M@BDJUh4/lWC9jnR
WQGoool001Coool[[j:N0jZ4KPBWNfT4Sf==1:=VD@B^Pfh4[HYh1:n=P@>_TH@4[iB71:nAP0B_Rgl4
Z8]k1:f7M`B^QWH3/89g1:V6L0BYOVh4/8]m1:n=P0B_SGd3[hf01:b0M0BVJ5d4UVEE195SDPBBI5<4
TFYI0i9_F`BQM6<4X7UU1:MlJPBWOV`4Xg9Q0ia`G`BMKEd8VVIF19Q/F`BNOV`4UeHo0j65M@BDJUh4
/lWC9jnRWQGoool001Coool[[j:N0jZ4KPBWNfT4Sf==1:=VD@B^Pfh4[HYh1:n=P@>_TH@4[iB71:nA
P0B_Rgl4Z8]k1:f7M`B^QWH3/89g1:V6L0BYOVh4/8]m1:n=P0B_SGd3[hf01:b0M0BVJ5d4UVEE195S
DPBBI5<4TFYI0i9_F`BQM6<4X7UU1:MlJPBWOV`4Xg9Q0ia`G`BMKEd8VVIF19Q/F`BNOV`4UeHo0j65
M@BDJUh4/lWC9jnRWQGoool001Coool[[j:N0imXC`AU?2P4P51116Do=PC:VGh4/I201:n=O@>_SGh4
[hf21:n=P0B_RWH4ZXMc1:MnK`BQLf@3XgUY1:N5L@BbUH04[I1l1;>AQ@B_SH03[hen1:R3MPBPMEl4
UfAI19EYC`B?HE44W6aK0iYbH0BOKf04YGYY1:QiJPBPNF@4YGm/0iicH@BNM644VW5O19QXF0BHJEh4
VgEU195I@`>MJEH4WVIJ1;>_ZRN_XYhEoooo000Doooo:jnRWP>OJ4l4IC`X181@@@AU?cH4bYUn1;6@
P0B_SGd3[hen1:n=PPB_SH04[hYf1:Z7L`BWOVl4XG=T0j=iJ@BWQG44/YF01:f@O0BcTHD4[hf00jn=
OPBXPgH4X7EO19MTF@BEJDl4Sf5A19a/F`>JLV04WfmP1:EjJ@BXNFX4X7UT1:EoK0>NLf44WWAQ19Ya
G`BHJ5P4V6UN19]eI@BAFD<3WFUF19iVFPBc[jXW[j:N5Oooo`005?ooob^_XYh3WfQ?16Dl:0B0D444
IClf1<ZIOPBaT804[hem0jn=OPB_SH84[hf01:n:MPBZQg<4Ygi_1:5cI0>SNFT4YhEa1;:EP0B]T7`4
/i651:n=P0>_SGh4Z8=f1:1eG`BGI5T4UFU?18mQD@BLK5/3VW9P19m_H0BUNVT4Z7UZ1:1iI0BUOf`3
WW=Q19idH@BJLEl4V6QH19QYGPBKMFD4TEU30ieYEPBNIUX4/jnZ9jnRWQGoool001CooolW[j:N1:nO
V@>MJUX4GcX[14P`9`AG=c84/HQe1;6@P@B/Rgl3/i641:n=M`BVPg<4/Y611:N0KPBbRgP4[X=f0jac
J@BXOFH4YGeY1:nBOPBdUhT4[hf00jn=O0BXNf`4VfeK191PD@BBGdh4S6AC19ITD`>ILV04Wg5N1:Ie
HPBUNFX4WV]L1:5dHP>IL5l4U6aJ19Q_G@BHJ5P4V6UN19Q_G@AmBcL3SD`d1:Q_EPBg];/W[j:N5Ooo
o`005?ooobN_XYh4[inI0ieZFPAO>R/4B30W15Lg<PBaR7D4/I211:b;O`>cTH@4[heg1:J3L`BbTH44
Yh1^1;:;N0B^PgH3[7=Y1:QmIPBUOFT4[i9n1;BGR@B_SH03[hel1:QkK0BKKE/4T61A199OCPB<I5<4
UVAC0iUbH0BOLEh4YWER1:EiJPBNJe`4XGAR0iU`G`BDK5X4V6mM19QXF0BHJEh4V6mM17e;=`>=C3@4
Z6mF1;Nd^bN_XYhEoooo000Doooo9jnRWPB_WiT3WFYJ15lj:`A8<2L4EcLb1;68M@BaT844[8]o0k>A
Q0B_SGL4YX=c1;:AP@BWP6h4/X]h1:j3MP>/LfT4Z7eV1:EmJ@B_TWh4]9N91:n=P0>_SG`4Z7]/19]]
F`B@H544TUm>18aTD`BFI5<3VG9P19maGPBVMF84YGUZ19i[G0BQM683VG1O19A/FPBHKed4V6QH19QY
GPBHKed4OD/g0he<=0BXKeH4]kBk9jnRWQGoool001CooolW[j:N1:nOV@>MJUX4GcX[14P`9`AG=c84
/HQe1;6@P@B/Rgl3/i641:n=M`BVPg<4/Y611:N0KPBbRgP4[X=f0jacJ@BXOFH4YGeY1:nBOPBdUhT4
[hf00jn=O0BXNf`4VfeK191PD@BBGdh4S6AC19ITD`>ILV04Wg5N1:IeHPBUNFX4WV]L1:5dHP>IL5l4
U6aJ19Q_G@BHJ5P4V6UN19Q_G@AmBcL3SD`d1:Q_EPBg];/W[j:N5Oooo`005?ooobN_XYh4[8en0jIl
L`@k6A<4A2XR14T`:PC5Tgh4ZXYg1:n;N@>[SWl4[hen19mjJ@B=JUT4RF=@16iAA`AXAcd3S50j1:a_
G0BIE3l4Wem71<bhXPBcUH/3[hf01:QnK`BKJE/4T6=<18mTC0B;FD/4VW1N0i1XF@B9J5P4T6UI19Qa
HPBDLeh4YWQU0iedHPBGKU`4TV]J19U[FPBOK5h4V6aM17A5=P=f?2d4Te=01;Bj]RN_XYhEoooo000D
oooo9jnRWPB/SGh3YWac13/I4`A4:R84BC0Z1<FCOPBZRWL4[h]i0j^>O`B_SGh4WgYY18eZF@B9He04
KU5716Q7?@><D3X4[6mL19UD?`BOGdL4c;RR1;>ER`>_SH04Z7i_19]YF`B@Hd`4SfA<18]IB`BJL5h3
T6QI18UXF0B@JET4V75R19AcGPBVN6D3WGAR19M^G0BBJeX4VF]J19m/GPBHK5d4M4Df0gHl;@BCDd04
];Zf9jnRWQGoool001CooolW[j:N1:b=OP>VO7<4>aTC14@Z8PA9<2X4aI=n1:Z:M`B_RgT3Zhio1:n=
OPBONVT4SFYI18USD0A^DDL4J4Lm0ha@>PB/Ke`4VE@o19mOA`C<^:84/iF;0jn=P0BXOVl4VfUK191S
C0B?I4`4ReU;19Y`GP>@J5T4RFQH191YF@BHLF84U7=N1:IhI@>MM684UfiL199[FPBIJeX4WfaN19Q/
G@AdACH3MS`]19=C@0Bd^[HW[j:N5Oooo`005?ooobN_XYh4[8en0jIlL`@k6A<4A2XR14T`:PC5Tgh4
ZXYg1:n;N@>[SWl4[hen19mjJ@B=JUT4RF=@16iAA`AXAcd3S50j1:a_G0BIE3l4Wem71<bhXPBcUH/3
[hf01:QnK`BKJE/4T6=<18mTC0B;FD/4VW1N0i1XF@B9J5P4T6UI19QaHPBDLeh4YWQU0iedHPBGKU`4
TV]J19U[FPBOK5h4V6aM17A5=P=f?2d4Te=01;Bj]RN_XYhEoooo000Doooo8jnRWPBaY9l4YW]W0ia/
G@A2;2T4:A`H144V8PBhV884ZhMf1:V5L`>cSW`4[hek1:Z6MPB<IE84Of5E14Hg;P@k9b<3DS0T171A
A@BDCS/4Qdm319Q^G`B`SH43[hf21:QlI`BKJEP4RUa918mUB@AW:A/4/HAZ0ia_D`BFKE`4SUi91:ei
IPBBK5d4WG9M0iidI0BJLEl4RfED18a/F`BIK5h4TV]F1793=`>4BSP4V5E91;:VX@BZWYXS[j:N5Ooo
o`005?ooob>_XYh4/JBO1:IkI`>LK5d4@R`Y12TL60A19R84^9R21:^7MPBYQG<3/hil1:n=N`BZQWH4
S6EB17mQE@A6=bh4>bLS0e8`90A`DDD4U4hk18M?@`BHKUl4/8f10jn=PPBXO6L4VfUH18YLB@B?IDT4
IbTK1;64JP>LKe<4UVeL18iNB@B]NFH4TVaM19ebG@>NM6@4VW5O18]UE0B<K5/4VFaN199[EPAb@cL3
Q4Xh19QEB@BbYZ44ZYjJ8jnRWQGoool001CooolS[j:N1;6TW`BVNfL3W6aM148/:@@Y71P4@BHR1;RH
PPB[QgH4ZHEc0k>>O0B_SG/4ZXIf18aUDPAoHED4ASL^13/W8`=B<2@4L55519A>>`B7Cd<4V6iO1;2=
P@>_SH84Z7aW19]YF0B:G4T4SfE916LY6`BaQ6X3W6mC19I]G0B>GTT4[GUV199/G@BMLUd3WWAT19Ya
G`B;IE@4S6aK19U/GPBBJeH4LT<g0hA:>0BHEDT4/ZJQ1:ZNVR>_XYhEoooo000Doooo8jnRWPBaY9l4
YW]W0ia/G@A2;2T4:A`H144V8PBhV884ZhMf1:V5L`>cSW`4[hek1:Z6MPB<IE84Of5E14Hg;P@k9b<3
DS0T171AA@BDCS/4Qdm319Q^G`B`SH43[hf21:QlI`BKJEP4RUa918mUB@AW:A/4/HAZ0ia_D`BFKE`4
SUi91:eiIPBBK5d4WG9M0iidI0BJLEl4RfED18a/F`BIK5h4TV]F1793=`>4BSP4V5E91;:VX@BZWYXS
[j:N5Oooo`005?ooo`B_YJ44[jNS1:nQW@B_Yj<C[j:N15<X80CoaZP3YGYY15@d;@@[8RH4=20K1<RL
QPB]S7T4[hek0jV8MPB`Sg`4/i6519mhI`BPKf84LUM>13d`<0<e9R@4Cchh17=EC0BDHUH4YXMd1;2H
S0>_Uhd4Z8Qf19]^G@B9FdL4OeM716Li;@AcCTL3L4hn12LE50B<DSl4MeY916I1<@BQLE`3V6I81:]e
G@B>KUl4S6MF19UYF`B1GDd4G3P]0g=1=@BcLf44]JNZ1:jQWB>_XYhEoooo000Doooo1:nUX@B_Yj<4
[j6M1:nWXa>_XYh4DbPP1?o6Z0>UNVT4E3@]12/R9P@d81/4b9b61:f<N@B_SG/3ZHQf1;2?O0BcTHD4
WgQW1:1_HPAbEdh4?C0`0cDV90A??SP4LeE<19AREPBVQg@4/9R<0jnGS@BXR7H4VfiM18UKA`AoEdL4
IcT]17=>A`=`CSh49aDD18aB?`AgFTT4IT4a1:5aG0>HITP4ZgEM18i^G`B<IeH4VFUK185MC@AL>2d3
Ld4e1;=cH@BeYjX4[Z6M8jnRWQGoool001Coool4[jFQ1:nWX`B_XId4[jNS4jnRWPAC:204olJX0jEj
J@AD=2d4:b8V13@P6`C8W8H4[Hai1:n=N`>YR7H4/8ml1;>AQ@BON6L4X6mR179GCP@m<303=BHT14ln
>0AcED`4U69F1:J7M0B`V8`3[iN=1:R8MPBKKUd4RE]717mGA`AW>Bd4Ldi70g1>?P@W5A@4S58o17MJ
B@AV@C44XG5L0iQVB0B[MEd4SViO18aWEPBIJE/4PEe=15`h;@=c@CD4/g=Q1;FWZPB^XIdS[j:N5Ooo
o`005?ooo`B_YJ44[jNS1:nQW@B_Yj<C[j:N15<X80CoaZP3YGYY15@d;@@[8RH4=20K1<RLQPB]S7T4
[hek0jV8MPB`Sg`4/i6519mhI`BPKf84LUM>13d`<0<e9R@4Cchh17=EC0BDHUH4YXMd1;2HS0>_Uhd4
Z8Qf19]^G@B9FdL4OeM716Li;@AcCTL3L4hn12LE50B<DSl4MeY916I1<@BQLE`3V6I81:]eG@B>KUl4
S6MF19UYF`B1GDd4G3P]0g=1=@BcLf44]JNZ1:jQWB>_XYhEoooo000Doooo1:nMV@B_Xil4[ijJ1:nO
V`n_XYh4FCL_154e;PA?5@l3XFE?14@[<0@b9Al4>bDR1;JEP0BYR7H4/8in0j=fI0B/TGP4^IjA1:Z;
NPBSMf@4UFIE18iVD`>:I584PEI418mYD`BOLV<4YWm]1;2ER@>_ThD4Z7i^19]dH0B@FdH4R5m:185=
@@AfFe@3FTQ211TF60A>;B84GT<l14@c:`AgCSd3OeQ718iSC@B;Gdl4RFaK19U/F0AK>S@4E3PZ0e/c
:0BYHTd4_lg<1;:VXR>_XYhEoooo000Doooo1:nMV@B_Xil4[ijJ1:nOV`n_XYh4FCL_154e;PA?5@l3
XFE?14@[<0@b9Al4>bDR1;JEP0BYR7H4/8in0j=fI0B/TGP4^IjA1:Z;NPBSMf@4UFIE18iVD`>:I584
PEI418mYD`BOLV<4YWm]1;2ER@>_ThD4Z7i^19]dH0B@FdH4R5m:185=@@AfFe@3FTQ211TF60A>;B84
GT<l14@c:`AgCSd3OeQ718iSC@B;Gdl4RFaK19U/F0AK>S@4E3PZ0e/c:0BYHTd4_lg<1;:VXR>_XYhE
oooo000Doooo1:nMV@B_Xil4[ijJ1:nOV`n_XYh4FCL_154e;PA?5@l3XFE?14@[<0@b9Al4>bDR1;JE
P0BYR7H4/8in0j=fI0B/TGP4^IjA1:Z;NPBSMf@4UFIE18iVD`>:I584PEI418mYD`BOLV<4YWm]1;2E
R@>_ThD4Z7i^19]dH0B@FdH4R5m:185=@@AfFe@3FTQ211TF60A>;B84GT<l14@c:`AgCSd3OeQ718iS
C@B;Gdl4RFaK19U/F0AK>S@4E3PZ0e/c:0BYHTd4_lg<1;:VXR>_XYhEoooo000Doooo1:nMV@B_Xil4
[ijJ1:nOV`n_XYh4FCL_154e;PA?5@l3XFE?14@[<0@b9Al4>bDR1;JEP0BYR7H4/8in0j=fI0B/TGP4
^IjA1:Z;NPBSMf@4UFIE18iVD`>:I584PEI418mYD`BOLV<4YWm]1;2ER@>_ThD4Z7i^19]dH0B@FdH4
R5m:185=@@AfFe@3FTQ211TF60A>;B84GT<l14@c:`AgCSd3OeQ718iSC@B;Gdl4RFaK19U/F0AK>S@4
E3PZ0e/c:0BYHTd4_lg<1;:VXR>_XYhEoooo000Doooo1:nJUPB_Wi/G[j:N13XQ70A4;RD4>b0M0d8[
9@@T5aP4?2LR13`U80BhUH04Zhai1:V<O@>UMFh4TF1A19]]F`BfTgh4Z8Qd19Y`HPB?FDP3UV=:1:1V
C`BRIdh4`9Z21;::N0B`Sh<3[iB41:QnLPBKN6P4T65>18iSB0B<JDh4W6]J0i1UF0A5=SD4:R8T14Lb
;@A;?3D4Hda20g]F@`B9IEL4VfaE18eVF@B<JEH4B2lU140X8`=H<bH4U4Dd1;g0_bN_XYhEoooo000D
oooo1:nJUPB_Wi/G[j:N13XQ70A4;RD4>b0M0d8[9@@T5aP4?2LR13`U80BhUH04Zhai1:V<O@>UMFh4
TF1A19]]F`BfTgh4Z8Qd19Y`HPB?FDP3UV=:1:1VC`BRIdh4`9Z21;::N0B`Sh<3[iB41:QnLPBKN6P4
T65>18iSB0B<JDh4W6]J0i1UF0A5=SD4:R8T14Lb;@A;?3D4Hda20g]F@`B9IEL4VfaE18eVF@B<JEH4
B2lU140X8`=H<bH4U4Dd1;g0_bN_XYhEoooo000Doooo1:nJUPB_Wi/G[j:N13XQ70A4;RD4>b0M0d8[
9@@T5aP4?2LR13`U80BhUH04Zhai1:V<O@>UMFh4TF1A19]]F`BfTgh4Z8Qd19Y`HPB?FDP3UV=:1:1V
C`BRIdh4`9Z21;::N0B`Sh<3[iB41:QnLPBKN6P4T65>18iSB0B<JDh4W6]J0i1UF0A5=SD4:R8T14Lb
;@A;?3D4Hda20g]F@`B9IEL4VfaE18eVF@B<JEH4B2lU140X8`=H<bH4U4Dd1;g0_bN_XYhEoooo000D
oooo7jnRWP@n91`4<adH134T7P<g8Qh4;b0L12/P70A<<bh4/85]1;VAOPBZRWP3ZhYn1:5mKPB4FDT4
O4i317ILC`B4G4`4Gd@i0fA7?@A/AST4P5A718m/G@BTPG84ZhYj0jn6N0BXRG04VgAS191OE0AlB3<4
RUDl1:F3G`>OLV04V6mL199XFPAkEdL4Lda218eMC0>?I544V6UG18a/EPBOLU/4PEm?12hS7@@a8ad3
Oe1316La9`Bo]KDW[j:N5Oooo`005?oooan_XYh4?R@L13<M60@a91h3=b8N12lP70@[81`4C3<^1;21
K@BiTGh4ZXYh0j^:OPBQOFh4Q5U917a>@`AfG4l4Q5a<15m4>@=TAcd4K4Hi181DA`B?K5d4Y85b1:^:
NP>_QWP4Z8U`19]dH`B@Ge@4O4Pc18YE?0BUPel3Wg9P19Q_G0BBJ5X4NeM717=<@PB=GD`3SfAA19QY
E`B<K5H4Wg9K185OC`@^8ad4<B<M0gm@@`AW<BL4_kFe9jnRWQGoool001CooolO[j:N13hT70@c7AP4
<B@N0cLR7P@_81`4:b0L14`c;PB`PFd4^I5n1:Z:N0>[RWh4XGe^18AIB@AlCT<4MUa?18ALC0AOA3T3
I4Lm16a6>@B0E4L4SfaM1:B1LPB[RWX3[hIh1:R9L0BKM6<4T5mD17a8<`B:EC`4YH=O0imbH0BHKe`4
TVQJ17]GA`AcC484SEe<0hmTD@BHJEL4S6aF19mbF`B1Gdl4;R<M134S7@=oD4<4Ic4W1;ne]BN_XYhE
oooo000Doooo7jnRWP@n91`4<adH134T7P<g8Qh4;b0L12/P70A<<bh4/85]1;VAOPBZRWP3ZhYn1:5m
KPB4FDT4O4i317ILC`B4G4`4Gd@i0fA7?@A/AST4P5A718m/G@BTPG84ZhYj0jn6N0BXRG04VgAS191O
E0AlB3<4RUDl1:F3G`>OLV04V6mL199XFPAkEdL4Lda218eMC0>?I544V6UG18a/EPBOLU/4PEm?12hS
7@@a8ad3Oe1316La9`Bo]KDW[j:N5Oooo`005?ooo`R_XYh4[j6M1:nWX`n_XYh4Ab`S134J5@@^8A`3
:R0L11`A4P@d8ad4B3Ha1:5hI0BlU7l4/i9o0jn=P@B_Sh84ZXMg19Y[GPAiCd/4OU5<18M?@`>0CCh4
NdPi18UCA0BNMVH4/9241:b8N0>`Pg/4[7e`19iiJ0BCIUd4LT8l15T`:PAW@S03KDPd1;QiG0B[OVP4
VVmH191[F0B<JEP3UFQE18UUEPBOKf84TVaF15/m;`@d91h4=bdX0hE??@An?bh4K5YC1?[ooR>_XYhE
oooo000Doooo2:nRWPB_XId4[jNS3jnRWPA7;2<4<AXE12hQ70<Z81`4714B13@S7@A8=S44XGQT1;bD
O`BcTWl3[hf11:n?PPBZQgL4VV]N17U?B`AnDD`4Qdm30h1=?PAkB3T4RE=419ifIPB`T8@4[8Qh0k23
N`B/OG04WWUX19=VG@Ab@S`4FC0Z16M2<0=]B3@4^7UL1:]nJ0BJKeP4T6]H18aYF0>EJ5D4RFEF19m_
HPBBK5H4Fcd_13@T7P@g;BP3QDlm17ho;PA/FU<4n_on8jnRWQGoool001Coool8[j:N1:nQW@B_Yj<?
[j:N14L/8`@a6QD4;R4L0bXP70@L4A84=2<M14Pf<@BQN6@4_9Ao1;>BO`>_SH44[hn21:Z7M`BJJeh4
NDm;17iAC0B7Cd<3P4dn17]8>@B9Dd@4WWIV1;2@Q0B/R7P3/8=k1:amL0BNNFP4TfIM1792?0AI<2X4
Id8`0fe8=0BhNE`4ZgiX19Y_F0B@JeP4S6UH0iEXE@B9IEH4WfmR199/EPAK?Bl4=2@N13L]:0>5Ccd4
OSl^16aJD`CjoohS[j:N5Oooo`005?ooo`R_XYh4[j6M1:nWX`n_XYh4Ab`S134J5@@^8A`3:R0L11`A
4P@d8ad4B3Ha1:5hI0BlU7l4/i9o0jn=P@B_Sh84ZXMg19Y[GPAiCd/4OU5<18M?@`>0CCh4NdPi18UC
A0BNMVH4/9241:b8N0>`Pg/4[7e`19iiJ0BCIUd4LT8l15T`:PAW@S03KDPd1;QiG0B[OVP4VVmH191[
F0B<JEP3UFQE18UUEPBOKf84TVaF15/m;`@d91h4=bdX0hE??@An?bh4K5YC1?[ooR>_XYhEoooo000D
oooo2:nRWPB_WYX4[inK3jnRWPA3;bT4?2LR12lN6P<_81`48QXF12lO70A9=S44UVaI1:j;N0B`Sg`3
[hf11:nCQPB_ThD4[iF92:n@P@B_SWh3[iF91:n>OPB_Sgd4ZXI`1:^>O`BZSGd3YH=`1:V3L@BUPg44
XWa/19U`HPA^Bd<4CS4]0ch_:0AF=BX4JT@c19QOB`B6Ie44UF590h]MB0BPLV<4S6AD19EVEP@m9R44
=28M13PW9`==8QX4NC0Q15Q5?PBl/ZlS[j:N5Oooo`005?ooo`R_XYh4[ijJ1:nOV`n_XYh4@blY13`W
8P@_7QX3;b0L128J5P@_7a`4BCHa19I/F@B^RgP4/8ml0jn=P@B_ThH4[i>51:nER@R_T844[hin0jnE
R@B_SWh4[hmm1:Z6L0B[SWl4ZXem0jF3L0BYPg44YH=a1:9lK0BIL684KT]314ha;@<n;bP4ESDZ16Y4
<`BHGd/4QVMA19EQB@>;GDP4X79S18aTE0BEIUH4?BHQ13@R7@@h9bL3CB8J17T`8@AHACh4_;:_8jnR
WQGoool001Coool8[j:N1:nNVPB_Wi/?[j:N14<_:@@l9b84;ahJ0blP70@R6QH4;alL14Tf<@BFK5T4
[X]h1;2?O0>_SH44[i>61:nCQ@B_UHT8[i211:n>OP>_UHT4[hin1:n?O@BZQW04Zhio1:Z=O@>UPg04
ZH=a1:F3L@BRO6`4VG1R16i;@`A><Bd3?RlX15He:PAZA3<4V5m;18IWD@BEHDT3Ree81:1bH`B<I5@4
UFIF13dV8@@d8Qd4>2LW0ddR6PAi<244F4Dn1;bb[b>_XYhEoooo000Doooo2:nRWPB_WYX4[inK3jnR
WPA3;bT4?2LR12lN6P<_81`48QXF12lO70A9=S44UVaI1:j;N0B`Sg`3[hf11:nCQPB_ThD4[iF92:n@
P@B_SWh3[iF91:n>OPB_Sgd4ZXI`1:^>O`BZSGd3YH=`1:V3L@BUPg44XWa/19U`HPA^Bd<4CS4]0ch_
:0AF=BX4JT@c19QOB`B6Ie44UF590h]MB0BPLV<4S6AD19EVEP@m9R44=28M13PW9`==8QX4NC0Q15Q5
?PBl/ZlS[j:N5Oooo`005?oooan_XYh4Ac8]14Ld<0@V7QX3<R0L12hP6`@c92<4AcD_18]RC`BdRGD4
^IN40jn=O`B_THP4[iN91:nGS@B_WIL4[iR?1:nCQ`>_UHT4[i:41:nCQ@B_Sgd4[hYd1:n=N`>XPW04
ZGm^1:UnK0BYQg@4ZGea19ijK0BEJf03NE=;15@m>0A6<Rd4ECP`16=8?0AcE4L3KE1318QGC`BEKeX4
SV1?13/T80@`81`4;24M0bTL5`A99R04G44j1;ne/b>_XYhEoooo000Doooo7jnRWPA7<Rd4Ac@`12HN
6P<b81`4;R0K13<T8`A7=Bl4Rf9?1;B9M@BiUh@3[heo1:nAR0B_UhT4[iN=1:nMU`B_V8l4[i>70jnE
R@B_TX@4[i>51:n?O@B_RW@4[hek0jR2L0BYOfh4ZGi/1:V7M0BYOG44WWY/19E[H0=iDd/4E3dh14Hb
;@AE>304HdPl17=DA`=]D4<4R5M?19E_FPB>H4l4>b@P130P70@/8Ad3:A`G14TV80AL@CX4_kFc8jnR
WQGoool001CooolO[j:N14Lb;@A7=3049QhJ0c8P70@^81/4<b@S14Le;`B;HTl4]8Ue1;VGQ0>_SGl4
[i681:nGR@B_Uhd4[ifG1:nHS`B_ThL3[iF91:nBQ0B_ThD4[hmm1:n:M0B_SG/3Z89`1:UoKPBYOV`4
ZHMd1:UmL@BNNV`4UF]P0gUCB`AD?CP4AS8]15Dh<0ASB3`4LeA70fe@@`B8Edl4UFmJ18iPC`@k9204
<20L12`Q7@<Y71L4BBHP15a1>PBo]K<S[j:N5Oooo`005?oooan_XYh4Ac8]14Ld<0@V7QX3<R0L12hP
6`@c92<4AcD_18]RC`BdRGD4^IN40jn=O`B_THP4[iN91:nGS@B_WIL4[iR?1:nCQ`>_UHT4[i:41:nC
Q@B_Sgd4[hYd1:n=N`>XPW04ZGm^1:UnK0BYQg@4ZGea19ijK0BEJf03NE=;15@m>0A6<Rd4ECP`16=8
?0AcE4L3KE1318QGC`BEKeX4SV1?13/T80@`81`4;24M0bTL5`A99R04G44j1;ne/b>_XYhEoooo000D
oooo7jnRWPA;<2L4BS<Z13TZ9P<]7a/4=A`G13TV8PA7<RP4K4m21;>4K0BcUX83/i5n1:n=P@B_ThH4
[iF91:nCQ@B_WIL7[iR?1:nBQ0B_ThD4[i601:nAP`B_RgD3Z8=`1:V7M0BYOfh4ZGi/1:V1LPBRNf/4
WgUV0iEcH@B<J5P4Q6EE175BA@A_CD44OeE70hYTE`B>HeH4Rf9E16i=>`@m:2<4<20L13PU80<V7a/4
<R4L14le:PBaXJ<4bLc77jnRWQGoool001CooolO[j:N14/`9`A:<bX4>BXV0bdO6`@e71L4>BHR14Lb
:0A/Cd84/hA/1;>FPP>cTGh4[hf11:nCQPB_UHT4[i>51:nMU`N_V8l4[i:41:nCQ@B_TH04[i631:n;
M@>XPg04ZHMd1:UoKPBYOV`4ZH5b1:9kJ`BONFH3UG=Q18aXF0B4IED4LE9516m=@@AoEDL3RVAG18iS
EPB;HUD4KTdk13dX8`@`81`4>2DP0bHO6`@b8A`4CcDZ1;6QX`C9c<LO[j:N5Oooo`005?oooan_XYh4
Bc0W14Xc:P@i:RH3;AlK13DL5`@i9R84Ac8X16a?@PBcQ6`4/iJ20k>AOPB_SH44[i>61:nER@B_ThD4
[ifG1jnHS`B_TX@4[i>51:nAP0B_TH<4[h]e0jR3L0BYQg@4ZGm^1:UnK0BYPG84XW][19miIP>ELf44
S6QH18AUE@AaDTD4Kde117mEA`>:I5L4SV=F18]RE@A^CC/4?BPS130P70@h9B039QlK138Q70A?=BX4
/J6S1<W<aan_XYhEoooo000Doooo7jnRWPA3:b84CSTc13TX8`<i92049A/F13HQ7@@g8ah4H3h`191S
B@C6XHh3/99o1:n=P@B_ThH4[iVA1:nCQ`B_ThD4[ifG1jnFR`B_ThD4[hei1:n=O`B/QGH3[89`1:Un
K0BYQG84ZH5_1:UnK0BRN6H4X7=Q0j1dHPBILf84V6aJ19eaG`BDKed4TVQH0iUYF`BIJEX4RUe;14he
;@@/7QP4>RHV12LL6`<X7AL4718B14DZ8`B=KfL4a/;37jnRWQGoool001CooolO[j:N14<[8PA>>C<4
>BPS0cTT80@U6aH4=R4M13LS7PAP?S04T6=91<JQSP>`TWl4[hf11:nCQPB_VI44[i>71:nCQ@B_WIL7
[iJ;1:nCQ@B_SGT4[heo1:b5MP>/PW04ZGi/1:V5LPBYPFl4ZGi/1:9hIPBPLf43X7AR19UcHPBHK5X4
WG5O19A_G@BBJ5P3VFUK19UYFPB:GD/4CSD]12`N60@j9RH49a`K0bPM5`@L4Q84ABXS18e_I`C6`/<O
[j:N5Oooo`005?oooan_XYh4@b/R14hi<`@i:2<3>B@P12DK5P@f8Ad4=b<N160n<0B@HdT4aZ6>0k2B
O`B_SH44[i>61:nIT@B_ThL4[i>51:nMU`N_UX/4[i>51:n=N@B_SGl4[8Ef0jb2L0BYOV`4ZHEb1:V1
K`BYOV`4XWQV1:1cH@>PM684VG=R19Q/FPBMLEl4U6mM199XF0>IJE/4VFUJ18YMB`A>=Bd4;1hH13XV
9P@W71/3:1dG11`B4PA5:R<4SFmW1<K2`an_XYhEoooo000Doooo7jnRWPA3:b84CSTc13TX8`<i9204
9A/F13HQ7@@g8ah4H3h`191SB@C6XHh3/99o1:n=P@B_ThH4[iVA1:nCQ`B_ThD4[ifG1jnFR`B_ThD4
[hei1:n=O`B/QGH3[89`1:UnK0BYQG84ZH5_1:UnK0BRN6H4X7=Q0j1dHPBILf84V6aJ19eaG`BDKed4
TVQH0iUYF`BIJEX4RUe;14he;@@/7QP4>RHV12LL6`<X7AL4718B14DZ8`B=KfL4a/;37jnRWQGoool0
01CooolO[j:N14L^90A6=C44AC<^0cTW8`@f8ah4;1lK13TY90A==c44JdPh1;b9K`>iVH@4[i651:nA
Q0B_Vi04[ifG1:nCQ`B_UHT3[i:42:nCQ@B_SG/4[8]e1:b5L`NYPFl4ZGi/1:MnK0B[NfT4Yg]Y19ac
H@>MM684WGMU19UcH@BHK5X4VVmM18]XF0>BJEP4QVIE16Y;?P@o:B<4=bTT11lF5P@W7Ad36Q4B12DK
6`@b81/4NEeF1<:e/Qn_XYhEoooo000Doooo7jnRWPA7;R@4ASDa14Dc;P<i9b<4=R<N12`O6`@i:B@4
CCLa16]8>0BlRFl3^IV41:nAQ@B_TH@4[i^@1:nMU`B_ThL4[iF90jnBQ0R_ThD4[hek1:b;M@B/QG<7
ZH5_1:UnK0BWOV`4Zg]Y1:MkJ@BLLf43WGAR19egI@BILf44V6aJ19Y_G@B;J5P3TVUH18IVE@AZBch4
?bTS13LY90@O5QH49adM0aXA4P@U6a/4<R0K17UMEPC2]K8O[j:N5Oooo`005?oooan_XYh4AbhT14He
<@A5<bh3>BLS13HS7P@/7a/4>BTT14dg<@A[B3P4_8U_0kVIQ0B_THD4[i641:nKT0B_WIL4[i>71:nE
R@>_TX@8[i>51:n=N`B/RgD4[8Ec1jV1K`BYOV`4Ygi/1:]kJ@BWNfT4W7=Q0iedHPBMMfD4VG=Q19Q/
FPBJKed4RfQH0i9YF0B6IUD4JT/n13lY8`@g:B@47aHF12LM7@<J4A849A/K138P6`AiGEH4`[Fb7jnR
WQGoool001CooolO[j:N14L^90A6=C44AC<^0cTW8`@f8ah4;1lK13TY90A==c44JdPh1;b9K`>iVH@4
[i651:nAQ0B_Vi04[ifG1:nCQ`B_UHT3[i:42:nCQ@B_SG/4[8]e1:b5L`NYPFl4ZGi/1:MnK0B[NfT4
Yg]Y19acH@>MM684WGMU19UcH@BHK5X4VVmM18]XF0>BJEP4QVIE16Y;?P@o:B<4=bTT11lF5P@W7Ad3
6Q4B12DK6`@b81/4NEeF1<:e/Qn_XYhEoooo000Doooo7jnRWPA7<R/4CCPa14Xh<P=2<B`4>B<O12HL
5`@o9b84DcP^16Q;?@BFJU@3^9R61;>BP`B_SH@4[i641:nKT0B_WIL4[iR?0jnCQ`B_SWh4[i>51:n=
P0BZRWL4YGm]0jMmK0B[NfT4[Gi`1:9nJ@BSNFH4XgUZ19afH@>MM684WG5O19YdH@BJLEl4UFQF19A^
G@><He44OUU<15hl;`@n9b849adH12HL7@@O5QH391/F12<J70@j9B04R79[18I/IAn_XYhEoooo000D
oooo7jnRWPA7<R/4CCPa14Xh<P=2<B`4>B<O12HL5`@o9b84DcP^16Q;?@BFJU@3^9R61;>BP`B_SH@4
[i641:nKT0B_WIL4[iR?0jnCQ`B_SWh4[i>51:n=P0BZRWL4YGm]0jMmK0B[NfT4[Gi`1:9nJ@BSNFH4
XgUZ19afH@>MM684WG5O19YdH@BJLEl4UFQF19A^G@><He44OUU<15hl;`@n9b849adH12HL7@@O5QH3
91/F12<J70@j9B04R79[18I/IAn_XYhEoooo000Doooo7jnRWPA7<R/4CCPa14Xh<P=2<B`4>B<O12HL
5`@o9b84DcP^16Q;?@BFJU@3^9R61;>BP`B_SH@4[i641:nKT0B_WIL4[iR?0jnCQ`B_SWh4[i>51:n=
P0BZRWL4YGm]0jMmK0B[NfT4[Gi`1:9nJ@BSNFH4XgUZ19afH@>MM684WG5O19YdH@BJLEl4UFQF19A^
G@><He44OUU<15hl;`@n9b849adH12HL7@@O5QH391/F12<J70@j9B04R79[18I/IAn_XYhEoooo000D
oooo7jnRWPA7<R/4CCPa14Xh<P=2<B`4>B<O12HL5`@o9b84DcP^16Q;?@BFJU@3^9R61;>BP`B_SH@4
[i641:nKT0B_WIL4[iR?0jnCQ`B_SWh4[i>51:n=P0BZRWL4YGm]0jMmK0B[NfT4[Gi`1:9nJ@BSNFH4
XgUZ19afH@>MM684WG5O19YdH@BJLEl4UFQF19A^G@><He44OUU<15hl;`@n9b849adH12HL7@@O5QH3
91/F12<J70@j9B04R79[18I/IAn_XYhEoooo000Doooo5jnRWPB_XId4[:>O14<c;@A:>384Cc`f0dLe
<0@b81`4>BTT13LW8`A6<BX4Ndhk19AQCP>^QW44]9B01:n=P@R_Sh84[iVA1jnHS`B_TX@4[i>51:b;
N`BcSgl4Z8=`0jF1K`BRNVT4XgEW1:MiJ@BSLf44X7IW1:1`H@>JKUl4WWAO19Y_G@BHKed4U6EE18mW
EP>;FdT4MU1114H`9P@m9R48:1lK12LN6`<S6QH4:B0L13`U8@C6_KX4ZYjJ7jnRWQGoool001CooolG
[j:N1:nQW@B/Xil4@c<]14Xh<PA??3H3AcD`138P70@i:B@4=bLS14Ha:PAkCS/4U65>0jj6L@BdU804
[hf12:n?PPB_VI47[iR?1:nBQ0B_ThD4[8]k1;>?O`BXPg03YH5_1:9jJ@BSMFL4YgUY1:=cH@BPMVL4
X71Q0iY^G`BNM5l4VVmM19Q_G@BDIED4SfMF0h]KB@AfD444AS0V13dV8@PX7a/49ahK0b<J5P@Y81`4
?2DQ1<Jm^PBZWYXO[j:N5Oooo`005?oooaN_XYh4[j6M1:bSW`A3<bd4BSPb14ll=P=7=C04<R0L13TY
90@g9b<4AS4Z17]>>`BDHDh3[XIa1;BDP0B_SH48[hn21:nIT@N_V8l4[i:41:nCQ@B/Rg/4/hmo1:R3
L0>UPFl4XWYY1:=eI`BWNFT4Xg=Q1:1fI`BPL643VViO19idG`BJKed4V6mM19AUE@B?IeH3Re]917I@
@@A6<2H4?BHQ22PO6`@W7Q/38aXF12TP70@l9B44a[fj1:ZNVQn_XYhEoooo000Doooo5jnRWPB_XId4
[:>O14<c;@A:>384Cc`f0dLe<0@b81`4>BTT13LW8`A6<BX4Ndhk19AQCP>^QW44]9B01:n=P@R_Sh84
[iVA1jnHS`B_TX@4[i>51:b;N`BcSgl4Z8=`0jF1K`BRNVT4XgEW1:MiJ@BSLf44X7IW1:1`H@>JKUl4
WWAO19Y_G@BHKed4U6EE18mWEP>;FdT4MU1114H`9P@m9R48:1lK12LN6`<S6QH4:B0L13`U8@C6_KX4
ZYjJ7jnRWQGoool001CooolG[j:N1:nNVPBZUY84>RXU158g;@A6=c83CCXe13l^:P@f9b84@2lZ14D_
9PAZD4@4R5A10kB3K`BcVHD4/i651:nAQ0B_UhT4[iN=1jnKTPB_U8T4[9:11:b<N`B]S7T4[7a[0jMk
IPB[OVl4Yg]V1:=iJPBSMF@4W7AR19efI0>IJe`4U6aM19Q[FPBHKe`4TV]J18]SD@=nED@4Gcde14@Z
8`@^8Qd49a`G12HL7@@Q5aL35A8B128G5`AB=Bl4][6^1;:VXQn_XYhEoooo000Doooo5jnRWPB_WYX4
ZYJB13XZ9@AB=bd4ASLb0ddj=@@o;RX4=RLR140_:PA5;bH4JU1418QD@@>dPfl4/iV51;>AQ@B_TH@4
[iN91:nGS@N_Vi84[iB91:bBP@B/S7/4[Hai1:alJ`>WNfH4Zgi_1:MkIPBSNFX4XgET19adHPBMMV@3
VF]L19A/G@BHJeX4V6mL199[FPB;He43OUE415lm=@A4:R<4;R8M12LL5`@V71d48ALG0aDB4P@R5aL4
DSD_1;Ja[PBbYZ8O[j:N5Oooo`005?oooaN_XYh4[ijJ1:ZFTP@j:RD4DSL]14Hg<P==>SD4?bhZ13HW
8PA0;bX4ABlV16Y@A0B8E443]8=_1;>IQ@BcTHD4[i641:nGR@B_Uhd7[i^B1:nDR@B/TX44[8ak1:f<
N@B/O6/3Yg]V1:]nK`BWNfH4XgUZ1:=eI0BLM684WGIT0iU[G0BDK5d4V6]J19Q_G0BBJeX4Rf=A0giE
A0AO?CD4A2XS12hR7@@W71L49Q`M124G5`<E4Q848QLG158e;`Bf/Jh4/ZJR7jnRWQGoool001CooolO
[j:N14Da:`A6;b@4CS/e0d`i=0A2<B/4?2LR14Hb9`A6=2l4GTPk16a2=@>XLe`4^9R41;2>O`B_SH84
[i681:nDQ0N_U8P4[i671:Z:M`BUOfd4ZHAb1:MnJP>WO6H4XgUW1:=lI0BSNFD4Xg=Q19aiI`NMLEl4
UfmM19QXF0BEIUD4QfED17iGA@=O?SH4DSHY13<Q7@@[8A`4;R0K12<K6`@O5QH37ADF13@S7`A/CDX4
M59<8jnRWQGoool001CooolO[j:N14Da:`A6;b@4CS/e0d`i=0A2<B/4?2LR14Hb9`A6=2l4GTPk16a2
=@>XLe`4^9R41;2>O`B_SH84[i681:nDQ0N_U8P4[i671:Z:M`BUOfd4ZHAb1:MnJP>WO6H4XgUW1:=l
I0BSNFD4Xg=Q19aiI`NMLEl4UfmM19QXF0BEIUD4QfED17iGA@=O?SH4DSHY13<Q7@@[8A`4;R0K12<K
6`@O5QH37ADF13@S7`A/CDX4M59<8jnRWQGoool001CooolO[j:N14Da:`A6;b@4CS/e0d`i=0A2<B/4
?2LR14Hb9`A6=2l4GTPk16a2=@>XLe`4^9R41;2>O`B_SH84[i681:nDQ0N_U8P4[i671:Z:M`BUOfd4
ZHAb1:MnJP>WO6H4XgUW1:=lI0BSNFD4Xg=Q19aiI`NMLEl4UfmM19QXF0BEIUD4QfED17iGA@=O?SH4
DSHY13<Q7@@[8A`4;R0K12<K6`@O5QH37ADF13@S7`A/CDX4M59<8jnRWQGoool001CooolO[j:N14Da
:`A6;b@4CS/e0d`i=0A2<B/4?2LR14Hb9`A6=2l4GTPk16a2=@>XLe`4^9R41;2>O`B_SH84[i681:nD
Q0N_U8P4[i671:Z:M`BUOfd4ZHAb1:MnJP>WO6H4XgUW1:=lI0BSNFD4Xg=Q19aiI`NMLEl4UfmM19QX
F0BEIUD4QfED17iGA@=O?SH4DSHY13<Q7@@[8A`4;R0K12<K6`@O5QH37ADF13@S7`A/CDX4M59<8jnR
WQGoool001CooolO[j:N15Do>@A1;RP4BCD_0e<l=PA3<2H4?RhY13dZ90A;=c44AcD]15Y0=`>=Ed<4
]8U_1;ZOS@B`Sg`4/i621:n=OPB_SG/3[8]i1;2?O`BcTH44Z7m]1:MkJ0BWNfH3X6iO2:EgI`BXNFL4
X71N1:1bH0BMKUl3VW9M19Y_FPBEIEH4TVIE17iKBPAW?c<3CcDY13HS7P@Y7AL49a`M138Q70@T6a`4
6Q4B0b0F5`@m9R44b;nl1;:VXR>_XYhEoooo000Doooo7jnRWPAE?cT4@BhX14Te;`=C?3H4@c0V13h^
:@@m:R@4BcLa14Le;@AJ@3L3SEM31;B9K`BjWhd4/8ml1;>APPB_SGh4[hek0jb;N@B`Sgl4/i611:Qo
K@BWNfP4Yg]V0j1^G`RUMfL4Z7UW1:1`GPBPLV04WFiO0iYbG@BJKeX4UFEF199VE@AnFdX4Iclc0dle
:@@f8ah4:AdG12LL7@@b8A`491/L11XA4P<P5QL4?BHQ1<Ro_0BbYZ8S[j:N5Oooo`005?oooan_XYh4
ECli144^:0A9=Bl3Dc`f14<`9P@n;RT4?BXT14/g<@A7=Bd4FT0g0heG@`BdRFl4^Yn=1;2?O0BcTH84
[hen1:n=N`>/RgT4/8mo1;>AP@BXOfd4Yg]X1:MkIP>PKUl8YGMW1:QiI`BPL5h4X79P19e^G`>JLUd4
VVmJ19EUEPBBIUD4OU]:16Lo<`=?=BT4=R<N12TM5`@W71d4<R4L12@K70@J4A8381HG13dV8@C8_k`4
/ZJR8jnRWQGoool001CooolO[j:N15Do>@A1;RP4BCD_0e<l=PA3<2H4?RhY13dZ90A;=c44AcD]15Y0
=`>=Ed<4]8U_1;ZOS@B`Sg`4/i621:n=OPB_SG/3[8]i1;2?O`BcTH44Z7m]1:MkJ0BWNfH3X6iO2:Eg
I`BXNFL4X71N1:1bH0BMKUl3VW9M19Y_FPBEIEH4TVIE17iKBPAW?c<3CcDY13HS7P@Y7AL49a`M138Q
70@T6a`46Q4B0b0F5`@m9R44b;nl1;:VXR>_XYhEoooo000Doooo7jnRWPALB3h4BCLd14Xh<P=9=C04
BSD^13PV9@@n;2H4@c8/14`i=0A6<2H3HSha19iaF0BfRW84/i5l1;6EP0B`T7`4/9=o0jb;N@BYQW@4
[Hej1:Z2L0BSL5h4YGMQ0j1cG`BMKU`4WGMT1:9dH@BPLEl4VV]J19i[G0>GJET4UFiI18iUD@B7F4D4
OEI314hd:@<h8ah4;R8M12DK5P@P5QL48QLG11DB4P@E4A83>2<P13hW80Bj][PW[j:N5Oooo`005?oo
oan_XYh4G4Pn14Tg=0A:>383BCD`14Xe;P@h9RD4?R`V14<b;0A<>C@4AS0V0f8n<@BNLEP4]XYb1;>A
O0BaUH04/91l1;2CO`>/RgT4ZHId1:f=NPBZPW04Xg1N1:EgH@>PLel4WFiL19egI0BRM644X75O19Y[
FPBNJe`3UfUI19E^F@B>IE44QeQ517eF@`A>=2T3>2<N12hR7@@U6aH481HG128G5`@E4Q845A4B0cPS
80@n9b04^[Jh9jnRWQGoool001CooolO[j:N15a8?PA9=c@4BSPb0dTe<0A:=Bh4>2HU13h/9PA3<R`4
C3Td14H`9P=R?S44WW5H1;J:LPBcTG`4/IF01;2@O0B`Tgl3[8]i1:V6M0B]SGX4ZX9`1:=`GPBUMf43
X7=O19e^G0BMMf@4XWAQ1:1aG`BJJeX4WV]L0iMYF@BEKUT4SVEA18MHA@AmET<4CS@Y0cPS7P@^8Qd4
9A/F120F5`@R5aL45A8B11DA4P<h8b04?RLP1;Zf^2N_XYhEoooo000Doooo7jnRWPALB3h4BCLd14Xh
<P=9=C04BSD^13PV9@@n;2H4@c8/14`i=0A6<2H3HSha19iaF0BfRW84/i5l1;6EP0B`T7`4/9=o0jb;
N@BYQW@4[Hej1:Z2L0BSL5h4YGMQ0j1cG`BMKU`4WGMT1:9dH@BPLEl4VV]J19i[G0>GJET4UFiI18iU
D@B7F4D4OEI314hd:@<h8ah4;R8M12DK5P@P5QL48QLG11DB4P@E4A83>2<P13hW80Bj][PW[j:N5Ooo
o`005?oooan_XYh4L5U?13l[8`A;>SD3AcD`150m=`@o:b<4=b@Q14Xj=0A1<2X4CcXc0clZ90A_DD44
PUY81;5dG0BlTgd4Z89]1:n?OP>/RgL4[8Q`1:n8M@BPN6D4TfMD1:5[E`>VKeL4XW5Q19i/F`BNJ5D4
WWAQ19Y[D`BEIUT3TV=A18]PCPAoH4h4Jd@g160h:PA3:R@3<R4L12DL5`@P5QL481HF11XA4P@C4A84
7QDF0c8Q70AlET`4MUQ>9jnRWQGoool001CooolO[j:N171IC`@o:b<4BcXe0dLe<0A@?CL4?b/S13LT
8@A:>S@4@C0Z14lj<`<o:R@4Ke51189JB0BaM5`4_9=m1:R2K@B_Sgh3[8]g1:b8L0B_R7D4X7QU19=W
E0BQJeL3YVmG1:9aH@BNK5/4WVQE19idH@BJJe<4UFII0i9SD@B;H4h4Of1>16]4=`AP>2X4@bXT0c8Q
70@U71L481HG120F5P@J4A844a4B11hE5P<b8A`4O5I<17IHCRN_XYhEoooo000Doooo7jnRWPA`FDl4
?b/S14/j=@=7=C04D3dg13l[8`@g9244BSXd144`:PA?>S<3?bXT16mA@@B2FTP4/GAL1;bCO@BXPVd4
[hmn0jb;M`B/R704[hQe1:1hI@BCIe@4XF]G0jI_E`BRLF44WVaK19iXE@BNM644VV]C19EVF@>BHe44
Rf1>17mPCPA[A3L4H3PZ14<Z90<b8A`49A`G120F5`@P5QH46Q4B11<A4P@N5AH3<R4L17aFC0AfF4hW
[j:N5Oooo`005?oooan_XYh4L5U?13l[8`A;>SD3AcD`150m=`@o:b<4=b@Q14Xj=0A1<2X4CcXc0clZ
90A_DD44PUY81;5dG0BlTgd4Z89]1:n?OP>/RgL4[8Q`1:n8M@BPN6D4TfMD1:5[E`>VKeL4XW5Q19i/
F`BNJ5D4WWAQ19Y[D`BEIUT3TV=A18]PCPAoH4h4Jd@g160h:PA3:R@3<R4L12DL5`@P5QL481HF11XA
4P@C4A847QDF0c8Q70AlET`4MUQ>9jnRWQGoool001CooolO[j:N19V2P`A9<R`4@2hZ1d/h<PA0<R/4
>BDT14`c:0A7=S84D3dh0dDd;`A8=Rl4G4Hm17I<?@BAGdP4SVYO18aZF0>RKUP4XgiY1:5hH`B>IED4
QeU317a@?@>AGD<4Vem;19a/D`BPIE44TF1@191NA`BGH4T3Sf1>17eFB@AeBCX4GSP[14TY8`@e8Qd3
9a`G124F5`@J4A8<514B12TO6`<h8b04^Jj/1:^KUbN_XYhEoooo000Doooo7jnRWPBIPX<4BC8/140^
:PM;>384@38[13TU90A<<bP4AcHb150m>0=5=2l4B3H_15a6?@AfC3d4TEm818iZG`B<JUP3XViH1:=n
J@BQN6<4SVEE18MI@`AlD3d3TEe319]OB`BLK5<4X6EA195PD0B@GTL4Uf190hmPCPAmETT4MDTj15hh
:`A9:B<4=B8M0bLL5`@Q5QL46Q4B31@A4P@Y7a/3>2<P1;V^[0B[ViLW[j:N5Oooo`005?oooan_XYh4
VH:314Tb;0A0;RX7BcPb140b:`@i9B@4C3<X14Lf<PA@?CP3AC@_14Pf;`ALASd4MT`m195OB0B>JUl4
S6YH0j9^F0BSOVT4XGQS18iUE@B7FD<4O50m0i5M@`BKGd/4W6aC1:1UD@BAH504T5i719MPB@>?H4h4
OEI917E9>PAN>2/4BBTS13DR7@<W71L48AHG11XA4P`D4A84:AlK0cPS80Bi[Z`4Zi^G9jnRWQGoool0
01CooolO[j:N19V2P`A9<R`4@2hZ1d/h<PA0<R/4>BDT14`c:0A7=S84D3dh0dDd;`A8=Rl4G4Hm17I<
?@BAGdP4SVYO18aZF0>RKUP4XgiY1:5hH`B>IED4QeU317a@?@>AGD<4Vem;19a/D`BPIE44TF1@191N
A`BGH4T3Sf1>17eFB@AeBCX4GSP[14TY8`@e8Qd39a`G124F5`@J4A8<514B12TO6`<h8b04^Jj/1:^K
UbN_XYhEoooo000Doooo8jnRWPAUDDT4>bXS0dXh<`A6>384A38]12TP70A7<R`4DSdg150m=`=D@S`4
CS`g15E2>@AMAC`4HTDh1651>PAO@3<3I44i17U;>PAlFDL4HdHm16E4>@A]@C83Jd<^17A5=`B9F444
REM1189B?@B0Dd04LdDd0gY?@@A^@cH4G3``14<X8PA2:bH49Q/F0bHL5`@O5QH46A4A21<A4P@/7a/4
8QXK0fI;A0BCR8D[[j:N5Oooo`005?ooob>_XYh4IE5913/Z8`=:>3<4ASPb14@b;@@Y81`4Ac8/158m
=`A@?CL3E48l14hl=`AE@ST4GDDl1695>0AQ@CX4Gd0c0fA1>@AiBcX4O5U716=6?@AUA3T4KD4b0f]3
;PAdACL4REQ118UG@@B2DSd4P5=017=5=0=jCd44KT<f15`l<0A3:284@R/V12HK5P<V71L47aHF11TA
4@PC4A84;1lK128J6`=VBd@4ThR5:jnRWQGoool001CooolS[j:N16EAB@@k:R<3BSPc14Hh<PA4<Rd4
:B0L14Lb;0AB?CL4D3dg0eA2?0A>?3L4ED8i15e5?0ARACP4HD4j15m0<`=T@CT4ND/j17aIA`ASASd4
ID@i16e1<P=[@bh4M4Dg18UH@@B9Ed44PU8m181C@0AcAC@3NTm116i3=PAL?304@bPR148[9P@V6aH3
9Q`G11lF5P@I4A484a4B12`O6`@R6Q/3IT]419>8QB^_XYhEoooo000Doooo8jnRWPB4Kg04?BTU0dHe
<0A9>384AcHa13h`:`A2<bh4D3dh15M3?@=>>cH4E40j15Xm=@ASA3H4E3``14/j=0A3;BL3DCPa14HX
8`AI?cH4DSXc14Pc;@A8:R@3Bc4Y14/[8`AF;bH4Gch]15/j:`AL>R/4DbdU0e8^9PA;;BH4B2/T130S
7@@Z7AP48QLG1b0F5P@C4A44514B12`O8`@/7aX4?Rl/0hEZI`B@Lfd[[j:N5Oooo`005?ooob>_XYh4
Q6m`13dY9@=6=C04BCPb14Lf<@@n<2/4@S<^150m>0AG@cd3CS/f15A0>PAJ?CD4Hd@f15@l<0A;>S@4
@bdW0e4h<@A6:2<4FClf158j<`A8<bd4B2XT0d/a:@A;:b<4ERlV15ln;@AK>R/4G3X[15<]9@=B;RH4
BbdV14P[90@`8ad4:QdH128G5`LP5QH44a4A11@A4P@/7b<4;1lJ13h_;0>5JVL4T7=]:jnRWQGoool0
01CooolS[j:N18A_L0@m:BD3ASD`14Th<PA7=S44?S0[148c;PA@?CP4Ed<m0dhk=PAD@3X4FSde16=4
=PAD?304BcXd14<]9`=A>344ARPS15To=PAB>S<4B3<]14PZ90=;<BT4Bb/S15H_9PAO?Rd4FcX[15`j
:`AC;BD3DRhV14/]9PA8:b@4<2<M12XM60@R5aL781HF11<A4@@D4A84;1lS12`O6P@n;b`3QFYW191c
KB^_XYhEoooo000Doooo8jnRWPB4Kg04?BTU0dHe<0A9>384AcHa13h`:`A2<bh4D3dh15M3?@=>>cH4
E40j15Xm=@ASA3H4E3``14/j=0A3;BL3DCPa14HX8`AI?cH4DSXc14Pc;@A8:R@3Bc4Y14/[8`AF;bH4
Gch]15/j:`AL>R/4DbdU0e8^9PA;;BH4B2/T130S7@@Z7AP48QLG1b0F5P@C4A44514B12`O8`@/7aX4
?Rl/0hEZI`B@Lfd[[j:N5Oooo`005?ooob>_XYh4YYBE15a2?`<h9b84AcD`14`i=0A6=2l4ED8l148a
:`AKAT03AC<]154m>0AK@3L4CSHa14le;@A:=Bl4?blY0dlh<`@d92<4@38[144X8`@o:B@4<b8M0blR
7P@f8Qd4@2HQ140W8@@f91d4>B@N13LS7@=19R44<b4L13@R7@@V71L49A`G1alF5PPD4A847QDF13PX
9P@g8b04KEI@0g9GD2n_XYhEoooo000Doooo8jnRWPBVU9D4G48o0cPW8PA7=C04C3Td14Hd;`AE@S`4
@S4[15]6@0=5<bd4DCdh15]0=`A>=S44CcD]14Xe;`@o;bT3CcPc13@T8`A0<R/4@BPS13lY90@c8Qd3
;b8N13HR7@A09R44@2LQ13HT7@@i91h4=b<M0d4V8@@c8A`4=28M12HL5`@U71L77aHF21@A4P@N5AH4
>2PV13LS80A]EU03LUM@;jnRWQGoool001CooolS[j:N1:JDU@AL@Sl3>2LR14Le<0A<>C@4AS@_15E2
?0A2<B/4FdI00dDc;@AA?CP4Fd0g14hf<@A?=Bd4BSD_13l_:@=?>3<4=2@S140b:`A1:2<4?bTT13<R
7@<_8Qh4=R8M140V8@A09b44=R@M13TT7P@g8ad3@BHQ13<Q70@d8Qd49Q`G12DL5`LO5QH8514B11hE
5P@h:2H4=b<P16eFD0=bEe0_[j:N5Oooo`005?ooob>_XYh4YYBE15a2?`<h9b84AcD`14`i=0A6=2l4
ED8l148a:`AKAT03AC<]154m>0AK@3L4CSHa14le;@A:=Bl4?blY0dlh<`@d92<4@38[144X8`@o:B@4
<b8M0blR7P@f8Qd4@2HQ140W8@@f91d4>B@N13LS7@=19R44<b4L13@R7@@V71L49A`G1alF5PPD4A84
7QDF13PX9P@g8b04KEI@0g9GD2n_XYhEoooo000Doooo9jnRWPB7LFl3@2/U14Pi=0A<>C@4AcD`148e
;PAF@C/4DCli0d<e<0A3<2X4G3`_144`:PA7=Bh4A38]13@X:`=5=Bd4>RHW13`W8P@b8RH4;b8L12hQ
70<V71L4;24M12hQ70@`8Qd4:1`G128G5`@Y7AL3=B8M12LL5`@R5aL49a`G12DK6`@O5QH3514B11lF
5P@U7QX4<B@R13HS80A[CdT4Jda5<ZnRWQGoool001CooolW[j:N18MaK`=0:bD4B3Td14`i=0A7=C04
@SD^15I1>`AA?cT3@cD`14<`:PAL?2l4@C0Z14Le;PA4<Rd4=2P[0dDe;@@j9RL4?2LR138R9P@_8Q`4
;R4L0bHL5`@/8Ad4;R4L130R7@@X71L48QLG12TM5`<e8Qd49a`G128G5`@W71L49A/K11lF5P<D4A84
7aHF12DN6P@a9284=R<P16]?B@A[C4Db[j:N5Oooo`005?ooobN_XYh4Qg5_0d0[9@A8>C@4C3Td14Le
<0A2=Bh4ET4k154o>@=3=C04@c0Z15`l;`A1<2X4AcD^14@b;@@d:2/3ACD]13XV9`@l9b84<R8V12lR
70@^8A`39Q`G12`Q7@@^8A`4<28M12PL5`@R5aL4:AdG0cDR7@@W71L48QLG12LL5`@U6a/47aHF0a@A
4P@O5QH49AhJ134T8P@f8b04Jdm916]<AC:_XYhEoooo000Doooo9jnRWPB7LFl3@2/U14Pi=0A<>C@4
AcD`148e;PAF@C/4DCli0d<e<0A3<2X4G3`_144`:PA7=Bh4A38]13@X:`=5=Bd4>RHW13`W8P@b8RH4
;b8L12hQ70<V71L4;24M12hQ70@`8Qd4:1`G128G5`@Y7AL3=B8M12LL5`@R5aL49a`G12DK6`@O5QH3
514B11lF5P@U7QX4<B@R13HS80A[CdT4Jda5<ZnRWQGoool001CooolW[j:N1:6;S0=A=S<4@BhZ14ll
=PA7=C04B3Pb14Hi=0AD?cT3AC@^13h]:0A3;RL4=R<M14Dc;@@h9bH4=bLW0c8S7P@c8bP4:1dL12<G
60@X7Ad49Q`L0b0F5P@V7A`48ALG12LM7@@P5QH49A/K12TO6`<V6a/48AHF11@A4P@E4A845A8B11DA
4P<T6a/48QXF120F5`@e7QP4LeUD16mECSJ_XYhEoooo000Doooo9jnRWPBQRh`3DCHc144^:PA??3H4
AcD`14Ph<PA6>C@4E3li0dDd;P@n;BP4@bhW13HS7@A5<bd4>2LV13LW9`<b8ah4<b<X12PM70@S5aP4
:1dM12HL70<P5QH49QdL124G5`@W7Ad481HF12DK6`@Y7a/39Q/K124F5P@D4A845A4B11DB4P@E4A83
91/K128J5P@P5QL4=AhH17=IE0A_EDhf[j:N5Oooo`005?ooobN_XYh4XH^<0e4f<`A1;RX4Cc`f14Le
<0A8>384ASTd15@o>@=5=2h4?RdX14<^9`@f8ad4AC<]13PW9P@g9bL3<R<N13<S:0@X7A`48aLH12PM
7@@V71`381HF12HM70@Q5aL49adM120F5P@U6a/4:AlK0bHK6`@Q5QH4514B11DA4P@E4Q845A4B0b@K
6`@R6QH481HG13DN60AcFE@4KeE>=ZnRWQGoool001CooolW[j:N1:6;S0=A=S<4@BhZ14ll=PA7=C04
B3Pb14Hi=0AD?cT3AC@^13h]:0A3;RL4=R<M14Dc;@@h9bH4=bLW0c8S7P@c8bP4:1dL12<G60@X7Ad4
9Q`L0b0F5P@V7A`48ALG12LM7@@P5QH49A/K12TO6`<V6a/48AHF11@A4P@E4A845A8B11DA4P<T6a/4
8QXF120F5`@e7QP4LeUD16mECSJ_XYhEoooo000Doooo:jnRWP=iGED4>R@O13X[9PA;>384BC/e14Tj
=@AB?ST3@c8a13XU80@l:bH4:b0L13DS7P@^8ah4=28N0b4G5`@S5aP49a`M12@K6`@O5QH49A`M0alF
5P@U6a`47aHF13LT80@B41449a`M12XQ70<T6a`8514B11TA4P@R6Q/481TJ0b<J6`@g91l4=RTR14Pd
;`B<QX`4Zi^G=ZnRWQGoool001Coool[[j:N0gUME@@j91l4>R/V14/h<PA9>cD4BCXe158n>@=3<S44
>RDP13`[9P@[81`4=B<N12hS7P@d8Qh38ALG12<G60@W71d491/K11lF5P@U71d37aHF12DK70@O5QH4
=b@P118@4@@W71d4:R4L0b@K70PD4A846A4B128J6`@P6AX38aXK13LT7`@f:B84B3@_18b6S0B[ViLf
[j:N5Oooo`005?ooob^_XYh3NEeE13XT7`@j:bH4BcPb14Tk=@A9>SD4DShi0d<b<@@j9B04?2/V12/P
70@e8ah4;R<N13@R7P<Q5aL48aLH12LL7@@T6a/47aHF12DL7@<O5QH49A/L11lF5P@g92044Q0A12LL
7@@Z8A`391/L21@A4P@I4A848QXK120I6P<S6Q/4=b@O13HY8PA8=2l4S8J<1:^KUcJ_XYhEoooo000D
oooo;ZnRWPAiGED4=b8M13/`;0A3<B/4DT4l150n>@=??3P4>2/W140]:0@]7b<49A`K138Q70@U71`3
:R0K12LN6`@S6Q/C81HG12TP70@W6a`4>c8f12lX90@Z71l37aHF12<K6`@T7AX491`J128J6`@k;2P3
<2@R13LS7`AL?384Of5B18eYFSZ_XYhEoooo000Doooo;ZnRWPAiGED4=b8M13/`;0A3<B/4DT4l150n
>@=??3P4>2/W140]:0@]7b<49A`K138Q70@U71`3:R0K12LN6`@S6Q/C81HG12TP70@W6a`4>c8f12lX
90@Z71l37aHF12<K6`@T7AX491`J128J6`@k;2P3<2@R13LS7`AL?384Of5B18eYFSZ_XYhEoooo000D
oooo;ZnRWPAiGED4=b8M13/`;0A3<B/4DT4l150n>@=??3P4>2/W140]:0@]7b<49A`K138Q70@U71`3
:R0K12LN6`@S6Q/C81HG12TP70@W6a`4>c8f12lX90@Z71l37aHF12<K6`@T7AX491`J128J6`@k;2P3
<2@R13LS7`AL?384Of5B18eYFSZ_XYhEoooo000Doooo;ZnRWPAiGED4=b8M13/`;0A3<B/4DT4l150n
>@=??3P4>2/W140]:0@]7b<49A`K138Q70@U71`3:R0K12LN6`@S6Q/C81HG12TP70@W6a`4>c8f12lX
90@Z71l37aHF12<K6`@T7AX491`J128J6`@k;2P3<2@R13LS7`AL?384Of5B18eYFSZ_XYhEoooo000D
oooo<ZnRWPAjF4l4=b8M144d;`A1<2X4Cd0j0e]5?`A8>C@4?bdT13LX9P@W7Q`49Q/L124F5`<V7AL4
9Q`M220F5`@T6a/47QDF0b@K6`@N5AH481LG13hf=0@g:384E4Q2148e=@<`92L4>2`Z130U8P@V7QX4
=bPT13TY9@=:>3<4C30Y16mAB`B3HUPn[j:N5Oooo`005?oooc:_XYh4NUQ?13LR7@A1=2l4@C0Z14m0
>P=KACl4B3Td13l]90@g:2H49ahL12HK70@Q5QL39QdG12HL7@PP5QL491/K11hE5P<T6a/47QDF120G
5`@n=S@4=bPb15A8@PA2=CD3<2@W13P/:P@`9B849QhJ13LX90@i:BD3BSPc14``:@A_DD/4Pf9H?ZnR
WQGoool001Cooolb[j:N17YHC`@g8Qd4@C@_144`:PA?@3X3FdDo14Pi=0@o;B@4=bPV12LN70@V6a`4
8AHG0bHM5`@V71d881HG12@K6`@N5AH391/K11hE5P@P5aL4?SHd13LX<PADB484@SDe0c0T9`@h;2X4
<2DR12HN6P@g:2@4>BTU0dXh<`A<<2T4Ke5;18=RF3j_XYhEoooo000Doooo<ZnRWPAjF4l4=b8M144d
;`A1<2X4Cd0j0e]5?`A8>C@4?bdT13LX9P@W7Q`49Q/L124F5`<V7AL49Q`M220F5`@T6a/47QDF0b@K
6`@N5AH481LG13hf=0@g:384E4Q2148e=@<`92L4>2`Z130U8P@V7QX4=bPT13TY9@=:>3<4C30Y16mA
B`B3HUPn[j:N5Oooo`005?oooc:_XYh4/jNS17eLE0@n9Al4BC`h14@e<0=HASl4ET<m150l=@@g9R44
=bPT13T]:P@]9B<3:A`I12LO6`PS6Q/47aHF120F5`<Z82@48aXJ12PN6`@W7Ql4@cHb14dh=P@]8B43
=bPR13DW8P@]8204=2<M13/[9PA5;bH3Gd@j16M@CPB=KEh4[inK?ZnRWQGoool001Cooolb[j:N1;>W
X`AmG5@4?RDO14Tl>0A4=C03F4Ho15I3?@A@?3D4=bHQ13LX90@i;BX4;BDS0bTL6@@W7a/88aXK11lF
5P@P5QL3:R0T12<J6P@X7Q/49ahO14<f<PA=>3H4;B4Q0cLX8P@e9b84;B0P13@S7@@k:bH4ABlV0em4
>PAWD4h4SFeN1:nOVcj_XYhEoooo000Doooo<ZnRWPBcYj<4OEaD13hU7`A9?3P4A3D`0eQ6?`AF@cd4
D3`e13LV8@@g:2@4>BdZ12dU8`<Y71T49alK22<J6`@O5QH481HG0bXP90@S6QX4:1hK12LN7`A3=S84
CCPf12dQ8@<g:284=BLR12dP80@d8ad4>b/V14D_9P=OA3X4Ie1>18e]GPB_Wi/n[j:N5Oooo`005?oo
oc:_XYh4/jNS17eLE0@n9Al4BC`h14@e<0=HASl4ET<m150l=@@g9R44=bPT13T]:P@]9B<3:A`I12LO
6`PS6Q/47aHF120F5`<Z82@48aXJ12PN6`@W7Ql4@cHb14dh=P@]8B43=bPR13DW8P@]8204=2<M13/[
9PA5;bH3Gd@j16M@CPB=KEh4[inK?ZnRWQGoool001Cooolj[j:N17E@@P@n9Ah4@2l[0eE0>PAUD4X4
FdY414Tf<@@d9B44>RPW13lY8`=1<bh4<RPT128I6P@P5QL4;b@X12XP8`<d:RH4:b4W144b;0@S7204
D3lg13l`;`@m;RX3=RXW13@X90@h:bT4@38]13TZ9`AO@CD3KE1617aCB@BTT912[j:N5Oooo`005?oo
ocZ_XYh4ME1213hU7PA0;b/3ED0j16E@BPAKBT@4BCHa13@U8@@j:2L4?bTS0d4c;P@b:2@48QTJ120F
5`@_92P4:R0S0c@Z9P@[8BL4@C8/12<L80A@?cL4?c0_13d^:P<f:RL4=2PT13P[:@A0<Rd4>BXW15m1
=@=]D4H4O5=91:B@T4:_XYhEoooo000Doooo>ZnRWPAeD484?RDN140_:`=E@3X4IE1:15]:A0A9=S44
=2DQ13XX9`@o:B<3@C<^138X90@R6AX481HG12lT:0@Z82<3=2XV12/Q9`A1<R`48a`P150o=`@o<2l4
?BhZ0cHZ9`@d:2@4>2/Y140b;@@i:RL4Gd4e0fe@APAlDdT4Y92@@ZnRWQGoool001Cooolj[j:N17E@
@P@n9Ah4@2l[0eE0>PAUD4X4FdY414Tf<@@d9B44>RPW13lY8`=1<bh4<RPT128I6P@P5QL4;b@X12XP
8`<d:RH4:b4W144b;0@S7204D3lg13l`;`@m;RX3=RXW13@X90@h:bT4@38]13TZ9`AO@CD3KE1617aC
B@BTT912[j:N5Oooo`005?ooocj_XYh4MEU<13@E1P<e9Al4DCdh161<A@ANDe<4E3dd148b<0A3<Rl3
?2XX13lh=0A5=SL4=RTT12hR9@@g;SH3@34]14Ll@0A2<BX4?Rl]14dm>@A@>SH4C3@`0d`e:`A6>3@4
Dcde1617>`A4<RX4SFiR0heTEPB_Wi]6[j:N5Oooo`005?ooocj_XYh4MEU<13@E1P<e9Al4DCdh161<
A@ANDe<4E3dd148b<0A3<Rl3?2XX13lh=0A5=SL4=RTT12hR9@@g;SH3@34]14Ll@0A2<BX4?Rl]14dm
>@A@>SH4C3@`0d`e:`A6>3@4Dcde1617>`A4<RX4SFiR0heTEPB_Wi]6[j:N5Oooo`005?ooocj_XYh4
MEU<13@E1P<e9Al4DCdh161<A@ANDe<4E3dd148b<0A3<Rl3?2XX13lh=0A5=SL4=RTT12hR9@@g;SH3
@34]14Ll@0A2<BX4?Rl]14dm>@A@>SH4C3@`0d`e:`A6>3@4Dcde1617>`A4<RX4SFiR0heTEPB_Wi]6
[j:N5Oooo`005?ooocj_XYh4MEU<13@E1P<e9Al4DCdh161<A@ANDe<4E3dd148b<0A3<Rl3?2XX13lh
=0A5=SL4=RTT12hR9@@g;SH3@34]14Ll@0A2<BX4?Rl]14dm>@A@>SH4C3@`0d`e:`A6>3@4Dcde1617
>`A4<RX4SFiR0heTEPB_Wi]6[j:N5Oooo`005?oood:_XYh4WHN70ehj=@@e8A`4CS`d14i7C0AbGUT4
HTi9169@B0=HAT<4CD1115=4A@ANCD`4CC`h14dm?P=1<C@4AcHb14ll>@AA?ST4C3Td15dk<PAI?3D3
Ecdd15U2>`AB=bh4N5aD1798<@AhEda=[j:N5Oooo`005?oood:_XYh4WHN70ehj=@@e8A`4CS`d14i7
C0AbGUT4HTi9169@B0=HAT<4CD1115=4A@ANCD`4CC`h14dm?P=1<C@4AcHb14ll>@AA?ST4C3Td15dk
<PAI?3D3Ecdd15U2>`AB=bh4N5aD1798<@AhEda=[j:N5Oooo`005?oood:_XYh4WHN70ehj=@@e8A`4
CS`d14i7C0AbGUT4HTi9169@B0=HAT<4CD1115=4A@ANCD`4CC`h14dm?P=1<C@4AcHb14ll>@AA?ST4
C3Td15dk<PAI?3D3Ecdd15U2>`AB=bh4N5aD1798<@AhEda=[j:N5Oooo`005?ooo`B_YJ44[jNS@JnR
WPAeFET4@1HA13@H4`A6>3P4NFEM16iOF`=MBch4He1:16ADC`AWDT`4Hda915U6?P=>?c`4Cc/h14@f
<0AE@T04FD@n158k<`AR@ST3EcPb18i/HPAQ<AX4DaX@18e`KE6_XYhEoooo000Doooo1:nUX@B_Yj=1
[j:N17EIF@A05Q44=1PC14Hh>0AiIEd4KUmK0ee;?PASD4X4I5A?16MBC0ASC4T4FDHn0dho?0A?>cP4
A3H`15E2@0AIA3h4DS/c1692>@=G>384SVaR164a6PAC6Q04SG1]DJnRWQGoool001Coool4[jFQ1:nW
Xd6_XYh4MEUI140F4@@d61<4ASPh17UUG@A^Ge/3GD/n16=@BPATE4l4Ie9<16=<B@AIASh3CSll14lk
>0A4=S04ED9015U4?PAB>c<4HT8i0eLh<PB>K684HC4J15<J40B=L6eA[j:N5Oooo`005?ooo`B_YJ44
[jNS@JnRWPAeFET4@1HA13@H4`A6>3P4NFEM16iOF`=MBch4He1:16ADC`AWDT`4Hda915U6?P=>?c`4
Cc/h14@f<0AE@T04FD@n158k<`AR@ST3EcPb18i/HPAQ<AX4DaX@18e`KE6_XYhEoooo000Doooo1:nJ
UPB_Wi]9[j:N1:JDU@A_DU`4FcDi17IBF0=fEEL4L4Th15Ph;0AG@cT4L5QC175DB@=^ETl4KeM@16]D
B`ATCdL4JDe116QCA`B7KF@3?142168e<`BNQHEI[j:N5Oooo`005?ooo`B_VYH4[inKBJnRWPBVU9D4
Ke9L15/e>@AfDUP3MUEG1719>0AH>2`4Ed<i171HD`AaE4T3KUI?16mGD0A[E4/4I4m716U=@@AXDdL4
QfeT0c`A0PAR=C<4WXF5FJnRWQGoool001Coool4[iZF1:nOVdV_XYh4YYBE16mBG0AK=CT4MU9H0gIE
E`A`BCP4F3P/15M3>@A`F5<4LEA90fiFC`A_Ee04JeA;16A?A`AYCD44J5=718M]I0<l4@84HSDc19j5
QEV_XYhEoooo000Doooo1:nJUPB_Wi]9[j:N1:JDU@A_DU`4FcDi17IBF0=fEEL4L4Th15Ph;0AG@cT4
L5QC175DB@=^ETl4KeM@16]DB`ATCdL4JDe116QCA`B7KF@3?142168e<`BNQHEI[j:N5Oooo`005?oo
of6_XYh3YYBJ1:RCUPBMPhP4L55M15PhA0AD;Rd3DBTN154[80AA9a`4C28G14DF1PA24`04Of5F0jnO
Vf6_XYhEoooo000DooooHJnRWP>VU9X4Z9>F19f3R0A`DEd4F3Q415@^;@=A:Ah4DB/P154W70A<8QL4
AAH6148C00AoHEH3[inKHJnRWQGoool001CooomQ[j:N0jJDVPBXTiH4WH>8171AG@AH>4@4E2h]0e4Y
7PAA:b04DBLL14`R5`A55PH4@Q<017mQEP>_Wi]Q[j:N5Oooo`005?ooof6_XYh3YYBJ1:RCUPBMPhP4
L55M15PhA0AD;Rd3DBTN154[80AA9a`4C28G14DF1PA24`04Of5F0jnOVf6_XYhEoooo003ooooo8Ooo
o`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Ooo
o`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo002Ioooo0`00
08Coool009coool00`000?ooooooo`21oooo001loooo0P0000Coool200001?ooo`800004oooo1000
00;oool300000oooo`<00003oooo0P0007koool007_oool010000?ooooooo`0000;oool010000?oo
ooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool00`000?ooooooo`03
oooo00@0003oooooool00023oooo001moooo00<0003oooooool00oooo`050000oooooooooooo0000
00;oool010000?ooooooo`0000;oool00`000?ooooooo`0400000_ooo`040000oooooooo0000Pooo
o`00O_ooo`030000oooooooo00?oool010000?ooooooooooo`800004oooo0`0000?oool200001?oo
o`@00022oooo001koooo00@0003oooooool00002oooo00@0003oooooool00002oooo00@0003ooooo
ool00005oooo00<0003oooooool0SOooo`00O?ooo`800004oooo0P0000Coool200001Oooo`80002?
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "After removing the needless variables, checking the used memories reveals \
that a relatively large amount of memories are used.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
Remove[\"color3D\",\"zcolor3D\",\"zSpect\",\"incColor3D\",\"incColor3DG\"];
memoryUsed\
\>", "Input"],

Cell[BoxData[
    InterpretationBox[\(8347\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ 8347, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4.4.3 Illusive image",
  FontFamily->"Times New Roman",
  FontSize->12]], "Subsection"],

Cell[TextData[{
  "\t",
  StyleBox[
  "Similar to those of the previous section, we work out the 8 illusive color \
images by means of the function \"illusion3D\". Figure 15 shows the 8 \
illusive color images.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["illusion=illusion3D[sample,rotation];", "Input"],

Cell[CellGroupData[{

Cell["\<\
illusionG=Table[Show[convertRGB[illusion[[i]]],
\tPlotLabel->StringForm[\"``deg.\",360*(i-1)/rotation],
\tAspectRatio->dim[[2]]/dim[[3]],DisplayFunction->Identity],
\t{i,rotation}];
Show[GraphicsArray[
\tTable[Table[illusionG[[i+j]],{j,0,3}],{i,1,rotation,4}]],
\tImageSize->{400,200},PlotLabel->\"Fig.15. Original illusive images\"];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .48837 
%%ImageSize: 400 200 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0116279 0.238095 [
[.5 .50087 -98 0 ]
[.5 .50087 98 12.5625 ]
[ 0 0 0 0 ]
[ 1 .48837 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50087 -159 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.813 moveto
(.15) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Original) show
165.000 12.813 moveto
(illusive) show
219.000 12.813 moveto
(images) show
255.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .48837 L
0 .48837 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0116279 0.245293 0.233112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(180) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
988F8C988F8C988F8C988F8C988F8C988F8C988F8C988F8C978F8C978F8C978F8C978F8C
978F8C978F8C978F8C978F8C968E8C968F8C968F8D968F8D968F8D968F8E96908F969191
958F8E968E8C968E8C968E8C968D8B968E8B968E8B968E8B968E8C978E8C978E8C978E8C
978E8B978D8A978D8A968C89968B88968A87958A87958986958885958884948783938581
91827E938682948784958885958986958A87968A87968B87968B88968C89978C89978D8A
978D8A978D8B988E8B988E8C
988F8C988F8C988E8C988F8C978F8C978E8C978F8C978F8C978E8C968E8C968E8C968E8C
968E8D958E8D958E8D958E8D958E8C948E8D948E8D948E8D938F8E938F8F939090949293
938F8F938E8D938D8B948D8B948C8B948D8B958D8B958D8B948D8B958C8B958C8A958C8A
958C8A958B88958A8794888694878493868392858192838092827E91807C907E7A8E7D77
8D7B768F7E7990807C91827E92847F928581938682938783948784948885958986958A87
968B88978C89978D8A988E8B
988F8C988F8D978F8C978E8C978F8D978F8C968F8C968F8D968E8C958E8D958E8C958E8D
948E8D948E8D948E8D938E8D938E8D928E8D928E8D918E8E918E8E918F8F909091909193
908E8F908D8D918C8B918C8B928B8A928B8A938C8B938C8B928C8B938C8B958B8A958B89
958A8894898794888693858392838090817E8F7F7C8E7E7A8E7B778D79748B77718A746D
8A756F8B78728C7A758D7C778E7E798F807B90817D91827E928480928581938783948885
958986968B88978C89978D8B
988F8C988F8D978F8D978E8C968F8C968F8D968F8D958F8D958E8D948F8D948E8D938E8D
938E8D928E8D928E8D918E8D918E8D908E8D908D8E8F8D8E8E8E8E8E8E8F8D8F918E9093
8D8D8F8D8C8C8E8B8B8E8A8A8F8A8A908B8A928B8B938C8C938D8D938E8C958C8C948A89
94898794878593858392828090807D8F7D7A8D7B778B78748A757089726D876F68856B63
866E6787716B89746E8A76718B79738C7B768D7D788E7F7A8F807C90827E918480938682
948884958986968B88978D8A
988F8C978F8D978F8D968F8D968F8D958F8D958F8D948F8D948E8D938E8D938E8D928E8D
928E8D918E8D908E8D908E8E8F8D8E8E8D8E8E8D8E8D8D8E8C8D8E8B8D8F8A8D908A8F92
8A8C8E8A8B8B8B8A898C89898D89898E89898F8A89908B8A918C8B918C8B928C8B928A89
92888692868392838191817E8F7C798D79758B767288736E866F69856B6583686181645C
826860846B64856E6786716A88736D8976708A78738C7B768D7D788E7F7B90817D918480
938682948885958A87978D8A
988F8C978F8C978F8D968F8D958F8D958E8D948E8D948E8D938E8D928E8D928E8D918E8E
908E8E908E8E8F8E8E8E8D8E8D8D8E8C8D8E8B8C8E8A8C8E898B8D888B8D868B8E868B8F
868A8C87898A8888898988878A87878B87878C88878D88888E88888F89898F8988908887
8F85838F83818E807D8E7D7A8C79768A747088716C856D6882696381655E7E61597E5F57
7F625A80655D826861836B64846E6886716B87746E8977718B79748C7C778E7F7A90817D
918480938783958986978C89
988F8C978F8C968F8D968F8D958E8D948E8D938E8D938E8D928E8D918E8E918E8E908E8E
8F8E8E8E8E8E8D8D8E8D8D8E8C8D8E8B8C8E898C8E888B8E868A8D84898C82878A818689
8387898487888586878686868786868885868985858A86858A85858B85858B84848C8383
8C81808C7F7D8B7C798A797589747187706C846B668167617F635C7D5E567959507A5A50
7B5C547C5F577E635B7F665E816962836C6685706986736D8876708A79748C7C778E7F7B
90827E928581948885968C89
988F8C978F8C968F8D958E8D948E8D948E8D938E8D928E8E918E8E908E8E8F8E8E8F8E8E
8E8E8E8D8D8E8C8D8E8B8D8E8A8D8E898C8E888C8E868B8E858A8D81888B7A82867D8487
808587818587838586838485848384858484868383868282878282878181888080887E7E
877C7B87797886767486747184706C826B668067617E625B7A5D5578584F75524776544A
77564D7959507A5D547C60587E645C806860826B65846F6986726D8876718A7A758D7D79
8F817D918480948884968B88
978F8C978F8D968F8D958E8D948E8D938E8D928E8D918E8E908E8E8F8E8E8E8E8E8E8E8E
8D8D8F8C8D8F8B8D8F8A8D8F888C8F878C8F868C8E858B8E848B8E828A8E767F847B8286
7E83857F8485808384818384828282828182838182848081847F80847E7E847B7C847879
83767683747382716F816E6C806B677E66617C625C7A5C5576564E735147704A3F724D42
73504575534976574E785B527A5F577D635B7F6760816B64846F6986736D8977728B7B76
8E7F7B90837F938783968B88
978F8C968F8D958F8D948E8D938E8D928E8D918E8E908E8E8F8E8E8E8E8E8D8E8F8C8E8F
8B8D8F8A8D8F898D8F888D8F878C8F868C8F858C8F848B8F848C8F80898C7B84877B8386
7C82857D82847E81827E81827F80817F7F80807F80817F7F817E7E817C7C817879817576
8071727F6E6E7E6C6A7D69677B656279615C785C5776585173524A704C426D44396D4539
6F493E714D4272514775554C775951795E567C625B7E6760816B6584706A87746F8A7974
8C7D798F827E928682958A87
978F8C968F8D958F8D948E8D938E8D928E8E918E8E908E8E8F8E8E8D8E8F8C8E8F8B8E8F
8A8D8F898D8F888D8F878D8F858C8F848C8F838C8F828B8F808A8E7E888C7C85897B8386
7B82847B81837B80817C7F7F7C7E7F7D7E7E7D7D7E7E7D7E7F7D7E7F797A7F75777E7173
7D6D6F7C696A7B676779646277605E755C5873585272534C704E466D483E6A4035683D31
6A42366C463B6E4B40714F4673544B765951795E567B635C7E6861826D6785726C887772
8B7B778E807C928581958A87
978F8C968F8D958F8D948F8D928E8E918E8E908E8E8F8E8E8E8E8F8D8E8F8B8E8F8A8E8F
898D90888D90868D90858D90848C90828C90818B90838D927D888C7C868A7B85887A8386
7A8284798182797E80797D7D797C7C7A7C7C7A7C7C7B7B7C7D7E7E7D7B7C7D78787C7474
7B707079696978646475605F735C5A7158556F544F6D50496C4B436A463C68403465392D
65392C683F336A44396D4A3F6F4F4572544B755A51785F577C645D7F6A63836F69867570
8A7A758D7F7B918481958A86
978F8C968F8D948F8D938F8E928E8E918E8E8F8E8E8E8E8F8D8E8F8C8E8F8A8E90898E90
888D90878D90858D90848D90828C90818C907F8B90758388788589798589798487788386
788285788183777E7F767B7C767A7B767A7B777B7B787B7B7A7D7D7B7F7E7B7C7B7B7A79
7A7674776D6B756564725E5E6F59576D55526B514B694D4669494168453B663F34643A2D
62352864392C663E326844396B493F6E4F4672554D755B5379615A7D6760816D6785726D
8978738C7E79908380948986
978F8D968F8D948F8D938E8E918E8E908E8E8F8E8F8D8E8F8C8E8F8B8E90898E90888E90
878E91868D91848D91828D91818C917F8B917E8B90758389768489768488768387778487
778386778183757E7F73797A73787A73787A717879777F7F7A7F7F7D82827D81807C7B7A
7A7977777371736B696D5F5E6B5655685250674E49664A4466473F65443A643F3462392D
5F33265F322561382B643E3267443A6A4A416E504872574F765D567A645D7F6A6483706B
8776728B7D7890837F948985
978F8D958F8D948F8D928E8E918F8E8F8E8F8E8E8F8C8E8F8B8E908A8E90888E91878E91
868E91858E92838D92818D917F8C917E8D9372838A738389748389758489758286768487
778588778386758081727B7B6E7778768080757F7F7781817981817A80807C82817D7F7D
7E7C7B7C777578716F6D6462665755644F4D634B4762474163453E63433A623E3460392D
5E34275C30225C32265E372C623E3466453B6A4C436F534B735A5378615A7D6861816E69
8675708A7B778F827E948885
978F8D958F8D938F8E928F8E908E8E8F8E8F8D8E8F8C8E908A8E90898E91878E91868E92
858E92848E93828E93808D927D8B917D8C936C7F87708188728388738489748488758588
76868A7786897684857782826F787872797A747B7B757B7A767D7C787D7B797C7B797776
7A76747B74707C7370776B686B5E5C604F4D5E47445E443F60433C614239613E345F392E
5D33275B2F20592F215931255C372D61403666483F6C4F4771574F765E577B655F806C67
85736E897A768E817D938885
978F8D958F8D938F8E918F8E908E8F8E8E8F8C8E8F8B8E90898E90888E91868E92858E92
848F93848F94838F94808E9377878D75868D6F80886F8288718288728288728388748589
76888C77878B78898A7A8989748383737E7F737D7D737B7B747B7B767A7A767A79767573
777270766E6B776E6B76686472625E6555515B46425B423E5D413A5F41385F3E345D392E
5B34285A2F21582E1F572F225732285D3B3163433A684C436E534C735B5479635C7E6A65
83726D8879758E807C938884
968F8D958F8D938F8E918F8E8F8E8F8D8E8F8B8E8F8A8E90888E91868E91858E92848E93
838F9483909584929786949B7B8C926F838A70828A6F82896F838970828970838972858A
74878C748588728183738284728282728181738080738080748180767F7E767E7C767B79
76777374706D746D6973686371615D6B5A555E4A4659413D5B403A5D40385E3E345D392E
5A3428592F22552A1C4E271A532E2359362C5F40366548406B504971595276615A7C6863
82706B8778738D807C938784
968F8D948F8D928F8E908F8F8E8E8F8C8F908A8E90898E91878E91858E92838E92828E93
828F948290968594998B999F85949975878E70838A6E82896D83896E82896E828970858A
72878C7285896E7E816E7D7F6F7E7F6F7E7F707E7F717E7F727F7F737E7E737C7B737977
72757271716E6F6D686E69646D645F6B5E5864544E5C47425A423B5C40395D3E355C3A30
5A352A593125592F224A24184E2A1F5533295C3C3362453C684E466E564F745E587B6761
806F6A8677728C7F7B928784
968F8D948F8D928F8E908F8F8E8E8F8C8E908A8E90878E91858D91838D92828D92808D93
7F8E947F8F958091977F8F967B8C9373868E6E82896B80886B81886B82886C82896D848A
6F858B6F84886C7E816A797C6B7A7B6C7B7D6D7C7D6E7C7D6F7E7E717D7D717A7A707675
6F73716E6F6C6B6A67696561685F5B655A5461524C5D4A455B453E5B423A5C3F365B3A31
59362B5933265830224722174B271D5130265839305F4239664B436C544D735C5679655F
7F6D688576718C7E7A928783
968F8D948F8E928F8E908F8F8D8E908B8E90898E91868E91848D92828D927F8C927D8C93
7C8C937A8C93788C9476899072848C6E8088697E87687D85687E85687F86688087698188
6B83896B81876A7E8268787B68777969787A6A7A7B6C797B6D7B7C6E7C7C6E797A6E7575
6D70706C6D6B69686566635F645D5A6258535F524C5C4A455B46405A433C5B40375A3B32
5A372D5A35285B32244520144623184E2C2255362C5C3F376349416A524A715B5477635E
7E6C678575708B7E7A928683
968F8D948F8E928F8F8F8F8F8D8F908A8E91888E91858D91828D92808C927D8C927A8B92
788A9276899273879070848D6C8088697C84667B83657A82647A82647C83657D84657E85
668086677F85677D8265787C64747766767867797B69797B6B797B6C7A7C6C78796C7575
6A706F696C6B66666463605E605B585F57535D524E5B4C475A484259443D594038593C33
59382E5A362A5E3527492317421E134A281E5233295A3D3461463E6850496F595276625C
7D6B6684746F8A7D79918683
968F8D948F8E918F8F8F8F908C8F908A8E91878E92848D92818D927E8C927A8B92778A92
7488917187916D828C6A7F8865798363788161788061777F60777F617880617A82617A82
627C83637C83637B8162777C61737762747764767866767968777A6A787A6A7678697273
676E6E656A69626463605F5C5C59565B54515A504D594C4858494357453E574039573C34
57392F59372B5F382B562E20472115452218503027583B325F443C664E476D575174615B
7B6A6583736F8A7C78918682
968F8D948F8E918F8F8F8F908C8F91898F92868E92838E937F8D937C8C93788B92748992
7087916C838E677D886378835E747E5B747E5C747D5C747D5C747D5C757D5D767E5D767F
5D777F5E777F5F777D5F757B5E7377607376617477637477657578677578677476666F71
646B6C6166675E62615B5C5B595654575350564E4B564B4756474255433D543F38543B33
54372E55342A573429563024522B1E4C291F5030275639315D423B644C456B564F725F5A
7A696482726E897C78918582
968F8D948F8E918F908E8F918C8F92898F92858F93828E937E8D937A8C93768A93718992
6C879267828E627C875C737F59707A57707A57717B58717B58717B58727B58727B59727B
59737B5A727B5A72795A70775A6F755C70765F7377617377637578657578657375636E70
61696B5D64655B5F60585A5A55555454514F524D4A534A4652464251423D503E38503933
4F352E4F31294F30264D2A1F4A24184B281E4E2F2554372F5B4139624A4369544E715E58
79686380716D887B77908582
968F8D94908F9190908F90918C9092899093858F94818E947D8D94798C94748B946E8892
68859061808B5A7884546F7B516B77516C77526D78536E79546F79546F78546F78546F78
546E77546D76546D75556B73566B71586D735B70745E7276617478637478647174626D70
5F686A5B6364575D5E545757515252504E4D4F4B494E48454E45414D413C4C3D374B3832
4A342D492F27492D2547261C4320154523194B2B2251352D583E375F484267524C6F5C57
7766627F706C887B77908581
968F8E94908F9190918F91928C9193899194859095818F967D8E96788D96738B956C8995
64828D5979864F707D4968764967744B68744D6A754F6B76506C77516D77516D77506C76
4F6B754E69734F68714F677051686E546A70586D725B70755E73776174786271745F6C6F
5C6668596062545A5C5055564E50504C4C4B4B49474A46444A434049403C483C37463731
45322C432D26422A224022193F1E14401D1346281F4D322A543C355C464065504B6D5B56
7565617E706C877A76908481
96908E9490909291928F92938C92958992968691978190977D8F97788E97728D986D8C98
64838F557684486B7A3D61704162704565724867744B69754D6B764E6C774E6C764C6B75
4B697449667048636D49626B4C636B4F666D546A70596E745D72775F73776070745D6B6E
5A6567555E6051585A4D53544A4E4E474A4A46464545434145403E443D3A433A35423631
40312B3E2B253D2922391F17381C133A191041241C492F2851393359443E624F496B5955
7464607D6F6B8679768F8481
97908E9591909392929093948D93968A93978693988292997D9199778F99728E996E8D9A
688694577785456978375D6E3B5E6E4062704465724868754B6A764B6A754B6A75486772
45657043626E425F6B445E68465E674B616951676E576D735C72775F73785F70745C6B6E
596567535D604E57594A5253464C4D434848424444414040413E3C413B393F38343E3430
3C302A3A2B26382722321D1730171033150D3C211A442C254D373156423D5F4D48685853
72635F7B6E6A8579758F8481
97908F9592919493949194968F95988C959A88959B83949B7D929B77909A718E9A6C8B97
6584925274833F667630596B365C6C3B606F4063714568754B6C784E6E7A4E6E794C6C77
4567733F626E3D5E6A405E68425C65465D654F666D556C735B72785F74795F71765C6C6F
586567525D5F4F585A4A5254454C4D4046473E42433C3E3E3C3C3B3D3A373C36333A332F
382F2A372B263527222F1F192B15102D120B361E183F292449352F52403B5C4B47665652
70625E7A6D698478758E8481
97918F96929295949593969891979A8E989C8B989E86979E7F949D76909B6E8D9A6A8995
6885925476853E65762C5669325A6C385F6F3D6271436775496C7950717E54747F587580
51707B48697542646F42646E46636C49626A4F676E556D745B737A5F757B6072785D6C71
596669505B5E4E575A485153414A4C3B43453A4041373C3D3839393937363A353338322E
352E2A332A26302521271C1824140F27100B311C163A272244322D4F3E39594945635551
6E615D796C698378758E8380
98918F979393969696959899949A9D929B9F8F9CA28A9BA28298A176919C648492638391
62818E5274833B64762854682F586B355D6E3B6171406574466A774D717E5274805A7883
5B788356747F4F6D774969734966704B656E506870556D755B737A60767C62757A617075
606D70586265535D604C5658404B4F3C454838404233393C34373836353539353337322F
342E2B322A262B24202018151A0F0C200D092B1814352420402F2C4B3B38564744615350
6C5F5C776B688277748D8380
989290989494989898989A9C979DA0969FA394A1A791A2A98AA0A87C97A26687955A7D8B
577A894A6F803862742653672D576A335C6D3961723E6373436775496D7B4F7380547683
54768253737F4F6F7B4B6A764A68724C6871506A72566F765C747B60767D63767C637377
616F7160686A6066675E62624D5457474C4E4347493A3F41393C3D3939393A3735383331
35302D322B2827211F1B1614130A081808042414112F201D3B2D2A4739365246435E524F
6A5E5B766B688177748D8380
9993919A96959A9A9A9B9D9F9BA0A39BA4A89BA7AC9AABB19BB0B888A1AA75949F638592
587B8A476E7F3761742552672B5669315B6D3862723E6676426877456A78496E7C4C717F
4D72804C707D4A6D7A486A764867734C6A74516C755670785C747C61767D63777D637278
616E725E696B6067686467675D60605557574E4F504547484041423D3C3C3B39383A3533
37312F342E2B25211F1815140F0A091204021D100E291D1B362A284337344F44415C514E
685D5B746A678076748C8380
9A93919B97979C9C9C9DA0A19FA4A7A0A9ACA1ADB2A3B3B9A7BAC193AAB37E9AA56C8C99
5C7F8D4870813561742453682754682F596C355F703D6676456C7C49707E4D72804F7583
5378865377845174824E717D4D6D794E6D77526E7856717A5B747C60767E64787E64747B
606D735C676C5B65675B6163585E5F56595A505353474B4C4345453F3F3F3D3B3B3A3736
393331342E2C2321201414150F0D0C0C0201160C0B2319183127253F35334C4240594F4D
665C5A7369678076738C8280
9A94929C99989E9E9EA0A2A4A3A8AAA5ADB1A8B3B8ABB9BFB0C1C89FB3BB8AA2AC75939F
6183914B72833662752554692553672B5769325C6D396272406979476F7E4D74824F7785
5279885379875378865075824F707D4F6F7A52707A55727A5A747C5F767D64797E697A7F
67757A606B71596468545D62525A5D5156594D5153484B4D4446474141413E3D3D3E3939
3C3635342E2C2221210F13140B0B0C0600000903031C15142C24233B333249413F574E4D
655C5A7269677F76738C8280
9B94939E9A99A1A0A0A3A5A6A6ABADAAB1B4ADB8BCB1BFC4B6C7CDA7BAC293AAB47E99A5
69899750768739647727566B2452662854672E596A355E6E3B6373416878456D7C497080
4B73824C73824D73824D72804D717E4E6F7B51707A54717B58727B5C737B61757C66777D
6B787C6B7479676E725C6468535B5E4D54584A5053474B4D444748424343424040413D3C
413A39332F2E2221220F1417060B0D06040505010317121328222238313147403F564E4D
645B5A7168677E75738B8280
9C95939F9B9AA3A1A1A6A8A9AAAEB0AEB5B8B2BCC0B7C3C8BDCCD1AEBFC69CB1BA859FAA
6F8E9B567B8B3E687B29586D2251662551652B556731596A365E6E3B62723F6675436A79
456D7C476E7D486F7E496E7D4A6E7C4C6E7B4F6E7A526F7A5570795870785C7178617278
657378677276687073666C6E616668595E605457594F51534C4D4E474748454343434040
433D3C353131242525151A1C080E11030608010104131112252122363131453F3F544E4D
635B5A7168677E75738B8280
9C9594A09C9BA5A3A3A9AAABADB1B3B2B8BBB7C0C3BCC7CCC2CFD5B2C2C9A2B5BE8CA5B0
7593A05C7F8F446C7F2D5B70225166224F632752642D566732596A365D6D3A61713D6473
406776426978446A7A456B7A476B79496B794B6C784E6C78516C76546D76586D755B6E74
5F6E73616D72636C7062696C6065685D6164595C5D5356574F50504B4B4B494746474342
433E3C3633332828291B1E200D121503080B0002040F0E10232022343131454040544E4D
625C5A7069677E76748B8280
9D9694A29D9CA6A4A4ABACADB0B3B5B6BBBEBBC3C7C1CBD0C6D4D9B7C7CDA7BAC293AAB5
7C99A66285954A72843360742352681F4D61244F622A53642E5666325969365D6D396070
3B62723E64744066764167774368774569764869764A69754D69744F6972536972566971
596A705B696F5C676C5D65695B6366595F62575B5D5356584F51524C4D4D4B4949494645
413E3E353434292A2C1D2023111619060C1002070A0E0F11232223353233454141544F4F
635C5B7169687E76748B8280
9E9695A39E9DA8A6A6AEAEAEB3B6B7B9BEC0BFC6CAC5CFD3CCD8DDBCCAD1ACBEC699B0BA
84A0AC6C8D9B53798B3B677B2A586E1F4E63224D612750622B53642F5565325868355C6C
375E6E3961713B62723D64733F65744165744366744666724865714B65704D656F50656E
53656D56656C576369576166576064565D6055595C5356585152534F4F4F4E4B4B4B4746
43403F3737372C2D2E212427161B1E0C1317080D11111316252527373536464343555150
635E5D716A697E77758B8380
9E9795A49F9EAAA7A7B0AFB0B6B8B9BCC0C3C3C9CCC9D2D6CFDBE0C0CFD5B0C2CA9FB5BF
8BA6B17493A15A7F90446D80315E73245267224D61254E612951622C53642F5565315768
335A6B355D6E375F703960703B61713D62713F637141636F43626E45616C49616C4B616B
4E6169516169526067535E64535D61535B5F53585C525558515354504F504F4D4D4B4847
4240403938392E303125282A1B1F2212181C0F14181B1D202A2B2D3A383A494646575353
655F5F726B6A7F77768C8381
9F9795A5A09EABA8A8B2B1B1B8BABBBFC3C5C6CCCFCDD5D9D4DEE2C5D2D8B5C6CDA5B9C3
92ABB77C9AA86487974B758736647829576C234F63234E61264F612951622C53632E5465
30576731596A335B6C355C6D365D6D385E6D3B5F6D3D5E6C3E5E6B405E6A435E69465E68
495E674C5E664D5D644F5C62505B6051595E51585C515558505455515152504E4E4A4848
4342423A3A3B313334272A2D1E2225151B1F1015192123262F30323E3D3E4C494A595555
676161736D6C8078778C8481
9F9895A6A09FACA9A9B3B2B2BBBCBCC2C5C7CACFD2D2D9DCDAE3E6CAD6DCBBCAD1ABBEC7
9AB1BC85A1AE6D8E9E557C8E3E6A7E2D5D72235166224D61244E61274F612950622B5162
2C53642E55662F576831586932596A335A6A355B6A375A683859673B5A663E5A65415A65
445A64475A634A5B624C5A614D595F4E585D4F575B5055584F53564F50524D4D4F484849
414243393B3C313436282C2F1F2528191F23171B1F27292C3535374241434F4D4D5C5858
696363756E6D8179788D8482
9F9896A6A19FAEAAA9B5B3B3BDBDBEC5C7C8CDD1D3D6DCDFDFE7EBD1DCE1C2D0D6B2C3CC
A1B6C18DA7B37695A45F849547728535637826556A224E63234E61254E61264F60284F61
2951622A52632B54652D55672E57682E56673056663155653355643555633856633C5662
3F576142576145576048575F4A585E4C575C4E565A4F55594F53564D50534B4D4F47484A
4143443B3D3E3336392B2F3223282C1E232724272B2E30333B3B3D4746475351515F5B5B
6B666576706F827A798D8582
A09896A7A1A0AFABAAB6B4B4BEBEBFC7C8C9D0D3D5D9DFE1E3EBEED9E3E7C9D6DCB9CAD1
A9BDC796AEBA7F9DAB698B9C537B8D3F6C802D5C72245166224E62234E61244E60254E61
264F612650622750622752642953652953642A52632B52622C51602F516032525F365360
3A535F3D545F41545E44555E47565D4A565C4D565B4F565A4F54574D51534A4D4F45484B
4043463B3E4034383B2C313423292D1C21252A2D303537394141434C4B4C575555635F5E
6D6868787271837C7A8E8583
A09896A8A1A0AFABAAB7B5B4C0BFBFC9C9CAD2D5D6DCE0E2E7EDEFE0E8ECD2DDE2C2D1D8
B1C4CDA0B6C08AA5B27595A46185964D768939667B29586E235166224E63224D61224D61
224D60234D61234E61234E62245063245063244E61254E5F274D5E294D5D2C4E5D304F5D
35515D38525D3D525D41535D44555D48555C4B555B4F565B4F54584D52554B4E51464A4C
4044483B4043353A3D2E3437292E3223272B3133363C3D3F4746485150515C5959666262
706B6A7A7473847D7B8E8684
A09896A8A2A0B0ABAAB8B5B4C1BFBFCACACAD3D5D6DEE1E3EBEFF2EAF0F3DBE4E9CBD8DE
BBCBD3ABBFC897AFBA829EAC6F909F5C82934A73873763792B596F245268224E63224E62
204C601F4B601F4B601F4C60204D611F4D611D4B5E1E495C20495B234A5B274B5B2B4C5B
304E5B344F5B39515C3E525C43545D48565E4B565C4F565C50565A4F53574C5053484C4F
43484B3F4346383D4130373B2D3337313437393C3E4344464D4C4E565555605D5D696565
736E6D7C7675867E7C8F8784
A09896A8A1A0B0ABAAB8B5B4C1BFBFCACACAD4D5D5DEE1E2EAEEEFF0F6F8E4ECEFD4DFE4
C4D2D9B4C6CFA2B8C38EA8B47D9AA86C8D9D5D81924B73863C677B315E7329566B265267
214E631E4C611D4B601D4B601E4C611D4C611B4B5F1A485C1B475A1E4759224A5A274B5A
2B4C5B2F4D5B364F5B3C525D41545E47575F4C585E4F585E50575C5055594E53564B4F52
464B4E42474A3C4145363C3F2F3437393C3F4243464A4B4C5352535C595A6461616D6968
76706F7E7876877F7E908785
A09896A8A19FB0ABA9B8B4B3C1BEBECAC9C9D4D4D4DEDFE0E9EBECF4F7F9EFF4F7DFE7EC
D0DBE1C0CFD6AFC2CB9BB2BD8BA5B17B99A66D8D9C5E8192507688446C7F3A6478335E71
2D586C275469235066224F64235065204F651E4E631D4B601B4A5D1C485C204A5C254B5C
2A4D5D2F4F5D34505D3B535E4256604959614D5A61525B61535A5E53595C5256594F5356
4B4F52484B4E43474A3D41453B3D404344474A4B4D525152595858615E5F696565716C6B
797372807A7888817F908885
A09895A8A19FB0AAA8B8B3B2C0BDBCC9C7C7D3D2D2DDDDDDE7E9EAF4F6F7F7FAFDE9EFF2
DAE2E7CBD7DDBCCBD3AABDC699AFBA8AA3AF7C98A56D8C9B5F81925578894D7182456B7C
3D6578366073315C702C586C2C586C2A566A275468245166224F63214D61244D60284F60
2C50603252613753603E56624559634C5C64505D64545E63565D62565C60565A5D53575A
5053564E50534B4D4F44484B484A4C4D4D4F5252545957595F5D5E6663636D6969746F6E
7B7574837C7A8A8280918886
A09795A7A09EAFA9A7B7B2B1BFBCBBC8C5C5D1D0CFDBDBDAE5E6E6F1F2F2FAFDFEF4F8FA
E4EAEED5DEE3C7D3D9B6C5CDA7BAC397ADB78BA3AF7D98A5708F9D6686955D7E8E567887
4F7283476C7D43697B3D64763A6174375F71355D70325A6D2F596B2F5769315668345767
3758673B5A67415B67475E684C5F685361685662685A62675B61655B60635A5E60585B5D
55575A5456585152555152545253555656575A595A605E5E6562636B6767716D6C787271
7E7877857D7C8B8381928987
A09795A79F9DAEA8A6B6B1AFBEBAB8C6C3C2CFCDCCD8D7D7E2E2E2EDEEEEF8FAFAFBFDFE
EEF1F4E0E6EAD2DBDFC1CED4B4C3CAA7B9C19CB0B98DA4AF809AA678929E6E8A97668391
5F7E8C5677875374834E6F7F4A6C7D46697A4467784165753F63733E61713F6170426170
45626F48626F4C646E52656F56666E5A676E5D676D60676C61666A6164676062655E5F61
5B5C5E5A5A5C59595B5A595B5B5B5C5E5D5E6260606663646B6767706C6B7570707B7574
817A79867F7D8C8482928A87
9F9794A69F9CADA7A5B5AFADBCB7B6C4C0BFCCCAC9D5D3D3DFDEDDE9E9E8F4F5F5FEFFFF
F7F9FAEAEEF0DDE3E6CFD8DCC1CCD2B4C2C9AABAC19EB0B991A6B0899EA87E95A0778F9B
708995698390637F8C5E7B895A7785567482547180526F7E4F6C7B4F6B7A4F6B78526C78
556C78586D785B6E775F6E77626E75636D73656D72676D70686C6F686A6C656668616264
5F5F615F5F60605F606160616361626563646865666C6869706C6C74706F7974737E7877
837C7B88817F8E8683938A88
9F9694A59E9BACA5A3B3ADABBAB5B3C1BDBCC9C6C4D2CFCEDAD8D8E4E3E2EFEEEDFBFBFB
FFFFFFF5F7F8E8EBEDDBE0E3CED6DAC2CCD1BAC5CBAFBCC3A4B3BA9BABB390A2AA889BA4
81959E7B909A748B957087916C838F687F8B647C88627A866077835F7682607580647781
6476806777806B787F6D787E6F777C6F767A7075787174767072746E6F716E6C6E6A6869
6461626664656765666866666A67676C69696E6B6B716D6D7570707973737D7776817B79
867F7D8A83818F8784948B88
9E9693A49C9AABA3A1B1AAA9B8B2B0BEB9B8C6C1C0CDCAC8D5D3D1DEDCDBE8E6E5F2F0F0
FDFBFBFFFEFEF4F4F5E7E9EADADEE0CFD5D8C7CED1BFC7CCB5BFC4ADB8BDA3AFB69AA7AE
93A1A98D9CA488989F82939B7D8F97798B9475879072848E70818B6E80896E7E87728088
7581897882897A82887C81867D80847C7F817A7C7E797A7B7978797575767270726E6C6E
6D6B6B6D6A6B6E6B6B6E6B6C706C6C726E6E74706F7672717974737D7776807A79847D7C
88817F8C8482908885948B89
9E9592A39B99A9A19FAFA8A6B5AFADBBB5B4C2BDBBC9C4C3D0CCCBD8D4D3E0DDDCE9E6E5
F1EFEFFBFAF9FDFBFBF3F1F1E5E6E7D9DBDDD0D4D6CBCFD2C4C9CCBDC2C5B5BBBEABB3B8
A4ADB29EA7AC98A2A8939EA48E9AA089959C869299828E96808C937C88907B868D7D868C
7F868D858A8E888B8E88898C88888B868587838283807F807E7D7D7D7B7B787676767273
7471717470707470707571707671717772727974737B76757E7877807A79837D7B87807E
8A82818E8583918986958C89
9D9492A29A97A79F9DACA5A3B2ABA9B7B1AFBDB8B6C3BEBDCAC5C4D1CCCBD8D4D3DFDCDB
E7E4E3EFECEBF8F6F5F9F6F5EFECECE4E3E3D9D9DAD3D4D5CED0D1C9CBCCC2C4C6BBBDC0
B6B8BBAFB3B6A9ADB0A4A9AC9EA4A899A0A4959CA091989D8F959B8B9297878E92868C90
878C908B8D918B8D8F8C8C8E8C8B8D8C8A8B898787878484848181827F7F7D7A7A7C7878
7B77767A76757A75757A75757B76757C77767E78777F7A79827B7A847D7C867F7E898280
8C84828F8785928987958C8A
9D9491A19896A59D9BAAA2A0AFA7A5B3ADABB8B2B0BEB8B6C3BEBCC9C4C3CFCBC9D6D1D0
DCD8D7E3E0DEEBE7E6F4F0EFF4F0EFEBE7E6DFDDDDD8D7D7D4D2D3D1D0D0CBCACBC4C3C4
BFBEC0BBBABCB8B7B8B3B3B4ADAEB0A8A9ABA4A5A89FA1A49C9EA1989A9E97989B929497
949597979597989596989494979293959191938E8D8D89898A868588848384807F827D7D
807B7B7F7A7A7F7A797F7A79807A79817B7A827C7B847D7C857F7D87807F8982808C8482
8E8684918886938A88968D8A
9C9390A09794A39B98A79F9DABA4A1AFA8A6B3ADABB8B1AFBDB6B5C1BCBAC7C1BFCCC7C5
D2CDCBD8D3D1DED9D7E4E0DEEDE8E6EFE9E8E9E3E2DDD9D8D6D2D1D2CECED0CDCDCDC9C9
C9C5C5C5C1C1C0BCBCBDB9B9BBB7B7B6B2B2AFACACA9A7A9A6A4A5A2A1A3A19E9F9B9A9B
9C9A9B9E9A9A9E99999E98979C96969A9493999291908B8B8E89888B8685898383878180
85807F847F7E847E7D847E7D857E7D857F7D867F7E87807F8982808A83818C84828E8684
908885928987948B89968D8A
9B928F9E9593A19996A49C9AA8A09DABA3A1AEA7A5B2ABA9B6AFADBAB3B1BEB7B5C2BCBA
C6C0BFCBC5C3D0CAC9D6D0CEDBD5D3E0DAD8E5DEDCE3DCDAD9D3D2D3CDCBCEC9C8CCC6C6
C9C3C3C8C2C0C5BEBDC1BAB8BDB6B5BAB4B2B5AFADB1ABAAABA6A5A7A3A3A5A1A1A39F9F
A19E9DA29D9CA39D9CA39B9AA19A999D97969C9595958F8E918C8B8F89888D86858B8583
8A83828982818982818982808982808982818A83818B84828C84838D85838F8784908886
928987938B88958C89978D8B
9B918E9D93919F9694A19996A49B99A69E9CA9A19FACA4A2AEA7A5B1AAA8B4ADABB8B1AF
BBB4B2BFB8B6C2BCB9C6C0BDCAC3C1CEC7C4D2CBC8D7D0CDD7CFCCD5CCC9CFC7C5C8C1BF
C7BFBEC6BEBDC4BBB9C0B8B6BCB5B3BAB2B0B7AFAEB5ADABB1AAA8AFA7A6AAA4A3A8A3A1
A6A1A0A4A09EA49F9EA29C9BA59F9EA39C9B9C959497918F948D8C928B899089878F8886
8E87858D86848D85848D85848D85838D86848E86848F87848F8785908886918986928A87
938B88958C89968D8A978E8B
9A918E9B928F9D94919E9593A09795A29997A39B98A59D9AA79F9DA9A19FABA3A1ADA5A3
B0A8A5B2AAA8B4ADAAB7AFADBAB2AFBCB4B2BFB7B4C1B9B6C2B9B6C2BAB6C5BCB8C1B9B6
BEB6B3BEB6B3BDB5B3BDB5B2BAB1B0B4ADABB2AAA9B0A8A6ADA6A4ACA5A3AAA3A1A7A19F
A69F9DA49E9CA9A2A0A49E9BA19A989E97959B949298918F968E8C948D8B938B89928A88
918A88918987918987918986918986918987918987928987928A87938A88948B88948B89
958C89968D8A978D8B988E8B
99908D9A908E9B918F9B928F9C93909D94919E95929F9693A09794A19895A29996A39A98
A49B99A59D9AA69E9BA89F9CA9A09EAAA29FABA3A0ACA4A1ADA4A1ADA5A1AEA5A1ADA4A1
ACA3A0ACA4A0ACA3A0ADA5A1AFA6A2AEA5A1ADA4A2ACA3A1ABA29FAAA19FA9A19FA9A19E
A79F9CA19997A098959E96949D94929B93919A918F98908E978F8C968E8B968D8B958D8A
958C8A958C8A958C89958C89958C89958C89958C89958C8A958C8A968D8A968D8A968D8A
978D8B978E8B988E8B988E8C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0116279 0.488926 0.233112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(225) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
8D8A898D8B898D8B898D8B898E8B8A8E8B8A8E8B8A8E8C8A8E8C8B8E8C8B8E8C8B8E8D8B
8E8D8C8E8D8C8E8D8C8E8D8D8E8E8D8E8E8D8E8E8D8E8E8E8E8F8E8E8F8F8E90908F9293
8E8F8F8E8E8E8E8E8D8E8E8D8F8D8C8F8E8D8F8E8D8F8E8D8F8F8D908E8D908F8D908E8D
908E8C908D8B908C8A8F8B898E8A878E89868D88858D87858D85838B84818A827F89807C
877C7889817D8A83808B84828B85838B86848C86848C87858C87858C88868C88868C8886
8D89878D89878D89888D8A88
8D8B898D8B8A8E8B8A8E8C8A8E8C8B8E8C8B8E8D8C8E8D8C8F8E8D8F8E8D8F8F8E8F8F8E
8F8F8F8F90908F90908F91918F91918F92928F92928F93938F93948F94958F95978F979A
8F94968F93938F92918F9291909190909191919291929291929291929291939291939190
92908F928E8C918D8B908B888F89868E87848D85828C83808B817D897E79877A76857771
83746E867975877D78887F7B89817D8A827F8A83808A84818B84828B85838B86848C8784
8C87858C88868D89878D8988
8D8B898E8C8A8E8C8B8E8C8B8E8D8C8F8E8D8F8E8E8F8F8F8F8F8F909090909190909191
90929290939390939491949591949591959691969791979890979A90999B909A9D909CA0
8F999B909798909596909595919595929595939595949695939695949695959594949392
94929093908E938E8C918B889088858E85828D837F8B7F7C8A7C7787787385736D816E66
81706983746E857772867A75877C78887E7A897F7C89807D8A827E8A83808B84818B8583
8B86848C87858C88868D8987
8D8B8A8E8C8B8E8D8C8F8D8C8F8E8D8F8F8E90908F909191909191909293919393919494
91959591969792979892979992989A92999B929A9C929B9D929C9F919DA0919EA291A0A5
909C9F909A9C91999A919899929898939898949898959898959998959998969797969594
95939194918F948F8C938B889187848F84808D807C8A7C7788777285736C826D667E675E
806B64826F6883736D857670867873867A76877C78887D79887F7B89817D8A827F8A8381
8B85828B86848C87858D8987
8E8B8A8E8C8B8E8D8C8F8E8D8F8F8F909090909191919292919394919495929596929697
92989993999A939A9B939B9D939C9E939D9F939EA1939FA293A0A492A0A592A1A791A3A9
919FA3919DA0929C9D929B9C939A9B949A9B959A9A969A9A969B9B969B9A979A99979796
969592969290958F8C948C889287838F827E8D7E7989797486736D846E678068607D6359
7F675F806B64826F6883726B84746E857771867974877B76877D78887E7B89807D8A827F
8A84818B85838C87858C8887
8E8B8A8E8D8C8F8E8D8F8F8E90909090919191939391949492959692969793989993999A
939A9C949B9E949D9F949EA1959FA295A0A495A2A695A3A794A4A893A4AA92A5AA91A5AB
91A2A691A0A3929EA0939D9F949D9E959C9D959C9C969C9C979C9C989C9C989B9A989998
979694979391968F8C958C8893868290807C8D7C76897671867069826A617E63597C6056
7E645B7F685F806B63826E6783716A84736D857670857873867A75877C78887E7B89807D
8A827F8B84818B86848C8886
8E8C8A8E8D8C8F8E8E90908F90919191939391949592969693979893999A949A9C949B9D
959D9F959EA195A0A396A1A596A3A796A4A896A6AA96A7AC96A8AE95A8AF92A8AF90A5AC
91A3A892A2A593A1A393A0A1949FA0959F9F969E9F979E9E989E9D989E9D999C9B999A99
989795989491978F8C958B8793858290807B8D797489746D856D6581665D7C5E537C5E54
7D61587E655C7F685F806B63816E6682706A83736D847670857873867A76877D78887F7B
89817E8A83808B85838C8886
8E8C8A8F8D8D8F8F8E90919091929291949492969693979893999A949B9C959C9E959EA0
96A0A396A1A597A3A797A5A998A6AB98A8AD98AAAF99ABB199ADB399AEB58FA7AF8EA4AB
90A4A992A3A793A2A594A2A395A1A296A1A297A0A198A0A099A0A0999F9F9A9D9D9A9B9A
999896989491978F8C968A87938581907E798D787288716A836A628063597B5A4F7B5C51
7C5F547D62587E655C7F685F806A63816D6682706A83736D847570857873867B76877E7A
89807C8A827F8B85828C8785
8E8C8B8F8E8D90908F90919191939392959693979893999A949B9D959D9F969FA196A0A3
97A2A698A4A898A6AA99A8AD99AAAF9AACB19AAEB49BB0B69CB2B99BB3BB89A3AC8EA5AC
90A5AA92A5A994A4A795A4A696A3A497A3A498A3A399A3A29AA2A29AA1A09B9E9E9B9B9A
9A9896999391988E8B96898693847F907D788C7770886F6883685F7F60567A584C7A594E
7B5C517C5F547D61587E645B7F675F806A63816D6682706A83736D847671857974877C78
887F7B89817E8B84828C8785
8E8C8B8F8E8E90919091929292949593969793989A949B9C959D9F969FA197A1A497A3A6
98A5A999A7AC9AA9AE9AABB19BADB39BB0B69CB2B99CB4BB9FB7BF94AFB78BA5AD8FA7AD
91A7AC93A7AB94A6A996A6A897A5A698A5A599A5A59AA5A59BA5A59CA4A29CA09F9C9C9B
9A9795999290988D8B96888592827E8F7B768B756F876E6683665D7E5F547A564A7A564A
7A594D7B5B517C5E547D61587D645B7E675F806B63816E6782716B83746E857772867A76
877D7A89817D8A84818C8785
8E8C8B8F8F8E909191919393929596939899949A9B959C9E969FA197A1A498A3A799A5A9
99A8AC9AAAAF9BACB29CAFB59CB1B79DB3BA9EB6BD9FB9C198B3BC8FABB48FAAB291AAAF
93A9AE94A9AD96A9AC97A8A998A7A899A7A79AA7A79BA8A79CA8A79DA5A49DA1A09D9C9B
9B97959A918F988C8A96878392817C8E7A758A736C866C6583665D7E5F547B574B785346
7955497A584C7A5B507B5E547C61587D645C7E68607F6B64816F6882726C847570857974
877C7888807C8A83808C8784
8E8D8C8F8F8F90929292949493969794999A959B9D969EA097A0A398A3A699A5A99AA8AC
9BABAF9CADB29DB0B69DB2B99EB4BC9EB7BF9FB9C29CB9C291AFB891AEB792ADB493ACB2
94ACB196ACB097ABAE98A9AB99A9A999A8A89AA9A99CA9A89DAAA99EA6A59EA2A19D9D9B
9D98979B918F998C89958582917F7B8D787388716B856B6382655C7E5F547C584C785245
77514478544879574C7A5B507B5E547C61587D655C7E6861806C6581706A83746E847873
867B77887F7B8A83808B8684
8E8D8C90908F919292929595939899949A9C959D9F97A0A298A2A599A5A99AA8AC9BABAF
9CADB39DB0B69EB3B99FB5BDA0B8C0A0BAC3A1BDC792B2BC91B0BA92AFB893AFB695AFB4
96AFB498AFB399ADB099ABAC99AAAA9AAAAA9AAAA99CA9A89EA8A79FA6A69EA1A09E9E9C
9F9B999C93919A8C8A958482907D7A8C7772877069846A6281645B7F5F547C584D795347
764E4077514478544878574C795B507A5E557B62597D665E7E6A63806E6782726C837671
857A75877E7A89827F8B8684
8E8D8C90909091939392969694999A959B9D969EA197A1A499A4A89AA7AB9BAAAF9CADB2
9EB0B69FB3B9A0B6BDA1B9C0A2BCC4A2BFC89DBCC78EAFBA91B0B993B1B994B0B796B1B7
98B2B79BB2B69BB0B299ACAC9AABAB9CABAB97A6A59BA7A79DA5A49FA5A4A0A4A2A1A09E
A19D9B9E96939C908D958683907C798A7571866E6883686081635B7F5F557D594E7A5448
774F41764D3F76504377544877574C785B51795F567B635B7D67607F6C6581706A83746F
857974877D7989817E8B8683
8F8D8C909190919494939697949A9B969D9F97A0A298A3A69AA6AA9BA9AE9CACB19EB0B5
9FB3B9A1B6BDA2B9C1A3BCC4A3BFC8A5C3CC93B4C08FB0BB91B1BA94B2BA95B1B798B3B9
9AB5BA9DB5B99DB2B49CAEAE98A7A79AA7A897A3A39BA5A59DA5A49FA4A4A1A6A5A2A09E
A29D9BA19996A09592978A868E7D7988736F846D6781665F80625A7F5F557E5B4F7B5649
795042764C3D754D4074504375534876574D775C527960587B655D7D69627F6E6882736D
847773867C7888817E8B8583
8F8E8D909191929495939798959B9C969EA098A1A499A5A89AA8AC9CABB09DAFB49FB2B8
A1B6BCA2B9C1A4BDC5A5C0C9A5C2CBA4C3CD8CAFBC8FB0BB91B1BB94B2BA96B2B899B4BA
9CB7BC9FB7BA9EB4B59EB0AF94A2A397A3A499A4A49BA4A39EA6A6A0A6A5A2A6A5A2A09E
A29E9CA29996A197939B8D8891827E877470826B6580645E7F6159805F567F5C507C574A
7A5143784C3D754C3E724C3F714F4373534975584F775D5479625A7C67607E6C6681716C
837671867B7788807D8B8583
8F8E8D919191929595949899959C9E979FA298A3A69AA6AA9BAAAE9DADB29EB1B7A0B4BB
A2B8C0A4BCC4A7C1CAABC6CFA4C3CC99BAC68BAEBA8FB0BB92B2BB95B2BA97B3B99AB5BB
9DB8BD9EB5B89DB1B39CADAE96A6A698A5A69BA6A69CA5A59FA8A7A1A7A6A3A7A5A2A29F
A29E9BA19794A096929C8E889786818B79748069647E635D7F6158806056805D517E584B
7B5244794D3E754A3B714A3B6E4A3E704F4573554B755A517860577A655E7D6A6480706A
827570857A7688807C8A8582
8F8E8D91929293969694999B969D9F98A1A399A4A79BA8AC9CABB09EAFB59FB3B9A1B7BE
A3BBC2A5BFC7AAC5CEAFCBD5A1C0CB8DB1BD8DAFBB90B1BB93B3BB95B2BA97B3BA9AB5BB
9DB7BC9DB3B79AACAE9AAAAC99A9A99BA8A89CA7A89EA8A8A0A9A9A2A9A8A3A7A5A3A3A1
A39E9BA198959E95909C8E88978680907C76826B667E625C7F6158816157815E527F594C
7C54467A4F40784C3C6C44366B463A6D4B4070524773574E765D5579635B7C69627E6E68
81746F847975877F7C8A8582
8F8E8D919292939697959A9C979EA098A2A59AA6A99CAAAE9DADB39FB1B7A0B5BCA1B8C0
A3BCC5A5C1CAA9C6CFAAC8D39DBEC990B2BE91B2BD92B2BC94B2BA96B2BA98B2BA9AB5BB
9DB6BB9DB3B799ABAD99A9AB9AA9AA9BA9A99DA8A99FA9A9A1AAAAA3AAA9A4A7A6A4A4A2
A39F9CA19A969D958F9A8D8896857F8F7C7587706980655F806259816157825F53805A4E
7D55477C51427C4E3E673F316842366A483C6E4E4471554B745B527761597A67607D6D67
81736E847974877E7B8A8482
8F8E8E919393949798969B9D979FA299A3A79BA7AB9DABB09EAFB59FB3B9A1B7BEA2BAC2
A3BEC7A4C1CBA5C5CFA2C2CE9DBDC896B6C193B3BD93B2BB95B2BA96B2BA98B2B99AB4BA
9CB5BB9CB3B79AADB099A8AA9AA8A99CA9A99EA9AAA0AAAAA2ABABA4ABAAA5A8A7A5A4A2
A4A09CA29A969D938F998C8694847D8E7B7489726B83696282655B826359836054815B4F
7F56487E52437D4F3E653D2F643F326845396B4B416F524872584F765F5779655E7C6B65
80716C837873867E7A8A8481
8F8F8E929393949899969C9E98A1A39AA5A89CA9AD9EADB29FB1B7A0B5BCA1B9C0A2BCC5
A3BFC9A3C2CDA2C3D0A0C0CC9CBBC698B6C094B3BD94B1BA95B1B996B1B998B2B99AB3BA
9BB5BA9CB3B79CAFB29AA9AB9AA7A89CA8A99FAAABA1AAAAA3ABABA5ACABA6A9A8A6A5A3
A49F9CA19A969C928E978B8592827D8E7B7489736B856B6284685E84655A846155825C4F
8057497F5444805140633C2D613C2F65423669483D6C4F4570564D745D5578635C7B6A64
7F706B827772867D7A8A8481
908F8E929494959999979D9F99A2A49BA7AA9DABAF9FAFB4A0B3B9A2B7BEA2BBC3A3BEC7
A3C1CCA3C4D0A1C3CE9FC0CB9BBAC497B4BD94B2BB94AFB895AFB897B1B898B2B899B3B9
9BB4B99CB2B79CB0B39BABAD9BA7A89DA8A99FABABA1AAABA3ABABA6ADACA7AAA8A6A6A3
A49F9CA19A969C918D97898491817B8D7B738A736C876D64866A6085665C846256825D50
80584A7F5445815342673F305D382A623E3266453A6A4D426F544B735B5376625A7A6962
7E6F6A827672867D79898381
908F8E939494959A9A989FA09BA3A69DA8AC9FADB1A1B1B7A2B6BCA3BAC1A4BDC6A4C1CA
A4C4CEA3C6D2A1C2CE9FBFCA99B6C095B2BB94B0B994AEB795AFB796B0B798B1B899B2B8
9AB2B89BB1B79DB0B49BACAE9BA7A99DA8A99FAAABA2ABABA4ACACA7ADACA8ABA9A6A5A3
A49F9CA099959B918C96898390807A8C7A728A746C897067886C6286685D846357825E51
7F584B7D54457D51426E443560382A5D382C644237694A406D5248715951756059796761
7D6E69817571857C79898381
90908F939595969B9B99A0A29CA5A89EAAAEA1AFB4A2B4B9A4B8BFA5BCC4A6C0C9A6C4CE
A5C7D2A4C7D3A1C2CE9DBAC696B1BB93AFB993AEB794AEB695AEB696AFB698B0B799B1B7
9AB1B79BB0B69CAFB39BABAE9BA8AA9DA9AAA0ABABA2ABABA5ADACA8ADACA9ABA9A7A5A2
A49F9B9F98949B908B958882907F798C7A728B756D8A7269896E6386695E846458815E51
7D584B7A5244774E406F4536643A2B5D382B63413568493E6C504670574F745F5778665F
7C6D68807470857C78898380
91908F949696979C9C9BA1A39EA7AAA0ACB0A3B1B6A5B6BCA6BBC2A7BFC7A8C4CDA8C7D1
A7CAD6A5C8D4A1C1CC9AB5C093AEB891ADB792ADB693ADB695AEB696AFB697B0B799B0B7
9AB0B69BAFB59AADB19BAAAD9BA8AA9DA9AAA0ABABA2ABABA5AEADA9ADACA9ABA9A7A5A2
A49E9B9F96939A8F8A948780907F798D7A738B766E8B736A896F65866A5F836458805E52
7C584B775143734D3E6C4334633829623B2D64403467473C6B4E456F564D735D5677655E
7B6C6780746F847B78898380
919090959797999D9E9CA3A59FA9ABA2AEB2A5B4B9A7B9BFA9BEC5AAC3CBABC7D1ABCBD6
A9CCD7A6C8D39FBEC996B1BC90ABB68FABB491ABB492ADB594AEB696AFB698B0B798B0B6
99B0B59AAEB399ABB09AA8AC9AA7A99CA8A99FAAAAA2ABABA6AEADAAAEADAAABA8A8A5A2
A49E9A9F9691998E899486809080798E7B748D786F8B746B8A7065866B608365597F5E52
7B574B755042714C3E6A423363392961392C633F3266453A694D436D544B715C5476635D
7A6B667F736E847B77888280
9191909697979A9E9F9EA4A6A1ABADA5B1B5A8B7BBAABCC2ACC2C9AEC7CFAFCBD5B0D0DB
ADCED8A7C6D19BB9C58FACB88CA8B38DA9B28FAAB391ACB594AEB696AFB698B0B799B0B6
99AFB499ACB198A9AE98A7AA98A5A89BA6A89EA8A9A2ABABA7AEADAAAEADABABA8A8A5A2
A49D999F9590998E8895878192817A8F7D758E78708B756B897066866B608365597F5F52
7A584B745143704C3F694132633A2B5E3527613C2F644338674B416B524A705A5274625B
796A647E726D837A7688827F
9291909798989B9FA0A0A6A8A4ADB0A8B4B7ABBABEAEC0C5B0C5CCB2CBD3B3D0D9B5D5E1
B4D1DBA7C4CE97B5C187A6B387A4B08AA6B18DA8B290ABB494ADB597AFB699B0B799B0B6
99AFB498ACB196A7AC95A4A896A3A699A4A59DA7A7A2AAAAA7AEADABAEADACABA8A9A5A2
A59E999F95909B8E8896898293827B907E758E79708B746B897066866B608265597E5F53
79584B7451456F4D40674132603A2B5B31235E392C61413565483F6950486E585173615A
7869637D716D82797688827F
9292919899999DA1A2A2A8AAA7B0B2ABB7BAAFBDC2B2C4C9B5C9D0B6CFD7B8D4DDB9D8E2
B8D2DCA8C3CD95B2BE80A1AF82A1AD86A4AF8AA6B18FAAB394AEB698B0B79BB2B89BB1B6
99AFB496ABB094A5AB93A2A694A0A396A1A29BA4A5A1A9A9A7ADACACAFADADACA9AAA5A2
A79E99A196919D8F89998A8394847C917E768F7A718B746B887065856B608265597E6053
79594C745346704E406542345C3628572E1F5B36295E3E3363463C674E466C574F715F59
7668627C706C82797587817F
939291999A9A9FA2A3A4AAACAAB2B5AFBABDB4C1C5B7C8CDBACED4BBD3DBBCD7E1BCD8E1
BCD4DCA8C1CB90AEBA799CAB7D9DAB82A1AD87A4AE8DA9B294AEB599B1B89DB3B89EB2B7
9BAFB494A9AF8FA3A890A1A5919EA1929B9D99A1A2A1A7A7A8ADACADAFADAEACAAACA7A3
A9A09AA39791A0918B9C8C8497867E927F778F7A7189736A876F65856B6082665A7E6053
795A4C745447704F41634134573326532A1C5733275B3B3060443A644C446A554E6F5E57
7566617B6F6B81787587817F
9493929A9B9BA1A4A5A7ACAEADB5B7B3BEC1B9C6CABECDD2C1D4DAC1D8DFBFDAE3BED7DF
BED2DAA6BFC98BABB77397A7799AA87F9FAA84A2AD8BA7B092ACB399B1B79CB2B7A2B4B8
9DB0B493A8AE8EA1A68C9FA48D9B9E90999B989FA0A0A6A6A8ADACAEB0AEB0AEABAFA8A4
ADA49DA49791A3948DA08F869A8880927F778E797188736A866E64846A5F83665A7E6053
795A4D7655476F4E405F3F325231244E271A53302557392E5C4138614A4267534C6D5C56
7365607A6E6A80787487817E
9493929C9C9CA3A6A6AAAFB0B1B8BAB8C2C4BFCBCEC5D4D8CADBE1CBE1E7BED8E0BCD3DB
B9CED6A5BDC688A8B56E93A37597A57B9CA882A0AB88A4AD8EA8B095ADB499AFB59FB2B7
9BAEB395A8AE8FA1A68B9DA28C9A9E919A9D989FA0A1A6A6A8ADACAFB0AEB2AFACB1AAA5
B0A59FA99A93A99890A7938A9A8880937F778F7A72877269846E6482695E8265597F6154
7B5C4E7857496F4E405B3D304C2D214925194F2E2253362C583F365E484064514A6B5A54
71645F786D697F777486807E
9594939D9D9DA5A7A8ADB1B2B5BBBDBDC6C8C6D0D3CEDBDFD8E7EBD3E6ECC1D7DFB9CED7
B4C8D09EB7C283A4B26A90A07195A37899A5809FAA86A1AB8BA4AC91A9B096ADB399AEB3
98ACB194A7AD90A2A78D9DA18E9B9E939C9E99A0A0A1A7A6A9ADACAFB0AEB2AFACB2AAA5
B0A59EAD9D95AD9B92AD988E9B8981968179917C7386726A846D6482695E836659816254
7E5E507C5A4A6D4D3F583B2F462A1F442216492A204E3329543C335A453E614F48685853
6F625E776C687E767386807E
9694939E9E9EA7A9A9B0B3B4B9BEC0C2C9CBCCD5D8D7E2E5E4F1F5D6E6EBC8DBE1B9CDD5
AEC3CC96B2BE7EA0AE678E9E6D92A07596A27D9CA6849FA989A3AB8EA5AD93A9AF95ABB0
95A9AF92A5AB8FA1A78E9DA28E9B9E949D9F9AA1A2A2A7A7A9ADACB0AFADB3AFACB3ABA6
B0A59EAD9E96AD9B92AC978DA08D8499857C937D7489746B876F65866B5F85685B856456
826052805C4D6B4B3E54392E42291F3E1D1243261C492F264F383156423B5D4C46655651
6D615C756B677D757285807D
9695949F9F9FA9AAAAB2B5B6BCC1C2C6CDCED1D9DBDDE7EAEBF6F9DDE9EECCDCE2BBCED6
A9C1C991AFBA7A9DAB658C9D6A8E9D72939F7997A2819DA687A1A98CA4AB91A6AC91A6AD
93A7AD91A3A990A1A68E9EA28F9B9F959FA19CA4A4A3A9A8AAACABB0AEACB3B0ABB5ACA8
B2A59FAD9E97AB9A91A7948BA18E849D877E967F758F776D8C73688A6E61896A5D886658
886354825D4D694A3D4D362C422A20391B113D2219422B2349352E513F395A4A44625450
6B5F5B736A667C7572847F7D
979594A1A0A0AAACACB5B7B7BFC3C4CACFD1D5DCDEE2EAECEFF9FBE2EDF1D0DEE3BDCFD6
A8C0C990ADB9789BA9658C9C678B9A6E8F9B75939E7C98A1839CA589A0A78DA2A88DA2A9
90A3AA90A2A891A2A790A0A4939FA397A2A39EA6A7A3AAA9A9ACAAAFADAAB2AEA9B6ADA8
B5A8A2B0A099AC9B92A5938BA18D849E877E998177947B7091766A8E71648C6C5F8C695B
8D6757815C4D66483C4A352B422B21381C12321A123B251E43312A4C3C365647425F524E
685E5A7169657B7471847F7D
979694A2A1A0ACADADB7B8B9C1C5C5CDD1D2D9DFE0E5ECEEF3FAFDE6EFF2D4E0E5BFD0D7
AAC0C990ADB9799BA9668D9C6589986B8B9872909A79939D7F98A0849BA2889EA48BA0A6
8EA1A78FA1A791A2A893A2A796A3A79AA4A69FA8A8A4AAA9A9ABA9ADACA8B0ACA7B4ABA5
B6A9A2B4A39CB19E95A9968DA48E859E887F9B8278977D7293786B9072658F6F61916C5D
9269597F5A4B65483B4D372D3F2920351C1327130C32201A3D2C274739335245405C504C
665C597068657A7371837F7D
989695A2A2A1ADAEADB8BABAC4C6C7CFD3D4DBE0E1E8EEEFF5FCFDE7F0F3D8E3E7C1D2D9
ACC1CA93AFBA7B9DAA688E9D6488966889956F8D977590997B949C81979E859AA1899DA3
8C9FA58FA1A692A3A894A4A898A5A99BA7A9A0A8A9A4ABAAA8ABA9ABAAA7AFAAA5B1A9A3
B4A7A0B3A39CB29F97AE9990A89288A28B819E8479997E7397796C937566957163956E5F
936A5A7D594B66483C4F382E3B281F2D19121F0F092B1C163728234235314E423E594F4B
635B576E6764797370837E7C
989695A3A2A1AEAEAEBABBBBC5C7C7D1D4D5DDE1E2EAEFF0F7FDFEE9F1F3DAE4E8C5D5DA
AEC4CC97B1BB80A0AD6D919F6388966586936C8A94738D967991987E949B83989E889BA1
8B9EA48FA0A692A3A895A4A999A6AA9CA8AAA0A9AAA4ABAAA7AAA8AAA9A6ADA8A4B0A7A1
B2A59EB2A29AB19E95AE998FAA9389A68D83A1877B9D81749B7C6E99786A997466987161
9169597B584A64473B4F372E39271F2717121A0D082316123024203D322F4A403C564D4A
615A576D6663787270827E7C
989695A4A2A2AFAFAEBBBBBBC7C8C8D3D5D5DFE2E3ECF0F1F9FEFFEBF1F3DCE5E9C8D7DC
B3C7CE9CB5BE86A4B07294A2658997638491698792718B94778E967D929982969D879AA0
8B9DA28EA0A692A3A896A5A999A7AB9DA8AAA1AAABA4AAA9A7A9A7A9A8A5ACA7A2AEA5A0
B0A39DB0A099AF9C94AD988EAB9389A88E83A5897DA28477A07F719E7B6C9E77689B7262
8E675777564862463A4D362D37261F221611150C081A100D2B211E39302D473E3B544C49
6059566B6563777270827E7C
999695A4A3A2B0AFAEBCBCBBC8C9C8D4D6D6E1E3E3EDF1F1FBFEFFECF2F3DDE6E9CBD9DE
B8CAD1A2B9C28CA8B37798A5698C9A6284916885906F8992768D957C909781949B86999E
8A9CA18EA0A592A3A796A5A99AA7AB9EA9ABA1AAAAA4AAA9A6A9A6A8A7A4ABA6A1ADA49E
AEA29BAF9F97AE9B93AD978EAB9389A98F83A88A7EA68679A38173A27D6EA179699A7161
8863547353465E433848332B32231D1E1411110A07150D0A271F1C362F2C453D3B524B48
5E58566A656376716F827E7C
999695A4A3A2B0AFAEBCBCBBC8C9C8D5D6D6E2E3E4EFF1F1FCFFFFEEF3F4DEE7EACFDBDF
BDCDD3A9BDC591ABB67D9CA86E909D6587946885906F8891758C947B909781939986979D
8A9CA18FA0A593A3A797A5A99AA7AA9EA9ABA1AAAAA3A9A8A5A8A5A7A6A2AAA4A0ABA39D
ADA099AE9E96AD9A92AD978DAC9388AB8F84A98B7FA88779A68374A57E6FA17969966E5E
835F516F50435840364230282D201A19120E0A0604140E0C251F1D352F2C433D3B514B49
5D58566A656376716F817E7C
999695A5A3A2B0AFAEBCBCBBC9C9C8D6D6D6E3E4E4F0F1F1FDFFFFEFF3F4E0E8EAD2DCE0
C2D0D6AEC0C898B0B984A1AC7393A06A8B976A86916F8891758C947C909681939986979C
8B9BA08F9FA493A3A797A5A99BA8AA9EA8AAA1A9A9A3A8A7A5A6A4A7A5A1A9A39EAAA19B
AC9E98AD9C95AD9991AC968CAC9288AB8F83AB8C7FA98779A88375A57E6E9E7767906A5B
7D5B4E674B40523C333C2C25271C18130E0C05020016111025201F342F2D433E3C504B49
5D5856696563757270817E7C
999695A5A3A1B0AFAEBDBCBBC9C9C8D6D6D5E3E4E3F1F1F1FFFFFFF0F4F5E3E9EBD4DEE1
C6D2D7B3C4CA9FB5BD8CA6B07A98A471909B6D8994708892768C947C909782949A87979D
8C9BA0909FA394A3A798A5A99BA7AA9EA8A9A1A9A8A2A7A6A4A5A2A5A3A0A7A19CA99F9A
AB9D96AB9B93AC9890AC958BAC9287AC8E83AC8B7EAB877AA88374A37C6D997364886557
75564A60473C4B372F3528221F18140D0A0904020117131226222135312F433F3D504C4A
5D5957696564757270817E7C
999695A4A2A1B0AFADBCBBBAC9C8C7D6D5D4E3E3E2F1F1F0FFFFFFF2F5F6E6EAEBD8DFE2
CAD5D9B9C8CEA6B9C195ACB5849EA97996A1718D97728A93778D957D919883959A88989E
8D9CA0919FA395A3A699A5A89CA7A99EA7A8A0A7A7A2A5A4A3A3A0A4A19EA59F9AA79E98
A99B95AA9991AA978EAB948AAB9186AC8E82AC8B7EAA8779A682739E796A916D5F7F5F52
6B504658423843332C2D231E17121005040309070719161628252436333144403F514D4C
5D5A586A6665767271817E7D
999694A4A2A0B0AEADBCBAB9C8C7C6D5D4D3E2E1E0F0EFEEFFFEFDF6F7F7E9ECEDDBE2E4
CFD8DCBFCCD0AEBEC59DB1B98FA6AF829CA677929D758D97798F977F939984969B8A999E
8E9DA193A0A396A2A599A5A79DA7A89FA7A8A0A6A5A1A4A2A1A19EA29F9BA39D99A59C96
A79993A89790A9948CAA9289AB9085AB8D81AB8A7DA98678A37E7097746688675A75594D
614A414F3C343B2E28241D1A0F0E0C0000000E0D0C1C1A1A2A2827383534454241524F4D
5E5B5A6A6766767371827F7D
989694A4A1A0AFADACBBB9B8C7C5C4D3D2D1E1DFDEEEEDECFDFCFBF8F8F7ECEEEFE0E5E6
D4DBDEC6D0D3B6C3C8A6B7BD99ACB48DA3AC829AA37C939C7D929A81959B86979D8C9B9F
909DA194A0A397A2A59AA4A69DA7A89FA7A79FA4A49FA2A09F9F9CA09C99A19B96A39994
A59791A6958DA7938AA89087AA8E83A98B80A8877AA583759C796B8E6E617E61556C5349
58453C4637303128231B18160A0B0A0000011110101F1E1E2D2B2B3A383747454353514F
5F5D5B6B6867777472827F7D
989594A3A19FAEACABBAB8B6C6C4C2D2D0CEDEDCDBECEAE8FAF8F7FBFAF9F1F1F1E5E8E8
D8DDDFCCD4D7BDC8CCAEBBC1A2B2B997AAB18EA2AA859AA28499A085989F89999E8F9DA1
939EA196A1A398A2A59BA4A59FA6A7A0A6A69EA3A29C9F9E9C9C9A9D9A979E9894A09691
A2958FA3938BA59088A68E85A78C81A6897EA384779E7D7093736684675C745B50624D44
4F3F383D312C27221F131312040606060607151515232222302F2F3D3B3B494746555352
615E5D6C6968777473827F7E
989593A2A09EADABA9B8B6B4C4C1C0CFCDCBDBD9D7E8E6E4F5F2F0FEFBFAF5F4F3E9EAEA
DDE0E1D2D8DAC4CDD0B5C0C5ABB8BCA0AFB59AAAB092A3A98EA0A68C9EA38F9DA294A0A3
96A1A397A2A499A2A49CA3A4A0A6A5A0A5A49DA1A09A9D9C999A979A97949B96929E948F
9F928DA09088A18D85A28B82A2897EA1857A9C7F7395766B896C617A61566A544B58463F
463934332B271F1C1B0E0F0F0003040D0E0F1B1B1B282727343333413F3E4C4A49585554
63605F6D6B6978757483807E
979493A29F9DACA9A8B7B4B2C1BFBDCCCAC8D8D5D4E4E1DFF0EDEBFDF9F7FAF7F5EDECEC
E2E3E4D7DADCCBD1D3BBC5C8B1BCC0A9B5B9A3B0B49DABB098A7AB97A5A998A4A79BA4A6
9BA4A69BA3A59BA2A49DA3A3A0A4A49FA2A29C9F9F9A9B9A98989697949298938F9B918D
9B8F8A9C8D869C89829D877F9C847B99807693786E8A70667D655C6F5A515F4E464E403A
3B332F292523191818090C0D0407081415162121212D2D2D3938384443424F4E4D5A5857
6562616F6C6B79767583807F
979492A19E9CABA8A6B5B2B0BFBCBAC9C7C5D4D1CFDFDCDAEBE8E5F7F4F1FCF8F7F1EFEE
E6E6E6DBDDDDD0D4D5C2C9CBB8C1C3B2BBBEACB6B9A6B1B4A2ADB1A0AAADA1A9ABA2A8A9
A1A7A89FA5A69FA4A59FA2A2A0A3A29FA1A09C9E9D9A9A9997969495929096908D978E8A
978C87978A8496867F96837B947E769079708871697F6961725E5764534C554741433A36
312C2A212020141515070B0C0F11121B1D1D2728283333323E3D3D4847475351505D5B5A
676563716E6D7A777684817F
969392A09D9BA9A6A4B2AFAEBCB9B7C6C3C1D0CDCBDAD7D5E5E2DFF0EDEAFBF6F4F6F2F0
EAE8E7DFDFDFD4D6D7C9CDCEC1C6C8B9BFC1B5BCBEAEB6B8AAB2B4A9B0B1A8AEAEA7ABAB
A6AAA9A2A7A6A4A7A6A1A3A2A0A2A19FA09F9D9D9C9A999796959393918F938E8B948C88
9389849286818F827C8F7E778B797286736C7E6B6473625B675852594D484A403D383331
2726251C1C1D0F11120F12131A1C1C2425262F2F2F3939394342424D4C4B565554605E5D
69676672706F7B7977848180
9693919E9B9AA7A4A2B0ADABB9B6B4C2BFBDCCC8C6D5D2D0DFDCD9EAE6E3F4F0EDF8F4F2
EDE9E8E3E1E0D9D9D8CFD0D0C7CACABFC3C4BCC0C1B6BBBCB1B6B7B1B4B4AEB0B0ACAEAD
AAACAAA6A8A7A6A7A6A3A4A3A2A2A09F9E9D9D9B9A999796959391928F8D918C8A918A86
8F86828C827E897E79887A7583746E7C6D6873655F695D575D524D4F47433F3A382F2E2C
2122221517181315161B1D1E2425262D2E2E3636363F3F3F4848475150505A5958636160
6C6A687472707C7A78858280
9592909D9A98A5A2A0ADAAA8B6B3B1BEBBB9C7C4C1D0CCCAD9D5D3E3DFDCEDE8E6F6F1EE
F0EAE8E6E2E1DDDBDAD4D3D2CBCCCCC5C7C7C2C4C3BDBFBFB8BABAB6B7B6B1B2B1B0B0AE
ADADABAAAAA8A8A7A5A5A4A3A3A19F9F9D9C9B9A9898969493918F918E8C8E8A878D8784
8A8380877F7C857B778277727D716C7468646A605C605753534C4945413F373634282929
1A1C1D17191A1F20212627272D2E2E3536363E3E3D4645454E4D4D5655545E5D5C666463
6E6C6B7674727E7B7A858381
9491909C9997A3A09EABA8A6B2AFADBAB7B5C2BFBCCAC7C4D2CFCCDBD7D4E4DFDDEDE8E5
F0EAE8E9E4E2E0DCDBD8D5D3D0CECDC9C9C8C7C6C5C2C2C1BEBDBBBBB9B7B5B4B2B3B1AF
AFADABADABA8A9A7A4A6A3A1A2A09E9E9C9A9A9896979493928F8E8E8C8A8A87858A8582
86807E837D7A8279767E7471766D6A6D6561625B585752504B48463E3D3D313232242627
1A1C1C222323292A2A2F30303637373E3E3E4545444C4C4B5453525B5A596261606A6867
716F6E7876747F7C7B868382
94918F9B9796A19E9CA8A5A3AFACAAB6B3B0BDB9B7C4C1BECCC8C5D3CFCCDBD6D4E2DDDA
E9E4E1EBE5E2E4DEDBDBD7D5D2CFCDCCCAC8C9C6C4C6C3C1C1BEBCBEBBB8B9B6B3B4B1AF
B1AEABADAAA7A9A6A4A6A3A0A29F9D9E9B99999795959391908E8C8B898887848385817F
827E7C817C7A7F787579716F716A686762605C5856504E4D464545393B3B2D3030242626
2526262C2D2D3333333939393F3F3F4646454C4C4B5352515A5858605F5E6765646D6B6A
7471707A7876807E7C878482
93908E9996949F9C9AA5A2A0ABA8A6B2AEACB8B4B2BEBAB8C5C1BECBC7C5D2CDCBD8D3D0
DED9D6E4DEDBE5DFDCDED8D5D5D1CECECAC8C9C5C3C6C2C0C3BFBCC0BBB7BBB6B3B5B1AE
B2ADAAADA9A6A9A6A2A6A29FA19E9C9C9A9798969493918F8F8D8B898786848280817F7D
7E7C7B7F7B797C7675746F6E6E696765615F5856554C4C4C424343383A3B2D2F302C2D2D
3232333838383D3D3D4343424848484E4D4D5453525958585F5E5D6563636B6968716F6D
7674737C7A78827F7E878583
928F8E9894939D9A98A29F9DA8A4A2ADAAA8B3AFADB8B4B2BEBAB8C3BFBDC9C4C2CEC9C7
D3CECCD8D3D0DED8D5DED8D5D7D1CDCFCAC7C8C3C1C5C0BDC2BDBAC0BAB6BBB5B1B5B0AC
B1ACA9ADA8A5A9A5A1A6A19EA19D9A9C9996979492918F8E8E8C8B8886868281807E7E7D
7C7B7A7D7A78797574726E6D6B6867615F5F5555554B4C4C404242393B3A3535363A3A3A
3E3E3E4342424747474C4C4B5150505655545B5A59605F5E6563636A68676F6D6C747271
7977767E7C7A83807F888584
928F8D9693919B97969F9C9AA4A19FA9A5A3ADAAA8B2AEACB7B3B1BBB7B5C0BCB9C5C0BE
C9C4C2CDC8C6D2CCC9D6D1CED6CFCCCFC9C5C7C2BEC1BCB9BFB9B6BDB7B4B8B3AFB2ADAA
AFAAA7ABA6A3A9A3A0A5A09DA09C999B9895969391908E8D8D8B8A8786868583827D7D7D
7D7C7B7C7978767373706E6D6866665F5E5E5656564A4C4C424343414140434242464645
4A49494E4D4D5251505655545A59585E5D5C6261606765646B69686F6D6C737170787574
7C7A78807E7C858280898684
918E8C9591909995939C9997A09D9BA4A19FA8A4A2ACA8A6B0ACAAB4B0ADB7B3B1BBB7B4
BFBAB8C2BEBBC6C1BEC9C4C1CDC7C4CBC5C1C6C0BDBFBAB6BBB5B2B7B1AEB3AEABAFAAA7
ABA6A3A9A4A1A6A19DA29E9A9E9A989B9895969391908E8E8C8B898887878584847E7E7E
7D7D7C7A7978757373706D6D6766665F5F5F5A59584C4D4D4B4B4A4E4D4D504F4F525251
5554545857575C5B5A5F5E5D6261606664636968676D6B6A716F6D7472717875747B7978
7F7C7B82807E8683828A8785
908D8B93908E9693919996949C99979F9C9AA39F9DA6A2A0A9A5A3ACA8A6AFABA9B2AEAB
B5B0AEB7B3B1BAB5B3BDB8B5BFB9B6C0BAB7C0BAB7BEB8B4B6B1ADB2ACA8ACA8A5AAA5A2
A7A2A0A6A19EA29E9A9F9B989C99979B9895969390928F8E8D8B8A898888858484818080
7D7D7D7A7979767474706E6D6A69696362615D5C5B5756555958575B5A595C5B5B5F5D5D
615F5F6362616664636867666B69686E6C6B716F6E7371707674737977767C7A787F7C7B
827F7E8582808785838A8786
8F8C8B928E8D94918F9693919995939B98969D9A98A09C9AA29E9CA4A19FA6A3A1A9A5A3
ABA7A5ADA9A6AFAAA8B0ACA9B2ADAAB3AEABB3AEABB4AFABAFAAA7ACA6A3A8A4A1A39F9D
A19D9AA19D9A9F9B989D99979B9795989593959190928F8E8E8B8B8B8988868584838282
7F7F7F7B7A7A787775706F6E6E6D6C6A68686664646664646765646866656967666A6968
6C6A696E6C6B706E6D72706F7472707674727876747A78767C7A787E7C7A807E7C82807E
8582808784828986848B8886
8F8B8A908D8B928E8D93908E9592909693919895939996949B98969C99979E9A999F9C9A
A19D9BA29E9CA39F9DA4A09EA5A19FA6A29FA6A29FA6A19EA4A09DA39E9BA29E9B9C9997
9A97949B98969A97959B979499959395929093908F918E8D8E8B8A8C8989898786868484
8381807C7B7A7C7B79777574767473767372747271747170747271747271757372767473
7775747876757A77767B78777C7A787E7B7A7F7C7B807E7C827F7E83807F858280868382
8785838986848A87868C8987
8E8B898F8B8A8F8C8B908D8B918E8C928F8D928F8E93908E94918F959290969290969391
979492989492989593999593999694999694999694999593999593989492979391959290
94918F95918F94908F95918F95918F928F8D908E8D8F8C8B8E8B898C8A888B8987898786
87848382807E83817F82807F827F7E817F7D817E7D817E7D817E7D817E7D817F7D827F7E
82807E83807F83817F8481808582808583818683828784828785838885848986848A8785
8A87868B88868C89878C8988
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0116279 0.732558 0.233112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(270) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
767E7F767E80777F80777F80777F81778081778081788082788182788182788183788283
7982837982847983847983857983857984857A84867A84867A85877A85877A86887A878A
7985877A85867A84867A84867A84857A84867A85867B85867B85867B85867C85867B8585
7B84857B83847B82837A8182798081798080787F7F787E7E787C7C777B7A767979757776
737473757877757A7A767B7B767C7C767C7C767C7C767C7D767D7D767D7E767D7E767D7E
767D7E767D7E767E7E767E7F
767E80777F807780817880827881827982837982847983847A84857A84867B85877B8587
7B86887C87897C878A7C888B7D898B7D898C7D8A8D7D8B8E7D8B8F7E8C907E8D917D8F93
7D8D907D8C8E7D8B8D7E8B8D7E8A8C7E8B8C7F8B8D808C8D808C8E808C8D818C8D818B8B
808A8A7F88887F87867D85847D83837C81817B807F7A7E7D797B7A77787675757373716E
726F6C747472757775767877767A79767A7A777B7B777B7B777C7C777C7C777D7D767D7D
767D7E767D7E767D7E767E7E
777F807780817881827981837982847A83857A84867B86877C86887C888A7D888A7D898B
7E8A8D7F8B8E7F8C8F808D90808E91818F9281909481919581929681939881959981969C
819498819295819194819193829192829193839193849292849292849292849191848F8F
838D8D828B8B818A898188878086857F83827E817F7C7D7C7A7A7878767375726E726C67
726D6974716E757472767775777877777978777A79777B7A777B7B777C7B777C7C777C7D
777D7D767D7D767D7E767D7E
777F807880827982837982847A84857B85877C86887D888A7E898B7E8A8D7F8B8E808D90
818E9181909382919483929684949784959985969B85989C85999E859A9F859BA1859DA3
849A9F85989C85979A859799859698869698869697869596859596869595869494869392
859190858F8E848E8C848B898287868184827F817F7D7D7B7B797679757176706B736A65
746D6975706D767370777573777775777876787978787979777A7A777B7A777B7B777C7C
777C7D777D7D767D7E767D7E
777F807881827982847A84857B85877C87897D898B7E8A8D808C8E818D90828F92839194
83939684949885969A86989C87999E889BA0899DA2899EA489A0A589A1A789A2A989A3AA
88A0A5889EA3889DA0899C9F899B9E899B9D8A9A9B8A9A9B8A9A9A8A99998A9898899696
889493889291878F8E878D8B858A8883858382827F7F7E7B7C79757A746F776E69746963
756D6876706C77726F787471787673787775787877787978787A79787A7A787B7B777C7B
777C7C777C7D777D7D767D7E
7780817982837A83857B85877C87897E898B7F8B8D808D8F818F92839194849396859598
86979B87999D889B9F8A9DA18B9FA48CA1A68DA3A98DA5AB8EA7AD8EA8AF8DA9B08CA9B0
8CA6AC8BA4A88CA2A68CA1A48CA0A28DA0A18D9FA18E9FA08E9F9F8E9E9E8D9C9C8D9B9A
8D99988C96958C93928B908E898B8A878785848380827E7B7F79757C736E776C66766A63
776D6878706B78726E797470797572797774797876797977787978787A79787B7A787B7B
777C7C777C7C777D7D767D7E
7780817982847B84867C87887E898B7F8B8D808D90828F9283929585949786969A88999D
899B9F8A9DA28CA0A58DA2A78EA4AA8FA7AD91A9B092ACB393AEB593B0B892B1B98FAEB6
8EAAB08EA8AD8FA7AB8FA6A890A5A791A5A691A5A691A4A592A4A492A4A492A2A292A0A0
919E9D919A999097958F93918D8F8D8A8A8888858285807D817A757D736E796C65796C65
796E6879716B7A726E7A74707A75727A76737A7775797876797977797A78787A79787B7B
787C7B777C7C777D7D767D7E
7880827983847B85877D888A7F8A8D808D8F828F9284929585959887979B899A9E8A9CA1
8C9FA48DA2A78FA4AA90A7AD92AAB093ADB395B0B796B3BA98B6BE9BBBC394B5BE90AFB7
91AEB391ACB192ABAF93ABAD94AAAC94AAAC95AAAB95AAAA96AAAA96AAA997A8A897A6A5
97A3A2969F9E949B999397959192908E8C8A8B878487817D837B7680746F7B6D667B6E67
7B706A7B716C7B736E7B74707B75717B76737A77747A78757A7876797977797A79787B7A
787B7A777B7B777C7D767D7E
7881827A84857C87887E898B808C8E828F9184929586959887979B899A9E8B9DA28DA0A5
8FA3A890A6AC92A9AF94ACB395AFB697B3BA99B6BD9BB9C19DBEC69EC0C88FB2BB91B1B9
93B0B694B0B595B0B396AFB297AFB198AFB099AFB09AAFAF9AB0B09BB0AF9CAEAE9CACAB
9BA8A69AA3A2999F9D979A98949592918F8C8E89868A837F867D788377717E70697E716A
7E726B7D726D7D736E7D746F7C75717C76727B77737B78757A78767A7977797A78797A79
787B7A787B7B777C7C767D7E
7881827A84867D87897F8A8D818D9083919485949787979B899A9E8B9DA28EA1A590A4A9
92A7AD94ABB195AEB497B1B899B5BC9BB8C09DBCC49EBFC8A1C4CD96BAC48CB0BA92B3BB
95B4BA97B5B999B4B89AB4B79BB4B69CB4B59DB4B49EB5B59FB6B5A0B5B4A0B3B2A0B0AE
9FABA99EA7A59DA2A09B9D9B97979494918E908B878C8580897F7A85797381746D81736C
80736D80746D7F746E7E756F7E75717D76727C77737C77747B78757A79767A7978797A79
787B7A787B7B777C7C777D7D
7881837B85867D888A808C8E828F91849296879699899A9D8B9DA18EA1A590A4A992A8AD
94ABB197AFB599B3BA9BB6BE9DBAC29FBEC6A1C2CBA4C7D19BC0CA90B6C093B6BF96B7BE
98B8BE9AB9BE9CB9BD9DB8BB9FB8BA9FB8B9A0B9B9A1BAB9A3BCBAA3BAB8A4B7B5A4B4B1
A3AFACA2A9A7A1A5A29E9F9C9B9996979390938D898F87828C817C887D7686787183746E
82746E82746E81756F80756F7F75707E76717D76727C77737C78757B78767A7977797A78
797A79787B7B777C7C777D7D
7982837B85877E898B818D8F83909386949888989C8B9CA08DA0A490A4A992A8AD95ACB1
97AFB69AB3BA9CB7BF9EBBC3A1BFC8A3C3CCA4C7D19FC4CF94BBC696BBC597BBC49ABBC2
9CBCC29EBDC3A0BDC1A1BDBFA2BCBEA3BCBDA4BDBDA5BDBCA6BDBCA7B9B8A7B6B5A7B2B0
A7AEADA6AAA8A5A6A4A1A09E9E9A979A9490958E899188838E837E8A7F78887A73867770
85756E84756E83756E82756F8075707F76717E76727D77737C77747B78757A79767A7978
797A79787B7A777C7C777D7D
7982837C86887F8A8C828E9184929587969A8A9A9E8D9FA390A3A792A7AC95ABB198AFB5
9AB4BA9DB8BFA0BCC4A2C0C9A4C5CEA7C9D2AACED89DC4D099C0CB9ABEC89BBEC79EBFC6
A0C0C7A3C2C7A5C2C5A5C0C2A6C0C0A7C0C0A7C0BFA8BDBDA9BABAAAB7B7A9B1B1A9AEAD
AAAEADA9ABA9A8A6A4A4A19EA09A989B9592978E8A93898490847F8D807A8B7C75897971
86756D86766E85766E83756F82756F8076707F76717E76727D77737C78747B78767A7977
797A79787B7A777C7C777D7D
7982847C87887F8B8D83909286949789989C8C9DA18FA1A592A5AA95AAAF97AEB49AB3B9
9DB8BEA0BCC4A3C1C9A6C5CEA9CAD3ABCFD9A5CCD898C0CC9BC1CB9DC1CB9FC1C9A1C2C9
A4C4CAA7C6CBA9C6C9A9C4C4AAC3C3ADC3C3A9BBBBA8B7B8A9B3B4A9B1B1A9B1B0ACB0AF
ADAEADACA8A7ACA6A4A8A2A0A39B999D9592988F8A94898491847F90817B8E7D768C7B73
8A787088766E87766E85756E83756F81756F8075707E76717D76727C77747B78757A7977
797A78787B7A787C7B777D7D
7983847D8789808C8F8491938795998A9A9D8D9FA391A4A894A8AD97ADB39AB2B89DB7BD
A0BCC3A4C1C8A7C6CEAACBD3ACCFD8B0D4DEA1C8D49BC1CD9DC2CC9FC3CCA1C3CAA4C5CB
A7C7CDABC9CDACC8CAAEC6C7ABBEBFA8B7B8A3B1B2A7B2B3A9B1B2ABB2B2ADB3B3ADADAC
ACABAAADA9A7AEA9A7ABA3A1A59C999E95929A8F8A96898493857F92827C9180788F7D75
8D79718B766C8A766D87766D84756E82746E80756F7F75707D76717C76737B77747A7876
797978787A79787B7B777D7D
7A83847D888A818D8F85929588979A8C9CA08FA1A593A6AB96ABB099B0B69CB5BBA0BAC1
A3BFC7A7C5CDABCBD3AFD0D9B0D4DDAFD5DF9CC3D09CC2CE9FC3CDA1C4CCA4C4CBA7C6CC
AAC9CEAEC8CCADC5C7ADC1C2A4B6B8A6B6B8A8B7B8AAB6B7ACB7B9AEB8B9B0B8B8B0B4B2
B0B2B1AEADACACA9A8A8A29FA59D9AA097939B908B97898495868094847D94827A927F76
907B728E786E8C776F89766D85746C82736D80746E7F746F7E75707C76727B77747A7875
797977787A79787B7B777C7D
7A83857E898A828E908693968A999C8D9EA291A3A895A9AD98AEB39CB3B99FB8BFA2BEC5
A6C3CBAAC9D1AFD0D9B6D8E2B5D9E3A7CEDA98C0CD9DC2CDA1C4CDA4C5CDA6C5CCA9C6CC
ACC8CDACC4C8A9BDC0A6B6B9A3B2B4A8B4B6ABB7B8ADB8B9B0BCBCB2BCBCB3BCBBB3B8B7
B3B6B5B1AFADAFADAAABA6A2A7A09CA199949B8F8A98898497868097867F97847C958078
937C7391796F8D766C89746A84716A82726B80726C7F736E7E746F7C75717B76737A7775
797977787A79787B7B777C7D
7A83857F898B838F918795988B9A9E8FA0A493A6AA97ABB09AB1B69EB6BCA1BBC2A5C1C8
A8C6CEACCCD5B1D3DCB7DAE4ACD1DC9BC3CF9BC1CDA0C4CDA3C5CDA6C5CCA9C5CBABC7CC
AEC7CCAEC4C7ABBDBFAAB9BBAAB7B9ACB6B8ADB7B8AFB8B9B1B9BAB4B9BAB4B8B8B5B5B5
B4B1B0B3AEADB0ADAAADA7A3A9A19DA399959B8E8A99888499878199878099857C988279
957E75947C71947B708A736A846F6882706980716A7F726C7D736E7C74707B75727A7774
797876787978787B7A777C7C
7B84857F8A8C8490928896998D9CA091A2A695A8AC99AEB39DB3B9A0B9BFA4BFC6A7C4CC
AAC9D2ADCED7AFD3DCABD1DD9EC6D399C0CDA0C3CEA3C5CEA6C5CCA9C5CCABC5CBADC6CB
B0C6CBAFC4C7ADBDC0AEBCBEAEBBBCB0BABBB1BABBB3BBBCB5BDBDB7BCBDB8BABAB8B8B7
B7B4B3B6B1AEB3ACA9AFA4A2A99D9AA394909C8C879987829A87819C87809C867D9A8379
987F75977D72967B6F866E64836D65816E667F6F687E706A7D726C7C736F7B75717A7673
797875787978787B7A777C7C
7B8486808B8D8591948A989A8E9EA193A4A897AAAF9CB0B69FB6BCA3BCC3A7C2C9AAC7CF
ACCCD5AED1DBAED4DFABD1DDA7CCD7A5C7D2A5C6D0A7C6CEA9C6CCACC6CBAEC5CBB0C6CB
B1C7CBB1C5C8B1C1C3B1BEC0B2BDBEB3BDBEB5BEBEB7BEBEB9BFBFBBBFBFBCBEBDBCBBB9
BBB7B5BAB3B0B5ADA9B1A6A2AC9F9BA69793A1908B9D8A859D89819E89809E887E9C847A
9A8076997E72997C6F866D62816B61806C647F6E667E6F697D716B7C726D7B74707A7572
797775787977787A7A777C7C
7B8586818B8D8692958B999C90A0A395A6AA9AADB19EB3B9A2BABFA6C0C6AAC6CDADCBD3
AFD0D9B1D4DFB1D6E2B0D4DFAED1DBACCCD5AAC9D1ABC7CEADC7CDAFC7CCB1C7CCB2C8CC
B4C8CCB4C6C9B4C3C6B4C0C1B5BFC0B7C0C0B8C1C1BBC1C1BCC1C1BFC2C1BFC0BEBFBDBB
BEB9B5BBB4B0B6ADA9B2A6A1AD9F9AA89893A4928CA18D86A08C83A18B82A0887F9E847A
9B81769A7E729A7C6F856C62816A617F6B627E6C647D6E677C6F697C716C7B736F7A7571
797774787877787A79777C7C
7C8586818C8E8793968D9B9D92A2A597A9AD9CB0B4A1B6BCA6BDC3AAC3CAADC9D1B0CFD7
B3D4DEB4D9E4B4D9E4B5D8E1B2D3DCAFCDD5ADCBD2AFC9CFB0C8CEB2C8CEB4C9CDB5C9CD
B7C9CDB7C7CBB8C6C8B8C3C4B8C0C1BAC1C1BCC2C2BEC2C1BFC3C1C2C4C2C2C2BFC2BEBB
BFB9B5BDB5B0B8AEA9B4A7A1AE9F99AA9992A6938CA48F87A48E85A48C82A2897F9F857A
9C8176997D72997C6F876E6480685F7E69607D6A627D6C657C6E687B706B7B726E7A7470
797673787876787A79777C7C
7C8587828D8F8895978E9C9F94A4A79AABAF9FB2B7A4BABFA9C1C6AEC7CEB1CED5B5D4DC
B7D9E3B9DEE8BADDE6B9DBE4B5D2DAB1CDD4B1CBD2B2C9D0B4CACFB6CACFB7CBCFB9CBCF
BACBCEBBCACCBCC8CABBC5C6BBC2C2BDC3C3BFC4C4C1C5C3C3C6C4C5C6C4C6C5C2C5C0BD
C3BBB6BFB5B0BBAEA9B6A7A1B1A099AC9A92AA958DA9928AA89087A68D83A48A80A1867B
9C8176987C7092776C856D637F675D7C655C7C685F7C6B637C6D667B6F697B716D7A7370
797573787876777A79777C7C
7D8687838E908A9698909EA196A6A99DAEB1A2B5BAA8BDC2ADC4CAB2CCD2B6D2DABAD9E1
BDE0E9BFE4EDBFE2EABCDAE2B7D0D8B5CDD4B5CBD2B6CBD1B7CCD0B9CDD1BBCED2BCCED1
BDCED0BFCCCFBFCACBBEC6C6BEC4C3C0C5C4C2C7C5C4C7C5C6C9C6C9C9C6CAC7C3C8C2BD
C6BDB8C2B6B1BEB0AAB8A8A1B3A099B09B93AE9890AD968DAC948AA99186A68C81A2877C
9D8276977C7091766B866C607B6055765E557B665D7C69617C6C657B6E687B716C7A736F
797572787775777978777C7B
7D8688848F918B979992A0A299A8ABA0B0B4A6B9BDACC1C5B2C8CEB7D0D6BCD8DEC0DEE6
C3E5EDC4E6EEC3E0E8BED6DEB8CFD6B6CDD3B8CDD2B9CDD2BBCED2BDCFD3BED0D3C0D1D3
C1D0D2C2CFD0C1CCCDC1C9C8C1C7C5C3C7C5C5C8C5C6C8C5C9CAC7CCCAC6CDC8C3CBC3BE
C9BEB8C4B7B1C0B0A8B9A8A0B6A29AB49E96B29C92B29A8FB0978CAC9387A98E82A4897D
9F8377997C7093786B8A6E628164587E64597D665D7D69607C6B647B6E677B706B7A726E
797471787775777978777B7B
7E87888590918D999B94A2A49CAAADA3B3B7AABCC0B0C4C9B7CDD2BCD5DBC2DDE4C7E5ED
CAE9F1CBE7EFC7DFE7C0D4DCBACED5B9CED3BACED3BCCFD3BED0D4C0D2D5C2D3D6C4D3D5
C5D3D4C5D1D2C5CFCEC5CBCAC4C9C7C5C9C6C7C9C6C9CAC6CCCCC7CFCCC7CFC9C4CEC4BE
CABEB7C6B7B0C1B0A8BDAAA2BBA69DB9A298B7A095B69D92B4998EB09589AC9084A88A7E
A284789C7E7195796D8D706386685C82675B7F675D7E685F7D6B637B6D667B6F6A7A716D
797470787674777978777B7B
7E87888691928E9A9C96A3A69EADAFA6B6B9AEBFC3B5C8CCBCD1D6C2DADFC9E3E9CFECF3
D4EFF5D4EBF1CCE0E6C1D4DABBCED4BBCED3BCCFD3BED0D4C1D2D6C4D4D6C6D5D7C8D6D6
C9D5D5C9D3D3C8CFCFC7CCCBC7CAC8C7C9C6C9CAC6CCCBC7CFCCC8D1CCC7D2C9C4D0C5BE
CDBFB8C9B8B1C5B3AAC2AEA4C0A99FBEA69BBCA398BA9F94B79B8FB3978AB09184AB8C7F
A586799F8073997C709172668A6C5F83665A80665C7E685E7D6A627C6C657A6E687A716C
797370787673777877777B7B
7F8889879293909B9D99A5A7A1AFB2AAB9BCB2C3C6BACCD0C1D6DAC9DFE4CFE8EDD7F1F7
DDF2F7D8EAEECDDFE3BFD1D7BCCDD3BCCED2BECFD3C0D1D4C4D3D6C7D5D7CAD7D7CCD7D7
CDD7D6CCD5D4CBD1D0C9CECCC8CBC8C9CAC6CBCAC6CDCBC7D1CDC8D4CEC8D5CBC4D3C6BF
D0C1B9CDBAB2CAB5ACC7B1A7C6ADA2C3AA9EC1A69ABEA296BB9E91B7998CB39486AE8E80
A8887AA383759E7E719574678C6D608463568165597F675D7D69607C6B647A6D6779706B
78736F787573777877767B7B
7F8889899294929D9E9BA7A9A5B2B4AEBCBFB7C7C9C0D1D4C8DBDECFE4E8D6EDF1DCF4F8
DFF1F4D7E8EBCBDCE0BBCDD3BACBD1BCCDD1BECED2C1D0D3C6D4D6CBD7D8D0DADAD2DBDA
D3DAD8D0D7D5CDD1D0CACECCC9CBC8C9C8C4CBC8C4CECAC5D2CDC7D6CDC8D7CBC5D6C7C0
D4C2B9D1BDB3CFB8AECEB5AACBB0A5C8ACA0C6A89CC2A397BE9F92BA9A8CB69587B19082
AC8A7CA78577A281739878698D6C5E8461548163577F655B7D675F7B6A627A6C66796F6A
78726E777572777876767B7B
80898A8A9395949EA09EA9ABA8B4B6B2BFC1BCCBCDC6D6D8CFE0E3D6EAEDDDF2F6E2F6F9
E7F5F7DDE8EBCAD9DDB7C9CFB8C9CEBACACFBDCCCFC1CFD1C6D2D4CBD5D6D0D8D7D4D9D7
D4D9D6D0D5D3CCCFCDCACDCAC9C9C6C7C5C1CAC6C1CEC8C3D3CCC6D7CDC7D9CCC5D9C8C0
D8C4BAD4BEB4D3BAAFD1B7ABCFB3A7CDAFA2CAAB9EC4A598C0A092BD9C8DB99788B59283
AF8C7DAB8778A582739876678B695A835F508061557E64597C665D7B6961796B65786E69
78716D777472777776767A7A
80898A8B9495959FA1A0ABACABB7B8B6C3C4C1CFD0CCDBDDD7E7E9DFF0F3E3F7FAE6F6F8
E7F2F4D8E3E6C5D4D8B2C5CBB5C5CBB8C8CCBCCACDC0CCCEC4CFD0C8D2D1C9D2D0CED3D1
CDD2D0C7CDCBC4C7C5C2C4C2C0BFBCC2BDB9C8C2BDCEC6C0D4CBC5D8CEC6DBCDC5DBCAC0
DCC8BDD8C0B5D9BEB2D9BCAFD7B8ABD1B2A4CDAC9EC6A698C3A293BF9D8EBC9889B79383
B28E7EAF8A79A984739A76668B6758825C4E805F537D62577B655B7A675F786A64776D68
77706C767371767775767A7A
81898A8C959697A1A2A2ACAEAEB9BABAC5C7C6D3D4D4E1E2E1EFF0EEFDFEEBFBFDEAF6F6
E7EFF0D7E1E3C2D1D5AFC1C7B2C3C8B6C5C9BAC8CABECACBC2CCCCC5CDCDC6CECCC8CECC
C2C8C7BDC3C3BBBFBEBABCBBBDBBB8C2BCB8C8C0BBCEC6C0D4CBC5D9CDC6DBCCC3DBC8BF
DBC5B9D8BDB1DDBFB1E0BFB0D7B8A9D2B1A2D0AE9FC8A798C4A293BF9D8EBD9888B99483
B6907FB48C7BAD85739B75658A6657815C4E7F5E527C61567A635A78665E776962766C67
766F6B767370767675767A7A
81898A8D959698A1A2A4ADAEB0BABBBDC8C9CBD6D7DAE6E6EEF9F9F4FFFFEDF8F9EDF4F4
E8EEEDD5DEE0BECDD2AABDC3AFBFC4B3C2C5B9C7C8BDC8C9C0C9C8C3CAC9C5CAC9C5CAC7
C3C7C5BFC2C1BCBEBBBBBAB8BEBAB6C3BCB7C8C0BACFC5BFD5CBC3D9CCC4DCCBC2DBC7BD
D9C3B7D7BDB1D7BCAFD8BAACCEB1A4CCAD9FC9A99BC1A294BE9E8FBC9989BD9786BC9483
BA917FBA8F7CAE85739A7565886657805C4D7D5D507A5F5478615876645C756761756A65
756E6A75726F757674757A79
82898A8D959699A2A3A6AFAFB2BCBCC0C9CACED8D8DEE8E8F0FAFAEEF7F7EAF2F3E5EBEB
DFE5E5CBD7DAB8C8CDA7BAC0ACBCC1B0BEC2B5C1C3B9C2C3BEC6C5C2C8C7C5CAC7C7C9C6
C6C7C4C2C2BFC0BFBCBFBCB9C0BAB5C4BCB6C9C0B9CFC6BFD5CAC2DACBC2DCCBC1DCC8BC
DBC3B7D8BEB1D6BAADD1B5A7C7AC9FC4A89BC1A496BC9E90BC9B8CBE9989BF9886BF9583
BF9380BE917DAD83719773638664567E594A7B5B4E785C52765F5674625A73655F736964
736D6974716E747574757979
828A8B8E96979AA2A3A7AFB0B4BCBDC1CACAD0D8D8DFE8E8F0F8F8EDF4F4E8EEEEE0E6E7
D5DDDFC4D0D4B4C3C8A5B7BDA9B9BDAEBBBDB2BCBEB6BEBFB9BFBEBCC0BEBFC1BEBDBFBC
BCBDBBBABAB7BAB8B5BBB7B3BDB6B2C4BBB5CAC1BAD0C6BED6C9C1DACAC0DCCBBFDEC9BD
DEC5B8DABFB1D8BBADD3B6A8CDAFA1C8A99BC4A495C19F90C29E8DC29C89C39A87C39884
C49682C0927DAC816F926F5F8564557C574978584C745A4F725C53715F5871635D716762
716B6772706D737473757979
828A8B8E96979BA3A3A7AFB0B4BCBDC2CACAD0D8D8DFE7E6EEF6F5EBF1F0E3E9E9DAE1E2
CFD9DAC0CCCFB0C0C4A4B6BCA7B6BAABB7BAB0B9BAB4BBBAB7BBBAB9BBB9B9B9B7B8B8B5
B9B7B4B9B6B2BAB5B1BCB6B2C1B9B4C7BEB7CDC3BCD2C7BFD7C8C0D9C9BFDBC8BCDCC5B9
DCC2B4DCBFB0DCBDAED6B8A8D1B2A2CEAD9DCBA898C8A493C7A18FC69E8BC69B88C69A85
C99983BF907BA87F6C926F5F896657805B4C74554970554B6E58506D5C556D605A6E6560
6F6966716E6C727372747978
828A8B8E96979BA3A3A7AFAFB4BCBCC2C9C9D0D7D6DEE5E4EDF3F2E8EEECE0E6E5D6DEDE
CAD4D6BBC9CCAEBEC2A3B5BAA5B3B7A9B5B7AEB7B7B2B8B8B5B9B8B8BAB7BAB9B6BBB9B6
BCBAB6BEBAB5C0BBB6C2BCB7C6BFB9CBC2BBD0C6BED4C8C0D7C9C0DAC9BEDAC7BBDBC5B7
DAC1B3D7BBADD6B8AAD4B5A6D5B3A3D3B09FD1AB99CDA795CBA390C89E8AC79C87CA9B86
CC9983BC8D78A87D6A9671608965557B5749694B4069504668544C6958516A5D576B625E
6D68646F6D6B717371747878
828A8B8E96979BA2A3A7AFAFB4BBBBC1C8C8CFD6D5DDE3E2EAF0EFE4EAE9DEE4E3D3DBDB
C7D2D3BAC7C9AEBDC1A5B5BAA5B2B6A8B3B5ADB5B6B1B7B6B5B8B6B8B9B7BBBAB7BDBBB8
C0BCB8C2BDB9C5BFBBC8C1BCCBC3BDCFC6BFD3C8C0D7CBC1D9CAC0DBC9BEDCC8BBDCC5B8
DCC2B4DABEAFD7B9AAD3B3A4CFAE9FCDAB9ACCA896C9A492C9A08DC89E89CC9D88CD9B86
CB9881B98975A67B68946D5D825E5072504461453B614A41624F4763544E655A5568605B
6A66626D6C6A707271737878
828A8A8E96969AA2A2A7AEAEB4BABAC1C7C7CED4D3DBE1E0E9EFEDE3E9E8DCE2E1D1D9D9
C6D0D1BAC6C9B0BDC1A8B6BAA5B2B5A7B2B3ACB4B4B1B6B4B5B7B5B9B9B6BDBBB8C0BDB9
C3BFBBC6C1BCC9C4BECCC5BFD0C8C1D3CAC2D7CCC3DACDC3DCCCC1DDCBBFDEC9BCDEC7B9
DEC4B5DCC0B1DABBABD6B6A5D2B0A0CFAC9ACCA795CBA491CCA28DCDA08BCF9E89D09C86
C9957FB58671A076648E68587A5A4C694C415A423859443C5B49425E504A615651645D59
6863616B6A686F7170727777
82898A8E95969AA1A1A6ADADB3B9B9C0C6C5CDD2D1DADFDEE7ECEBE1E5E4DADFDED0D7D7
C7CFD0BCC6C8B3BEC1AAB7BAA6B2B5A6B0B2ABB3B2B1B5B3B6B7B5BABAB6BFBDB9C3BFBB
C6C2BDCAC5C0CDC7C2D1C9C3D4CCC4D8CDC5DBCFC6DECFC4DFCEC2E0CDC0E1CBBDE1C8BA
E1C5B6E0C1B2DDBDACDAB8A7D7B3A2D5AF9DD3AB98D3A894D3A590D3A28DD4A08AD29C85
C5917BB0816D9C726088635474554860463C513C334E3B3453433D584B465C534E615A57
65615F6969676E706F727777
82898A8D959599A0A0A5ACACB2B8B8BEC4C3CBD1CFD8DDDCE5EAE8DEE3E1D7DCDBCFD5D5
C6CECEBCC5C6B3BDBFAAB6B8A6B2B4A5AFB0ABB2B1B1B5B3B7B8B5BCBBB7C1BEBAC5C1BC
CAC4BFCDC8C2D1CAC4D5CDC5D9CFC7DCD1C8DFD2C8E1D2C6E2D0C4E3CEC1E4CCBEE4CABB
E4C7B7E3C3B2E0BEADDEBAA8DCB6A3DAB29ED9AE9AD8AB96D6A791D6A48ED5A18ACE9982
BC8B75A87B68946C5B7F5C4E694D41543E3546332B43322C4B3D38524742584F4B5D5855
62605D6767666C6F6E717676
81898A8D9494999F9FA4ABABB0B7B6BDC2C1C9CFCDD6DBD9E3E7E5DDE0DED5DAD8CED4D3
C6CDCDBEC6C6B3BDBFABB7B8A6B2B4A5B0B1ABB1B0B2B5B3B9B9B5BEBCB8C4C0BBC9C4BE
CDC7C1D1CBC4D6CEC6D9D0C8DDD3CAE0D4CAE3D5C9E5D4C8E6D2C5E6D0C2E7CEBFE7CBBB
E6C8B7E6C4B3E4C0AEE2BCA9E0B8A5DFB4A0DDB19CDBAC97DAA992DAA58ED59F88C8947D
B58570A075628964547354475D443948352D362721392B264438334C433F534C495A5553
605E5C6666656B6E6E717676
8189898C9394989E9EA3A9A9AFB5B4BBC0BFC7CCCBD4D9D7E1E5E2DADEDCD3D8D6CDD2D1
C7CDCCBEC4C4B4BDBDAEB7B8A9B2B4A9B1B1ADB1B0B4B5B2BBBAB6C1BEB9C7C2BCCCC6C0
D1CAC3D6CEC7DAD1CADED4CBE2D6CDE4D7CDE7D8CCE8D6C9E9D4C6EAD2C2EACFBFEACCBB
E9C8B7E8C5B3E7C2AFE5BDAAE4B9A5E2B5A0E0B19CDFAD97DDA992D9A38CD09B84C08D77
AC7D6A956C5B7E5C4E674B40513B323D2D262D201B362A263F353148403D504A47575351
5E5C5B6465646A6D6D707676
8188898C9393979D9DA2A8A7ADB3B2B9BEBDC5C9C8D1D5D3DEE1DFD7DBD9D1D5D4CCD0CE
C6CBC9BEC4C3B7BEBEB1B8B9ADB4B4AEB4B3B1B4B2B7B6B3BDBBB7C4C0BBCAC5BED0C9C2
D5CEC6DAD1CADFD5CCE3D8CEE7DACFE9DACEEBDACDEDD8CAEDD6C7EDD3C3EDD0BFECCDBB
ECC9B7EAC6B3E9C2AFE7BEAAE6BAA5E4B6A0E4B29CE2AE97DEA991D7A189CB967FB88671
A276638A65547454475D443945332A30231E261B173228243C3330453E3B4D4846555250
5C5B5A636463696D6D707576
8088888B9292959C9CA0A6A5ABB0AFB6BBBAC1C6C4CDD1CFDADDDBD4D8D6D0D2D0CACECC
C6CAC8C0C5C3B9BEBEB5BAB9B2B7B5B3B7B5B4B6B3B9B8B4C0BDB8C8C2BDCEC7C1D4CCC5
DAD1C8DFD4CCE4D8CEE8DACFEBDCD0EEDDCFF0DDCEF1DACBF0D7C7F0D4C3EFD1BFEFCEBC
EECAB7ECC6B3EBC2AEEABEA9E8BAA5E7B6A0E6B29BE2AE96DDA78ED29C84C18E78AC7D69
946C5B7E5C4C674B3F4F3A303628212016122117142E262339322F423D3A4B4745535150
5A5B59626463696C6C6F7576
8087888A9191949A9A9EA4A3A8AEADB3B8B6BEC2C0C9CDCBD5D8D6D2D4D2CDD0CDC9CCC9
C5C8C6C1C4C2BCBFBDB8BBB9B7B9B7B7B9B6B8B8B5BDBAB6C4C0BACCC5BED2CAC2D9CFC6
DFD3C9E5D7CCE9DACFEDDDD0F1DFD1F3DFD1F4DECFF4DBCBF4D8C7F3D4C3F2D1BFF1CEBB
F0CAB6EEC6B2EDC2ADECBEA9EABAA4E8B59EE5B099E0AB93D7A189C8947EB685709F7461
8763537152455A42374130282B1F1A1B120E231B182D262337312F403C3A49474551514F
595A59616363686C6C6F7576
7F87878990909299989CA2A1A6ABAAB0B4B3BABEBCC4C8C6D0D3D0CFD1CECBCDCAC7CAC7
C5C6C4C1C3C0BDBFBCB9BBB8B8B9B6B9B9B6BCBAB6C1BCB7C8C2BBD0C8C0D7CDC4DED2C8
E5D6CBEADACDEEDDCFF2DFD1F6E1D2F9E1D1F9DFCEF8DCCAF6D8C6F5D4C2F4D1BEF3CDBA
F1CAB5F0C5B1EEC1ACECBDA7EAB9A2E7B49CE2AD96DBA68ECE9982BC8A75A77A67906A58
79594A64493D4C372E32251F1F1713150D0B201A182B262435312F3F3C3B484745515150
595A59606363686C6C6F7576
7F8687888E8F9197979A9F9FA3A8A7ACB1AFB5B9B8BFC2C0C8CBC8CBCDCAC9CAC7C6C7C4
C2C3C1C0C1BEBCBDBAB9BAB6B9B9B5BAB9B5BEBBB5C3BDB7CCC3BBD3C9C0DBCEC4E4D4C8
EAD8CBEFDCCEF4DFD0F7E1D1FBE3D2FEE3D2FDE0CEFADCCAF8D7C5F6D3C0F5D0BDF4CCB8
F2C8B4F0C4AEEEBFA9EBBAA4E8B59EE3B098DBA890D19D86C08F79AC7F6C976F5E805F4F
6A4E41533D333B2B25241B17120B09110B091F1A182A26253532303F3D3B484746505150
585A5A606363676C6D6F7576
7E8586868D8E8F9595979D9CA0A5A4A8ADABB1B5B3B9BDBAC1C4C1C9CAC7C7C8C5C4C5C1
C1C1BEBFBFBCBCBCB8B8B8B5B8B7B3B9B7B2BEB9B4C2BCB5CAC2B9D2C7BEDDCEC2E8D5C7
EFD9CBF3DDCEF7DFCFFBE1D0FFE3D0FFE1CFFDDDCBFBD9C6F9D5C2F7D1BEF5CDB9F4C9B5
F2C6B1EFC2ABEBBCA5E8B69FE3B099DBA992D19E88C3917CB0836F9C7462866354705245
5942374230292B201B18110F0A0604140F0E1F1C1A2B28273533323F3E3D484847505251
585B5B606464676D6D6F7576
7E8586858C8C8D9393959B9A9CA2A1A4A9A8ACB0AEB4B7B5BBBEBBC4C6C2C4C5C1C0C1BE
BEBEBBBCBCB8BABAB6B6B6B2B6B4B0B8B5B0BDB8B2C1BBB4C7BFB7D0C4BBDBCBBFE5D1C3
EBD6C7F0D9C9F4DBCAF8DCCAFCDDCAFBDBC8F9D8C5F7D4C1F6D1BCF4CCB8F2C9B4F1C6B0
EEC1ABEABCA6E5B59FE0B099D9A892CF9F89C2927DB285729E76658967577356495D453B
46342D2F241F1C15120B0806060403151211211E1D2C2A293635343F3F3F484949515352
585C5C606465686D6D6F7576
7D8485848B8B8B9291929898999F9EA0A5A4A7ACAAAEB2B0B5B8B6BCBEBBC0C2BFBDBEBB
BBBBB8B8B8B5B6B6B2B2B2AEB4B2AEB7B4AFBCB7B1C1BAB3C7BEB5CEC3B8D7C7BCDFCCBE
E5CFC0E8D0C1EDD3C2F1D3C2F3D4C2F3D3C0F2D0BEF1CDBAEFC9B5EDC5B1EBC2ADE9BEA9
E5B9A4E1B49EDAAD97D4A691CA9D88BF927FB086749F79688B695A765A4D61493F4A3830
3227211E18150E0B090100000907071715152322212E2D2C373837414141494B4B515454
595D5D616566686D6E6F7676
7C8484838A8A899090909695969C9B9DA1A0A3A7A6A9ADABAFB2B0B5B7B5BBBCB9BABBB8
B7B7B4B4B4B1B3B2AFB1B0ACB3B1ACB6B2ACBBB5AFBEB7B0C3BAB1CBBEB3D2C1B6D7C4B7
DCC7B9DEC7B9E3CABAE5CAB9E7CAB9E7C9B8E6C7B5E5C3B1E1BFADDEBAA8DCB6A3DAB39F
D6AE9AD0A894C9A08DC19886B78F7DAB85749B78688A6B5C765C4F634C424D3C34362B26
201A17100D0C0100000201010F0F0F1B1B1A2626263031303A3B3A4244444B4D4D535656
5A5E5E616667686E6F6F7677
7C8384828989888E8E8D9393939998999E9D9EA3A2A4A8A6A9ACAAAEB1AFB4B6B3B7B8B5
B3B3B0B0B0ADB0AFABAFAEAAB0ADA9B1AEA8B7B1ABBAB3ACBFB6AEC7BAB0CBBBB0CFBDB1
D3BFB2D5C0B2D9C1B2D9C0B1DAC0B0DABEAED9BBABD6B7A7D2B3A2CFAF9ECCAB9AC9A695
C3A18FBD9A89B59382AE8B7BA48273967769866A5D755D52634F454E3F38392F2A231E1B
12100E0201010000000B0B0B1616162021212A2B2B3435353C3E3E4547474D5050545858
5B6060626768696F706F7677
7B8383818788868C8C8B9191909695959A999A9F9E9FA3A2A3A7A5A8ABA9ACAEACB1B2B0
AEAEACACACA9ABABA7AAA9A5ABA9A4AEAAA5B2ADA7B6AFA8BAB0A8C0B3A9C1B3A9C5B6AA
C8B7AACAB7ABCCB7AACDB7A9CDB5A7CBB2A4C8AFA1C5AC9DC1A798BEA394B99E8FB5998A
AF9384A78C7EA185789A7E71907568826A5E725E536250484E413B3B322E292421161514
0405050000010A0A0B1314141D1E1E2627272F3131383A3A404242484B4B4F5253565A5A
5D62626369696A7071707778
7B82837F8687848B8B898F8F8D9393929796969B9A9A9E9D9EA2A0A1A5A3A5A7A5A7A8A6
A7A8A5A6A7A4A6A6A2A5A4A1A6A4A0A7A4A0AAA6A0AEA8A1B1A9A1B5ABA2B7ABA2BAADA2
BCADA2BEADA2BEACA0BEAB9FBCA99DBAA69AB7A397B4A093AF9B8FAB968AA49084A18C7F
9A8579947F748E796E8672687B685F6C5C545D50494C433D3B35322A2826191919090B0C
010203090A0B1213141B1C1D2425262C2E2E3437373C3F3F4447474B4E4F525656585D5D
5E6464646A6B6A7172707778
7A82827E8586828989868D8D8A90908E9493929796959A99999D9B9B9F9E9EA19F9FA2A0
A0A29FA0A19F9FA09D9F9F9C9E9E9B9F9E9AA29F9AA5A09AA6A09AAAA29AABA299ACA299
AEA299AEA198ADA096AD9F95AC9E93AA9B91A7988DA3948A9F8F85998A8093847B8E7E74
86776F82746B7C6E6673655E665B5559504B4B45403B38352C2B2A1D1F1F0F1213050708
0809091214141B1D1D2325262B2D2E3335363A3D3D414445484B4C4E52535459595A5F60
606666666C6D6B7273717879
7A81827D8485818888848B8B888E8E8B91908E9393919695949897969A99989B9A999C9A
999C9A999B99999B98989A979899959998949997939B98939B98939E99929F98919E9790
9F978F9F968E9F958D9E948B9C928A998F87968C849288808E847D897F788379727D746D
78706A736B666C645F615A5657524E4C48453E3C3A2F302F222424151919090C0D0A0C0D
1416161C1E1F2426272B2E2F323536393D3D404344464A4A4C5051525757585D5D5D6263
626869676E6E6C7374717879
7981817C83847F8687828989858B8B888E8E8B90908D92928F9493919594929695939795
94979594969594969493959392939091918E90908C91908C918F8B938F8A928E898F8C86
8F8B858F8A848F8A838F89828D87808A847E87827B837D787F7A757A757176716D716E6A
6D69666B666364605C5A5654504E4B424241333635262A2B191F201115160F1213181A1B
1F222326292A2D30313437383A3E3E404445464A4B4C5051515656565B5C5B6061606566
646A6B696F706D747572797A
7980817B82837E8585808787838989858B8B878D8D898F8E8B90908C91918D92918E9291
8E92918E92908E918F8D8F8D8B8D8A8B8C89888A8688888588878388878286858084837E
83827E82807C817F7A817F797E7D787B7A7578777375747172726E6D6D6B6B6B68646564
6263615E5F5D5557564D4F4E424545363A3B2C31321F2627161B1C171A1B1D2021242728
2B2E2F313536373B3C3D4142424647474C4D4C5152515657565B5C5A60605F6465636969
676D6E6B71726E7576727A7B
7880807A82827C83847E8586808787828989848A8A868B8B878D8C888D8D898E8D898E8D
8A8E8D898D8C898C8B878B8985888680838180828080827F80817E7F7F7B7B7C79777976
7677747778747677737375716F726F6F726F6E716E6B6E6D686B6A6569696367665D6162
5B5F5F565A5A4F5353464B4B3C424332393A2C3233202527202425272A2B2C3031323637
373B3C3C4141414646464B4B4B4F504F5455535859575C5D5B61615F6465626869666C6D
6970716C7374707778737A7B
787F807981817B82837D84847E8585808687818788828889838989848A8A858A8A858A8A
858A8A858A898489888387868185837E82807B7E7C797C7A777A77757875727673717472
7073716F72706C706E6B706E6B706F6C706F686D6D676C6C656A6B6368695F64655B6161
565D5E5157594B50514348493C4243353A3B2E32332A2F30313637363B3C3B3F403F4445
434849484D4D4C51514F5555535859565C5D5A60605D636460666763696A666C6D696F70
6C72736E7576717879737B7C
777F807880817A81827B82837C83847D84847E85857F8686808686808787818787818787
8187878186868085857F84847D82827B807F797D7C757A796E73726B716F6C72706B7070
696E6D686E6D686F6E696F6F696F6E686E6D656C6C646A6B6067695E65675C6364596062
565C5E5157584D525344494A3E43443B3F403B3F413F4445424749464B4C494F504D5253
50555653595A565C5D595F605C62625E6465616768636A6A666C6D686E6F6A71726C7374
6E757670777872797A747C7D
777E7F787F807880817981817A81827B82837B82837C83837C83847D84847D84847D8484
7D84847D83837C83837C82827B8180797F7F777D7D757A7A7277776F75756C7273676E6F
676D6E686F6F676E6E686E6E696F6F686F6E686E6F666D6E646B6C62696A6067685E6567
5B616352595A4F55564B51534D52544F54554F5556515758545A5B565C5D585E5F5A6162
5D63645F656661676862696A646B6C666D6E686F6F6970716B72736C73746E75766F7777
71787972797A737B7C757C7D
767E7F777E7F777F80787F80787F807880817980817980817980817981817981817A8181
7A8181798081798081798080787F7F777E7F767D7E757C7C747B7B72797A7178796F7677
6F76776F76776E75766E75766D7375697172687072676E70666D6F656C6E646B6D626A6B
6067685E656661686961686962686962696A636A6B646B6C656C6D666D6E676E6F686F70
6970716A71726B72736C73746D74756E75766F767770777870787971797A72797A737A7B
737B7C747C7D757C7D757D7E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0116279 0.97619 0.233112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(315) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
405C6F405D70405D70405D71405E71415E71415E72415F72415F73425F73426073426074
426074436175436175436176436276436276446277446377446377446378446378446378
446377446378446378446378446378446378446478446478456478456478446478446478
446477446376446376446276446275436275436175436174436073436072425F71425E70
425E70425E71425F72425F72425F72425F72415E72415E72415E72415E71415E71405D71
405D70405D70405C70405C6F
405D70405E71415E72415F72426073426074436175436175446276446377446378456479
45657A46657A46667B47677C47687D48687E48697F486A7F486A80496A80496B80486A80
486A80496B80496B81496B80496B80496B80496C814A6C824A6D824A6D824A6D814A6D80
496B7F496A7E486A7D48697C48687C48687B47677B47667A466578466476456274446071
445F71446174446275446276446276446175446175436175436174436074426073425F73
415E72415E71405D70405C70
405D70415E71415F7342607443617544617644637745647946657A46667B47677D48687E
48697F496A804A6B814A6C824B6D844C6E854C70874D70884D71894D72894E728A4E738A
4E738A4D72894D72894D72884D72884D72884D72884E72874E73874D73874D73874C7286
4C70844B6F834B6E824B6F824C6F824C6E824C6D814B6B7F4A6A7D49687B486678466374
466274476577476579476679476579466579466579456478456377446276446275436174
426073415F72415E71405D70
405D70415E7242607343617544627745647846657A47667B48677D49697E4A6A804B6C82
4B6D844C6F864D70874E72894F738B50758D51768F517890527992537A93537A93527A93
527A92527A9152799152799152799051788F51778D4F768B4F758A4F75894F75894E7589
4E75894E75894E75884E74884F74884F73874F72864E70844D6E824C6D804B6B7E4A697C
4A697C4A697D4A6A7E4A6A7E4A697E49687D48677C48667B47667A466579456378446276
436175426073415E72405D70
405D71425F7343607444627645647846667B48677D49697E4A6B804B6C834C6E854D7087
4E728950748B51758E527790537992547B94557D97567F9957819B58829C58829D58829C
57819B57819B57809A568098567F97567F95557E94557C92547B90547A8F53798F52798E
52798E52798E52788E51788D52798D52788C52768B51768A5174895072864F6F834E6E82
4E6E824E6F834E6E834D6E834C6D824C6C814B6B804A6A7F49687D48677C47667A456478
446276436175425F73415D71
415E7142607344627645637846667A48687D496A7F4B6C824C6E844D70874F728950748C
51768E537891547B94567D96577F9958829C5A849F5B86A25D89A55E8BA75E8CA85D8BA7
5C89A45C88A25B87A15B86A05B869E5B859D5A859C5A859B59839A588297588096588096
578096578096577F96577F95567E94567E95567D93567B91567A9054788D537488527387
5274895274895173895073884F71874E70864D6E844C6D824B6B8149697E48687C47667A
456478446276426074415E71
415E7243607444637746657A48677D496A7F4B6C824D6E854E718850738B51768E537891
557B94567D9758809A59829D5B85A05D88A45E8BA7608EAB6291AF6495B36597B66395B3
6190AD608FAA608EA8608DA75F8CA65F8CA55F8CA45F8CA35F8BA35E8BA25E8AA15D89A0
5D89A05D889F5D879E5C869D5C859D5B859C5B849C5B839A5A8097587E95577C91577A90
567A91567A9155799054788E53768C51748A5072884E70854D6E834B6C814A6A7E48687C
46667A456377436074415E72
415E7243617545647847677C49697F4B6C824D6E854E718850748B52768F547992567C95
587F9959829C5B85A05D88A35F8BA7618EAB6391AF6595B4689AB96CA0C16B9FC06698B7
6596B36494B06494AE6493AE6493AD6493AD6494AD6494AD6495AD6495AD6495AD6494AC
6493AA6492A96390A8638EA7628DA6618CA4608AA35F89A25E879F5D859D5C839B5B829A
5B829A5A8098597F96577D94567B9254788F53768C5173894F71864D6E844B6B8149697D
47667A456377436175415E72
415F7244627646657A48687D4A6B814C6E844E718850748B52778F547A92577D9659809A
5B839E5D86A25F8AA6618DAA6391AE6594B26798B7699CBC6CA1C26EA4C46BA0C0689BBA
689AB8689AB76899B6699AB5699AB5699AB5699AB4699CB56A9DB66A9FB76BA0B86BA0B8
6B9EB66A9BB36A98B16996AF6895AD6693AC6691AB6490AA638FA9638EA8628DA7608BA5
5F89A35E87A15D859E5B829B597F97577C94557A9153778D51748A4F71864D6E834B6A80
48677C466479446276425F72
425F7344627746667A49697F4B6D834E708650738A52768E557A92577D9659809A5B849E
5E87A3608BA7628FAC6492B06796B5699ABA6B9EBF6DA2C36FA5C9699FC26599BB699DBD
6B9FBD6C9FBE6DA0BD6DA0BD6EA0BC6EA1BC6EA2BC6EA3BC6FA5BE70A6BF70A6BF70A6BE
70A5BE70A3BC70A1BA6F9EB86E9CB66C9AB46A98B26996B06895B06795B16796B26695B2
6491AD628EA9618BA55F88A15D849D5A8199587D95567A9153768D5173894E70854C6C82
49697E47667A446276425F73
425F7345637747677C4A6A804C6E844F728852758D547991577D9559809A5C849E5E88A3
618CA86390AC6694B16898B66B9CBB6DA0C06FA4C673AACE6DA4C7669BBD699EBF6CA1C1
6EA3C270A4C471A5C572A6C472A7C473A7C373A8C373A9C374ABC574ADC675AEC675AEC5
75ADC475ABC375A8C174A6BF73A3BD72A0BB709DB86E9CB76C9BB76C9CB96C9EBC6B9DBC
6999B76795B26591AD638DA86089A35E859E5B819A587D9556799153768C5072884D6E84
4A6B8048677B456377425F73
42607445647848677C4B6B814E6F8651738B53778F567B94597F995C839E5E88A2618CA7
6490AC6794B26998B76C9DBC6FA1C271A5C773AACD6EA5C86AA0C36CA2C56EA3C570A5C6
72A7C874AACA76ACCB77ADCB77ADCB78ADCA78AEC978AEC978ACC678AAC579AAC579A9C3
79AAC37AACC57AACC57AAAC378A7C176A4BF74A2BD72A0BC709FBB6F9FBC6FA1BF6FA3C3
6EA2C26C9CBA6997B46793AE648EA9618AA35E859E5B8199587C9455788F52748A4F6F85
4C6B8049687C456478426073
42607446647949687E4C6D834F718852768D557A92587E975B829C5E87A1618BA6648FAC
6794B16A98B76D9DBC70A2C273A7C875ABCE79B1D577AFD471A8CC71A7CA72A8CA74A9CA
76ABCC79AECF7BB1D17CB2D07DB2CF7DB2CF7DB1CE7CAFCB7CA9C57CA5C07CA1BD7BA0BB
7DA4BF7EA9C47FABC67EACC67DABC57BA8C379A6C277A4C075A2BF73A2BF73A3C173A5C4
72A5C570A3C26E9EBB6B98B56893AE658EA86189A25E849C5A7F97577A9153768C507187
4D6D8249687D466478436074
43607446657A4A6A7F4D6E8450738A54788F577C945A819A5D859F618AA5648EAA6793B0
6A98B66D9DBC70A2C274A7C877ACCE7BB2D677AFD472AACE74AACD75ABCD76ABCC78ACCC
7AAFCF7DB2D380B5D581B7D582B7D484B7D382AFCB7EA5C17CA1BB7A9BB57A9DB67DA2BC
7FA0BC81A1BB83A6C184ADC882AEC97FACC77CA9C47AA7C278A4C177A4C276A5C376A7C6
77AACA76A9C973A4C2709EBB6C98B46892AD648DA66087A05D829A597D9455788E517389
4E6E834A697E466579436074
43617547667A4A6B804E708652748B557991597E975C839D6088A2638DA86692AE6A97B4
6D9CBA70A1C174A7C778ACCE7BB1D47EB5D97BB2D676ACCF77ACCF78ADCF79ADCE7BAECF
7DB0D07FB3D282B5D486B8D785B2D07EA4C07B9FBA7D9EB97D9CB77D9EB97D9DB97D9BB5
7C9BB47E9EB781A3BE86A9C487AEC983AEC980ACC67DA9C57BA7C37AA6C37AA7C57AAAC8
7AABCA7AABCA79A9C775A4C1709DB96C96B16790AA638AA35F849C5B7F9657799053748A
4F6F854B6A7F47657A436174
43617547667B4B6B814F708753768D577B935B80995E86A0628BA66590AC6995B26C9AB8
709FBE73A5C578ABCD7CB2D580B7DA7FB7DA7BB2D579AED17AAED07BADCE7CADCE7EAFCF
80B0D082B0CF82AFCD81ACCB80AAC87FA9C780A8C681A7C581A7C482A8C682A8C582A8C4
81A8C47FA5C27DA1BD7DA2BC83A9C287B0CA85B0CA82ACC87FAAC67EA9C57DAAC77DABC9
7DADCC7DAECE7CADCD7AAAC775A2BE6F9AB56A93AD658DA661869F5C8198587B9254768C
5070864C6B8047667A436175
44617548677C4C6C8250728855788F597D965D839C6188A2648EA96893AF6C98B56F9DBC
72A3C276A8C97AAFD182B9DD87C0E67EB6DB77ADD07AAED07CAFD07EB0D07FAFCF80AFCE
81AECD80AAC77EA2BF7A9BB77B9CB880A3BF82A6C384A9C785ADCA86AECB86AECB86B0CE
86B0CD85ACCA83AAC781A9C480A8C385ADC787B0CB84AEC982ACC881ACC880ACC980ADCB
80AECC7FAFCE7EAECD7BAAC878A4C1729DB86D95B0688FA86388A15E829A5A7C9355778D
5171874C6C8148667B446175
44627649687C4D6E8352738A5679915B80985F859F638BA56791AC6B96B36E9BB972A1BF
75A6C578AACB7BB0D27FB5D87EB4D879ADD179ABCE7CAED07FB0CF81B0CE82AFCE83AFCD
84AECB84ACC983A9C581A4C082A2BE83A2BF84A3BF85A4C186A5C287A6C487A7C488A6C4
88A6C487A9C786ABC784AAC682A9C681A8C484ABC686AEC985AEC984ADC983AECA83AECC
83B0CD83B1D086B6D582B1D07AA6C3759FBB6F97B26A91AA658AA360849C5B7E9556788E
5272884D6C8148677B446175
44627649687D4E6F8453758B587B935C819A6187A1658EA86A94AF6E99B6719FBD75A4C3
77A9C979ACCE79AED072A7CA6CA1C573A7CA7CAED080B0D083AFCF84B0CE85B0CD86AECC
87ADCA87ACC887ACC888ABC888A9C689A8C589A9C58AA9C68BABC78CABC88CABC88CABC8
8CABC88CABC88CA9C789A6C485A3BF82A0BB82A1BC85A7C287ACC887AEC986AECA86AFCB
85AFCD85B1CE85B0CD83AECB7DA8C577A0BB7199B36C92AC668CA461859D5C7F9657798F
5373894E6D8249677C446275
4562764A697E4F708554768D597D955E839C638AA46890AB6D97B3719DBA75A3C178A8C8
7BADCE7CB0D37CB2D67AB0D57AAED07DAFD082B2D285B3D287B2D088B1CE8AB0CD8AB0CC
8AAFCA8AAECA8CB0CC8DB1CE8DB0CC8EAECA8EAECA8FAECA90AECA90AECB91B0CC91B1CD
92B0CC91AFCB90AECA8DACC78BA9C589A7C287A6C287A8C288ABC589AEC889AFCA88B0CB
87B0CC87B0CD87B1CE84AECA7EA8C379A1BC739AB56D93AD688DA563869E5E8097587A90
5374894E6E8349687C446275
4563774B6A7F50718756788F5B7F9661869E668DA66B94AE709AB675A1BE79A7C57DADCC
80B2D382B7D983B9DC84B9DD85BADD87B9DA88B8D68AB7D58CB6D38DB5D18EB4D08FB3CF
8FB3CD8FB2CD90B2CE91B4D092B5D192B4CF93B4CF94B4D094B3CF95B3CE95B3CE96B4CF
95B4CE94B2CD92B1CB91AEC88EABC58CA9C38BA9C38AAAC38BACC68CAFC88BAFC989AFC9
88AFCA86AFCA86AFCB86B0CD81ABC87BA3BF759CB66F95AE698EA664879F5F8198597B91
54748A4F6E834A687C456276
4563774B6B7F5172885779905D81986388A1698FA96E97B1749EBA79A5C27DACCA81B2D2
85B8D988BDE08AC0E48CC1E38DC0E28CBEDE8DBDDC8FBCD991BAD792BAD693B9D594B8D4
94B6D294B5D195B5D196B7D397B8D497B7D397B6D198B6D098B6D098B6D099B6CF99B5CF
98B5CE97B4CD96B3CB94B0C992AEC690ACC28EAAC18EAAC28FADC68FAFC88DAFC88BAFC8
89AEC986ADC883ACC884AFCC83AECA7CA5C0769DB77095AE6B8FA765889F6082985B7B91
55758A506F834A687C456276
4664784C6B80527389597B925F839A658AA36C92AC729AB577A2BE7DA9C682B1CF87B8D8
8BBFE08FC5E692C8EA94C9EB94C5E693C2E094C0DE95BFDD96BFDC97BEDA98BEDA99BED9
9ABCD79ABBD59ABAD49BBAD49BBAD69CBBD69CBBD69CBAD59DBAD49DBAD49EBBD49EBAD3
9DB9D19CB6CF9AB4CD98B3CB97B1C894AEC593ADC393AEC593AFC792B0C890B0C98EB0C8
8AAEC785ABC57DA5C179A4C17FAAC67EA7C1769CB67196AE6C8FA76789A06182995C7C91
56758A506F844B697D456276
4664784D6C8154748A5A7C9361859C688DA56E95AF759DB87BA6C182AECB88B6D48DBEDE
92C7E897CEF09AD2F39BCFEE9BC9E79AC5E49AC3E19BC3E19CC4E09DC4E19EC4E09FC4DF
A0C3DEA0C2DCA0C0DA9FBED79FBDD7A0BED8A0BFD9A1BFD9A1C0D9A2C0D9A2BFD8A2BED6
A2BDD5A1BBD3A0B9D09EB6CC9BB3C99AB1C899B2C898B3C997B4CA96B4CB94B4CB91B2CA
8DB1C988ADC682A8C07AA1BA7499B37499B2769AB37296AE6D90A76889A06283995D7C92
57768B516F844B697D456276
4664784E6D8255758B5C7E9463869E6A8FA87298B179A1BB80AAC587B2CF8DBBD994C4E3
99CCEC9ED2F1A1D2F1A1CFEE9FCBEA9FC9E7A0C8E4A0C8E4A1C9E5A3C9E5A4CAE6A5CAE5
A6CAE5A6C9E3A5C7E0A5C5DDA5C3DCA5C2DAA4C1D9A4C1D8A5C1D9A5C1D9A6C1D8A6C0D8
A6BFD6A5BED4A3BBD0A1B7CC9FB6CB9FB6CC9FB7CC9EB7CD9DB8CE9BB7CD99B7CD96B6CB
92B3CA8EB0C789ADC583A8C17EA3BC7BA0B8789CB47497AE6F91A76A8AA06484995E7D92
58768B5270844C697D456276
4765794E6D8256768C5E7F966588A06D91AA759BB47CA4BE84ADC98CB7D393C1DF9BCBEB
A2D2F3A7D4F5A9D4F3A8D1F0A6CFECA5CDEAA5CCE8A6CCE8A7CDE9A8CFEAAAD0ECABD1EC
ACD1EAACD0E9ACCEE6ABCBE4AAC9E1A9C7DFA9C5DDA9C4DBA9C4DAA9C4DAA9C3DAA9C2D8
A9C1D7A8BFD4A7BDD2A6BCD1A6BCD1A5BCD1A5BDD2A4BDD2A3BCD1A1BBD09EBAD09CB8CE
98B6CD94B4CA8FB1C88AADC587ACC483A8C07DA0B77799B07192A86B8BA165859A5F7E92
59778B5270844C697D466376
4765794F6E8357778D5F8197678AA17094AC789DB680A7C189B1CC91BBD79AC6E3A3D1F0
ACDBFAB4DFFDB5DDF9B1D7F3ADD3EEABD1ECAAD0ECABD1ECACD1EDADD2EEAFD4EEB1D5EF
B3D6EFB3D5EDB2D3EAB1D0E7B0CDE5AECBE2ADC8DFACC7DDACC5DCADC4DBADC4DAADC4DA
ADC3D9ACC2D7ACC2D6ACC2D5ACC2D5ADC2D6ACC2D6ABC1D5A9C0D4A6BED2A4BCD1A1BBD0
9EBACF9AB8CE97B7CE92B4CC8DB1CA87ACC481A3B97A9BB17494A96D8CA167859A607E93
5A778B5370844D6A7D466376
476579506F8358788D618298698CA27296AD7BA0B984AAC48DB5CF96BFDB9FCAE6A8D4F1
B3DEFAB9E1FCBAE0FAB7DBF5B2D6F0B0D4EEAFD3EDAFD3EDB0D3EEB2D5EEB5D7EFB7D8F0
B9D9F1B9DAF1B9DAF1B7D7EEB5D3EAB2CFE5B0CBE1AFC8DEAFC7DDB0C7DCB0C7DCB1C7DB
B1C6DBB1C6DAB2C6DAB3C7DAB4C8DBB4C8DBB3C8DBB1C7DAAFC5D8ADC2D6AAC0D4A7BFD3
A4BDD1A1BCD19EBAD09AB9CF94B5CB8CADC385A5BA7E9CB27795AA708DA269869A627F93
5B788C5471844D6A7D466376
486579506F8359798E6283996B8DA37497AF7EA2BB88AEC792B9D39BC4DEA4CEEAACD5F0
B2D9F3B8DDF7BBDEF7B9DBF4B5D7F1B3D5EFB2D4EDB2D3ECB4D5EEB7D8F1BBDCF5BFDFF8
C1E0F8C1DFF6BEDDF3BCDAF0B9D7EDB6D1E7B3CCE1B1C9DDB1C7DBB1C7DBB2C7DCB3C7DC
B5C8DCB6C9DCB8CBDDBACCDEBACDDFBACCDFB9CCDEB7CADDB4C8DAB1C5D8AFC4D7ACC2D5
A9C0D3A7BFD2A5BFD2A1BED29AB8CD91AEC389A6BA819EB27996AA728EA26A879A637F93
5C788C5571844D6A7D466376
486679516F845A798E6383996C8EA47699B081A5BC8CB1C997BDD6A1C9E3AAD3EEB2DAF4
BBDFF7C0E1F8BEDEF6BADAF2B7D7EFB5D5EDB3D3EBB3D2EAB3D2E9B5D3EAB8D6ECBDD9EE
C3DDF2C4DDF3C1DBF1BED9EEBBD8EDB7D2E7B4CBDFB2C7DBB2C6D9B3C6D9B4C7DAB6C8DB
B8CADDBACCDEBBCCDEBCCEDFBED0E1C0D2E3BFD1E2BCCEE0B9CBDDB6C9DBB4C7D9B2C5D7
AFC3D5ACC1D3A9BFD1A3BCCD9CB6C894AFC18CA6B9849FB27C97AA748FA26C879A648093
5D788B5571844E6A7D476376
486679516F845A798E6384996D8EA4789AB083A6BD8FB4CC9CC2DBA8CFE9B1D9F2B7DCF6
B9DBF3BADBF1BBDBF1B9D8EFB7D5EBB6D3EAB5D2E8B4D1E6B3CFE3B1CCE0AFCADEB0CBDF
B4CDE2B7CEE3B8CEE1B6CBDEB2C7DAB1C5D8B2C6D9B2C5D7B3C4D6B3C5D7B5C6D8B7C9DA
BACDDDBDCFE0C0D0E1C4D4E5C7D7E7C7D6E6C4D3E4C1D1E2BECFE0BACCDDB7C9DAB5C7D8
B3C6D6B2C5D5B0C3D3AABDCDA1B5C598AEBF8FA7B9879FB17E97AA7690A26D889A658093
5E798B5671844E6A7D476376
48667A516F845A798E6483986E8EA4789AB084A6BD92B5CDA2C7DFB4DCF6BEE5FFBEE0F8
BDDCF3BCDAEFBBD8EDBAD6EBB8D4E9B6D2E7B5D1E5B5D0E4B3CDE1B1C9DBAEC6D8AAC2D4
A5BCCFA5BBCEA8BDD1ABBED1AEBFD1B0C2D3B1C3D5B2C4D5B3C4D5B3C4D4B3C4D4B4C4D4
B5C3D3B8C5D4BFCCD9C6D3E0C8D5E3C6D4E2C8D5E4C6D5E3C1D1E1BDCEDEB9CAD9B7C7D7
B7C7D6B7C7D6B6C5D4B1C1D0A7B9C89CB0C193A9BA89A1B28098AA7790A26F889A668092
5E798B5671844F6A7D476376
486579516E825A788C6382966D8DA27898AE84A5BB92B4CBA6CAE3B4D8F1BFE0F7C6E5FB
C5E1F6BFDBF0BAD6EBB7D3E8B6D2E6B6D0E3B5D0E2B5D0E2B4CDDEB2C8D9AFC4D4ACC0CF
AABDCDA9BBCBA9BAC9ABBBCBADBDCCB0BFCEB1C1D1B2C2D2B3C3D2B3C2D1B3C1D0B3C0CF
B2BFCFB2C0CFB2C1D0B4C3D1B8C6D4BBC9D7BBCAD8BBCAD8B9C8D6B8C7D4B8C7D5B9C7D5
BAC7D5BBC9D7BAC8D5B3C2D0AABDCCA1B5C596ABBB8CA2B28299AA7990A1708899678092
5F788A5771834F6A7C476376
486477516D8159778B6380956C8B9F7795AA82A1B78EAEC49CBCD3A8C7DEB2CEE4BAD5E9
BDD7EBBAD4E9B6D2E5B6D1E4B5CFE2B5CDE0B3C9DBB2C7D7B4C9DAB5CADAB4C7D7B3C4D2
B1C0CEB0BECCAFBDCBB0BECBB0BECBB0BDCBB1BFCEB2C2D0B3C2D1B3C1CFB3C1CDB4C1CD
B4C1CEB4C0CEB1BECCABB9C7A7B6C5ABBAC8ADBDCBB0BECCB3C1CEB7C4D0B9C5D1BAC6D2
BCC8D4BDC8D4BAC6D2B3C1CEABBCCAA3B5C499ACBB8EA3B28499A97A90A1708898678091
5F788A5771834F6A7C476375
486477506D80597589617F936B889C7492A67E9CB189A7BC94B1C69FBCD1AAC4D8B0C9DD
B3CCE0B4CCE0B5CCDFB5CDE0B6CEE0B4CBDCB3C7D8B0C3D2AEBECCADBCC9ACBBC7A9B6C2
A5B1BDA5AFBAA6B0BBA8B1BCABB5C0AFBAC6B2BECBB3C1CEB4C2CEB4C0CCB3BFCAB5C1CB
B7C3CDB7C3CEB5C1CDB2BECBAFBCC8AEBAC6AFBAC6B2BDC8B6C1CBB9C4CDBAC6CFBCC7D1
BEC9D3BFC9D3BBC5CFB1BDC9ABB9C5A6B6C49CAEBD90A3B28599A87A8F9F708797677F90
5F77895770824F697B476275
4764774F6C7F577488607C90688598718EA17A97AA839FB38CA7BB95B0C39EB8CBA5BED1
ABC3D6AEC6D9B1C8DAB4CBDDB6CCDDB5CADBB3C7D7B2C3D1AFBECBACB7C3A8B1BCA5ADB8
A4AAB3A4A9B1A5A9B1A8ADB6ADB4BFB1BBC6B4BFCBB6C1CEB6C1CDB4BFCBB2BBC7AFB8C2
B0B9C2B6C0C7BAC4CDBAC4CDB7C1CBB6BFCAB5BFCAB7C1CAB9C3CCBBC5CEBCC5CEBDC7CF
C0C9D1BEC8D0B8C2CBB5BFC9B1BDC8ADBCC9A2B3C191A3B18598A67A8E9D708595677D8E
5E7687566F814E697B476275
4763764E6A7E5672855E798C6681946E899C7691A47E99AB86A0B28EA6B895ADBF9CB4C6
A2BACBA7BFD0ADC4D5B1C8D9B4CADAB5CAD9B5C8D7B3C5D3B2C1CEB0BCC8AEB8C2ACB4BE
ACB3BCACB2BAADB3BBAFB6BEB2BAC3B5BEC9B7C2CDB8C3CFB8C3CFB6C1CCB4BEC8B0BAC3
ADB5BDAAB3BBACB6BEB3BCC4BAC2CABCC4CCBCC4CCBCC4CCBCC4CCBBC3CBBBC3CABDC5CC
BFC5CDBCC3CBB8C0C8B8BFC7B4BCC5A9B4BF9CAAB78F9FAD8395A3788C9A6E8392667B8C
5D7585556E7F4E687A476274
4662764D697C5570835C778A637E906B8597728C9E7993A58099AA869EB08DA5B695ACBD
9BB2C3A2B9C9A9BFCFB1C6D6B6CADAB7CBDAB6C9D8B5C7D5B5C4D1B4C2CEB3BFCAB2BDC7
B2BBC4B3BBC4B4BCC5B6BEC7B8C1CABAC3CDBBC6D0BCC7D1BBC6D1BAC5CFB8C3CCB5BFC8
B2BBC4AFB7C0ACB4BDAAB3BBABB3BBAFB7BFB2BAC2B3BBC2B4BBC2B8BEC5BCC1C8BEC2C9
BDC1C8B9BEC5B5BAC2B2B6BFAEB2BAA4ACB698A4B08C9BA880919F7688966C808F647989
5C7383546D7E4D6779466174
4662754C687B536E805A7486607A8C6781936E8798758D9E7B93A58299AB889EAF8EA4B4
96ACBC9EB4C4A7BCCCB0C5D3B6CAD9B8CCDAB8CBD9B8C9D6B8C8D4B8C6D1B8C5D0B8C4CF
B8C3CDB9C3CDBAC4CEBCC6CFBEC8D2BFCAD4C0CCD5C0CCD6C0CBD5BFC9D3BDC7D0BBC5CE
B8C1CAB5BEC6B2BBC2B0B7BFAEB5BCADB4BBAFB5BBB2B7BDB5BBC0B9BDC3BCBFC5BDC1C7
BBBEC4B5B8BEAFB3B9A9AEB5A4A9B19DA5AF94A1AC8998A47C8C99728391697C8B617685
5A7080536B7C4C6677466173
4561744B6779516C7E5771835E7788647D8E6A8293708898778D9D7D92A18297A6899EAC
92A5B49CAEBCA5B8C6AEC1CEB6C9D6B9CCDAB9CCD9BACBD8BBCBD7BBCBD6BCCAD5BDCAD5
BECBD5BFCBD5C1CCD6C2CDD7C4CFD8C5D0DAC6D1DBC6D1DAC5D0D9C4CFD8C3CDD5C1CAD2
BEC7CEBCC3CBB9C0C7B6BDC3B5BBC1B5BAC0B5BABFB7BBC0BABCC1BCBDC3BEBEC3BEBEC2
BABABEB1B2B7AAACB1A3A6AC9CA1A8949BA38C96A0818E997685916D7D8A6577855E7281
586D7D5169794B6476456072
4560734A6577506A7C556F805B7485607889667D8D6C8292718796778C9A7D919F8396A4
8B9EAB94A7B49FB0BDA8B9C5B2C3CEB8CAD6BBCDD9BCCEDABECFDBBFD0DCC1D0DBC2D0DA
C4D0DAC5D2DBC7D3DCC8D4DDCAD5DECBD6DFCCD7E0CCD7DFCBD6DECAD4DCC9D2D9C7CFD6
C5CCD3C2C9CFBFC6CBBDC3C8BBC0C5BBBFC3BBBEC2BBBEC2BCBEC2BCBEC2BDBDC1BABABD
B1B2B6AAABAFA2A4A9999CA190949A878D947F868F76808A6E7B8667768361727F5B6E7C
556A7A4F66774A6374455F72
4460724964764E6879536C7D5870805D7484627988687D8C6D818F738593788A977E909D
8698A490A1AD9AABB6A4B5C0ACBEC9B5C6D2BBCDD8BFCFDBC1D1DDC3D3DFC5D5E0C7D6E1
C9D7E1CBD8E2CDD9E2CFDBE4D0DCE5D1DDE5D1DDE5D2DCE4D2DBE3D0DAE0CFD7DECCD5DB
CAD1D7C8CED2C5CACFC3C8CCC2C5C9C0C3C7C0C1C5BFC0C3BEBFC2BFBEC1BCBBBDB5B4B7
ACABAFA3A2A698999E8E909684878E7A7F866E747B68707866717B616F7B5C6D79576A78
5267764D6474496173445F71
445F724862744C667751697A556C7C59707F5E7482637886697C8A6E818D7485927A8B97
82929D8A9AA494A3ADA1AEB8ABB9C3B5C3CCBCCBD5C1D0DAC4D3DEC7D6E1CAD9E3CCDBE6
CFDDE8D1DFE9D3E1EAD5E2EBD7E3ECD8E4ECD8E4EBD8E3E9D7E0E7D6DEE4D4DBE1D2D8DD
D0D5DACDD1D6CBCFD2C9CCCFC7C8CBC5C6C8C3C3C5C2C1C3C1BFC0BEBBBDB8B5B7AFADAE
A4A2A599989B8E8E9283858A797C816F737A666D74616A725E69735B6974576774536673
4F64734B6272476071435E70
435E714761734A64754E6676526978566B7A5A6E7C5D707D6274816779866E7F8A75848F
7B8A9485939D909EA79CA9B2A9B4BDB5C1C9BECBD4C4D2DBC8D6E0CBDAE4CEDDE8D2E1EC
D5E4EFD7E6F1DAE8F2DCEAF3DEEAF3DFEAF2DFEAF0DFE9EFDEE7ECDDE4E9DAE0E5D8DCE0
D5D9DCD2D5D9CFD1D4CDCED0CACBCDC8C8C9C7C5C6C6C2C3C3BEBFBEB9B9B6B1B1AAA6A6
9E9A9C9190918585887A7C7F6F717562676C5C61685A626A58626B55626D53626E50626F
4C616F49606F465E6F435D6F
425E704660714961724C63734F6574526775556875586A765B6C7861707B6876816F7D87
77858E818E978C98A198A3ABA6B0B7B4BEC5BFCAD1C6D2DACBD8E1CFDDE7D3E2ECD7E6F0
DAE9F4DEECF6E0EEF7E2EFF6E4F0F6E6F1F7E7F1F6E6EFF3E5ECEFE3E8EBE0E5E7DDE1E4
DADDE0D7D9DBD4D5D6D1D0D1CECCCDCCC9C9C9C5C5C6C2C1C2BDBBBBB4B3AFA9A8A29D9C
9490918685867A7A7C6D6F726063675355594F5358525960515B64505D674E5D694C5E6B
4A5E6C475D6D455D6E425C6E
425D6F445E70475F704960704C61704E627050636F52636F55646E596770616E7769757E
717D867B868E879198949DA3A2ABB0B0B8BEBDC6CBC8D2D9CFDAE2D4E0E8D8E5EEDDEAF2
E1EEF5E5F1F8E8F3FAEAF5FBECF6FBEEF6FBEEF5F9EDF3F6ECF0F3EAEDEFE6E9EBE3E5E6
E0E0E1DCDCDCD9D7D7D5D2D2D2CDCDCEC9C8CAC4C2C5BEBCBEB6B4B4ACAAA7A09E999392
8A86867D7A7B6F6E7062636657595D4F52574C51574C535A4C565F4B58624A5965495A67
475B69455B6B435C6C415C6E
415C6F435D6E455D6E475E6D495E6C4A5E6B4C5D694D5D674E5C66525F6759656C626D74
6B757C757E8480898F8C959A99A1A6A7AFB4B8BFC4C6CED2D0DADFD7E3E8DDE9EFE2EEF4
E7F3F8EBF6FAEEF8FCF1FAFEF4FBFEF5FBFDF6FAFCF4F8F9F2F4F5EFF1F1ECECEDE8E7E7
E4E2E2E0DDDDDCD8D7D8D3D1D4CDCBCFC8C5C9C1BFC1B8B5B7AEAAAAA19E9B93918D8785
807B7A726F6F6462635555584A4C4F46494D454A50464D5546515946535D465561465764
455867435A69425A6B415B6D
415C6E425C6D445B6C455B6A465A6947596647586447566046525A48545A515B625A636A
626B716B747A767F85838B8F90979B9EA4A7AEB3B5BFC4C6CED4D6D9E1E4E0E9ECE7F0F3
EDF6F8F2FAFCF5FDFEF8FEFFFAFFFFFDFFFFFDFEFEFBFBFBF8F7F6F5F2F1F1EEEDEDE9E8
E8E3E2E3DDDCDED8D5D9D1CED3CAC7CCC3BFC4BBB6B9B0ABABA29E9D94918E8784807977
716C6C63606055535449484A3D3C3D393A3D3E434840484F424C55424F5943525E435461
42566542586741596A405B6D
405B6D415B6C425A6A43596843576543566243535F42505A404C54424B52495258525A60
5A6268656B706F75797A8085868C9092989AA0A5A7B0B5B6C1C5C6CFD3D4DCE1E2E7ECED
F0F4F5F6FBFBF9FEFEFCFFFEFFFFFEFFFEFCFFFCF9FEFAF7FCF7F4F9F2F0F4EDEAF0E7E4
ECE3DFE6DDD9DFD5D1D8CDC8D0C5C0C6BCB6BBB0AAADA29D9F94908F8683807875716B69
625D5C5350504543453B3A3C35353836373B393D433B434A3D48513F4C56404F5B40525F
405463405766405869405A6C
405B6D405A6B41586841576641556340535F40505B3F4C563D48503C454A3F474C474F54
50575C596064646A6E6F74787A7F82878C8E94999BA2A6A8B1B5B6C0C3C4CFD1D1DBDDDD
E5E7E7EDEFEDF3F4F1F7F7F3F9F7F2FAF5F0FAF3EEFAF2ECFAF0EAF7EDE6F4E8E2EFE3DD
E9DCD6E3D5CFDCCEC8D2C5BFC8BBB5BCAFA9AEA19C9F938E8F85817E76736F68655F5A58
504C4B413E3F3534342C2B2C2A2A2D30323634393F373F473A454D3C49533D4D593E505D
3F53613F55653F58683F5A6C
3F5A6C3F596A3F57673F55643F53603E505D3D4D583B495339444C363E45373E433E454A
474E524F565A575D6162676A6F73767C80828A8E8F989C9DA6AAAAB3B7B6BFC2C2CBCCCB
D5D4D2DDDBD8E4E1DDE9E5E1EBE6E1EDE6E1EFE6E0F0E5DEF0E3DBEEE1D9EBDED5E6D8D0
E1D2CAD9CBC3D1C2BBC7B9B2BBADA6AD9F9A9F928D8F847F7E75716D66635D57554D4948
3D3A39302E2D2523241F1D1E2322242B2E3230363C343C4437424B3947513B4B573C4F5C
3D52603E54643F57683F596B
3F5A6C3F58693E56663E54633D515F3C4E5B3A4A56384650364149323B4230363B34393D
3D4246454A4E4E5356585D5F65696B7175777E81838B8E8F97999AA4A5A4B0B0AEB9B9B7
C1C0BEC8C6C3CFCCC8D5D1CCD9D4CFDAD5CFDCD4CEDCD2CCDCD0C9D9CDC5D7C9C1D3C5BD
CEBFB7C6B7AFBCAEA7B2A49EA79994998D888A7F7B7A716D6B63605B55534B46453B3737
2C292A201E1E161313171516212225272B302D343A313B4334404A374550394A563B4D5B
3C515F3D54643E57683F596B
3F5A6C3E58693E55653D53623C505E3A4C5938495436444E333F473039402C33382C3236
32383B3B3F4244484B4F5355595C5F6366686F72737C7E7F898B8C9596969F9F9EA7A7A5
AFAEACB7B5B1BCB9B6C0BDB9C4BFBAC6C0BAC7BFB9C6BDB7C5BBB4C3B8B1C0B4ADBCAFA8
B5A9A1AEA19AA599939C908A918680847A75756D69665F5C57514F474342373434282627
1C1A1B110D0D100C0D18181A202226262B312B333A2F3A42333F493544503849553A4D5A
3B505F3C53633D56673E596B
3F5A6C3E57683D55653C52613B4F5D394B5837475334434D313D462E373F292F35262A2E
292C2F303437393C3F4145474C4F51575A5B6265666D6F70797A7A8384848C8C8C949493
9B9B99A1A19FA7A5A2ABA8A4AEAAA6AFAAA6AFAAA4AEA8A2ACA69FAAA29CA69E97A19892
9A918B9389848C827D837A7579716D6E6663615A58524D4B423F3E3431312726261C1A1B
0F0C0C0C0909131214191B1E202429252C322A333B2E3A43323F4A344450374956394D5B
3B505F3C53633D56673E596B
3E596C3E57683C54653B52613A4F5D384B5836475333424D303D462C363E272E35202428
1D1F222426292D303236383A3F4243484B4C5154545A5D5E6467676E6F6F7879787F8080
8586868B8B8A908F8E93919094929096939196939095928E938F8B908C888B868285807C
807A7679736F726C696A6562605B5954514F4845443A39382E2D2D2221221515160B0B0C
0908090F0E0F1516191B1E2320262C252E352A353D2E3B4431404B344551364956384D5B
3A505F3C53643D56683E596B
3E596C3D57683C54653B5261394F5D384B5935475433424E2F3D472C373F272F3621272C
1A1D2018191B1F2123292B2D313536393D3E414445494B4C515353595B5B616363686A6A
6E706F737373767677797A797C7C7B7D7D7C7E7D7C7D7C7A7B7A7878767474716F6C6A67
64625F5F5D5B59585651504F4646463D3C3D3333342828291C1D1E1313140B0A0B050202
080606101114171A1E1C2228222A302630382A36402E3C4731414D344652364A57384D5C
3A50603B54643D56683E596B
3E5A6C3D57693C55653B5262394F5E374C5A35485533434F303E492C394227323A222A31
1D222615181A1416171B1E202428292D3032343638383B3D3E414345484A4B4E50525455
575A5A5B5E5F5F62626265656467676567676568676567676465656263635D5F5F585A5B
5255564A4D4F4345473B3D3F3335372C2E302325271A1B1E101113070809020000040202
0D0D0F13171A191F241F262D232D3528333D2B39432F3E4A32434F344754364B59384E5D
3A51613C54653D57683E596C
3E5A6C3D57693C55663B536339505F384D5B36495733455230404C2D3B4629353E242F36
1F272D1A1F24131619121416181B1D1F2324262A2C2B2F302F3233343738383C3D3B4041
3E4345424749474C4D4A4F504D51534E53544F54554F53544D52534C51534B5053484E52
44494D4045493A3F4333373B2A2E31202427161A1D0E111406080A0000010301020A0B0E
111418171D221C252B212B3326323B2937412D3C4730414D334552354957374C5B394F5F
3A52623C55663D57693E596C
3E5A6C3D586A3C56673B53643A5161384E5D364B593447553243502F3F4A2B394427343D
232D351E262C181E2311141710121416191B1C202220242623272926292B282D2E2C3233
2F353730373832383A353C3E383F413940423941433A41453A4145384044374044363E43
333B402E363B262F3420272C181F2310151A0A0E1204070A000001020102090A0E101419
161D231C242B202B3325313A2836412C3B472F404C314451344755364B59384E5D395060
3B53643C55673D58693E5A6C
3E5A6D3E586A3D57683C54653A526339505F374D5C354A5833475431434F2E3E4A2A3944
27343D222E361D272D181F241015180B0E100F1315171C1E1D22241E23251D22231C2224
1D232621282A242C2E232C2E222B2F252F342934392B363B2B363B2C363C2B363D2A353C
28333A232E351D272E16202610181D091116050B0F0205070506080B0F1311171D171F26
1C262E212C3525323C2837422C3C482E404D314451334755354A59374D5C3950603A5263
3B54653C56683D586A3E5A6D
3F5B6D3E596B3D57693C56673B54653A526239505F374D5C354A593347553143502E3F4C
2B3B462736402330391F2A32192229131B200E13170E131612191C161C20171E21171F22
1821241822261823271A262C1E2A31202C34202D3622303925333C26333D24313A232F38
212D361C2830172129101A200C151A0A101405090C070B0F0F161B151D241A242C1E2A33
22303A263540293A452C3E4A2F424F314553334857354B5A374D5D3850603A52623B5465
3C56673D57693E596B3F5A6D
3F5B6E3E5A6C3D586B3D57693C56673B54653A5263395061374E5E364C5B344958324654
3043502D3F4B2A3A4626364022303A1E2B3319252D131C230D161C0D161C121C22162126
15202515212617242B1A282F1D2B321D2B331D2C351D2C371D2C371E2D371E2D381D2B36
1C29321B242D172028121A200C12170A10150F161D151F271A262F1F2C3623313C263642
293A472C3E4B2F424F314553334857354A5A364D5C384F5F3951613A53633B54653C5667
3D57693D586A3E596C3F5B6D
3F5B6D3E5A6D3E596C3E596B3D586A3C57683C55673B54653A5363395161384F5F364D5D
354B5A3348573145532E42502C3F4B293B4726374222323D1F2E391D2B36192732182530
1927311A29321A28311B2A321E2E3621313A23333D23333F22333F22333F22333E23333F
21303C1B283215212916212A1A26301D2A341F2E3923333E263744293C482C3F4D2E4250
304554324857344A5A364C5C374E5E3850613952623A53643B54663C56673C57683D586A
3E596B3E596C3E5A6D3F5B6E
3F5B6E3F5B6E3F5B6D3E5A6D3E5A6C3E596C3D596B3D586A3D57693C56683B55673B5466
3A5364395263385061374F5F354D5D344B5B3249593147562F45542E43532D42512C4150
2C41502C41502C404F2B3F4E283C4B273A4A263A48263A47263947263947253846253744
243643273A472A3E4B2B3F4D2C414F2E43522F4554314757334A59344C5C364D5E374F60
3850613952633A53643A54663B55673C56683C57693D576A3D586A3D596B3E596C3E5A6C
3E5A6D3F5B6D3F5B6E3F5B6E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.25526 0.245293 0.476744 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
69.000 12.813 moveto
(deg) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
677073677073677073677073677073677073677073677073687073687073687073687073
687073687073687073687073697173697073697072697072697072697071696F70696E6E
6A7071697173697173697173697274697174697174697174697173687173687173687173
6871746872756872756973766974776975786A75786A76796A777A6A777B6B787C6C7A7E
6E7D816C797D6B787B6A777A6A76796A7578697578697478697477697376687376687275
687275687274677174677173
677073677073677173677073687073687173687073687073687173697173697173697173
6971726A71726A71726A71726A71736B71726B71726B71726C70716C70706C6F6F6B6D6C
6C70706C71726C72746B72746B73746B72746A72746A72746B72746A73746A73756A7375
6A73756A74776A75786B77796B787B6C797C6D7A7E6D7C7F6D7D816E7F836F8185718288
7284897081866F7F836E7D816D7B806D7A7E6C797D6C787C6B787B6B777A6A76796A7578
697477687376687275677174
6770736770726870736871736870726870736970736970726971736A71726A71736A7172
6B71726B71726B71726C71726C71726D71726D71726E71716E71716E70706F6F6E6F6E6C
6F71706F72726E73746E73746D74756D74756C73746C73746D73746C73746A74756A7476
6A75776B76786B77796C7A7C6D7C7F6F7E8170808371818571848872868B74888E758B92
758A9074878D73858A728388718186707F846F7E826E7D816D7B7F6D7A7E6C787C6B777A
6A7679697477687376687274
6770736770726870726871736970736970726970726A70726A71726B70726B71726C7172
6C71726D71726D71726E71726E71726F71726F727170727171717171717072706E716F6C
7272707273737174747175757075756F74756D74746C73736C72726C71736A73736B7576
6B76786B787A6C7A7C6D7D7F6F7F8270828572848874878B758A8F768D927890977A949C
799198788E94768B9175898E74868C738489728287718085707F836F7D816E7B7F6C797D
6B777B6A7679697477687275
6770736870726870726970726970726A70726A70726B70726B71726C71726C71726D7172
6D71726E71726F71726F717170727171727171727172727173727174727075726F75706D
7573717574747475767376767276767176767075766F74756E73746E73746D73746D7576
6D77796D797C6D7C7E6E7E8170838672868A74898D778C917990967A949A7C979E7E9BA3
7D979F7B949B7A9198798E95778C9276898F75878C7384897282877180846F7E826E7B7F
6C797D6B777A6A7578687275
6770736870736870726970726A70726A71726B71726B71726C71726D71726D71726E7171
6F71716F7171707171717271727271737271747371757371767472777472797471797470
7975737876757777767677787578787478787377787277777177777076767076776F7778
707A7C707C7E717F82718285738689758B8F778E937A92977D969C7E9AA1819EA681A0A8
809DA57F9AA27D979E7C949B7B9197798E94788B9176888E74868B7383887180856F7E82
6E7B7F6C787C6A7679687376
6770736870736970726970726A71726B71726C71726C71726D71726E71716E71716F7171
7071717171717272717272717372717473717673717774717975727B76737D78757E7976
7C78767B78777A7978797979787979777A79767A7A75797A757A7A747A7A747B7B737C7C
737E7F73808274838675868A768B8E788F937B94997E989E809CA382A1A986A6AF85A5AF
84A3AB83A0A8819CA48099A17E969D7C93997A8F96798C9277898F75868B738388718084
6F7D816D7A7E6B777A697376
6770736870736970726A71726B71726B71726C71726D71716E71716F7171707171707171
7171717272717372717472717572717673717773717974717A75727E7774857D79827B78
7F7A787E7A787C7A797C7B7A7B7C7B7A7B7B797C7C797D7D787D7D787E7E777F7F778181
78838478868779898B798B8E7B8F937D94997F989E819DA485A2AA87A7B08AADB889ABB5
88A9B286A6AF85A2AB839FA7819BA37F979F7D949A7B9096798D9277898E75858A728286
707E826E7B7F6B777B697477
6870736870726970726A71726B71726C71726D71726E71716F7171707171717171717171
7272707372707472707572707773707873707973717A74717B74717D757189807B847D79
817C7A807B7A7F7C7B7E7C7B7D7D7D7D7E7D7C7E7D7B7F7E7B807F7B81817B84837B8786
7C89897C8B8C7D8E907E91937F949881999E839DA385A3AA89A9B18CAEB88FB5C08DB2BD
8CAFBA8AACB689A8B187A4AD85A0A8829CA480989F7E949B7B9096798C9276888D748489
7180846F7C806C787C697477
6870736970726A70726B71726C71726D71726E71716F7171707171717171727170737170
7472707572707672707772707873707973707A73707B74707B73707F7673847B78847C79
837D7A827D7B817E7D817E7D807F7E80807F7F807F7E80807E81817E83837E87867E8A89
7F8E8D809191819395829698849A9D869EA387A3A889A7AE8CADB58FB3BD92BBC692BAC6
90B6C18EB2BD8DAEB88AAAB388A6AE86A1A9839DA481989F7E949A7B8F95788B9075868B
738286707D816D797D6A7578
6870736970726A70726B71726C71726D71716E71716F7171707171727170737170747170
7572707672707772707872707A73707B73707C73707D74707F7571817773837A76847C79
847D7B847E7C847F7E838080838180828181828281818281808281808685808A88818E8C
829290839695849898869B9D889FA18AA3A78CA7AD8DACB38FB1B992B7C195BFCA97C2CE
95BDC993B9C491B4BF8EB0B98CABB489A6AE86A1A9849CA381979E7D92987A8D9377888D
748488717F836D7A7E6A7578
6870736970726A70726B70726D71716E71716F7171707171717170727170747170757170
76726F77726F79726F7A726F7B736F7D736F7E746F7C726D827773837975847A77857C79
857D7B867E7D86817F868282868383858383858383848483828181828483828787838B8B
848F8F869696879B9B8A9FA08CA3A58EA7AA90ABB092AFB693B4BC95B9C397BFCB9AC6D2
9AC6D397C0CC95BBC692B5C090B0BA8DABB48AA5AE87A0A8839BA280959C7C9096798A8F
75858A7280846E7B7E6A7579
6870736970726B70726C70716D71716E717170717171717072717073717075716F76716F
77726F78726F7A726F7B726F7D736F7E736F80746F8A7C77877A76867A76867B78877C79
877D7A877E7C888180898483898584898584888484878484858282848081848384848586
85898B8892948A9A9B8DA1A190A6A892AAAD94AEB496B2B996B6BE97BAC499C0CB9BC5D2
9DCAD79BC6D399C1CD97BBC694B6C091B0B98DAAB28AA4AC869EA582989F7E92987A8D92
76878C7381866F7C7F6B7679
6870726970726B70726C71716E71716F717170717072717073717074716F76716F77716F
78716E79726E7B726E7D726E7E736E80746E81746F8A7C76897B76897B77897C78887B78
887C79887E7C8A81808C86858C87858C87858E8786888080858080827D7D827E7F838485
858688888C8E8C949692A0A194A9AA97ADAF98B1B699B5BB99B8C09ABBC59BC0CB9DC6D2
A0CCD9A0CDDA9EC7D49BC1CD98BBC595B5BE91AFB78DA8B089A2A9859BA280959B7C8F94
78898D7482876F7C806B767A
6870726A70726B70726D71716E707170717071717073717074716F75716F77716E78716E
79716E7A716D7C726D7E726E80736E81726C8D7C758C7C768B7C768A7B768A7D79897B78
887A77887C798A7F7E8D8484918887897F7F8A8080887E7E867E7E857F7F837D7E828082
81838483888A878E90929B9D99A8AA9BB0B29CB4B89DB8BE9CBAC19CBCC59DC1CB9FC6D2
A1CBD8A3CFDDA3CDD9A1C8D39DC1CB99BAC495B3BC90ACB48CA5AC879EA582979E7E9196
798A8F758488707D816B777A
6870726A70726C70716D70716F717170717072717073716F75716F76716E78716E79716D
7A716D7B716C7D716C7F726D82746E82736C9380788F7E778D7C778C7B768B7B778A7A77
897975887976897B7A887D7D9087878D86858B84848A8485898283878284868384868889
85898B848B8F838C8F88949794A1A39FB0B2A1B8BBA1BBC09FBCC39EBDC69EC1CBA0C6D1
A2CCD8A4D0DFA6D0DEA6CEDAA3C8D29EBFC999B7C093B0B88EA8B089A1A8849AA07F9398
7A8C91768589717E826C777A
6870726A70726C70716E70716F717071717073717074716F76716F77716E79716D7A716D
7B706C7B706B7C706B7F716C8878728A7972907F77907D778E7D778D7D778D7C778B7A76
8977738878748776758576768B7C7C8C81808C82828C84848B8484898585898586898A8C
888D8F89919488919489979B8D9DA19AAAAEA4B9BDA4BDC1A2BEC5A0BEC7A0C1CBA2C6D1
A4CBD7A5D0DEA7D1E0A8D0DDA8CDD7A2C4CE9CBCC597B3BC91ACB38CA4AB869CA381959A
7C8D9277868A717F836C777B
6970726A70726C70716E707170717072717074717075716F77716E79716E7A716D7B716C
7C706B7C6F6A7B6D68796B6484736D907C758F7D75907D76907C768F7D768F7C768D7A75
8B78738B7A778D7E7C8C7D7B8D7D7D8D7E7E8C7F7F8C7F7F8B7E7F898081898183898486
89888C8B8F928B92968C979C8E9EA294A5AAA1B5B9A6BEC2A4BFC5A2BFC7A1C1CBA2C6D1
A5CBD7A6D0DDAAD5E3B1D8E5ACD1DCA6C9D3A0BFC99AB7BF94AFB68EA6AD899EA583979C
7D8F9478878C727F836C787B
6970726B70726D70716F707071717073706F75716F76716E78716E7A716D7C716D7D716C
7D706B7D6F697A6B667466607A6B668A78718F7C75917D76927C76917D76917D768F7A75
8D78738D7A7691817E9182809081809081808F81808E81808D80808C81818C83848C8688
8D8A8D8E8E9190929791969B929BA094A1A79BABB1A3B8BDA5BDC4A3BFC6A2C1CAA3C5CF
A5CAD5A6CEDAA6D0DDB5DBE7B1D5E0AACCD6A3C3CC9DBAC397B1B991A9B08BA1A784989E
7F909579888D7380846D787B
6970726B70726D70716F707071717073716F75716F78716E7A726E7C726D7D726D7F726C
80716B80706A7F6E6880706984736C8C7971917D76947F77947E77947D77937D76927B75
907A74907B7793817E9586839485849384829283829183829081818E82828E85858F898A
908C8E919093949598969A9E97A0A49AA5AB9EADB3A2B5BAA4BAC1A4BDC5A3C0C9A4C5CE
A6C9D4A6CCD9A7CFDDB8DDE8B4D8E2AECFD9A7C6CFA0BDC699B4BC93ABB28CA3A9869AA0
8092977A898E7381856D787C
6970726B70716D70716F707072716F74716F76716E79716E7B726D7D726D80736D82736C
83736C85736C87736B89766F8D7B73917F7796817897827A97817A978079977F78967E77
947C76947E7895817D978784978886968785958584938684928483918383918685918A8A
928F8F93929496979A999CA09BA2A59DA7ACA0ADB3A3B5BAA4B9BFA5BCC3A4BFC8A5C4CD
A5C8D2A5CAD7A4CDDBBADFEBB9DCE7B1D3DDAAC9D3A3C0C89CB6BE95ADB58EA4AB889CA1
8193987A8A8F7481856D797C
6970726B70716D707070707072706F75716E77716E7A726E7D726D7F736D82736D85746D
87756D89766D8C786F8F7B72937F7796837B99847C9A857D9B857D9B837C9A827B9A817A
997F7998807A98827D9A87839B8B88998987988684968684948684938583938786938A8A
958F9096939499999B9C9FA19FA4A7A0A8ACA2ADB1A4B3B8A5B7BDA6BBC2A6BFC7A6C3CC
A6C7D1A5C9D5A1CAD8B6DCE8BDE1ECB5D7E1ADCCD6A5C2CB9EB9C197AFB690A6AD899DA3
8294997B8B907582866E797C
6970726B70716E707070706F73706F75716E78716D7B726D7E726D81736D85746D88756D
8B776E8E786E927D739580779A867C9C877E9E877F9E88809F88809E877F9E857D9E857D
9D837C9C837C9C847E9D88839E8C889D8B889B8987998986978885958785958987968D8C
9891919A95969D9B9C9FA0A3A3A6A9A4ABAEA5AFB2A6B3B7A7B6BCA8BAC1A8BFC6A8C3CB
A8C6D0A6C8D4A0C7D4A9D1DFB8DEEABADDE7AFCFD8A7C4CDA0BBC399B1B892A8AE8B9EA4
84959A7C8C907583876E797D
6970726B70716E707070706F73706E76706D79716D7C716C80726C83736C87746D8B766D
8F786E937C719882779C877CA18B81A48B81A38B82A38B82A38B82A38A82A28981A28980
A28880A18880A08882A08A84A18C889F8C899E8B889C8B889A8A87988A87988B8999908E
9B94939E9998A19D9EA4A3A4A6A9ABA8ACAFA9B1B4A9B4B8A9B8BDAABCC2ABC0C7ABC4CC
ABC8D1AACBD5A8CBD6A9CFDBADD4E1B3D6E0AFCFD8A9C6CEA2BDC49BB3BA94A9B08DA0A5
85969B7D8D917683876E7A7D
6970726B70716E706F71706E73706D76706D7A706C7D716C81726C85736C89756C8E766D
93786D987D719D8378A38C80A68F85A88F85A88E84A78E84A78E84A78D84A78D84A68D84
A68C84A58D84A58D86A58F88A5908AA38F89A08C889E8C889C8A879A8A879A8C8A9C918F
9E9694A29B9AA4A09FA7A5A5AAAAABABAEB0ADB2B5ACB5B9ADB9BDAEBDC2AFC1C7AFC6CC
B0CAD1B0CED6B0CFD9B2D5E0B5DBE7B4D7E1B1D0DAABC8D0A4BEC69DB5BC96ABB18EA1A7
86979C7F8E927784886F7A7D
6970726B6F706E6F6F706F6E736F6D766F6C7A706B7E716B82726B86736B8B746B91776D
977A6F9E7F74A5877BAB9084AE9488AE9388AD9287AC9186AB9086AB9087AB9087AB9087
AB9188AB9289AB928AAA948CA9948EA7928CA48F8BA18D899E8B879C8B879B8E8B9D928F
A09795A49C9BA8A2A1ABA8A8AEADADAFB1B2B0B4B6B1B7BAB1BABEB2BEC3B3C2C8B4C7CD
B5CBD2B6D0D8B6D2DAB8D9E3BCDFEABADCE6B4D4DDAECAD2A7C1C8A0B7BD98ADB390A3A8
88999D808F937784886F7A7E
6970716B6F706E6F6E706E6D736E6C766E6B7A6F6A7E70698271698772698C746A93766A
9B7D72A68679B08F82B69789B6988BB4978BB2958AB09489AF9388AE9288AE9288AF9389
B0948AB1968CB0978EB0988FAE9791AB958FA7928DA48F8AA18C889E8B879D8E8BA09390
A39997A69F9DABA5A3AFAAA9B1AFAFB3B3B4B4B6B8B5B9BBB5BCBFB6BFC3B7C3C8B9C8CE
BACDD3BCD2D9BDD5DDBFDDE6C0E1EBBFE2ECB9D7E0B2CDD5ABC3CAA3B9BF9AAFB492A4A9
8A9A9E818F937885896F7B7E
696F716B6F6F6D6E6D706D6C736D6A766D69796E687E6F688270688771688D7267927367
9B7C70AA897BB79485C29E8FBE9D8FBA9A8DB7988BB4968AB29489B19388B19389B3948A
B4968BB6998FB79C92B69D94B39C94B09992AB958FA6918BA28D88A08C889F8F8BA29491
A59A98AAA19FAEA7A5B2ACABB5B1B1B8B5B5B9B9BABABCBEBABFC1BBC2C5BCC5CABDC9CE
BFCED4C1D4DAC2D6DDC6E0E8C7E3ECC5E6EFBEDBE3B6D0D7AEC6CCA6BBC19DB0B694A6AA
8B9B9F829094798689707B7E
686F716A6E6F6C6D6D6F6C6B726C69756C68796C677D6D66826E668870668D7166917265
97796BA8887ABA9687C8A291C4A191BF9D8FBB9A8DB7978AB49589B4958AB4958AB7988D
BA9A8FBC9D91BDA094BBA197B9A198B49E96AE9891A8928CA38D88A08C87A08F8BA39491
A69A98ACA29FB1A8A6B5ADACB9B3B2BCB7B7BDBBBBBEBFBFBEC1C3BEC4C6C0C7CBC1CBCF
C3CFD5C5D4D9C7D8DDCDE2E8CFE8EFCCEAF2C3DEE5BBD3DAB2C8CEA9BDC2A0B2B797A7AC
8D9CA08491957A868A707B7E
686F706A6D6E6B6C6B6E6B69706A67736A65776A647C6B64826D64886F658E7165937468
9A7B6DAD8B7CC09989CFA694C9A393C49F90BF9C8EBA978AB49387B19185B19186B39388
BA988CC09D91C2A195BFA197BDA39AB9A29AB09992AA938CA48D87A08B86A08E89A39390
A79A98ADA2A0B0A7A5B5ADABBAB3B2BFB9B8C1BDBCC3C1C1C3C3C4C2C5C8C3C9CCC5CCD0
C7D0D5C8D4D9CAD8DDD0E0E6D4EAEFD2EDF4C9E1E7C0D6DBB6CAD0ADBFC4A3B4B899A9AD
8F9DA18592967B878A717B7E
686E70696D6D6A6B6A6C69676E6865716763746761796861806B62896F6491726595766A
977A6DAB897AC19A89D3A996CDA593C7A090C29D8EBC988AB69386AF8E81AB8B80A78A7F
AE8F84B7968ABD9B90BD9B91B99C93B69D95B09891AA928BA48C85A08A849F8D87A2938E
A69996AFA4A1B1A8A5B7AEACBEB5B3C4BCBAC5BFBEC8C3C2C7C6C6C6C8C9C5CACCC7CDD1
CAD1D5CCD5D9CFDADED8E3E7DBEBF0D8EFF4CEE3E9C5D8DDBBCDD2B0C1C6A6B6BA9CAAAE
919EA28693967C878A717C7F
676E70686C6C6969696A67666B65626D646070635D75645D7D675E896E639B7B6D9C7C6E
9D7E71AD8B7CC49B89D7AB97D0A794CAA291C49E8EBF9A8BB99588B28E81AD8B7FA5877C
A4877CA98B80B09288B6968CB6998FB49A91AF978FAA928AA48C859F89839D8A859E8F8A
9F928FA79D9AACA29FB3A9A7BFB4B0C3BAB7C7BFBDCCC6C3CBC8C7C9CACAC6CACCC8CDD0
CBD1D4CDD5D9D4DBDFDFE7EAE5F0F3DFF2F6D4E7EBCADBDFBFD0D3B4C4C7A9B8BB9EACAF
93A0A38894977D888B727C7F
676D6F676B6B67676767656368625F69605C6B5E586E5D56755F5783685D99786AA58274
A88576B5907FC79D8BD9AC98D2A895CCA392C69E8DC19C8CBC988AB69284B08C7FAB897C
AB897DAC8C80B09084B49589B5978DB3978EAF958DA99089A38B849F89829C89839C8C88
9E908E9F97959F9998A19D9DB2ABA8B8B3B1BCB8B6C5C0BEC6C3C2C6C6C6C5C8CAC7CCCE
CACFD2CDD4D7D8DEE0E4E9EBECF5F7E7F7FBDBEBEED0DFE2C4D2D5B8C6C9ADB9BCA1ADB0
95A1A48994977E888B727C7F
666C6E65696A656565646260645F5C645B5764585365544E644F47775E558A6B609C7A6D
A78475B89180C89E8BDAAD98D4A996CEA492C79D8DC19989BD9788BA9587B69183B38E80
B28D7FB38F82B59285B79589B7988CB3958BAE938AA98F87A38B839E89829C88829C8D87
9E918DA196949F98979B9898A29F9FAAA8A8B1B0AFBAB8B7BFBEBDC2C3C3C4C6C7C5CACC
C8CED0CBD1D4DADEE0E7EAEBF0F5F6EDFBFDE2EFF1D6E2E4C9D5D7BCC8CBB0BBBEA3AEB1
97A2A48B95987F898B737C7F
656C6E646868636363625F5E605B585F56535E524D5C4C4658453E6C554C81655A937366
A38072B78F7ECA9E8BDBAC97D8AB97D0A693CAA08FC29989BA9383B68F81B28D7FB08A7C
AC8779AC887BAE8B7DB18E82B29286B19288AD9187A98E85A48B839F89819B87819B8B84
9F928CA39893A49A98A49E9CA7A1A0A9A6A5AFACACB8B4B3BCBABAC0C0C0C2C4C4C5C8C9
C6CCCECBD1D3DCDEDFEBEBEAF0F2F3F3FDFEE9F3F4DCE6E7CED8DAC0CACCB3BDBFA6B0B2
99A3A58C96987F898C737D7F
656B6D6366676161615F5D5B5C57555A524E574C475446404F3E37604C44755D538A6C60
9E7C6EB48D7CC99D8ADAAB96DAAC98D4A896CDA392C69D8DBF9686B89081B28B7DB0887A
AD8677AC8678AC8779AF8A7DB08F82B09085AD8F85AA8D85A58B83A089829B8681968580
988A859F948EA69B97ABA29DADA5A2AEA9A6B2AEACB7B4B2BBB9B8BEBEBEC1C2C2C1C6C6
C3C9CACBD1D3DDDEDEF0ECEBF4F4F3F9FFFFF6FCFCE3EAEBD3DBDCC4CCCDB6BEC0A8B1B2
9AA3A58D969880898C737D7F
646B6C6165665E5F5F5C5A59595452554E4B5247434E403B49383258453D6C554B81665A
967668AF8978C69B88D8A994DBAD99D7AB98D1A695CAA191C49C8CBE9787BA9283B68F7F
B48C7DB38C7DB28C7DB28D7FB28E81B19084AE8F85AB8E84A78D84A38C849E8A83998882
948783948B8698918DA39B97ACA4A1B2ABA7B5AFACB8B4B2BBB8B7BDBCBCBDBFBFBEC2C3
BEC5C6CCD0D1DDDEDDF0EBE8F9F4F2F9FBFAFAFEFCE8EDECD7DDDDC7CECEB8BFC0A9B1B2
9BA4A58E9798818A8C747D7F
636A6C6064655C5E5E59575655514F514A474D433F483C3742332E514039634E457A6055
907164A98474C19784D6A792DDAE99DAAE9AD4AA98CEA695C9A191C49D8DC0998ABC9586
BA9283B89182B79081B69182B59183B39184B09185AD9085AA8F86A78F87A38E879E8D87
9A8C87988D89978F8C9993919E9997A6A19FABA8A6B0AEACB3B2B1B8B8B7BABCBCBCBFBF
BCC2C3CACECEDBDADAEAE5E3F7F1EEFCF9F7FEFEFBECEEEDDADEDDC9CECEBAC0C0ABB1B2
9CA4A58E9798818A8C747D7F
636A6B5F63645A5C5C565554524E4C4D4744483F3C4338333D302A4D3D365D4A41735A4F
8A6C5FA38070BB9380D2A48FDDAE99DDB09CD8AD9BD2A998CDA695C9A292C59E8EC29B8C
BF9889BD9687BB9585BA9485B89486B69486B49387B19387AE9389AB9289A7928AA4918B
A0918C9E928D9C938F9D96939F9A97A29E9BA6A3A2ACA9A8B0AFAFB4B4B4B6B8B9B8BCBD
BCC1C3C9CCCCD7D7D6E4E1DFF2EDEAFCF7F4FFFDFBF0F1EFDCDFDDCBCECEBABFBFABB1B2
9DA3A58F969881898B747D7F
62696B5D6263595B5B5453524F4C4A494441443C383E342F392B2648383258453D6C554A
8366599D7A6AB58D7BCC9F8BDCAD97E0B29EDBB09DD5AC9BD1A999CDA696C9A292C69F8F
C49D8DC19B8BBF9989BE9888BC9788BA9689B79689B5968AB2968BB0968DAC968DA9968E
A6958FA49690A39893A29A96A49C99A6A09DA8A4A2ACA9A7B0AEADB3B2B2B4B6B6B6B9BA
BEC1C1CACBCBD6D5D3E2DFDCEEE9E6F9F3EFFDF8F5F1F0EEDCDDDCCACDCCBABEBEABB0B0
9CA3A48E969781898B747D7F
61696A5C61625759595151514C494846413F4039353A302C33272243352E534139664F45
7B5F53937264AC8674C49884D5A791E0B19CDDB29ED8AF9DD4AC9BD0AA9ACDA797CAA393
C8A191C69E8EC49D8DC29B8CC09A8BBE9A8BBC998BB9998DB79A8EB49A8FB29A90AF9A91
AC9A92A99A93A89C96A89E99A89F9BA9A29FAAA6A3ACA9A7AEADACB0B0B0B1B4B4B4B8B9
BCBFC0C8C8C8D3D2D1DEDBD8E9E4E1F3ECE8F7F2EEEEECE9DADAD8C8CAC9B9BCBCAAAEAF
9CA1A28E959681888A747C7F
61686A5B60615558584F504F494746433F3C3C3633362D2930241F3F302A4F3D35604A40
74594E8B6C5EA5806FBB927FCEA18CDBAD98DDB29EDAB19ED6AE9DD3AC9BD0AA9ACEA897
CCA594CAA291C8A08FC69F8FC49E8EC29D8EC09C8EBE9C90BC9D91BA9E93B69E93B49E94
B19E96AE9E96AD9F98ACA19BACA29EACA4A0ACA7A3ADAAA7AEACABAFB0AFB0B2B2B4B7B8
BDBFBFC6C7C6D1CFCEDAD7D5E4E0DDEDE7E3F0EBE7E4E2DFD5D4D2C5C7C5B6B9B9A8ACAC
9AA0A08D9495808889737C7E
60686A5A5F615457574D4E4E474544403C3A393330322A262B211D3A2D274A39325A463C
6D54488365579B7868B48A78C99B87D6A893DCB09CDCB19ED9B09ED6AE9DD3AC9CD1AB9A
CFA898CEA695CCA493CAA392C9A292C7A192C4A092C2A193C1A194BFA195BCA196B9A197
B6A198B3A199B2A29BB0A39DAFA49FAEA6A1AEA7A3AEAAA7AFABAAAEAEADAFB1B1B5B7B7
BCBDBDC5C5C4CECCCBD8D5D2E1DDDAEAE4E0EFEAE6DEDCD9D0CFCDC1C2C1B3B6B5A6AAAA
989E9E8C92937F8788737B7E
60676A595F605356564C4D4D4443433D3A3835302D2D2623251C1935292344352E544138
654E437A5E51927161AA8371C19581D2A28DDCAE99DDB29EDBB19ED8B09ED6AF9DD4AE9D
D3AC9BD1AA99D0A897CEA796CDA695CCA595CAA495C8A597C7A698C4A599C1A59ABEA59A
BBA59BB8A59CB5A49DB3A59EB2A6A0B1A7A2B0A8A4AFAAA7B0ACA9B0AFADB2B2B0B7B7B6
BEBDBCC6C4C3CECBC9D7D3D0E0DAD7E6E0DCE8E4E0D8D6D3CACAC8BDBEBCB0B2B2A3A7A7
969C9C8A91927E8687727B7D
606769595E605155564A4C4C4242413A3837322E2C2923202018142E231E3D2F294D3C33
5E493E72584C896A5BA07B6AB88D7ACA9C87D9AA95DDB19CDCB19EDAB19ED9B09FD7B09E
D6AE9DD5AD9CD4AB9AD2AA98D1A897D1A998CFA999CEAA9ACCAA9BCAAA9CC7A99CC3A99D
C0A89EBDA89EBAA89FB7A8A0B5A7A1B3A8A3B1A9A5B0AAA6B0ACA9B2AFACB4B2B0B8B7B5
BEBCBBC4C2C1CCC9C6D4D0CDDCD7D3E1DCD8DBD8D4D1CFCCC4C4C2B8B9B8ACAEAEA0A4A4
94999A898F907D8586727A7D
5F6769585E5F505455494B4B4141403837362F2C2A26201E1C1411261C1836292346352E
564238695145806254967463AC8472C0937FD2A38DDBAE99DDB19DDCB19EDBB19FDAB19E
D9B09ED9AF9DD8AF9DD8AD9BD6AC9AD6AC9BD5AD9CD4AD9DD3AE9FD0AE9FCDADA0C9AC9F
C5ACA0C2ABA0BEABA1BBAAA1B8A9A2B5A9A3B2A9A4B0A9A5B0ABA8B2AEACB5B2B0BAB7B4
BFBCB9C4C1BFCBC7C4D3CECBDCD6D2E3DEDAD5D2CFCAC8C6BEBEBCB3B4B3A8AAAA9CA0A1
929797878D8E7C8385717A7C
5F6769575E5F505455484A4B3F40403636352D2A29231F1D1812101F17132D221D3D2E27
4E3B325F493F755A4D8A6A5B9E7A69B28976C69984D6A791DCAE99DDB19CDDB29EDDB29E
DDB29FDCB29EDCB19EDCB19DDBAF9CDBAF9CDBB19EDAB1A0D8B2A1D6B2A2D3B1A2CFB0A2
CAAEA2C7ADA2C2ADA2BEACA2BBAAA2B7AAA3B4AAA4B0A9A4B0ABA7B2ADAAB4B1AEB9B5B3
BFBBB7C4BFBCCAC5C2D1CBC8D6D1CDDCD8D4CECCC9C3C2C0B8B9B7AEAFAEA3A6A6999D9D
8F9495858B8C7B828471797B
5F6769575D5F4F5455474A4B3E40403535352C2A29211E1C14100D150F0C241B16342721
44342C5440376850457D6153906F60A37D6CB58C78C89C86D4A690DBAD97DDB19CDDB19D
DFB39FE0B49FE0B49FE0B39FDFB29EE0B29EE2B4A1E1B6A3DFB6A4DCB5A4D8B4A4D4B3A4
CFB1A4CBB0A4C6AEA3C1ADA3BCABA2B7A9A1B4A9A3B0A9A3AFA9A5B0ACA8B3AFACB7B3B0
BCB7B4C0BCB9C7C2BECFC8C4D2CCC8CECBC8C6C3C1BCBBB9B2B3B1A9AAAA9FA2A2969A9A
8C919283898A79818370787B
5F6769575E5F4F5455474A4B3E40403535352B2A2A211E1D1511100F09071B13102B201B
3B2D264B39305D473C71574B826557937262A27E6DB48C79C39884CEA18CD6A994D9AD98
DEB19CE1B39EE2B49FE2B49FE1B39EE2B39EE4B4A0E5B7A3E4B8A5E1B8A6DDB5A5D8B4A5
D4B3A4D0B2A4C9B0A4C3ADA2BEABA1B8A8A0B3A7A1B0A7A1AFA8A3AFAAA6B1ACA9B4B0AD
B9B4B1BDB8B5C3BEBAC9C3C0D0CBC8C6C3C0BDBCB9B5B4B3ACADACA3A6A59B9E9E929697
898F908187897880816F787A
5F6769575E604F5456474B4C3E41413536362B2B2B21201F1614130B0806100B08201813
2F241E3F3029503D34644D42745A4E846659927263A17E6DAF8977BB9380C59B87CCA18E
D2A793D8AB96DCAF99DDB09BDCAF9ADFB09AE1B19CE2B49FE4B5A2E3B7A3DFB5A3DAB4A3
D5B2A2D0B0A2CBAFA2C4ACA1BDA99FB6A69EB2A59EADA49EACA5A1ACA6A3ADA9A6B0ACA9
B4B0ADB7B4B1BCB8B5C2BEBAC4C2BFBCBBB8B5B4B2ADAEADA6A7A79EA1A0969A9A8E9394
868C8D7F8587777E806F777A
5F676A575E604F5557474C4D3F42433638382C2D2D2222221816150B090808050216100D
251D1834282243342C554239665045755C5083675A927364A07E6DAA8776B28E7DBA9483
C29A87C99F8CCEA38FD3A793D3A793D5A995D8AB97DBAE99DDB09CDEB29EDBB29FD7B09F
D3AF9FCDAD9EC8AC9FC1A99DBAA69CB3A39BAFA29BABA19CA9A29DA9A39FA9A5A2ACA8A5
AFACA9B1AFACB4B2B0BBB7B4B7B5B3B2B2B0ADADABA6A8A6A0A2A1999C9C9296968B9091
848A8B7C8385757D7F6E7779
5F686A585F61505658484D4E404344373A3A2E2F302424251A19190E0D0D0502010B0705
1B15112A211C382C26493A3258453C685248745C5082675A8F706299796AA28171A98778
B08D7CB89382BC9684C29B89C59E8BC8A08ECAA28FCDA592D0A694D0A896CEA997CBA898
C8A798C4A598BEA498B8A197B3A097AC9E97A99D97A59D98A49E9AA49F9CA5A19FA7A4A2
AAA8A5ABA9A7AEADAAAEADABADACAAA9A9A8A5A6A59FA1A19A9D9C9498988E9293878D8E
8187887A8283747C7E6D7678
5F686A586062515759494E50414547393C3D3032332728281D1D1D121111070505040201
110E0B1F19152D24203E312B4B3C3558463E634F46725B507F6559876D61917568997C6E
A08173A98878AC8B7CB19080B59382B99685BB9887BE9A8AC09C8CC19E8EC09E8FBD9E8F
BA9D90B79D90B39B91AD9A90A99991A59891A298929F98939E99959E9B989F9D9AA1A09E
A4A3A1A5A5A3A6A6A4A5A6A4A4A4A3A1A2A19D9F9F999C9B9498988F93948A8F8F848A8B
7E8586798082737B7D6D7578
60686B59606352585A4A50524348493B3F403335362A2C2C2021221616170B0A0A010000
08060515110F221C193027233E332D4B3D3655453E614F466E594F766157816A5F887064
8F766A967C6F9C8073A18476A5887AA98B7DAB8E7FAD9081B09384B09485B09487AD9387
AA9387A79287A49188A091889D918A9C928C9A928D98928F9793909795939A99979E9D9B
A0A09EA0A09F9FA09F9E9F9E9C9E9D9A9C9B979A999397968F93938B8F90868B8C818788
7C8384777E8071797C6C7577
60696B5A6164535A5C4C5254454A4C3E424336393B2D30312527271B1C1D101112040404
0000000A0807171412241F1C3129253D332E453A3450433C5B4C4564544C6F5D5577645B
7E6A61846F658B746A8F786E937C709780749B83779D85799F887CA0897D9F8A7F9B887E
9B897F98887F9487809287819088839089858F8A878E8B898F8D8B91908E919391959796
9B9E9D999B9A989A999799999598989396969194948E92928A8F8F868C8C8288897E8486
798082757C7E70787B6B7477
61696C5B6365545C5E4E5556474D4F414647393E3F3235372A2C2E21232417191A0D0F0F
0204040001010B0B0A18161525211F302A2738312E4038334A403B5247425C5049655851
6C5E5672635B7767607D6C6482706886746B8A786F8D7B718F7E74917F769181788D7F77
8A7E76877D76857D77837E79827F7B83807E8583818685848687868A8A898D8F8D919391
9294949295949194949194938F93938D91918B8F90898D8E868B8C8288897F85867B8283
777E80737B7D6F777A6B7476
616A6D5C6466565E605057594A5052444A4B3D4244363B3C2F3334272B2C1F222316191A
0E10100405060204040C0E0E1A19182624222F2B2934302D3B3633423D3A4A4441544C47
5B524D615853675D576C615B71655F766A63796D667D71697F736C83776F847972827973
8079727A7571777471777673777774797A787C7D7C7F807F818282828484878989898D8C
8B8E8E8B8F8F8B8F8F8A8E8F898E8E888D8D868B8C84898A8187887F85867C8284787F81
757D7E717A7C6E76796A7376
626B6D5D6568586062535A5C4D5456484E504247493C4142353A3B2E3334272B2C202324
181B1C10131407090A06090A1013131B1C1C2626252C2B2A312F2E3634333D3B3944423F
494744504C4956524F5B5653615B57665F5B6A635F6E6762706A64746D6878716D79736F
78736F74726E747270737371737472737574767878787B7B7B7E7E7D8080828585838787
84888985898A858A8A858A8A84898A8388898187888085867D84857B8283798081767D7F
737B7D70787A6D76786A7375
626B6E5E67695A6264555D5F50585A4C5254474D4F4147493C4143363B3C303436292E2F
2327281C1F211418190B0F100B0F101418192022222728282B2D2C2E2F2F3435343B3C3B
40413F4445434748474C4C4B52514F5756545B5A57605E5B63615E6765616867646D6B68
6B6A68686A68676A69676B6B686D6C6A6E6E6C717272767675797A777B7C7B7F807D8282
7F84848085858085868085867F85867E84857D83847B82837A8082787F80767D7F737B7D
71797B6E77796C7577697275
636C6F5F686B5C6467586062545B5E5057594C5254474E5042494A3E4345383E4033383A
2D3234272C2E2126281B1F21121719101617161C1D222627292D2E2D31312F3232323636
363A3A3A3E3E3F4343424646444848494D4D505353565856595B5A5D5E5C5E6160646564
636564616565616666616768636969656B6C666D6E6F747471767774797A767C7C787E7F
7A7F807B80817B81827B81827A81827A8082798081787F80767D7F757C7E737B7D71797B
6F777A6D76786B7476697275
646D70616A6C5E66695B6365575F62545C5E51585A4D5456495052454C4E41484A3D4345
393F40343A3C2F3536292F31242A2C1F25271A21231C2325262C2D2C3234313637333939
363C3C373D3F3A41423E454742494A454B4D4A50524E545554595A585C5C5A5E5E5C6060
5E61625D62635C62635C64655E6566626869636A6A6A70716E737470767772797A747A7C
757C7D767D7E767D7E767D7F767D7F767D7E757C7E747B7D737B7C727A7C70787B6F7779
6D76786C74776A7376687274
646E71626C6E60696B5E66695B6466596163565E60535B5D51585A4E55574B5254474E50
444B4D4047493D4346393F42353C3E31383B2D3437282F322830332A333630383A373E40
3840413941423B44463F4749434A4C454D4F4850514A52544E5557505859555B5C575C5E
595E5F5B5F615B60615D63645A60615C6364636A6B686E706B72736D74766F7678707779
71787A72797B727A7B727A7B727A7C72797B71797B70787B70787A6F77796E76796D7578
6C74776A7376697275687174
656E71646D70626B6E616A6C5F686A5D66685C64675A6265586062565E60545C5E525A5C
4F575A4D55574B5255485052454D50434B4D40484B3E46493D46493D45493A43473E4649
41494C41494C424A4C424A4D454E4F4B52544D55564F575952595B535A5C555C5E585E60
5960625B6163565D5F5B61645E656761686A646B6D676E706971736B72746C74766D7577
6E75776E76786E76786E76796E76796E76786E76786D76786D75786C75776B74776B7476
6A7376697275687274677174
666F72656F71646E70646D70636C6F626B6E616A6D60696C5F686B5E676A5D66695C6567
5B64665A6265596164576063565F61555D60545C5F535B5E525B5E525A5E515A5E525B5E
535C5F535B5F535C5F525A5E50595D515A5E525B5D535C5E545D60555E60565E60565E61
5860635E66685F676A61696B626B6D646C6E656E70676F716870736971746972746A7275
6A73756A73756A73766A73766A73766A73766A73766A73756A7375697275697275697275
687274687174677174677173
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.25526 0.488926 0.476744 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
727576727476727476727476717475717475717475717375717374717374717374717274
717273717273717273717272717172717172717172717171717071717070716F6F706D6C
7170707171717171727171727072737071727071727071727070726F71726F70726F7172
6F71736F72746F737570747671757871767972777A72787A727A7C747B7E757D80767F83
788387767E82757C7F747B7D747A7C74797B73797B73787A73787A737779737779737779
727678727678727677727577
727476727475717475717375717374717374717273717273707172707172707071707071
707070706F6F706F6F706E6E706E6E706D6D706D6D706C6C706C6B706B6A706A68706865
706B69706C6C706D6E706D6E6F6E6F6F6E6E6E6D6E6D6D6E6D6D6E6D6D6E6C6D6E6C6E6F
6D6F706D71736E72746F747770767971787B727A7D737C7F747E827681867885897A888E
7C8B9179868A788287778084767E82757D80757C7F757B7E747B7D747A7C74797B73787B
73787A737779727678727677
7274767173757173747173747172737071727071717070707070706F6F6F6F6E6F6F6E6E
6F6D6D6F6C6C6F6C6B6E6B6A6E6B6A6E6A696E69686E68676F68656F66646F65626F635F
7066646F68676F6A696F6A6A6E6A6A6D6A6A6C6A6A6B696A6C696A6B696A6A6A6B6B6C6D
6B6D6F6C6F716C71736E74776F777A717A7D727C8074808375838878878C7A8C927E9199
7E8F967C8B917A888D79858A788387778185768083767F82757D81757C7F747B7E747A7C
74797B73787A737779727678
7274757173747172737072737071727070716F6F706F6E6E6F6E6E6F6D6C6E6C6C6E6B6B
6E6A6A6E69686D68676D68666D67656D66646D65636D64626D63606E625F6E615D6E5F5A
6F63606F65636E66656E67666D67676C67676B67676A67676A66676A6667696868696A6B
6A6C6E6B6E706B70736C74776E787B707B7F727F8375838877888D7A8C937D92998198A1
7F949B7D90977C8C927A898F79878C798589788387778286778084767E82757D80757C7E
747A7D74797B73787A727678
7174757173747172737071727070706F6F6F6F6E6E6E6D6D6E6C6B6E6B6A6D6A696D6968
6D67666C66656C65646C64626C63616C62606C615E6C605D6C5F5B6D5F5A6D5E586E5C56
6E605C6E625F6D63626D64636C65646B65646A6565696565696464696465686566686869
696A6D696D6F6A70736B73776D787C707D8172818676868B798C927B91987F979F829CA6
8098A07F949B7D90977C8D947B8B917A888E79868B788489788287778184767F82757D80
757B7E747A7C73787A737778
7174757172737071727070716F6F6F6F6E6E6E6C6C6E6B6B6D6A696D69686C67666C6665
6C65636B64616B62606B615E6A605D6A5F5B6A5D596A5C586B5B576C5B556D5A556E5A54
6E5D596E5F5C6D615F6C62606B62616A63626A6363696363686363676363676465676667
68696B686C6E6970736A73776C797D6F7F8372838976898E798F967D959E819CA6839FA9
819BA48097A07F949C7D91987C8E957B8C927A898F7A878C79858A788387778184767F82
757D80747B7E74797B737779
7173757172737071716F6F706F6E6E6E6C6C6E6B6A6D69696C68676C66656B65636B6462
6A62606A615E6A5F5C695E5A695C58695B576959556958536957516A57506D57506F5A53
6E5C576D5D5A6C5E5C6C5F5E6B605F6A6060696160686161676162676162666364666566
67686A676B6E6870736A74786C7A7D6F7F8472868B768B927A929A7E99A283A1AC83A1AB
829EA7819AA38097A07F949C7E91997D8F957C8C927B898F7A878C798589788287778084
767E81757C7F747A7C737779
7173757072727070716F6E6F6E6D6D6E6B6B6D69696C68676C66656B64636A63616A615F
695F5C695E5A685C58685A5667595467575267555066544E66524C66514A705850715B54
6F5B566D5C586C5D5A6B5D5C6A5E5D695E5D685F5E675F5F665F5F666060656262656465
666769676B6E6870736975786C7A7E6F818672878D778E957C959D7F9CA684A5B084A3AE
83A0AB829DA7819AA38097A07F959C7E92997D8F957C8C927B8A8F7A878C798489788185
767F83757D80747A7D73787A
7173747071726F6F706F6E6E6E6C6C6D6A696C68676C66656B64626A626069605E695F5C
685D59675B5767595566575266555065534E65514B644F49634D46644C44765C53715A53
6F5A556D5A566B5B586A5B59695C5B685C5B675C5C665C5D655D5D655E5F646161646465
656769666C6E6771746976796C7B806F828773888F7790977C97A0809FA985A7B385A6B1
84A3AE83A0AB829EA7819BA48098A07F959C7E92997D8F957C8C927B898E7A868B788387
778084767E81747B7D73787A
7173747071716F6E6F6E6D6D6D6B6A6C69686C67656B64636A626069605E685E5B685C59
675A5666585365565165544E64524C644F49634D46634B446048406B5048745A52705852
6E58536C58546B5956695957685A59675A5A665A5A655A5A645A5A635B5D635F60636364
65686A666D6F67727469777A6D7D81708489748A907891997C99A281A0AB85A9B585A9B5
85A6B284A4AE83A1AB829EA7829BA48198A07F949C7E91987D8E947C8B917A888D798589
788285767E82757B7E73787A
7173747070716F6E6E6E6C6C6D6A696C67666B65646A636169605E685E5B675C58665A56
66575365555064534D63504A634E48624C4561494260463E674C4370544B70554D6E5550
6C56516B5652695653685756675857665858655858645758635758625A5B625E5F626364
64686A656E7067737569787C6D7E8371858A758C9379939A7C99A281A0AB84A8B487ACB9
86AAB685A7B385A4AF84A1AB839EA7829BA381979F80949B7E90977D8D937B8A8F7A868B
788387777F83757C7F73787B
7172737070706F6D6D6D6B6B6C69686B66656A646269615F685F5C675C59665A56655753
64545063524D624F49624D46614B4361484060463D63463D6E50476E51486D524B6C534D
6B534E69534F68545167565466565666575765565663565762555661595A615D5E626264
626768646E706673766A7A7D6E808472878C778E947A949C7D9AA381A0AB83A7B387ADBA
88AEBB87ABB786A8B385A4AF84A1AB839EA7829AA381979E7F939A7E8F957C8B917B878C
798488778084757C7F74797B
7172736F6F706E6D6D6D6A6A6C67666B65636A6260685F5D675D5A665A56655753645450
63524C624F49614C46604A425F473F5F453C5E42386D4D436E4F456D50476C50496A504B
69504B67504C66524F665453665555655555655556635657615758605959615E5F616163
606466636C6E6573756A7B7D6F828573888D788F967B959D7E9BA480A0AB83A7B286ACB8
89B1BF88AEBB87ABB787A8B386A4AF85A1AA849DA68299A181959C7F91987D8D937C898E
7A858A788185767D8074797B
7172736F6F6F6E6C6C6D69696B66656A646269615E685E5B665B5765585464555063524D
614F49604C465F49425E463F5D433B5D40376243387150456E4F466C4E466B4F48694E48
674D48644D49644F4D66535365545463545468595A645858625A5B605A5B5F5B5D5E5F61
5E626461696C636F726A797C6F8386758A8E7991977C979F7E9CA480A0AA82A6B185ABB7
88B0BE89B2C089AFBC88ABB788A8B387A4AE86A0A9849CA482989F80939A7E8F957C8B90
7A868B788286767E8174797C
7072736F6E6F6E6B6B6C69686B6564696260685F5D675C5965595564565163534E614F4A
604C465E49425D463E5C433B5C40375A3C336C4B3F704F446E4E456B4D456A4E48674C46
654A45624A46624D4B635151675858655857685C5C645A5A625A5B605B5B5E595A5D5F61
5D62645E66695F6A6D687579718286778C907B92987E99A07F9DA580A0AA81A4B084A9B6
86AFBD89B3C28AB2BF8BAFBC8AACB789A8B288A3AD869FA7849AA282969D8091977D8C92
7B888C798387777E81747A7C
7071726F6E6E6D6B6A6C68676A646369615F675E5B665A5765575363544F62504B604D47
5E49435D463E5B423A5A3F365A3D345B3C32735043704F446E4E446B4D45694D47664B45
634843604845614B4A614F506B5D5C685C5B665B5B645B5C6159595F595A5D595A5D5F61
5D61635D66695E686C6472776E7D81788B8F7D949A7F9BA1809EA67FA0A980A3AF83A8B5
85AEBC87B3C28AB3C18DB3C08EB0BC8CACB68AA7B088A2AB869DA583989F8193997E8E93
7C898E798488777F82747A7C
7071726E6E6E6D6A6A6B67666A636168605D675C5965595564555162524D614E485F4B44
5D473F5B433B583E355439305B3C33664539745145704F446D4D446A4D45684C46654A44
624742614A47624E4C635251695959675A59645959635A5A6057585E58595C585A5D5D60
5D61645E686B5F696D63717768797E74868B7F969B819CA2809EA77F9FA97FA2AE81A7B4
84ADBB86B2C18AB5C48EB5C491B5C18FB0BA8CAAB48AA5AE879FA8859AA182959B7F8F95
7D8A8F7A8589777F83757A7D
7071726E6D6D6C69696B6664696260675E5C665B5864575363544F61504A604C465E4841
5C443D5A4038553A3150342A5E3F34724E427250446F4E446C4C446A4D45684C45654A44
624843624C486553516555536656566457576358576157575F56565D56575C585A5C5C5E
5C61645E676A616A6F63717768797F6F83897D9499819DA3809EA77E9EA87EA1AD80A6B3
83ABB985B0BF87B3C393BBC994B9C592B4BF8FADB88CA8B189A2AA869CA483969D819197
7E8B907B868A788083757A7D
7071726E6D6D6C69686A656368615F675D5A65595663555162524C604E485F4A435E473F
5C433A5A3E3556393055372C6241366F4D416E4D426D4D436B4D45694D45674D45654A44
624944624C486654526656546556556456566257566056565E55555C55565B58595B5B5D
5C60635E6569626A70657277697A8070838A788F967F9AA07F9DA67E9EA87DA0AC7FA5B1
82AAB883AEBD83B1C198C0CE97BDC995B7C391B1BB8EAAB48BA4AD889EA685989F829298
7E8C917B868B788184757B7D
7071716E6C6C6B686769646268605D665C5864585462544F61504A604C465E48415D453D
5C41385B3E345A3A305D3D3162423769493E6C4C426C4D446A4D45694D45674D46654B45
634A44634C4865524F6657556557566356566156555F55555D54545B54555A57585A5B5D
5B5F635D6569626C706673796B7B8271848B768D947C969D7D9AA47D9CA67C9FAB7EA4B0
80A9B781ADBC82B0C19AC2D09BC0CD97BAC694B4BE90ADB78DA7B089A0A8869AA183949A
7F8E937C878C798185757B7E
7070716D6C6C6B6766696361675E5C655A5763565261524D604E485F4A435E463F5D433A
5C40365C3D325D3C2F5F3F3363443967493F6B4C426B4E456A4E46694E46674D46654C45
644A45634C4863504D6556546558576357566055545E55555C54545A5354595657595A5C
5B60635E6569636D7168747A6D7D8271848B768C947A949D7B97A17B9AA57B9EAA7DA3B0
7FA8B680ABBB7FAEBF9CC3D29EC3D09ABDC996B7C293B0BA8FA9B28BA2AA879CA384959B
808F947D888D798285757B7E
6F70716D6B6B6A6666686260665D5B64585562545060504B5F4C465D48415D443C5C4138
5C3E335C3B2F5E3C31603F3464453B684B426B4D446B50476A5047684E47674D47664C46
644B46634D48634F4C6454526458576257566054545E55545C545459525358555759595C
5B60635E6569636E7268767B6E7E8472848C758C9378929B79959F7A99A37B9DA97DA2AF
7FA7B580ABBA7EACBD98C0CFA2C7D59DC1CD99BAC595B2BD90ABB48CA4AC899DA585969D
8190957D898D798286767C7E
6F70716C6B6B6A656567605F645C5962575360524E5E4E485D49435C453E5B42395B3E35
5B3B315C392D5E3D3160403566493F6A4D446B4F466B51486A5048694F48674E47664D47
654D47644E48624F4B6453516458566257566055545D54545B5353585253575456595A5C
5B60635F666A646E7369767C6F7F8573858D758B93768F9877939D7997A27B9CA87DA1AE
80A7B482ABBA82AEBD91BBCA9FC7D5A2C7D39BBDC896B5BF92ADB78EA6AE8A9FA686989E
8291967E8A8E7A8386767C7E
6F6F706C6A6A696464665F5D635A576155515E504B5D4B465B47405A433B593F36593B31
5A382D5B382C5E3D31624539694E446C50466C51486B51496A5149695049674F48664E48
654E48644F4963504C6454516457556256555F54545D54545A5253575253565456585A5D
5B606460676B646F746A777D6F808673858D748A92758D9676919C7996A17B9BA77EA1AE
82A7B485ADBB88B1BF90BAC99BC5D4A2C7D49CBECA97B6C193AFB98FA8B08BA0A88799A0
8392977F8B8F7A8387767C7F
6E6F706B6969686363645E5C6158555F534F5C4E495A494359443D584038573B3257382E
5835295A372B5E3E33654A3F6C51476E52486D52496C52496A5149695049684F48664F48
654F4964504A65524E6455526457556256555F54545D54545A5152565253565456585A5D
5B616460696C6570756B787F6F808672858C748991748C9576909A7995A07C9BA77FA1AD
83A7B488AEBC8CB2C193BCCB9CC7D69DC4D29BBFCB98B8C394B1BA90A9B28CA2A9889AA1
8493987F8B907B8487767C7F
6E6F6F6A6868666261635C5A6056545D514D5A4B4658464056413A553C3454382E543429
56332859372C604136694E436F544970544B6E544B6D524A6B5149695049674F48674F49
664F4A65514C66544F6557536558566357566055555D5454595152555152555457575A5D
5B616560696E6671766B797F6F7F8671848B728790748B94758F9A79949F7C9AA680A1AD
84A8B48AAFBD8EB3C195BDCC9CC6D69EC6D39CC0CD99BAC596B2BC92ABB48EA3AB899CA2
859499808C917B8488777D7F
6E6E6F696868656160615B595E54525A4E4A57484455433D533D3651383050342A4F2F24
52312758392E64463A70534773574C72564D70554C6E534A6B5149695049674F48664F49
66504B66534E675651675855675A576459576157565D5454585152555152545457575A5D
5B6266606A6F6671776A787E6D7E8570828A71878F748A94768F9979949F7C9AA680A0AD
85A7B48BAEBC8FB3C096BECD9CC5D4A1CAD89EC3D09BBCC798B4BE94ADB58FA5AD8B9DA4
86959B818D927C8589777D80
6D6E6F68676764605F5F59575B524F574B48544541513F3A4F3A334D342C4C2F264A2A1E
4B2E24583B31684A3E78594C785B4F75594E72574D6F544B6B524A685049664F48664F49
66504B67534E6958536A5B57695C59665B5A6258585D5555585152545152535457565A5D
5A6166606A6F64717769767D6C7D846F818A71868F748B94768F9979949F7D9AA681A0AC
86A7B48BAEBA90B2BF98BECD9FC5D4A4CEDCA1C6D39EBECA9AB7C096AFB791A7AE8C9EA5
87969C828E927D8689777D80
6D6D6E676666625E5D5D5755584F4D54484550423D4D3B364A362F493028472B2246271D
472D23573C326A4D417F5E507D5E52795B5075594E70554C6B5149674F48644D47644E49
66504B69544F6B5A546C5D596B5F5C695E5D645B5A5E5656585253535052525356555A5D
5861665E696E62707666757C6B7B836E818970858E748B94778F9A7A949F7D9AA6819FAC
86A6B38BACB98FB1BF9ABDCBA3C9D7A8D1E0A4C9D6A1C1CC9CB9C398B1B993A8B08EA0A6
89979D838F937D868A787E80
6C6D6E666565605D5C5B5553554D4A5045424B3E3A48373245312B442C2443281E43271E
432B23573E346F51458663548262547D5E52785B5172564D6B514A664E47624C47614D48
64504B6B5650705C576F5E5A6E615E6D6462665E5D5E585857525352505251535553585C
565F655C686E5F6E7463737B6879816D808870858E768C9578909A7A949F7D99A5819FAC
86A5B38BABB88FB0BE9CBECBA8CCD9ACD5E3A8CCD8A4C4CF9FBBC59BB3BB95AAB190A1A8
8A999E8490947E878A787E80
6B6C6D6564645E5B5A585351524A484C413E46393541322D3E2B253E272040251C412820
412D255940367454488C68588665578060557B5D5274584F6D534C664E48634D485D4B47
624F4B6C5751715E5973605B7264616F666467605F5F5959575253514F514F515450575B
525B625B686E5C6B725F707965777F6D808871868E778C9579919B7B95A07C99A5819FAC
86A5B289AAB890B1BFA0C0CDADCEDBB1D8E5ACCFDAA8C6D1A3BEC79EB5BD98ACB392A3A9
8C9A9F8591957F878B787E81
6B6C6D6363635C595955504F4E4745473D3B4034313A2B2735241E341E1841271F432C24
4631295A423977574A916C5C8A685A8463577D5F54775B5271574F6A524B66504A604D48
64514C6A5751705E5974625D7365616E656267605F5E5959575253504F514D50534E555A
4F5A6056656C56676F586C7565777F6C808870858D788D967B919B7D96A17D9AA6809EAB
84A3B187A8B690B1BFA4C2CFB3D2DEB6DAE6B0D1DDACC9D3A7C0C9A1B7BF9BAEB594A5AB
8E9BA087929680888B797F81
6A6B6C6262625A5857524E4D4A4442423937392F2C3124202718142C19133E2820463128
4B372F61483D7C5B4D956F5F8E6A5C87665A7F6055795E54745B536E564F69524C66514C
67534E6B58526F5D5872625E7164616C6361665F5F5E5859565253504F514D50534D555A
4F5A6152626A52646D52677164767E697E866E838C798D957B929B7D96A17C99A67E9DAB
81A1AF83A5B592B2C0A7C4D0B9D5E0BBDDE9B6D5DFB1CCD6ABC3CCA5BAC19EB0B797A7AC
909DA188939781898C797F81
696B6C6161615856564F4C4B46413F3D3634332A27281D1A1B0E0A29191437241E46322A
513C33694D41815F51987161926D5F8A695D8263597B6056765C54715A526C56506A544F
6A56506D5A54705E5871625D7164616B6260655E5D5D58585652534F50524C50534C5459
4F5A6152616952646D5368725F727B667A836C828B768B9478909A7994A07A97A47A9BA9
7D9FAD7FA3B294B4C1ABC6D1BDD6E0C1E2EDBCD9E3B6D0D9B0C7CEA9BDC4A2B3B99AA9AE
929EA38A9498828A8D7A7F82
696A6B6060605655554D4A49433E3D3932312E262422181514090622161133231D443129
563E366E50458562549A73629571628D6C6086685D7E6259785E56735B546E59536E5952
6C58526E5C566F5E5971615D7064606A605E635B5B5C56575553544F51534C4F544A5357
4D5A6052616854656E586B745E717B62788169808A708892738C9775919E7695A27799A7
779CAB7DA2B296B5C2B2C9D3BDD5DFC6E4EEC2DDE6BDD4DCB6CAD1AEC0C6A5B5BB9DABAF
94A0A48C9599838A8D7B8082
686A6B5E5F5F5553534A4848403C3B35302E2A23211D15131006041D120E2F211C423029
573F366F52468764569A73639874659170648A6C6183675E7C635A765F58725D57725D56
6F5C556F5D576E5D586F5F5B6C605C685D5C6159585C55565653555052554D5156495257
4A575D4F5F6653646D5A6C745E727B617881667E886B848F6E8995718E9B7393A07396A4
7298A87EA3B299B7C3B5CAD4BDD4DEC7E3EDCDE5EDC4DAE1BCCED5B3C3C9A9B8BDA0ADB1
97A1A58E969A848B8E7B8082
68696B5D5E5F5352524847463E3A3A322E2D26201F1A13110C050219100D2B1F1A402F28
553F366F52468664569972639A76679474678D6F65866C6280675F7B645D77615B745F59
715E58705E586E5D576C5D58695C58655B596057575B55565654565253574F53584B545A
49565D4B5C634E616A5669725B717A617780647D8768828D6C87946F8D9A70909E6E93A2
6D96A680A5B49AB7C4B2C8D2C0D6DFCAE3ECD8ECF3CDDFE5C2D3D8B8C6CCADBABFA3AFB3
99A3A68F979A858C8E7C8082
67696A5D5D5E5251524745453B3938302C2B241F1E1711100A0302180F0C271C183E2D26
533E356C50458462559771629B776997766A9072688A6F66846B637E68617A655E76625C
73605A705E596D5C576B5B57675A566458565F57565B545557545654555850555A4E565C
4B585F4C5C634D606851666F576D775D747E617B8666818C6886936C8A996A8E9C6A91A0
6C95A582A6B499B7C3B0C7D1C4D7E0D2E6EDE0F0F6D4E3E9C8D7DCBDCACEB1BDC1A6B0B4
9CA4A891989B868C8F7C8183
67696A5C5D5E5151514544443A38382E2B2A221E1D15100F080201160E0C251B173A2A25
513B33684E447F5F52926E609C77699A796C93756B8C7269866E67816B647C676177645E
74615B705F596D5C576A5B566659556357555F56555B545558555755565952575B4F585E
4D5A614D5D654E616A516670556C7659727C5E7884627E8B648391668795668B99678E9E
6E96A684A7B59BB8C4B0C8D1C6D8E0D8E8EDE5F2F7DCE9EDCFDBDFC2CDD0B5BFC3A9B2B5
9EA5A892999C878D8F7D8183
67696A5B5D5D5050514444443837372C2A2A201D1C130F0E060100140E0C231A16372823
4C3831634A41795B4F8D6B5D9A76689C7B6E96786D8E746B887169826D667D696278655F
74625D715F596D5C57695A566658546257555E55545B555658565856575A53585D515A5F
4F5C624F5F6650636B526771546C7657717C5A76825D7B885F808E618493618897648D9D
7198A888A9B79DB9C5B2C9D2C8D9E0DDE9EEEAF3F7E5EFF2D4DEE1C6CFD2B8C1C4ABB3B6
9FA6A9949A9C888D8F7D8183
66696A5B5C5D4F50514343443736372B29291E1C1C120E0E040100130D0C221916342621
47352E5D463D73574C88675A9673659D7B6E977A6F90766D89726A836F687E6B64796661
75635E715F5A6D5C58695A566558546156545E55555B555659565957585B54595E525B61
515D6450606851646C526871546C7656707C5775815979865C7E8C5D82915E8696658E9E
779CAB8CACB9A1BCC7B7CCD4CDDCE2E1EBEEEEF5F8EAF2F5D8E0E3C9D0D3BAC2C4ADB4B7
A1A7A9959A9C898E907D8183
66696A5B5C5D4F50514343443736372A29291D1C1B100E0E030000110C0B211815302420
42322C56423A6E5449826357916F629A786B977A6F90776E8A736B846F687E6C66796862
75635E705F5A6C5C58685A566558556156545E55555C56575A575A58595D555B5F545C62
525F6651616952656D526872536C7754707B567480577886597C8B5A81905E86966991A1
7CA0AE90AFBCA7BFC9BDCFD7D2DFE5E6EDF1F5F9FBEBF1F3DAE0E2CAD0D3BCC2C4AEB4B6
A2A7A9959A9C898E907E8183
66696A5A5C5D4F50514343443636372929291C1B1B0F0E0E020000100C0B1F17152D231F
3D2F29513F37674F467B5E538C6C5F95746895796E90776E8A736B836F697E6C66796863
74645F70605B6C5C58685A566457556157555E56565C57585A595B585A5E565C61555E64
53616752636A52666E536973536D7754707C547380567886577C8A5A81916188986F95A4
82A4B198B4BFADC3CCC3D3DAD8E3E7ECF1F3FAFDFFE9EEEFDADFE0CBD0D2BCC1C3AFB4B6
A2A7A9969A9C8A8D8F7E8183
66696A5A5C5E4F505142434436363729292A1C1B1C0E0E0E0000000F0B0A1C16142B211E
392D284C3B35604A4273594F85675B8E6F6492766B8F776D89736B836F687D6B65786862
73645F6F605C6B5C58675A566458556157565E56575D58595B5A5D5A5C5F585E63566065
54626954646C53676F536A74536D7853717C537481547885577C8B5C8392668C9B779AA8
8AA9B59FB8C3B4C8D0CAD7DDE0E7EBF2F5F6FBFDFEE8ECEDD9DDDECACED0BCC0C2AFB3B5
A2A6A8969A9B8A8D8F7E8183
66696A5B5D5E4F5052434445363738292A2B1C1C1D0E0E0F0000000D0A0919151427201D
352A2646373159463E6A534A7B615686695E8E72688D756C88726A826E677C6A65776761
72635F6E605C6A5C59665A576358566158575F58585D5A5B5C5C5F5B5E615A6065586167
56646A55666E556871546B75546E7953717D537481557886597D8C6186956E92A080A0AD
94AFB9A7BDC7BCCCD3D2DCE1E8EDEFFAFBFCF6F8F8E6E9E9D7DADBC9CCCEBBBFC0AEB2B3
A2A5A795999A898D8E7E8182
66696B5B5D5F4F51524345463738392A2B2C1D1E1F0F1011000102090808161312241D1B
30272340332F51413A624E467059507D6359886D628A7268867068806C667B6964756661
71625E6C5F5C695D5A665A586258576058575F595A5E5B5D5E5E615D60645C62665A6369
58666C57686F566B73556D76546F7A54727E5475825679875C818F688B997798A58AA6B2
9EB5BEB0C3CBC4D1D7DBE2E5F0F1F3FFFFFFF1F2F3E3E5E5D5D7D8C7CACBBABDBEADB0B2
A1A4A5959899898C8E7D8082
67696B5B5E5F505253444647383A3B2C2D2E1E20211112130203040707081311101F1A19
2B2421392F2C493C3759484266534B725C537D655C836C63826D657E6A64796862736460
6F625E6B5F5C685D5A655B59625857605858605B5B605D5F6060635F63665E64695C666B
5A686E596A72586C75576F7855717C56747F5778855A7C8A63869471919E819EAA93ACB6
A7BAC3B9C8CFCED7DCE4E7E9F5F4F5FFFFFEEEEFEFE0E1E1D2D4D4C5C7C8B8BABCACAEB0
A0A2A4949798888B8D7D8082
676A6B5C5E60515354454749393B3D2D2F312123241315170507080405060E0E0E1A1717
272220332B2842373351443E5D4D4668554E715D557A655D7B665F7A676076666170625E
6C615E695E5C675D5A645B5A6059585F5959615C5D63606163636562656861676B5F696E
5D6A705C6C745A6F7759717A58737E5976815C7B8861828F6C8C997B98A38BA4AF9DB2BB
B0C0C7C2CED3D8DDE0ECECEDFBF9F9F9F9F8EAEAEADCDDDDCFD0D0C2C4C4B6B8B9AAACAD
9EA1A2939697888B8C7D8081
676A6C5D5F6152545647494B3B3E3F30323424262817191B0A0D0F0104050A0B0C161515
221F1E2D27253B322F4A3F3A5447435F504A65554F6D5C56715F5973615C70625D6B5F5C
695E5C685D5B665D5B635C5B5F595A5F5A5B625E5F65626366656865686B64696D616B70
606D725F6F775E727A5D747D5D76815E7A8563808C6A899476939E859EA995ABB4A7B9C0
B9C6CBCCD4D8E0E3E4F1F0F0FFFCFBF2F1F0E4E4E4D7D8D8CBCCCCBEC0C1B3B5B6A7AAAB
9C9FA0929496878A8B7C7F81
686B6C5D6062535657484B4D3E4042333537272A2B1B1E200F121402060805080A121313
1D1C1B282523342E2C443A374E433F564A465C4F4B62544F675854685A56675B58645B59
645B59645C5A645D5B625C5C5F5B5B605D5D636060656465676769686B6D676C70646E72
64707563727963767D627880637B84667F896C8791758F99829AA390A5AEA0B1B9B1BFC5
C4CCD0D6DADCE6E7E7F6F3F2FBF8F7EBEAE9DEDEDED2D2D2C6C7C7BBBCBDB0B1B2A5A7A8
9A9D9E90939486898A7C7F80
686B6D5E61635457594A4D4F40434536383A2B2E3020232514171A080B0E0307080E1011
1919192422222F2B2A3D3634473E3C4D4441534946594E4B5D524E5F55525E56545D5756
5E5857605A59605B5A605D5D5F5C5D605E5F63616265656668696B6A6D6F696F72687175
68737868757B697980697C846B81896F868F778E9680969E8DA1A89BACB3AAB8BEBCC5C9
CED3D5DEDFDFEBEAEAF8F4F3F0EEEDE4E2E2D8D7D7CCCCCDC1C2C2B7B8B8ACAEAFA2A4A5
989A9C8E91928588897B7E80
696C6D5F626456595B4D5051434648393C3E2F323425282A1A1D200F121504090B090D0F
1517182020202B29283632313E393746403E4A4341514947554D4B564F4E575151585454
5955565D58595B58595E5C5D5F5D5E605F60626263656668696A6C6C6E706C71746B7377
6C767B6D797E707D8370818874868D798C9381949B8C9DA498A7ADA6B2B7B5BFC2C7CCCE
D8D9DAE3E3E2F0EEEDF0EDECE5E3E3DBDAD9D0D0D0C6C6C6BCBDBDB2B3B4A9AAAB9FA1A2
9698998D8F908486887B7E7F
696C6E616465585B5D4F525446494B3D40423337392A2D2F20232615191C0B0F12070B0D
1216171C1E1F262627302F2F383535403C3B433F3E4944434E49484E4B4B514F4F535152
5553555957585958595C5B5C5D5D5F6061626264656668696A6C6E6D70726E73756E7579
70797D737D8176818677858A7C8B918392978C9AA096A2A8A2ADB2B0B8BCC0C5C7D0D1D3
DEDDDDEAE8E7ECEAE9E4E2E1DBDAD9D2D1D1C9C9C9C0C0C0B7B7B8AEAFAFA5A6A79C9E9F
9395978B8D8F8385877A7D7F
6A6D6F6265675A5D5F525557494C4E414446383B3E2F3335262A2C1C2023121719090E11
0F1517191D1E2224252B2C2D3433333A38383D3B3C4240404745454948494E4D4E4F4F51
52525455555757585A5A5B5C5C5E6060626364656767696B6C6E706E717371757872787B
757C7F7880837A84887D888D828E938B979B959FA39FA8ACACB3B6BABEC0C8C9CBD7D6D6
E5E3E2E8E6E5E0DFDED9D8D8D2D1D1CAC9C9C1C1C2B9BABAB1B2B2A9AAABA1A2A3999B9C
919394898B8D8184857A7C7E
6B6E6F6366685C5F615457594D505245484A3D404335383B2D303324282B1B202212171A
0F1517161B1D1F2324272A2C2F313236363738393A3D3D3E4142444446484A4B4D4C4E50
50525452545756585B595C5E5D5F61616365656769686B6C6D707171737575787A757A7D
797F817C82857D8689818B8E899295929A9E9DA4A7A8ADAFB4B7B9C1C2C2CECDCDDBD9D8
E5E3E3DDDCDCD6D5D5D0CFCFC9C8C8C1C1C1BABABBB3B3B4ABACADA4A5A69D9E9F959798
8E909187898B808384797C7D
6B6E706468695E6163575A5C505355494C4F4246483B3E4133373A2C303324292B1D2225
161B1E141A1D1B212424282A2D303233353736393B393C3E3E414341444746494C4B4E50
4E515452555856595B595C5F5D606261646666686A6A6C6E6F7173747677787B7C7A7E80
7D81837E838580878A868E908E9597989D9FA3A7A9AFB1B2B9BABAC6C4C4D2CFCFDBD9D9
DAD9D9D3D2D2CCCCCCC6C6C6C0C0C0B9B9BAB3B3B4ACADAEA5A7A79FA0A1989A9B929495
8B8E8F8587897F8183787B7D
6C6F7166696B6063655A5D5F5457594D5153474B4D4145473A3E4134383A2D3234272C2F
2126291B21241A202321272A2A2E31313537363A3C393D3F3C40433F444844494C4A4E51
4D525552565956595D595D605E616363656867696B6C6E707072747678797B7D7F7E8082
81838480848683898A8B90919196989A9EA0A7A9AAB3B3B3BDBCBCC7C5C4D2D0CFD3D2D2
CDCDCCC7C7C7C2C2C2BCBCBDB7B7B7B1B2B2ABACADA6A7A7A0A1A29A9C9C9496978E9092
898B8C8385877D8081787A7C
6D7071676B6C6265675D6062575B5D5255574C5052474B4D4145473C4042363B3D313638
2C3133272C2F21272A21272A282E32303538373C3E3A3F423D42453F4549444A4E4A4F53
4E535652575A565A5E595E615E6265636669686B6D6E70717173747779797D7E7F818182
838485828587868A8B8D91929497989EA0A0AAAAAAB4B3B3BFBDBDC6C4C5CACAC9C5C5C5
C1C1C1BCBDBDB8B8B8B3B3B4AEAFAFA9AAABA4A5A69FA0A19A9C9C9597989092938B8D8E
8688898183857C7F80777A7B
6D7072696C6E6468696063655B5E60565A5C5255574D5153484C4E44484A3F43463A3F41
363B3D3237392D3336292E3129303330363A383D413E434640464942484B474C504D5255
50555854595C565C5F5A5F625F636664676A696C6E6F71727274757879797A7C7D828282
828384838687898C8C8F9192979999A0A1A1A9A9A9B5B3B3BDBCBCBEBEBFBCBDBDB9B9BA
B5B6B6B1B2B2ADAEAFA9AAABA5A6A7A1A2A39D9E9F989A9B9496979092938C8E8F878A8B
8385877F81837A7D7F76797B
6E71736A6E6F666A6C6366685F62645B5E60575B5D5357594F53554B4F52484C4E44484B
4045473D4144393E41363B3E32383B343A3E393F42404549444A4D484E514C5154505558
54595C565B5E595E625D616561656764676A696C6E6F71717374767778787A7B7B818181
8282838586878A8C8C8F9292989999A0A0A0A5A6A7B3B2B2B4B4B5B1B2B2AFB0B0ADADAE
AAABABA7A8A8A3A4A5A0A1A29D9E9F999B9C9697989294958E90928B8D8E878A8B848687
8083847D7F81797C7D75787A
6F72746C6F71696C6E66696B6366686063655C6062595D5F565A5C5357595054564D5154
4A4F51484C4E454A4C42474A4046493F45483F454841474B494E524D535753575A555A5D
585D5F595E615D616560646763666864676A696C6F6D70717274757677777A7B7B7E7F7F
828282858686898B8B8F91929596969C9D9EA2A3A4A8A9AAA6A7A8A4A5A6A3A4A4A0A2A2
9EA0A09C9D9E999B9C9798999496979193948E90918C8E8F898B8C868889838587808384
7D80817A7D7F787A7C757879
7073746D71726B6E70696C6E666A6C6467696265675F63655D61635B5E60595C5E565A5C
54585A5256595055574F53564D52554C51544C51544B505450555853595C575B5E5C6062
5E62655E626560646762666864686A676A6C6A6E6F6D7071717474747677797A7B7C7D7D
80808084858587888A8F9091919293959797999B9B999B9B989A9B97999A969899959697
9395969193948F91928D8F908B8D8F898B8D87898B8587898385878183857F81837D7F81
7A7D7F787B7D76797B747779
7074756F72746D71726C6F716A6D6F696C6E676A6C66696B646769636668616566606365
5E62645D61635C60625B5F615A5E60595D60595D60595E615B5F625C61645D6164636668
65686B64676965686A64686B666A6C6A6D6F6C6F706E7172717475737676767879797B7B
7C7E7F838485838486888A8B898B8C898C8D8B8D8E8B8E8F8B8D8E8B8D8E8A8C8D898B8C
888A8B87898A8588898487888385878184858083847F81837D80817C7F807A7D7F797C7D
787A7C76797B757879737678
7174767074757073746F72746E71736D70726D70716C6F716B6E706A6D6F696D6F696C6E
686B6D676B6D676A6C666A6C66696B66696B66696B666A6C666A6C676B6D686C6E6A6D6F
6B6E706A6E706B6F706A6E706A6E706D70726F7172707374717476737577747678767879
787B7C7D7F817C7E807D7F807D80817E80827E81827E81827E81827E81827E80827D8081
7D7F817C7F807C7E807B7E7F7A7D7F7A7C7E797C7D787B7D787A7C777A7B76797B75787A
757879747779737678737677
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.25526 0.732558 0.476744 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
89818089817F88807F88807F88807E887F7E887F7E877F7D877E7D877E7D877E7C877D7C
867D7C867D7B867C7B867C7A867C7A867B7A857B79857B79857A78857A78857977857875
867A78857A79857B79857B79857B7A857B79857A79847A79847A79847A79837A79847A7A
847B7A847C7B847D7C857E7D867F7E867F7F8780808781818783838884858986868A8889
8C8B8C8A87888A8585898484898383898383898383898382898282898281898281898281
898281898281898181898180
89817F88807F887F7E877F7D877E7D867D7C867D7B867C7B857B7A857B79847A78847A78
84797783787683787583777482767482767382757282747182747081736F81726E82706C
82726F8273718274728174728175738174738074727F73727F73717F73727E73727E7474
7F7575807777807879827A7B827C7C837E7E847F808581828684858887898A8A8C8C8E91
8D90938B8B8D8A888A898788898586898585888484888484888383888383888282898282
898281898281898281898181
88807F887F7E877E7D867E7C867D7B857C7A857B79847978837977837775827775827674
8175728074718073707F726F7F716E7E706D7E6F6B7E6E6A7E6D697E6C677E6A667E6963
7E6B677E6D6A7E6E6B7E6E6C7D6E6D7D6E6C7C6E6C7B6D6D7B6D6D7B6D6D7B6E6E7B7070
7C72727D74747E75767E77787F797A807C7D817E8083828385858787898C8A8D918D9398
8D92968B8E918A8B8D89888A888788888687888586888485888484888384888383888382
888282898282898281898281
88807F877F7D867D7C867D7B857B7A847A788379778277758176748175728074717F726F
7E716E7E6F6C7D6E6B7C6D697B6B687B6A667A69647A67637A66617A65607A645E7A625C
7B65607A67637A68657A68667A6967796967796968796A697A6A69796A6A796B6B796C6D
7A6E6F7A70717B71737B74767D78797E7B7D807E80828284848689868A8E898F948C959A
8B92968A8F92898C8F888A8C88888A888789878687878686888585888485888484888383
888382888282898281898281
88807F877E7D867D7B857B7A847A788378768276748175727F73717E726F7D706D7C6E6B
7C6C697B6B677A696579676378666177645F76625D76615B765F5A765E58765D56765C55
775F5A77615C77625F766360766461766462756564756564756565756666756767766969
776B6C776D6E7870717872747A75777C7A7C7D7D8080818483868A858B908891968B969C
8A9297898F93888D90878B8E87898C87888A878788878687878586878585878484888384
888383888382888282898281
887F7E867D7C857C7A847A788378768176748074727F72707E706D7C6E6B7B6C697A6A67
79686478666277646075625E74605B735E59725C56725A5471585271575072564F73564F
735953745B57735D59735E5B735F5D725F5E72605E71605F716060716161726363726465
72666773696A736C6D746F7176747578787A7B7C7F7D818480868A838C9188939989959C
889297878F94878D91868B8F868A8D86888B868789868688878687878586878485878484
888383888383888282898281
887F7E867D7B847B798378778176748074727F726F7D706D7C6D6A7A6B68796965776662
76646075625D735F5A725D58715B557058526E564F6D534C6C514A6C4F476D4E46705149
71554F7157527058547059576F5A586E5A596E5A596E5B5A6D5B5B6D5B5B6D5D5D6D5F5F
6E61626E65666F686A706C6E727072757577777A7D7A7F827E858A828C9186939A86939A
869197868E94858D91858B8F858A8D85898C85888A868789868688868587878586878484
878384888383888282898281
877F7D867C7B847A788277758075727F72707D706D7B6D6A7A6A6778686476656175635E
73605B725D58705B556F58526D554F6C524C6A4F48694C4567494164443C6B4A416F5048
6E514C6E534E6D54506C54526B55536B55536A55546A555569555569555668575768595A
685C5D6960616B64666C686A6E6D6F71737574787B787E827C84897F8B90849299849198
848F95848E93848C91848B8F848A8E84898C85888B85878A858789868688868586878485
878485888484888382898281
877E7D857B7A8378778176747F73717D706E7B6D6A796A6778686476656174625D725F5A
705C576F59536D56506B534C6A5049684C4566494264463E624139613F37704D446E4E46
6C4F496B4F4A6A4F4C69504D68504E67504F66504F655050654F4F644F50635151635354
645759655C5D6660626865676B6A6D6E7073717679757C807982877C888E818F96818E95
818D94828D92828C91828B90838A8E83898D84888C84878A858789858688868587868586
878485878484888383898281
877E7D857B798278768075727E726F7C6E6B7A6B6878686476656174625D715E5A6F5B56
6D58526B544E6A514B684E47664A4364473F62433B6140375E3B3269453B734F456D4C44
6A4B45684A46664B47654B48644B49634B4A624B4B614A4A60494A5F4A4B5F4C4D5F4F51
60545661585A625D5F64626468686B6B6E716F7478737A7F7680857A868C7E8B927E8C93
7F8C927F8B92808B91818A90818A8E82898D83888C83888B84878A858689858687868586
878485878484888383888282
877E7C847A798277757F73717D706E7B6D6978696676656274625E715E5A6F5B566D5752
6B544E68504A664C4564494162453D6041395E3D345B382E643F356F493F6C4940694841
6747416546416346426247446047456047465F46465E45465C43455C45475B484A5B4B4E
5C50535D56585E5A5D616063646669686C6F6C727670787D737E8377828979878E7C8B91
7D8B917D8B917E8A907F8A90808A8F81898E82898D83888C83878A848789858688868587
868586878484888383888282
867D7C847A788176747E72707C6F6C796B6777676374635F725F5B6F5B566D57526A534E
685049654C4563484061443C5E40375C3C335B382E603B306B443969443A68443B65443D
63433D61423C5F423E5E42405D43415C43425B42425A424359424358464758494A584D4F
5851525955575A595B5E5F61616568656B6F6A71766E777C717C8175808777858C79888F
7A8A917B8A917C8A917D8A907F8A8F80898E81898D82888C83888B84878A858689858687
868586878485888383888282
867D7C8379778075737D716E7B6D6A78696575656172605C6F5C586D58536A544E67504A
654B456247405F433B5D3F365B3A3158362D553127623B2F663F34654137644138614039
5F3F385C3D385A3D3A5A3F3D593F3F583F3F583F40574242564545554848564E4E565152
55515256545657595B5B5E615F6567646A6D6871756C767B6F7B80727F8574838A76868E
798A927989917A89917C8A907D8A907F898F80898E81898D82888C83878B848789858688
868586878485888383888282
867D7B8378778074727C6F6D796B6876676373625E705E5A6D5A556A555068514B654C46
6247415F433B5C3E36593A3156352C5430265A3327673F33643E34623E34603E365E3D36
5B3B35583934563936563B3B553C3C523C3C564444574847564C4B564E4E564E4F534F50
52515253575853595B575D5F5C6466626A6D6770756B767B6E7B806F7E8471828973848C
75878F7789917889917A8A917C8A907E8A907F8A8F81898E82898D83888B84878A858688
868587878485878384888282
867C7B8278767F73707B6E6C786A6675656272605C6E5B576B575268524C654D47624842
5F433C5B3E3758393155342C5330274F2B215E372B643E32623D33603C335E3C355B3A34
5838325436325337355139385441405748475C4E4D584D4C564E4D544D4D524C4C525253
535455525658515658545C5E5A6366616A6D65707569767B6C7A806D7D836E7F8770828A
72868E7489937589927889927B8A917D8B917F8A90808A8F82898E83898C84888B858789
868687878586878484888282
857C7B8277757E72707A6D6A77686573635F705E5A6C595469544F664F49634A445F453E
5C4038583A3254342C502F264F2B22502A20633C2F633D31603C325E3B335B3B34583933
553631513733523A38523E3D5B49475949475748475549485348465147464F47474F4B4D
4F4D4E515253535657575D605A62655F686C646F7468767B6A797F6B7B826B7D856D8089
6F848D7187917388907689927A8B937D8C927F8B91808B90818A8F83898D84888B85878A
868688878586878484888382
857C7A8176757D716F796C6975666372615D6E5C576A565267514C634C466047405D413A
593C3455362E502F2649271D4A261C583125673F32623D325E3B325B3A32593A33563933
533732533B3756423F5949465C4D4B574B495448475247464F43434D43434C43444C4748
4C494A4E505250525554595D585F635E666B64707567767B68797F687980687B836A7F87
6C838C6E8690728993768B957B8E957D8D947F8D93808C91818B90838A8E84898C85888A
868688878586878484888382
857C7A8076747C706E786A67746561705F5B6C595568544F654E496149435E443D5A3E37
57393153332A4E2C2348251B532E23643C30643E325F3B325C3A32593A33563A34543833
513833513B385442405546445548465349475248475047464E46454B46454B47474A4A4A
4B4E4F4C51524F525552585C565E625C666A64717566777B66787E66787F667A83677D86
6A818A6B838E6B848F758C957B90977D8F967F8E95808D93828C91838B8F848A8D85888B
868789878687878485888383
847B7A8075737B6F6D77696672635F6E5D596A575366514C624C465F46405B4039583B33
55362D523128502C23542E2261392C663F325F3C315C3A31593A33563A33543A34523934
4F3934503B3852423F5143415144434F45444E45444C44434A4242484342474545474748
484B4C494E514C5356505B5D5662655C6B6F63737866787D65787E63787F637982657C86
67808A68828D69849079919B7C929A7E9199809097818F95828D93838C90848A8E85898C
86878A878687878485888383
847B797F74727A6E6B75676571615E6C5B57685550634F496049435C433C583D36553830
53332A512E24512B20542E225833285A382D5A392F583931563933533934513A344F3934
4E38344E3A374E3E3C4E413F4D42414C42414A4141484141464040444040434142434446
44484A454C4F4A52564E595D53606459686C5E6F7462757A62767E61767F617781637B85
657F8966818D66839079929D7E949E7F939B809199819096828E94838D92848B8F858A8D
86888A878688878585888383
847A797E7472796D6A7466636F5F5C6A595565524E614C465D4540593F3955393252342C
502F264E2B204E291D4F2B20512E2453332A55362E5438315238325038334E38334D3733
4B37334B39364B3C394B3F3E4A403F483F3F473E3E443E3E433E3E403D3E403F41404244
41464A444B4F4952564D595E52606557676C5B6D735E72795F737C5E747D5F7780617B85
647E8965818D6583907A939D7E959E80949D81939B829198839096838E93848C90858A8E
86888B878788878586888383
837A797E7371786C697264626D5D5A685652634F4B5E494359423C553C3552362E4F3028
4C2B214B261B4B261B4A271E4D2C2350322A52342D5036304F37314D37314B36324A3632
483632483834473937473C3B473F3E453E3E433D3D413D3E403C3E3D3B3D3D3D403D4144
40464A424A4F4751564B585E51606655666D596C735B70785B717A5B737D5D7680607A85
637E8966828D66839078919B7F97A081969F82959D82939A839197848F94848D91858B8F
86898C878789878586888383
837A787D7270776A687163606B5B58655450604D485B4540563E395138314E312A4A2B23
48261C46211745221946241B4A2D254E322B4E342D4D362F4B3530493530483430463430
453431443533433735443A39443D3D423C3C403B3B3E3A3C3C393B3A393B393A3D3A3F42
3C4449404A4F44515649585E4E5F6653656D556A72566D75576F7859727C5B757F5E7984
637E8967838F6D88937A929C8098A2839AA38397A083949C839299849096848E92858C8F
868A8C878789888586888383
8279787C716F7569676F615E69595662514E5D4A4557423D523B354D332D492D2545261E
421F16401B12401D1543251D482F274A322B4A342D49342E48332F46322E44312D43312E
42312F403330403534413939413B3C3F3A3B3D383A3B383A39363936363935383C373D42
3942473D494E414F5547575E4C5F664F646C51676F526972536B75566E7959737E5D7883
627D8968838F6E899479939F849FAA89A1AA8499A283969E83939A849197848E93858C90
868A8D87888A888687888384
8279777B706E7468666D5F5D6657545F4F4B594642533E3A4D3731482F294327213F2119
3C1A123B19113C1F1741292147302949322C47322D46322D44312D42302C412F2C3F2E2C
3E2F2D3D302F3E33323E36373E383A3C383A3A373A39373A36353833353932373C343C41
3641473B484E3F4F5746575F495D654B61694D636D4D65704F6873536C7856717D5B7682
607C8866838F6C879475919D7E9BA7819BA68299A282969F83949B849198848F94858D91
868B8E87888A888687888484
8178777A6F6E7266646B5D5B6355525C4C4855433F4F3B3648322D432A243D221B381A12
35160E3418103820183F2B2345312A46312C45312C43302C412F2B3F2D2A3D2C293B2C2A
3A2C2B3A2E2D3A30313A34353B36383A363938363936353933333830333830363B313B41
35414839484F3E4F5742555D445962465D67485F6A49626D4B66714F6A76536F7B577581
5D7B8763818E6A8692728F9C7997A37D98A48098A28197A082949C849299849095858E92
868B8F87898B888687888484
817877796E6D716563695C5961525059494651403C4A3733432E293D2520361C1630130C
2B100A2B140E331F193E2B2544312B44312C43302C412F2B3E2D293B2B29392A28372929
362A2A362C2C3730303833343835373836393635393334383033372E33382D363B2F3A41
32404736474E3A4C553D515B3F5660415964435C6745606B4864704C68754F6E7B547380
5A7986607F8C66838F6E8D997593A07C99A57F99A38197A182959D83939A859197858E93
868C8F87898C888788888484
807776786D6C6F6462665A585E504D5546434D3C3945332F3E292536201B301712280E08
220D0827151132201C402E2843322C43312D41302C3F2E2B3B2C29382A28352828332828
322829332A2B342E2F3631333734373635393435393234382E32372B31372A343B2C3940
2F3E4632454D354A53384E5839525D3C55613E5965415D6944616E4866734C6B7951717F
5777855C7C8A61818E6A8B9873929F7B9CA97E9AA68098A282969F83949B859298868F94
878C90878A8C888788898484
807776766D6B6D62616458565A4D4B5143404838363F2E2B372421301B1729120E230B07
200E0B28171434231F44322C45342E43322E41312D3E2F2C392B293428272F25252D2425
2C25272F282A322E2F35313336343736373B34373B31353A2D323829323728343A29383F
2B3D462E424C304751314A55344F5A37535F3957633D5C6841606D456573496A784E6F7D
537583587A885D7E8C6787967293A17B9EAB7E9CA8809AA48298A084959D859399869095
878D91888A8D888789898484
7F7675756C6A6B615F615654574B494D403E433432392927301F1C291512220D091D0906
180A082217143526224836304736314535304233303E302E392D2B342A292F27282B2628
2B26292F2A2C333032353235363639383A3E35393E31373C2C333928323826333A26373F
273B452B414B2C45502E4854304C5832505D3554613B5A673F5F6D4263724668774A6D7C
5073825478875A7D8C6789987496A57CA0AF7F9EAA819BA68399A284969E86949A879196
878E92888B8D888889898585
7F7675746B6A6A605E5F5453544847493C3B3E302F332422281816200F0C1C0805190907
180D0B271C193A2B274D3A344A3A344737334335323F33313B302F372D2E362D2F312C2E
322D2F3832343B383A3D3B3D3F40433D4246373D4231393F2B343A27313924323A24353F
233742273F4A26414D2643502847542E4D5B3253613959673C5D6C406271436776486C7C
4D7181507586567B8C6589997498A77DA3B17FA0AC829DA8849AA48598A087959B889297
888F93898C8E89888A898585
7E7675736A69685E5D5D5351514645453A38392C2B2B1E1D1E100F110201140402150909
18100F281E1C3D2E2A503E384D3C37493A364537354135343D33333A3232393133373133
3D3738423C3C4440414543444244473D4347373F4431393F2B343A26323924333C243740
243A4627424E22404E1F404F2847562D4E5D2F51603758673B5D6C406271426777466B7C
496F804B7384527A8C648A9A7599A87EA3B180A1AD839EA9859CA58799A188969D899398
899094898C8F89898A898585
7E7675726A69675E5D5B52514F45444237363429282519191106060B0000120706120B0B
1711122A211F41322D55423C50403B4C3D3A4638374237363F36373C35363A35363A3538
3C383A403D3E4341444445474145493C4348373F45303A402A343C26333B23343D243842
263C4828424E284350274553314E5B3352603656643E5D6B416170436676426879436B7C
456E80457083517A8C658A9A7799A87FA3B282A2AF85A0AB879EA7899BA38A989E8A959A
8A91958A8D908A898B8A8586
7D7675726A69665D5C5950504D43433F36353127272117170F0505110808150D0C1A1414
201A1A34282547373258453F53433E4F413D4A3E3C463D3C41393A3D37383A3538383639
39383B3D3D403F40434043463F454A3B4349363F463039402A353D25343D23343E233743
243C4827414E2945522E4A583853603B57643E5B6943616F436473416676406779406A7C
406C7F416E82527C8E688C9C799BA981A6B584A4B187A3AD89A0A98B9DA58C9AA08C969B
8C92968B8E918B8A8B8A8686
7D7574716968655D5C58504F4B43423E35352F27272017170F0707120B0B1711111F1918
2A22203B2F2B4B3C375A48425646425144424D4341494140464041433F41403E41424043
43424445454845474A44484C42494D3B444A353E452F394129363E25353F233440213642
213A4725404E2744522C495732505E3756643B5B6A3E606F3D61723D63763C65783C677B
3B697D3F6D82537E906D90A07A9BAA83A8B687A7B38BA5B08DA3AC8EA0A78E9CA28E989D
8E94988D8F928C8B8C8A8686
7D7574716968645C5C58504F4B43423D35352F272720181911090A140E0F1C1616251E1D
3026253F33304F3F3B5B49435849455448454F46454B444548444546444646464847474A
46484B46494D454A4E43494D3E464B384148323C432D384028373F263640243743233A46
233D4B23404F2342512947572E4D5D315262345767375B6C385E7039617439647739657A
36667C406F845780936D90A07699A87FA4B38BAAB68FAAB491A7AF92A3AA929FA5919A9F
9096998E91938D8C8D8B8687
7D7574716968645C5C5850504B43433D36362F2829211A1B120C0D1711131F191A292121
352B2944363351413D5C4A455A4C48564A485148484D47474A4647474548454649444649
43454941454A3F44493D4348394046343D442F39412B373F28363F253641253844243A48
253E4C2844522947552B4A592A4C5C2C4F602E546632586A345C6F376175386378356479
33667C437287578295698E9F769AAA84A8B696B4BF96AFB997ABB396A7AE95A2A8949DA1
92979B9092948E8C8E8B8787
7D7574716968645D5C5850504B44443E373730292A221C1D150F101B1516211B1C2C2424
382D2C45383651423E5A4A455A4D49574C4A524A494E48494A4749474648444548424447
3F43473D42463A4044373E43343C423039402C373F28343E26353F243641233744233A47
233D4B2541502846552C4C5B305160325465335769365B6D365F72376176336277326479
34677E46768A5984976B92A27DA1AF8DAFBB9EBAC49EB5BE9DB0B89CABB19AA5AA979FA4
95999D9293958F8D8E8C8787
7D7575716969655D5D5851514B45453E3838312B2C241E1F1610121C1617231D1E2E2626
392F2E4539364F423E5749455A4D4A584D4C534B4B4E494B4A484A4646494244473F4246
3C4044393E43363B41333A402F373E2C353D28333C25323C23333E223440213643213846
213B4A233F4E25445429495A2D4F5F30536533586A345B6E335D72325F743061762F6379
366A804A798E5F899B7197A785A5B396B3BEA5BDC7A6BBC3A4B6BDA1AFB59EA9AE9BA2A6
979C9E949597908E8F8D8888
7D7675716A69655E5E5952524C46463F393A322D2E2520211813141E1A1B2520212F2828
38302F4339374C413E554845594D4A594F4D544C4D4E4A4C49484A4545494042463C4044
393D42353A3F32383D2E363C2B333B27323A24303921303B20313D1F323F1E34421E3745
1E3A491F3E4D224253254758284C5D2A50622C54672C576B2C5A6F2C5D722B5F752D637A
3A6E844F7E92638D9F779CAB8BAAB79FB9C3AEC3CCB1C4CBACBCC2A7B4B9A3ACB19EA5A8
9A9EA0969698918F908D8888
7D7675726A6A665F5F5A53534D4747413B3C342E302722231A1517211C1E282324302A2A
393131433A394C4240554947594D4B5A504F544D4E4E4A4C48474A4344483E41453A3E43
353B4032373D2E353B2A323A263038232E37202D371E2D391D2F3B1C313E1B33411B3544
1B38481C3C4D1F415221455723495C254D6126516527546929586E295B712A5E7531667D
43748A5784976B93A480A3B196B2BEABC1CAB9CCD4BCCDD3B4C2C7ADB8BDA7B0B4A2A7AA
9D9FA29898999390918E8989
7E7675726B6B6660605B54544F4849423D3E3630322924261C181A221F212A2527312B2C
3932324139394C4240544847594D4B5A4F4E544E4F4D4A4C46464A4143473B3F44363B41
32383E2E343B293139262F37222C351F2B351C2A361A2B37192D3A192F3D183140183444
193748193B4C1B3F511D43561F475A204B5F224E6324536825566D255A712A6077376B82
4A7A8F5F8A9D769BAB8CABB8A2BBC6B7CAD2C9D8DEC6D4D9BBC7CCB3BCC0ACB3B6A5AAAC
9FA1A399999A9491918E8989
7E7676736C6B6761615C5656504A4B443F403833342B26281E1A1D2521232C2729322D2E
383233413B3B4B4242514847564D4B564E4E524E4F4B4A4D4445493E4146383D4333393F
2E353C293138252E35212B341D29321B2832182733172936162B39152D3D153040153344
163748173A4C183D501A42551B465A1D4A5F1F4E6320526822566D265C732F647B3F7288
5382956A93A481A3B198B4BFAEC4CDC2D2D9D2DFE4C9D5D9C0CACEB7BFC2AFB5B8A8ACAE
A1A3A49B9A9B9592928F8989
7E7776736C6C6862625D5758524C4D4641423A36372E2A2C211E202824262E2A2B332F31
393436413B3C4841414E4746524B4B514B4C4E4B4D48494C4244483B3F44353A412F363D
2A3139252E35202A331C2731182530162531142532122735122938122C3C122F40133244
13364815394C163D5018415519455A1B495F1B4D631D516821566E285E7634698047798E
5D899C759AAB8BABB8A2BBC6BACCD5CFDCE1D9E4E8CDD7DBC3CCCFBAC1C4B2B7B9AAADAF
A3A4A59C9B9C9692928F8A89
7F7777746D6D6A63635F595A544F504944453E393B322E302522242B27292F2D2F353133
3935373F3A3C4641414A45464D484A4C484A4B494C46474B3F4247373D4231383E2B333A
252E37202B331B273117253014232F1122300F22310E25340F28380F2B3C102E40103143
11354813394C143D5115415617455A18495F194D641D51692258712D637B3E7187538296
6B93A481A3B398B4C0B0C5CFC9D7DEDFE9EDDEE8EBD1D9DCC6CDD0BDC2C5B4B8BAACAEAF
A5A4A69D9B9C969393908A89
7F7877756E6E6B6565615B5C5751524C4749413D3F3632342A27292D2B2D322F32363336
3A37393E3B3D43404247444648464848464947474A4245493B3F45333A412D353D263039
202C361A283316253012222F0E202E0C202E0B21300B24340B27380C2B3C0D2E400E3144
0F354911394D123D5213415615455B174A611A4F661F546C285E76376B81497A8F608B9E
789CAC8EADBAA5BDC8BECFD7D4E0E5E4EDF1DCE4E7D2D9DCC8CED0BFC3C5B6B8BAAEAEB0
A6A5A69E9C9C979393908A89
807878766F6F6D6667635D5E5954554F4B4C4541433B37392F2C2F302E31343235383538
3A393B3E3C3F4240434644474746494646494345493E4348373D442F373F28323B212D37
1A29341525321122300D202E091E2D061E2E0620310723350927390A2B3D0B2E410C3245
0E354A0F3A4E113E5313425815465D184B631D526924597131667D43758A5885986F95A7
86A6B59BB6C2B3C8D1CDDAE0E0E8ECEAF2F4DFE5E7D4D9DBCACED0C0C3C4B7B8BAAEAEAF
A6A5A69F9C9C979393908A89
8079787771706E68686560605C5758534E504A4647403D3F37343734323536353839383B
3D3C3E3F3E4143424546454946464A45464A41444A3C4248333C442C363F24313B1B2B37
1527341023310B202F081E2E041C2D011C2D021F3105233507283A092C3F0A2F420B3347
0D374B0F3B5111405614455B174A611C4F6724576F2E62793F70865380936890A17FA0B0
95B1BEACC2CCC4D4DADBE4E8EDF4F6EEF4F6E0E5E7D5D9DACACDCFC0C2C4B7B8B9AFAEAF
A7A5A59F9C9C989392908A89
817A79797271706A6A6862635F5A5B5752544E4A4C4642453E3B3E36353838373A3B3A3E
3E3E4140404343434747474A47484C46484D41464B3D434A353D462D384122313D172A38
1026340C2231082030041E2F001C2F001E30022234042639062A3D082E410A32460B364A
0D394E103D5414435A1749601C4F6624566D2E61773C6E834F7C90638B9D799CAB8FADBA
A6BDC8BDCFD6D4DFE4E7EEF0F5F9FBEBF0F1E0E3E5D4D7D8CACCCDC0C1C2B7B7B8AFADAE
A7A4A49F9B9B989292908A89
817A797A7373726C6C6A6465635D5E5B5657534F514B484A4441443B393D3B3A3E3F3E41
41414443434745454949494D494B4F474A4F42474D3E444B3840482F3B442434401A2E3C
1429380F26360B243507233503223504243706273A082B3E092E430B33470D364B0E394F
113E541543591A4A601F4F6626576D3060763D6D824D7A8D61899A7698A88CA9B6A2BAC4
B9CBD2D0DBE0E3EAEDF4F7F9F9FBFCEAEDEEDEE1E2D3D5D6C9CACBC0C0C0B7B6B6AEACAD
A7A3A39F9B9A979292908A89
827B7A7B7474746D6E6D67676660615F5A5B585355514D4F4A47494341443F3D40424144
44444747474A49494D4D4D514B4D51484B5043484E3E454C38414A313C47283843203341
1A303F172F3E122C3D0E2C3D0C2B3D0C2C3F0D2F410E324510364A123A4E143D52164156
1A465B1E4B612552682B596E356277406D804F798B6086977496A589A5B29EB6C0B5C7CF
CDD8DEE1E7EAF1F4F6FEFFFFF6F8F8E8EAEADCDDDED1D2D3C8C7C8BEBEBEB6B4B4AEABAB
A6A2A29E9A99979291908989
837B7B7C7575766F6F6F696A696364625E5F5C5859565254504D4F4A484A444346454447
48484B4B4B4E4C4D504E4F534C4E53494D53444A5041484F3C454E34414C2D3E49283B48
2338462138461C35451A354618354618364719384A1A3C4E1E405221455723495C254C60
2951652F576B365F723E6779487082547A8B6487977594A389A3B09CB3BDB2C3CBC9D4D9
DFE5E8EFF2F3FEFFFFFDFEFEF0F0F0E4E4E5D9D9D9CFCECFC5C4C5BDBBBBB4B2B2ACA9A9
A5A1A19E9998979190908988
837C7B7D7676777171726C6C6C6667666162615C5D5B5759565355514E504B494C48474A
4C4C4F4F4F524F50545051554F52564E5157484E54454C5340495138454F34444F30424E
2C404D2A3F4D263E4D263F4E253F4F2541512644542948582D4C5D30506133546536596A
3C5E704265764A6C7D5174845B7D8C6988967995A28AA2AD9CB0BAB1C0C7C6D0D5DCE1E4
EDEFF1FDFEFEFFFFFFF4F4F4E9E9E9DFDEDED5D4D4CBCACAC3C1C1BAB8B8B2AFAFABA7A7
A49F9F9D989796908F908988
847C7C7E7877797373746E6E6F696A6A6566656061605C5D5C585A5754565351534E4D4F
51515353535654545855565A54565B51555A4D5258495057454F573F4C563E4C563A4955
374855354854334855324856324A58344D5B37505E3A53623E5867415C6B4661704A6675
506C7B5873815E7A8765818E6F8A977D95A18DA1AC9DAFB7B1BEC4C4CDD1D6DBDEE9EAEB
FBFAFAFFFFFEF5F5F4ECEBEBE2E1E1D9D8D8D0CECEC7C5C5BFBDBDB7B4B4B0ADACA9A5A5
A29D9D9C9696958F8E8F8887
847D7C8079787B7474767070726C6C6D6869696465656162615D5F5E5A5C5A585A585759
58575A59585B59595D5A5B5E595B5F585B5F55595F51575E4E565E4A545D48545D45525D
43525D41525D41535F415460435662455965485C684B5F6C5064705469755B6F7B5E7380
657A866B808B718691798D978497A093A3ABA2AFB6B3BCC2C4CACDD5D7D9E6E6E6F6F4F3
FEFDFCF6F5F4EDECEBE4E3E2DBDAD9D3D1D1CBC8C8C3C0C0BBB8B8B4B1B0ADA9A9A7A2A2
A19B9B9B9594958E8D8F8887
857D7D817A797D7676797272756F6F716B6C6D68696A6566666264646061615E60605D5F
5F5D605F5E60605F626060636161646061655D60655A5F65595F65555D65545D66535D66
515D66515E67525F6952606A53616C55646E5867725C6B7560707A66757F6C7B8471818B
7988907D8B948391998C9AA199A4AAA6AFB4B4BABFC4C7CAD3D4D5E2E0E0F0EDECFAF8F7
F7F6F6EDEBEBE4E2E2DCDAD9D4D2D1CCCAC9C5C2C2BEBBBAB7B4B3B1ADACABA6A6A5A09F
9F9999999392948D8C8E8786
857E7D827B7A7E77777B7474777171746E6F716C6C6E696A6B6768696566676465666365
66636566646666646767656867666A66676B66686C64676C64676C61666D60676E61686F
606870606971606A72616B74636D7566707869737B6D777F717B827680877C868D828B92
878F958C9499939BA09EA5A9A8ADB1B3B7BAC1C3C5D0CFD0DDDBDBEAE6E6F6F3F2F5F3F2
EBE9E9E3E1E0DBD9D8D4D1D0CDCAC9C6C2C2BFBCBBB9B5B5B3AFAEADA8A8A7A2A2A29D9C
9D9796989191938C8B8E8786
867E7E837C7B8079787D76767A7474777171746F6F726D6D706B6C6E6A6B6D696A6C686A
6B686A6B696A6B696B6C6A6C6D6C6F6E6E716F6F736E6F736E70746C70756D7176707379
70747A70757B70757C70767D72787F757B81787D847C828780858A858A8E898E928E9195
92969994999C9B9FA3A5A9ABAFB1B4BDBDBECCC9CAD9D5D4E6E0DFEEEAE9F0EDECE7E5E4
E0DDDCD9D6D5D2CFCECBC8C7C5C1C1BFBBBAB9B5B4B3AFAEAEA9A9A9A4A3A49F9E9F9A99
9B959496908F928B8A8D8685
867F7E847D7C817A7A7F78787C76767A7474787272767071746F6F736E6E726D6E716D6E
716D6E716D6F716E7072707274727574737677757977777A77787C77787D797A7F7B7C81
7C7D817D7F837E80857E808681828784858A87888C8A8B8E8D8D919292949494979B9A9B
9D9C9EA1A0A2AAA8A9B2B0B1BDBABAC9C5C4D3CECDE0D9D8E9E4E3E8E5E4E2DFDEDBD8D7
D4D1D0CECAC9C8C4C3C2BEBDBDB9B8B8B3B2B3AEADAEA9A8A9A4A3A59F9FA09B9A9C9696
989291948E8D918A898D8584
877F7F857D7D837C7B817A797F78787D76767B7575797474787273777272767172767172
7571727672737673747874767A77797F7C7E7F7D7F7F7D807F7E81808084848386888689
89888B88878B89888C8C8A8E908D90908D90918E919491929794959A96969C9899A29E9D
A4A0A0A9A5A5B0ACACB9B4B4C3BDBCCDC6C5D3CDCCDFDAD8DFDBDAD8D5D4D3CFCECDC9C8
C8C4C3C3BEBEBEB9B9B9B4B4B4B0AFB0ABAAACA7A6A8A3A2A49E9EA09B9A9D9796999392
968F8E938C8B8F88878C8584
87807F867E7E847D7C827B7B817A7A7F79787E78777D77767C76767B75757A75757A7575
7A75757A75767B76777C78797E7A7C817D7F8481838683858885888A878A8D898C8E8B8D
8F8C8E908D8F938F91948F91948F90938F909792929893939A95949C9796A09B9AA49E9E
A9A2A1AEA8A6B4AFAEBCB7B6C3BDBCCAC5C4D1CDCCD5D0CFCEC9C8C9C4C3C4C0BFC0BBBA
BCB7B6B7B2B2B3AEAEB0AAAAACA7A6A9A3A2A59F9FA29C9B9F99989C969599939296908F
938D8C918A898E87868C8483
88807F877F7E857E7D847D7C837C7B827B7B817A7A8079797F79797F78787E78787E7878
7E78787E79797F7A7A807B7B827D7D847F808682838A8586918C8D948E90938D8F948F8F
9691929791929790919690909690919791929A93939B95949F9896A19A98A39C9BA69F9D
A9A3A1AEA8A7B2ADACBBB6B5C1BCBBC4C0BFC4C0BEC0BBBABDB8B6B9B4B3B6B0AFB2ADAC
AFAAA9ACA6A5A9A3A2A6A09FA39D9DA19B9A9E98979C9595999392979190958E8D938C8B
918A898F88878D86858B8382
88818087807F877F7E867E7E857E7D847D7C847D7C837C7C837C7B827B7B827B7B827B7B
827B7B827C7C837C7C837D7D847E7F8680808882828A85858D8888908A8A938D8C989190
9892919790909891919791919690909790919791909992919B94939D96959F9897A19A98
A49E9CADA6A5B0AAA9B4AEACB2ADABB0ABAAB0AAA9AEA8A7ABA5A4A9A3A2A7A1A0A59E9D
A29C9BA09A999E98979D96959B9493999291979090968F8E948D8C938C8B918A89908888
8E87868D86858C84838A8382
89818088818088807F87807F87807F877F7E867F7E867F7E867F7E867E7E867E7E857E7E
857E7E867F7E867F7E867F7F8780808881808982818A83838B84848D86858E8786908988
908988908988918A89918A89928C8A968E8D978F8D98918F9992909A93919B94929D9594
9F9897A19A999E97969E97969D97969D96959C95949B94939A939299929198919097908F
968F8E958E8D948D8C938C8B928B8A918A899089888F88878F87868E86858D86858C8584
8C84838B83828A83828A8281
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.25526 0.97619 0.476744 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(135) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
BFA390BFA28FBFA28FBFA28EBFA18EBEA18EBEA18DBEA08DBEA08CBDA08CBD9F8CBD9F8B
BD9F8BBC9E8ABC9E8ABC9E89BC9D89BC9D89BB9D88BB9C88BB9C88BB9C87BB9C87BB9C87
BB9C88BB9C87BB9C87BB9C87BB9C87BB9C87BB9B87BB9B87BA9B87BA9B87BB9B87BB9B87
BB9B88BB9C89BB9C89BB9D89BB9D8ABC9D8ABC9E8ABC9E8BBC9F8CBC9F8DBDA08EBDA18F
BDA18FBDA18EBDA08DBDA08DBDA08DBDA08DBEA18DBEA18DBEA18DBEA18EBEA18EBFA28E
BFA28FBFA28FBFA38FBFA390
BFA28FBFA18EBEA18DBEA08DBD9F8CBD9F8BBC9E8ABC9E8ABB9D89BB9C88BB9C87BA9B86
BA9A85B99A85B99984B89883B89782B79781B79680B79580B7957FB6957FB6947FB7957F
B7957FB6947FB6947EB6947FB6947FB6947FB6937EB5937DB5927DB5927DB5927EB5927F
B69480B69581B79582B79683B79783B79784B89884B89985B99A87B99B89BA9D8BBB9F8E
BBA08EBB9E8BBB9D8ABB9D89BB9D89BB9E8ABB9E8ABC9E8ABC9E8BBC9F8BBD9F8CBDA08C
BEA18DBEA18EBFA28FBFA38F
BFA28FBEA18EBEA08CBD9F8BBC9E8ABB9E89BB9C88BA9B86B99A85B99984B89882B79781
B79680B6957FB5947EB5937DB4927BB3917AB38F78B28F77B28E76B28D76B18D75B18C75
B18C75B28D76B28D76B28D77B28D77B28D77B28D77B18D78B18C78B28C78B28C78B38D79
B38F7BB4907CB4917DB4907DB3907DB3917DB3927EB49480B59582B69784B79987B99C8B
B99D8BB89A88B89A86B89986B89A86B99A86B99A86BA9B87BA9C88BB9D89BB9D8ABC9E8B
BD9F8CBEA08DBEA18EBFA28F
BFA28FBEA18DBD9F8CBC9E8ABB9D88BA9B87B99A85B89984B79882B69681B5957FB4937D
B4927BB39079B28F78B18D76B08C74AF8A72AE8970AE876FAD866DAC856CAC856CAD856C
AD856DAD856EAD866EAD866EAD866FAE8770AE8872B08974B08A75B08A76B08A76B18A76
B18A76B18A76B18A77B18B77B08B77B08C78B08D79B18F7BB2917DB3927FB49481B59683
B59683B59682B59581B59581B59681B69782B79883B79984B89985B99A86BA9C87BB9D89
BC9E8ABD9F8CBEA18DBFA28F
BFA28EBDA08CBC9F8BBB9D89BA9B87B99984B79882B69681B5947FB4937CB3917AB28F78
B18D76AF8B74AE8A71AD886FAC866DAB846BAA8268A98066A87E64A77D63A77D62A77D63
A87E64A87E64A87F65A97F67A98068A9806AAA816BAA836DAB846FAB8570AC8670AD8671
AD8671AD8671AD8771AE8772AD8672AD8773AD8974AE8975AE8B76AF8D79B0907CB1917D
B1917DB1907CB1917CB2917CB3927DB3937EB4947FB59580B69782B79883B89985BA9B87
BB9D89BC9E8ABDA08CBEA28E
BEA18EBD9F8CBB9D89BA9C87B99985B79782B69580B4937DB3917BB28F78B08D76AF8B73
AE8971AC876EAB846BA98269A88066A77D63A57B60A4795DA2765AA17458A17357A27458
A3765BA3775DA4785EA4795FA47961A47A62A57A63A57A64A67C65A77D68A77F69A77F69
A87F69A87F69A88069A8806AA9816BA9816AA9826CA9846EA9856FAB8772AC8B77AD8C78
AD8B76AD8B76AE8C76AF8C77B08E78B18F79B2917BB3927DB4947EB69681B79783B89985
BA9B87BB9D89BD9F8BBEA18E
BEA18DBC9F8BBB9C88B99A85B79882B69580B4937DB2917AB18E77AF8C74AE8971AC876E
AA846BA98268A77F65A67D62A47A5FA2775BA174589F71549D6E509B6A4C9A68499C6A4C
9E6F529F70559F71579F7258A07359A0735AA0735BA0735CA0745CA1745DA1755EA2765F
A2765FA27760A27861A37962A37A62A47A63A47B63A47C65A57F68A7816AA8836EA8856F
A9856EA9856EAA866FAB8771AC8973AE8B75AF8D77B18F7AB2917CB4937EB59581B79783
B99985BA9C88BC9F8BBEA18D
BEA18DBC9E8ABA9B87B89883B69680B4937DB2917AB18E77AF8B74AD8970AB866DA9836A
A78066A67D63A47A5FA2775CA074589E71549C6E509A6A4B976546935F3E94603F996748
9A694C9B6B4F9B6B519B6C519B6C529B6C529B6B529B6B529B6A529B6A529B6A529B6B53
9B6C559B6D569C6F579C71589D72599E735B9F755CA0765DA17860A27A62A37C64A47D65
A47D65A57F67A68069A8826BA9846DAB8770AC8973AE8C76B08E79B2917BB4947EB69682
B89985BA9C88BC9E8ABEA18D
BEA08DBB9D89B99A85B79782B5947EB3917BB18E77AF8B74AD8870AB856DA88269A67F65
A47C61A2795DA075599E72559C6E519A6B4D986748966343935E3D915B3B945F3F976445
97654797654897664996654A96654A96654A96654B96634A956249956048945F47945F47
94614995644C95674E966950976A52996C53996E549B6F559C70569C71579D72589F745A
A0765CA1785EA27A61A47D64A68068A8836BAA856EAC8872AE8B75B08E79B2917CB4957F
B79883B99B86BB9D89BDA08D
BDA08CBB9D88B99985B69680B4927CB18F79AF8C75AD8971AA856DA88269A67F65A47B61
A1785C9F74589D70539B6D4F98694A966545946140925D3C905A3696603D9A6644966242
946042936041925F42925F42915F43915E43915D43915C43905A418F59408F59408F5941
8F5A418F5C438F5E4590614791634993654B95674D96694F976A4F986A4E98694D996A4D
9B6E529D71569E745AA0775EA27B62A57E66A7826AA9856EAC8972AE8C76B18F7AB3937D
B69681B89985BB9D89BDA08C
BDA08CBA9C88B89883B5957FB3917BB08D77AD8A72AB866EA8826AA67F65A37B61A1775C
9E73579C6F53996B4E976749946344925F3F905B398C5531925B38996442966140935E3E
915C3D8F5B3B8E5A3A8D593B8D583B8C583C8C573C8C563C8B543A8B52398A51398A513A
8A523B8A543C8A573E8B59408C5C428D5F448F6247916348936448936346936143946243
966648986A4D9A6E529C72579F765CA17A61A47E65A7826AA9866EAC8973AF8D77B2917B
B5947FB79884BA9C88BDA08C
BD9F8BBA9B87B79883B4947EB19079AE8C74AC8870A9846BA68066A37C61A1775D9E7358
9B6F53986B4D966748936243905E3D8E5A388C5532915A37955F3C935D3A915C3A8F5A39
8D58378B553589533488523488523487523587513687513687533987553A86553A86563C
86553C85533A85533A85553C87583E895B408B5D428D5F438F6044906043905E40905C3C
915D3D93634596684B986C519B71569E755CA17A61A47E66A7836BAA8770AD8B75B0907A
B3947FB69783BA9B87BD9F8C
BD9F8BB99B86B69781B3927CB08E77AD8972AA856DA78168A47D63A1785E9E74599B7053
986B4E9567489262438F5D3D8C58378A5431864E2A88502B8E57338E58358D57358B5635
895433865130844E2E834D2F824D30824D30824E3183503483563A835A3F835E42845F44
825B4081563B80543981533982543A84573C86593D885B3F8A5D408C5D408C5C3E8C5A3B
8D5A3A8F5C3D91614494674A976C519A71579E765DA17B63A58068A8856EAC8973AF8E78
B2927DB69782B99B87BC9F8B
BC9F8BB99A85B59580B2917BAF8C75AB8770A8836BA57E65A27A609E755A9B7155986C4F
9567499262438F5D3D8B5837885331844D2988502B8D55318B55328A5432895433875333
855030824D2C7F4A2A7E482A7D482B7B482C7D5034815A3E835E4485644A856249825D43
805F437E5E447C593E7B52377D513680533883563B85583D875B3E885B3D895A3C895839
8855358956368C5B3D8F614493674B976D529B72599F785FA27D65A6826BAA8771AE8C76
B1917CB59681B99A86BC9F8B
BC9E8AB89985B5947FB18F79AD8B74AA866EA68168A37C629F775D9C7257996D5195684B
9263458F5E3E8B5838875331844E2B814A26844D29895330885330875230865231845130
824F2F804C2D7D4A2B7947287A4D2F815B3F84604582614682634882614682624682644A
83644B8161487E5C4179563B7851367C51367F533982563A84583C85593C85583A855537
8554358554358656388A5B3E8F624693694E986F559C755CA07B63A48069A8866FAC8B75
B0907AB49580B89A85BC9E8B
BC9E8AB89984B4947EB08F78AC8972A8846CA47F66A1795F9D74599A6F53966A4D936547
8F60418C5A3A875432834D2A7F4825804825844D2A86512E85512F845231835231815030
7F4F2F7D4F307D50327E53347F55378056387F57397E583A7E583B7D57397D573A7D573B
7E573B805A3D825E42825D437C563D784F357A4F357D533780553981563A825538825436
8252338251318352328555388A5D4190654A956C529A72599E7960A37E67A7846DAB8973
AF8F79B3947FB89985BC9E8A
BB9E8AB79883B3937DAF8D77AA8770A68269A27C639E775D9B7156976C5093674A906243
8D5C3D89573685502E7D4622783F1981492488522F85512F83502F814F2F8050307F5031
7E51327F5538815D408564488463477F5C407D593C7B56387A5235795134795134794F31
794F327A53357C55387E563B7F573C7A5238784F347B51367D53377E53377F53367F5234
7F5133805031815132845537875B3E8D6247926A4F9770579C775EA17D65A5836CAA8872
AE8E78B3937EB79984BB9E8A
BB9D89B69783B2917CAD8C75A9866EA47F67A07A609C745A986E5394694C9164468D5E40
8A593A875534844F2D804A27814B2786522E86543183512F804F307E4F317D50317C5032
7B51347B53367C563A7E5B3F7D5D417C5D407B5C407A5B3E795A3D78593B78583B77593B
77593B7856387954387B55397D56397E573B7B54397951367A51367B52367C51357C5133
7C4F327C4E2F79492A7D4E2F85593C8A604490684D956E559A755C9F7B63A4816AA98771
AD8D77B2937EB79884BB9E8A
BB9D89B69782B1907BAC8A74A7846CA37E659E785E9A7157956B509166498E60428A5B3C
88563686533186512F8D5835935E3A8C583583512F7F4F2F7C50307B4F317A4F32795133
78523578533778533777543777563976573A76563A755639745438735437735437735437
73543773543773563876593B7A5C407D5F447D5E437A583D785337785136795135795034
7A50327A4E317A4F327C513482573A885F448E664C936D5399735B9E7A62A38069A88670
AC8C76B1927DB69883BB9D8A
BA9D89B59681B08F7AAB8972A6826AA17C639C755B976F5492684C8E62458A5C3E875737
845231834F2C834D29854F2A85512F82502F7D4D2D7A4C2D784D2F774E31754F32754F33
755035755135734F33724E31724F337151357151357051356F51356F51346E4F336E4E32
6D4F336E50346F513572533874563A76583D78593D78573D77543A765137765035774F34
784F33784F32784E317B513581573C865E438C654A926C5297725A9C7961A17F68A7856F
AC8B76B1917CB69783BB9D8A
BA9C88B49580AF8E78A98770A480699E7961997259946B518F65498A5E4186583A825233
7F4D2C7D48267C46237B46227A452278462577472975482A73492C724A2E714B2F704C30
704C32704D326F4D316E4B2F6D4A2E6D4B306C4B306B4B2F6B4C306A4C316A4C31694B30
6A4B316B4D326D4E346E513771543A73563C74563C75553C745339735037745036765036
775035795035795034794F327E5437845C408A6349906A519671599B7860A07E67A6846E
AB8B75B0917CB59783BA9D89
BA9C88B49480AE8D77A8866FA27E679C775E96705691684E8B6145865A3D8253357E4D2D
7A472677421F753F1B733E1C723F1D7341217242237043266E45286D45296C462A6B472B
6B492D6B4A2E6A4A2E69482C68472B68482C68492E67492F67492F67492F664930664A30
674A31684B32694C346B4F366D51396F533D71553E71553D705239705037725037745037
7651367952377C53377B50337C5135835A3F8962488F6A519470589A77609F7D67A4846E
AA8A75AF907CB59783BA9D89
B99B87B3947FAD8C76A6846DA07C659A755C936D538D654A885D418256397D4E30784727
74401F703A196D37156B36146B3A196C3D1F6B3F216A4022694023684125674125664126
65432865442A65452B64452B64452963442963442963452A62452B62452B61442B61452C
62462E634930654B32674C34684E376B513A6C523C6C513A6C50386D4F376F4F36714F37
7551387A543A825A3E865B3E80553981583E8963498E695193705898765F9E7D66A3836E
A98A75AF907BB49682BA9D89
B99B87B2937EAB8B75A5836C9E7A6397725A916A508A624784593E7D513477492B724121
6D381768310F652D0C643011643618653A1B653C1E643C1E633B1F623B1E613B1F603B20
5F3C215F3D235F3F256041286042285F41275F40265E40265E3F265D3F265D40275D4129
5D422A5E442C5F462F614933644C36654E37664D37674C36684B35694B346B4B346E4D35
724E367752397D573F855E458B664C8B664D89654C8D6951926F5897765F9D7C66A2836D
A88974AE907BB49682BA9D89
B99B87B1927DAA8A74A3816B9C79619570578D674E865E447F553A784D307244266B3B1C
663313612D0E5E2D0E5E30116034156036185F371B5F371B5E361A5C361A5B35195A351A
59351A59361C5A381F5A3A225A3C235A3D255B3E265B3E275A3E265A3E26593E27593F27
5940295A412B5C442F5E4833604934604933604833614832624731644832664832694934
6D4C35714F3876523A7C573E815C43845F4787634B8B6851906E5895755F9B7B66A1826D
A78974AD8F7BB39682BA9D89
B89A86B1927DA98973A180699A775F926E558A644B835B417B523673482C6C3E20643414
5D2D0C582B0A562B0C572E0F5930135A32155A3317593317583216573015552F13542E13
532E15532F1653311954341B55361E563820563A22563B24563B25563B25563C25563D27
563E2857402B58422D59432E59432E5A432E5A422D5B422D5C432E5E442F61452F634731
6749326B4B35704E3775523A78533B7C573F825F4888664F8E6D5794745E9A7A65A0816D
A68874AD8F7BB39682B99C89
B89A86B0917CA88872A07E6898755E8F6B538762497F583E764E336E442865391C5C2E0F
5324054B20024A22064E280C522C11542E13552F13542E13532E12522D11502B114E2A10
4C29104C2A124D2C154E2F184F321A51341D523720533822533A23523B24523B25523B25
523C26533D28533D29533D2A533D2A523D29533D29543E2A563F2B59412D5B432E5E442F
6145306547316848316D4B33724E3578533B7E5C4685644E8B6B5692735E987A659F816C
A58874AC8F7BB29582B99C89
B89A86AF907CA787729E7D6796735D8D6952845F467B553B724A30694024603519572B0E
4C2105461E03451F0548240A4D290F4F2B11502C12502C124F2C114D2A114A281048270F
46260E46250E46250E4828114A2C154D301A4F341E5037215038224F38234F38234E3824
4E39244E39254D39254C38254B37244B37244C37244E3825503A27523D29553F2B58402C
5B422E5E432E61452F6546306B4A3473523C7A5A4581634D886A558F725D9679659D806C
A48773AB8E7BB29582B99C89
B79A86AF907CA686719D7C6694725C8B6850815D447751386D462C643B215B3115532A0F
4D260C47220844210846240B4A280E4C2A104D2B124D2C134B2A1148270E44230A402007
3E1F073E200941220C43250F462812492E184C331E4E36224E38244E38244D38234C3823
4A37234936234734224533214532204533204633214835224B37254E3A27503B28533D2A
563F2C58402D5A402D5E412D6547326E513C7659457E614D8669558D715D9578659C806C
A38773AA8E7BB29582B99C89
B79986AE907BA586719C7C6693715B89664F7E5A43734E366842295E361C552C114D250B
4420083F1E0741210945250D4828104A2A124C2C144C2D154C2D164A2C15472913422611
3C220D3B220C3E240E412611442712482D184B34204D38244D39264C39264B3825493724
473522453321443321433120412F1E3F2D1C402E1D43311F4634224936244B38264D3A28
503C2A533E2C56402E5C43326349376B503E7359467B604D8368558B705D9378659B7F6C
A28774AA8E7BB19582B89C89
B79986AE907BA586719C7B6692715B87654F7C5942704B33633D245730164E260D482309
46240C45240E44240E462710482A14492C154A2D174B2E194C301C4E331F5035214F3420
4B321D48311C47311E4934214D38254E3A274D39264D3A284C3B294C3A284A3927483625
45322242301F3F2F1E3B2B1A3828183829193B2C1B3E2E1D41301F4533224836254A3827
4C39294D3A2A4F3C2C5542325E4A3A67514070584678604E816855896F5D9277659A7F6C
A18674A98E7BB19582B89C89
B79985AE907BA586719B7C6791715B87654F7B59426D4A325D38204B2309411A00411F07
42230C432510442712452914472B16492D184A2E1A4A2F1B4C321E4E3624513927553D2B
5A43305A443157422E54412E51402E4F3D2C4E3C2A4D3B2A4C3B2A4C3B2B4C3B2B4B3B2B
4A3C2C473A2B403326392C1F372A1C392B1D372A1B392A1C3E2E1E423121463526483828
483829483829493A2B4E3E2F584637634F3E6C5645765E4D7F6755886F5D907765997F6D
A18674A98E7BB09582B89C89
B79A86AE917DA587739C7D6992725D8767517B5A446D4B3459351C4B270E401F08391A04
3A1E0940240F452914482C17492D19492F1C4A2F1D4A2F1D4B32214D3726503B2B533F30
5542325644345645365444345242334F40314E3E2E4D3D2D4C3C2D4C3D2E4C3E2F4C3F30
4D40304D3F304D3E2F4B3C2E47392B44362844352744352746372947382B47382A46382A
45382A44362845372A4C3D2F5542335E4A3A695444735D4D7D6655866F5E8F7766987F6D
A08775A88E7CB09583B89C89
B79B88AE927EA688749C7F6A937460886A557D5E4871513B63432C5738214D311B452A16
422814452B16492D1A492E1B4A301D4A321F4C36244D38284B36254A35254B38284C3B2D
4E3F314F41335042344F41344F41344F42344E40314D3D2F4C3D2E4C3E304C3E324B3E32
4B3E314B3F314E413354463858493A5445375242344F41334C3E31483B2F463A2E45392D
43372B42372B45392D4C3E315443355C4A3B665344715C4D7B6656856F5E8F7767987F6E
A08775A88E7CB09583B89C8A
B79B88AF927FA68A769E806C9477638B6D5981634E7658436B4E3960432E553B274F3622
4C331F4B331F4A33204A321F49311F4B34234C38274F3C2D51413352433653443856493D
5A4E425A5045594F44574E43544A3F5045394D41344C3E314B3D314B3F334C40354A3E34
483C32483C314A3E324D41345043375145395045394D4237493E34463B3245393043382E
41362C40362C443A304E423654463A59493B6351426F5C4D7A66578570608F786898806F
A08876A88F7DB09684B89D8A
B89B88B09380A88B779F836F977A678E715E8568557C604C7358446A4F3C6147345A412E
543C295139264E37254B34224933224A35244C38284D3C2E50413453483C574E435A5247
5B554C5B564E5A564E575249524B404E44394B4034493E31493E324B40344D443850473D
4F463D493F38453B32453B32483E344940354A4035483E35463C33443A31433A31423830
3F362E41372F473D344A40364E42375243365D4C3E6E5C4E7A67598571628F7A6A988271
A18978A9907EB19684B89D8A
B89C89B19581A98D7AA18673997E6B917663896E5B816654795F4D7159476A5240634B39
5D453458402F523B2A4E37264B35254A35264A37284C3A2C4D3E314F433751473D534B41
534C43534D45524C445049414D453C4A4136483D32473C30473C30493E334B41374F453C
524A42554C445349414C433B453D35433B33433B33433B33433B33443C34443C35423A33
403A32433C34473F374740384B433A564B406355487060527C6A5C877365917C6D998473
A28A7AAA9180B19785B89D8B
B99D89B29683AA8F7CA388759C816F947A688D7361866C5A7F665579614F725A496A5342
644D3C5D46365640304E39294935254834254936274A382A4A3B2E4B3D314C40354D4238
4D443B4C443B4B433A494138473E35453C3244392F43382E44392E453A30473C334A4037
4D443B50483F534B42554C44544C445048404D453D4C443D4B443D47413A433E37413D36
423E3746413A4A453D4D4940514D455B5349675B4F7364577F6E60897769937F709B8676
A38C7CAB9281B29886B99E8B
B99D8AB39784AC917FA58B799F8573987E6C9178678A7261846C5A7D6654776150715B4B
695343614B3B5843334F3A2C49352647332547342647362947372B47392E473A2F473B30
473C32463C32453B3143393041372D40352B3F332A3F33293F342A40362C42382F443A31
473E354A41394D443D4F4840514A43524B44504A444D48424A443F46423C43403A423E38
44413B4A4741504C4656514A5B564E625A506B5E5376675B8373668D7C6E9683749E897A
A58F7FAC9483B39988B99E8C
BA9E8BB49886AE9381A88E7CA188779B8271957D6C8F7767887262826D5E7D6859766153
6D5A4B6351435A4739513E3149362946332546332645342744342844342943352A42352A
41342A40342A3E33293D32283B30273A2F25392E24392E253A2F263B30273C322A3E352D
413831433C34463F3849423C4A443E4A453F4A454048443F45433E43423C41413C41413D
4545414E4D4855534E5C5953635E576B645C73695F7E7166897A6E9282759A887AA18D7E
A79282AE9686B49B89BA9F8D
BA9F8CB59A88AF9583AA907FA48B7A9F8776998272937D6D8E7869887365826E607C695B
7461546B584B604F4257463A4D3C31473529443226433125413024402F233E2F243D2F25
3B2F253A2D24382C23372B22352A2134292033281F332820342921352B23362D26383029
3A332C3D3630403934423C37443F3A44403C44413D44413D43413D43413D42423E454542
4E4D495554505D5B5666635E6F6B6578726B807970897F7591847998897C9E8D80A49183
AA9585B09988B59C8BBAA08D
BB9F8DB69B89B19786AC9382A78F7FA28B7B9D8677978273927E708C7A6C877568816F62
79675B6F5E526554495B4A3F5341364A392D4432274030243E2E223C2C203A2A1F38291E
36281E34271D32261D30241B2F231A2E221A2E221A2D231B2D241C2F251F302821332A24
352E2837312D3A35303C37333D3A363F3C383F3E3A403F3C41403D40413E4344424A4B48
5354505C5D59676661716F697B7871858079918B84978F87998E849E9084A39286A89587
AD9889B29B8BB69E8CBBA08E
BBA08DB79D8BB39988AE9685AA9383A68F80A18B7D9C8779968375917E728B7A6D857468
7D6D6275655B6B5C525E514754463C4A3C3343342A3E2F253B2C2138291E35261C332419
3022172E20162C1E152A1D14281C13271B13271B14271C16281F1829211B2B241E2D2722
2F2A25322E2934302D3633303837343A39373C3C3A3D3E3C3E403F414442474A48505251
5B5D5A66676471716D7C7A7586837E908C8599928B9E958DA1968CA4968BA8988BAC998C
B09B8CB49D8DB89F8EBCA18F
BCA18EB89E8CB59B8AB19989AD9687A99485A59183A28F829D8B7E9886799180758A7B70
84756B7A6C626F615863564D564B424A3E3641342B3B2D2437291F34251B3122172D1E13
2A1B1028190E25170D23150C21150C20150D20150F201610211813221B16251F1A27231F
2A26232D2A26302E2B32312F353432373736383A39393D3C3C4140414646494E4E555959
6165636E6F6E7A7A77858380908E8A9D9893A39E97A59D95A79D94AA9D92AC9D91AF9D90
B39E90B69F90B9A190BCA290
BDA18FB99F8EB69E8DB39C8CB09A8BAD988AAA978AA79589A493879E8F8497897E908278
887A717E716873675E675C54594F484B413A40352E392D2534271E3022182C1D1328190F
25160B2113091F11081D10091B0F09190E08180E0919100C1A13101C17141F1A18221E1B
25221F2826242B2A292E2F2E313332333636363A3A393D3E3D4244444B4C5056575D6263
6B6F6E797A7985858392908D9F9C98ACAAA6B0ACA7ADA69FAEA49BAFA298B1A296B3A194
B5A193B8A292BAA291BDA391
BDA290BBA18FB8A08FB69F8FB39E8FB19D8FAF9C90AD9C90AA9B91A6988F9E9188968A81
8E8279847971786E676B625C5D544F4F4741423934372D2630251D2B1F17271A1122150D
1E110A1A0E07170C05150A04130904110904110A06120C09130F0C1512101916141C1A19
1F1F1E2323232628282A2D2D2D3232313637353B3D3A414341494B4B5355585F61666C6D
75797982858490918F9D9C99A8A6A2B0ADA8B3AEA8B3ACA5B3A9A0B4A79DB5A69AB6A598
B8A496BAA494BCA393BEA391
BEA390BCA291BAA291B8A192B6A193B5A194B3A296B2A298B1A399ADA098A69A939D928B
948A838A817B7F7670736A65665E5958504B47403B39312D2F2520281C172216101D110B
180C071409051107030E05010B04010A04020905030B07060D0B0A100E0E131312171818
1B1D1D1F2222232728272C2E2B323430373A363E403E474A485155555E61646C6E72787A
7F84858D90909B9D9CAAAAA7B5B3B0B9B6B2BAB5AFB9B2AAB9AEA6B9ACA2B9AA9EB9A89B
BAA798BCA596BDA594BEA492
BEA391BDA392BBA493BAA495B9A596B8A699B8A79BB8A99FB9ADA5B7ABA5AEA49DA59C95
9D948E948B8589807A7C74706F6864615B58514C4A403B39312B29261E1B1F1613180F0C
1209070D05030A02010701000500000200000201010404040708090A0D0E0E1112121617
171C1D1C222321272A262E312C3538333C403B4449464F54545D61626B6E71787B7F8688
8E93939C9F9FAAACABB6B7B5C2C3C2C6C5C2C1BCB7BFB7B0BDB3AABDB0A6BCADA1BCAB9E
BDA99ABDA798BEA695BFA492
BFA492BEA493BDA595BCA697BCA89ABCA99DBCACA0BDAFA5BFB3ABBDB4ADB6ADA7ADA59F
A59D979A948F908A86857F7A79736F6D67655F5A584F4A493E3A39302C2B231E1D181312
0F0B0A09040406010103000100000100010300030601050803080B060D0F0B12150F181B
131C20192226202A2E2732372F3A3F394349444F55525D62606B6F70797C7F878A8E9496
9DA2A3ACAFAFBABCBAC4C5C3CACAC7C9C8C4C6C2BCC4BCB5C2B7AEC0B3A9BFB0A4BFADA0
BFAB9CBFA899BFA796BFA593
BFA492BFA594BEA797BEA899BEAA9CBFACA0BFAFA4C0B3A9C2B7AFC3BAB5C0B8B3B8B0AB
AFA8A3A69F9B9B9591908B8785807D7873716B66645D59574E4A493F3C3B302E2E242222
1A18181210120C0B0E08080C06080D050A0F050C11050D13050F150812190B171D101C22
1623291C2A302331372D3A4037444A435056515E63606C71707A7E81898C90979AA0A5A7
AFB3B4BEC1C0CACBCBD3D4D3D5D5D2CFCDC9CBC6C0C8C0B8C5BAB2C3B6ACC2B2A6C1AFA2
C0AC9EC0AA9AC0A797C0A593
C0A593C0A695C0A898C0AA9BC0AC9FC1AFA2C2B2A7C4B6ACC6BBB3C9C1BAC8C1BCC1BAB5
B8B1ADB0A9A5A8A29E9D9895908C89837F7D7571706763625955554C4849403D3D343334
2A2B2D2224271B1E22161A1E14191E12191E10191F0F1A210F1C24111E2614212A19272F
1E2D3526343C2E3D4438464D445259526065606D72707B80818A8E92999CA2A8AAB2B6B7
C2C5C6CFD1D2DADCDBE0E2E1DCDDDBD4D1CDCFC9C3CBC3BBC8BDB4C6B8AEC4B4A8C3B0A3
C2AD9FC1AB9BC0A897C0A694
C0A593C0A796C1A999C1AB9CC2AEA0C3B1A4C5B5A9C7B9AFC9BEB6CDC4BDCFC9C4CBC6C2
C2BDB9BAB5B1B1ACA9A7A2A09A96948E8A88817E7C7471706866655B5A5B4F4F51464648
3E3F4137393C3033372A2E33262B30252A30232B31232D33232F3626323A28363E2C3A42
3140483948504351584D5B6158666B667277758084858E92949C9FA4AAACB4B9BAC4C8C8
D3D6D5DFE1E1E9ECECE8EAE9DEDDDAD8D4CFD2CBC5CEC4BCCBBFB5C8BAAFC6B5A9C4B2A4
C3AEA0C2AB9BC1A897C0A694
C0A593C1A796C1AA9AC2AC9DC3AFA1C5B3A6C7B6ABC9BBB1CCC0B8CFC6BFD3CCC7D3CDC9
CDC7C4C4C0BDBBB7B4B0ACAAA6A3A09C9997908D8C8381807674736A696960606158585A
505153484A4E4346493F42463B4045393F453840463942483A444B3C474E3F4B52435057
4A565E515E655A666C636F756E797F7B858A8A929699A0A3A8AEB0B8BCBDC8CBCBD7D9D8
E3E5E4EEF2F2EFF3F2E7E7E5DFDDD9D9D4CED4CCC5D0C5BDCCC0B6CABBAFC7B6AAC5B2A5
C4AFA0C3AC9CC2A998C1A694
C0A593C1A897C2AA9AC3AD9EC4B0A2C6B4A7C8B8ACCBBCB2CEC2B9D1C8C0D6D0CAD9D5D1
D6D3D0CFCBC8C6C3C0BEBAB8B3B0AEA8A5A49D9A9992908F8685857C7B7B7373736B6B6C
6464665E5E60585A5D54575B51555950555950555B51575D535960555D635961685E676D
656E746C767B737D827C858A868E9291999C9EA5A7ADB2B4BDC0C1CBCECED8D9D9E3E5E4
F0F3F3F3F6F6ECEDEBE6E4E1DFDBD6DAD3CDD5CCC4D1C5BCCDC0B5CBBBAFC8B6A9C6B2A4
C4AFA0C3AC9CC2A998C1A694
C1A693C1A897C3AB9AC4AD9EC5B0A2C7B4A7C9B8ACCCBDB2CFC2B9D3C9C1D8D1CADFDBD7
E2E0DDDBD9D6D2CFCDC9C7C5C0BDBCB7B4B3AEABABA5A2A19B9898919090878687807F7F
7A79797474756F70716C6E6F6B6D6F696C6E696C6F6A6D716C70746F737774797D7A7F83
7F8589868C908D9396959A9D9FA4A6ABAEB0B7BABBC5C6C7D1D2D2DDDEDDEAEAE9F4F4F3
F6F7F6F0F1F0EAE9E6E4E1DCDFD9D3DAD1CAD5CAC2D1C4BBCEBFB4CBBAAEC9B6A9C7B2A4
C5AFA0C3AC9BC2A997C1A694
C1A693C2A897C3AB9AC4AD9EC6B0A2C7B4A6CAB8ABCCBDB1D0C2B8D3C8C0D8D0C9DED8D3
E5E2DFE7E6E4E0DEDCD6D4D2CECAC9C6C2C1BEBBBAB6B4B3AEACACA6A4A49E9C9C979595
918F908C8C8C89898886858683838482828381828382838584858787898B8B8E90939598
9B9DA0A0A2A4A6A7A9AEAFB0B9B9B9C2C3C2CCCCCBD7D7D6E3E2E1ECECEBF4F5F4FAFDFD
F7F9F9EFEEEBE8E5E1E3DDD7DDD5CFD9CFC7D5C9BFD1C3B8CEBEB2CBB9ADC9B5A8C7B2A3
C5AF9FC4AB9BC2A997C1A694
C1A593C2A896C3AA9AC4AD9DC6B0A1C8B3A5CAB7AACCBCB0CFC1B6D3C6BDD8CDC5DDD5CE
E2DDD9EAE7E5EBE9E8E4E1DFDBD7D6D2CFCDCBC9C7C7C4C2C1BEBCBAB7B5B4B1AFADABAA
A8A5A5A4A1A0A09D9D9D9A9A9B98989A98989A97989A98989B9A9A9D9C9CA2A0A0A7A5A4
ADAAA9B5B2B0BCBAB8C4C2C0CCCAC8D3D1CFDCDAD8E5E4E1EFEEECF8F7F6FDFFFFFBFDFD
F2F2F0ECE8E5E6E0DBE0D9D2DCD2CAD7CCC2D4C6BCD0C1B5CDBCB0CBB8ABC9B4A6C7B1A2
C5AE9EC3AB9AC2A897C1A693
C1A593C2A896C3AA99C4AC9CC6AFA0C7B2A4C9B6A8CCBAADCFBFB3D2C4B9D6CAC1DBD0C9
E0D8D2E5E0DBECE9E6EDEBE9E7E4E2E0DCDBD9D5D3D4D0CFD0CDCCCBC8C7C7C3C2C4BFBE
C1BCBABDB8B6B8B3B2B5B0AFB2AEACB1ACABB0ABAAB0ACABB2ADACB3AEACB4AFACB7B1AD
BBB6B2BFBAB6C5C0BCCCC8C4D5D1CEDFDBD8E9E5E2F1EEEBF9F7F5FFFFFEFCFEFDF5F4F1
EEEBE7E8E2DDE3DAD4DED4CCD9CDC4D6C8BED2C3B8CFBEB2CCBAADCAB6A8C8B3A4C6B0A0
C5AD9DC3AA99C2A896C1A693
C1A593C2A795C3A998C4AC9BC5AE9EC7B1A2C9B4A6CBB8AACDBCAFD0C0B5D4C6BBD8CBC2
DCD2CAE1D9D3E7E1DCEEEBE8EFEDEBE9E6E4E3DFDDDFDBD9DCD8D6D9D6D4D7D2D1D3CDCC
D0CAC8CFC8C7CDC7C5CAC3C1C7C0BEC6BFBDC6BEBCC5BEBAC5BEBAC7BFBBC8BFBBC9C1BC
CCC4BFD1C9C4D9D0CBDFD8D3E7E0DCEFEAE5F5F1EDFBF8F5FFFFFEFDFEFDF6F5F1EFEBE6
E9E2DCE3DBD4DFD4CCDACEC5D7C9BED3C4B8D0BFB3CEBBAECBB8AAC9B4A6C7B1A2C6AF9F
C4AC9BC3AA98C2A796C1A593
C1A592C1A795C2A897C3AB9AC5AD9CC6AFA0C8B2A3CAB5A7CCB8ABCEBCB0D1C1B5D5C6BB
D8CBC2DDD1C9E2D8D2E7E0DBEFEAE7F4F1EFF0ECEAE8E3E1E2DDDBE1DCDAE2DDDCE3DDDB
E2DCD9DED7D5DBD3D1DCD3D1DDD4D0DAD0CBD6CBC6D4C9C4D4C9C4D3C9C3D4C9C2D5CAC3
D7CCC5DCD1CAE2D8D1E9DFD9EFE7E2F6EEE9FAF4F0FDFAF8FAF9F7F4F0ECEEE8E2E8E0D9
E3D9D1DED3CADACDC3D7C8BDD3C3B7D1BFB2CEBBAECCB8AACAB5A6C8B2A3C6AF9FC5AD9C
C4AB9AC3A997C2A795C1A592
C0A492C1A694C2A896C3A998C4AB9AC5AD9DC6AFA0C8B2A3CAB5A6CCB8AACEBCAFD1C0B3
D4C4B9D8C9BFDCCFC6E0D5CDE6DDD6ECE4DFF1ECE8F1ECE9EDE6E3E9E3DFE8E1DEE8E0DD
E7DEDBE7DDD9E7DCD8E5D9D3E1D5CEDFD3CBDFD2C9DDCFC6DACCC3D9CCC2DBCEC5DCD0C7
DED2C9E3D7CFE8DED6EFE5DFF3EAE5F5EFEBFAF6F3F8F4F0F0E9E4EAE2DBE5DBD3E1D5CC
DDCFC5D9CABFD6C5BAD3C1B5D0BDB0CEBAACCCB7A8CAB4A5C8B2A2C7AF9FC5AD9DC4AB9A
C3A998C2A896C1A694C0A592
C0A491C1A593C2A794C2A896C3A998C4AB9AC5AD9CC6AF9EC8B1A1C9B3A4CBB6A7CDB9AB
CFBCAFD2C0B4D5C5B9D9C9BFDDCFC5E1D4CCE6DAD2ECE3DCF2E9E3F2E9E3EDE3DDE9DED9
EADFDAEADED9E8DBD4E5D7D0E2D4CDE2D4CCE2D3CAE2D3C8E2D3C8E1D2C8E1D2C7E2D4C9
E3D6CDE4DBD2E8DFD7EDE5DFF3EDE8F5EFEAF0E9E2EAE0D8E5D9D0E0D3C9DCCEC3D9C9BD
D6C5B8D3C1B4D0BDB0CEBAACCCB7A8CAB5A5C9B2A3C7B0A0C6AE9EC5AC9CC4AB9AC3A998
C2A896C2A795C1A693C0A492
C0A492C1A592C1A693C1A694C2A795C3A897C3AA98C4AB9AC5AC9CC6AE9EC7B0A0C9B2A2
CAB4A5CCB7A8CEBAACD1BDAFD3C0B4D6C4B8D9C8BDDDCDC2E0D1C6E2D4C9E6D8CDE7DACF
E6D8CEE5D6CDE5D7CEE4D5CDE1D1C9DECEC5DCCCC2DCCCC0DDCCC0DDCCC0DDCCC1DCCCC0
DECFC3E4D7CDEADED6E9DED5E5D9CFE2D5CBE0D1C6DCCCC1D9C8BBD6C3B7D3C0B2D1BDAF
CFBAABCDB7A8CBB5A5C9B3A3C8B1A1C7AF9EC6AD9DC5AC9BC4AB99C3A998C3A897C2A795
C1A694C1A693C1A592C0A491
C0A491C0A491C0A492C1A592C1A593C1A693C2A694C2A795C2A896C3A997C4AA98C4AB99
C5AC9BC6AD9CC7AF9EC8B0A0CAB2A2CBB4A4CDB6A6CEB8A9D0BAABD1BCACD2BDAED3BEAF
D3BEAFD3BEAFD3BFB0D4C0B1D7C3B4D8C5B5D9C5B7D9C5B8D9C6B8D9C6B8DAC7B9DAC8BB
DBC9BCD8C5B8D5C1B4D4C0B2D3BEB0D1BCADD0BAABCEB8A8CCB5A6CBB3A3C9B2A1C8B09F
C7AF9EC6AD9CC5AC9BC5AB99C4AA98C3A997C3A896C2A895C2A795C2A694C1A693C1A593
C1A592C0A492C0A491C0A491
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 200},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000b1P00`40o`000?l0003ooooooi7oool0
0?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool0
01koool8V8n<2IN?S003UXj<UXn<UXn=00:FShd019J?SYJ@SiJATIF?SP>FSX`01IJ=RiJ>RiJ>RiJ>
RiJ>S003Uhj<00^GSX^GSHZGSHZFS8VFRhRFRXNERXNERHJER8FER8BDQh<00Y>5P@0;TH9nThJ2U8N4
UHR5UHV6UHZ7UXZ7UX^7UX^8UXb9Uhb900:GSHX00iN=RiR>RiR>S00Ioooo00B=RXV=RhV=RhV=RhT3
SX^:00F>S8Z>S8^>S8^>S8^>SH/00hj=S0:>SHd3SXj=00N>SXj>Shj>Shn>T92?TY>>Shn>SXh00Xj>
S@0CShf<Shj=Shj=Shj=Shn=T8j=T8n=T8j=T8j<T8f;T8b:Sh^9SXZ7SXV6SHR5SHN5SHF3RhB1RX9o
00:9P7`01hMlN8V1OHZ3P8^4PX^5Ph^6Q8b6Q002S8N50hb8QP:=RHL00hf9R8f:R?ooo`0Goooo00Ef
OWmfOX1gOh1gOh1gOh400WN0P@08N822N862N862N863N8:3NH:3NH:4NH>40gV3Q@03NHB5NXB6NXB6
009jQHL017Z6R7Z7RWV5QgZ5QP9jQ8H00gZ4QGZ4QWZ5QP03NhF600elQHIkQHEkQ8EkPhAkPX=jPH9i
P85iP81hOgmhOWihO7agNgYfNGT00WEgMP04LgAcMGQgMGYjMW]k0gIlO003MWamMWemMWen00AfOGh0
0gInOWInOoooo`0Hoooo00]0G6m0GG10GG10GG50GW51GW51GW91Gg91Gg=2Gg=2H7<00T9PM093HGD2
@f5f0T=RMP03A69gA6=gA6=g00=4HgP00dASMdASN4ASN003A6=h0TATN095I7P2A6Ah00]4I7M4HgI4
HgI4HWI4HWE3HWE3HGE3HGA3H7=3H792Gg400d9NL003@Uia@Umb@Umb0092Gg83@Eib0T5NL@05@5ea
@5e`@5e`@5a`@5a_023oool001koool2V8n<00BHSXbHShbGShbGSX`2Uhn<00FGSXbFSXbFSXbFSXbF
SXd019F>S@0>UHj<U8j=U8j=U8j=Thn>Thn?Ti2@U9:CThn?Thj=Thf;U8f;U8b;U8f;0YF=R`03U8f;
UHb;UHb:00:ES8X02YF;R9F:QiB8QYB7Q9>6Pi:5PI:3P9:2OY60O91nNP:>OGL048ekMXmnNI20O962
OY:4Oi:5PI>6PY>7PiB7Q9B8QIF9QYF:QiJ;R9N<RIN=RYR>RaWoool018f;RHf;RXj;RXj<RP:>S8/2
SXf<0Xn>S@:?Shh00hn?Shn@T8n@T003Si6A0XnBTP07Si>CSi>DSiBESiFGSiNJSiBFSi>C00:?TY40
0i2AT92ATI6BT@03TY:A00fCTY6CTI2BT8nBSXbASH^@RhR?RHJ>QhB=QH:<Ph2;PGf9OWV7NWH00XEg
L@0@PgA^QWUeQgehR7mkRH5mRX9oRX>0RXB1RhB2RhF3RhJ4S8N4S8N5S8R6SHV7SHV86?ooo`0:MWj0
Mgn0Mh21N822N862NH:3NH:4NH>4NXB5NXB60W^5Q`03NhJ8O8N9O8N:009lR8/07gf9Rgf9S7f:SGf;
SWf;Sgj<T7j=TGf?Tgf=T7f<SWf;SGj;SGj:S7j;S7n;SH2<SH2<SX2<SH6<SH6;Rh2:RWn8R7n7QWf5
Q7f3Pgb1PG^0OgYnOGUkNWMhMWEeL`02Lg5^00IbKfadM79eMgEfN7MfNWUfNWX2Mg]k0WMlO003Mgem
MWemMWen009fOGh00gInO_ooooooo`0Goooo00I0GG10GW51GW91Gg92H7=2H7@2@f5e00M4HWI4HgM4
HgQ5I7U5IGY6IGY6IW/00TMWO007AfQmB6QnB6UoB6YoB6Z0BFZ0BF^00098JX000dU[P4U[PDU[P002
BF^00159K85:K89:KH9:KH9:KH5:KH19Jgm9JWi8JWe8JGa8J7a8J7]7Ig]7IWY6IGQ6I7I5HW@00TAP
L@03A5maA65dA69e0094HWH2A65e00U3HGE3HGA3H7A2H7=2Gg=1GW91GW50GG10G7008?ooo`007_oo
o`0<V8n<V8n=Uhn<Uhj<Uhn=Uhn<UXn<UXn=UXj<UHj=UHj<UHj=0iB>S@>CSXd2TXj=0Y6>SP05THn?
T92AT96CT8j?T8f=00:AS8/2TX^:0Y><R`0?TXb;Thb;UH^:UH^9UHZ8U8V7U8R6ThF3TX>0T85nSgml
SWijSW]gSGUdRgMa00::M6d048YeKh]hLXajMHelMhinNHn0Ni21OI62OY:4P9:5PI>7PiB8QIF9QYJ;
R9N<RIN=RaWoool01hf;RHj<RXj<Rhj<Rhj=S8n>SHn>SP02Shn?00J@T92@TI2@TI6@TY:@Ti>@Ti@3
TIBE01jAUIJAUYNAUiR@UiZ@VI^@VYf@W:2?VI^@UiR@UIJ@UIFAUIFBUIFCUIFDUYFCUYFDUYFEUIBD
Ti:DTY2CT8jCSXbARhR@R8F>QH:=Pgn;Ogb:O7N7N7>5Lfd2PFiV0121L6V3M6j5Mg:6NWF7O7R8OWZ9
Ogb9P7f:PWj:Ph2;Q86;QH>;QXB<QhF<R8J=RHLHoooo00mgOh1gP85hPH9iPH=iPXAjPhEjQ8IkQXMl
QXQlR8YmR8YmRH]nRXeoRhioS8l00X2=T00?P8jAPHnBPI2DPI6EPI:FPI>HPIFIPIJLPIBHPI:EPI6D
PI6CPY6BPY6CPi6C00>4TY803HBATHB?Sh>=SH:;Rh6:RH68Qh26QGn3PWj1OgamO7YjN7QfLgEbKP02
LVaW00ibKFUdLFieM79fMgEgN7MgNGQgNWUgNgYgNg]gO7]gO7agO7egOGefOGd2MWen6Oooo`0?@5e`
@Eia@Emc@V1d@f5eA65fA6=gAFAiAVEjAVIkAfMmB6QnB6UoBFZ0BV^1009:K8801d]]Q4a^QDa`Qde`
R4eaRDebRDibRP02CW>:0TebR@A=LXP044ibQdicQdecQdecQdabQTa`Q4]_Pd]^PT]_PTa_PTa^PTa]
PD][OdYZODUXNdQVN096Hg@01DIRM4MUMdMUNDMVNDMUN@02AVEi00U5I7Q5HgM4HWI4HWE3HGA2H7=1
Gg91GW50GG008?ooo`007_ooo`05V8n<V8n=Uhn=Uhj<UXn<00:FShd019F?SIF>SIB?SIB>S@:CSXd2
TXj=0i6>S@0NT8j=T8f>Shf>SXj>SXj?SHnASY2CSHf?SHb<SX^;SXZ:ShZ:T8^:TX^;Thb<Thf=Thj<
UHb<U8Z9U8V7U8N5ThF3TX:0T81mSgejSG]gRgQdRWE`RG9]QfmX0XE[H`0@QViWQg5[RGA^RWIaRgUc
S7]fSGehSWmjSh1lT89nTHB0ThJ2U8R4UHV6UX^8Uhf:6Oooo`07SH^:SXb;SXf<Shf<Shj=Shn>T92?
00:@TI401Y2BTi6CTi6DU96EUI6FUi:GV0:BUiT049:HVY:IVi:JW9:KWI:LWi6MX96NXY6PYI2LWi2J
W96IVY6HVI:HV9>HV9BHV9FHV0:EVIP03IJGUiJEU9FCTIBASiB?S9>;R967Q8n4P8f0O8YlMhQgLXEc
K89]IP02OVMN0120JfB2KfR3Lff5MW26N7>6NWJ7O7R8OGV8Og^9PGf:PWn:Ph6;QH:;QXB<QhF=RHLH
oooo00mgOh1hP89iPX=iPXAjQ8EkQHMlQXQmR8YnRH]nRXeoRhj0SI21SY61T9>2TI@00X>BUP0OQ9BG
Q9FIQIJKQIRLQIVNQIZOQI^QQIfSQ9ZOQIRLQINJQINIQIJHQYJHQYJGQYFFQIFFQYFEQYBDQY>BQI6@
QHn>Q8j<Q8^9PXN6PHB2Oh5oOGekNgUfNGEaMW1[009cJVD03WA]JGE`KGIcL7MeLgMgMGMhMWQiN7Qi
NGMjNWMkNWMkNgMlO7MlOGMmO@9fOGhIoooo00m0GG11GW92H7=3HGE4HWM5I7Q6IGY7IW]8Ige9JGi:
JX1;K89;KHA<KhI=L8L00TibR@05Cg>;D7F=DGJ?DGR@DWVB009CNY<00e9jTe9jTU9jT@02DWVA00EB
NI1AN8mAMhe?MX]?MHX00TmeR@=>MHT02DieR4idR4mdR4mcQdmbQTi`Q4e^PTa]P4][OP03BVUl00m:
JGe:JWi:JWi:JGi9J7e8Iga8IW]7IWY6IGU5HgQ4HWI3HGE2H7=1GW90GG008?ooo`007_ooo`03V8n<
Uhn=Uhn=00:FShd2UHn=00BDShfDSXfCSXfCSXd2TXj=00FASXf@SXf@SXj@SXj?SHh00Xj=SP0=SHf>
S8f>Rhf?RXf@RXnBRXb>RX^;RhZ9S8V9SHV9SXV9ShZ9T8^:00:AS8/03I:<Ri::RI:8QY:6Pi:3PI61
OXmlNHeiMH]fLXQcKXI_JHE[IH=XH@02PFAL0122J624JfB5KVN6LFZ8Lff9MW2:N7><NgJ=OGR>Og^@
PGfAQ82CQX:DR8FERXNGSHXIoooo00n>RhZ>S8^>SHb?SXf?Shn@T92@TI6ATY:ATiBAU9FBUIJBUYNB
V9VCVIZCVY/00Y>KW@0OTibNTifOTijQTinRTj2TTZ2UTZ6WTJ>YTInSTIfPTYbMTY^LTiZKU9ZKUIZJ
UYZJUY^KUY^JUiZIUiNFUYFBUY:@UHn<U8b8TXN3Sh9nSGiiRGUdQW=]Q6iWP6QP009mHeT047mWGh1[
I89_J8=bJhAdKXEgLHIiM8MkMXMmN8QnNhV0OHZ2OhZ4PH^5Phb7QHb8QaSoool03gMoP7R1PWV2Q7Z4
QG^5Qgb7RGf9Rgj:SH2<SX6=T8:?TX>AU8>CUXBDV8FFVP02QYRL00j7VIj8Vj29WJ:9WZB9X:F9XJN9
XZV9XjZ8X:F8WZ>8WJ29W9n9Vij9Vid2RYZK00n:VYZ:VIV:V9R9UYJ8U9>8TY67Shj7SH^5RXR3QH>2
PWmoOW]lNGEjM6mgKVT00WAYH`0@MFeXMW1/Mg9_N7AaN7IcN7MeN7QgN7UhN7YiN7YjN7]kMgakMgal
MgamMgemMWen6Oooo`0?@5ea@Umc@f1dA69fAFAhAVIkB6MmBFUnBV^0Bfb3C6j5CG27CW:9D7B;DGF>
009BMi0025=iTUAkU5EmUeIoVEN1VeR2W5R2WER2W09GPI/02EN0VUJ0V5IoUeIoUEEnU5ElTUAkT5Aj
Se=iS`03DWV>00UBN8iAN8eBNHeBN8aBMX]AMXYAM8U@LXI?Kh<00di^PP0?CVn3CVj3CFj3C6f2C6b1
Bf^0BVYoBFQmB6MlAfIjAFAhA69f@f5e@Umc@Eea023oool001koool01YR?S9N?S9N?SIJ?SIF?SIF>
S@:DSXd019>>SI:>SI:>SI6>SP:@SXh08Xn>SXj=SXj=SXf=SXb=SX^<SXZ<SXV;SHR;SHJ;SXJ;ShJ:
S8N9RXR8RHV8QhZ7Qh^7Qhb8Qhf8R8j8R8n9RHn9R928Qhn5Phn3PHj0OHimNXaiMXYdL8QaK8E]J89Y
Hh5UGWiQF@9nGeL047mRFX1UGH9XHH=[I8A^J8IaJhMdKXUgLH]iM8alMhioNY21OI64P9>7PiF9QYN<
RAWoool03hj;RXj=S8n>SHn?SY2@T92ATI6CTi6DU9:EUY:FUi>HVI>IVY>JW9BKWYBMW`02U9jQ01nE
Wj:EX:BEXZJEXjNDY:RCY:ZBYJZAYJ^AXZJAX:>BWZ2CWInDWIjEW9fEW9bFW9bGW9bHW9bHViZHVIRG
UYBGTi6FShbES8RCQX:@P7b=O7J9MW66L6V2JV5nHeT00WaPEP0@OVAKOfQOP6]SPViWPg5ZQ7=]QGI`
QGQcQWYeQgahR7ikRH1mRX9oRhB1RhJ4S8R66?ooo`0?Mh21NH:3NX>5NhF7O8N9OXV;Oh^=P8f?PHnB
Pi6DQ9>FQIFHQYNKQiVMR9^O00::WJ407h^OY8bQYXfSZHfUZhjW[HjX[hfY/8bY/8bV[8^TZ8bRYXbQ
Y8bPXXfPXHfOXHjOX8jOWhjNWXfLW8fKVXfIV8bFUHbCTX^@SXV;RXN7QHB3P89nNgmiMGacKWM/IP02
MVYS00agKFQhL6]hLViiM71iMG9iMgAiN7IiNGMhNGQhNWUhNgYhNg/2Mgal00=gOGefOGkoool06?oo
o`0?@Eia@V1cA69fAF=hAVIjB6QmBFYoBfb2C6j4CG27Cg:9D7B<DGJ>DgRAE7^D009FOIH04UMoVER2
W5Z4We^6XUf9YEj;Yej<Z5f;Yeb9Y5b8XU^7XE^6X5^6WU^5WEZ5W5Z5VeV3VUR2U`9HP9H2Eh2F00UG
OiIGOiEFOYAFOYEFOI=FNi5FNY1DN8eCM8P00U9cQ`9BM8T03U5cRE1cR4maQdi`QTe^Q4a]PT][PDUY
OTQXO4MVNTETN4ARMT9PM45NLB3oool001koool01YR?S9N?S9J?SIJ?SIF>SIB>S@:CSXd01Y:>SI6>
SY6>SY2>SXn>SXj>SP>=SHh07hb=SX^<SXV<SXR;SXJ:SHB9S8:7RX66RH>7RHB7R8F6QhJ6QXN6QXR5
QXV5QHZ6QHZ5QH^5QH^4Q8b3Phb1P8aoOH]lNHYiMHUdLHM`K8A[IX5WHGmSG7eNEWUID002NUY@011k
G5AlGeMnHe]oIUj1JF:3K6J5L6V6Lff8MW2:NGB<O7N>Og^@PWjBQH6DR8FFS8TIoooo00n>S8Z>SHb?
SXj@T8n@TI6ATi>AU9FBUYJCUiRCVIZDVYbDVifEWInEWZ6EX:<00YJQY@0@UZ>WUZBXUZJZUZN/UZR^
UJR_TZR_T:F/TJ>XTZ:UTj6STj2QU9nPUInOUYjOUijN0YRNW@0=VIbKVIZIV9NEV9BAUhn<UH^7ThF2
T81kSGUdRGA]QFeUPFIMO5iC009lGU@047eQF7iUG7mXGh1[Hh5^IX9`JX=cKHAfL8EhLhIjMXMmN8Qo
NhV1OXZ3P8^5Phb8QQSoool03gN0PGV2Q7^4QWb7R7j9Rgn;SH2=T8:?TX>BUHFDUhJFVXRIWHVKWhZM
XXbPY@02SJ:W00f>Y:Z?YjfAZK2B[;>C[[FC/;RB/KV?[[J>Z[2>Z:f?Yj^?YZR@YJL00Y6UYP0?TJBU
TZBTTZBTTZ:RTZ2PTIjMTIZIT9NESi>ASHn=RXZ8R8F2QH1mPGYeOG=^00=iK6D047U^J7UaJgYbKWYd
L7YeLWYfLgYgMGUhMWUiMgUjN7QjNGQkNgQlNgMlO7MmOGImOQWoool03d5NLT=PM4ASMdIUNTQWODUZ
Od]/PTe^QDiaR51cRe5fSU=hTEEkU5ImUeR0VP02FH:M01=KQJ1MR:ANRjMPSZ]RTJmTUK=UUkISUK=Q
T:ePSjYPSZQPSJMOS:IOS:EOS:AOS:=ORj=NRj9NRZ400Uf9X00:GHROGHNNG8JMG8FMFhFLFhBLFh>J
FX2GF7jEEgbA0UMjT09FNY403UEiT5AhSU=fS55dRU1bR4i`QDe^Pd]/PDYZOTQXO4IVNTESMd=PM45N
LR3oool001koool019R?S9N?S9J?SIF>S@:DSXd019>>SI:>SY6>SY2>SP:?SXh00hj>SXf=SXb=SP02
Rhf>01n:SHj9S8j8S8j6Rhj5RXf1R8]jPXImQ8N0QHN1QHN3QHJ3Q8F4PhB5Q8B6Ph>6PX:7PX:7PH68
P828OWj7O7^7NGR6MWB6M764L6b2JfJ0If5nHU]jGEEhF4meDTL00WIDBP0@MeI=NEU@NUeDO61HOVAL
P6QPPV]UQ6mYQW9]R7IaRWYeSGeiSh5mTHB0U8R4UX^86Oooo`0?SXb:Shf=Shn>T96@TI:BTIBDTYJF
TiNHTiVJU9^LUIbNUIjPUZ2SUZ6UUj>W00:GYJT07iRVZiRX[IRZ[iV[/IV]/iV^]HnW[hjTZi2TZI:S
Yi>RYIBRXiFQXYJQXYNPXIRPX9VPX9VOWiZMWIZKVYVHUYRDTIN?S9J:Qi>5PI1nNHehLXQaJX=ZHX1S
FG]JC`02NeaA011lGeAmHUQnIEaoJ5n0JV>1KFJ2L6Z3Lff4MG25N7>6NgJ7OWZ9P7b:PWn;QH:<QhDH
oooo00mhP89iPhAkQHMmR8YoRXf0SHn2Si:4TYF5UIR7Ui^9VYj:W:6<WjB=XZN?Y:X00Y2W[@0<TZZ`
TjfcUK2gU[>jV;JnVk_3U;FnT:ngTJjcTJbaTZ^_Tj^]0YBZ[00AUJZ[UJZZUZZZUZZYUjRXUjJUUj>R
UYnNU9^ITiNETI:@SXb:RhN4Qh5mPg]fP7A_NfeV009kKVL02g]`JW]aK7]cKW]dL7]eLG]fLgYgM7Yh
MGYhMWUiMgUjN@02N7]j00=gNg]gO7efOGh06Oooo`0?@Eib@f5eAFAhAfMlBFUoBfb2CFj5CW68D7B;
DWJ?E7VBEWbEF7nIFH:LFhFP009MR:<035n;Yf6>Zf>A[fFE]6RJ^FbP`F^O`6JH]fFF/fBD/6BD[VBC
[P9TTjd2I9B]0fBE[@0<I9B/I9>ZI9:YHi2XHhjWHXfVHHbTH8ZSGhVRGXNOGHFMG8>K0e^2VP0?FX2H
FGnFEgfDEW^BE7R?DgJ<DG>9Cg66CFj4Bf^1BFUmAfIjAF=g@f5e@Eib023oool001koool02YN?S9N?
SIJ?SIF>SIB>SI>>SI:>SI6>SY2>SXn>SP:>SXh00hf=Shb=Sh^=S`02RXf?01n8S8n7S8n6S8j5Rhj4
Rhj2RXifOhAkPXInPhEoQ8F0PhB1PhB2PX:2PH:3PH:4P864Oh24OWj4Ngb4N7V3MWJ3M7>2LFn1KVb0
JfMnIV5lHUajG5EfETicDDM`BSl00W9=@P0@Le15ME=9MUM>N5]BNUmGOF=KOfMPPF]TQ6mYQW=]RGMb
Rg]fSWmkT8=oThN3UX^86Oooo`0?SXb;Shj=T92?T96ATI>CTYFFTiNHTiVJU9^MUIfOUYnQUZ2SUj:V
V:BXV:JZ00:IZ:d07iVZ[iZ//IZ^]9^`]Ybb^I^c^hVS[8jU[92UZY:UZIBTYiFTYYJSY9NSY9RSXiVS
XYZRXYZQX9^NWY^KVYZHUYVCTIR>RiJ9QY>4Oi1mN8agL8Q_J8=XGgmPEWYHC002NUU>011kG55lGeAm
HEQnI5]oIen0JV>1KFJ2L6Z3Lff4MW65NGB7O7R8Og^9PGj;Q8:<QhDHoooo00mhPH9jQ8ElQhQnRH^0
S8j2Si64TYF6UIR7Ui^9VYj;WJ:=X:F?XjR@YZbBZJl00YB//`0OUJnfUk>jVKJmVkW1WKk6W/38Sk:k
TK6iTk2fU;2eUK2cUZnbUjnaV:n`VJn`VZn_V[2`Vk2_W:j^W:b[VjRVVZ>RVInMUiZHU9FBTHn<SXV6
RX=oQWehPgMaOW1Y009nLFX047ibJgebKGecKWedKgaeLGafLW]gLg]hMGYhMWYiMgUjN7UjNGQkNWQk
NgMlO7ImOQWoool03d5OLTARMTIUNTQXODY[PDa^Q4iaR51dRe9gSeAjTUMmUUV0VU^3WUf6XUn:YP02
HHfZ00]STJiUU;9WV;MYW;a/XL9^Y<A[X<1XVkYXV[QXV[MXVKH00fVJ]@04JIZdJIbeJYffJYng0V^P
^00;JijfJY^cJYRaJIJ_J9F]IY>/IY6[I92ZHhnYHhjXHXfW009PRjD045n9Xej7XEf5WU^2VeUoUeMl
U5EjTE=gSE5dRTmaQTe^Pd]ZP4QWO4ITNDARMT9OLR3oool001koool03iN?S9J?SIF?SIB>SI>>SI:>
SI6>SY2>SXn>SXj>SXf>Shb>Sh^=ShZ=ShV=S`02R8f?00Z7S8n6S8n5S8n4Rhn4S8n0RHakQ8MkPhIl
PXEmPX@2OX6201=oP85oOh20Oh21Ogn1OWj1O7b1N7V1MGJ0LG9oKVinK6YmJFMkIF9iHEahG5MfF55c
DTY`C49]A3T00Ve5>@0@KdTnLDe2LU57MEE<MeUANEiFO69KOVMPPF]UQ71ZQgA_RWUdS7eiSh9nTXJ2
UHZ76Oooo`0?SXb;Shj>T96@TI:BTYBETiJGTiRJU9^LUIfOUYnQUj6TUj>VV:FYVJN/VZV^00:JZk40
7Y^]/i^`]Ybb^Ibd^ing_iB_]h^U[HnW[I6W[9>WZiBVZIJVZ9NUYYRUYIVUYIZUYI^UYIbTXYbPWibL
ViZGUIVBT9R=RiJ8QI:2OXmkMX]eKhM^IX=VGGiOE0=jETX047YICG]KDGaNE7eQF7eTFgiWGh1[Hh5^
Ih9aJh=dKXEgLXIjMXMmNXV1OHZ4PHb7QASoool03gR1PWZ4QWf7RGn:SH6=T8>AU8FDUhNGVhVJWX^M
XXjQYI2TZI:W[IB[/IF^]002Uk6h01nI]KbK^<2M_<BN_lRQa<fF^/B</;ZB/k^E];ZG]KVI];RJ];NK
];JL];FM];BN]KFO][FP]KBP/k:P/:jOZjVNYjFMXZ2KWI^GUiBDTHj@RhN<QH29OgZ5NG>1M6d00X5c
K00@P7=]P7A]OgA^OWE_OWEaOGIbO7McO7MdNgQeNWUfNWUhNGYiN7]jN7]kMgalMgem6Oooo`0?@Umc
A69gAVIjBFUoBff3CW26D7>:DWJ>EGZBEgfFFH2JFhBNGXNSH8^WHXn/009TT[002VNF]FVJ^V^N_ffR
`fnUbFVO`VFI^fVM_F^O_FbO_P9]X;d01FjP_6jQ_6jR_6jS_6nU_P02L:Jo00a`Y[i`YKi`Xka`XKY_
W[Q^W;I/V[AZV;9YU[1XUK1WUK5WU[82IYFb011TTJeRSZUQRjEOR:5MQ9eJPIUHOIEFNY5CMXeALhU>
L8E<K899JGi7IWY4HWI2Gg<Poooo000Noooo00nGShbFShfEShfDSXfCSXfBSXjASXj@SXj?SXj=SXn<
SXn;SXn:SHn9SHn8SHl00XN=S`0OQHb?Q8b?Phb?PX^?P8Z>OXR<O8F9Nh>6Nh:4Nh63Nh21O7moO7io
OGinOGenOWenOgenOgUjOgEgOW5cOFe_O6UZNfMWNFARMf1NMEaHLeQBLU=<L4i6KDPnJT0e009X?C40
46Y2=Va6>fi;@75?AW=DBgIIDGUNEW]SG7iXHH9]IhEbK8QgLX]kMhj0O9:5PIF:QaWoool03hj<Rhn?
SY2ATI6CTi:EUY>HVIBJViFLWYJOXINQY9RSYiVUZIVX[9ZZ[i^//P02W:ne01nL/KNM/kZN][fO^L6H
/kb?ZkB?Z[:AZZnCZJjDZJfFZJbGZ:VHYjRIYjNJYjNKZ:NLZ:NMYJBMXJ2MW9^KUiFJTHnHS8ZFQh>B
PGb>NWF:Lfb6K6F3IUenGeAkEd/00WQCAP0@NEE9NUQ<NU]@NeiDO65HOFALOVQPOf]TPFmXPW9/Q7E`
QGUdQgahR81lRX>0S8N46?ooo`0?N863NhF6OHR:P8b>PXnAQ9:FQiJIRIZMRifQSZ6UT:BYTZR]U:^a
UjneVK>j00:K][h07ifj`YnnaZ72bjC7dI_0bY2f`9>f_iJg_YRh_YZi_Ybi_Ifh^inh^Ynh^J2i^J6j
^J>l^Z>j^:Bg]JBd/J>_[::YYj6UXYjOW9^IUYNCT9>=RHn7PXb1O8QmMXIhL@02PgA^0X9dKP0>PGE_
P7E_OgE`OWIaOGIbO7McO7QeNgQfNWUgNGYhNGYiN7]kMgalMgem6Oooo`0?@UmcAF=gAfMlBVZ0C6j4
Cg:8DWF=E7VAEgfEFH2JG8BNGXRSHHbXHi2/IYBa009XV;H07f^L^ffP`6nTaW>ZcVfTafJK_FVN_fbQ
`FjS`W2Ta76UaG:Va7:Wa7>W`g>X`g>Y`gB[aGB]aWF^aWF^aGF]a7F[`gFX`GBV_g>S_G:P^g2M^6jL
]fbK]fbL^FbN_002Jifl011YVKMWUK9UTJeSSJQPRJ=NQIiKPIYHOIEFNI5CMXa@LXQ=KXA:Jh18Ig]5
HgM2Gg<Poooo000Noooo00nGShbFShfEShfDShfBSXjASXj@SXj?SXj>SXn=SXn;SXn:SXn9SI28SI26
SI000XF=T00=Q8b@PXb@PH^@PhfBOHR<O8J:NhF8NX>6NX:4NH62NGj0NGemNGal009jO7`047]kO7en
OWekO7ehN7adM7]`L7UYJGQTI7EPGg=LFW5HEFmDCfe@BFa;@fY6?6Q0=09U>Bd046Di;6Po<fY4>Fe:
?fm?AG9DBgEJDGQOEgaTGGmZHh=_JHIeL8YjMHeoNi64PIF:QQWoool03hj=S8n?Si2BTY:DU9>FUiBI
VYFKWIJNX9NPXiRSYYVUZIZX[9^[[ib]/Yf`]P02WK:i01nN];bN]knO^L:L^L:A[kRA[[NB[KBC[;:D
[;6F[;2GZjjHZJ^IZJVIZ:RJZJVLZJRMZZVNYZFNXZ6MWI^MV9NKTHnIS8VEQH:AOg^=N7>8LF^5Jf>2
IEanGeAlF4`00WQBA@0@Me54N5A8NEM<NU]@NeiDO65HOFELOVQQP6aUPG1ZPgA^Q7QcQW]gR7mkRX>0
RhJ46?ooo`0?NH:3NhF7OXV;PHf?Pi2CQYBHR9RLRibPSJ2TT:BYTZR]UJbaUjnfV[>jW;No00:N^l<0
7j6ob:?3c:C7dIo4ciBkaYJkaINka9Zk`Ybl`Yjm`j2m`J6m_j:l_Z>l_JBm_JFm_:Jm_:Ni^:Nf]JNb
/:N^[JJZZ:FVY:6PWYjJUiZDT9F>RI68Phj3OXYoN8QjL`02QWM`0125MFj4MFj3MFj2MFn0MG1oMW5n
MW9mMg=lMgAkN7EjNGIjNGQiNWUhNgYgO7agOGdIoooo00m2H7A5I7Q8Iga;Jh5>KhIALh]CMhmFNiAI
OiULPiiNR:9QS:MTT:aWU;9YV;L00VbM_00;Kj72LJG7Lj[=KZG8JZ33K:;5KZ?5L:G6LZO8M:[:MZc;
009g[L/027R]bWR^bGR^bGR/aWRZaGVZaGVY`gVZ``9j[<D027ZZ`gRW`GJT_gBR_G:P_72O^fnO_6nQ
_`9_Xl<046jR`VbL^VVG]6NC[VB>ZF6:Xej5WU^1VEQlU5EhSe9dRTm_QDa[P4UXO4ETN49PLb3oool0
01koool03iN?S9J?SIB?SI>?SY:>SY6>SXn>SXj>Shf>Shb>ShZ>T8V>T8R=T8N=T8F=T002Q8f@00b2
S921S91oRi1ePhQhQHUiQHUiQ8MhPhIhPXEhPH=gOWmfNg`2MWYk015gNg]hNg]jOGekOgikO7]kNWUj
MWAgKF]eIFAbGUi_FEM]EE9[DD]YCDIYBD5XAC]V?c@00V@j;@0@HSDXI3T/IShbJ4@iJdToKTm6LUE=
ME]CNF5JOFMPPFeWQG9]RGQcS7iiT8>0U8V66Oooo`0?SXf<T92?TI:BTYFETiRIU9ZLUIfOUj2RV::U
VJFYVZR/Vj^_W:fcWK2fW[>i00:O]Kd07j2h`:2j`j6mai:b_96`^Y:_^9>_]YF_]9J_]9R_/iV]/9V[
[9VZZYZZZYZZZIbYZ9jXYinVYYjQX9jNW9nKVIbCTIZ<RYF4PY1mNXagLXM`JHAZHX5TFgmOE7aHC@02
NE=7011fCT1gDDAhE4QhEdaiFe1jGUEkHUUmIUinJV>0KVN2LVb3MW65NWF7OWZ9PWn;QX@Hoooo00mi
PX=lQXQoRXb2SY64TYF7UYZ:VYj=Wj>@XjNBYjbEZk6H[kFJ];ZM^;nP_<@00Z;0b@0OY<G>YlWBZ/kH
WLC@VL3;V[k8Vkk7W[o6X<37Xl;7YL;5YL32Y/30Yl30Yl2oZ;fmZKZjZ[NgZK6aZJj]ZZj]ZJ^YZ:JT
Y:6NX9ZHViFBUhj:ThV4T8AoSH1jRgae00:9NG4048IeKHIfKXEfKX=eKh9eKh1fL7mfLGifLWegLgah
M7]hMWYiMgUjNGQkNWMlO7MmOAWoool03d9PM4ITNDUXOTa]PdmaR59fSEEjTUQnUe^2W5j7XF6;YVB?
[6ND/FZH]ffM_002L:;200acYlQeZlii/MEg[mAaZ<aaYlYbZ<YdZLYfZlai[/mk/M5l/]02OK;?015m
/Lil[l]lZLElYL1lXKekX;]mY;mnZLAoZlIn[<ImZlEkZ<=iY/9gY<1eX[mcX[mcXl400W>Ua00@LZG5
L:?2KYjkJiReJ9>^IHjXHHVRGXBLFWnGEgZADgJ<D767CFf2BFQmAVAh@f1d8?ooo`007_ooo`0?Uhn=
UXn=U8n=Thj>THj>T8j>Shj?SHj?S8j?Rhj@RHj@R8j@QhjAQXfAQ8fA00:2SI40386<TGn;TGj;T7F3
RGJ4RGJ4R7J3QgN4QgN3QWN1PgEnOg=iNP9cN7X04G5hNGMoOgYoOgf2PWf1P7akNWYiMgMcLG=[JFeO
GV]FEFQBD6M>BFI:A6I7?fE4>V@o=002HST]011O<bIO<REQ>2]T?S9WA3YZBT5^D4QbEdmfGEIjI5eo
JVB3L6^7MW:;OGR@PgnDRHDIoooo00n>SHb@T92ATi>BUYJDVIZEVifFWZ6GXJBIY:RJYj^KZZnL[K:N
/;JO/kVP][d00Z6i`00OX[c4X[o8WKc7SZnjTK2iTk6iU;2gU[6gV;:gVk:fVk2bVJb/VZ^[W:^[UjJU
VjNWWJFTWjFTX:BRXJ2NXIfKWYJCW92=UHJ3T7aiRWEaQViXPfQPPF=KOemEOEU>009jE4P047M?@GI=
?gI@@gMDB7MGC7QKDGUOEW]SFgeWH7m/IH5`JX=dKhEiM8MmNHV1OX^6PaSoool03gV2Q7b7R7n;SH>@
TXJDUhVHW8bMXHnQYI:UZYFZ[iN^]9Zc^Ifh_Z2la:?1b@02Y/G>01nYb]>[cmVUc=RH`<bK`L^M`L^O
`LVQ`/VTa<ZWa/^Ya/VYa<BZ`l>]`l>Y^k^X]kRY/kBY/K6Y/K2//:n][Zf/Z:N/YZBXXZ2SViVMUI:H
ShZDRHBAQ7n@PG^>OGH00XakL`0@RWQ`R7I^QgI^QGE^PgE_PGE_P7E`OWIaOGIbO7MdNgQeNWUgNGYh
N7]jN7akMgem6Oooo`0?@f1dAVEjBVYoCFj4D7>:E7R?EgbDFX6JGHFOHHZUI8jZIi>`JYRfKIflL:;2
009dYlP07gN/cW^beWN_e7:ZcWBZcGF[cGJ[c7R/c7Z_cgfbdh2eeH6geH:ge8Bgdh:_bgjU`GbQ^gZK
]GZM]WfR_7nP_86Q^h>V`HB]b8:^bGn/agbYa7ZW`WRT`GNT`WJU``02MZO6011gZ/YfZLUcY<9`W[]/
V;AXTZeTSJIPQj1MPYYIOIAEN8iALhU>KX=:JGi6IGU3H7@Poooo000Noooo00nGShfEShfDShfBSXjA
Shj?SXn>SXn<SXn;SY2:SY28SY67SY66SY65SY:3SI800X6=T@0OOhbAOXfCLX>:Lh>9M8>9MHB9MH:6
MXB7MhF8Mh>6MH21LW]kKWMhMX20MGmoMh61NH61NX20O8:1OGmmOWakO7MeN75_KFARIUMEI4m=Hd]7
HTM1HdDnHd<jHShd009P>Bd045hd9e``8U`b9Uhg;68n=6I5>fY<@fmCBg=JDgQQFWeXHH5^JHIeL8Yk
Mhn2OYB8QAWoool03hn=S92AT96DU9>FUiBJViJMWiNPXYRSYYZVZY^Y[Yb//Ij`]Inc^J6f_J:i`@02
Xkc401nS_lRU`lbC]<2?/;^A/KZD/[ZE/KNH/kVJ]KZM]KVM/[BL[ZjHYjNJYjRGXj>KYJFMYJBOY:BQ
YZFRX9jRWI^QVIJPUI:GRXJ>OGV8Lfn4KFN1IUn0HUYoGeEnFdl00W]FB@0@NE12MT`mMDe0M513ME=8
MUM=MeaBNF1HNfEMOFUROfiXPW=]Q7McQWahR85nRhF36?ooo`0?NH>4OHN9P8b?Q96CQiFIRYZMSInS
TJBXU:R]UjfcV[:hWKNmX;c3Y<78YlK>00:Zbm<07jc?f;3DgZ78e9_1cIg2c9o3c:73bZC5bjO7cJ_9
cJc8bZk6aj^n_jRg^:>a/ZNb/jVa/Z^b/Zfc/jf][:b[ZZfYYjjYYj^SXJFLVIjETYZ?RYJ9Q9>5Oi:2
O960N002Sgee012=NG6;MVb:MVf7MVf4MFj2M6j0MFmoMG1mMW5lMW=kMgAjN7IiNGQhNWUhNg]gOGdI
oooo00m3HGE7IWY:Jh1>L8IBM8]ENI5IOYMLPiePR:9SSJQVTZiZUkA]W;Y`XL5dYlL00WR/cP0ONk7D
O[GINk;FMZc?Mjc?N:g?NJg>Njk?OK3@Ok?BP[GDQ[SGQK;@OZC0NinjOIjiOIbgOIjiOIfiOI^eO9^d
OYjgPJ>nQZW4Qjk9Pjk9P:c6OJW5NjO3NZK3NZO5009jZ/P2NZ_:00iiZLMeY<5`WKU/U[5WT:YSRZ=O
Q9aKOiIGNI1CM8Y?KhE;JWm7IGY3HG@Poooo000Noooo00nGShfEShfCShjBShj@SXj?SXn=SXn<SY2:
SY29SY67SY66SY:5SY:4SY>2SY<00X2=TP0OOH^AOHbCK7n7L868LX>8LhB9M8B8MHF8MXJ:MhJ9MXB5
Mh:2KgQhLWUjM7]kMG]jMWelN7ekNGakNGMfNWIdNgA`O7=`Mf]XJeiLH4m=GTM4GT@oH4<lHD8iHChd
009O>Bh045dc9e/_85T_8ETa9E`g;F50=VI8?fa?Ag5GCgINEg]UGh1/IhEcKXUjMXj1OI>8QAWoool0
3hn>SI2ATI:DUI>GV9FKW9JNX9RQY9VUZ9ZX[9b[/9f_]9nb^:6f_::i`JBma@02YL3901nU`/^T`lf<
[kb?/;^A/K^D/[ZF/[RI];ZL]kbO]kZN];FN/:nDXZ>GXjBIY:BKY:>NYZJPYZFRYZFRX9jRWYbRVIJQ
Ui>KSHRAPWj7M722JfF0I5ioHEV0GeIoG5000WaGBP0@NU53N4`mMD`nLT`oLDm3Le=9MEQ?MeeDNF9J
O6MPOVaVPG5/PgIaQW]gR81mRhF36?ooo`0?NX>4OHR:PHf?QI:ER9NJS9bPSj6UTjJ[UZ^`VK2fW;Fk
X;[1Xko7YlG=Zl_C00:_d=T07k3DgJoEgic3d9c2cYo3cJ74c:C4bjO6c:[9cZk8c:g5ajg1`ZBf^:Jf
^:Rg^:Zf]jbg^Jjh^K2h^;2d/[2b/Jj][:bYZ:RRWjFMVZ2GTi^@RiN9Q9F6P9B4OIB2NP02TWmf012@
Ng:>N6j<Mfn9MVf5M6b2Lff0M6ioM6mnMG1lMW9kMgAjN7EiNGMhNWUhNg]gO7dIoooo00m3HGE7IW];
Jh5?L8MCMXeGNi=KP9UNQZ1RRjIUT:aYUK9/V[Q`WkicYLEhZld00Wbbe@0OP;OJOkOJNk;ENJkANZk@
Njg>O:g>OZo?P;3@P[3?PZo=PJc;P:[8OjW7P:S6PJO5PJO4PZS6PZS5PZS4PJS4OjG2OJ6mOJ:lPjW2
Qk3:QK3:PZc8Oj[6OZW5OJ[7009mZlT047f]c7f^cWb]cGZZagFR_VnJ]FZC[FF=YV66Web1V5QkTUAf
S51`QTa[P4MVNT=QMB3oool001koool03iN?SIF?SI>?SY:?SY2>SXn>Shf>Shb>T8Z>T8V>THN>THJ>
TXF>TXB>Th:>T`02P8fB01mmRi5mS9=/OhM`PHQbPhQcQ8UdQ8QeQHQfQXYgQXUfQ8EgPX9_N7QbNGYd
Ng]eNgYfOGahOG]iO7]iMgIjMWAkM71lLg1gJfQ[GUaPCdeNAdANA3mP@caQ@SUQ?S@00Uli;P0@GC<W
FblPFBlQFC4UG3L]HD0fITPoK4m7LEM?MUiGNfEOP6aWQG=^RGYfSX5mThR56Oooo`0?Shj=T96ATYBE
TiNHUI^LUYjPV:6TVJFXVZR/W:^`WJndWk:hXKJlX[W1Y;g500:U`<T07jG2bjC3cHb__8n`^i6a^iBb
^YJb^9Vd^Ybg_9ng^Yjd]Ij`[iBRXiNSY9VTY9^TXijVYZ2VYJ:VYJ:PWZ:NW::IUZ6GTi^=R962OXMd
L89[IH1TGWmQFH1OEWmLD002O5M:011jDD=hC3eeC3ibC3maCd=cDdUeF4mgGEAiHUYlIf1nK6J1LFb3
MW66NgN8P7f;QH<Hoooo00mjPhAmR8Z1SHn5TYF8UiZ<W:2?XJFCYZ^FZk2I/;JL]K^P^/6S_lNWaLf[
bm<00Zo@f@0O/=CM[mGOW<?@W<;>Wl?=XLC<Y<C;YlK<Z/W>[/S<[LG7[L72Y;JhY[JhZ;NhZ[Jg[;Ni
[[Ri/;Rh/;Bb/;:a[Zf/[:VXZ::OYIfJX9NCVi2;UhV4UHJ0U8AmU89j00:BOgH0491kLXihKXagKhUf
KHEdK89cKH1dKWmdKgieL7afLW]gM7YhMGUiMgQjNGQkNgMlOAWoool03d=QMDMVNd][PDm`Qe=fSEMk
Te^0VEj6X6:;YVF@[6VE/VbJ^72O_W>UaGR[c@02O;;E01n0]mYo]mYk/]Ei[]5j[]1k[Lil[Lin[ln0
/=22/<n2[lf1[<^0Z/QoZLN0Z<J1YlF1YlB2Z<J2Z<F2Z<B1Z<AoYL9mXKemX[b3ZL:7/<Z5/<Z2[<Qo
Z/InZLEmZ/L00Wf[b@0@OJg<OJk>O:g=NZ[7MJ:nKiZeJY>]IHfVHHJOG86HF7^BE7J<D726C6^0AfIj
@f5e8?ooo`007_ooo`0?Uhn=UHn=Thn>THn>T8j?SXj?S8j?Rhj@RHj@R8jAQXjBQHjBQ8nCQ8nDPhnD
00:0SY<07gN7SGF6SFn0R6n2R762R7:2R7:3R7B5RGJ8S7N7RgR9RWZ9RGB3Pg=nOg=mOG=kNgAkNgIj
NWIjNGIeLgMbL7I^JgM^JgIXI79RGVEEDE]6@U]2?Ue1>Um1>5ln=002GCT^011K=2QJ;b5H;QmG;b9G
<RQM>c5S@cYXC4=^DdacFeAiHeanJVF3LVf8NGF>P7bCR8@Ioooo00n?SXfATI6BUIFDV9VEW9jGWj:H
XjJJYZZKZZjM[K:N/KNP];^R^<2T_<BW`LX00Z_6c`0OY<?<VK[6RjjjSk2kT[:kUK:jUk>iV[FkWKRm
W[FhWK6cW:f^UZJVV:FVVjJVW:FUWjRWXJNVXjNUXZ:OXYjKXINDX9JBW8j8UhJ1RgUdP6UTOV=MOf5H
P61FP5eA009nF4/047]BA7U=?WE:>g5:>fi:?W1?AG=EBgEJDGQPEgYUGWeZI81`JX9eL8EjMXR0O8Z5
PQSoool03gZ3QGj9RX:>T8JCUXZIW8fNXY6SZ9FY[IR^/ibc^Inh_j:naJK3bj[9dJo@f@02]]SR01ne
fN>Wc]ZH`<fM`/fQa<fTaLfVaLbYa/b/b<f/a<RY_L2V][VS/[BX];J[]kR]^;V`_;bb_;bc_;^c^;Nc
][Fa[jf_[JZ[YZ:WX9bQVIBKShZHRHBGQX2GQWnGQ7`00YF0N00@TgacTGU_SGI/RGAZQ75ZPW9[P79/
Og=^OWA_O7EaNgIcNWMeNGUgN7YiN7]kMgam6Oooo`0?A65eB6MlC6b2D7:8EGR?FGfFGH>LHHRRI8jY
J9>_K9ReKiflLZ?2MZS9NZoA00:2^Md04HO0iWjffgN]d7Z^d7b_d7j`d7n_ch2_cX6^cH2ZagjR_gZK
]g^L^82S_h:V`hBYahF]bP02QZk;00b6/<j6/<f5[<Z3Z/N1ZLB0Z<>5[LN7/<^4[/V2[<R1[<R0[<T2
P:g;0120[/ao[lin[/ekZ/QhY<5bWKQ]UK1XSjQSR:5NPYYJO9=EMheALHM<K858IW]4HGDPoooo000N
oooo00nFShfEShfCShjAShj?SXn=SXn;SXn:SY28SY66SY65SY:4SY>3SiB3T9F4TYL00XJDV`0>NhbB
Kh>:L8::Kh:9Kh>9L8:9L8>9LXF:M8N<M8F8LX63Lh:4LX:2LX610W>0P00?M860MWmnMWilMW]iMWMc
M71]M6eYLfQSLF5MJeYEGTY6FD4mFd0jGD0hGShd009M>Bh045Xd:5T_8UDZ74hW6U<^8eTf;5m0=VE8
@6]@BG5IDWIQFWaXHh9`JhMhLhf0O9>7Q1Woool03hn>SI6BTY>FUYBIViJMWiRQXiVTYi^X[9b[/9j_
]Inc^J6g_Z>k`ZFoaj[5cP02[l_E01nQ`<^=/Kf=[k^@/K^C/k^E/[ZG/kZJ]K^M]kbM/kNJ[:jJZZbI
ZJVKZ:RLYjRNZ:RPZJVRZJRSYjFSXj6SWY^QV9FNUI2LSXRGQX2@O7J2JfInHUaoHER1HEN1GU800WmI
C00@O5A6NTm0N4`lK4@fJdHjKD]0L597LeM>MUeENF=KO6UROViXPGA_Q7UeQgmlRXF26?ooo`0?NX>5
OhV;PhnAQiFHRiZNSj2TTjJZUj^`V[6fW[JlXK_2YL78Z<K>[<cE/M?L00:gf^@07jcAg9_3ci_1cJ34
cJ?5cJK5c:W5bj_7c:k7c:k4aj^m_jZi^jZg^Jbf^:fg^:nh^K6i^[Bi^[Bh^;Fe]KBa/;>^[K2]ZZfW
XjVQWJ>IUI^>RYV8Q9V7PIV7P9V5O002V89i012EOWFDO76DNg2:LfZ4KfR2L6V0LFYoLVamLfilM71k
MG9jMgAiN7IhNGQhNgYgO7`Ioooo00m4HWI9J7a=KX=BLhYFNI5KP9QOQImSRjEWTJa[U[=^VkUbXKme
Y/EhZ/]k/=800Wnef00CO[CHNJgANJ_>O:k@Ok3?PK3>PZo>Pjo=Q:k;Q:c9PjW5PJC0PZ:nPj:oQ:>o
QJC1QZG2QjK4QjO400:8Y/@02XNYahJ[ahBZaX:YaX6Xa8B[aXJ^bHF^bHB]bH>^bP:3[/`048>`cH>a
d8JfeH:ad7ZV`gFO^fnG/VZAZVF:Xf24W5]nUEIhSU9bR4e/PDQWNdAQMB3oool001koool03iJ?SIB?
SI:?SY2?Shj>Shb?T8Z>T8V>THN>THF>TX>>TX:>Th:?U8:@UXFDV@02RiVO00F5U9UeQhi`PhY^PXU]
PhT00Vj2R@05L8F:LXN<LXF9KWj1KWeo009_OWl04G1nOg5nOg9oOg=nOW=lNg=iMg9eLW5aKVm]J6iY
I6eTGf]NF6ADCUa7@UY2>ea0>Edn=@02G3X`011J=BYI<BEI;b9:91Q>:QmE<bUL?3=RACaXCTI^ETmd
GUQkIf60KfZ6Mg:<Og^BQh@Ioooo00n?SXfATY:CUYNEVYbGWZ2HXZFJYZVLZZjM[K>O/KNP]KbQ^<2S
_<FU`LZYa/l00Z[8d`0OWKk9T;:nTK:mT[:lU;:jU[:jV;:jV[FkWKJkWK>gVJ^]VJV[VZVZVjVYWJRY
WjVYXJZZXjZYY:NVY:BRXinLXIZFWIF?VXf8UXEoSgaeQg1YP6EOP69IPF5GPUmC00:0FTh047eEAgaA
@Wa>?VLo<FQ2=VY8?6i>A75EBgAKDWMQFGYWH7e]Ih5cKXAiM8MnNhZ4PQSoool03g^4QGn:S8B@TXRF
VHfLX96RYYFX[9V^/ifc^J2i_jBoaZO4c:[9dZg>ejoCg002Zm7M01nNa]>I`<fP`ljSaLjVaLbYaLb[
aL^]a/^`a/^_a<N]_L2^_;j^^kb`^[^a^[^c^kbe_Kfg_;fh^[Zh^;Ng];>f/Jjc[:V_Y::YWIZSU92L
S8NIQh:JQh6LQh2LQWd00YZ3N@0@V7meUgebUW]_QViTPfeUPFiVOfmXOW1ZOG9/O7=_NgEaNWIcNGQe
N7UhN7]jMgal6Oooo`0?A69fBFQmCVn4DgF;F7^CG86JHHNQIHjXJYB_KYVfLInmMJC3MjW9NJc>NJk@
009bYlX02FbQaG>WbWb^d82`d8>_chB`cXF`cHJ^c8N]bP02Qjc800J8ZlR8ZLJ9Z<F9ZLF:ZLJ;ZlL5
S:_800V<ZLN9Y/B5Xkn2X;^2XKb5Yl:7[<R7[/V6[/X00XJ_b`0@QJo=QK7>QK3=Pjk;OJS5Mj2kLIVc
K9:/IXbTHHFMG7nFEgV?Dg>9CVf2BFMlA69e8?ooo`007_ooo`0?UXn=U8n=TXn>T8n?SXj?S8j@RXj@
QhjAQHfAPhfBPXfBP8fCOhjDOhnEP96G009oSiH07g^<Tg>6SVj2RF^0R6^1R6^2R6b2RFf4RVn5Rfn4
R6anPFYiO6]jNfakOFelOFilOFmnOW5mOG5jNW1fMFmcLFi_K6]ZIfUUHFQOFfEJE65BC5e:AE]5?U]2
>U`o=P02FcXa011I=R]I<bIH<2978QM;9aeA<2IH>C1O@SUVBd=/E4ecG5IiIEmoKFR5MW6<OWZBQh<I
oooo00n?SXjATi>DUiRFVifGWj:IXjNKYj^MZk2N[kFO/kVQ]kjR^/:S_/NT`L^UaLl00Z;2cP0OWKg8
U[K1Tk>mTk:kUK:jU[:jV;:iV[BjW;FkW;>gVZf`VJRZVZRYW:VYWZVZX:ZZXZ^[Y:^ZYJRWYJBRY:2L
XYZFWI>?VHb6U8AmSW]dRG9[PfURPVEKPV=IPf1D00:1Fdl047mFB7iB@ge??VDm;f@o<VQ5>F];@FmB
B79HCgIOEgUUGWa[IH1aK8=hLhInNXZ4PASoool03g^4QX2;SHFAU8ZHVXjNXI>TZ9NZ[ib`]Ynf_:>l
`jO2bJ[7cjc<eJkAfjkDg`02Zm7M01nWc=NUam:Ua]2Wa/jYa/b/a/^^aL^`a/^aal^aaLRa`L>a_/2b
_Kjc_Kje_[jg_[ji_knk_knl_[fl^kVk]kFj/k2e[JVaYZ:/Wi^VUi>QT8^MRXFMRH6NRH2NR7h00Yb4
NP0@VX1fVGibVGa_QVeRPF]QP6aTOfiVOVmYOG5[O79]NgA`NWEbNGMeN7UgN7YjMgal6Oooo`0?AF9f
BVUnCg25E7J=FGfEGX>LHhZTJ92[KINcLIfjMJ?1N:S8Njg>O;3CO;;F009j/=D03GZ^d7f_d8:bdXFc
dXNbd8RacXZ`cHZ`c8Z_bXZ^bXb`c8facXf`c002SZk:012?[/Z@[/Z@[/^A/<bA/LfB/<bA[l^@[/Z=
[<N;ZLF9Yl:7Y/:7Z<:8ZlF9[/R9[lX2R;3;0127/<b7/<f7/Lj4[/YnZ<=iXKacV[E]TjeXSJESQYiN
P9MHNY1CM8U>KX=9J7a4HWDPoooo000Noooo00nFShfDShjBShj@Shn=SY2;SY29SY66SY64SI:2SI9o
S99mS9=lS9=jS9=hS9@00WJ9T00OLXB<KX28JGj7J7f5J7j5J7n6J827JH68Jh>9Jh67JWj2J7QkJ7Mi
JGQjJWYkK7UkKG]lKWalKWUjKWEeKG1`K6e[JFQUIV=OI5eJHUQCGe9<G4Y5FdI0FT<lFd0g009J>c80
45Xg;EXe:5/b94DP54HS64h/8UDf;5`o=f=9@FYBBW5KE7MSGWi/IhEeL8]nNY:6PaWoool03hn?SY:C
TiBHVIJLWYRQXiZUZ9bY[Ij]/Yna]j2e_:6i`::laJ>obJ?2cJ;3d002X<3<01nL^lJH]/2D/kfD/KZE
/KVF/KVH/[VJ/kZK]KZL/kNL[k:JZJ^JYjRLZ:VOZZ^QZZZSZj^U[:^VZJRVYJ>TWibQVYJLTXjGRhFB
PWf>NgB9Lf^5Jf:4J5j4IEZ4HED00X9LC`0@P5M9OeA4P550Hc`]HC`_ID8fJDPmK4m5L5I=M5eEN6=L
NfYTOg1[PWMbQWejRXB16?ooo`0?NhF6PH^=QY:ERiVLT:2SUJJZVZfaW[>iX[ZoY/36Z/K=[L_C[m3I
/MCO/MKR00:`e=l07jkAfjc<eJ[9dJ_7cZg7cJo7c;77c;;8c;C8c;C6bKC3a[C0`KFo`;O0`;S1`K_1
`Kc1`Ko2`Ko0_[nm^kji]K^d/;J]ZK:VXJfOVZRHTjBBS:6=QZ2<Pj6;PZ28O`02WXAj012KPGJJOW:J
O6n5K6:1JV5oJf9nK6AmKVMlKfUlLFakLfmjMG5iMgAhN7MhNWUgO7`Ioooo00m5HgM;JWm@LHMFN8mK
OiIQQYiVSJI[U:i`V[IeXKiiYlEm[Lb0/]>2]mV3^M`00XBig@0AQK[MQkWJR;SFR[OES;KCSKGAS[C@
Sk??Sk?=Sk;=T;;>TKC@T[GAT[C?TkC?U;C@U;??00:E/lh039JdciFdcYBbcI:abi6^b8j[aHbY`h^Y
`hZZ`h^/aXb_b8^_b@:9[lT048R_bXJ_bXJ_bhJ`cH6[b7^S_gFL]VnE[VV>YVB7Wen1V5UkTEAdRTm^
PdYXO4ERMR3oool001koool03iJ?SIB?SY:?Shn?Shf?T8Z>THR>THF=TH:=TX2<TWf<TWZ;TWR:TWJ9
TW>7T002L8B=01m/P8QYO8AVNh=UNX9TNX9TO8=UOHAUOXEVP8IWOhEWOH9UN7aTM7MVMWQWNG]YNG][
NG]/NWa/N7U/MGEZL6mYK6]VIVASH5iPFeQOEe=MDTiKC4MJB49IA3eI@3P00UTl<`0@FCP^FSHZGSDW
BB<G@QhCBRPNDS<YFSddHDHnJ519KeUBMV9LOF]VQ7A_RWeiTHJ36Oooo`0?T8n>TYBDUIVIUifOVJ:T
VjNZWJ^_WjndX;>iX[NnX[_3Xkk7Xl7<XlC@XL?>00:O`</07i^ja9Nd_IBb^iB_^9F_^9Na^9Rb^9Vc
^I^d^Ibb]ib`/i^[[I^WZ9fXZIn[Zj6ZZj>[ZjJ][:NZZ:JVXjBOW:6JUYbASIN9Q961NhekLhYcK8M]
I8IZH8EVG8AREP02PUe@0120F4YoE4F1Dd9W?c1M>2YR?S9VACYZCD9_E4]cFe=fHUYjJF9nKfZ2MW:6
OGV9Ph4Hoooo00elQHJ1S8j7TiJ=VifBXZFGZJfL/;BQ][bV_L>Z`lZ]bM6`cmNce=h00[CIi0:ef>40
7k;Cg:o=eJg;dZo9ck38c[;8c[C9cKG9cKO9cKO7bkS6b;S3a;S0`K[1`Kc2`[k2`Ko3`L;4`/;2_l:n
^kni]Kfe/;R^ZKBWXJjOVJZITZJCS:B?QjB>QJB<PZ:9O`02WhEj012LPGJIOG:IO6n7KVB0J5mnJF1m
JV9mK6ElKVQkL6]kLVijM71iMW=hN7IhNWUgO7`Ioooo00m5HgM;JgmALXQGNI1MPIQSR:5YSjU^Uk5d
W[YiYL9m[<Z1/]:5^=V8_N2:`>@00Xc1h`0?SL3RS;kNSKgLSkcITK[GT[[FTkWEU;SDU;KBU;GAUKGA
U[OCUkSDUkOCUkKA00>H]]003IVfciVeciRecYNdcIJcbiB`bI:^aY2/`XjZ`HjZ`Xn]aXn_b8f_b002
Rjo80129[/V6[LR3[<R4[lb3[/YlYL1fWKM`UJi[SjMUR9mPPYQKNi5EMHY@Kh=:J7a5HWHPoooo000N
oooo00nFShfDShjAShn?Si2<Si2:SY67SY:4SI:1SI9nS99jRi9gRY9dR95aQi5]PX`00VYoR006IGV3
HgR1HGR0HGMoH7MoHGR00V5jPP0GHWb3Hgb3Hg^1HWMlHG=gHWAgI7IhIWIiJ7MjJWQjJWIhJG9cIfi^
IFYYHVASH5mLG5UFFeAAFU1=FDa8F4U3EdDnEd0i009G?3@045Li;eTg:elh:eH^84LQ5DDR650`9ePk
<Um4?6I>AfeGDGAQFg]ZIH=cKhYlN966PQWoool03i2?SY>DU9FJVYROX9^SYYfX[9n]/J6a]j:f_:>j
`JBmaZC1bZC4cZ?6dZ72cP02Wko:01nI]/2E/[^D/;VD[[NE[kNF/;NH/KRI/[RJ/[RK/KNM/;BK[:jK
YjVMZ:VOZZ^RZj^T[:bW[JbXZjVVYJ>TWibPVIFKTHbFRH>@P7Z<NW::M6b9L6N8K6:6J5f4HeL00X9N
D@0@OeQ;OEA5OE52KT@eH3PZGCP/I48gJDY0KE98LEUAMF1INFMQOFiYPGEaQGaiRH>16?ooo`0?O8F7
PXf?R9FGSYbOU:BWVZ^_Wk:gY;ZoZL76[/O>/LkE]MCL]mWS^MkX^]gV00:ifn@07kGBf[7=e;7;d[;9
d;C:ckK:ckO;ckW;ck[;c[_:c;c8b[_5a[_2`[g3`ko4a<75`l?6a<G6a<K5`/G0_L>k][ne/;^^ZKJW
XK6PVJbJTZZESJVBRZR@QjJ=PjB:P002XHIk012LPGJHO72BMfb5KF=oIeelIEalJ5mlJf=lKFIkKfUk
LFejLg1iMG=hN7IgNWUgO7`Ioooo00m6I7Q<Jh1BLhUINi9OPiYURZ=/TZabV[EgX[imZLJ2/Ln7^=R;
_n2?aNJBb>X00YC9j`0=U<GVTl;PU<3NUKoMU[oLUkkJV;kJVKkIV[cGV[_EV[[DVk[DVk[F00:L^mH0
49bjeIfje9fje9jke9jjdifidIbfciZdcIRcbiNab9B^aI>]`i>^aI>_ai:`b92`b@:>/<P048Z^ahF[
aGfU`GVT`GnZaWjW`GJL]W6F[Vb?YfN9X662VEalTEIeRU1_Q4]YODERMR3oool001koool03iJ?SIB?
SY6?Shn?T8b?THV?TXJ>TX>>Tgn=Tgb<TgR;TWB9TW27TFb3SVMmR002HgR300=NM7iKM7iLM7d00Uad
O@0JG7EmGGInGGIoGGMoGWMoGgMmGgEkGW=gH7=fHGAgHgAgIGEhIgEhIgAfIVmaI6]/HFIWGV9QFeaK
FEIDEe=@ETi;ET]7ETM2ED<mE3lh0U@k<`0@E3L^EC@ZEc@YES0TDR/NC2TOD30WESTaGD8kI4a5JeI?
LUmJNVUTPW9^RGahTHF26Oooo`0?T92?TiFEUY^KVJ2RW:FXWZZ^XJndX[BiY;RoYKc4Y/39Y/C>YLOB
Y<OCXL;>00:M^/H07iJa^i>_^I>^]iB^]YF^]YJ_]YR`]iVa]iZa]i^`]Yb_/i^[[Y^XZYfYZZ2[Zj:[
ZjF][:R][:V[ZJNUXZBOVinHU9^@RiF8PY1oNHajLX]eKHYbJHU^HhIYGXATF002PEiA011mF4]jDTAg
CT1_ACIT>R]M>2]S@CEXBCi/D4I`EdmdGeMhIUmlKFR0M725O7R9Ph0Hoooo00mmQXN3SY2:UYR@WZ6F
YZVM[[6R]KZX_L:]a<Zbc=:fd]ZjfN6mh>Voi>foh^X00[cJhP0O]m3H]LgD]L_B]/_A]lc@^LgA^lkB
_<kA_Lk@_lc?_l[;_/K6_/C3`<G4`/O5a<O5a/W6bLW6b/O3b<:ma[fh`[Ja_[2Z^:RQ/j2I/9^C[YR@
[IJ=[9B:ZI66YXb100:RQg`049f2MYMlL95fJhI/H7]PEGINEG]VGGaYHGa/IG]^J7]aK7YcKgUeLWQg
MGMiN7MlNaWoool03dITN4e/PEAdRUYlTf65W6R=YFjE[gFM^7^V`H:^bhRfe8fngY;7j9O>l9[Bl`02
Vlo^01nKbNNJaNBJ`n6K`n6La>2Ma>6Na>2Oa=nP`mjP`]bP`=ZO_]NO_MNP_]RP_mVQ_mVQ`=VR`=VR
_mRR_]JR_MFQ^m>P^M2N]/bK/lVJ/LRI//RH/lVG]<ZF]<^D]</00Y6bbP0@SK79R:g6PZS0NZ6jM9Vc
M9VbMYZcLYJ^KI2WJ8VPHX>IGGbBEgJ;DFn4BfUmAF9f8?ooo`007_ooo`0?UXn=U8n>THn@SXnAS8nB
RHnBQHnCPXjCOXfCNXbCMXZCLHVBK8NBIh:>HWb7009LLgl00eU`NUM`NUMaN`02F75k0UQbN`0HFG9k
FG=kFW9kFW9iFW1gFVmeG71fGg=gHG=gHgEhIGEhIG=eHfi`HFU[GFAUFemPF5YJEEEDE55?DTe:DdY6
DTI2DD8mD3hh0U0i<`0@CcD^Cc4YCc0VCBXOBR@HBbPNCRlUE3L_Fd4iHTY3JEA>LEiHNFQSP75]R7]g
T8F26Oooo`0?TI2?U9JFUibLVj6SWZNZX:b`Xk6fYKJlY[_2Yko7Z<C=Z<OAYl[FYLSDXL7<00:J]L00
7i>^^96]]i:]]Y>]]YF^]YJ_]YN`]iV`]iZ`]Y^_]IZ]/I^Z[I^XZYfYZZ2[Zj:[ZjF^[JV][:V[ZJNU
XZBNVinFTiZ?RYB7P91oNHejLh]fKX]cJXU_IHIZGh=TF002P5iB011lF4]gDD=cCCi/@cAS>2UR>beT
@3AWAca[CTE_ETecGEIgIEikK6N0M6n4NgR9Ph0Hoooo00mmQXR4Si6;UiVBX::IZ:^P/;BV^Kf/`LFb
b<jgd=Jlf=k0g^K3iNg4i^k3h>P00[kFgP0O^<oF]/gC^<gB^LgB^lkB_LoC_]3C`=7C`M3B`/o@`Lc=
`LW8`LO5`lO5aLS5a/S5bL[7c<[6cLS3bl>nbKjha;Na`;2X^JRP]Z:J]9jF/YbB/YZ?/9N<[9>7ZHj2
00:TRGd049n3MiUlL9=hJhY^HX5TF7iTFGeVGGeYH7a[I7]^Ig]`JgYbKWUdLGQgMGMiN7MkNaWoool0
3dITN4i]PUEeReanU6>6WVZ?Z7:H/GVQ^h2ZaHNbchfkfIC4hiW<k9kBlJ7Bl@02XLo^012ObnZObNNP
b>BPb>BQbNFSbNFTb^JUb^FVb^FVbN>Uan2UaMfU`mbU`]ZT`MVT`MP2YL7I00fV`MRV`=RV_mJU_]BS
^m2Q]lbO]/^O]/bO]lbN]lfM^<jK]lfI]ld00YJfb`0@T[?:S[37RJg5PjS1OZ>lNj2hN9bdM9N^Ki6W
JXZPI8BIGWfBF7J;DW24C6UmAF9f8?ooo`007_ooo`0?UXn=U92?TI2@Si2AS92BRI2CQHnDPHjDOHfD
NHbDM8^DKXRBJ8F@HH2;FWR4009DKg/01E5[Me5/Me9]N5=^NEA_N@03E6mh01MDKWMDKGIDKGEEJg=F
Jg5HKG=KL7ANLWIQM7QSM7QTLGARKG1OJ6YKHfAGGEiDEeMADU9@CTe?BdU>B4E>AD5=@Ca<?CL00T/h
<P0@BS@]BBlWBBdUAbHL@b0EAB<IBb/RDCD]F3hgGdQ2Ie9<KeaGMfIROg1/R7]gT8F16Oooo`0?TI2@
UINGVIfNW:>UWjV[XZjbYKBiYkVoZKk5Z/?;ZlOAZl_FZLcGY/SCWkk900:F/K`07i2[]Xn[]96[]9:]
]IB^]YJ_]YR`]iR`]YV`]IZ^/iV[/9ZX[9ZWZIbXZInZZZ:[ZjJ^[JZ^[JZ[Z:RUXZBNVYnFTIV>RIB6
P920NHikM8ehKh]dJhY`IHI[H8=UF@02OeiB011kEd]eD49aC3iZ@S=S>BUQ>BaS?c9VACYYCD=]E4]a
G5AfHeejJfIoLfj4NgN8PX0Hoooo00mnQhR5T96=VI^DXZBLZZfS/kNZ_<2`a<VgcM:leM_2gNC7iNg:
jO7;ino7gnL00/3Dg00O^/kE^LkC^/kC_<oC_]3D`=;E`]?Fa=?EaM?DaM7BaLo>aL_:a<W7aLW6alW6
bL[6c<c7clc7clW4c/Bnb[jga[N``K2X_JZR^jJM^J:H]j2E]YfB]9V>/9F9[92400:XRWh04::4N9an
LIEiKHe`HhIXG89WFgmWGGiXGge[Hg]]IW]_JWYaKGUdL7QfM7MiN7MkNaWoool03dMUNDi]PUIfS5io
UVF8X6fAZWFK]7bT_XB]bHbgdi?1gi_;jj;BljODmJWDl`02Z=7`012VcnbUcNZUc>RVc>RWcNVXcnZZ
d>b[dNb/dNZ/d>V/c^J[bnBZbN6YamnYaMfYa=/2ZLCJ00FY`mZY`]RY`MNX_mBW_M800ZJld@06YKcA
YKgBY;gBXkcAXK_@W[[@0YbhcP0@V;K=U;C:Sk78RZg5Qjc4PjS0OJ2gMiV`LI:XJh^QIHFJGgjBFGN;
DW24C6UmAV=f8?ooo`007_ooo`0?UXn>U92?TI2ASi6BS96CRI6DQI2EPHnFOHjFN8fFLh^EK8VEI8:=
FGV6Cg1m0099J7H01DUWM4]XM4eZMDm[MU1/M`02DFeg01Q@K7I?JgE>JG=?J75?Ig1AJ6iDJW1HKG9K
L7ENLgMQM7QRLGAOK6mLIVQIH69DFUa@EEI>D51<C4];BDM:ATA:@d19@3a8?3L2ASLa0115<Ra3;BI2
:R908QTo7QA07A=6:1m=<RYD?3ELAT1UD4]]FeIeIF5nL6b7NWJ@Q84Ioooo00nATI2FUiNJWYnNY:JQ
ZjfU/KFX]k^Z_<:/`/V^aln_bmF`d=^]c]RWa]6K^LD00Xn/^00OS:RcSJVbSjZcTJbeU:jfUZnfV;2g
VK2fVJndVJbaV:V^V:NZV:FXVjJXWZRYXZ^[Yjj]ZZj]Zj^XZ:FRY9fIWiF@VHj8UHN1TX5jSgeeSWQ`
RgE[RG1VQV]PPfEI009oGe8047YHBgAA@g1<?fU1<V<j:ehe9f4l;fA3>6M;@F]BBW1JDWARFgUZI7ib
KH=jMXR2OaSoool03gj7R8JATXjJW9JSYYj][jJf^Jjo`kG8c;cAe/;JglWSjLo/lmC_mMC[lLcPiP02
`MCJ01nkc]Bkc]>lcm>nd=C1d]K4e=K6eMO8e]K9eMG9dm?8clo7c<_7b/S7bLK9b/K<blO?c<SAc<OB
bLC@aKk=_kS9^;75/j[2[ZC0ZInnYY^lXiRjWiBgVhncUhZ`TH@00Z^<O`0@YHIiWh1cVGa`TG9VRVaO
PfIJP6ILOVQNOFYRO6aUNViXNW5/NG=`N7IcMgQgMg]k6Oooo`0?AfEiCfj3EgN=Gh6GIhZQL9B/N9ff
P:O1RK7<TK_GV/KSXm7`[=_j]=om]Mgi00:aeo<04ZgCkZ_Ak:[@k:_Ak:cAkJgBkZoDk[7Ekk?Fkk?E
kK;Cj[7@ik3=iJk;hZg8gjc7gJc5g:g4f`:]a=X00jg3fJc2ejc2eP02[<;E00J]`]J/`]J[`MFY`=BV
_]:T_=42XK_@012N^/nJ^<jG]ljB]<b=/LZ7[<B1XkUjVk5dU:U]S:5WQIYPOY=JMh]CL8A=JWe6HgHP
oooo000Noooo00nFT8jDT92BTI:?TY><TYF9TYJ6TIN1T9MmSiMhSYMbSIQ]S9QTPhmEMXA8JgX00SeQ
L00O@F9`AFEbB6MdBfUeCF]fCVagCVafC6]eBfUdBFI`B6=]BF9[C6=[CfI]E6Y`FFidGG9gGg=gH71d
GF]^FVEWEEiPDEQJCE=DBTi>AdY:ATI5AD=1AD0nA3dj@cXe0092=S40440a:ch[9CdY8STO5cPL4cXI
444T74T_:54i<eU4?V9?BF]IEGATH7e_JhIiMXn4PAWoool03i:AT9NHV9^OX:2VZ:B]/:Rd]j^j_Zk0
aK35c;;;dk?@fKGEhKCAfjO4cYNe`@02QjJc01n7Y;2:Y[6=Z;:@ZkBD[KFG[kJI/;NI/;JI[kBH[;6F
YjbEY:RFXjJIY:FMYjNRZZZW[Zf[[Zf/ZjRYYJ:UWYVOUI2KSXRFRH:CPW^@OWF>NG2;M6^9L6J6Jf22
IET00WiOD`0@NEQ;M555Kde0Id4bH3X[Fc4SGST/HD4eIDPoJE18KUQALf5JN6USOG5]PWUfR89o6?oo
o`0?OhR9Qi:CT9^MVJFWXJnbZ[Vl//?6^/c@`MKJbMoTcnS]eo7ggO;gf>[^cMoS00:odML07kc=dkc>
d[k?dl3Ae<CCe/OEel[GelcGelgGe/cEe<_Ad<W>c<S;b<W:a/_:a/g;am7=b=C>b=G;a=?6_m31^Lfj
//Ze[<NaYlJ]X/>ZW/6VV[jRU[^NTKNIS;>DQP02[Xj0012XR7ZSPgFNOW6EM6N<KF24HeJ1IEUoIeem
JF1lJfAjKFMiL6]hLfmhMG=gN7MfNg/Ioooo00m7IGU@Kh=HN8eQPYQYS:9bUZekX;V4Z/B=]LnF_m^O
b^JXe?6cg_ZihObjh?X00[OKm@09/]K`/=C^[m?][m?]/=?^/]G^]MO_]mS`^MWa00:if_401[OGk[GC
j[;?iK3;hJo8gZo7g@:`am`01K77fk76fk76f[;6f[?7fP02]<SK00Fcb=^aamZ_aMR]`]JZ`=@00ZNo
d`0@Y;gAXKcAW[[@V[W?U;G;S:g3QJFjOYbbMiFZL8fRJHJJHWnCFgR<E764CFYmAV=f8?ooo`007_oo
o`0?Ui2>UI6@Ti:BT9>DSI>FRY>GQY>HPY:IOI6IMhnILXjIKXfJJ8JDEgN5AFUh008gGFh01C]NKT1R
L4AULTQXMD]ZMP02BfYe01Q8Ig95IG13HVi2Gf]4GVQ6GVM;HFUAIfiGKG=LLWMOLgQOL7ALJfiIIFMC
GF1>EeU:DU=6C4e3B4Q2A4A1@411?Sa1>cTo>3@2?S@`010l<2Xj:bHh9b8b7AL`5a0c5@dl8AY4;2E=
=c5F@SeOCDQXF5=bHemkKVZ5NGF?Q84Ioooo00nBTY6HVIVMXJ:RZ:ZW/;:[]kZ__L:ba<VebM2fcmNh
e=fif>:hd]bX`lfE/[h00X2Q[`0OPZ6]QZB_RZJaSjZcU:jfV;2gVk:hVk6fVJndUZ^`U:F[Tj:VU:2S
UZ6RVjBUXJVYYjf/[:n][JbYZZFRYijIXIJAWHn9VHZ3U8AlTGifSgYaRgA[R71UQF]PPVEI009nH5<0
47UIC7ACAW1>@6E2=5`f:5L^7e/f:Ehn<f=6?6M>AVaGCg5OFGIXHWa`K89iMHN1OaSoool03gn8RHVB
U9:MWY^WZJFb]:jl_kO7bL3Ae<SKg/oTj=K]lMcdn=oam=OXjl_Lh002^lgC01njbm6lcM6nc];1d=?6
e=K;emS@f][Bfm[Cf]S@emG=dM3:c/c9blS9b<C;b<C>b/GBcLOFcLSGblGFal3D`[WA_K??^:k>]J[;
/:G8[:36Z9c2XiNnWi:jVXbfUHL00[6@PP0@[8YlYhEgXX5cV7QYSFaNQ65DPF=GOfEKOFMONfYRNVaV
NFmZN79^MgEbMgQfMW]k6Oooo`0?B6EiD6n3FGV>HX>IJhfSM9N_OZ:kR:k7T[WCVlCNY<kZ[=G`/]Wc
^=gg^mkg00:ifo@04;GGlK?Ekk;DkK;Ck;CEk[OHlK_LmKoOn<7Pn<7Om[kMlkcJl;WGkKKAik?<hK79
g@:aam/03K;7g;?7g;G8g;K9g;S;gK[<g[[=gk[<gkW<g[O:gKC8f[75f:o4e`02[<;E012Y`=>W_m:U
_m:Q_]:J^<fA[/>9Y[Z1W[9iUZYbSZ9ZQiYSOi=LN8aELHA=JWe6HgHPoooo000Noooo00nGT8nETY6D
TiBAU9J?UIR<UIZ8UI^3U9]mTY]gT9YaSYY/RiMUQ99BM8<oIWH00S1IJ`0O=Ua/>f1_@6=aAFQeBfah
CVijCViiC6agAFMc?f9^?EiZ@5iX@UaUAUeUCfI]EFacFg9hGgAiGg5fG6a_F6EWDUeOCeQJBU9DADa=
@4I7?T93?3hn?3`k?CXg?3Hc008j<bl043P_:SL[9SDW8RlO6B/E42dB2cHN63lY94Te;e90>ea;AfIF
DW1RGWY]JHAhMHj4PAWoool03i>BTIVJVYnRXjBZ[:Zb]Jnj_KC1aKO8cK[>e;_CfkcGhKcHhKcDg:S1
bi2^^P02NIb[01mmWJ^2XJf7Y:j=ZK:D[[FI/KRM/kRN/[NK[kBDZJn?XjR@XJFAWZ6BVifIXJ:QYjNX
[Jb][jf^[:Z/Yj>YX9ZSUi6PTH^LS8BGQWjBOgN?NW69LfZ7KfF5Jf22IUX00WiPD`0@NEY<M5A7L4m1
Hd4dEc<VDbXLEc<WFc/`H4@jI4a4JUE>KeiGMFIQNfm[PGQeQh5o6?ooo`0?P8V:RY>EU9jPWZV[Z;Bf
/[o1_<_=a]KHcn3Se^[]gO;fh_KiioGggNS[b]WM00:gbLl07kS9c[[:ckg<cl7?dLKBe<_Ee]3HemCI
emCIe]3Edlc?cL[=b/W9a/O5`L[6`Lk8`m?<a]O=amW<aMW8`=S4^]Bn]=>j[m6gZlncYlf_X/Z[W/BU
V<2PT[fLSKVGR002]I:3012_S7f[QgRUPW>HMVN;JEZ3Ge20HEEnI5UlIUekJF5iJfEhKVUhLFegM79g
MgIfNWXIoooo00m8IWUAKhAJNHiSPiU/SZAfVK21YKb</LVG_MJQbN>Zdnjbf_BkgoO0hORng_H00[[J
lP0O]mO_]MG]/m?[/m;Z/m;Y]M?Z^=K/_MW^`mgba=gc`M_a_]W^^mS]]m;W]<_O//OK//KI/lKI]<OJ
]/SK^<[M^/cN^lcN_<kO_]3Q`=;S_m7R_<kP^L_M]/WK]<OI00:baML04:o3eJc1djVodJ>lcIbfb9B_
`HbV^HBO/WbGZWB?XVb7VVB0TeehReEaQ4iZODMSMR3oool001koool03iNASiJBTYFDUI>FV96GVXjH
W8^HWXJGWWnDWGJ@Vfj=VVZ9UFR5TUAfQCiUMP02;5IY01lbFV`hGflmHW53IgE9K7U@LGiDM7mHMH1A
L7]8JGE2I6m2I6i6Hfa9HVY?IfiEKGAKLgYOMG]PLWQMK75IIVU@Fei>EeY8DE=1BT`k@dDj@44g?3dh
>CTi=cHj=C<00SPb;P0@=BhZ<bXV<2DQ9a`H91@?9a0;<A`F>RLRA38]CchiFDU5HeEAKV5MNFaYPgQe
SX>06Oooo`0?U9>BVY^KXJBUYjb^[KFg/kk1^LK:_/gB`MCJ`MSO_m[S_]OO_];JY[o9Rj^g009cUjL0
7gVJZ7nOZXBR[H^W/9://iVa]ibb]j:d^9f`]9>X[XjQYXbOY8fKWY2IViROX:2VYZR][:j`[[2^ZjnX
Y:fTWJBGTJ>DSJ2?QYZ8P99oMhiiLHQcJXI^I8AZGh=VFP02OV1C011iFTefEDM_CT1O?c9B<BA>9aYC
<2EG>BiL@CQQBT9WDda]G5IcIF1jKVZ0N7B7PGhHoooo00n0RHZ;U9FEWj6PZjb[]kRf`lC1cm3<fmgG
inWOl??Smo[Vm_SWl_CHhnK5e=P00[;5b`0O]LG;^<S<_<[=`<c>a<o@b=;AbM;@c]?AcM;@alg;a<O5
`/C2`;nl`[fib<:mc/K0e<_5f<k6flg5fl[0g<Rmf<2efKjbfKb_ekR[dK:TcJbNaZJH`j:C_if>_9R9
00:gTh<04;:>OZn:NJV4LiYfIX]WF89LCX1ODgeREg]UFgYWGgQZI7M]J7M`K7IcLGIgMGIjNQWoool0
3dQVNE5_Q5YiSV>4VFf>Y7RJ/8>V_Hndc9c2fjS?jK7Il[OLm[WKlk[KlK_Kl@02^MS_01ngeN^fdnZe
d^RddNJccn>ac>2_b]j`bmndcN:gc^>hc^6fbmjbamZaaMRba]VbaMNca=JcaMNea]RgbMZjcMfmcn30
d>74e>G7enO7e^K4dnC1dN:ncn2jc=fgbMX00[G7f00@/lKF//GE/<?CZ[g=XKG5V:joSjNiQinaOYNZ
MY2RKHRJIH2CGWV;EW64CVYmAf=f8?ooo`007_ooo`0?V96?Ui>CUYJFUIRIU9ZMTY^OSibRRY^RPYRQ
MY6LI8BBHh>AHX6>DWB3>fAf008XE6P07bmHJcEMKS]QLD1UM4IZMdeaOU9dP5YhPe]hPeIdOdm]MdUY
LdUVL4]UKU1XL5E]ME]cNV1fO69eNV5`MF1]L5QRIE=MH4aFF41;Cca5B3Q0@S<i?3@g>3He=CTe<`02
=c8_010d;R/b:RH[920P61DJ3``P3@T[61@e9210;ba;>cQFAdAQDe1/GeagJfR2MgB=Ph0Ioooo00nD
Ti:LW9bSYZJZ[k2a^;Zh`/Boblk5e=S:fn7;hNNnf>2ldm^ic]JU_LJ8Z;D00VjCX`0OMINUNibXPZ2[
R:B]SZR`UJfdVJneWk:gVjjcUJR^Sj6VRifRS9ZNTIZMV9nPXJJVZ:f/[k2^/Zn//JZU/:FOZIZCZIR@
Yi>:VXR0TgmgSgYbQg9YQ6iTPVUNPVEI009oHE@047]LCWQGBFm>@5/m<4`]8DTU6Dl^8U<f;5Po=Ui8
@6AABV]JE75TGgQ]JGmgM8J0OQSoool03h69RXbEUYNQXZ:/[Zji^[[5alKCe=CQh^7_l>kmo^_koN[f
m^O_l=OQhl;Ae@02[l7701nb`lRfaLVjb<Znb/_2c<c5cLg6c/c8c/c2b<Nm`l>k_kjj_;^m^kS2_;S8
`;_>a/3DblGIcLKKc<?Kb;oKaKWH_K7M_k7P_k3G^:WB/J;@[Yo8YiS4XY>oWHjmV8P00[VDP`0@]Y1o
]8ak[HEcVgEURVIGPEa>OeiBO65FNV=JN6INMfURMVaWMVm[MW=`MWIeMWYj6Oooo`0?B6IjDFn4FWV>
I8>HKXjTN9Z`Q:JmT[G=X/OO]=cf_^Go_^3h_Mcc_=[_^mS]00:je^/04KSDjKKBikGAiKG@i;?=hK79
fjk6f:[2e:FlcjFkcZRmdJ^ndJjodK32dk73eK;4eK?4e@02/lCD00bda=Be`m>haMBoc=W6dn38eN?6
e>;8eNC6eN?1dN6mc]jib]T2]lOG0[O7eP0>]/GD/L7@YkW8W;31TjVjRJ6bP9RZMi2RKhRJIX2BGWV;
EW64CfYmAf=f8?ooo`007_ooo`0?V9:@V9BDV9RHV9ZLUifPUYnSU:6WTJ:YRZ2XO9NRIXNEFWf;EgZ9
BVn0>69d008VDfL07beGJS=LKCUQLSiSLd=WMDU]NdmcP5AfPeAfPU=cOdm_Nd]ZMTYXLTaXLE1ZLUI_
MUadNf1fOF=fO6=cMf5_LF1XJV1VIeiRHTeDEdM<CT=7BCXo@CTl?CTi>CXg=@02>3<a010e<2db:bPW
8AlK5Q@C2PPH20@T514_81dk;BY7>CIBAT=NDTmZGU]fJfR1MgB=Ph0Ioooo00nEU9>MWIfUYjR]/K:e
^kfma/S6d=?>fmoHin_Ci^c1emnic]Ndb=2N]l:3Y;800VZ@X00OLIFSN9VUP9nZQZ6[RjB/TJV`UZfc
VJjcV:baU:N]T::WSIfQSY^NTibNVJ2PXJNVZJf/[k2^/Zn//ZZU/:FN[IfE[I^B[IR>VhV1UX5iTGac
QW9ZQ6eTPVUNPfII00:1HU@047iND7aJBVe=?ePk;dHZ7d@R5TTZ84hc:E@l<eY5?V5?B6QHDfmRGWM/
J7ifLhJ0OQSoool03h69RXfEUYRQXZB][[2j^kg8bL_Fem[Vi^kinOCoonghnNgdm>S^kMGNh;k=dP02
Z[g301n__lBc`/FialRmb<W0bLS3b/W5b/W5b/O3alFo`/6l_[^k^[Rn^[K3_;O8`;[?aKoEbl?Ic<CL
bl;KakgI`kOG_K7G_:oH^Zc>/JC<[Io9ZI_1XYBnWXnlVHVmUhH00[bDP`0@^Y5o^Xml[XEcVWEUR6IG
P5a=OEe@NUmDN65HMVALMFMQMFYUMFiZMG9_MGIdMGYi6Oooo`0?B6EiDFj2FWR<Hh:FKHfRN9R^Q:Fk
T[C;Y/[S]=Sa_n3ga^GkaN7f_m_`^]K[00:gdnP06[KBi[K@hkG@h[G@h[C=g[;8fJo4e:c0cjZmcJVk
bjVjbJ^kbjfmc;2oc[71dK;2d[?3d[?2dK?1d;?0ck:ock;0ck;1d;C3dKS6e;_9e`:kb]P00kW8e[S7
e;S7e@02^LOE012jamFkbMNjb=Fc`]2Z_LbQ]LFFZk^<X[:2VJYiT:5`R9UWP99ON8YGLH=?JWa7HgHP
oooo000Noooo00nITi6JUYFJVYZKWInKX:>KY:RKYjbJZk6K/;R8XJYeU9mSQI9HNhY7KWlgHG@00REB
I`0O:eIY<E]]>69b?VIf@VQgAFYhBFilC75oCG:0C71mBVejB6YfB6McC6YdDFaeEW1hG7AlHGImHgMm
Hg9hHFibGVU[H6MXI6MWGF1PEEMGCTm@ADM8@452?C`l>cTh008j=C<043La;c@^:bDQ7aPE50l:2A84
0Qd@3RTM6cHZ:4<g=4m4@EaACVQMFgAZIh1fM8b3P1Woool03iJDTijNWZNYZK2c];Vn`<;9blcEf=OR
iNCamMKVjlSKhKW=eJk3c9Jb_WjP[P02IhjN01m]TZ1eUZ9mW:J4WjV9Xj^>YJfCZJnEZk2EZJnBYJ^?
XJN>WJ:>VijDWInJXJ:RYjNY[Jb`[jfc[jbcZjJ`YIj]WYJ]Vi:/UhfPSHBIQGbCOGB9M6^7KfF6Jen5
J5/00XETEP0@PV1BP5a=Jd/nE3T^@RTO?QdB@bHLBBlVCcPaET8kGDa6IEIAKF5LMF]WOGEbQH1m6?oo
o`0?PXV:SIFFVJ:SYZn_/[bl`<W:c]SHg^SXl?[jk_Ogj_;ciN_[gnGUbmOJ^<S=00:W^/007jbl`K2n
`[G1`kW2`kk6aL;8alG:alO9a/K7a<;2_l2o_;nl^L2j]LBl]/W0^Lo6_mG:`][;`]c;`Mc8_=_3]mRn
/MJj[M6eYlN/WlBXVl6TU[bNT;bKS;jIRKnHQP02_iF3012oTh2nTGf]Pg6GLf>6I5InFDYkFdihG59f
GeIdHUYcIEmcJFAcKFUdLFidMGAeNGTIoooo00m8I7MAKH5IMh]SP9E/RimgUJZ2XKN>[/BL_=>Xamjb
c^BjeNVmen^je>Vfd^D00[KAi00;]LoR]LgP/lWK//OG]<WJ]L[J]<OG/lCB/L3>/;k<[kg;00:`_//0
4[2mbk6oc[;2d;?2dK?1ck?1cKC1cKC1c[C0c[6nc:^iajNfaJ^jb:fmbk2nc;?1c[O4d;W5d@:ja]80
4;c8e;g8e;[6d[?1cZ^lbZ>ea9V/^hjS/XBIZGZ@XG28V6N0TEmhRUMaPdmZO4MSMB3oool001koool0
3iZCTI^GUibLW9fPXInTYj2Y[:6]/Z>c^JNj`I>Z/gjJYFb<VEaoSDQ`PCEQM00295=X01lWE6P_FF`e
Gg0mIWI5K7a9L7i=LX1?MH=CN8ICMhAAM89>LGe=KGU>KGMBKWQFLGYKM7aPMWiTN7iTM7]PKG=LIfaK
IFMKHF=HGUmFFEY@De=7Bda3ADDo?clm>c/00SXg=P0@>C<a=2h/8b4P51@E3`d<30815P`;8aTH<BLU
?cDcC490FDm=IUaJLfUWP7IcS8:06Oooo`0?UYFDWinOZJZZ/[Ff_<72a/g>dMWKgNOZjoKigNW^c=cR
^lkFZL79TJnjNYf[009US9d07fZ>WG:CWgVGXX6MYXNQZHbTZi6V[96V[I>W[I6SZI2QYXjNXXnKWiFO
XIbTY:>YZ:Z/Zk2^[;>`ZkF/Z;:UWjfNUj^JTJNDRj6>Q9f7OYIoMHmgKHacJ8Y^HHUZG@02R6IH0128
HeB2GDeYBSe==Ra2:R0i6a4m8QU2:b=9=BiA?cUJBTARE51[Ge]cJVIlMG:4OgdHoooo00n2RX^>UYNJ
XZ>W[k2d_;g1b/[@f=SOj>S`n?S]m?CXk^kPi^OEgMo4d=Bd`lP00ZFg_@0OZKVm[[^m/[bn][jo^Knn
_<2n_l6n_Knl_;fk^[Zg^[Re^kNc_KJba;^eb/6jd<Jne/W1f/[0g<^og/Vmg/Fhf[naf;^]dkJXcJnQ
b:VKa:BE`In@`Yj=`Yb9`iZ700;3V8@04<BFP/2BOJb1Ki9_GhETEGaGBGQHC7AJCg9LDg5OF75SGG5W
HW5[Ig9`KG=dLgEiNAWoool03dQTMe1]P5UeRF5oTf^8W7BBYWjL/HVW_9BaaYnldJ[4f;39gK?<h;C<
h;G<g`02]LgP01nfc^2dbmbcamR``m:^_/b]_<V/^lNY]/:U/KfU[kZV/;^X/Kb[]L2_^/Jb_/^c`Ljd
`/jd`<bc_lZe`L^g`lfg`lje`Lfb_/^__<R^^/J_^/Jb_LRf`L^ia<fja/l00[c7d@0@_/WC_lWC^lG?
/Kg9ZkW5Y[K4W:jmT:>bQIVXNXnOL8NGIgn@GgN9Eg22CfUkAf9e8?ooo`007_ooo`0?VYBBW9VHWYjN
X::TXjRZYJfaZ;>hZkVo/<78Wk>kRZ:/MI>OHH>ABg:3=V9e008UE6T07bECIb]GJC9LKCURLT1YNDM_
OTedPTmgQE9iR5=iQe=hQU1ePTm`ODm_NU9`NUEbNUYdO5mfOFAiOVUjOfMeNV1[LEUTJ5AMHU9JGE5F
FDeADdQ;CDA6Ad51@Chm?@02?STi010l=SDd;R`R8B4?4a@;2``600090`<L5A@/92<k<c99@CmGCTeU
G5YbJFMoMW><PX0Ioooo00nGUIBQX:2Z[:be]kNo`lC:cm7Eg=kRj^c_nO_RkO7@g^>mcmJX`<V@[KUh
VjT00VF<W00OIh^JKXnKMI>NO9RQPibURJ2WSJ:XSJ:YT:>ZT::XTJ:WT:2TTinSUj:SWZJWXjZYZJbZ
[jfZ/ZjY]ZfX]JRR/:2I[9^BYI>;XHf4WXMnVH5gU7]`TGIZSW5TS6aO00:<JE/048eWEh5LCFI8?4Xe
:d8[8CPL4S8J4S/U7T<a:T`l=UI7@UmBCVQNFW5YIG]dLHAoOASoool03h::RhjFUi^SXjN_/;Bl_L;:
b]3Hf=oWi^kfmN_al>?YjM[Qh/oIf/3<ck30a002Y;Jl01nW][Z[]kZ`^KZd^kZg^kZi^kVi^KNh^;Fi
]kBi][:j]K6l][;1^KC7_[O=`kcBakoGb<3IbKoKb;cLaKWL`[CL_k3L_JkF^:SA/Z;>[Ig;Z9S8Y9?7
XHo6WX_6VhP00/JJQ@0@bIV3_i1kZ7m/TVmORFIGP5]<M5E9L5E;KUQ@KEaEKF1JKVEPKfUVLFi/LW=b
M7Uh6Oooo`0?AfAgCfaoEgB8H7b@J8FHLHjQNYNZPincS:NkUK33W[S;YKkAZl?F[/KI/LSJ00:dbmd0
5[K<gKG:fk?7ek;3dJnnbjbg`jRa_:F]^:BZ/jBY/JFY/JR]]Zfd_k6ka[BobkK1c[K1cKBobk:kajnh
`[2i`[K0a`:ja<d01kO1bkJob[Fob[O1b[W3c;_5c[c5cP02_LO?0130bM6nb=2h`/^e_lVa_LR]_<VR
/l6AXk65V:IjSYe`QIEWOHiNMXMFKh5>JG]7HWDPoooo000Noooo00nKU9>NVYVQX:2SYJJVZjfZ/KB]
^;ba_lBfalfW^/:CZ[AnVJEYRIM@MXLiI7L00RMFJ`0O959V:5AW;UUZ=Ei^>f=c@FQhAFelBG20Bg>2
C7>2CG>2CG:0CG5nCVmkDG1jE75kF79kG7=kHGElIWMmJgQlJgAiIfibG6AXDe]NCEAHBU1CAd]=A4M8
@T=3@T100091?C`0444j>C<_;R8Q8PlD5`H;3@H41@D10aLB4bPR8SPa<DM0?eI>CFAKFW5XIgieLh^2
P1Woool03iNFU::QX:b][KNh^L75aLgAd]WOh>G/k_?joNK_l]CPiKo@ej[0bI2]^GVKZ@02IXfL01mU
RIQ[RiQbT9YiTieoV:24Vj:8WZB;X:J>XJN?XJNAXZRCXZNFXjNJY:JOZ:RTZZVYZjV][:R`[:NdZjFf
ZJ:dXibaWYFYUXfTSXFNR7nKPWRGOG:CN6^@LVF?Kf400Y5/G@0@TVUIOeY;IDPkCCL]?bTP=A`C9a<<
<R0J?B`WAcTcDTE0G51<IUaIL6QUNW=aPgmm6?ooo`0?PXZ;SYJGVj>SYjn_];bl`/W9d=OFg^GTkO?b
j>k/h>KUe]kNb]CF^lW<[[k200:S]KX07jFc]jVe]jjg]k:h^;Fi^;Rj]kZi][^i][bj][jj]L2k]/:l
]lJo^L_2^m36_]C8`=O9`=[9_][7^m_5]m[1/mNk[MJhZ]BeY]FcXm>`Wm6[VLfWUL^ST<RNR/NLQ`02
bY^6013<VH>lSGRXOFZFLF29IEEkEdUYBd1YD4IXE4aYF55ZGEM[HUi]J6A_KF]aLg5dN7PIoooo00m7
HgI>JWiFLXENNHaVPIA^RIafTJAnVJ^6X;:>Y[RE[KnL]<JR^/^W_m2]a=D00[78f@0?]<[J]L[I]LSG
/lGC//7>/;c8[[S2[;Bn[;>l[;:j[K>k[kJn/[[3]Kk9]l;=00:h`ll02;K1c;Bnb;2j`jfe_JZc^jbf
_[>la;[2bPBla<`05;_3bk_3b[g5c;g5c;o5cKc3bkS0b;RoakBlaJVd_ibZ]hnO[H>EXgR<VVj3TVIk
S5eeQEE^OdiXNTMRM23oool001koool03ibETinKVZ>QXJJXZJZ^/:je^;:l`;O3b;g<dJjoaYba^XFO
ZVn>VeIkRciXN`02:EQ]01lRDFHUDFD[EFLaFFXfGVhkHW8oIWE3JWU5KGa7KWe8Kgi9KWe:KWa<KW]?
KWYBKgYEL7UHL7QLLGQQLWQULgQWLWIXL7=VK6iQIVQIGV1DEeU?DE=<CDi7AdQ5@d<00T=0@00@@cdl
=C4a92DU5AXL20hA0`H80@444a4B9B4R=S4aACloE4i=He]JLFQWOWEcRh:06Oooo`0?V9JEXZ:Q[Jj]
^;Zja<K7cm?Dfn3Qj>k_mOcmio3cf>?W`M;I[<7:TjnjNifZ009XSYd07fB8UVR9UFn=UgF@VG^DW86G
WXFJXHVMXhbOYHnQYY:SZ9BTZ9RUZI^WZJ2XZJB[ZZR[ZJ^ZYjnZYK6YXkBWX;>SW;:OUjjIT:RBR::;
PIj4NIUnLiMiK9=eIYEaH`02UFiO012CJUYmFD]VB3a?>2hk:1l]6A8O3`T[71Hg:2=2=C5>@SiICd]S
FeM^IfAiLg23OW`Hoooo00n2RX^>UYNKXZ>W[jnd^k_1b<S?e]GMhn;Zl>oTj^WNi>?Cfm_7d]>jalV^
_L400ZFe^P0OYK:fZ;>e[KFf/KNf]KRf^;Vg^kZg_K^h`;bh`[fiaKnkb<6lbl>mclJodlS0el_1fL[0
flVng<Rkg<Fhg<:df[j_ekVZdk>TcjjOcJ^Jc:RFbJBBbJ2=b9j9c9f800;=VhH04<^HPKV9MJIkJ9A]
GH9ND79@A655>f5:@F9?Af=DCVEJEFQPFfYVHVe/JW1bLG=hN1Woool03dIRMTeYO5E`PeagRV=nT6^5
Ug:<WWVCYH2IZXJN/8fU]YF/_I^b`j:ibJVoc`02/LKF01nfb]ZgbmZfbMReamFea=6d`/jc_lZb_LNb
^lBc^lBd_<Ff_/Nh`LZj`lfka]2lam6ka]6jaLnh`lbe_lRb^lB_]l2/];fZ/k^[/k^_]knb^/:c^l:d
^l:h_/Fl`LP00[k2b@0@_L78^Kk5]K[2/[Jo[[:jY:bfV:B`S9^XP96OMXRFK82?I7V9G7>3E6enCFMi
AV5d8?ooo`007_ooo`0?W9FDX9bKYJ>SZJZ[[K6c/[Rk]l33_<O<`/oE//;9X[FnS:F`MI>PG7n?A6ao
008]Fg007b9AIR9?HbMBI2eFIc9IJSIMKCYQLCeTLd1WMT9YN4AZNTE[NTM[NDU[ND]/N4i/N55/MUA]
MUQ]ME]^M5m^Lf5]LV=/L69YK61UJ5eQI5ULGE=FEdm@D4];BdU7AP02Ad=20113?S`f<c<X:2TK7R0=
4QD320/00P@?3Q0S828d<C55@41DCTeRG5Y`JFMnMWB;PX0Ioooo00nHUYFSXZ6^[Zjj^k_5alOAe=GM
hN;Zko3goOkYlO?Ji>S5eMZ^a<bG/K^0X:d00VfAW`0OHhRFIHJCK8ZDLhfFNI6HOYBKPiRNR9^QRijT
Sj2VTZ>XUJBYVJJZW:RZX:VZY:^ZYjZXZZVV[JRT/:NQ/ZFN/Z:J/IjE[YV?ZY>9YXf3XHMkWH5dVga^
VGQZVGAV00:HLF40495YFG]HBVA7>dlg;STW7bLG4QX=22<F4S0T83db;dY0?5I=BV5JEfeVHgQbL89n
O1Soool03h::RXjFUYZRXZN^[[Bj^/77alkDdm_Qh>W_kN?Yj=cRhM7IfLK@dK[6bK2m`@02Z;Jj01nU
/[FW/[>/];Ba][Be]kFi^KJm^kS0_KW3_k_6`Kc9a;k<aKo@b<7Cb/;Gc<?JcL?Lc<7MbkoNbKcNakWN
a;GL`;7J^j_F]ZGB/:3?[9[<YiG;Y97<XXg=X8_?WXT00]2LQP0@bIEo]HIaX7ITSVQHNUY<JDa1FT8h
FD@lFdU2GU1:HEIAI5eIJ6=QJfYXKg5`LWMg6Oooo`0?AV9eC6QkDfj0FWB6H7Z<Ih6CKXNHMHfNNi>U
PYV[R9j_SZBdUZblW[C4Ykc<00:`aM<07kK:fKS<f[S;fKS9e[S8e;S6dKS5d;S4ckS3cKW3cK[4c[c6
ckk8d[o:e<3<eL3<e/3;eKo9dkg7d;_5c[S1b[Fna[:k`[2g_jje_:fd^jne^k:g_KFk`;Vm`kboa@02
_L77012k_/Be^;j_/kVY[[FTZK6MYJnDXJb9V:AlS9UbPi5YO8]QMXEJL81CJga<IWM6HG<Poooo000N
oooo00nMUYBRWIbVY:B[[:f`/kFf^kjk`lO1bm36e=VgalfW^/:CZ[ElVJIRQIE:LX@00S=PM00O8e9X
7deQ94mR:U=T;UIV<UUY=Ue]>F1`>f9b?VAd@6If@FMg@fQgAFUfB6UfBVUeCFUdCfUbDfUbEVUaFFY`
FfU_G6M/GFEYFf=VFEmREe]MDeIHCe5BC4e=BdU90099ATD0444n?SDd=2TZ;1dP8a4F6@H<40872Ph?
4B<R8cDb<dE1@EA?Cf=LFg5YJ7ifM8^2P1Woool03iRFUJBRXZn_[[^k^lO8b=?EeMoRhnc`lOWnon_a
lmcUjLSGg;?7cYbe_XJT/002LYBR01mURIMSQ95YQi9aRiAgSYImTYV2UYf7VZ2;WJ:>X:JBXjRFYJVI
Yj^MZ:ZQZZ^TZZVWZJNYZ:F/Yj:^YJ2`Xif`X9V_W9B]V8j[ThVXSX>URGfRQ7NPOg6NNfbNMfP00Y]b
HP0@SVMGMeI8HTHjCCH]=bHO8QHA5@`86Q0=:b4N>C0]AchkE4a9H5UFJfESMg9`PWil6?ooo`0?PXV:
SYFFVZ6QYZf]/kVi`<K5cM;Af]oNinc[hNGTf]oNd=OGalo@_<K8/kk100:Z]kX07jJb]JJ`/Z^c/[6e
/kJg]KZj][nm^L>o^lK2_L[5`<g7`]79`mC<a=S=aM_?a]k?a=o>`^3=`>7;_N78^^75]^31/]fm[=Zh
YmNcX]F_WM>[V=>XU=>UT=>RSMBPRP02dYb50135TG^`PFfLLV28HeAdEDQPASaA?3=>>cAC@ceHBdIL
DdiQFUMUHEmYJFM^L6mbMgLIoooo00m5HGA;IgUAK7iGLH=NMhQTOHiZPY=`R9QgSIemTZ62UjJ9WZbB
YKBL[[bU^<H00Zk1cP0O]/WF^LcJ^LcI^/_H^l_G^l_F_<[E_L[E_/_E_l_E`LcF`/gGa<oHaM3Ja]7K
a]7JaM3Ia<oH`lgE`L[B_/O>_<?;^L37][g3]K_1]K[0]KZo]k_0^[c1_;g3_[k300:n_/804;Zj_[6b
]jZ//J>V[9bQZ9BKXhbFX86>VGJ5TFemRVEgQEibPEQ]OE5YND]TMTEPLR3oool001koool03ijFUJ>N
WJRVYZj^[[>f]kVn`;o6b/G?dlcHgKc:dJbnaYV`^XBP[6b=Ve=iR`02>fMk01lZF6hOCV<RCF4WD68[
Df@_EFDbF6PeG6`gGVhiHG4kHW8mI7<oIGA1IGA3IWA6IW98IG5;IG1=IFm@IFiCIFeFIFaGHfUGHFIG
H6AFGF1EFEaCEUQADU=?Cdm>Bd/00T]7AP0@@d0o=cLg;2d^8B@W5Q/N31<G20dA4A<F9BDW=cDfAT=3
EE5@HeiMLFYYOWMeRh>06Oooo`0?VIJEY:>R/:n^_;bkb<W8e=KFhN?SkO7anokok?;cgNKYbmWN^<[A
X[W2S:Rc009gV:D07fV<VV:4TFR5T6n9TWJ=UGb@Uh6DVhJIWXZLXHjPYI:SYiJUZIZWZijYZj6ZZZBZ
ZJJYYZRWY:^VXJfTWZjRVjnOUjjKTjfGSZ^CRJV?PjR:OZJ6NJ>1Lj9mKZ5iJ@02VW5Q0128HeAcDdIN
@cQ8<b/b8adN514A2PLE3@XW7a`f;ba5?C]BBdQNF5IZIF=fLFn2OW`Hoooo00n2RHZ=UIFIX:2U[:bb
^;Rna<?;dLoHgMcUj^SNhn7Gg=_?eMG6c/jlaLJc_Kl00ZZf^00OY[:dYJn`Zk:a/KFc]kRe_;^g`Kjj
aL6lb/BocLS2dL[4eLg5fLo7g=78gm;8hM;6h]34hlk1i<bni<Zki<Nghl>bh;j]g[ZXg;JSf[:NfJjJ
f:^FeZNAeZB>eJ6:00;>VH804;b;MJQkJ9A/FgmLCVU=@E@n=DHc:d<b;4/m>597@UQ?BeeHEF9PGFMW
IVa_KW5fMQWoool03dEPLdYUMe1ZO5E_P5]dQF1hRFImSFb2TW67UWN<VWfAWh>FY8^NZiBW]9n`_@02
Z;W501Zb`ljhb]JkcMVlc]Zncm^od=c1d=_2d=[4d=[5d]_7dmc8e=g:eMk;e]o<en3<emo;e]k:e=c9
d]W7cmK5c=?2bLnoa/^m`lRk`<Fk_l<2^kk20[bn`P0C_Kg1^[Zm^[Zm/K:fZZ^_XZBYVIbQT9BJQhfD
OhJ?MX2:KW^6IgJ3HG9oFfilEFYjCfIgBV=dAEmb023oool001koool03ijGUJBOWZZWYk2_/;Jh^Kc0
`l?9c<WBe/oKh<3?eK32bYne_h^V/GBCXEYoT002A6f001laGW<TDVLRCF4UCV4YDF8/Df@_EFDaEfPc
FV/eGFhgGg0iH70kHG4mHW4oHg51Hfm3HVi5HFa9HFa;HF]>HFUAHFUBH6MCGVACGF5CFemCF5aBEEQA
DeA@Ce1?CDd00T]8A`0@@T10>CPi;S0a9BPZ6alR4QPL3a@H6adP:R/]>SPjBDI6Ee=CIEmOLV]ZOgMf
S8>16Oooo`0?VIJEY:>R/:n^_;bkb<W8eMKFh^?Tko7ao?ook_?dg^OZcm_O_LgCZKg5TJ^f009mW:P0
7fj@WFF7U6R5T6n8TGF<U7^@Uh6CVHJGWHZLXHnPYI>SYiNUZIZWZYjYZj6ZZZ>YZ:FXYJNVXZZTX:^S
WJfPVJjNUZfJTZfGSJbCR:^?Q:V;OjR7NJJ3M:EnKj5iJ@02UViN0123Ge5_D4=H@3I2<2P]81XI4Ph:
1P@D3P`U7ade;ba3?C]ABdUMF5IZIF=fLFn1OW`Hoooo00n1RHZ=U9BIWinTZj^`]kJm`/79clgFfmWS
inGMh=kEf]S>e=?6cLfna/Jc_Kl00Z^g^00OY[:dYK2aZk6`/[Fc^KVe_[bha<2kbLBncLO1dL_4e/k6
fM38gM?:h=C:hmG9iMC8i];5i]32iljoil^ki/Rgi/Bci<2^h[bYh;RUgkBPgK6LfjbGfZVBfZF>eIn8
00;8U7d04;F5L:1eHXUTE7=DAee4>DPe;CHW8CT[9T@h<da3?e=<BEYEDf1NG6IVIF]^KW5fMQWoool0
3dAPLTUTMTiXNE=/OEQ`P5edQ69iR6QmS6f1Sg>5TgR:Ugj@WHJHY92Q[IZ[]P02Y;G000f/_/Vea]:k
cMRocm_1dMg3dmo5eN37e^79en7;f>;=fN;?fnC@g>D00]7Mi@0@d]cTd]_Sd=[PcmONc=GKb]7Gb<kB
aL[?`lS<`/G9`<?7`<75_l33_[o2_kk1_;^m0[Fd]`0@[:^_Xj:VV9VNSY2FQ8N>NWn6KWAkJ71hIW5k
HFmkG6eiEfYhDVMfCFAdBF5cA5ma8?ooo`007_ooo`0?WiNEYJ2NZjRX/[6a^;Zk_l?5a/c?cMGIe=kR
aM;H]LK=YKW3TZ^gO9ZXI8NG009;MHL07cITN2UGK2=?Hb=>HBI?HBUAHRaCHbiDIC1GIc5IJS=KK3EL
KCIMKCQNKC]OKCeNK3iNJd1NJT=NJDINJ4UNIdaNITeMI4mLHU1KH55IGU5HG55EF51DEE5ADU1>CP02
BTQ80113@T8j>S/a<c@W:RdN8RDE6al@5ATQ8bH_<38n?Ci<BDYIEEEWHF5cKFb0N7N<Q84Ioooo00nI
UYFUXj:`[jjl_;_9bLSFe]KSi>C`lO7mooo_loCPj>[Bg>32d=J^`<RH/;T00XBQ[00OLi>PJX^GJXJA
KhRAMHbDO92FPI>IQYNLRi^PSinTTj>WUjFYVjRZWZRZXJVYXjRWYJJTYjFQZJ>NZZ6K[9jH[IbE[IVA
[9J<[9:8Zhn3ZhaoZHMiZ8=eYGi^WWMW00:@JU/047eKCVM;@58l<c`/9BLL61<>30D201HA42DP7c@_
;D<n?51;BEeHEVUUHgEbL85nO1Soool03h69RHbCU9RNWZ>YZJne];_0_lO<bmCIen7Uh][Ng=?He/gB
dLO=c;k4a;Bm_@02[[Nh01nY/[BY/K6]/K2d]K:k^[K1_[W7`[c<a/3Ab/?Fc/OJdL[Ne<_Re/gTelgW
f<cXe/WYe<KZd/;ZckoZc;_Yb;OXaK?W`ZoU_J[T^JGR]J3P/IcO[IOMZI;IXhc@Vh@00/2=M`0@[7eZ
UFaKOUa>Id]0DC/b?BdV;B0K=RXV?cDaB40mD4Y7Ee=AGUaKI6ETJVe]L7If6Oooo`0?A5mbB69dC6Ig
DFUjEFalFG1oGWB2HgR6JGb:KX6=M8FBNX^GPY:MRYZTU:>]00:Q[[P07j^i`kG3c;c;eL7@f/CCg/OF
hL[IhlcKi/oMj=7OjM?Qj]GRjmOSk=STk=STjmSSjMOPimKNi=CKhM;HgM3Ef/gAe/_?d/W<clO8blG6
b<?3aL;1`l6o`;jk_KRe]`02[jf^012TXZFIV9^>SY:3QHYiO85_LgYVKGAQJW9NJG=KJGAGIgACIW=?
I7=;HW97H753GW0Poooo000Noooo00nOV9FVX9n/ZJVc/[:k_;c2aLO:cm;BfMcJhnK:e]bkb]6[_/NJ
/Kb5XJi]SYh00UElSP0O?VYn;Eeb8e5V8TeQ94iQ9dmQ:E1R:e5R;5=T;UEV;eMX<EQY<UUZ<eYZ=E]Z
=eYX>5UW>eYV?UYU@EYUA5YTAeYSBU]RC5YQCEUOCUQMCeMKD5EHCe=FCe1BCDe?0098B4T04452@cTk
?34d=RP/;alU:1TO8aLK7bLY;3De=d91@dm=CEaHF6USHgE^KH5iN8f4PQWoool03iVFUJFSXK2_[[fl
^lW9b=KFeN?Tho7alOoooo3dmN?YjmCNhLKBek?4bYne_@02S:J`01mjV:AaT9]]RIA`R99fS9AlT9N2
U9Z7Uif<Vj2@Wj>DXjNHYJVKYjZNZ:VQZJRRYjJTYJ:UXj2WXIbYWiZ[WIJ[Vi>/V92/UH^/TXN/SX>/
Rgj[QgZXPgBSO6fILf@00XQUE`0@MEI:H4LlBcL_=BPR7aPD3@X910815a<B9R8Q=C4_@clmD4a:GEUG
JFETMG9`PGil6?ooo`0?PHR9S9>CUifMXZRW[K>b^KjmaLW8dMGCg^7Oem_IdMGDc=3>a/_9_/C3]kjn
00:a^;T07jfd]:jd/k6d/[Nf/kfk]lC0^l[5_]39`]G>a][Ab]oEc>?Hc^OJcnWJc^_JcNgHb^gFangC
`ng@_nc=^nc9]n[6/nW2[nNnZ^JjYNBfX>BbW>:^UmjYTMNQRL^FO`02^8Ia012RMV>:IEAdE4MMA3U5
<bX`8ahV6aLb:2@l<c15?S]=B4IEDU1LFeYSI6=YKFe`MGHIoooo00m3GW57HG=:I7E>IWIBJGQFJgYJ
KWaML7eRM85WNHI^OhYeQ8mkRYB5Tif@WZL00YbY/P0OZKBm]L79_/_Da=;Kb=KPbm[Tc]gXd^7/eNC_
enKaf^Sbg>[cg^[cgn[bgn[`gnW_g^O/gNCYf^3Uf=cPeMWLd]GIcm7DcLk@b/_=b<S9alG6a/;3`kjo
_[Vi][6a00:ZYZH049jJW96@THF5R7YlOfmaMF9WK5aQJ5YRJUQRJeERKE=RKU1RKdaQKdUPKdINKd=M
Kb3oool001koool03inHUZJQWjjZZKFc/kfm_/G7b<gAdmKLgmoWjm7LhL;@e[;3c:6f`HfW/gJEY002
GhBE01m7LXDeHgPVEFXRCV<SCV4UCV4VCf0XCf4YDF8ZDV<[E6D]EFL^EfP^EVL`EVHaEFDcEF@eEF<h
EV<lEV8oEf52Ef55Ef18Eem:F5i<Eea>EUY?EEU?DeI=D5=;CDl00TM8BP0@@D=4>cdn<cHi:blb8bP/
7R<W92L[;S0c>c/mAdI7De5AGe]KJfIUMW1_PWYiSHF26Oooo`0?VIJEY::Q/:n]_;^jbLS7e]GDhn?R
lO7`ooool_Gfi^[[f=oRb]GI^LS>Y[W100:E[;D07hBNZGVFXG6=Ug::TgN=UGfAV8>EVXRHWXfLX96O
XiFSYYVUZ9bWZIjWZ:2WYj:UY:>SX:BQWZFOVZNNV:VKUJZITJZGSZ^DRZ^AQZb>PZb;OZZ7NJJ2Liii
JY5]G`02OemB011[D4IH@SQ3<b`]8ahG4Q0510<91`LI5QHX9B@f<c54@3mACDaMFUQZIVEfLW61OWdH
oooo00n0R8R;TY:EW9bPYZF[/:nf^k[1a/C=dLoJgM_Df=K@d]3:c/c6b/S0aL>i_[h00[Fj^@0O/[Ne
/kNe];Jc^KRd`;fhb<:mc/O1e<c5f]78gmC<i=S>j=[?jmc@k]g?l=g>lM[;l=O7l=C3km6okljlk/Zg
k<Jcjl:^j[jYj;ZUikJPi[:KhZjFgJN>dYb4`Hih00:/OFT049A/FgiLC6M;?dlj<3HX8B0F4R4G52hV
8cTb;d8m>T]7AE=AD5YKFF9THfU/K6meMQWoool03d9NL4IPLDUQLTaSLdmUM59WMEEXMEQZMU]/N65`
NfQfPFmmQgN5SX6>UhbHX@02V:>[01nV/;Nd_/Fob]76d][;f>7?gNOCh^cGi_3JjOCNk?KPk_ORkoKT
l?KVlOOWlOKVko?Uk>oSj>_PiNOMhNCJgN3GfM_DeMKAd=7>c<g<bLW9aLG6`/72_K^k];>_ZJP00Z:M
W00@U92AQXF6NWYlKFmbH6=WDeEICe=HDUUPDE]TD5eWCUeYC5i[BUi/Aee]AEe^@Ua^8?ooo`007_oo
o`0?X9RFYj6P[j^Z][Bd_[joalS9d=?EfMoQhn_^fN?WbMKL^L[AZKg7UZjjOif[009YRi`07e=kSCm/
P2eLLRAAIR9>HR=>HBA>H2E>HBI?HBI@HRM@HRMBI2UCIBUCI2YBHb]BHRaAH2mAH39BGcICH3YCGceD
Gd5DGTAEGTMFGDYFG4eFFdmFFTmDEdeADdY=C`02ADQ;0110@dHk?T0d>3//<C@S:BdL8BDZ;C0e=cU1
@D=<BdaGEEESGei]J6QhLW63O7Z>QH<Ioooo00nIUYBTXZ2`[Zfl^[W8alKEe=?RhN3`knkoo_gfmoOY
k>gKh^C?f=boc=2^_/D00Yfa^@0OSjJ_PYbVMi:MMHfGNHnGOi>IQ9JKRYVNSYfQTj2SUZ:UVJFWWJNX
WjNXX:JUXJBRXJ6NXYnKXifIYIbFYiVCZ9N@ZIB<ZY:9Zi25Zhf1ZhYmZHIhXgi`UgAVR6MJ009eFDd0
465:@Dll=3/^:2@M6Pl>300000h=31`J6RXX9cPe=4E2@E9?CEiKFVYWIWIcLH9oOASoool03h27R8ZA
TIBJVYjTXjR^[K>h][k2`<W=bmGHe];Dd/g@cLW<bLG8a/74`[bo_@02^;^i01ng^KNg^KJh^;Fm^[K4
`;[<aKkBb/;IclKOdlWUelcYf/o]gM3agm7cgm7dg/odfl_df<Oce<?bdKoac[_`b[K^a[;]`Zg/_ZWZ
^ZCX]IkU/9WPZi?GXHW8U7jfQG000YmdH@0@Qf=CLE95FT8g@C0X:alJ6a8>8a/H;BHS=c4_@3`jBDM5
DE5?FEYIHF=SJ6a/KgEf6Oooo`0?@Ue_A5i`Aem`BF1`C65`CV9`D6=_DV=_EFA^FFM`HFigJGEnLGf6
NhJ>Qi6H00:DWJ<07j:[/;2h_[g6blSBfLoJh]CPj=SUk]gZl^7^mNGan>Scn^[enncfnnkfnnkenNgc
m^c`ln[]knKYjn?Ui^3PhMcLg=WGemGBd];=cLk9b<[4`/Fn_;jf];B/ZZNPWP02VI>B012:QXImNW]_
KW1RHfIGFEe?DUM<DEM<DeY<EUm;F69:FFE9FVM7FfU5Ff]3G6a1G6hPoooo000Noooo00nPV9JXXJ2_
ZjZg]KC0_ko9bL[BeMKLh>;WkNoPj>cBgN;2dMRaa<fP]/2:YK800WFEY006HHFFCGJ9>FIk:EQ^8e5V
8TiS0R9=H@048TeP8deQ8diQ8diR0RA@H`0A94iQ9DiO9deN:DeM;4iM<4mM=E5M>59M?E9M@E=MA5EM
B5ELBeEKCeIKCeAHCE9EBdiA0096BT`04414B3]0@cDj?Bhd=bT^<R<W:c4c=S`m?dM6B55@DEaIFFIR
HW1[JWYdLhAmNhj6Q1Woool03iRFU:BQX:n][;^i^<O5a=?BdN7Og^k]k?glnoShmnc^kn3Ui]CKg/K@
dkK3b002Y[Nm01nI[;B=Xjb2VZ=lTiamTYZ1UI^6Uif<Vin@WJ6DX:>GXZFJY:JMYjROYjNOY:BOXZ2O
WibPW9VQViJSVIBUUi6VUHfWThZXT8NZSX>YRh2XQgZUPgFLNF^>KV5nHED00VaCB@0@F4DlASL`<BPS
6aPF2P/:00014A0@7ahN;B/[>SPgAdE3De5?GeeKJfQWMgAbPWmm6?ooo`0?OhN7RI2@TYVHW::QYZ^Z
/;Bc^[jla<S6d=?@cm7>blg:al[7aLK4`L?0_Knl00:i^kP07kRi][Vi][bj]/6l]lS2^m38`=O=a=kB
b>GFbn[JcNkMco;OdOKQd_WQdOWOc_SLb_KHa_GD`_CA__?=^_7:]O35/Nk1[>bmYnZiX^NdW>:]U]^V
S/jIP[b:MJMjI`02T6YH011iFDYTBCe<=bhb9AlO5a<E3@/P6QP[9R@e<Blo?3]8AdEADE1IFUUPHf=X
K6a_MGHIoooo00m1G6m3GFi5GFi7GVe9GVa:GV]<GFU=GFM>G6IBGfMIIFaRKGA[MGaeOXB0RHl00XbE
VP0OVJ6VYjnd^;o4a/kBd=[Oen?XgNW_h^kdio?hjoKjk_SllO[nm?_nmO_mm_[lm?Sil_Ceko7ak>c]
j>OWi>;Rh=gMg=SGf=?Ae<g;clS5bL6o`KRe]jjZZZ6NVi>A00:=QhD0481kNW9_KfARHeEEF4Y<CdI9
CDE:D4I=EDIAFDICGDIEHDIGI4EHId=JJD9JJd5KKB3oool001koool03j2HUZRRX;2[Z[Re]<6o_l[:
b]?Ee]kQhn__l^[`lm_TjL_Hg[_;dj^ob9N_^P02PYj/00U_T9mLPY=:LhLgHgT[FFlTDVPRCV<RCV8P
C6000Qm;H00D7daP84eQ7deQ7D]N7TUL84UK8dYK9d]K:daK<4iK=4mK>E5L?U9L@eAMB5INBeILCeIL
D5IJCe=GC51C0TQ<C`0@@dQ;?d=6>3e1<3Lk;C<g<C@g>C`n@dA6CDa>EUEEH5eMJFEULfi]O7IeQWil
ShN46Oooo`0?V9FDXj6O[Zb[^[Rfa/C2d]3>g]cKk>[Xn_Sgno[ilO7aiNSXf=gOc=CG_LS<00:^^l40
7j:b^INZ/HjRZXFJXXBIX8FHWhVIWXnMXI>NXIJQXiRRYI^TYInVYj2VYYjSXYbOWYbLVYfJUijHU:2F
TJ:ESj>CRjF@R:J>QJN<PJJ9OZ>4MiimL9=cIXAWG7AKD002HTe4011??cPm<B`W8QlC4a841PH61PLE
5ADS8R8`;blm>c]9AdIEDe9QGUe/JFQgM7>2OghHoooo00moQXN8SXnAUiNJWinSZ:N//Jne^KRo`/38
blS;cL[9b/O6alC2`l70`Kjl_KX00[Vj]P0O^KVe^[Ve_[^e`kfgc<>kdlW0flk4i=C8j]S;kmc>m=o@
mn7Ann?Bo^?BoN3>n]c:n=O5m]?0mM2mm<bhl/Rdl<B^k[nYjkZTj;FNhk2HfjR@dIf6`8mi[7m/UfmN
00:0Gdl046Y>@E<m<c/[9B@K5a8;2A4;2AlJ62XV9CDb<3lm>dQ7AU1AD5QJFV1SHfM/KFmeMQWoool0
3d5LKT9LKDAKK4EKJTIJJDMIITMHI4MFH4IBFTQDFU5KHUYSJV9[LF]dNWIoQ@02Ph^?01n@Ui^NY:N^
/kFoa<K>e=KIhNCPjNcWl??]m_Sbn_ceoOkho_ojooomooomo_kkno_hmoKel_7ak^g]jNSXhn;SgMcN
f=GIdLkCb/O<`ko4^kJi/:^[XYjMU96>Qh@00X1iM`0@LFa/Hf1PEE=DBDQ:?C`m>CXm?T=8@4Q?@TaE
@TmI@e9N@eAQ@UIU@UQW@EUZ@5]]8?ooo`007_ooo`0?X9RFZ::P/:^Z^;Fd`Knob/[:dmGFg^7Sjnob
j_3cfnCYbmSN^l_CZko8Ujnj00:2WZ`02Fn@Web2TdYcQcMSNB]IKbABJ29>Hb9>HR1<H0027d]P01@O
C60PCF4OCF4MBehNBE`PBE/SBU/WBe/[C5/`CU/dCe/iDE`nDUa3E5e8EUi;EUa?EUa@EUY?DeM<D5<2
B4a?0113B4/o@dHh?D4`=c/]<cLa=3Li?3i3A4I=C4iFEEEPGEeYIFEcKVelMWF6OWb?Qh@Ioooo00nH
UIBSXIn^[:^j^;K6a<;Bd<kNg=_/j^Sjn?Okn_WalO7Uj>SHgMo<e=Nmb<`00Zjk`@0OX[:iUjZaSZ:Z
QIZRQ9VPQIRORIVNSifQTijQUZ6SV::UVjBUWjJWX:JVWZ>RW9nNW9bJWIZGWYRDX9JAXYF?Xi>;YI28
YXj5Yhb1YXUnXhAgWWe`Tg=VQ6MLM5]@009RCD@044lo>3da;2LR7a<C4P@61PH61aDE5B<R8S0_;cdk
>dU7AUECDV5NGFaYJ7MdLh9oOQSoool03gn6QhR>Si6GUiZOWj>XYjba[kFi^;o2`<S;b<_=b/W:alK7
a<;3`L31_[bm^P02^KZf01ni^KFj^KFn^kG3_KO<`k_CbL3Kc/CTe<SZf<__g<kdgm3ghM7khm;nhm;m
h<kjg<[helGfdl3ed;gdc;Sbb;C`a:k^_jW[^ZCX]IkS/9SKZ93AWHK0SgV/OfbGKeh00X1OC`0@JTi1
Dcdc>b/U91/G4P/94@/97aXH:RHU=C8`?cdkB4M6D55@F5YJH6=SIfa]KgEf6Oooo`0?@Ea^@Ua]A5]/
AE]ZAUYYAeUVAeQTAeIPAU9JB5AJDE]RFV=ZHV]aJgAjMWn500:3Rhl07i2GVijTYjjc]Ko4a/kDe]WQ
i>3Yk>O`lngfn?;jo?Gmo_Snoo[ooogooogno__knoSgm_GblO7^kNgYj>SSh^?Mg=kHeMWAc]?:alc3
_lBk][V`Zj^RWYfDTHj7Q002P7Ug011aK6aSH61EDeA9B4Xm?3di>Sdn@dQ0B4m2C5E2CeU3DUi3E652
EVE2F6M1FFY0FfdPoooo000Noooo00nPV9JXXJ2`ZjZh]KC1_ko:b/[DeMGNhN;Zk^o`m_STk>oDgnC4
d]Vda/nR^<<00XjX]00:OIZXK8fMGH6BBg>6?6Mk<Eic:EI[9U9W8DiS7TaQ0Qe;H00C7TaQ7DaQ6d]O
6TQL6dMJ7TMI8TYJ9d]J:daK;deK=TmK?59M@EANAeMOC5QNCeQND5MLD5EICU=F009;Ce8044I;CT97
BSa1ACHl?bld=cTl?d93ATY;C5=BDeaIFVAQHFeYJ7I`KgihMXMoOY27QAWoool03iRETj:PWZf[ZKRf
]<C1`<o=bm_IenSVi?Gbl?kkn_GdlnWZj]gPhM;Hf/C=d002]L3501n[^;bP[kFJZ[2BXjV>X:J<WZ>?
WJ:DX:>FXJ>GXZBIXZBLXjBPYZFPYJBMXJ2JWIbIVYNJUiBKUY:NU8nOTXfPT8RQSHFRRh:RRGjQQGZL
Og>EMV^9K65jHEIZE4/00UQ6?`0@ASTd<b/W7a`K3Pl?00<43@h?6a/K:2LW=3<c@ClnC4Y9F5EDHf1O
KF]YN7EdPh1n6?ooo`0?OXF6QXf>SiFEUifLX:FTZ:f[/KFc^Kfj`LC1bL[7alS5a<G1`L6n_knl_;bh
00:h^;D07kRg/kVg/[ji]<:l]L[2^M;7_]g>`^SEanoIbo?Mc_OOco_Qd?oSd?oQcogMbo_Ia_WE`_OA
__G=^OC9]O;6/No2Zn^lYNRfWn>`VM^YT]6NR<>AO;23KiadHXISE002L595011I@SM2<2T[81/H4@l:
1P@D3`hO71X[:2Le<c8o?Se8B4M@DU5HFe]PI6AWKFe_MGHIoooo00m0Ffe1Ffa2FVY3FFQ3EfE3EV93
Dem2D5Y0C5A2Be99DUQBFV1JHVQUJg1_MGT00WZ0Q@0OQXb@TYRJX:FW/;Ff`LG6cm?Dg>7Rinc]l?Ce
m__knOkno?onooonookloocio_[go?OdnO;`m>gZl>OTk>?Oi]gIgmGAf<g8d<G0a[bf^k2Z[J:MWiB@
ShJ3P7Qe009aJfT0469MG5=@D4E3AC/j?3De>3Hg>cTm@c]3BSe8DCm<ET1?Fd1BGd1DHd1GIT1HJD1J
K23oool001koool03j2HUZRQWk2[ZKRd/l6n_/[9bMCDe=kOh>W[k?CgnNodmmoWk=3KhL3?eZo2b`02
Vk:m01n;YK5kVJI]SIaNPI9@MXQ4K7ljI7PcGW4]F6`WE6TSD6HRCf@SD6DPCfDNCV<MBf0KBUdLB5`P
BU`UBe`ZCEd_CeddD5dkDei2EV19FF5=FV5BFf5CFUiCFEaBEUT00TmCEP0@BdmBB4]>@dM:?D55>ce0
@dA7BT]=DU5BFEQHHEiOJFEULFa[NG=bP7YhR85oT8R56Oooo`0?UiBCXYnM[:VX]kBb`Knmc<[8f=GD
i>7Ol>g[oOWgn_OekNc/h^?Tem[Lbm7C00:kaLP01k6l`:Ve^J>`]9f[/9RWZiNUZIRTY`02VjBV01JK
XjFKXZBMXj>PY:BOXZ:LWinJViZHV9JGU9:HThnKTHfKShZLSHJLRH:MQgnLQ7^IP7JCN6j:L6ImIEa_
FU5OCTH2CT0j010k<blY9B<I61P930d41`PD5AHQ8B4];Bdi>3Q4@d9?CTeJF5MUHV5_K6]iMWF3P7lH
oooo00mnQHJ5S8b=Ti>EViZLXZ6TZJR//:jd]kFk_[_4a/;4aL70`Kjn_[^l_;Rj^[H00[Jf/P0O][B`
^;F`_KRb`K^dakngd<Bkfl^oiM73jmK7l=W9m=_:n=c:o=g:nm_8nMS5mmC1m]6lm<bhl/VdlLJ`k/6[
j[bViKFOh;2IfJRBcin9`Y9m/XEbWWIURFMGLeI9009MAC/044Hd;BlT7a`E4P/81PH40aDB4B4N7B`Z
:CHe=3lo?dQ9BE5CDUQLG61TIFQ]KFmeMQWoool03d1KKD1JJd5HJ45GIT5EHd1CGd1@Fcm<ESe8D3a5
BSm7C4M?E51GG5UPI6AZKP02KgAh01mjOh:7S8jDVI^RYZRa]KK0`lC?dM7KgMgUinO]kngcm?7gmo?i
mo;jmO3jlnkjl^cjl>[gkNKdj>;_hmgYg=KSeLoLc/SBaKo8^kFl[jV^XIbOThj?QH5nMW=_J6D00UmJ
F00@D4a;@Cho=C@d;2//:RX]<38f=3To=cm7>TE=?4UC?DeI?U1M?e=Q?eEU?eQX?eY/8?ooo`007_oo
o`0?X9REZ:6O/:ZX^;>b`;flbLO7dm;BgMgMinWZm?Kgmo[mjNobf^;WbmOM_<_C00:Z_LH02iV_^XZS
[gbHYFf<Ven1TUEhRDeaPTE[O3eUN3IPLc5LL002;5Q/018ZEVXWE6PTDFHRCf<QCF4TCF0XCf0/D60b
DV4gDf0nEV95FF=<G6A@GFADGV=FGF9FG61FFUd2DeMJ011@DeI>D5=;CDm4B4]8BTa=CDmBDUAIEeUO
GEiVHf=]JFUdKfikMGB3O7Z:PX2AR8HIoooo00nGU9:QWYb[Z:Je/[2o_;[9alGDdLoOg=[[j>Ggm?7l
n?OaknkVi^KKgMg@e=D00/;9b`0O^<73/[^n[;JiY[6dXZfaX:Z]XJV[XZRYXJNXWjFVWjBUWj:RX:>R
Wj6PW9jMVYZIUiJDUI:@UY2=Uhj:Uhb7UhZ4UXIoUX=kU7ifT7U`R75YOfUQLUiGI5=<EDM10093>SH0
434/:R4P81@E5@L;30lA4Q/M7BLX:3<c<Shm?DQ7Ae=AD5eKFVMUHg5^KGYgMXB1OaSoool03gf4QHB;
Rh^BTI:HV9VOWZ2UY:N/ZZjb/;Fh][bn^l32_kfn^k^k^;Rh]KJf/P02/[:^01nd/Zjg]:nl]k71^[?7
_[G>`kSGakcOc;kUcl3Xd<7]dl;adl;ce<;cdl3bd;kacK[_bKG]aK7[`ZgY_ZWU^JCQ]9kJ[IODYY7:
WHRoTWn`QWBONFR;JEYfFTeQBCl00TXh<00@<RLQ7QPE3P/90@002@L75aDE8b8Q;Rd/=cPg@D51BD];
DEADFEeMHFEVJ6e^KgIf6Oooo`0??eY/?eUZ?eMW?eET?e=P?U1M?DeH>dUC>DA<=Si5=ci3?TE:AdiB
CeIJEeeQ009RIfX07fmcMWb0PXZ>SiRLWJJZZ[>g][o2`/_<bmGDd]gKf>CQgNWUhN_VhNgVhNoVh?3U
g_3SfnkQfN_NeNKHd>7Bb]W;`m72^lNi/[^]YZfOVYnBSHn4OgieLFeVHeeGE@02CDU8010m>ST`;RdU
8b@O7AhS8R@[;S8`=S`d?4@g@T/iAe4kBeLlCe`mDV0nE6@oEfPoFF/Poooo000Noooo00nPUiFWX9j_
ZJNg/[6o_;_8aLGAd<oKfm[Ui^Kal_;joOkdn?[Tj^kEg^?7dmT00[K5c@0OYk[3UjfgRj>_OIRUL8nM
IXJEGGj>EWR7Cg:3Afam@fUk?FAf>V5d=ema=Ee`<UY];eU[;eMY<EIX=5MW=eQW>eYW@E]WAeiXC5mX
Df5XEV9XFV9WFf5UFf1SFUiP009HFed045EGFUAFF55BEE5BE59CEEIFEeYIFV1NGVERHf]WIg5]K7Qb
LGihMhEmO8^3PI:9QaWoool03iJCTZ2MVjVVY;:_[[bi]lK3`M3=bm[GeNGRgo3]j__fm?Kbl>[XimoO
gmCFe`02bLg>01o1a/Ri_l6e_;j^][RZ/[BY/;6X[ZjWZj^VZZVRYjJTYjJQXj:PXZ6OX9nMWIbJVINF
UI>CTHnCSX^DS8RCRHBBQX6?PWb?OWN;NG:6LfanJfAcHU]WF59ICDQ:@3d00SPc<@0@9bHU71`M3a4B
3a8C6Q`L92DV;bl_>CTi@d92CDa;EUEDH5iMJFMVLW1_NgUgQ8606?ooo`0?O8B4PhZ:RI2@T9JEUYbK
WJ6PXjNVZJf[[k:`]KNe^kbi^[^h]kNd];Ba/k:_00:a/:`07k>a[;Jb[;^e[kjg/<>j/L^n/m;1]]O4
]mc7^Mk7^N?:^^G:^NO:^NO9^>K7]NG3/N6o[MjjZ=bfXmZcWmJ^V]2XU<VPSL6HQ[N?OJ^5M9]hJ8Y[
G7ILCf=<@Tdl=002=R/V010P6QL@3@`100020@4?3`lK6aXV9RH`<C0j>cY2A4A;CDeCEUIJGUiQIVMX
KVm_MWLIoooo00loFV`oF6TnEVHnE6<mDEllCU/jBUHhAU0f@DTb>d8`=S/d>Cdm@TI5BTi>DeH00UQM
G`0OIFU[LGEgOX63Rhj?UiVJY:FT/;2^^KVg`L2nb<K3clc8eM7<fMC?f]G?g=C>g=;<g=39fLg5elW1
dlFmc[nga[N__:jW/ZBNYiVDVHf8RWmkNW5]Jf=PFeECBdI5008k=cL042`Y:R0N7QHC4aLE5R4R9BL[
<2dd>S4k@cA0BSM5D3U:ES]=FcaAGceDI3iGJ3mIJb3oool001koool03j2GUJNOWJjXY[Ja[kjj^<K3
`/o=c=SGen;Rh^g^k_Sjn__mo^kam>3Vj];Kg`02`LkD01nd`lZW^L6L/;V=Y:n0VZIhTYi^RYMVPi5O
OXaFMhMCM8=>Kgm:K7e6JGY4IgQ1IGDoHg<nHG4oHG12HG15HVm8HVm<I6iBIFmFIViJIfiMIfePIfaQ
IVYQI6MPHVD00UiOH@0@FeaNFUYLFEUKFUUKFe]LGUeNHV1PIV=TJfMWL6a[MG1`NgEdPGYiQWmmS8B2
TXZ76Oooo`0?UY>AWY^JYjBR/:f[^KJd`[nmc<S6eM;@gmcIj^KSm?3]n?CbkNWXhn7PfMWH00;?d=00
7lO:b[o3a;c0`KJk_;6f]k6d]:j`/:b^[JZ/ZZJXYjJWYZ>TXj:RX9nNWIfKVYVGUYFCTI:?SI6<RY6:
QXn6PXb2OXUnNHQjMH=dKWa]J7=UGfUMEeeBCDm7@clj>002;bh/010Q8R8E5aPC5AHK7AhT9BH];Rhf
=SHo?cm8B4MAD51JFEQSHF1/JVQdLW1lNWR5PX0Hoooo00mlPhB2RHV8SXj=Ti>CVIRIWYfNXj:TZ:JY
[:Z^/Jnd][>g^;Fc/k2`/:f`[j/00Zn^ZP0O/:fY/JjX]k6[^[>/_kJ^akZ`bk^`ckfadknbeL2bfL6b
fL2af/2`f[j^fK^[e[NWd[>RcjnNc:^JbJJE`j6?_IZ9]I>2[X]kY89cUWMYQVYMMEeBHdm5CSlh>BlZ
008S7Q/0418@3P810@0000/;2aHF5R0Q8BX[:c@e=C`n?TE7Ade@D5AHF5]PH69WJ6U_L6mfMaWoool0
3cmJK3iHJCiEICeCHSa@GSY<FCQ9E3I4CS<oAc0i@2`c>2`b=S8h>c/o@TA8B`02Ce=E01mIG5mSIVQ_
LW=lOWn9RhbEUYJOWijWYjF_[Zbg]K6l^KK0_KW4_k[6`;[7_kW6_KO5^kC3^;70]:fl[jReZJ6^XIZU
VI>LT8ZAQX24NWEeKFUVGeaGDDm7@d8g=3@00RPV9`0@71XK4@d=40`=61PJ828V9R/a:c<j;cY2<cm9
=DA@>4UE>TeJ>e1O?5=S?EIW?UU[8?ooo`007_ooo`0?WiNDYYnL[JNU]Jn]_;Nfa<2oc<[9eM?CgmkM
jNWXm?Geo_oomoWjj^k`gN?V00;?f=`07l7<d[C2bJZj`Ij`^I6V/8VNZ7jEX7N?Vg29UFV3T6=oS5ik
REYgQEIdPUAaP59_OTm/Ndm[NTm[N59/N5E/N5Q]N5]^Mem^Mf9^MF=]LfE]LVM]L6Q/KfQZK6EVJ002
HF9T011OGf5OGf1PGf1QH65SHF9UHfAXIFI/J6U`K6adL6miM7=nN7N3O7^8PGn>QX>CRXPIoooo00nE
TY2MVYRUXZ2]ZZRf/k6n^kW7a<7@c<[IeM?Sgmc]j>KflNk`j^SVh^7MfmX00]CCdP0Oblc<aLO7`/C3
_Kno^;Zj][Nf/K:a/;2^[Jf[ZZZXZ:NUYJBSXj6OWifLViZHV9JDTi6?THj<SXZ7SHN4RX>0QgmlQG]g
PWMbOG5/M6QTJV1LH5MCDda9AD4o=cHd008X:BT041XL7ALI6QlP8BHW9bd^;SDf=Shn?DI5ADi=CEIE
E5iMG6ITHfi/JgIdLWikNXF3PASoool03g^3Ph67R8J<S8^ATI2FUIFJVIZOWYnSXZ>WYJR[ZJb^[;6b
/:j^[:b/ZJ^[Y`02ZZVU01n[ZJB^ZZFb[JNf[jRj/:S0/jW1/jW5]Z[8]j[:]j_<]j[=]jW=]JO;/ZC8
[j75[9g1YiRnXiBiWXneVHZ_ThBWS7jQQGRJOW6@MFR2JUibGU=RD4Q>@C/k<RhY92400QHE500@10D5
00012PX;4a@D7AhN9RLW;c4a>3Xj@492B4];Ce9CEUYJGF9RHfUYJW1aL7Mh6Oooo`0??eY/?UMX?EEU
?59Q>dmM>D]H=dMC=4==<Ce6;SLo:Ble9RX^:B`_<3@g>C`o0091ADL07da?DEMJFf9UIVe_L7UjNX>4
Q8b<S9BDTi^KVJ6QWjNUXZ^XY:jZYZnZYZnZY:jXXZbVWjZRW:JNUj6HTYZARi>9Q8b2OH=jMGUaKFiV
Hf5JF59=Bd8o?S@a<BLV9P0271XK010?30`<2@TC4Q@I6ahP92TU;38Z<c/^>T<b?dXdA50gBEHiCE/k
D5llDf<mEVLnFF/Poooo000Noooo00nOUYBUWY^/YJ>c[J^j]K?1_Kc9a/CBclkJf=SThn;_k^gkno_o
oooemoSXjnd00]_Ph`0Oc]KJ`/cA^/G;[kc3Y;>jVj^cT::ZR9^TPIFNNi2JM8^EL8NAK8>?J7n;I7b8
HWZ6H7N3GgJ2H7F0I7N1I7J0IgN0JgQoKGQnKgMlKgIjL7EhLGAfL79dKVmaKVa^009ZJ6T046AQHVIT
IFMUIVQVIVYWIfaYJFi[Jg5]KGE`L7UcLgegMX5kNHIoOHZ3PHn7Q9B;R1Woool03iBAT9bIUj>PWZ^X
Y[:_[KZg]L:o_<[7a=;?c=_Ge>COgNgXiO3Zj>WTh^3Lf`02f=GC01o@c/g9bLS7a/G2`/6n_K^k^KNe
];:c/Jn_[J^]ZjRYYjBVXj6RX9jNW9ZJV9JGU9>BShj>S8Z:QhF:QH:6P7j3OGZ2NGInM75fKFY]IF5R
FeQGDU1;B4Hn?Cda<S800R@V9`0@6Q`L8R<S:BXZ;c0`=SLg?ShnADE4C4a;E5=BFeYIHV5PJVQWLFm^
N7IdOgakQX>26?ooo`0?Nh:3OhJ7Q8^;RHn?SI>CTYNFUY^JVYjMWZ:PXJFSYJNUYjRVYjRUYZNTYZJR
00:UY:407jJTX:NTX:ZVX:jXXK6YXKF[X[N[X[Z]X[b]X[j]X[j/X;j[WkbYWKZVV[NSUkBPTjnKSj^F
RZB@Q:6<OiZ5NIAoM8iiKXIbJ7]XGfaLE5e@BDa3?C/e<RXX9QTI6@022@/<01010P<92P/B4a@K71dT
9BH/;Rhd=cLl?cm4AdM;CTmBEUIHGEeNI6ATJV]ZLG9`MgPIoooo00lnFF`nEfPlE6DkDV4jCedhBePf
Ae<c@Td`?DH/=ShW;SDP92PM7b8T9RT]<3800SHh>P0O?d93B4]<DEADFUeNI6MWKVm_N7UhOh20QHJ6
Rh^:T8n>Ti6@U9:@UY>AUY>@UI:>Thn;T8b8RhJ2QH1lP7YfNG=_LVaYJVERH5]IE55?B4E4>STh;Rd]
8R4R5ADF008;2``040T82@l>3aDF6A/N8b0V;2D^=BXe?BhkA350BcA5DCI9ESQ=FcY@GcaCI3eFJ3iI
Jb3oool001koool03ijFTjBLVZ^SXK6ZZKRb/;ji^<K1`<g:b=GCdMkLfnSViO;`l?gknoono_Cdm@02
inWZ01oJg^3?eMS7c]6oalbe_lB]^;fS[kJJYjjCXJV=W:B8V9n2Ti]mSiMiRiAeQi1bQ8i`PH]^P8U^
OXMbP8QePHUhPXUjPXQlPHImP8AlOh5jO7iiNW]iN7UeMGIbL7800Vi/KP0@KF][KFY[KV][KV]/L6a/
LVi^M71_MW9aNGAcOGMfP7YiQ7elR85oS8B2T8R5U8^96Oooo`0?U96?ViNFXIjLZ:FS[jbZ][>`_KVg
a<6nc<S5dlo<fmKDh]gJjNCQjnGRi=kK00;KemD07m;?cLc:b<W6a<K3`L6n_;jk^;Vf/kBa[k6^ZjfZ
YjVVY:JSX::OWIjKVIVGUIFCTI2>S8^9R8N4PhF1Oh9nO85lNWmhMGUaKg5ZJ6MRH5aHEU1>CDI5ACTk
>bd`<00292HV010U9RH/;Bdc<c<i>CTo?cm6ATE<C4]CDU5JF5QPGeiWIFA]JfYdLG1jN7J0OWb7Q88H
oooo00mjPX9nQHJ2RHV6SHf:T92>U9>BUiJEVYVIWI^KWijNXInOXZ2PXYnPXInOX9d00YnOW00OWYjK
WijJXYnJYJ2JYZ2JZZ:JZj:I[::I[Z:I[Z6H[J2F[InE[9jCZY^AYiR=XiB:Whn5VHZ0ThAkSWidQWM_
PWA[O6iVLfENIU]EFE1;BdE0>cPe;2/Z7AlO3a8C00851`P040P92A8D51/M7B<U9R/];S<e=SXm?D54
ADQ;C4iBDeAIFEYOH61VIVI/KF]bLg5hNAWoool03ciIK3eGJ3aDIC]BHCU?GCQ;FCE7E3=2CRlmAb`g
?bL_=R4W;1XM81PI6alQ8`02:B/]01la=CHi?Ci1A4E9BdaADe=IFe]QHf=XJVY^L6mcLg=fMWMiNWUl
O7]mOGanOGamO7YkNWQhMWAdLFm/JVMTHUmOGE]IF5IAD4m6ATHm?3dc<c@X:2TL7AhC4a@;2P/00PD2
0P0@20H6414D5aXN728X8RX`9S0h:SI0;Sa7<D5==4IB=TYG>4eL>U1P>eAT?EIX?UU[8?ooo`007_oo
o`0?WYFBXi^IZJ6O[jRV]Jn]^kFd`[fkbLC3d<c;f=CCh=gLjNKUlNo_no[ioO_k00;clO407nGVimWK
gM3De/_?d/C9c;g2aKFk_Z^c^:B]/YjW[9RRZ9>NY8jJX8VEW8JBVH:>UX2<Tgb8T7^6SGf6S7n6SHF:
SXR;SXR9S8R8RhJ5Qh>2Ph1oP7imOGekNgQfMP02MW9c011dLG5dL71dL71eLG1fLG5gLW9iM7=kMWEn
N7N0NWV3OG^7P7j:PX6>QH>ARHJES8TIoooo00nCT8jIUYBOW9ZUXZ2[Z:Jb[Zbh];:n^[S5`Kk;alGB
cL_Hdm3NfMKTg]_Ugm`00]kHe@0OeM7>c/[8bLG3a/;0`knl`;^g^kJc]K6^/ZfZ[JVVZJJRYZ:OXIjL
W9ZGV9JDTi6?Shf;RHN6Q8:0PGmmOWakOg]iO7IeM6m^KVUWIF5OF5IEC4a<@T=3>3Xk;Bl`008/;Bd0
438b<cPh>3dm?D=3@TQ8B4i=CEACDUUHF5mNGFESHf]YJ75_KGIdLgajN89oOXN5PaSoool02gZ1PWf4
QH68R8B;RhR>SX^AT8jCTi6FUIBHUiJJVIRKVP02VIbJ00NIViVIViRHVYNHVYNHVIFIV9BIUi<00Y^H
T`0JWYVBWiRAWYN@WiN?WiJ>WiF=WYB;W9::VHn7UXb4TXR0SXAmRGmhPgUbOGA]N71ZLf]VK6AOHEYF
Ee9>C4Q5?S`j;c0_8R@T5ATI2@`=0PX<3@0@51HF71hO92HW:bh_<SDf>Cdm@4=4ATY:C51ADUMGF5eM
GF9SHVQYIfi^K7=dLGQi6Oooo`0??UY/?EMY?5EU>e9R>DmN=daJ=DQE<d=?<3i9;3U29c8j8RXa7B8V
5APJ51HG008K7R007b@X:Bd`<S@f>3Pk?Ci1@dE8BT]>D59DEEMJFU]NGemRHV9UIFAWIfEWIfEXIfEW
IfAUIF9SHeeOGeQJFe9EETY=Cd=5Ac/m?c<e=b`^<2<U9aXK7Q0A4`L82@8000021082010=3@lC5aXI
7b@O9RdS;CDX<cd[>D<_?TXb@dldAe@fBeThCUdjDF4lE6DmEfPnFF`Poooo000Noooo00nMU9:RVYNW
Wif/YJ>bZjVg/Jnm^;K3_[g:aLCAc<_He=?Og=_Wi>?_k>_hm_D00_Wfm@0Oknc/i>?SfMWJdmCEc]3A
bL_<`/C6^kg0][Rk[k>fZJf`Y:V/WZBXVJ2TUIbPTIRMSiFKRi:GQhjBQXb@Qhb@RhfARhf?S8b>S8^=
S8Z;RHN7QhB4Q861PWmoOGYj009lN7P047]gMWYfMGYeMGYeMG]fMGagMWihMgmjNH9kNXAmO8IoOXV2
P8b4PXn7QI:9QiF<RQWoool03Y:?SYRDTifJV::OWJRTXZfZZ;>_[KRd/[jj^<>o_LW4`/k9am?>c=SC
d0?Nf=D07mOAcLo:alS3`LG0_L:m^/2j][^e/KF`[;6/ZJfXYJVUXJJQWZ6MVYbIUYNDTY6?SXj<RhR6
QX:1P7inOGakNWejN7UeM79^KF]XIf5OGeEEED]<C412@STk>SDe=P02>SXj010n?Si3@T97AdM<C4]A
D51FEEAKFUUPGeiUHf=ZJ6M_KFadLW5iMgInO7Z3P7n8QH@Hoooo00miPH5lPhAoQXN2RHV5Rh^8SXj;
T92=TY:?U9>AUIBBUYFCUiFDUiFDUYFDUY@00Y>ET`0OTY>@TI6>T92<TI2<THn;Thn:TXj9Shb6Sh^5
ShZ4ShZ3ShV2SHN0RXAnQh9kPgehOgYeNWEaMW5]LFiZKFUVJfISI61LFUIDD4i;@T91<cHe9RX[6AlP
4ADF3a8C008H6Q/041lR8bHY:Rd`<C@g>3Xn?T14ADI:Bda@DE5FEUIKG5]PHF1UIVAZJfU_L6edMG9i
NQWoool03ciJK3eGJCaEIS]CHcU@GcQ=FcI9Ec=5DS10C2dkARTe?R@_=QlW;AXO91<F6@024Q@F01lH
6adO8b@V:R`[;c0_<S<d=cPh?3dk@44n@dE2AdU7C4e:Ce1=DE=>DeA?E5E?DeA=DU=<DE=;D5=8CU94
BDe0ADTj?d<c=c/Z;S4P92LF6Qd>4A@620X000430@800PX;3P0@4A@H5adR72D[8B/c9S8k:CM1;Ca7
<45=<dEB=DUG=daK>DmO>U9R?5EV?EMY?UU/8?ooo`007_ooo`0?WIBAXIRFYIfKZZ:P[jNU/jf[^;:`
_[Rf`kjlbLC3cl_9e]7@g=SGhn3NjnOV00?dl>l07^_Wi]oMgMSGemCBdm7@d<_:blC3a;nn`;^j_;Rg
^;>c]:f^/:RYZjBUZ9nQY9bNXIRJWYNHVi:DUiBEUiNEUiREUYRDU9NBTiFATI>>SHf9RHZ6QHR4PhB0
O`:2OGd0481kNgmjNWmjNGmjNH1jNH5kNX9lNhAmO8EoOHN0OhV2P8b4PXj6Q968QY>:R9J=RQWoool0
3i:?SIJCTI^GUYnLVZBQWjVUXjfZZ;:^[;Nc/K^g]L2l^LG0_/W4`/g8a];<b@02e]7>01oFclc?bLG7
`[k1_;Vo^KJm]kBh/jnb[JZ_ZZN[YZ>YXj2UX9fPW9VKV9FFTi6@SXf=RhZ7QXJ5Ph9mOGemO7]lNGQf
Lg=`KVeXIVIOGUiFEUI:C4a2@d=1@D13@T800TI6A@0@BTU9CTe=DU5@EUEDFUUHGUeLHV5PIfETJfUX
Kfe/Lg5`N7EdO7YhP7ilQH:0RHJ46?ooo`0;NH21Nh:3OXF5P8N7PhV9QH^;Qhf=RHn>Ri2@S96ASI:A
00:>TY408hjBT8jAShf?SHf?SH^=RX^<RHR:QXR8QHR7PhR7PXJ5P8B3OX>2OX:0O85oNX5oNGimN7]j
MGQgLgEdLG9bKVe]Jf][J6AUI69SHEiOGEEGETe?CT95ACHj>b`a<QlV9aHK71LJ6adP8@0292LX010[
;Rla=CHg>c`m@D92ATM7C4e<DE9AEUMFFeaJH61OI6ESJFUWKFi[LG9^MGIbNW/Ioooo00lnFV`mF6Xl
EVLkDf@jDF4hCUdfBeTdAeDb@e0_?dX[>D@W=3dS;CDN9R`H7R<00Q4D5`0?418D5QTK720R82@V8bLY
9RT[:2d^;38c;cDg<3Lh<SPj=C`n>3m1>D12>D53008j@DD03SQ0A3M0A3Hn@c<k@2hf>bH_=20W;1PO
8a0E6PX>4P@72P000@810PT:3P8@51T041HM8a`T:b0[<bDa>RPf@B`kAbm0C354DCA7ECI;FCQ>GCU@
H3]CI3aEIceHJCiJK23oool001koool03ibCT:2GU:>KV:NOWJ^TXJnXY[>]ZkRa[kff]L6l^/O1_lc7
aM;=bmSCdMkIe`02i>3N01o]j>K_jNSYhn;MfMSFd]7Bc/k@cLg=bLW9aLG5`L70_;bm^KVk]kNf/[:_
[:bYYjVVY:FRXJ>QWYnKVY^LVY^NVYZNVIVNV9NLUYJJU9>ITY6@Rh^>RHR;QXF9Ph<00XN1P00@QH1o
Q7mnQ7imQ7imQGimQGmmQWmnQh1oRH:0RX>1S8B2SXJ4T8R5TXV7U8^9UXf:6Oooo`0?THj<UI6@VIFC
W9VGX9fKY:6OZ:BR[:RV/:bZ];2]]k>a^kNd_kZh`[jka/6n00;9a<407lg7a<_5`LK0_Knj][^e/[Na
[[>^ZjnZYj^VXjVTXJJQWJ:NVYjJV9^HUIJCTI2>SXb;RHR7QhF4Q7inOWemO7YiN7EcLg1]KFMVIUmO
GeYIF4a=CD];BTi=CE1?C`02DU9A011EE5AHEeMLFeYOGUeRHF1VI6=YJ6M]JfYaKfedLW5hMGAkNGQo
O7^2P7j6Ph::QhDHoooo00YhP81jPX9lPhAnQHJ0QhN2RHV4RXZ6Rh^7SHb8SHd2RHj=00>:SXf9SHb9
S8/00XN;R@0<QHR6P8>1P8:0P89oP85nOgmkNgaiMgUfMWMdMgQdMWMcLgEa0VmbK`0AKW5^Jfi]J6]Z
IFUYHfMVGF5RFemOEUYJCe=CAT];?493<STj;38c82DW82@U9bX[;30a008b=SL043Lk?3a1@D56ATI;
Bd]?D4mDEE=HFEMLGE]QHEmTIF9XJFI/KFU`LFacM71gN7=jNaWoool03ciJKCiHJSeGJ3aDICYBHcU@
GcM=G3E:F3=7E353CbhnBRXiA2Ld?B8^=QdW;@0261lT00l@5AP;3Q0?4aDG71hM8R@N8bDM8R<L8R@M
8bHQ:2XT;2hS;2hR:blU;c@Y=3T00R/f>`0>;3Hl:cHm:SDl:3<j8bhe7BL^5R0V41PM2A4F1@/?0PD7
1@H82`lC4ALM0QLO9P0@72H^8B`e9C8l:3M2;3a8;T1=<DAA<dME=DYI=deL>E1P>U9S>eAU?5IX?EQZ
?UY]8?ooo`007_ooo`0?Vi:?WYFCXIVFY9bJZ:2MZj>Q[ZNU/Z^Y]Zn]^[>a_[Ne`[bja/2oblG3d<[9
00;Fd<h07m_Edn3Jf>GNg>?Lf]WCd]?=blk9b<c6a/W3`lS2`<Fn_L6j^;ff]KZd/[F_[K6[ZZ^VYJNS
XjFQXJ>OWj6NWJ:MW:>MW:>KVZ6JVIfGUYbEUIF?SY6<Rhn9R8f6Q@02RhF300>:Ph:9PX69PX400XV2
P00;RH:1RX>1RhB2S8B3SHF3ShN4T8R6TXV7Th^8UHb9Uhf;01Woool03i2=Ri>@SYJCTIVFU9bIUinL
VZ>OWJJRX:VUXjbXYZn[ZK:^ZkF`[[Nc/KZe/`02_KRe01no^KK0^[O0^[Nn^;Bf/Jfb[:R/Z:FZYJ:W
XZ2VXIjRWYZOViRLVINKV9FFTi2BShj=RhZ9R8R5Q8B1P81mOGejNGUfM7A`KVeZJFUSHV5MG5]GEUEI
F5MKFUULFe/00UmMG@0@HEmOHf9QIVASJ6MVJfUXKVa[LFm^Lg5`MWAcNGMfO7YhOgakPWmnQH:0QhF3
RXN66?ooo`0:N7n0NH61Nh:3OHB4OXF5P8J7PHN8PXR9PhV9Q8Z:0hF:RP0SQHZ9Q8V8PhN6PhN6PHF3
OX:0NgilNGajMgYgMGQeLWIcLGAbL7=aKg9`K71^Jg1^Jg1_K71_J6e]Ifa/IFY[HfQYGfAUFf5QEUeN
DEMIBe1A@dQ9?493=CXk;S8c:Rl`<CHg=S/l>cm0008oA4D044=8BDQ=CDaADDmEEE=HFEILGEYPH5eS
I61VIf=YJVI/KFU_L6abLfieMW5hNG=kO1Woool03cmKKCiIJceGJCaFIc]DICYBHSU@GcM=G3E:FC=7
EC53D2hoC2/kARLf@2<`>@027bXb01lI8RTC6b0>4aL>4aHB6A`F720G7R4G7b8H8B@H8RHH8bLJ9R`N
:S4P;3@P;CHR<3TU<c`V<cdT<CXS;cPQ;CHL:30G8BT@6R0<5AX:41@52@`72`l?5Q/E7B@J92`00QhZ
<`0@8S0j9SE0:CY5;3i:;d9?<DEC<dQG=D]J=deM>51P>U9R>eAU?5IW?EMY?UU[?eY]8?ooo`007_oo
o`0?Vi6>WI>AWiJDXIVFY9^IYYjLZJ6O[:BR[ZNU/JZX]:f[^;6_^kBb_kRf`[bi00;6`;d07l[3`Lk7
a=;;b=O@cMO?c=G<bLo7aLS1_lNo_/Jn_LBk^L2h][be/kZb/;N_[[F]Zk6ZZ:nWYZZTXjRSXJJQX:BP
WZBOWZ:LVjFOWZ>LVibEU9NASiB=S9:;RI29Q`02ShR6012>QhF=QXB=QHB=QHB=QH>=QXB>QXB?QhB?
QhF@R8JARHJBRXNCRhRES8VFSHZGSX/Ioooo00n?S8^BSXfDTHnFTi6IUI>KV9JMVYRPW9ZRWYbTXInV
Xj6YYJ>[YjF]ZJJ_ZZP00[2/Z@08/ZfZ/jj[/jj[]:n[[jZW[:JSZ:BQXinM0Z6MVP0@Wi^HWIVGViNE
V9FCUI6@TXn>SX^;RhV8QXF4Ph:2OgmoNgYjN7MeL6m^KVe/JVQX0VITI003IfETJ6IUJFMV009ZJFP0
46aZJFi/Jg1^KG9`KgAbL7IdLWQfM7YhMWajN7ilNX1nO8:0OXF2P8N4PXV6Q8^8QQSoool02WMoP7R0
PGZ1PW^2Pgb3Q7f4Q7j5QGn6QX26QX27Q`>1QhL08h66QX25QGn4Q7n4Q7f2PW^0OgUmO7EjNFicLV]a
KfabL6]`L6U^KFQ^KFQ_KVU_KfU_KVQ^KFE/K6AZJf1WJEiUIeaSI5UPHUILGU5GF4eBDdA9BSi3A3/o
@3/o@Cm4AD97BDI;C4U?D002CE9C011@EEICFEYFG5eIGf1LHV9NI6EQIfQSJVYVK6eXKVmZLG9/LgA^
MGI`MgQbNGYdO7dIoooo00loFfhnFV`mF6/mEfTlEVLkE6DjDV<iD64gCUhfC5/dBEPbAU@`@e0]?d/Z
>TH00RHf@0048S0j7R/c6BD]4a`S0PdF70094Q`R5R4V5B0U5B4V5b@[6RP_7B/b7B/c7B`e008M;3L0
3Qh]=ah]>1d[=Q`Y<Q/T;ALP:18J80`B5`X@5@lF7ADO9aXV;al/=R<a?08V=T8042TjAb`nBbm2Cc55
Dc=8EcE:FSI=G3Q?GcUAHCYCHc]DICaFIceGJCeHJSiIK3mKKB3oool001koool03iZASY^BSifDTIjE
Tj2GUJ:IUj>KV:FMVZNOWJVQWj^SXJfUXk2XYK:ZZ;B]ZP02]jn]00Rj/Znl];:o]kC1^KK2^KK2^[K5
_;S1^KH2_[Jc01Fm]K>m]K:j/K2d[J^bZZV`Z:J]YZB/YJ>ZXj6WXInVWifTWYbYXZ2TWY^QVYRNUiFK
U9:HTHnFSXbDSH^CRhT00Y::R003THZ8THV7THV700:ARHH2THV700VBRHNBRXNCRXRDRhRDRhVES8VF
SHZGSH^HSX/06Oooo`0?Sh^:T8f;TXj=Ti2>UI:@UY>AV9FCVIJDViRFW9VGWYZIWibJXIfKXYjLXinM
00:TX9h07:FQWjJRWjJRWjJQWZBPWJ>NVj:NVibIUiZGU9^HUYZGUI^GU9VETiFBT9>@Si6>SHj;RXb9
RHV7QXJ4Q8>1P7akNWakNGMeM7IdLgIcLWAbLGAaL09dLW404gEcLWIdLgIdLgMeM7QfMGYgMW]hMgaj
N7ikNWmlNh1nO89oOX>0OhF2P8J3PXN5PhV6Q8Z7QXb9Q`0Hoooo00EgOWmhOh1hP85iPH5jPH800W^2
P`03O8>3O8>4OHB400=mQ8@08gf3Pgb3Pgb2PWb2PW^1P7UoOgMmOGEjNW9gMfmeMFabLfM^KfM]KVQ_
KfM^KVQ^KVU_KfQ_KVQ^KfI]KVA[K69YJV1WJ5iUIe]QHe9IFTmEET]ADdeBE4mDEDmEEU5GF5AJFeIL
GEQNG`02FV5R011MHfAOIFIQIfQRJFYTJfaVKFiXKfmYL75[LW=/LgA^MGI_MgMaN7UbNGYcNgaeO7dI
oooo00loFfdnFVdnFF`nFF/mF6XlEfPlEFLkE6DjDf<iDF4hCelfCEdeBeXcB5LaAE<00Ri2D00@;3m;
:C]79SM28S8m7bhi7B/f6BLb62D`6BLa6RTb6RPa6bXb7Rhf8C4j8c<m8c<o0R8c?`0=8S<n8c<o8C0l
6bPb5B4Y5R4Z6RH`7BXd7bhi8c<n9SM4:Ca8;3m=008^@U004315E398EcA:FSI<G3M>GSQ@HCUBHSYC
I3]DISaFIcaGJ3eHJSiIJciIK3iJKCmKKR3oool001koool03iV@SIZ@SY^ASi^BSibCT9fDTIjETYnF
Tj2GU:6HUJ:IUZ>JV:BKVJFMVZJNV`02Z9nL01nYX9jZXYn[Xj2/Y:6]Y:6]YJ6^YJ6]Y:6/Xj2/Y:2/
Xj2]YJ6_YZ:^YJ6]Y::/Xj6[XYnZXInYXInYXIjWWibQVINPV9FNUYBMU9:KTi6JTHnHT8jGShbFSX^F
SH/00YF=RP:ES8X5UHb90YF<RP>FSHX019N=RiN>RiR>RiR>S1Woool03hj;RHn;RXn<Ri2=Ri6>S9:?
SI:?SY>@SYBASiFBT9JBT9JCTINDTYRDTYRET`02VIFC0iVFU0:IUI<01YRDTYNCTIFBT9BASiFASiB@
S`:ETHl03I:?SI2>SHn<Rhj;RHb:R8^9QhV7QXN4Ph:0OX>1Oh:0Oh9oOX5oO@04PGim01>1Ogf2Ogj2
Ogj2P7j3P7n3PGn4PH25PX25Ph66Ph:7Q8:7QH>8QHB9QXB:QhF:QhJ;R8J<RHN<RHP06?ooo`03MWio
MgioMgn0009hOh0017R0PGV0PGV0PGV0P@9iPH42NX610WV0P@9iP8001gQoOgMnOgImOWElO7AkNg9i
NW5hN@03KgIg0VieMP0:KG=eJG5bJ71bIfi`IVe_IFa^I6]]HVY[H6MXGVEV0V5XJ@07HVQYHVUZHfY[
I6]/IFa]IVe^Ifi_009XKg0046U`LFYaLV]bLfacM6edMFieMVmfMg1gN71hNG5iNW9iNW=jNg=kO7Al
OGElOGEmOQWoool2?e]^00doFfdnFVdnFV`nFF`mFF/mF6XmEfTlEVPkEFLkE6HjDf@iDV<hD6400SM?
G`07=DeM=4]K<TUI<DMF;dED;T=C;D9A00</@E001Ra0Cb/oCRPlBbLjBRHjB2HjA`8V>DL03BDhARDg
A2@f@bLjAbXnBb/oCBa1Cbi3DRm5E357Ec=:FCA<G3I=GP02=dmP00hhD64iDV<jDf@jE6HkEFLlEVPl
EfTmEfXmF6XmFF/nFF`nFV`nFVdoFfd2?e]^8?ooo`00oooooi7oool00?oooonAoooo003oooooTOoo
o`00oooooi7oool004Woool30000F?ooo`<0001Goooo0`0005Soool30000=?ooo`00C?ooo`030000
oooooooo05Soool00`000?ooooooo`1Goooo00<0003oooooool0F?ooo`030000oooooooo037oool0
02_oool500000_ooo`800004oooo0P0000Coool400000_ooo`<00003oooo0`0000?oool20000=?oo
o`@00002oooo100000?oool200001?ooo`@00002oooo0`0000?oool300000oooo`80000coooo1000
00Coool00`000?ooooooo`02oooo0P0000Coool400000_ooo`<00003oooo0`0000?oool20000=Ooo
o`800003oooo1@0000;oool200001?ooo`@00002oooo0`0000?oool300000oooo`80000^oooo000]
oooo00D0003oooooooooool000000_ooo`040000oooooooo00000_ooo`040000oooooooo00000_oo
o`040000oooooooo00001Oooo`040000oooooooo0000>Oooo`030000oooooooo00?oool00`000?oo
ooooo`03oooo00@0003oooooool00002oooo00@0003oooooool00002oooo00<0003oooooool00ooo
o`040000oooooooo0000>?ooo`030000oooooooo00Goool01@000?ooooooooooo`000002oooo00@0
003oooooool00002oooo00@0003oooooool00005oooo00@0003oooooool0000ioooo00@0003ooooo
ool00004oooo00D0003oooooooooool000000_ooo`040000oooooooo00000_ooo`040000oooooooo
00001Oooo`040000oooooooo0000<oooo`00;Oooo`050000oooooooooooo000000;oool010000?oo
ooooo`0000;oool010000?ooooooo`0000;oool00`000?ooooooo`0400000_ooo`040000oooooooo
0000>_ooo`030000oooooooo00?oool00`000?ooooooo`05oooo00@0003oooooool00002oooo00<0
003oooooool0100000;oool010000?ooooooo`0003Woool00`000?ooooooo`04oooo00D0003ooooo
ooooool000000_ooo`040000oooooooo00000_ooo`030000oooooooo00@00002oooo00@0003ooooo
ool0000koooo00<0003oooooool00oooo`030000oooooooo00Coool010000?ooooooo`0000;oool0
0`000?ooooooo`0400000_ooo`040000oooooooo0000<oooo`00;Oooo`030000oooooooo00;oool2
00000oooo`040000oooooooo00000oooo`<00003oooo0P0000Coool40000>_ooo`030000oooooooo
00?oool00`000?ooooooo`02oooo0P0000Coool300000oooo`800004oooo100003Woool00`000?oo
ooooo`04oooo00@0003oooooool00002oooo00@0003oooooooooool300000oooo`800004oooo1000
03_oool00`000?ooooooo`02oooo00<0003oooooool00_ooo`800004oooo0`0000?oool200001?oo
o`@0000boooo000]oooo00D0003oooooooooool000000_ooo`040000oooooooo00000_ooo`030000
oooooooo00?oool00`000?ooooooo`13oooo00@0003oooooool00002oooo00@0003oooooool00003
oooo00<0003oooooool01Oooo`030000oooooooo04;oool010000?ooooooo`0000;oool010000?oo
ooooo`0000;oool010000?ooooooo`0000Goool00`000?ooooooo`13oooo00@0003oooooool00004
oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`0moooo000/oooo0P00
00Coool200001?ooo`800005oooo0P0004Koool200001?ooo`800004oooo0`0000Coool20000AOoo
o`800003oooo100000?oool200001Oooo`800016oooo0P0000Coool200001?ooo`<00004oooo0P00
03ooool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooo
oi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooo
oi7oool00?oooonAoooo000Noooo26M`L`UXL7<00fUaLfU`LfU`LP02JG1b00AYL75YKg1YKViZL743
JG5c00EYLWAYLGAYLGAYLGAYLG<00fQaL`0;J75dJ79eJ79eJG=fJGAgJGEhJWEhJWIiJWMjJWMkJgQl
009/NWh02fimPFaiOF]hNfYgNVYfNFYeN6UeN6UdN6UdMfUcMVQcMP02J79e00=XLWAWLGAWLG<06Ooo
o`04LWEfLWAfLWAfLWAf0g5dM@05LG=eLG=dLG=dLG=dLG9d00=aLW<2LG9b0g5aLP07LG5aLG1aLG1`
LFm_L6e/LG1`LG5a009aLG804g1bLg1aLW1aLW1aLW1`LVmaLVm`LVmaLVmaLfmbM6mcMG1dMW5eN75f
NG9gNW9hNW9jO7AkOWEmP002MWn300MhPhMfOX9eO7mdNgedNWadNG]cNG/00W=hNP=cMgT2LWIh00=b
MWMbMGOoool05oooo`05RH60RH5oR81oR81oR81n00:8Ogh028MoOHMnOHMnOHMnO8MmO8ImO8ImNhIl
N`>6O7X00hIkNXEkNHEkN@02QGYh00B5NGN5N7F6NWR5NWT2QG]i00>5NgZ5NgV5NWT00hAjN@0=PgYi
Q7YjQ7]jQ7akQ7elQGimQWmnQWmoQh20Qh61Qh>3R8B5RHJ600::R8T018b;S8Z7R8Z5QHV4Q0>9Ph<0
0hV3PXV2PXV2P@04RH:100>9PH69PH3oool06?ooo`0;_j>@_j:?_j:?_j:>_j6>_Z6>_Z6=_Z2=_Z2<
_J2<_In<00:mWh/2_9j:0[bNR@:lWHT00k^MR;^LR;^LR003^ib700>kW8RkW8NkW8L00k^LQ`:kVhL2
^Y^70[^KQ`0;^i^8^ib9^ib9^if9^if:_9f:_9j:_9j;_9n<_9n=_J2>00>mXHl00kfQS[fPSKfPS@02
_J2=0kjQS@:nXHh01KnRS[nRSknRSknSSknST00Poooo000Noooo0VM`L`04Ig5cIg1cJ71cJ75c0VQ`
L`05J75cJG5cJG5cJG5cJG5b00AZLG803VYaLf]aLV]aLV]aLVa`LFa`L6a_Kf]]K6a`L6aaLVabM6]b
M6]cM6]bM09ZLW@00f]bM6YcM6YcM@02JW=e00YZM7MZMGQ[MgU[N7]/NGa]NWi]O7m]OH5^Oh=_PHD2
LH:8011bQ8U`PHI_Oh=^OH5]Nh1]NWi/NGe/N7a[N7][MgYZMWUZMGQYM7MXLgIXLWEWLG@Ioooo00Ab
M7IbM7EaM7EaLgD2LG=d0W5bL`9`LG82L71a00=`L71`Kfm`Kfl00g1^KP9`KFd01g1/K71/Jg1[JW1Z
J71XIG1[JG1/K002L6e^00=_KVm_KVi^KFh00fe]KP0=K6e^K6i_KFm`KG5cKW9dKgAgL7IiLGQkLWYm
LgaoM7j2MX66N8F9009jR8h047b;TGV6RWR2QgN0Q7InPWEmP7ElOgEkOWAkOGAjO7AiNg=hNg=hNW=g
NG9fN79fMaSoool02XV1OhR0OhQoOXMoOHMnOHImO8ImNhIlNhEkNXEkN@:4NWP00hAiMh=hMX=hM@02
PgMd01n2MWB2MW>2MG:2M762M721Lfn1LVj2L6b2LVn2Lg62M7:1M7:1MG>1M7>0M79oLg9oLg5oLg9n
Lg9nM7AoMGF0MgN0N7V2NW^2O7b3OWj4Oh25PH:6Q8F8QhV:RX`00Xb>T@06SI2CRh^=RXR:RHN8RHF6
RHF50XR4Q0:8Ph<00hR2PXV2PXV2P@02RH:100>9PH7oooooool05oooo`06_j:?_j6>_Z6=_Z2=_In<
_In;0[bNRP07^if9^ib8^ib7^Y^6^YZ5^IZ5^IV400:hV8<01kRGP[NGPKNFP;NEP;NEOkJEOkJDO`02
]iEo00>fU7nfU7jfU7l00[JDO`0A]Y=n]I=m]I9m]I9m]I9n]I9o]YB0]YF1]iF2]iJ3]iN3]iN4^9R4
^9V5^IZ7^I^9^Yf;00:kWhh00k^PS[^NRk^MRP02^if90[^NRP09_9j:_9j;_9n;_In<_J2<_Z6=_Z6>
_j:?_j>?023oool001koool036M`LfM`LVQ`LfQaLfQ`LVQ`LfU`LfU`LVUaLfYaLVYaLfYaLP=[LG83
K75b0VeaLP9^LG401Fi`L6m_KVm^K6maL6mbLP02KW=d0VedM@9/Lg@03fecM6acM6YdMFYdMVYeMf]f
N6]gNFajO6elOfmnPG20Pg61QG64R7:6RgB8SP02MH^B011eRY1dQhecQHYbPhQaPHI`OhA_OX9^OH5]
Ngm]NWi/N7a[MgYZMWUYM7MXLgIXLW@Ioooo00MbM7IaLgEaLgAaLgAaLW=`LG9`LG400W1`L006Kfm_
Kfi_Kfi^Kfe]Kfa/Kfa[0fi[JP0NKVYYKVUXKVQWKfQUKfITKfERKf=OL6ITKfQWKfYYKfYZKVYZKFYZ
K6YZJfUZK6UZJfUZJVY[Jfa]Jfe_K6maK75cKWAgKgMjLGYmLWb0M823MH>8N8N<NXbB0WjAV@0@OXnF
O8^ANXR=NHF:N8>7Mh65MX23MWn2MGf1MGaoM7]nM7YlM7UkLgQjLgMiLWIh6?ooo`0?R81oR7mnQgim
QWilQWekQGajQG]iQ7UhPgUgPgMePWMePWIdPGEbP7AaP7=`009oLVl03gmaKWi`KGi_Jgi^JWi]JGi/
IgiZIWiYHgi[Igi]JWi^Jgi^K7e^KGe^K7a^K003Nfe]00ekKVikL71lLW9mM7AnMGInMgQoNGZ0O7f1
OX23PX>5QHN7RHb:SI400XfCV00>SI:FRhjARX^=RHR:R8N8R8J7R8F6R8B5R8B4R8>4R8>3R8>2R8:2
RH:20XV2PAWoool03knRSkjQS[jPS;fORkbNR[^NRK^LR;ZKQ[VJQKVIQ;RHP[NGPKNFP;JEOkFDOP02
]I=m00NdTW^cTGZcSgRbSgNbSWJbSGJaSGD00[6<M@:bSGH4/Xeg012aSGRaS7RbS7RbS7RcSGVcSg^d
T7bdTGfdT7fcT7fcTGfcTWjdU82eUH:fUhBgVHL2^Ib;00FiWH^hVXRhVXJhVHJhVXH00[VJQP09^Y^7
^Yb8^if9^if:_9j;_In<_Z2=_Z6>_j:?023oool001koool01FM`LfM`LVQ`LVQaLfU`L`02JG1b00AZ
L79ZLG9[L79[LG82K75b0VeaLP=^LG807VmaLVmbLG1bLG5aLG5aL79`KW5_K79bL79cLg5dM75eMG1e
MFmdMFedM6acLfabLVaaLfYcLf]eMV]fN6]hNVajO6emOfmoPW22QG:4R7B7RgF:SgJ=TWR@U`9jU9`0
47VAV7R>U7J;TGF9SWB6S7>4RG:2Qg60QG1oPfmmPFikOfaiOF]gNfYfNFUdMfQbMAWoool01g9dMG5c
M75bLg1bLg1aLW1`LFm_L002Kfi^00I_KFa^K6a^Jf]^JVY^JFQ]J6L2KFQV011]IfE]IVA]IF=]I69]
Hf1^HUm^HEe^GeY_Hf1_IF=^IVE^IfI]IfM/IfM[IfMZIfL2JVIW00eYJ6QYJV]ZK6i[KW1[L7=/M7M^
N7]`NgmbOh=ePhQgR8ejS9=mTYT00X6HX@0@OiBKOI2GO8bBNXV?NHN<NHF9N8>7Mh:6Mh24MWj2MGf0
MGanM7YmM7UkLgQjLWIh6?ooo`0?R81oQgmmQWelQWekQG]jQ7YhPgUgPWMePGIdPGEbP7AaOg9_OW5^
OVm/OFi[009lKFT07g][J7]ZIWYYI7YWHgYVHGYUH7YTGWYRG7]UH7YWHgYXIGYXIWYYIgUYIgUYJ7UZ
JGYZJGUZJWU[JgU/KGY^KgY`LG]aLg]dMWehNGikOH1nP8:2Q8B6RHJ:SXV?U002S9FJ00j;TYJ:Si:9
S8n8RXb8R8Z8QhV7QXN7QXJ8QHF8Q8F8Q8B8Ph>8Ph:8PX82RH:16Oooo`0?_j:?_Z6=_In<_9j:^if8
^Y^7^IZ5^9V4]iR2]YJ1]IEo]9=m]99k/i1i/Xmh00:aSGH01K2<M:n:LZj9L:j7Kjf6K@02[8E/00>]
QFb]QFf]QFh00Zf6KP05[HI_[XM`[XQb/8Ud/8Ye00:`RWH3/HYf00VaRWNaRgN`RgN`S7R`SGVaSg^b
TGfcTWndU8400kFFP`0?]IJ2]IF1]IF1]IJ1]YN2]iR3]iV4^9V5^IZ6^Yb7^if9_9j:_In<_Z6=_j:?
023oool001koool00fM`LfQ`LVQ`LP02JG1b0VY`LP04Jg1bJg5bK75bK75b0VeaLP05KW5bKg5bKg5a
Kg5aL79a009aLW403G9bLG=bLGAbL7EbKgE`KGEcLGEdM7AeMW=fMW9fMW5fMW1eMVmdM@02KW=d00e]
LgA]MGI]MgU]NGa]O7i^OX5`PhIbQXYdRHegS95iT9IjU9YlUih00WjKX`0@OINONiBKNY6HNHjEMhbB
MXV?MHN<LhB9LX:7LH24Kgj2KW]oK7UmJgMjJWEhJ79e6Oooo`0?LGAeLG=dLG9cL75bL71`Kfm_Kfi^
KVe]KVa[KV]ZKFYYKFUXKFMVK6IUK6ET009/I6807faSHFaRH6aQGVaPGFaOFfeOFVeNF6iLEViPG6iR
GfeSHVeTHfaUI6]UI6YUIFUUIFUTI6UTIFQUIVQXJFUZKFU]KfY`Lf]cMfehO71mPG:1QWJ6RgV<TW^A
V7nGW`02PYbV0120V:1oU9]mT9MlSIAkRi5jR8iiQX]hQ8UhPXMgPHAfOh9eOH1eNgidNWacN7YcMgPH
oooo00n8P7n7OWf6OG^5NgZ4NWR3N7J2MWB1MG9oLg5nLVmmL6elKV]lK6UkJfMjJFD00WUWH`0>N6IQ
MfAOMV9MMV5KMUmJMUiHMUeFMUaEMemJMf5LMf9OMV=PMVAQMVAR0WEUI00?MFEUMFIVMFMWMVUYMf]/
Mfe^N71aN79dNWEgO7YlOGf0P864PhJ:QH^@R96F00:;UY`048ZBUhV?ThR=T8N;SXN9S8N8RXN7R8N6
QhN5QXN5QHN4Q8R3Q8R3PhR3PXR2PXV2PAWoool03knRS[fPS;bORk^MRKZKQkVIQ;NHP[JFPKFDOkBC
O;>AN[:?N;6=MZn;M:j:L@02[HQ_00R/QVf[Q6^ZPVRYP6JXOVBWOF>WOF:WOF<2Z7iT00VXOfFYOfNY
P6RYP6ZZPF^ZPff[Q6n[QG2/QW000jf6L@09[HMa[XMb[HIb[HMc[HUd[XUe[X]f[hei/91l00>aTGd0
3k6@O;6AO;:AO;>BOK>CO[BDOkFEP;JGP[NHPkRIQKZKQk^MRKbNR[fPS;jRSP0Poooo000Noooo00IW
L7=XL7=XL79YL79ZL79ZLG82Jg5b00A/LG9]LG9]LG9^LG42Kg5a029`LG5aLW5aLW5bLW5cLW5dLg5e
Lg5fM79gM79iM75iM71iMG=hMWEgMgIfMgQeN7QdN7QcMgQbMgMaMgM`MWI`MWM_MgQ`NWa`O7iaOh9a
PXEcQXUeRhmgSY=jTYMmUYanVZ61WZH2PJ2X0120WJEoVZ9mUiilU9]kTIMiSYAhRi5fR8idQX]cPhQa
P8E_OX9^Ngm/N7aZMWUXLgHIoooo00maM7EaLW=`LG9`L75_Kfm_KVi^K6a^Jf]]JVU]JFQ/IfI/IVE/
IF=[I65[HV000V]QGP0OJV1MJUmKJUeIJUaHJe]GK5]EKEYEKUYDKUeIKUmLKF5OK69PJf9QJV=RJV=S
JF=SJ6=SIf=SIfAUIfIWJ6U[J6a^JG1cJW=gK7UmKgn3LX>9MXV>NHnFOIFNPIbV00:3WjT0486KY82G
X7nDW7fAV7b>UG^<TWZ9SgZ7S7V5RWR3QgN1Q7IoPWEmP7AkOWAiNg=gNASoool03hQoOXImO8ElNXAj
N8=hMX5fM81dLWmbL7i`KGa^Jg]/JGYZIgUXI7QVHWMTH002MF9N01mdH5]cGUUbG5IbFUAaF59aEe1b
ETmcETmcFE=dFeMcGEUcGU]cGeebGeibH5iaH5maH61aHF5bHf=bI6EbIVMcJFYcK6edKg5fM7EhN7Yk
O7mmPHB0QXZ3S968TiT00XVEW00<R9:GQhnDQhfAQX^?QXZ=QXR;QXN9QXJ8QhJ7QhF6QhB5QhB40XR3
P`03R8:2RH:1oooo01Soool03kjQS[fOS;^MRKZLQkVIQKNGP[JEP;BCOK>ANk:?N;2=MZn;Ljj9LJb7
KZ^4J`02ZH9Y01:XP6JWOF>UNf2TNEfRMUZQM5RQLeNRM5RSMU^SMefTN5jTNEnTNF6TNV:UNV>UNVBV
O6FWOFP2YgmY0ZQoJ@09Z81YZ81ZZH5[ZH5ZZH9/ZHA^ZHE_ZhMb[8]g00:]S7P2[H]f00j^S7J_S7N`
SWRaSgVbTG^cTWfdU7jfUX6gUh>hVHFjVhNkWHVmWh^nXHhPoooo000Noooo00IWL7=XL7=YL79YL79Z
LG9[LG82K75b00I]LG9^LG5^LG5_LG5`LG5aLG43LW9a01mcLW5dLg5fLg5gM75iMG9kMW=mN7EnNGIl
N7IkN7MjNGQiNGUhNGUgNWUfNWYeNGYeNWYdNWYdNg]cO7acOWmcP89dPhIeQXYfRhihSi=kU9UnV9j0
W:>2XJV6YZl00XFU[`0@Q:>[Pj2XPIbTP9VQOYJMO9>INXnFNHbBMhV?MHJ;Lh>8LH24Kgf1KGYnJgMj
JG=f6Oooo`0?LG=eLG9cL75aKfm`Kfi^KVa/KV]ZKFUYK6QWK6IUJfESJfARJV9PJV5NJUmL009YGUX0
46ULF6UKEfUIEFUHDfUGDFYGD6eGD6mJDfiLEfeMFVaNG6aOGV]PGfYPH6UQH6QQH@9WHF803FISI6IU
IVMXJVM[KVQ`LfYdN6ajOFmoQ7:6RgJ;TWZBVWjIXX>Q[002Pj6[0122WZN1VZ>0Uj1oU9anTIUmSiEl
S99kRHmjQhaiQHUhPXMgP8AfOX5eO7mdNWacMgTHoooo00n8Ogj6OG^4NgV3N7N1MWB0M79oLVmmL6el
KFYjJfQiJFEgIV9fI61eHUecGeX00W9MF00=LE]EL5QBKUI?KE=<K55:K4m7KDi6L559LEE?LEMBL5QD
L5UGKeYH009^FUT03fiKFVeKFfeKFfeMGFeOGfiQHViUIVmXJW1/KW9`LWEeMgMjOGYoPWj5RX:<T@03
QY>J0126TIN6SYB5SI65Rhn5RXf5RHb5R8Z6QhV6QXR6QHN7QHJ7Q8B7PhB8Ph>8PX:9PX4Ioooo00nn
XHflWh^kW8RiVXFgV8:fUH2dTgfbTGZaSWN_S7B^RG6/QfjZQ6^YPVRWOfD00ZImHP0CY7YOXWMKXGAH
Wg5DWFi@VfY<VVQ9W6Y<WVmBWg1EWg5GWg9HX7=IX7=JX7=KX7=LX7ALXGAMXGEN00:RMUl02Z9gH:9h
HJ=iHZ=jHZAjHjAkHjAlIJEoJ:N1JZR3KP:XQFl2ZHE^00jZQVn[Qg6/RG>^RgF_SGNaSgZbTGbdTgje
UH6gUh>iVHFjW8RlWh^nXHdPoooo000Noooo00AWL7=XL7=YL79ZLG82Jg5b00A/LG9]LG5^LG5_LG42
L75a00=aLG5bLW5cLW400WAbL@0OMG9aMW=aMg=aNGAaNWEbOWMdQGeiPW]hOgYhOWYhO7YiO7]jNgak
NW]kNGalNGemN7emN7inMgmoMh61N8>4N8J7NHV;NH^>NhnCOIBIOiRNPIfTQJ:ZQjN`RZfh00:9ZkD0
48RY/XJV[hFRZh>OYh6KXgnGWgfDVW^@UWV=TWN9SWF5RW:2QW1nPVikOf]gNfUdMaWoool03g5cMG1b
LW1`LFm^Kfi]KFi[JfeYJFaXIfaVIF]THfYSHFYQGfUOG6UNFVQLF002J5YF01mWFEAWEe9WEE1VE4iV
DTaVDDY`F51aFeA_FeI]G5Q/GEY[GEaZGUeYGUeXGeiWGemVGemVH61UHV9UI6EVIfUWJfiXL7=YMGQ/
NWi_PHIbQhegSYElUIeoW:J4YK000XBS[P0@Pj2[PYfWPIZSP9NPOiFLOY:IOHnEO8bBNhZ?NXN<NHB9
N865MWn3MGf0M7YmLgQj6?ooo`0?QgmmQWakQ7YhPWMeP7EbOg9`OG1]NfeZNVYWN6QTMVEQMF=NLf1K
LUeHL5]E009_F58036eECfaBC6Y?B6U<AFM9@FA4?6]:@Fm@B6iAC6iCCVeDD6aDDP9[EE<04FYEE6YE
EFUEEFUEEVQGEfQIFVQLGFUPHF]TIVaXJVi]Kg5cMGAhNgQnPWb4RGn;T8BBV@02Q96H00^4SiF4SY>4
S964Rhn4RXj4RHb5R8^5QhZ5QhV6QXR6QHH00XN4Q@03R8B4R8>2RH:101Woool03kjQSKbNR[ZKQkRH
PkJFP;BCOK:AN[6>Mjn;M:f9L:^6KJV3JZN0IZImHjAjG`02XWML00bPM5RNLEBLKU2JJT^GIDJCGcjD
H3nIIdRJJDbKJdnKJe6KK542VfaB0Y][DP>KJU8039][Di]/EI]]EYa_EiaaF9ebFIicFimeG:1fGJ5h
H:9jHZ=lI0>TOFD03jEoIjJ0JJR2JjV4KJ^7L:b9Ljj<M[2>NK:ANkBDO[JFP[RIQKZLR;bNR[jQS@0P
oooo000Noooo00YXL7=XL79YL79ZLG9[LG9/LG9]LG9^LG5_LG5`LG42LG5a00=bLW1cLW1dLW000WEb
L00OMg=`N7=`NG=aNWAaNgAaOGEaRH1kQ7eiPGajP7]jOgakOWakOGemOGimO7imNgmnNh1oNh61NhB3
NhN6O8V9O8^<OHj@OY6COiBHPIVNPifSQJ>ZRJVaS:jhSkG000:=/[d048b_^XZ/]XVX/HNT[HFPZ8:L
Y82HWgjDVg^@UWV<TWJ8SGB4RG60Q6mlP6ahO6UdMaWoool03g5cM71aLVm_L6m^KVi/K6eZJFaXIfaV
IF]THVYRH6UPGVUOG6QMFFMKEfMIE@02IUMB01mVEE1UDdiUDD]TCdUSCDITC4AfG5=aFU=_FUE]FUI[
FeQZFeUYG5]XG5]WG5aVG5eUGEeUGUmTHF5TI6EUIfUVK6iWLGAYMWU/Nh1_PXMcR8mgT9MlUj20WjV5
Yk<00XFV/@0@Q:>^Pj2[PYjWPI^TP9RPOiFLOY:IOHnEO8bBNhV>NXJ;N8>7Mh24MWj1M7]mLgQj6?oo
o`0?QgimQG]jPgQgPGIdOg=aOG1^NfeZNFYWN6QTMVEQM69MLUmJL5aGKeUCKEI@009[Dd`07fY@BFQ<
AFI9@VA6?V91>F4o=g1=A6i>AVa?BF]?BVY?C6U@CFQ@CVM@CfI@CfE@D6E?CfA?D6=ADF=CE6AGFFEL
GFIPHVQUIf]ZKFi`Lg5fNGElP7V2Qgb8SX6?UP02PHjE0121SIB2SI:2S962Ri23RXj3RHf4R8b4QhZ5
QhV5QXR6QHN6QHJ7Q8F7Q8B8Ph>9PX4Ioooo00nnX8fkWHViVXFgUh:eU7jcTG^aSWN_RgB]R72[QFfX
PVVVOfFTO66RNEfPMET00YibE@0;W6iAVV]=V6M8UV=3TehmTE/kU5loUfA5UfE7UfE8UfI900>FIDX0
19IUBiISBYERBIEPB0:DGdL02iAQBIETC9EWCYIYD9MZDYU/DiU^E9]_EIa`EYaaEiebF002WgAJ012P
MUbQN5jRNV6TOFBVP6RXPf^ZQFj/R7:^RgF`SWVbTGbdUGngV8>iVhJkWHVmX8dPoooo000Noooo00mX
L7=YL79ZL79[LG9/LG9]LG9^LG5_LG5`LG5aLG5bLG1cLG1dLW1eLW1fLW000WMbL00:N7=`NG=`NW=`
NgA`Ng=`OgIcQ7]hQ7aiPgejPWek0X5nO@0CP7mnP81oOh1oOX20OX61OX>3OXN6OXZ9Ohj=P96API>E
PYJHQ9ZMQYjSQj>XRJN^S:feSk>mT[_600:B^/H0492f`Hjb_Hf^^8ZZ/hRV[XJQZH>MY86HWgjDVW^?
UGR;T7F6Rg>2QW1mPFeiOFYeN1Woool03g5cM71aLFm^Kfi]KFe[JVaYJ6aWIF]THfYRH6UPGVQNFfQL
FFMJEVIHDfEFD@02IEA>01iTDTaTCdUSCDISBdAPB41[D4QdFU9`F59^F5=/F5A[FEIYFEMXFUUWFUYV
FUYUFUYTFUYSFeeSGf1SHfAUJ6YVKFmWLWAYMgY]OH5`Q8UdRY1hTIUlVJ:1X:/3QJVe0125Y[:4Y:j3
XJ^2WZN2VjB1V:1oU9anTIQmSYAlRi5jR8eiQHUhPXEfOX9eNgicN7XHoooo00n7OWf5NgV2N7J0MG9n
LVmlKV]jJfQhJ6AfIF5dHUeaGUY_FeI]F59[E4iZDD/00VQ>A`0OITY3I4LoHT<kHD0gGS/bJDDkLdm5
KDa4JT]5J4Y6IT]7ID]8I4]9Hd]:HT];HDY:H4U:GdY;Gda=GdmAH5AFHEQJHUeOI69TJ6Q[JfiaKgAh
LgYoMX25NXJ<OX^B009nS9<047n<TWn;TX2;TH6:T86:SX:9SH>8S8>8RhB7RXF6RHF6QhJ5QXN4QHN4
Q8R3PhR2PQWoool03kfPS;^MR;VIQKJFP;BBO;6?NJn<MJf9LJZ5KJR2JJIoIJAkHJ5hG9mdF9e`D`02
Vfe?00ZHJDZFIDFDHD2BGCb@FSJFH3fJITBFHT:DH4:CH442TUm200FAGd>AGT>AGD>AG4>@FT400XmI
@00<SeU1SeY1Sea3Sei5T657TF=9TfE;UFM=UVU?UfY?V6Y>V6U=0YUZC@0@VfiBWG5FWWAJX7MNXW]R
YGiVYh9ZZHE^[8Ub[Xaf/Hmj/i=m]YJ1^9V5^if9_J2<8?ooo`007_ooo`0?J71cJG1bJW1bJg5bK75b
KG5aKW5aKg5aL75aLW5`Lg5`M75`MG9`MW9`Mg9`009hLW007gYcL7]cL7acL7edL7meLH5gLh=jMXAl
NHAmNhAnO8AoOX>0P8>1P8:1PH:2PH62PH22PH26QH2:R86>S8:BT8>FUHBHV8JKWHROXHZSYhbW[Hf/
/hna^I:g`IFobP02Ul;>012E_LVC^LBA];n>/;V<ZkB9YZj6XJV4W:>1UiimTYQjSI=gR8edQ8QaOh=]
NWiZMGPIoooo00maLgA`L75_KVi^K6a]JVU/IfI[IFAZHf5YH5iXGU]WG5QVFUIVEe=UEE1TDdd00V=@
BP0OHdi8HTa5HDU2H4HnIda3L5A;L5E=KUE@K5IAJeIBJEICJ5MFIeQGIUQHIEQHI5MHHeMHHUYKHUiO
HV=TI6QZIFi`Ig=eJGQlKGj3LHF:MHbCNI>JO9VRPJ2[Q:Rd00:7[;T048JZ]XFW/hFT[hBQZh>NYh:K
Xh6GWh2DVgj@Ugf=Tg^:SgZ6RgR3QgMoPgElOg=hNaSoool03hMnO8AjNH9gMGmcLGe`KW]]JGQYIWIU
HWARGW5NFVmKEVeGDV]DCVQ@BVI<A@02I4U101mRACeP@CUN?CAK>2iT?cE_BCm/BD1YB45WAd5UAT5S
AT9RAdAPAdEPAdIOATINADIL@dELADMKB4YKBdiLD5=MEUQNFUeQH6=TIVUXK6m/LWI`N7ecOX=gPXUi
Qhh00Wb;T@9mRi403Wj:T7n:T82:Sh69SX:9SH>8S8>7RXB7RHF6R8J5QhJ5QXN4Q8R3PhR2PQWoool0
3kfPS;ZLR;RHPkFEOk>ANk2=Mjf:LZ^6KZR2JZIoIJ=kHJ5gG9icEia_DiU[CP02UfM901nDHdBBGcn@
FcV<EC6BFcRII4:FHD2CGSjAG3f?Fc^>FSZ=FC^=F3^<F3b<Ecb<ESb;E3Z;DSV:DCV:DCZ:DS^:E3b:
Ecj;FD2<G4:=GdB?HTNAHdRCI4RCHdJCHD<00YAR@`0@UVI8V6Y=VViBW79GWgILXGYQY7iUYh9ZZHI^
[8Uc[heg/Y5k]IAo]iR4^Yb8_J2<8?ooo`007_ooo`0?J71cJG1bJW1bJg1bKG5aKW5aKg5aL75aLG5`
LW5`M75`MG5`MW9_Mg9_NG9_009jLVl03G]cKgecKgidKgabKH9gLh=iMHAjMhElNHEmNhInOHJ1OhJ2
PXJ3P`02QH>30124Q8>2PH62Q8>2QhN3Rh^4Shn6UYJ7Vi^:Wj2<XjF>YjZ@Zk2B[kJC];bE^L>G_l/2
V/KB012Ja]>G`<bE^lJB]L2@/;Z=ZkB:YJj7X:R3Vj:0UIalT9IiRXmeQHYbP8A^NgiZMGTIoooo00ma
LW=`L71_KFe]Jf]/JFQ[IVEZI69YHEmXGeaWG5UVFUIUEe=TE51SDTeRCdT00V9=AP0OHD]3HDQ0H4Hm
HdHmKU17KU58KE9;K5==Je=>JE=?J5AAIeIDIUIFIUMGIEIFHeIGHUEFHEUJHEeNHV9THVMXI6i`IW=f
JWYmKX24LXN<MhjDNYBLOIZSPJ2[PjNc00:7[KX048R^^hN[]hJX/hFT[hBQZh>NYh:JXh6GWWnCVWj?
UGb;TG^7S7V4R7N0Q7ElOgAiNaSoool03hImO8AjN85fM7ibL7a_K7U[IgMWHgASGg9OFfmKEVeGDVYC
CVQ@BFE<AF=8@002HD@l01mN@3ML?3=K>2iP>c1[A3UYA3YXA3]UA3eS@ceQ@SaO@SiN@T1M@d5L@d9K
@T9J@T=I@T=HATMHBDYHCDmHDE9IEEMJFE]NGf5QIFQUJfmZLGI^MgaaO85eP8MgQH`00WV8S`0@NXZA
NhZAO8ZAOHZ@OhZ?P8V>PHV=PXR<PhR;Q8N:QHJ9QHJ7QXF6QhB5R8>3R8:26Oooo`0?_In;^Y^7]iR3
]9An/I1i[Xad[8Q`ZHA[YX1VXgaQXGMMWW=HVfmCV6]=UVM800:CHT<02i1N?HiJ>8aE<Y5J=iEO?9=M
>Y5L>XmJ>HeH=h]E=HUC=002R58d00R7DSF7DCJ7DCJ7DcV7ECZ6ECZ6ESb6EC`2QE<j00R5ECb7F3j9
Fd2;GD:=Gd>?H4B@H4>@GT02T5`l012AGCfCHdFFJ4^HK56KLEJNMEbQNV6TOVJWPf^ZQg2]RgF`T7Zc
U7nfUh>jVhNmWh`Poooo000Noooo00mXL7=YL79[L79/L75]LG5^LG5`LG5aLG1bLG1cLG1eLFmfLFmg
LVmhLVmjLVl00W]bK`0<OG=_OW=_P7A_RWagQgYfQWYfQW]hQgaiQgejQgilR860RHB30XV5Q00AR8B4
QhB4QH:2Q821Q8>4Q8F6QHV;R9:DRYZKSJ6QT:JXTZZ]U:jdU[:iU[JnUk[4VL3;00:KaM8049g:ei_6
diW1cINkaYBf`96`^HfZ/XZT[8JNYH:HWgjBV7Z=TWJ7S7>1QVmlOf]fNAWoool03g5bLfm_L6i]KFeZ
JVaWIV]UHfYRH6QOGFMMFVIJEVEGDfADD6=BC69?BF5<AP02H4Y201mOAcmOACaN@SQ]CD=^CdE]D4M/
D4UZD4]YD4]WD4aVDTmVE5=VEEEUEEEUEEISEUMQEeQPFEUQGUmQHF=PI6ISK6iULgEZNge_PXEcR8eh
SiIkUIenVjB0X:^3Yk800XJ/^00@RK6oR:jkQj^gQjRcQZB_QJ6ZQ9fVPYVQPIFLOi6HOHfCO8V>NXF:
N865MWf0M7Uk6?ooo`0?QWelPgUgP7EcOG5^NfeZN6UUMFEQLV1LKeaHKEQCJUA>Ie1:ID]5HTM0Gd<k
009M?cH07e/j<EPf;EDa9f8k;fHo=6E1=fA1>650>Elo>5`m>5Xm>UXo?ETo?ePo?ePo@5M2@UI5AEE8
B5I>CUIADUEADUIDEUMIFe]NHEmUIfAZKFQaMFafNfmkP79oQGB3RP02MXJ>011iRY9iRI5jRI5lRY1m
RY1oRHn0RHj1RHf2R8b3Qh^4QhV5QXR6QHJ7Q8F8Ph>8PX8Ioooo00nmWh^iVhJfUh6cTWb`SWN]RG:Z
QFfWPFRTOF>QN5jNM5VKL5>HJdjEIdRBHT<00XmM?@0<S5PgRU@aQThZR50[SULcSUPeSELeReHeRE@c
QU4`Q4h^Pdd_0X9=<00APThaPe0dPeHjPeXoPei2Q5m4PU]0PEHkP5@iPE<iPU@jQ5LlQUTmR5/oRUe0
S5e0S5`n00:<FS/048eJ>XmL?I5QA9AWBYM/DIYaEiifGJ5kHjF0J:R5KZb9Ljn>N;:BOKJGP[VKQkbO
Rb3oool001koool03fQ`LVU`LV]`LVaaLFiaLFmaLG1aL79aL7=aL7AaKgIaKgMaKgQaKWUbKW]bKP02
OG9^00anLfj0M6j1M6n:O7J9NgJ9NgN9O7R8NgR8O7V8OWb:PH2<QXD2S8N5016>QhJ8P825P822OGf2
OWn3Q8F5QXR8S8j<U9JBX:6DZJZG[JnH/KJI]K^I^<2J^lFK`</00Yg6dP0@X<cIX<gJW/ODVl7=V;_5
UKFnTJngSJR`RJ:YQI^RP9FKO8nDN8V=M8:7Kgb0JgIj6Oooo`0?LG9cKfm_KVa/KFUYJfIUJVARJF5N
J5iKIU]GIEQDI5E@He9=HDm9H4a6GdU2009NASl07ee3>ee0=f93>75@AFi?AVa>AV]?B6U>B6M=B6A=
BFA?CFICDfEDE6=DE6QIFVAHF69JFf1JFemKGEiOHEiRI65YK6=_LVYiO6n3QWF:SWVAUgbGWgjLY82P
ZX:V/@02QJ^g0128/;j9//29[kb8ZkN8Z;>7Y:j6X:V4W:B2V9n0TiYnSiElRi1jQX]hPXIfOX5dNG`H
oooo00n6OG^3N7N0M79lKfeiJfQfIf=cHUi`GUY]FUEZEE1XDD]UC4IRAd5O@c]L?SH00UTj<@0OESD/
E30VFS<WIclcI3hdHShdH3hfGSdfFc/eF3TdESTfES/kEC`lDS`lETA4EdQ7ETa;ETi>ETi?Ddm@DU5B
DeMHDeUKEeeOG6AVHVY]Ig1eJgIkKW^0Kgj4LH:9009cQ8`047F7SgN9TGR9TGZ:TGb:T7j:T7n:Sh69
SX:9SH>8RhB7RXF6R8J5QhN4QHN3Q8R2PQWoool03kbORkVJQKFEP;:ANjn<MJ^7L:R3JjEnIJ9jH9ie
FY]aEIQ/CiEWBI9R@hmM?@02RePg01n8Dc64CBV8D2^=EC6;EC::E3:9E3>7Dc>5D322CBaoBRYnB2Ym
B2]kB2amD3B1FSj3GTB5I4Z5HTV2GD>0Gd=nGTAlFCikDSMmDCJ0DcR3ES^5F3f7Fcj8Fcf9FS`00XUH
>@0@R5DeREHfS5/mSf54TfM;UfeBVg9IWgQOXWeUYX9[ZXMa[Xaf/I5l]IJ1^IZ6_9n;8?ooo`007_oo
o`0?J71bJW1bJg1bKG5aKW1aL75`LG5`Lg5`M75_MG5_Mg5^N75^NG5^NW5]O79]009nLVh07h1cKX5b
K8elMHalMX]lMXYkMXYmNHUkN8QjMhQlNHYoOXf4Q968QhUoOhZ0P8QnOXInOXEoOh=mOX:0PX63Q8>8
RXN>T9:KWIVXZY^`/Ybd^9fh_Ybj`IblaIg1b`02WlKB012QbmRScmfScMVQb=>M`L^I^/BE/kb@[;B<
YJb7WZF2UiinTIIiRXmeQ8Q`OH5[MgXIoooo00m`LW=_KVm^Jf]/JFQ[IFAYHV1XGeeWG5UUFEETEU5S
DdiQCdYPC4INBD9MASh00Ua3>`0OG40gFS`cK4/oL4m4KTi5Jde5JTi8Ida6IDY5HTY6HTe;He5AIeQH
IEQGJ5aLI5YJHUYKH5]KGUUJGEmQGF9TGVIYGfY]J7EiLH:6Mhb@Ni:HOYVPOifUP:2ZPJB`00:4ZKH0
48J__HVc`XZb_h^__8Z/]hVX/XRS[HJOYhBJXX:FWH2AUgf<TW^8S7V3QgMnPGAjO1Soool03hIlNh9h
MWmcL7]^K7QZIWEUHW9PG6iKEf]GDVQBC6E=Af98@Um3?5/n=ePi<@02EC@/01mC<2M?:b5N=b]T?S9R
?C=P?3=N?3EK>SAH>39D=S9C=cEA>CQD@D1GB4MLCTeHCDaFCTeDCDeBC4aBDU=CE5EBEUQAEUQDG5iJ
HfIQJVeUL7EYMW]/NX1]OH=^OhL00W22RP0@LXJ>M8VCMHVBN8VBNhZAOH^AOhZ@P8Z?PXV>PhV<Q8R;
QHN9QXJ7QhF6QhB4R8:26Oooo`0?_9j:^9V5]IAo/Hmi[H]dZXI^YX5XXgaRWgMMW79GVFeAUFQ;TV=5
SehnRePh00:7Dc407hA>:h5:9XA=:HUC<8QC<8MB<8IB<HAA<89?;h1<;Ge::gU7:7Y=;h5K?hAPAH9Q
AX9SB89QAX9RAX9TBX=TBh5QB7iL@GUF>gQA=WaA=WmC>H9F>XAH?8EI?8EH>P02QEDg0XED=@0>QUHh
RU/nSf96TfU>V6mEW7ELX7]SY81YZ8I_[8]e/91j]9F0^9Z5_9j;8?ooo`007_ooo`0?J71bJW1bK71a
KG1aKg5aL75`LW5`Lg5_MG5_MW5^N75^NG5]NW5]Ng5/OG5/009oLVd07h9dKX9cK9>0N8mnMhelMhak
MX]kMhYjMhUiMHQiMXUkNXQmOI27Qhf6QH^4Q8Z4QHV2PhN2Q8J3Q8J8RHF9RhB;Sh><ShRDUiBQXin`
/Z6h^j6k`9nl`ijmaYk1b`02X<KA012Rc=RTd=nVd=jVc]ZSb=:N_lVI]l2C/;R>Z;29XJR4VZ1oTiQj
S95fQHUaOX9/MgXIoooo00m`LG9_KVi]JfY/J6MZI6=YHEmWGU]VFUMUEe=SE4mRD4]PCDMNBD=MASiK
@SX00UXo=P0OFSddFc`bLe13L4m4KTi4Jde5JDe7IT]5HdQ3H4Q5HD]:HDm@JeeLJ5aKIU]KI5]LHEUI
GeUJGEUJGEmQGF5SGFIYGVQ/I79gKWf1N8^?OIBJOi^QP9jVOj2YP:>_00:3Z;D048F^_8Nc`XZc`Hfc
`8j`_8b/]XZW/8RRZhJMYH>HWh6CVGj>Tgb9SWV4R7MoPWAjO1Soool03hElNh9gMGibL7Y]JWMXIG=S
Gg1NFVaIE6UDCfI?BF=:A5m5?Ua0>5Pj<U@d;002D2lV01m?:b9@:R1S?2mS?C5P?39N>c=K>cAH>C=E
=S5A=c=B>SQB?SeKBDMIBDMGB4MEBDQCB4IAAdI?AdM?Bde?CDiADU=CEUMGGF1JHVEOJ6aTKgAXMW]Z
NGm[Nh9[OHD00Vf0R@0@KhB=LHNALhR@MXVBNX^COHbBOh^AP8^@PHZ?PhV=Q8R;QHN:QXJ8QhF6QhB4
R8>26Oooo`0?_9j:^9V4]9An/8mh[8UbZ8A/Y7mVXGUOWGAIVVmCUVY=TfE7Sf11S5XjQe@b00:3CBX0
7gm89H189HA=:XIA;XEA;hAB<H=B<H5@<7m?;ge?<7e@<WiC=7mE=h1F>7mG>GiH>WiH>geG>GeG>WeG
>giG>h1J?H9N@X9M@gaF?GQ?=GY?=GeC=h1E>H5F>X9E>002PU@f0122DS>2DC63DS:5ECR:GD6@IDZE
K5:JLUVNNF2SOVNWQ6f[RG>_SgVcU7nhVHFlWXXPoooo000Noooo00mXL79ZL79/L75]L75_LG5`LG1b
LG1cLFmeLFmfLFihLFiiLFejLFekLFamLF`00WmbK@0OPWA^PW=/Th1hSgigSGagS7]fRg]gRWYgRGUe
R7UfRG]jR7emT8N7SHJ5RhB4RXB5RH:3Qh:4QX>4QXR9QHV;Q8^?Phb?R9BGU:6SWk2bXKRkXK_0Wkc3
W[g6W/7;00:Pa]404:;<f:C@gjK@gZK>fZ?8dYjobIVg`9>`^8jX/8VQZ8BJX7nCV7Z<TGJ5RG5nPVag
NQWoool03g1aLVm^KVe[JVaXIfYTHfUQGfMNFfIJEfEGDf=DCf9@Bf1=Aei9@ee6?U]2>P02FSlf01mJ
?CAK?39cD4=`CdA^CTA[CDEYCDMVBdESB4=PB4EQBdYQCe1[GEaXG5]VFe]TFeaQFEUOFEYMFEYMGf5M
HF=MIVUNJ6aTLWM^OH5hRhmmU9YoVj60WZIoX:V0Xjl00X>X]@0@QJjlQk?2R[?1SK?0S[2lS:bfRZN`
R::[QYfUPiROPI>IOXjCO8V>NHB8Mgn2M7Yl6?ooo`0?QGakPWMeOW9`NVeZMfQULf=OL5iJK5UDJEA?
ITm9HdY4GdDnG40hF3XbE3@/009@;bH07dl[8U0Z86<l;f<m<F0l<Uhk<e/k=5Pi<eDf<E4g<e8j>58n
?E]9AeU9AeM8AeE9B5=8AU57ATm7Adm;CDm=CU5BDe=FEeMMH5YRIEmXK6A_M6QfNfYiOf]kPV]mQ@02
KH29011_Q8eaQi5cR91fRI9jRi=mS99oRi60Ri21RXn3RHf4R8^5QhZ6QXR7QHJ7Q8B8Ph8Ioooo00nl
WXZhVHBdU7j`SgR/RG:XQ6bTOfJQNEnMM5VJKe>FJTfCIDN?H46<FSZ7E3800X==:P0OOdPUP4PUQ4dZ
QU4^QE4_Q58aPe8aPE0`Odl_ODl`OE0bOU<dOeDgP5HhOeLiOUPjOUPkOELiOELjOELkOULkP5XmPUi2
PUe3O5HmN4leNTleOE<gP5DiPEHjPUDh00:2E3H0489B<h9A<H=B<XEE>8YM@I1UBYE/DYYbFIiiH:=n
IjN4KJ^9Ljn?NK>DOkRIQKbNRR3oool001koool03fQ`LVY`LVa`LFi`LFmaL75aL7=aL7AaKgIaKgMa
KWUaKGYaKG]`K7]`Jga`J`02Og5/01n8N7::NG:@OgN@OGN>OGN=OGN=O7N;NWJ9Mg>8N7B7MWF5MWJ;
O7b<PH2<PX:<Q8B;Q8B9QHF9QHJ9RXb8SHn9TIB8TIB9Ui^=WJ6JZZjT^KfT_L6R_/FP_/NP`L/00Z;6
d@0@Y<_GYM3NYm7PZ=3MZ<gGX/C>W;c5Uk>lTJbcS:B[QYbSPIFJO8fBMhJ:LGn3K7Mk6Oooo`0?L75b
KVi^KFYZJfMVJV=QJ61MIeaIIEUEI5EAHU9=HDi8Gd]4GDLoFd<kF3he009D>C007e/l<fI5>GAAAG1?
A6e=A6Y=AFQ<AVE:A697@V5:Af9>C6=BDFUIFFMJFFAIFF=JFV1GF5iHFEaHFUeMH5eQI5iXJemYKF=a
MfQiOWB6RgnFVh6LXX2NYgnOZGnR[P02PJNd0124[K^6//6:]LB>]LBA]L6?/;Z<Z[B:YJj7WjR5VZ62
UI]oSiEmRXmjQHUgOh=eNWdHoooo00n5O7Z1MWEmLFmiK6UeIV=bHEe^G5MZEU9WDDaSC4IPAd1M@CYI
?3AE=Ri@;bH00TTW7@0OBRHLF34UIclbHSdbGS/bFcXbFCXcESTcDcLbDc/gET8oFDU6G4e;Ed]9E4Q7
DTM6Cd=3CD=3C4=4C4M8C4U:CU1BD59EE5UMF5mSGVI[I71eIgIkJ7UoJ7V0J7^3009ZOhL046b3S6j6
T7:9TgJ;UG^>UGf=U7n=Th2<TH6;T8>:SXB9S8F8RXJ6R8N5QXN4Q8R3PQWoool03k^NR[NHPk>COJn=
MjZ7L:J2JJ9lHiigGI]aEYM/D9=WBY1R@heL?HUG=XE@;P02ODHR015h?aV1BBB8DRn5DBn3D2n1Cbn0
D31oD35nDC9oECR1GD25I4R4HdMoG41mFCakESQjDSD00WUA=00<NDlaNDlbNU<eO5DhOUHkOeLlNU8h
N4ldNe4fOE<gOU<gOe<f0WmB=00@Oe4cP50aPE4bQ5DgQe/nSF97TVY?Ug1GW7MNXGeUYH=/ZXQb[Xih
/i=n]iV4^ij:8?ooo`007_ooo`0?JG1bJW1bK71aKW1aL75`LW5`M75`MG5_Mg5^NG5^NW5]Ng5/O71[
O6mZNfeX009iJf@03XAcKI1lMHmmMI1mMY1lMXmmMXmlMXejMH]hLh]jMhenO8amNhemOHenOP:<Ogl0
3h]nOhV0PHV1PhV4QXV8S8^?TX^BUXbGW8jNXYBUZZ6e^JJn`ZBoaJ:oaj71b`02X/KA012UbmNVd=fZ
eN>af>F/dMbVbM>P_lVJ]knD[kJ>YZf9WZF3UiamSiAhQhabOh=/N7/Ioooo00m`LG9^KFe/JFU[IVAY
HV1WGUaVFeQTEe=SE4mQD4YPC4INB45LA3eJ@3QE>S400U0d:P0OGSldLTi2LU14Kdi4K4a4JTe5J4a5
IDY4HTQ3HTa8IE=AIEECIUIFI5MGHeQGHEMGGeIFGEIGG5QJG5aNG65TGVMZHFY_Hg5gJ7UoKh>9OIBI
PIfSP9jWOYjXOZ6]00:0Y[<048>[^HF`_hNc`i>kbIBiaI:d_hn]^8bX/HVRZXJLY8>FWH6AUgj;T7^6
RWR0PgEjOASoool03hElNX1fM7a`KWQZIgAUHG1OFfaIEFQDCfE>BF59@ei4?EXn=eLi<E<c:Th/8`02
B2DK01mC;R=T?31T?S9O>c9L>S9I>S=F>SAD>3=A>3=A>cQD@T1EATAEB4ICBDMBB4M@AdI>ATE;ATE;
AdM:BTY;CTm<DE9?DUEBF5aFGV9LIVYTLGEVMg]VN7iVN7mVNX<00VMmQP0@JX6:Jh>>JhB?MHbENi2G
OHnFOhjEP8fCPXbAPh^?Q8Z=QHR;QXN9QhJ7QhB5R8>36Oooo`0?^if9]YN3/Y5l[HaeZHI^Y7mWX7YP
W7AJV6iCU6U<TFA6SEi0RUTjQeDdQ4l]00:0BRL04h5;9hIB;XID<H=A;h1?<7i?<Ge@<Ga@<W]A=7]C
=WaF>WiK?geM@GaM@7]L@7YK?WUJ?GQI>gQH>`02MeTk00YhESQiE3QkECUmESUnEc]kE3UiDCIjDCIk
DSIlDCD2O54c011lCc9lCRmiBBYmCRn5FCb:H4B@J4fEKUFJMEbONf>TPFZYQg6]SGNbTgjgV8BkWXXP
oooo000Noooo00mYL79[L79]L75_L71aLG1cL6meLFmfLFihLFijLFelLFemLFamL6]mKfUjJfH00WAV
H005NV]VRWQaSgaeTGefTWaf00:AOGH01HmjMHehLhejMY61OY62P002T860016?PH2>PH2=P82<PH6<
PhB<QXR=RXf>SY6@TYNAUY^BVj2DXJNKZk6S^;fU_LBS_lJR`LX00Z?5c`0@YL[EY/kJY]3M]M_W/MGP
Z/cFXl?<WK[3Uk6iTJV`Rj6WQ9RNOi2ENHR=Lh24KGQk6Oooo`0?L75bKVe]K6UXJVESJ65OIeeJIEUF
HeEAHU9<H4i8GdY3GTLoG4<jFSheEST`009E=b`07f91=Vm=@Fi=@Ve=@f]=AFU=AFM=AFE:A699A69<
B6IDDVIFE6EFEFAFEV9GEV1FEUiEEEaEEU]HFE]KGEaPHeiUJF9ZL6EbMfUjP723RWR?UWnJX7nMYWjN
Z7fP[002OjFa0122Z[R3[[f3/L6H`<jG_LVE]l>A/K^>Z[B;Y:f8WZJ5V9n2TYQnS95kQX]hPHAeNgdH
oooo00n4NgZ0MG=kKfegJFIbHem^GEUZEe=VDDaRC4IOAT1K@3UH>c=E=ReB<BQ@;2<00U@^8P0OHCT/
ISlbGc`aG3XaFCXcESXcE3XdDSTdCcTdD3/hDT8oDD=1DDA3CdE4CTE4C4A3BT92B4=2AdE5AdM8B4]<
BDiAC5=FD5]MEV9UG6]_Hg=hIWQmIGQnHgQoHgV2009UO8H046N0RVR2SFV4T7VAVgbBVWjAVH2@Uh6?
UH:=Th><T8B:SXF9S8J7RXN6QhN4QHR3PaWoool03k^MRKJGP[6@Njb:M:N4K:=nIIihGYYaEiE[D95V
BHiP@XYK?8QF=XIC<HIA;`02SEPe00VCGSZ<F3F3DBmoCbmlD31kCc5jCc9iDC=hDSD00WQC=`06Me@g
MeHiMULjMUHjMEHiM5@h1G=D=`09LeHhMUTkNUa0OEm4OEi3NUPmN5<gN54fNE4e009iD3@047Y@<WY>
<GY?<WaA=89G>XQOA8iVC9=]DiUcFiijHZ>0JJR6L:b<M[6BOKJHPk^MRR3oool001koool03fU`LV]`
LVe`LFm`L75aL7=aKgEaKgQaKWYbKWabKGebKGmbK81aJh1`JWm^J002P71Y01n4Lfb<NG6AOGJDOgND
OWNDOGNCOGJBNgF@NWB@NgNCPGjEQX>DQHBCQ8:BPh:APh:@PH6>PX:>QHF?RHZ@S8jAT9>DUIRFVYjG
X:BJYJ^N[K>R]KZT^/6T_LFS`<T00ZC5cP0@Y/WDY/cIYloM^=gX]=SR[/oIYlK?X;g6VKBlTj^bS:>Y
QYZPP9:GNXV>Lh65KGQl6Oooo`0?L75aKVa/JfQWJFARJ61MIUaHI5QDHUA?HE1:H4a6GTQ1GDDmG44h
FchdFSX`009M?C407f92=fU9?Va<@Va=A6Y=AFU=AFM=AVE;AF=:A6=<B6EBCfIGEFEGEV=FEV5FEEmE
EEeDE5]DEEYGF5YKGE]OHeeUJF9/L6IcNF]kPW64RgJ=U7bFWGfJY7fLYWbOZ`02OZB`0120ZKN1[Kb2
/<6J`]2K`<fG^/JD];j@[KN=Yk29X:R6VZ63U9YoSY=lQhaiPHEeNghHoooo00n4NgUoM79jKV]eIfEa
HEi/FeMXEE1SCdUPBD=L@caH?CIE>31C<bYA;RAA:b000U@^8P0OF3<XFSP]FST_F3TaESTcDcTdDCXd
CcTdCSPdCSXgCShlCT4oCD91C491BT51B451AT10A410@d52@dA6A4Q:ADa?BU9FCUUMDf1TFFQ/GVmd
HWEjHWInHGIoHGN1009SNhD046EoRFJ1SFJ3T7VBWGjDWWnCVh2AVH6@UX:>U8>=TXB;ShF:SHJ8RXN6
R8N5QHR3PaWoool03kZMRKFFPK2?NZ^9LZJ2JZ5lHiaeFiM_E99XC8iRAHYL?XMG=hAB<H=?;8==:@02
QDlZ00f5DBn2D2mmCBejC2ehCBmgCS5eCc9eCc=eD3EeDCEcCc=bCS5bCc<00W5A=@0@L54eKe4eKe4d
KTlcKThbKDlcKU0dKe4eLU<hM5HjMUPmN5TmN5LmMe@jMU4gMU0e0WM?=00@N4lcN4lbN4haNe4ePELl
QUi3S6E:TVaBUg9JW7UQXGmXYhE_[8]f/I5l]YN3^if:8?ooo`007_ooo`0?JG1bJg1aKG1aKg1`LW5_
M75_MW5^NG5^Ng9]OG9]P7=]PW=/Pg=/QG=/Qg=[00:9MVl07hekLi5oMiJ1N9N2NYN1NYN0NIMoN9In
MiAlMYAnN9F1OIN7Q9N8QYJ7QIF5Q9>6Q9:4Pi63Pi66QI6:RY:?Si>BU9JGVYVLX9^RYIfW[:2]/j>e
^ZBi_jFl`jBob002YLC=012Ub=:Ub]NTcM^jgn^ig>NadmfZbM>S`<RL][jE[KF>Y:^8W:61TiQjRXmd
PHE]NG`Ioooo00m`L75]K6a[IfIYHf5WGUaUFUMSEU9QDTePCTQOBT=NASmM@cYL@3IL?C9M?2l00Ulo
<`0OHd@iIdToJda2Jdi5JTi6JDi6Ide6IDa5I4Y5Hda8He1=IEIDIEQGHeMFH5EDGUEEG5ADFU=DFEIG
FEYLFf1SGVEYHfeaJ7AjKGf2LHB;MXbDNYBMNiNQNiZUNijZ009mXk0047nX]X2[^gn^_ic3dYk3d9Zm
bIJg`Y>`^XnY/X^RZXNLXhBEVh2?U7f8SGV2QGEkOQSoool03hAjNGidLWU]JWAVHfmOG6YIEFEBCV5<
AUe5@5To>EDi<U8d;50_9Th[84hY7@02Cb/P01mA;RAC<bYE=RiD>35B>39@>3=>>3===c=;=c=;>CI;
?3U;?ci:@3m8?cm7?Si4?Si3?Si0?Ci0?d50@TA1ATY4Bdm9DUI=FEiBH6EGIfaKKG=NLWUOLgaNM7eO
Mh000V5kQ@0@I7j9IH6=IH>@NY>MOYFNP9BMPI>KPY6HPi2FPhjCQ8b@QHZ>QXR;QhN8QhF6R8>36Ooo
o`0?^Yb8]9F0[hihZHM`Y81YWWUQVG9IU6]ASfE9RUi1QUPjPU8cOdd/ODPVO4HS009kAR804GY58WQ6
9GM7:GE8:W=9;79:;W5;;g1<<71<<W1=<Vm=<Fi;;fe:;Ve;<6a;<6];;f]<<002JT`a00aYBc1ZBc5[
CC9]CSA^DCMaE3YcESadESaeECadDcUcD3MdD3H2MU0f011gD3EiD3EiD3AiCc9nE3N4G42:HdV@JU6F
LEVKN62POVNVQ6j[RgF`TGbeUh>jWHTPoooo000Noooo00mYL79[L75]L71`L71bL6meLFigLFijLVim
LVeoLff2Lff5M6f7MFf9MVf<N6l00XmkLP0OTgmgUX=kVHAlVXEmVhEmVh=lVX9kVX5jVGmiV81jV89m
VXN3Vh^8VHV7V8J4UXJ4U8J4ThF3ThN6ThZ:UHn@UY>DVIVKW9nQWjBWX:R/XZfaY;>hYKNmY[_2Y[o7
00:V`l`04:K7dJG9eJ7:f;KLj;gQk;GGhJg<eZG2biji`IN_]Y2V[HVMXh:DVG^;T7F2QViiO1Woool0
3fm`LFe[JfYVIVQRH6IMFfAHEF9DD61@Bem<AUe8@Ee4?5a1>5`n<e`k;ehl<@02H3ld01mTAC]XBd9[
CDA[D4MZD4MXCTMWCDMVC4ITBdISCDQSCdaTE59TF5MREeIPE5ANEEALE5AIDU=HEEMIFEaKH6=NIFUS
KW9XMW]^OXAbQ8aeS9=hTY]iUImjVJ=kWJT00WfR[`0@OjNeP:^jOZbmV<3?X/OEWL7=VK[5UK:mT:^d
S:B/RIfUQIJMPI2EOHV=NH:6MWan6?ooo`0=PgYiOW=aN6aYLVARKEeJJ5IBHdm;GTU3FD8lEC`eDSH^
Cc0XC2/Q009;9Q/2BRLN01m=;2=@<RYB=2e@=S1?=c5==c5;=S9:=S98=S98>3A7>CM7?3]7?ci5?Si3
?Ce1?Ci0?3hm>cdm?D0m@DA0ATY2BTm7DEI;F5iAH6IEIVeIK7=KL7QKLGYKLgeMMX000V1jQ@0@Hgj9
IX:=IX>@N96KOiNPPIJOPYFMPY>JPi6GQ8nDQ8fAQH^?QXV<QhN9QhF6R8>36Oooo`0?^Yb8]9B0[Xeg
Z8I_XWiWW7MNUW1FTFQ>Rf55QUXmPU<eOTd]NTLVMd8OMClK009c?Q`03g8o7G=18G928g139Vi5:6e5
:Fa6:V]7:f]9;F]:;VY:;VU8;6Q7:fQ8;6Q9;P03IdT_00eVBC1VBS1WBS5XBc9YC3A[CcI]DCU_Dcea
ECiaECe`DSU`D3MbD3L00WA@=`0@MU4fNE8gO5<gNe0cO54ePeXoRF98SfYAU71HVWMPWgeWY8A^ZXYe
[i1l]IN3^Yf98?ooo`007_ooo`0?JG1bJg1aKW1`L71_Lg1_MG5^N75]Ng9]OW9]PG=]QGA]R7E]RgM^
SWQ^TWec00:EP7L01YZ6O9b7OYj7Oij8P9n8P9j7O`:NQGd05if3O9b3O9b4OYf8Pij<R9f;R9^9QiV9
QYN8QIF7QIF9QiJ=S9RATIZEUYfKW9nPXj>VZJB[[ZF_/ZJc]jNf_:Rj`JRoaP02Z<?;012Xa]2Vb=BP
amBYdMnhg^ZjgNN_cmRWa<fP^l>I/KRBZ:j;WZB4UIYlS91ePhM^NGdIoooo00m_L75/Jf]ZIFEWH5mT
G5UREe=PDTiNCTQMBD=LACiK@SUK?SEK>c5L>BeN?C400V10=@0OITToJTe4Jdm6Je58JU18JDm8Idi7
ITe7IDe7I4i8HTm;I5=AI5QFHUMFH5EDGEADFe=CF59CEeAFFEYLFf1SGfIZI6icJGIlKgn5LhF=MH^C
MXnHMi>MNINRNibX009mXJh0482W]8:[^X:^_I6kbYo7eJ;7di^mb9Je_i:]]hjV[XZOYXJHWX:AUWj:
SWZ3QWIlOQSoool03h=jN7ebL7MZJ75SH6]KF6EDD61=B5]5@5Hn>E4h<Dha:TX[8dPV74HQ5dDR6@02
AR@K01m:;BE><R]>=2e==Rm;=C19=C18=316=315=354=C=3=cE4>SU4?Ce2?3a0>c/n>S`l>C/j>C/i
>Sdj?d8lA4U0BTm4DEI9F5i>GfICIFeEJW9FKGEGKgQILWaKMGl00UiiQ00@Hgj9Ih>?KHRCNY:LP9RR
PiZSPiNPPiBLPi:IQ92FQ8jBQHb?QXZ<QhN9R8F6R8>36Oooo`0?^I^7/iAo[HafYXA]X7aUVWELTfeC
SFE:R5e1PUHiODh`N4LWM40OL3XIKCLE009[=Q@03F/j6F`m7f/o8FY08VU08fQ19FM19FI19VE3:6E4
:VE5:fA5:fA5:@02Hd@Y011SABYRAB]RAB]QA2]QABaRARiSBC1UBc9WC3AXCSM[DCY/DSa/DCY/D3Q]
CcM_CcH2LDlg011eDCQjE3Z2FSj6Fcj0ECV1F3j9HdV>JE6CL5RHMUnNOFJSPfjYRWF_T7^dUX:jWHTP
oooo000Noooo00mYL79[L75^L71`L6mcL6ifL6eiLFelLFb0LVb3Lfb7M6f;MVf?N6jCO76HPWL00Yb7
O003XH^1Y8^1Xh^200:SRh806Z>:PZ:9PJ:9P::8P:68P:28PZ2:Q:6<R9n<RIj;R9b;R9Z:QiR:QiR;
RIV@SY^DTijIV:6MWZBSY:JYZjR/[jVa]:Vd^:Vh_JZl`Z_0a`:[a<`04:_8dJ[;eJS;eZW?fjgDhK?F
h:o?f:W6cZ:ma9^c^YBY/8fPYHFFVgf=TGJ3QfijOAWoool03fm_L6aZJVUTI6IOGF=JEf5EDEi@Bee;
AU]7@5Y3>eTo=UTk<EXh;E/h;5hm<@02HTDi01mYCTA/D4I/DDQ[DDUZDDUYD4UWCdQVCTQUCTQTCdUS
D4aTE55TEeEREUEOE5AME5AJDU=GDU=FE5IHFUeKH6APIf]TKgAZMge_P8IcQHedRY9eSIIfTIaiUZ5k
VjL00WjQ[P0@PZNdQJfkR;6oT;[9VlGDX/ODW;k:UkK1TjniSjR`Rj2XQiVPPi:GOh^?NX>7MWao6?oo
o`0?PWUhO75_MFUWKf5NJEUFHU5>GDY5Ed8mDS/eCC<]BBdUABHN@QlF@1/B@1dE00939Ad07dP_9dXb
:dXd;DTd;TPc;dHb;T@a;D<a;T8a;d0c<40e=44i>D4k?3lj>cdh>S/h>STf>CHf>CDh?3Lm@SU2Ace9
CT5?EDMGGTaOITmTK55WKe9YLU=[MEI^NEUcOP02GGR3011ROHUXPhm^RIAiTin4WjZ9XJZ4VJ:3UYj3
TiZ4TIN4SY>5S926RXf7R8Z8QXN8Ph@Ioooo00niVhNbTgj[RgFUPfbNNV>GLUZAJU2:HTN4FCimDCAg
BB]b@B5]>1MX<@mU;@`00V@`4@0OI3HHICXKIC`NI3`NHc/OHS/NHC/OH3/PGc`QGcdSGclUH44XH48X
Gd4WGd0VGT0VGSlVGClVGD0WGD4YGD8ZGT@/GdH_HDTcI4`fIDhgITdgId`fJ4/eJD/dJd/d009^CCD0
479>=WMB>GeG?hENAH]VC8]VCHUUC8eYDI9_F9MfGielIZ:3KJR9M:j@NkBFP[ZMRB3oool001koool0
3fU`LV]`LFi`Kg5`KW=`KGI`KGY`K7eaK85bK8EcK8UeK8ifKI=hKIQmLIf3N002Xhb000>VShFXShFX
SX@00ZN>Q0:WSH@06:J=Q:J<Q:F=Q:F=QZF?R:F@RZ>?RJ2<R9j<R9b:QiZ:QiZ<RYbASijFU::KVZBP
WjNUYJZZZj^^/:fb]Jbe^Jfi_Jjm`Zo1a`:_a/`04;3:dK3>e[3?fK;Eh;GKikCGhK7@fZ_8d:BnaYfe
_9J[/HjQYhJGW7n>TWN4R6mjOAWoool03fi_L6]YJFQSHfANG65HEEmCCea>BEY9@eU4?EQ0>5Lk<ULh
;UPe:EXg:ehn<`02IDXo01m/DDM^DTQ]DTU/DTUZDDUYD4UXCdQVCdQUCdUTD4YUDTiTEE9TEeEREUEO
E5AME5AJDE9FDU=FE5IHFUeKHFAPJFaUL7E[N7m_P8IbQHadRI5dS9EfT9YiUJ1lVjL00WnQ[@0@PjNd
R:jlS;;1Tkc;W<OFWLCBVko;V;S3U;6jT:VbS::YR9ZQQ9>HOh^@NhB7MWao6?ooo`0?PWUgNg1^M6QV
KEmMIUMDGdm;FDI2DchjCCLaB2lY@bLQ?b4I?1XB>aTA?1lG0091:B407dL`:DTb;4Lb;DHb;D@a;D8`
;44_;3l^;3h_;Cd`;chc<Shf=chh>S`h>SXg>STg>SHe>3<e>C8g?3@l@CI1Ac]8CSm?EdIGGdUMID]Q
JDeSKDeUL4mXLe=/N5IaO@02FgJ2011PO8QVPhm/QiAeTIenVjN1VjJ2VJ:2UYn3U9^4TIR4SiB5SI66
Rhj7R8Z8QXN8Q8@Ioooo00niVhNaTWfZRWBSPF^LNF6EL5N=Idj6GTAoECYhCC1bA2I[>aaV<a=Q;@iN
;@h00Uh`4@0@H3@EH3HHGcLKGcLKGSHJG3HJFcDIFSDJFCDJFCHLFSPOFSXRFS`SFSdUFchVFchW0UXn
9P0=FChWFClWFD0YFT4[G4@_GTPcH4TdH4TcH4PcHDPbHTLaI4PbITPb009YBC@046e<=G5?>7IB>WaG
?X5L@hAOAhMSBh]XDI1^F9EeGi]kIZ62KJN9M:f?Nk>FP[ZMRB3oool001koool03fU`LV]_L6i_Kg1_
KW=_KGI_K7Y`JgiaJh9bJhIcJh]dJi5gKIMjKiioM:F7N`02Zi2400F^U8R^ThR]TXN/THJ[T8H00j^@
Q`0GZi68Zi:9Zi::ZYB<ZIB>Yi:<Y8n;XHf9WX^7W8^7Vhj;WI:?X9NEY9bKZ::QZjRX[Zf][k6b/;Bf
/KNj/KZn/[k3/l;800:dald04;G;d[K@f;KBf[SIhkcOj[[Li[CDgJk:dZO1b:2g_IR]/i2SZ8RIWH2?
TgN4R6mjOQWoool03fi_KfYXJ6IRHF=LFV1FE5eACEY;AUQ6@5I1>UDl=5@h;U@d:EHc:5Tg;611=P02
JDi301m_E4U`E4]^E4]]DTY[DDUYD4UWCdQWCdUVCdYUDDaVE4mUEe=UF5ISEeIPEEEME5AIDE9EDE9E
E5MGFUeKHFEPJFiVLGI[NGm_OhIaQ8]bQi1dRiAeSiYiU9mlVZH00X2Q[@0@Q:RdRZnmS[?1UKg<W<KF
W/KCW<3=VK[5U[:lTZ^dSZ>[RIbRQIBIP8bANhB8Mgeo6?ooo`0?PGQgNVm^LVITJeeKHeEBG4a8ED<o
Cc/fB38]@bXT?B8K>1XB=AH>=1P@>20H008o:b<07dDa:THa;4Da;4<`;44_:cl]:Sd/:C//:SX/:cX^
;CX`<CXd=C/f>3Xf>CPf>CHe>C<c>30c>30f>c4k@CE1B3U8Cci?Ed9EGDAIHTIMIdQOJTURKD]VLDmZ
MU=_N`02EgF1011MNhMSPHiZQY9bSiaiUj=mV:B0V::1Uj22U9b4TYV4T9F5SY:6Rhn7RH^8QXN8Q8@I
oooo00nhVXJaTWfYRG>QP6VJMenBKUF:I4^3Fd5kDSIcB2a/?R1T=1AM;@aH:`YF:``00UL^3`0@FC0C
FS8EFS<GFC<GF38FEc0EEBlCE2hCDbhEDblFDc4IE3@KECHNESPPESXRES/T0UHk9@05ES`UESdWEShX
Ed0[F48]009I@bh01UY3;UY2;E]2;Ea3;Ui4;f55;`9SAc4046M9<V];=G1>=gEB>WQC>gaG?h9OB8QV
Chi]EiAdGYYjIJ21KJJ8M:f?Nk>FP[VLRB3oool001koool03fU`LF]_L6i_KW1^KG=^K7I^JgY_JWi`
JH9aJHMbJHadJY=fJY]mLZJ6NK2?PP02]YN900FfV8^dUh^bUHZ`U8V_ThP00ZjBR00H[i>9/9B:/IJ<
/9N>/9R?[YNAZiF?Yi:=Y8n:XHb8WX^7WHj;X9>@XiVGYYnMZjFS[jZY/Jn_/k>d];Jh]KVk]Kbo][o3
]l?80[W8cP0@^/gC_=;I_MGM_mgV`>7[_n;/^MOP//gEZl?:XkVoVZndTZBYRYZNPHnCN8F9Kg]n6Ooo
o`0?KVi_JFQXIF5PHE]IGUABFTi:EdQ4ED<mDcdfDCP`D3@ZCblTDS4WF3T^I4Hj009`DdL07g=GC79F
CG1EC6iCBV]ABFU@BFM?B6I?BFI@BfICCVMFDFMHEFMJEfAIEf5GEUeDE5QADUEADUADEeMJGE]RIV1Z
KfIaMfYhOVenQG22RW67SgB:U7J?VGVDWgbJYP02P:2]0125YkB;[[b?/l2F_/fLaMBQb]RN`m2K_<NH
];jD[KF?YJf;WJB6UI^1SI9lQHUgOH0Hoooo00n1N7MiKVeaIF=YG5UQDU1IBDIA@3a:=c=3;RTm9B0f
71H`4``[40X[50hc7aT00Sh[9@0OA34[A34/@c0/@Bl[?RdY>b/Y>BXX=bTY=RXZ=R`/=c0`>3<d>3Dg
>3Hi=SDi<c@h<3<g;S<h;CHk;cY1<T17=TM>>TaE?E5K?eIP@EUT@eaWAF1[B6A`C6QeCfik009DLh00
45YiQV1oS6J3Sfj=VGFCX7bIYGnIXh6GXH:EWH>CVXFAUhF>ThJ<ShN9S8R7R8R4Q1Woool03kRJQ[2A
O:R8LZ1nJ9QeGXm[DhMRBGmH?WI><fi4:6Di75`^3e<T1D/P0TXR1P02CRP<019B;15D;Q=E;a=D;Q=C
;Q9B;A5@:a5>:Q1<:A1<:Q9=;1E>;aQ?<QYA=1eB=b1C>29C>R=B>b@2DS/U00=B?2IC?BQC?BT00U<m
:P06DSdYDcdYE3hZESl[FD4]Fd<^0Ui4;`0@HDD`IDLaJ4PaKD/cLTheN5<kOUa6QFA>Rf]FTW=NV7YU
Wh5/YHQd[8mk/YF2^Ib98?ooo`007_ooo`0?JFmaJfm_KFi]L6e/LfeZMVeYNFiXOVmXPW1XQg5XSG9W
TW=WVga`ZXUk]iB500;2WXl07kjMSkZJSKNHRkBFR[:DRK6CR;6CRK>DR[BFRkJISkNLT[JMU;>LU;2I
TZ^ESjJARj:=R:2<R9n?Rj:DTJFJV:ZQWjjWYK:/ZkFa/KRe]KVi^[Zl_[Zo`K_2aKc5bP02_LW>012o
c]C1e=[2e]g6h>S7hnc5i^nnfn>fd=N^a/bV^l6M/;JDYZZ;Vin2T9AiQXU`NghIoooo00m]KVmXIfMT
H5mOFEMKDTmGBdQDAD5A?cY?>S===2a<;bI::Qi;;RAH>c5XBSh00WQIC00ON5]?MEU>LUM=KeA;Je9:
J519ITm8ITm9IU1;Ie=>JEQCJU]GJEaIIU]JHUQHGEEEF55BE55BDeAGEUYMFV5VH6Y_I75gJGImK7f4
Kh6:LHJ?M8^DMXnINIBOOIZV00:1X:`048JW]8^^^Y2b_iRncIo5e:C>g:76dijnbYZg`9J_]i6W[XbN
YHNFW8:>TWf6RGMmP1Soool03h1gMWQ]K6mTHVIJF5i@CEE6@ddl>DDc;chY9CHP6c0G4RP>228=22LE
4C8P7002@2hX01m3<Ra3<Be1<2`o;R/k;2Th:RPe:2Pc:2Pb:2Tc:R/d;Rlf<C<g=3Lf=CTd=CTb=3P^
<SL[<CLZ=3//>D0_?THbADdeBU<hCUPiDUdlEF4nFFE1GFU4HFi8IW=<JgT00U5aO`0@EgN5G7b:HH6>
JX^HLi:ONibYOYZVP9RRPYJOPiBKQI:HQXnDQhb@QhZ<R8N8RHB46Oooo`0?^9Z6[i1lYhMbWWeWUW=M
SFUBQ5m6NeDkLTX`JD0TH3DIEb/>C245AQh3AAl5009890X02DdY3dl[4E0/4U0/4Tl/4DdZ4DXX44PW
3dHV3P02ARD>00I8:15:;1E=<1Y?=1i@=b5@>282CcPS00E>>2A>>BA>>BE=>BE<>2D00T/g9005C3LT
CSPUD3XWDSdYECl[009H@2`045]2;Ui3;V55;fE6<6]:=7=B?7YJAH5SCHQZEHmbGIIiIIf0K:B7Lj^>
Nk:EP[VLRB3oool001koool03fQ_LFY^Kfa]KFm/Jg9/JGE/J7U/Ige]IX9^IXQ`IXeaIY5bIIMiJjR8
N[ZFQ`02b::A00G4XI6oWHnkVXfgUhZdUHT00[BERP0H]iR=^YZ?_9fA_J2D^j6G^J6H]9jF[YRAZ9:<
Xhf8X8b7X8n;XiBAYYZH[::O/JRV]Jf/^K>b_;Ng_K^k_[no_/73_/C6`<O;0/7;c`0@`loEaMCIamSM
cN;XcnS_c>[b`mkU^m?J//S>ZKg2X;:gUjN/SIbPQ96ENXJ:L7]n6Oooo`0?KFe^IfIVHUiMGEMEF4m=
E4Q5D48mCC/fBSH_BC0XAb/RARLMAbdSEc`bJTe1009oGU007geNDWUKD7EICW1EC6]ABFM?B6A=AfA>
BFI@BfUDCf]JE6aMFF]OG6UNGFAKFUiFEUQBDe=@DU9CEUEJGEQQIUiYKV9`MVIeO6]kPfj1RG25SWB;
U7N?VWZDWgfJYP02PIn/0126Y[>;[;V?/KnJ_L^SbMNXdN2TbMJQ`LbL^L>H/KVCZ;2>X:J9Uif3Si=m
QXYhOX0Hoooo00n0MgIfKF]]HV5TF5IJCD]A@d18>3Ho;R/g924`6aLY4PhS2`LP3P/X5a@d8al00T@b
;00OAC@^@c8^@C4]?Rl/>B/Y=2PW;bDU;B@U;2DW;bPZ<Rh_=C4c=S@g=SLk=3Lk<CDj;C8h:C8g:3@j
:CPo:ce6;T9<<4MA<DYE=4mJ=e=O>EMS?EaX@F1]AFEcBFYh009>Kgd045=ePeQjR5enS6N7UW:CXG^N
ZgjLZ82JY8:HX8BEWHFCVHJ@UHN=THR:SHR7RHV4Q1Woool03kNJQZn@O:J6LIelIYAbG8]XD85MA7MA
>6e6;6@k8E/a5E<Z3ddV34LR24@Q2002AR@;011::0i<:Q1=:a9=;1=;:Q589`i48`Y080Ln7`Ln80U1
8Pa39@m6:199;QQ<<ai>=R82CSPT00e=>2=<>2=:=b=9=R=7=295<b55<R15<b16<b58=B9;=bE>>RM@
>bP00U<m:P0@ESl/F40]FT0]GT4]IDLbKU4lMUU5OV5=QVUESG5MUGQUW81/XhMcZXik/YF2^Ib98?oo
o`007_ooo`0?J6m`JVe^Jfa[KV]YL6YWLfYUMfYTO6]TPVeTR6mUSW5UTgAXVW]][H]l`9V900;?YY@0
7lVSTlBOT;nLS[ZGR[BCQk6AQK6AQ[>CR;ZHS<2MTL:QUKnQUkfSV[VRV[2ITZZCS:B=Qj2;QZ2>RJ>C
T:NJV:fRX;2WYKF]ZkZc/[ni^<6m_<?1`L?3a<;5b<?9c002aLc@0137d=G8e=W:f=g@h>KDj^oBkOC9
hNO0e]^fb]2]_lBS];RIZJf?WJ65TYIkQhYaNghIoooo00m/KFiVIFEPGEaKEE=ECDY@AD9;?SY8=c95
<B]4;2A3:1i39ai3:b=G?SA_DDD00XISE00OPV9DOEiBN5]ALUI=Je5:ITi7HTa7HDe8I51;JeI@L5aG
KeiJKV5NKFARIUiMGUQHEe9CDU1BDE=EDeQLEUmUG6Q^GfidHg=kJ7V1KH28L8F>MXbEN92JNYBOOIVU
00:1Wj`048JU/h^[^8n`_YbnbjS<fJcEhjS<f:C4cinkaI^c^iFZ/I2QZ8ZIWXB@U7j7RWQnP1Soool0
3gmfMGE/JV]QGf5FE5M;BDe0?T<d<STY9c0O72TE4R8=2Ad91QP:228G53DV8P02B3H`01m7=S55=C12
<c0n<2hi;B/d:RT_9bP[9RP[9RT_:R`c<38e<SDf=STh>She>Cha=c`/<cTX<SPV<cXV=clW>dD[@D//
AE0^B5@`C5PbD5deE64kFVLoGfe2Hg96J7L00TY]O00@D7>2E7R7FWf<IhVHM9JUO:2_OijZPI^VPiVR
Q9JNQYBJQi6FQhjBR8^=R8R9RHF56Oooo`0?]iV6[Y1kYHIaW7aVTg5KRFI?OUY3LdhfJ48YGSHLEB`A
CBD;A208?ah7@B4900959@d07dPX44XZ4T`/54`]5D`]5TX/5DLY4d8V4C`R3C/R33hT3T4V4D@W4TP]
64/d84dh94di9T`i9T/h9DTg94Le8TDc8D@c8D<a844_7Sl]740^7D<a7dHd8TTf94/h9P02CCXX011@
?2YC?RaF@2iL@c9SBCM[D3icFDIkH4f3J5F;L5fCN6FKOfbRQgBZSW^aUH:hW8TPoooo000Noooo00mX
KW1YKFeZJfY/JFM^J6EaIf=dIf5iJ660Jf:9KfBALVFEMVZGNVf[RG[1VXT00]>YUP0OcJFCaj2@`Yf>
_9R:]Y>6[hj1Zh^0YhYo[Xn4]iJ:_I^@_I^A^IbC]YfE/9RAZY:;Y8b5X8Z4Whf7XY>>YYVF[jBQ/JRU
]jj/_[Fca;bjaKnnb<?2alK6a/S9aL[<00;7cM404<[AeLcEfLoJg]SSim_[l=S_m<kSjLGHgK_=d[31
aZJf^YbZ[Y6NXXJCUWb7RW5lOaWoool03f]/KFETI5iKFUQCDE9:B4a1?THi=D4b;Ch[9ChW840U744X
844]9EU0=WADB002S6QH01n6IEN0H5EkGE9dF4m]DdaVCTQSCDQMBdMRCd]/Ee5aGUUcH5]bI65_IVAW
H5mOFEUGDU=ACe5?DEA@Ee]BFf9KJ6iLJg9OL7UUMgm]P8QaQXigS9EiTI]kUJ1lVJD00X6O[00@QZFb
RJZhT;6oX<3=[LkK/MSU[<oJZ<KAXkk7W[FmV:bcTZ>YS9ZOQI6EOhN;N7j16?ooo`0?OgIeM6]ZJV1N
GeACE4Q7BC`k?S0_<b@R:1PF80l<70P56@T760d;9a`I>R/W009=>S@07dXj=4Lg<d<e<Slc<C/`;cL]
;SH];c4/;S8];cPb=3/h>Sdk?Cm0@ce2ASLm@S4i?b/d>RLa>B@b>R@e?b<g@RLoBRI1CBI3D2Q7E2i=
Fc9CHCUIIcaMK41RLD=WMP02B6al011=LH5@MHIFNhaURIUdV:MmXk5oX:b2WJR4VZB5V:27UI^8TYN8
Si>9S8j9R8Z9QHDIoooo00ngVHJ^T7^UQW6LNfJBLE^7IDmlFD9`Bc=S?BAG<1I>9Pe88`U690a590i4
90h00THW400OB2XDBB`EBRdGBbhIC30LCS<OD3DQCc@PBc8MB34LAc4NBC@QCCPUCSXWCCTVCCXXC3/Y
C3XXBSTWB3HUAC8R@S0O?blN>b/J>2PH>2TI>b`K?RhM@C0OAC<RB3HU009:>2L044`i:Ddj:Tll;5E2
<Ui:>VMA@71HAWQPCX5XEHU_GI9gIIYoK:66M:V>Nk6EP[RLRB3oool001koool03fM^L6Q/K6UYJFYW
IV]UHVeTH71SGGETGGeWGXU^Hi]kKIalKYenLJf;O<BKR@02ej^G01o@YiC:XY74WXjoVX^iUHRbSX6]
RgnUQgbTQgbYRh2`TXRfUXbfVHndVY6_UhnZTXZTS8FORH>MRXFNShZOTXnWWIZ/XYncZJNo];33^[O7
_kg<a/?;b<O9b/[6b/`00/S=d00@bm7DcMGIe=_OgnOZiO3cgo;fe>O[b]_O_m3C]<C7ZKRkWZb_Tj2S
R9BGOHR;LWao6Oooo`0?Jfa]Hf=SG5UIEE1?CTM5Acdk@3@a>R/W=B@N=1hH@BLO@b`TAS4YFT8iMeM:
00:AK5`07hYXFXASEgeOE7MKDW5GCfYBBfI@BV1=B6AAC6YGDG1NFGARGG=UHFiUHVMPGeiIFEMBDe1?
DDe@DdiEFTmJH5IUK5IWKeQ/MFEgOfb0R725SGR=UW^AVgfFXGfJYP02P9j[0124Xk67Z;J@/KnT`/nc
d]jff^J`dMf/bM>W`<VQ]knK[[FDYJ^>Vj27TYJ0R8]iOh4Hoooo00mnMWEcJVUXGUeMDe5AATE5>SPi
;2/[7QdN40lA0P4D108E2@TH40lX7Q`m;RX00U0n>00OCC`gBCXfACLe@CDd?C<c>S8b>C4c=c4c?CLh
@S`lA411AD=4@TA7?D=7=cm4<CTo:c@j9S8i93<l93M093Y69d9>8T1>7d1?:4MF;DiM;e5P=eQW>ee/
@69a@VMg0096Jg`044U_P4]cQ59jS6B:VWFIZ7jS/H2Q[H>NZHFLYHNIXHRFWHVCV8V@U8V<ShV9RXV5
QAWoool03kNIQJj@NjF6LI]lIi5aFhMUCg]I@Ve:<Udh84/S2D4J044O1d8S34<U44@W4P02ABTD0157
:aI9;AQ:;QY:;a]<<Qi>=RAA>BME?B]J@c1JA35G@RiD@BiA@2i??Ba>?2Y=>bY<>bX00T`k:`0<Bc/[
BS`/AcX[@3<V>B`O=bXL>B/M=bXK>BXL?RhN@S4QASDV0TPh:098>2T03TTj:dhn;eQ6=f=??VaFAGIN
CGmWEHQ_GI1gIIUoKJ66M:V>Nk2EP[RLRB3oool001koool03fM]KfM[JfMWIfMUHfQRGfUPG6]NF6iM
EWEOEh=XGIUhJZF2M:R5M[F@OlNMR`02fJbH01oBZ9G<Xi;6WXg1W8blV8ZfTXB`S7n[RGb[RGf/S82`
T8BdUHVeUhfcUhj_UHfYT8VSRhBORH:LRH>LS8RNT8jOUiFOVIRQWIfbZjRh/k6l^;K5`;k6`l;6a/K5
b<X00/O<cP0@b/oBcMCGf=kPi>W[k?GgioOkfn_^d=oRa=;E^<K9[KVlXJf`UJ6TRIBGOXR;LWao6Ooo
o`0?JV]/HV9RFUQGDTi=BTA2@STg>Bl/<B@P9aPD;1TC?RPPAS4XBcL_HDPmO5]=00:EKel07hiZG8MV
FWmPEGUNE7AKDfiFCfUBC6IAC6MCCV]HDVmMF79RGW5THFaSHFIOGeiHFEIBDe1?DDe@DdeEFTmJHE9R
JU9TKE9WLFAfOVUnQVj3S7V=UG^BVgfFXGbIYP02OYf[0121XJn3YKFB//2Wa=2ieN2kgNVfeMnac=J[
`lbU^/6N/;NGYjb@WJ68TiN1RHaiOh4Hoooo00mnMWEbJVUWGUeKDU5?ADA2=cHd:BPU6ATA1PH;000B
1`HB2`/G4A8Z8Am1<Rd00UE2?00OD40kC3djASPg@SLf?cHg?3Df>SDf>SDh?3Pj@3dn@d54A4E7@DE9
?4=8=cm5<3Y0:S@l9S<k8c@m93Q29Sa8:49>:4=@9dEC<DiK<e9P=UIT?Ue[@F5`@fIf@VQi0093Jg`0
44E^P4E`Pe5jS6F:VWNIZ7nS/X:R[hFPZhNNYhVKXhZHWXZEVXZAUHZ=T8Z9RhZ5QQWoool03kNJQZjA
OJF7LiamJI9bGHMWDG]JA6e;=5Te74/W3T0O23TJ13XN2D0T3dDY5002B2`G01Y9;AU9;aa:;ae:;ae;
<R5==bI@>b]C?c1E@S9FA3AFACIDA3AB@S=?@35>?Ri=?Be<?2e<?Bi<?Rm<?c1=@31=?c1=?Rm;?2i7
>B]4=RP2A3DW00=6=bU7>2]7>2X00THh:P0@ACPZA3HXACLZC3d_ED8cGTXjJEA4Lee=OFIEQVmNSgMV
V7m]X8MeZ8il/9F3^9b98?ooo`007_ooo`0?IVa^IFUZIFEUI69PI5mLI5]GI5QCIEA>I4m7MeiERV]P
W7Y]YhAe^960b9j;00;J[IP07mBYU/jTT/NMSL6IRKfGR;ZEQkJAPk>>P;:=Ok>?P[FBQKNERKNHS;>E
RjjCRZV?Qj>;Pij9PYb8PYb=QijASJ6FU9nHUi^HV::OWjZXZ;6`[kZh]knn_L;3`lC6a`02aL[<0138
c]3;dMCJg^3Wj^_`mOK]nogRko7Fh^C9eMNlb<^`^kjS[[6GXZB;UIQoRH]cO7lIoooo00mYJfaQHF5H
EUI?C4]6@Clm=S@c:RLX7AXK3PXY6A@g91i6<RYA?3=YCD61Ge400YQaH@0OTVeORVUMPV=INf1FMUaD
LEYBK5I@JUA?JUI@KEYDL5iHLF9MLFAQJf9PIEiMGEQHEU9CCe1BC51CC5AICeYQDV5YDVA]DfQbGg9k
IWZ3K8:;MX^DN92JNIBPNYNT009jVjT047fO[GnS/YBd`J_6dKgFh<7RkKcIhkK@fK37cZVma::c^IZY
[Y:NXhZDV8::SGYoPQSoool03gefMG9ZJFIMG5U@D4e3@clf=C4W9b4G5`l51A4821D=31XD520J6S@X
9DLg<P02F4Do01mC@ci?@Ce:?Sa6?Ca1>CXm=cPj=CPh=STi>3/m?D0o@4=0@dHoADXk@dTf?dH`>D0Z
=CdU=3dS=3hS=d<T?4PW@DhYAE8^BUPhDf0kEf@nFfU3HFm3I7=1IWI0IgT00T1ZO00@@6ao@Fj2DWb>
J8bLNI^YPJJeQ:BaQj>]RJ2YRifUS9ZPS9JKS9:FRhjARhZ;RXJ66Oooo`0?]i^8[Y9nYXQdW7mZTgAP
R6YEOEi8LE4kHd</EcPQCC4KABXF@RPDAB/FBBdJ0099;Q/02dX`7DXb7d`f94dh:4/f9DXe9D/h:4`k
;Dho<Dm1<e12=002Cd4d019?@SA>@35=?Bm<?Bi<?S1<?S9;?S9;?S5;?c5>@C=DASQHBCYDACMB@SA?
@C=<?S58>bm6>Rh2ACT]0113=b]2=b]5>Be<?S5D@cELBS]VDdAaG4ekIUJ5Kej?MfNHOfjPQgFXSWb`
UH>hW8XPoooo000Noooo00mUK6iTJ6QSHf=RGeiPFeQOEU=NDTeLC4IHACi/EDb1IEZCLfJSP7:gSgk:
WX/00]^/U`0Of:^Gd:JCbZ2?`YV9^Y>3]Xn1/Xeo/8Yl[8Mi[8Qk[X]m/Hj2/Y:6/I:8[I67ZHj5Y8^3
WhV1VhN1Vh^4Wi:<XiRCY9ZHY9jLYj6PZJJU[jb/^;Bc_;Zj`<30`/C400;5b<T04<K<c/_AdmcNgn_[
j_3blo?mo^Wcm=cVilkHf/3:c;>m_jJ`/YVSYHbFV7n9S7=mOaWoool03fUZJf1PH5IEEDe:BD<n?CTb
<BhV928H5A@91R8F4C<S7D@a:EHn=Vi@AHERE002VW=R01nELF:=K626J5enHUUhGUIcFeA^FE=^FE9/
F59^G5I_GUUaHEe`I61ZH5iSFe]LEUMEDeA?DE=<CeA:DeM=FV1BHFQDIFiHJgANLG]RN85YP8Y`R99c
S9MeTIifUJ800WNIY`0@Mib[OJ:bU[G2//WC_MGOa^C^`]gV_MCL]/[A[/36YKFkWJ^_U:2TS9FIPhZ=
Nh226?ooo`0?OGEdLFUXIEeLF51?Bd=2?SDe;bLW81LG3`L74P/;5a4A7aTH:R8P>bl[Bc`g009JB480
7eI6@U54@Te3@DU1@4I0@D<o@D0n@D90@d=2A4E5B4E7BTA8C499CC]4BSDnABli@BTf?RDe?b<d@24f
@R4jAbE0CRM4DRa9Ec9@GSMFI3]KJSiPKceQLSeSMSaUN002?6Mk010kJGdoKH9COY1]T:1jVjZ3Z;J7
Yk>;YK2=Xjb>X:N>W::>V9f>U9R=Si:<Rhb:QXHIoooo00ngVhR_TWnVRWJNP6bDMf>;KEV1HdifF4=[
CSUP@biE>bM?=R9<<am;<am:<b000TXb7`0OBC4OBc@SC3PWCc`]DD4cDT<fDd@hETTmFTi2FU15FDm4
Edi3E4XoD4DiCD4dC3haBcdaBclcC40eBShdB3`bB3`aBShbCD4dD4<gDDDiD4DiCD8gBChdAS/bACT`
0093>2h0444f;40f;4@j<4i2=UA6>UU9>f=A@VmLCGYVEhE`H8mhJ9R0Kj28MZR?OK2FQ;RMRR3oool0
01koool03fE[KF=VIf5QHEmMFeaGEEYBCUM<AeA6@4ln=f1<A7EMDhY/H9ilK[B=O<VMRP02fZ^F01oJ
[9SDZ9K=Xi;6WHfoUXJhT86bRgf`R7Z]QWN/QWR/QgV_RWf`Sh:`T8F]ShFZSHFURh>PRH:KQX6FQH2H
RXFOU8jVViN[XYf]YJ:^ZJJb[Zbg];:k^KRn_[k1`/800/76aP0@`lW:bm7CgMkNl>c[m?CcnOoom_cl
hn[[dm_La<c=][k0Z;6bVZ>USIJHP8V<Lgeo6Oooo`0?J6Y[GUmOEE=CBTQ8@3`k=C0^:R<Q7ADC40H4
7A8>;b4L@S0YEclfKe96QfAF00:JLf<07iQdII5`I8Y/HH=WGWaSFWIOF79MEg9MEVmLEFmMEfiMF6mO
FfaPG6QMG65IF5aEEUICEE1BEDeAETUBEdYGGDmOIU=TKEY/M5ibNf5hPFInR6^4Sfj9UG6>Vg>CX002
LiJT011bV:QnXk:I]l>eb]Bme=k7hng=iNg4f^6lc]Fc`lVY^;fP[K6GXJF>UYZ4RhikP88Hoooo00mm
MGAaJFQTG5aHD4m;@d8m=CD_9bLP61TA2@XD3PlL5QHU7Qd`9RDo<c1??c/00U]9@`0OF4U5E4Q5CdI5
BdA5B4A5ATA6ATI8AdM:ATQ;ATU=ADY>@dU=?TI;>458<Sa3;CQ0:3Lo9SI093M38cY68ce;8d1?8d9A
:DMG;TeM<E9R=5MW=e]/>5i`>F5d>FAg008iIGX043IVO41_Q5N0Tff@X7JIZ7nT/h^Z]XnZ]96W[i:S
ZY:OYI6JWi2FVHjAThf<SH^6QaWoool03kRKR;2CP:R;Min3KiMjIhiaGXEXEGaPC7=HA6Y??657=5Y1
;U@l:E4i9Thg9@02Bc@R01I9<b9:=BA<>2Q=?2i@@CACB3aGCT=JDTMKEDaKETiJETiGDTUBBd1>A3U;
@3A9?S59?S9;@3A=A3Q@Ace?ASe9?cP2AC/b00M8?SA9@3E:@3E8?SE6?3=4>S53>S400T8h<00@?cH^
@CL_AcddBT0fCT8gDT<fGD`nKUa>NVMIQG5RSgYZV89aXHUhZI1n/IJ4^9f:8?ooo`007_ooo`0?I6]/
HFEVGUmOG5YIFEABEDi;DTM3CT0kBCPbF4DmK5E;PFIJUWIX[hUhaY^800;HZI@07m^]VMN[V=6VULZQ
TLBLS;jGQkZBPkJ?OkB<OK><OK:<OK:=Ok:>PK6@Q:j?QJ^>Q:N=Q:><Q9j:PiV8PYB7PiB;QYRASJ>K
UjbTXK:[YkF_[;Rd/[^h]kfl_;fo_`02_/;3012naLK<d=7Mg]g`jnSim?;ino[jo_cXkNcGgMg7c/jh
_l2Y/K:KY:F>UiR1RXadOGlIoooo00mXJF]MGUmCDU98AdHn>SXb;RdV81lJ4a4<1@8I40d[7aY0;bQE
?cI_DTJ6I5H00YUbH`0OVWIWU7AWSFmUQVaRP6MONfAMMf5KM5mILEiHL5iHKUeGK5eHJEaHIE]IH5MG
FeEFEUAFDU=GCe=HBeAJBEIMBeaSCV5ZEVUbFg5jHGN0I7f7J8:=K8NDKhfJL92N009^Tj8046fFYX2U
]9Zga;;8d/3Fgl[Sk=S/llgOiL;Cf;S6c:fj_j>_/iVSYXnGVXF<SWb0PQSoool03geeM75YJ6ALG5Q@
D4]3@cdf=RlX:B4J6a8<3ALA4alI6RTQ8CD[:D@f<e51?@02G4Y501mJC4QFBTQAB4Q=AdM:ATM7ADQ5
ATU4ATU3ADU1ADXoA4Tm@dPi@4Hd?D@_>D4[=clX=SlU=T4U>4@T>TPU?T`XA58YAeD[BUTZC5`/Cf0^
E6HbF6XdG6lgHGDhHgP00SETN@0@<fIl@g:7Eh:EJHjOMYZZQ:RfU[BoUZniUj^cUZN^UJ:XU9fQTYNK
T9:DSXb>RhN76Oooo`0?^9b9/IF1ZHejXHIcVGi[TGISRFiKPFIDNEm=LEU7JU90Hd/iGDDdF40_DS/Z
009>=bH03d/e9DXe9TXg:4`j;4dn<Dm3=e57?E=;@E=<@e==AE9<A519@De5?4Y1=TPm<P02Ac``00Q9
?S=;@CM?ACaBBT9EC4ACBD5<@c]5?CD4@c/c01A4?3A4?3E2>S=2>S=0>S93?3A7?cM7@3Q;@cYFBd1S
EDQ`H59lJUb7LfFAO6fIQ7>RRWZZTH2aUhFhWH/Poooo000Noooo00mSJVaPI6ELGUiIEeIEDDmABTM=
@cm8?3M2<biA@3USCTEjH5F@LFBYQ7C1Uh@00]JWTP0OgJjIfZjJe:ZHcZJEbJ6Aa9f=`9V:_9F6^Y:3
^962]i21]Y62]I63/i64/965[I25ZXn6Yhn7Xhj7WXf7VXb7V8f9Uhn<VI>AWYVGYZ6OZjRV/:j//k:a
^;Rg^[bl00:l_kl04;c2`l[>c]_Jf^[UhoOak_cimoknnnc^kM[NgLW>c[[0`:^a/YbTYHjGV86:S7Am
OaWoool03fMYJUeMGU9ADTM5AC/i>30/:b@O7QLA40X30QP?32LL63h]9U<n=Fa@AHARE@02Ug5R01nK
MfVGMVZ@LVR:KfJ4Jf=nJ65jIEifHUacH5Y`GUU]G5M[FeMWFUITF5IOEeIKE5EGE5IDEEQ@EEY>EUa;
F5m<G6==H6QAIVmGKGMMM7iQNhIVPHaXQY=/RYUZSY`00VZAX00@K9FUPZJdVKO3/<OAa=OPd^K]h?3f
e>?Yb=OL_L[>/Kg1Y[2dW:BXTIRKQXb?O8636?ooo`0?OGEdLFUXI5eLF51@BdA4?SLg<2TZ8Q`M5@l@
6aDF8A/L;2@T>2d/ACPfDD8n009JBTD07eY=BEM<BU9:BDi8BDY7BDM6B4A5B494Acm3Ace2ASY0A3Ln
@c@l@S0i@2`g?bPd?RHe?b@f@B<gA2<jAb<mBbE1D2Q6EBa<Fc1AH39DIC=GJCIKKCIOLSMQMS=RM`02
<VAi010dIgi6MXYIQ9M[TZ9mXJn=[k^N^/BN]KjM/;RLZk6JYJZGWjBEVIfBTiF?SHj<QhLIoooo00ni
WHVbUX>ZSgbSR7FLPFnDNVR=Lf66K5YoIUEiHDmbFTUZDd9TCCaMASIF@3000Thi:@0OBCDUB3@UBCHW
BSPZBS/^BcdaC40eCD8hCD@kC4@kBd<jBD4hAcheAC`bA3T_@cP^A3T^ACX`Ac`cBT0gCD@kD4PoDd]2
EDa4E4a4D4Q0CDDmC4@mBd@mAd4j@chg0091?CH0448n=dI1>TY5?De9@55=AE]CBFMKCg=TEgm^H8Ug
JI=oL9^6MZ><O:^BPK:HQ[VNRb3oool001koool03f=ZJemSI5YLG5IEE59>C4e7A4Po?4<h<cd`:Tdm
=Ue:@G=JChY/Gj>0L;^CP002dZB?01oM[YWM/9cH[I_BZIS=YYG9XY;5WXk2VhboV8VmUXNkUHFjU8Fh
U8JfU8JdThNaThN^ThV[TXVWTXZTTH^PTHbNTXfLThnMUY>OVYNRWY^VXj:/ZJR`[jnd];Bf^;T00[Rl
_@0@_<73bLc<emOFi>7Ol^gZo?Odoogkl?7_g=oMblk>^[noZk6bWJ>USiJHPHV;M7eo6Oooo`0?IfUZ
G5eNDE5AADA4>SPh;R/Z8QhM5A0?20815Ph<9A/G>RXUDC/cJ4i4OemB00:BKV007iagJIYiK9=eJhab
JHI^Ih5[I7aWHGMTGWAQFg1OFFeLEfYKEVIIEF=GEEmFEE]DEEQEEeEFFE9GFdmHGTeJHDeMIDiQJU5V
L5E/MUUbO5ihQ69nRfB3TFJ7UFJ;V@02IhjN011^UZJ4YkFK^<B`b=76f>3Hj>gUl_OLjNg?fmo2cM2e
_l>Y/[FNYJRBVIb7SHmmPH<Hoooo00mmMGEaJFUUGEeHDE5;ADDn>3Pa:b`T7QlF418L5QLS7Ah^9RHi
;bi5>CI?@Sh00UM9A@0OFTe:F4e<Dd];CTU;BTQ:ATI9@TA7?d96?414>Ci3=S]1<cY0;cLn;3Dm:3<l
9C8l8c<n8SA08CI38CQ68C]:8cm>9DAD:DUJ;DmO<5=U<eQZ=5]^<eeb<Umd<65f008_HgT043IZP4Yi
SUn9Vg6GYhFU/iJc_ZFmajJk`jBf_J6_]IjY[Y^RYYNLWYBEUi2>Shf8R1Woool03kVMR[>GQ:bAOjF;
NIn5LiQnK95hIhYbHHA/FWeVE7MQD75KBfUC@f5;>eQ3<`02CcX/01m9=BI7<bE7=2I7=RU7=b]7>Bi7
>Rm7>c17?396?395>c53>C11=be0=B/o<bXo<bTo=2Y0=Ra2>2m4>S57?SE:@CU=A3e?B41ABT=BBdA@
BTA=B49:A3m6@Sa3@3X00T8n>00@A44kBTM1D4a6EU5:FeI>HUY@JeiCMVMKPg=VSGa^UX=dWXUjYHmo
[9B3/iV8^Ij<8?ooo`007_ooo`0?HVU[GF9SFE]KE5=BCda:BDA1A3`h?S@_>B/VB3PbF4DmK5E:PfII
WGYZ]Hek00;<Wh/07mb]Un2bW]^`WMF/Vm6YVLfVU/VRT/JOSlBMSL6KRknIRKjHR;bGR;ZFRKNFRKFF
R[:FRk2FSJbFSJVFSZJESjBFT:>HTj:JUZBLVJJPWJRTXZbYYk2^[K>b/[Bf]P02][Vj012n`L7:bl_F
eM?Rgmc^jNKilnomn?Gal>kLgMc:cLbj_[j[/;2LXjB>UYN1RH]dOGlIoooo00mWJFYKGEe@D554A4@h
=cL/:RXP7A`C3`h60@0D3P`S6QHg:2=<>35SBT5iFdl00Xe[G@0OVWIXW7]^UWQ]SWA[R75YPVeVOFUR
N6EOM69MLEmIKEaGJEYFIUQDHUMEGUEDFeEFF5IHEUMJDeQMDEYOCeaRCemVD6=[DVMaE6afEg5lFWJ2
GG^8Gh2>HHBCHHRG009TSId0476HZ8RY]ifiaK;9d/SIh=gYk^[cmnG_l]CNhLK?d[S1a:^c]YnVZIBJ
W8R=Sgf1PaSoool03gefMG5ZJFENGUUBDTa6ASli>S8];RDP8APC51hJ6bDP8BlX:3P`;d<i=da1?P02
EDQ501mICDYICdeDC4e>BTa9B4Y5ADU0@THl@4@i?D8e>Slb>3d^=S`[<c/W<SXT<3TQ<3/P<CdO<SlN
=48N=dDN>TTO?TdR@U<UAePXC5dZD68/E6L/Ef//FVl/GG8[GgD00ReSNP0@>Vj4CgjBHhfOMib[RjZg
WkW3[/?</LC;[;c2YkBiXjbaWZFXVYjPUYJHTHn@SHR86Oooo`0?^Yj;]9R6[Y>1Z8ilXHQgVh9aUGe/
SgMWR79RPVeNOFQIMV5CKEY;He53FTLi009A?S407dTf:DHc9DHc9TDd9d@d:4@d:D<e:T8e:T4d:T0d
:Shc:Cdb:3/`9cX_9CT^93T^9CX_9S/`9c`b:She;D4h<D<l=4Ho>4U2?4Y4?TY5?dY5@4Q4?dE3?T=2
?451?002@D4m0115AD5>CDQEDdiLFE=SGUM[I5acJEmnLFJ9NVjBPWFJR7ZQSGjWTX:^UXJdVhVjWhdP
oooo000Noooo00mQJFYLHF9GFEUADE5<BDQ6@Cm0>CDj<2`c9b93=BiC@CUVCdEkGe>CLVB/QW@00/BH
Q00OeJNAh;6LgK:Nf:nMe:bKd:ZJcJNGbZ>Cb:6AaYj>a9f=`Y^<`9Z;_YZ;_9V;^IV=]iZ>]9Z?/YZ@
[iZA[9ZBZIZCZ9bFZ9jIZ9nKZJ:OZZJS[:VW[Zf//;2`/KBd00:d^;T04;bo`<S8b=?BdMkKf>WThO?/
j?Obk^k/jM[Jf<S:bKVl_:Z^[ibQXXjEUX68RWAlOaWoool03fIYJU]LGDm@DD=3A3Lf=b/Y:AhL718>
3P@101<=328I5S@V8DLe;Ue6?G=GC002R6MJ01nFLfFMNfjGNVn@MVf9LVZ3KfQnJfAiIV5eHeiaGeY]
G5QYFUIUF5AQEUANEEEKEEIIEUUGF5]DFEiBFf5AGFA@H6QAI6aBJ75DK7IFL7aGMH5INHILOXaMPY5N
QYH00VF>WP0@Mib[S:biXKc7]lcDcMcRhN_^k_Ghj_;ef>3SbM3C^/;4[KBgXJNYUIZLRHj@OH636?oo
o`0?OGIeLVYZIUmOFU=CCDM7@C/l=2h`9b8S6QDG8A`N:2<T<2XZ>C4a@cXiC490009EBDL07eU=BeY@
CeA=CTi:C4Q7BT=4B3i1ACXn@cDk@38g?Bhe>bXb>RH`>2<^=b0]=ah]>Ad_>a`a?Q/c@A/eA1/hB1`l
CAm1DR55Eb=9G2E=HBIAIBMDJBUHKRUKLBYNM@02<FIm0113M8YGQ9M[TjB0Xk6F/[j[`LZic=BlcM>d
`/N]^;fW/;BRYjZMWj:HV9VCT96>RHTIoooo00njWhbeVXR_UH>ZT7nTRgZOQgJIPW:COFf>N6V8LfF2
KV1lJE]dHEA[F4]PCd800UM6>P0JCC`aAcDYA38V@c4U@C0T@2lS?RlT?BlU>blU>RdT>2`S=b/R=BXQ
=2TP<bPO<bPP=2TQ=B/S=RdV>30Y>S</?CH`@3Td@S`gA3ljA40l0TA1?@93@Cd04d92?TE5@TE5@Ti=
BEEDD5eKEVISGVm[IGQbJh1iL8UoMI64NIR9O9j=P:BAPjZEQK2IR;FLRkZPS@0Poooo000Noooo00mQ
J6YKH65EF5Q?D4m9AdI3?c`l=S<f;BT`91lo<2Y??CEPBT1dFDj;K5jUP6l00[^BO`0OcZ6<fjfHgK:N
f[6NeZjMdjbKd:ZJcZRGc:FDbZ:Ab:2?aYn?a9j>`Yf>`9b>_Yb@_9fA^YjC]YjC]9jD/IjF[YjF[InH
[:6K[::N[:BP[:NS[JZW[Zb[[k2_/;:b00:d]kP04;fo_lK7a]7?c][GeNCPgNgWho3[inCRgmGDd/G7
aKJi^JR/[9ZPX8fDUH28RG=lOQWoool03fIYJU]LGDm@DD=3A3Lf=bXY:AdL6a0>3P<0014<2b4H5C0T
848b;5I2>ViDB@02PV=G01nAKf:JN6^GNVn@Mfj:Lf^4KfQnK6IiJ69eHei`GeY/G5QXFUIUF5EQEUAN
EEELEUMJEeYHFEeEFemDG69BGfIAHFUBIFeBJ79CK7MDL7]FM81GN8IIO8]JPI1NQYH00VVAX@0@O:2^
T:nlYko9_LoGd]oUi^gamOWkjo7cf^3Rb]3C_<;4[[BfXZNYUIZLRHj@OX636?ooo`0?OWIeLV][IV1P
FeADCdQ9@Sdn=S0b:B@V71PJ8QlQ:RDW<B//>C8b@CTiC490009DB4L07eU=BeY?CUA>Cde:C4I6BT53
Ac/oA3Hk@C8h?Rhd>bTa>BH_=b8/=Al[=A`Z=QX[=aT]>QT_?APa@1PdA1TgB1TkC1/oDAe3EQm7FR1;
Gb9>HbACJ2EFKBEJLBYPM`02=f^2011:NXmORYefVj^<ZkRR^lJgb];9f=k6e=Vkalbc_<2//kJUZZbO
XJ>IVIZDTI6>RHTIoooo00nkWhffVhVaUhJ/Th:WSgnRRg^MQWNGPW>BOW2<NVb7MFR1Kf9iIe]_GU9U
E4T00U]:?`0=Dd4fBST]A38W@30T?RhR?2`P>RXO>2TN=RPN=2LM<RHM<2@K;b<J008^8QX042dS6bdT
72lU7c0X8C<Z93D^:3La;CXe<3`g<cdj=Sll>3ln>T0o?450?D11?T=4@P9:BdP045=DD5aMFFMVHG5_
JG]hLHF0NI6;Q9N?QiV>Q9j@Q:>BQZREQjfHRK:KRkJNS;^PSR3oool001koool03f1XJUYOHEAGEde>
CTM5A40l>STc<38Z9R/Q7CX]9dXi<UY6?6eDB8=UEi]hJ002]8Yh01o9VhOFZ9?L/9cL/IkI/9kF[YgC
[9cAZi[?Z9S>YYG<Y9?:Xi;9XY;7XI;4X9;2XI?1XIBoXIFlXIJiXINfXIRcXIVbXY^`Xif_Y9n^YZ6^
Yj>^ZZN_ZjZ^[Zf_/K400[Fg]`0@_;fmaLG4c/c;f=GBhMgJj^CPkn[Vg]cId<o=`L;1/kJeYZZZV9jN
S9:COhN8Lg]n6Oooo`0?IVUZFUaMCe1A@d=4=SHg:BTY71/K3`h>0P0040`;7aLE;B<O?BlYDClgIdm6
009kGU<07ha/GiEdJ9EiKY1gKXYcJh=_JGi/IWUXHgATGg1PFfaLF6QJEVAGEF5GEEiFEUaGF5YIFeQJ
GUILHEENI5=QIe9SJU9VKU=YLe=]MeA`O5AcP5IhQUMlRUZ1TF68V002KiFT0122Y;6H];n]`lc3dm[H
hnO/lO?joOoYk^oJgn3;d=:l`L>_];JRYjVFVYb:SHmnPH<Hoooo00mnMWIcK6]WHF5LEUI@BT]4?d0h
<c@[9RPN6QdU8B</9bTb;Bhh<S=1>c];@T800U58A`0OETe;ETi>DTi?BdY=A4E9?T56>3e3<cTo;SDl
:C4h9Bhe8B/d7BTb6bPb62Lc5bTf5R/i5Bdm5C105C=45SM85cY<63e@6T9E6dIJ7DYO7diS859X8UI]
9Uac;fAk008oLXP045>2UFZCY86S/IRd_jk4cL;BfM;Oi<WEfL3:c[No`Zne^:R/[Z6SY9^JViFBTXn9
RAWoool03k^PSKNMRk>IR:jFQJZCPjJ?P:6;OIb7NIJ3MI5nLX]jKHEdJ7e]HWEUFf]LDP02GU5701mD
ASa:?3=3=2Xn;bDk;24h:Ahe9Q`c91T`8QL^81H/7QDZ7A@X71<W6a<W6a@W71HX7aPY8A/[91h]9b8_
:RDb;RTd<2df<c0h=c@j>CLl?3Xm?S`n@3m1A497BTP00U1BD@0@FeeJIVMTLG5]O7YeQX=nT8b5VI:;
WYF=XIJ<Y9J;Z9R;[9V</9^<]9f=^9n>_:6?8?ooo`007_ooo`0?H6MZFEmPDeIFC4e=A4=3?CXh=C0]
;BHS9A`I=BTSA3D^E44hIDi3NUiATW5Q00:ZPg407l6EPM:RSMb^VMfbW]^aW]R`W]J_WMB^WM>/Vm6Z
VM2XUljWU/fVULbUULZTULRUUlNVV<BUVL6UV[jUV[^UVkRUW;FTWK>UW[:VX;6WX[2XY:nZYk2/ZK2_
[K:b/002]kNf012n_Kc6a<?>blWGdm3Pf]OVh=cXi>3He]?:b/Rm_[b`/[:SYjNFW9b:TI9nQXMbNgdI
oooo00mVJFYJG5i?D552@d@f=SLY:BXL6a`>3Ph0000?2`XL5Q@[8Ahi;BQ<>cEPBT800W=IC`0OQFMK
SVmTTWI[SgM]RG=[PfmXOF]UN6QRLfAOKf1LJeaHIeYFI5QEHEMFGUIGGEQIFeYMFUaOF5iSEV1UE69Y
E6A/DfM_DfYdDfehDg5lDgB1E7R5Egb;G8>BIXbK009gVZP048ZY]Inh`kC8d<[GgN3Wjo;em__mo^S/
kMWMg/[>d;c0`Znc]J:VZ9JJVhZ=Sgj1PaSoool03gigMW=/K6QRHUeGF59<CDI1@SXf=bhZ;24N82PT
9RhZ:c<_<CTd=T4k?4Q1@@02CTM601mBBd]ABda>Bde8BDa2A4Pk?d@e>T4_=SdZ<CTU;SDP:S<L9c4H
9C0F9C4D9C8B9cDB:CPB;3`B;d0C<T@C=TPE>D`F?E0H@EDIAEXKBElKCF<MDFPQEVhXGWHdJH000TMi
SP0@GHVLMIZ[Rj^hX[_6^/cEcmcQfNCXcMOK`lc?^/74/[NiZZf_XjBUW9^LUY:BShZ96Oooo`0?_:6>
^9j<]I^:/IV9[IJ7ZIB5YI63XXn2WH]nV8IiTH1eRW]`Q7E[NVaRKf5H009SETd07eI;@TXn=T4d:c/]
93LY7c@U6c4R5bdN4bXK42PI3RDG3B<E324E320E3B0E3b0F424H4b8K5RDO6RLS7bXV8bdZ9S0^:c8a
;cDd<SLg=SPj>CTm?3a1@456ATU>CP02EEUI011QIF=^KfijNWN5Ph2@SXZMV9>SWYNUWIFWWIBZWI:/
WI6_WI2cWY2fWi2iXI2lXY0Poooo000Noooo00mPIfUIGV1AEEI:C4a2@T4j>3Lb;R`Y8b0P61@^8ahm
;bU=?3=NBCibF4b9JU/00Z1kJP0O^8ejbYb7fJZEgK6Lg;6Nf[6NfK2Oek2NeZjMeJfLe:^JdZZHdJRG
dJVHcjVIcZZJc:ZKbZZLajVL`jVM`:RN_JRN^ZRO]jRP]JNQ/jRS/JVU/:ZV/:bY/Zn/];:`00:h]kD0
4;jl^lC2`Lc9a]C@cMcGdn7Lf=_He=7?c<C4`[Ri^:b^[Z2TY9BIVXV?T7f5QW9jOAWoool03fIYJU]M
GTm@DT=4ACHg>2TZ:a`L7@h>3`0000d:2ATE52LP7CDZ9THg<EU6?P02JU=:01mkHEJ6JEj>LVR=MFb8
LVZ2KVMlJVEgIf5bHem^H5aZG5UVFUMSF5IQF5MOF5QMFU]LG5mKGV5JH6EHHFMFI6YEIViEJ75DJgED
KWUCLGeCM85EN8IIOHaQQYE^TZ000X2P[@0@U:niYkg7_<cCd]cQj>g_n__lm_Shi^WYem[KbLc>^ko0
[[:cXZFWUIVJRHf>OX626?ooo`0?OgMgM6e]JV=SGeUJE4m@BDA5?STk<Rh`9B8T:bLY;bd_=C4c>CDg
?cXlAT51009:ADH07de8BTa8BT]9C4I7Bcm2AcLm@S4h?R/c>RD^=b0[<a/W<ALU<1@S;a4R<0lR<@hU
=0lX>0l[?10^@10a@a4eB1<iC1@mDAE1EQM5FQQ9GaU=I1eAJB9HLBeSNciaQ`02Dh:F011[TjB1Xk>H
]<2`aLo9emkOjNgNj>_AfMc6cM2m`/Fd^;Z/[ZnUY:JMVibFTi>@RXTIoooo00nmXHniWhjfWXfcW8b`
VX^]V8ZZUhZWUHVTThNNShBGRGj@PWR8NW5nLFQcIeh00VMLE00OFDm8Bd4j@3D^>BdU=2LN<28H;1dC
:1T?9AH;8A<97a487A096`l96@h860h96A0<6Q<@71LD7aXH8QhK9B8O:2HT:bXY;Rl^<C<b<cHf=SXj
>Cdn?D94A4]<D5IG009MHV<046]_KWUjNHF5Pi:@SInLV:bZY[2/YjfVWjjTVjnRV;6RU[>QU;FQTkRR
T[ZRTKfSTB3oool001koool03emWJEQNGe1DEDU;Bd51@3Pg=Rl/:RHP7Q`D4BHL63HY8dHe;UI2>6UA
AH1RE002UWAS01n/Q7;0TgoBXhgK[YWM/IgL/IkK/IoJ/IkI/9kI[igH[igH[I_F[9[F[9_E[IcD[IgC
[Yo@[Yo=[J39[9o5[:32Zj2nZj6kZZ6hZJ:eZJ>bZJB`ZJF`ZjRb[Zbe/[000[Zg]00@_kbia<6oblO4
dlk;g=KBhmkJeM;?b/S6_[jl/kBcZ:ZZW:2QTYNGQhf>O8>5LGYl6Oooo`0?IVU[FeeOCe5B@dE6=cPi
:R//7AhO3a0A00422@P85Q<B91dK<2LS@3<_DD4j009RCTH07g1ID7eSFHQ]HXYbJ8I`J81/IW]YI7EV
HG5RGVaOG6UMFVIJF69HEf1HEemIFUiKGEiNHEePI5aRIUYSJEQVK5MXKeI[LeE]MUA_NUAbOUAePUIi
Qeb1SfR;VGNHY@02RZJb012N]Kj``l_4dMOKh^G`lO?ooooal_?SiNGEemS7b/^j_Kj]/;:QY:FEV9V9
S8imP88Hoooo00moN7MeKVi[IFEQFeaGDE9<AdU1?Clf<S@Z9bT]:bdb;c8f<cHj=cTn>ce3@4800TM4
AP0OB4I8B4I9AdM:@TE9>cm5<cY1;CDm9S0i82`f6RPc5RD`4R8_3R0^320^2b4`2b@d2bLh32/l3Bi0
3S543cE94CU=4SeB4d5F5DEK5dYQ6TmV7eA/:5if=f^1BGZ?009PRih047RL[8j]^ZFmb;k?emCPiNC]
lMcTim;Ig<S>d;o3aKJh^Zj^/:JUYYjLW9NCTi2:RAWoool03kfRT;^QSkRPSkJOSk>NSk6MSjnLT:fL
T:ZKTJJHSijAR9J:PHj2NHAiLGQ^I`02Jf9L01mME4m?Ad52>C@g;BH`9Ad[7aLW6Q4R5@dN4@XJ3PLG
30DE2P@C2@@A2@@A2PHB30TC3``E4Q0I5Q@L6QTO7ahS8b<V:2PZ;Bd]<S8a=SLe>cdj@D=1BD];DeEH
Gf400VI/K@0@MGUiPXF4T96?WIbIZ:JR/:fX/jjX/jbU/jVP]:NM]JJJ]ZFH^:BF^ZBD_:>C_Z>A8?oo
o`007_ooo`0?GfMYEeiOD5AEB4Y;?d10=SHe;BXY8alM618@7aLC;B8M?BhWCS/bGdToMEY=00::JU/0
1YijJK:9M/JIQ=JWTMb^VMfaW0;M/Yh01=fbWmbbW]baW]baW@;K[i`04M^aW]ZaX=RbXMJbX]>aX/n`
X/Z^X/N]X/:]X[j/X[^ZX[NZXkBZY;2YY;2[Yk:]Z[Ba[P02^KFc012o^kO4_kc:aL;AblSFdLgLf=C>
c<W3`/2h^KN^[jjSYZJIWIf?U9F5RhakPXAaNG/Ioooo00mWJF]KGUm@DU=4ATLh>S//;BhN824A4Q<2
0`@71`PC4A0O6QT[924i;ba9?3L00UU8@P0OIU=;LUaCOFELPfaSPVeUOVYTNFQRLfAPKf9NJemLJ5eJ
IE]IHUQGH5QHH5]KH5eOH61SGf=VGVAYG6I[FVQ^FFYbF6aeEfmhEG5lEWAoEgR5FWb:HhJDLI6NPIjZ
00:C[;H04:Nj`kW8clkGg>CWjOGdmOooo^k_kn3QhM;De<G7b;Rj_:b^/:2RY9BGV8R;SGf0PQSoool0
3h1hN7I_KfeVIf=MGUUDEDm;C4E1@c/g>Bl/;c0^<C@b=CPe>3Xi>chl?d90@`02ATA701m7ATU6ATU3
ADTn@dPg?D@_=clX<S/Q;CLJ:C@E9C8A8S0=82h97Rd67Rh683478cD99cT::cd;;T4<<TD>=DX?>ThA
?U<C@UPEAUdHBf<MDVTTFG4aIWe3MHYHQIP00VnEY`0@QZJeVkK2/lSAcM[Ph>S/j_;dgnGWe=WKb/k@
`<?4]kRj[Zj_YZFVWibLUi>CT8Z96Oooo`0?_Z>@_::A^Z:A^:6B]Z6C]J6D/j:F/Z:H/J>I[J2HYYZC
WI:;U8Z3RX5kOgI`009cJVD07fINFEQ@BdM0>cTa;BlU82PL5b8F41dA2aP<1a@91A470`h50@/40@X4
0PT50`/71Pd;2Q0>3Q<C4QLH61/M7AlR8R<W:2L/;R/b=30g>SHn@3i7BTQAEEENHFA/KP02LWQj011o
Q8F=T92KWIbZZZNe/k2i][:j]Jni/ZZi[ZJi[::iZYjiZ9^jYiRlYIJmYIBnY98Poooo000Noooo00mO
IfUGGEm?E5E7BT/n@40e=CD/:RTQ7Q`D40dE3``T6aHd9b54=2aD@3MXD4D00WeQD`09T6mPXge/]Hah
b9b6e:J@fjfGgK6LgK6Mgk>O00;P]9l05>2cWmnbW^2bW^:dXN6fXmnfY=beY=RdY=BcY<naY<^`Y<J^
Xl6]Xkb[X[NYXKBYXk2YXjnYYK2/Z;>_[0:g/k004;bg]<2l^LO2_/o8a=;<b<k;b<K3`Kbk^K:c/JVZ
ZYnRXYJJVXbATX>9RWV1Pg1hNaWoool03fMZJeaNH55CE4E7BCTk?Bd_<B4S91<E5`D720@51Ph>3QXG
5bLR83<[:48g<`02DD@n01mMCDIXEDiaGEEjIEekIUmjIf1fIV5`HUi/HEiYGUaWGEYTFeYPFEQOFEUQ
G5eSH65SHfERIFQQIf]OJFiMJW1LK7AJKgMILGYHLgiIMX5LNhQQPXm/S9UkV:>;Y:l00Yfb^`0@/<37
`/kCf=gPk>c]noWinOWhj^[Zg=gMcm3@`/C4][RiZZb]WZ6RTiJGR8^<OH216?ooo`0?P7UhMg5`KVQX
IF1PG5MHDdi@BTI7@3do=c@g=38e=SDh>CPk?C`n?ci1@d950096ADT07dI6BTE6BT54BSa2B3<lA2`f
?b@a>a/[=aDW=10S<@/P;`PN;P@L;@4L;@8O<@DS=@LX>PT/?`X_@P/cA`dgB`lkDA50EQA5FaM:HAa?
IbAGKbiRNCm`QU>0TfR@X@02Oj2`012E/Kj/`/c4e=[Ki>S]m?K^m?KPiNOEfM[:cLo0`/Bg^;V_[ZnW
YJFOW9bHTi:@RXTIoooo00nnXi6mXi:kY9>jY9FiYIJhYYVhYi^hZIni[JFgZjF^Y9fUW9FMU8jDRhF9
P7X00WadL00OKfQTHE]HDDa:@3/i<B/Y9QhK7aHC60l<4PT73@D32P811`401@000P000P4110@41`P9
2Pd>3Q4B4QHG5a`M728S8BLZ9Rha;3Dh<ca0>dA9ATmDE5eQHV]^LGQk009oQXP048jCTibOWjZ/ZkJg
]L;3`/K5`/6l]kng/;fcZ[f`Y[b]XKb[W[fYV[fWV;jVUKnTTR3oool001koool03emWJEMMGdmDEDM:
Bci0@3De=B`Z:B4N71@@3AD?32@K5S@W8D@d;5A0=fQ@A@02OF5C00V@Kf2SOFbeS7S8W8KDYY3K[IOM
/IcM/IgO/il00^2dW`0Dh;>Ogk:Nh;:Nh[BQhKJSgkJTg;FTf;BTe;>Tck6Tbk2TaZjS`JfS_:^R]jVQ
]:VS/:VS[jVU/:bX/jn/0[Nc/00@_;Nd`;bial:nclS4d/c8c/_8a/?1_;^i/[>aZJZZWj:RUYZJS96B
PhV:NH63L7Qk6Oooo`0?IfY[G5iPDE=DADM9>C/m;Bla8B<T4aDG1@L810D63Ph>6QLG9b8P<b/X@SLc
009AA3h07ee=AVQECW5MEGYUGG]VGgYWH7IVHG1RGVaQGVUNG6MMFVAKFV1IF5mIFF5LGF=PHF=SIF9U
J65WJemYKUeZL5a/M5Y_MeUaNUQcOUUfPEakR662Sfb<VG^HXh^T[`02WK:k012``<O2c]?HgN3/k>gk
nOWinOSZj^[LgMg?d=32a<Bf^;VZ[:fNXJ:CUYN8RhamP84Hoooo00n0NGQgLG1^J6QUH61LEeQCCU1:
ATM0?Clg=3Ld<SDf=CPi>3/m?3ho?T53@TD00TI5B@0OATI:ADI:@DA:?498<ca4;3Ho934k6b/g5BLd
42<a2b0_21h^11`]0A`]0Qla1B<e1bPj2B`o2Rm22c=73CM;3c]A4D1F54EK5dYQ74mW95M_;V9i?g26
Dh2CJ92Q009oX;0049Fa_Zc2c<CDf]_Tj>gdm^kdm^3UimGIf/[=cl32a;Nh^Jn^[jNUYInLW9RCTY2:
RAWoool03kjSTKfST[^TTkZTUKVUU[RVVKRWVkRYWkV]YKN[YJjTWJFLUIfDSYB;QHV0NP02O7A`01m_
J6AQFeQAC4Y0>cTa:bTV7Q/O5Q<H3``B2@L=1@<:0P470@05000200020@4410@720T:3@h>4A8B5QLG
71dL8R<Q9bXV;S4/=CPc?40kA4U6CeADGF5RJfiaN7/00Wn6R00@SY>CW9nOZZb[][Ne`/?2a/G2`Kbg
_kN`_K>Z_K2V_:fQ_:^N_JVJ_JNH_ZJE_jBB8?ooo`007_ooo`0?GfMYEeiOCeAEAdY;?T10=CDe:bXZ
8AhM5A4@3`T76a<@:b0K>bdVBcT`GDLl009aEd/02X9UEi=bHZ9nKKB<NL>HQ<jQS=JYU=V]V=jaW>6c
WP;R]9l04n6cW^:cW^BdX>FgXnBhYN6hY]feYMRdYMBcY=2bY<V`Y<>]X[j[XKRXX;>WXK2WXJnXXjnZ
Y[6/Z@02];2]012i];6m^;G3_[[9`l3@blS6`l2m_;Ve];>/[JbSYZFKWYjBUYN9Si21QhUhP85_N7XI
oooo00mWJVaMGf5BE5I7BD/k?Sl`<S@T9RPG6A/:3@l110D:2``F5ADR7ah]9bDk<Rl00TXo>P0OE4M3
Ge1:IEE?KEaFLEmILf5LL69MJemLJEiLJ5eKIUeKHeaKGeUJGeYKHUiOIF9SIVEXIFQ[I6U]HF]`H6eb
GfmgGW9jGGAmGGJ1GWZ5Hh2<JXVDMY>NQIjYUJ^d00:W^L004;W6blcDf>3Si?7`l?olno;al>CTi=OH
f<_<c;k0`K>e]ZNZZibOX9:DUXN:RgaoPASoool03h5jNGUbLG1ZJVQRHemJFeMBE4i:C4I2AChk?SHe
>3Pg>S/j?Shn@D10@d=3A`02AdM:01m7B4a6B4e1AT/m@dXe?DH]>44R<CdG:SP@9S@<8S4883047Rl0
72l07S028S@49ST6:Sd8;T4:<TH;=TX=>Dh@?E@D@eXGBF0LCfHTEVd^HGLlKX=?O91SRieiW:/00Xn]
^P0@Y[g8_LoFe=oTink`mOWkjo3ah>?Ue=OHb/c=`<72]kNh[jf^YjBTWi^KV9:BT8Z96Oooo`0?_jBB
_ZBC_JFE_:JG_:RJ_:VM_:bP_JnU_k>[_KB]]ZfW[JFOYIfGVYB?T8Z600:5OgX07gUcKfeWIEmJF4m:
BChj>C0/:b<N7APC4Pl;2PT410H10@<00@000@010`031P4520<82`H=3`/B5@lH6a<L81TR9R0Z;RLb
=blj?cU3BDA?EE9MHV1[Kg1iO7n7RP02SYBF012MXZ>/[jnj_;[4aL?:b/O9b<C6`[c4_;G2]jk0/jVo
/:Bo[J2oZiboZ9VoYiJoYI<Poooo000Noooo00mOIfUGGV1?E5I7Bd`n@D4e=SH[:b/Q81lF51<;20H@
2`PP61<_91ho<2U@?C@00VA=@P0OM5Y>Q6IITW9SXGi][hUg^i>0aI^7c:6>dZNCf:^Fg:nIgK2Kg:nJ
gk2JhK6Lh[BOi;FRhkNSgkFSf[BSeK:Rd;2RbjnRa:bQ_JVO]ZJN/ZFN[JBN[:FQ[:JS[JVV00:`[:T0
4;B`[KNd/Kbh]L:n^/C2_kbk^;Fd/Zf^[JJWYijQX9JJVXjCU8J<SGn5QgMnP6mgNQWoool03fQ[K5eP
HU=FEdQ;CCi0@S<e=bLZ:a/N80lB508620D82Q8C4adL6bPU8c@^;002A3Xg00M>@cmFBTILCd]RE4mW
F5AXFUIWFeP00VAKF@0FI5aJI5eKHUaLGe]KH5eMHf1PIFAUIfMYJ6]]Ifa`I6ibI71eHg9iHgImHWR0
Hg^4IWn9K8NAMHnIPYZST:F^X;6i0[6oa@0@a<c@e][Li^OWm_?bnoSgjn[Yg]kNd];Ba/O7^kbm/;6b
YJNXVYfNT9>DQXV:O7n06?ooo`0?PGYiNW=cLVa/JVAUHeeNFeIGDdmABdQ:A454>cTm>cXn?ci1@D54
@d=7ADE90099BDd07dU;CdM:Cd97CCi4BcQ0B2lkA2@d@1X^?1@Y>0lV=P/T=@LS=@<R=@@T=`HW>PP[
?PT^@`/cA`dfB`hiCa4nE1E3FAY:H1m?IRIGKC1PMSe]PTejSF69VWJHZ8bY]P02X[[4012ibm;@fn3S
j^gdmoWinocZkNkNhN;CeMK9b/_0`<2g][J^[:fWXj>OViZGTY:@RXTIoooo00noY9:oYIBnYiNnZ9Vn
ZYbo[:2o[jC0/jW2]jo3^[G0^;>h/:^_Z:>VWi^KUI400Y2;Q`0OQH1mN7=aJfITGEUGCTY9?c`k<2h^
928R6QPH4Q0B30/>20P<1PP=1@X?1@`A1@dC1@lE218I2aLM41`R5R<Y72X`8c4g;CY0=dA:@e1FDEiS
H6aaL7YnPHV<T9NJ00:PYJL04:nc];k1`<[;bm?DdmGEd/o=bL_6`<S0^<Fj//>f[<:bY/6_X/2/W/2Z
V/2WUl2UTb3oool001koool03emWJUMNH4mEEdM<CCm2@cHh>2`];B8R8QPF5@/920P50QH@3BDM63@X
8T<d;002ED8i00]VD4EeG523IeZBLfBPOVfZQgJbSWfjU8?2VXO9Whc>Xhl00]>WT`0BeJVEf:^GfjjI
gK2Lg[:Nfk:Oek2OdjnOcJfNb:bO`JVM^ZJL/j>K[j:KZj6LZJ:MZJ>OZJFR0ZbXY@0@[jbY/Jn/];:`
^kNd]kFc/[:`[Jf[YZRVX::QVIbLTYJFRi2AQ8Z;O8>5MGeoKWMi6Oooo`0?J6]]GV5SE5MIBTe?@4=5
=SPj:bh`82<U51LJ20/>0`L83Q0A6ATI928R;b/Z008m=S@07dLn?4e4@E=9AUU>BeeBCUmEDUiFE5eG
EUiHEf1JFF1KFV1MGEmLGF1NGf=QHVEUIVQYJfY]KfU_LVQaMFQcN6QeNfUiP6UlQ6^1RFn6SgN>UX2F
WXfQZ9^//jZh_P02_<G9013>dmGNgmo[j^[hm??`k^gTh^;HemO<c<g1`/:g^;R/[ZnRY:FHVYb>TI:5
R8UkOX0Hoooo00n2NgYkM7AdKFi]IfMVH65OFU]HDeEACDm:AdU3@D@o?D12@DA4A4M7AdY9BDd00Te=
D@0OBdeAB4]@@dQ>?TE<>45:<Ca7:3Q383=16S0o5bln4R`m3R`m32/m32`o3Bm13S9543I:4SY>53eB
5T5F6TIK7T]Q9E9X:eU^=F9g@6f0CgV;H8JGM9JURJFbW[K000:eall04<gHg^7Wj_7dm_koooKhn>SZ
j]cMg]7BdlS7b;jn_[Jd]:j[ZjJRXYjJVINBTI29RAWoool03l2UTl2VUL2XV<2ZVl2/Wl6_X/:bYlBf
[<Jk/lW1^/S1_<6j]KRa[K2YYJRRWP02WIRE01n@S8V3OgeeLG1WHf9IEEE<B4U0?Cdd<c@Z:bdR92LK
7R8F6QhD6AhB6Ah@6Al?6R4?72@A7RHD8BXI9blN;CDV=3`^?D@hATe4DUUBH6EPKG9`Nh21RXjBVIbR
Z:X00[:f]`0@`/G6cm7Bf]cKh>;Qg=gKe=7=clW3bl>kb;fda[R^a;BX`k2S`ZfO`J^K`:RG`:JD8?oo
o`007_ooo`0?GfQZF5mQD5IHB4e>@4=4=cXj;Rl`92@U6QTI3Pd=1@812`L56aDA:R4L>2`V0099>S80
7eQ5?6QBB7ALD89WFXm`HYUiJZ:1LJV7N;2=O;RCP[bFQ<:KRLFNRlRPS/ZRSlfUT]2VU=2XU/jYUl^X
V<RWV<BUV;jTV;RQUk>PUjbNUjVMUjFMV:BNVZBOW:FQW`02YjBR012ZZ:F[ZJN^[JZ^[J^][:ZYZJRU
YZFOXJ6JWIbDV9R>TY>7SHj1QhQjPX=dO7i]MWPIoooo00mYK6eOHVAFFE]=D553ATPi?3h_<S@U:2XJ
7B0?4QD42@/93@lE5aPP820[:BP00SHb<@0O?STgAT0nBT=1DDU7EDe;ETm>Ee5AF5ADFEEFGEQIFeQI
GUaMGeeNH5mPHV9SIFIXJFY/K6i`K75dJg=gK7IkKGUnL7f3L868M8J=NHbCPIBKS9fTV:N]Y[:g]Ko2
00;7c<h04=SIf^?Sh_3^kO3]k>GShm_JfM3@d<K6a[bm_K:c]:VZZinQXYJHVHf?T8B6R7]nOaSoool0
3h=kNgaeMGI_KfmYJVUSI69NGeaHFEIBE51=CdY8BTA3ATE4AdQ8Bd];CTa=D002CTmC01m<CU=9CE=4
BU11B4llADhd@D`]?TTX>dPS>4HQ>4HL=DDJ=DHH=DHH=TLI>4XJ?4hN@58QAELSBE`UC60YDFD_Ef/f
Gg8nIgU8L89DNX]TQiMeU:>9Xk2L/kfb`l/00/WDf@0@gnGXko;co_oooOknl?3`i>CUfMWIclk?aLC5
_K^k];:b[:VYYJ6QWYVHUi6@T8V86Oooo`0?`:FC`:NF`JVI`J^L`ZjP`k6TaKFYakV_bKjfcLBmclW4
blK2`[fi^[Fa/JbY00:WXZ007iZFU8j:R85nO7AaL6QVIE]JFdm?DDI6B3ho@CLi?30c=bX^<bH[<2DZ
<2<[<B<]<b<_=RHb>RPf?R`j@S50B3U8D4=AF4eKHEQVJfIbMgF0Q8F>TYBLWjBZ[;Bi^P02a<S8013C
e]GOhN7Yk>cXj^WNgM[He<oBblG>a;c;_kG8^Zo6]JW4/ZC3[Z32Zi_1Z9O0YY@Poooo000Noooo00mO
J6YHH69AEeU9CU11ADLi?3d`<S<W:2PM7AdB4A471@D40P4A3P/O6AD]92000Sha:`0OBc`eF4HnHdm6
LU]@OfEIQfeQTGEXVGa^X85cZHQh[8]l/I20]I>2^IJ5^iR7_YZ:`9b<`Ij>`9j?_Ij?^Yf@]if@/i^A
[IZ@ZIVAYIRAXYRBWiRCWYVEWY^HWifJ00:QX9h04:BSXJFUXjJVY:FVY:BTXj6RXIfOWiVLViBHV8nC
U8Z?ShB:Rgj5QWV0PW=kOFeeN1Woool03fU/KV5TIEQKGDmBE4I9Bce0@S<g>BX];b0S9QDI70/?4PL;
3A8F5a`N7bHV9`02<2l_01lh=CE0?3]3?ci9A4=>BDQ>Bd]ACdmCDE9EDeEIEeQIF5ULFeaMGEmPHF9R
I6EVJ6UZK6i]L79^LgE^MGU`NGecOH5fPHIgQHYlRi63TYN<VZ2FXZRR[K:`^;c0aLL00]3Ad`0@g]gM
j^SWk>[Yi>;Qfm[Id]7AbLW9`<30]kNh[Zn_YJJWW9jOTiFGRhf?PhF7NWeo6?ooo`0?PgakOGIfMg5a
LVa/K6IWIV5RHEaMFeMIEU=EDDi@BdU<B4M:C4a?CdmBCe1D009@DED07dmBETiAEdQ>E4E<Dd19DCQ5
CcA4Cc12CRa0CBXoCBHnCBHoCRDoCbE1DBI4E2U8F2e<GC1@HC=DICIIJSaNL49UMTY/OE5dQ5]mS6V8
UWVEXXZR[Ib`^[70alK@e@02g>7T013]ko7mo_koooodm?CYjNWOg]kEe=C;b/[3`L6j^;Rb[jn[YjNT
WinMV9NFT8n@RHPIoooo00o0YI?1YiK1ZY[2[9g3[j75/jK7]Z_9^k7<`;S?a[oCc<OCcLW=alC4`;fk
]k@00[2/ZP0OYZ>PW9VGT8f<Ph60MWAcJVUYH61QF5QJD55CB4Y>@dI9?d96>d15>Cm5>416>D98>TA;
?4M>?d]B@e1GBUINDEiUFVI/HfmeKWUoNhF:RY:FVJ2SZ:j`^;bmb<_;00;GfMP04>?Ui>kbl^ocl^OW
iMoMfMWDc]C<aM35_Lc0]/Zk[lNfZ/FbYLB_X<>/W<:YV<6VU23oool001koool03f1XJeUPHe9HFTY@
DT=8BC/o@3<e=RX/;20Q8QHF5`/:2P4000P61ADA3b8L6@02<2LS01ln<be;?CIEACiQCdI^FDmfHEN1
JUn8L6B?MVZFO6nLP7>QQ7JUR7ZYRgf[SWn]T86`ThB`U8F`U8N]ThNZThNWTXNTTHRPTHRMTHZLTXbJ
TXfHTXnGTi2GUI>JVIL00YjMV`0@X:2NX:2OWj2OWYnNW9jMVYbKUiZITiNFSi>CRhn@QX^<PHN8O8>4
Mgj0LGUlK7Eg6Oooo`0?JVe_HVEWFUeODUEGBDa>@DA6>3/n;c<e9RX/720S4QLI2@hA3aDG6AdN8R@U
008[;2d07c@c<cXh>3dk?490@4M5ADU8BDi=CTm?DE9BE5EEEeMHFUYKG5aNH61RHfAUIfMYJfa^L6ia
Lg5eN79hNgElOgR0PgZ4R7f8SH:>Th^GViFOXinX[:bc][Zn`<S9b`02emKF013Uhn;Xi^GPgmkIf=SB
dM7:bLW1`L:i^[Za/[:YZZ^QXZ>IVibATiB9Rhf1Q8EjO7hHoooo00n4O7anN7MiLg=dKVi_JFYZIFIU
H65PG5eLF5YGE5ICDE=>CDmADE=CDeIDE5P00UEFFP0OE5IKDEEJCE9HBE1GADmG?daF?TaF>TUE=dQE
=DQD<dQE<TQF<TYH=4eK=e1N>U=R?UQW@Ea[AV5`BVIeD6akF7>1GWZ7IH6>KhZGOIFQSJ6/WJng/Kk4
a<gAe]_N00;Yj^/04?_jn_ooo_Gem>c[jn;QhMWHf=3>c/O5aKnm_KNd];2][:VUYJ:MWIbFUYF?SXn8
QaWoool03l2UTl6XUl:ZV/>]W/B`X/JdYlRh[<^l//k2^M78`=K@b]WEdMKCd<o;b<K3`002_[Zh01nc
/:jXYJBMVYVBT8n6QHElNg]cLg=[JfaTI6INGV1HFUeDEe]AEEU@EEU@EE]AEeeCFF1EGF=IHFQNIfeU
KWA/MW]cOH9lQHZ6SY:AVIbNYJN]/[Bm`<7;c/kHfMT00^?Ui00@l??cloKfk>g[i^CQgm_Ff]?=eLc4
dLFlcL2ebk^_b;JYa[:Ta:nP`jbL`ZVH`JJD8?ooo`007_ooo`0?H6U[FV5TDeYLC59DADY<?T93=STk
;C0a9BLW6a`M414B10@400002PP75a@B008T7a`07c4Y9Cdc;TDj=513?5]<AFADC6mMEGMTFgiZHHA_
IH]dJXmhKY=lL9N0M9^3Mif5NIn8O:29OIn:Oi^8OY^9OiR8OiB7P9:7PI28Pi29QHn:Qhj;RHn=Ri6@
SY6CT@02UINF012KWYfIViZHVYVGVIVEV9RCUYJAU9B>TY::Shn6S8b2R8UnQ8IiP89eO7i`N7][M7LI
oooo00m[KVmSIVQLGf5DEeU=D595B4Xm@4<e>3/]<3<T:2/K828B5aX?5ALF6adO8b@00RLZ;00O;c4b
=SHg>3Tj?Cdn@D94A4I8BT]=C4i@D59DDUAGEUQKFEaNGEmQHF=UIFMYJ6]/KG1aLG=eMGQjMGYmNGn1
O8:5OHJ9PH^>RI:ETYZNWJBWZ:f_];Ni`L;2c/g=00;KfMP04>GShmgLg=KEeM3?clW8b<71`KZj^k>c
]:^/[JBUYYfNWiFGV8j@THN9Rh23Q7UlOASoool03hAmO81iN7]dM7I`L79/K6eXJFUTIFEQHV5MGeiJ
G5YHFUQGFEQGFUUHFeUIG@02FU]N01mIFemHFemEFEmAEei>EUi:E5e8E5e5DUe3DUe1DUe1Dem1E613
EV95FFE8G6Q;Gfa@I71DJGEKKg]NLh1UNXI[P8]aQY5iSIN4Uj2CXj^R[kJc_<;4b/gEemWVi^H00_Kd
l`0@o_glm_GdkNc[i>?Rfm[Idm7AblS8`l30^kRh];6`[JVYYj:RXI^KViFDUHj=ShR76Oooo`0?`JJC
`JRG`j^Ja:fNaK2RakBWbKR/c;fbcl:idlW1f=7:gm_Gh^3MfmWFd/o=00;9alD07l2m_;Nd/jj[ZjFR
XI^HV96@T8N6Qh1oOgYiNGAdMFm`LFa^Kf]]KfU/KVU/KfY]LFa`M6mcMgAiOGYoPgn5RHJ<T8fCUYFJ
WInTYZ^^/;Nj^lG6am7Bd]gNgN[Zj@02m?Cc013fmoK`lO3ZjNKThMcOfM?JdL[Eb/;Aa;_>_kC;^Zk9
]ZW7/ZC5[j33[9_2ZIO1YY@Poooo000Noooo00mQJFaKHfEDG5i>EEI7CDm1ATLi?Slb=CLZ;2hQ8b@G
6AX=3`l210@00@4;2`X00QPF5@0O9B4O<2XW>34^@3PcBT0kDTM2G519IEQAK5iFLV=KMfMPOFaTPW1X
QWA[RWQ_SG]aSgidTGmfTH5hSGmgRWifQgefQGegPgiiPWmkPh1nQH>1QXF4QXN6RXZ9SHn=00:ATi40
49:DU9:EU96DU96DThnCThfATH^?T8V=SXJ;S8:8RGn5QW^2PgMnP7=kOFmgNV]dMQWoool03f]^L6AX
JEiQHeMJG51CEDU<Cd96B3/n@C<g>R``<b@Y:adR9AHK7Q@J7A/Q900292PZ01l]<38c=CLf>C/i?3hn
@D=1A4M6BDa;CU1>DEABEEQFFE]IG5mMH69QI6IVJ6YZK6i_LG=dMWMhNgajOX1mPH=nPhF0QhZ6SY2>
UINHWInSYjV_/K:i^[[6a<CBcll00]_If@0@f]WIdm;Bc<c<a/K6`<30^KVj/k>d[:f^YJNWWj2QV9ZK
TYBERhj?QHN9Oh63N7]m6?ooo`0?QGemPGYiOGIfNG9bMFm_LF]/KFQYJVEVIV9TI61QHEiPH5eOGeeP
GeiPH5mR009PH6<07f5QI61QIEePIEYOIEUOIEEMIEAMIU=MIU5MIU5NIe9OJE9PJU=QK5ETKUQWLUa[
MF1`NVIeOfakQ761RgV8T7f;U8>AVHbJXIVTZZJ_];Bj_lC7b]?DeN;Ph?3]k002n_Sg013gm_K]jn_T
h^;Lf]WDd]7<b/W5`/:n^kZg];>a[Jb[YZJUX9nOVIVITi:DSHb>QhHIoooo00o1YY?2Z9O3Zi[4[Ik6
/:;7]:K:^:_<_K7@`[SCb<3Hd<WNf=?Uh]oWi^CPg]`00]KDdP0Oc/[9a/;1_[^j][Bc[Zb/YZBTWYbL
UiFETHn@S8b<RHV8QXF6Ph>4PX:3PH:3PX>5Q8F7QhV;Rhj@TiFHVifPX::TYZNY[Zn`^KVi`/?2c<c;
emOFhn;Qk>c[m?Gd00;joOd04?OinNo^jnSUhN?MemgEcmW?amG9_m73^<jn//^i[LVeZ<NbXlF_WlB[
Vl:YUl6VU23oool001koool03f5ZKEaTIUINH51GFDY@DTA:Bce2A3Hk?2lc=2L[;1lR8aHI6Ph@40@5
1P84100230h>01lJ6APV928_:bTd<2dk=S=2?CY:A45DC4MKDTeQF5=WGEM/HE]aIEmfJV=iKFImLFUo
Lfb3Mfn4NG:2NG>0NG9jMG5gM75gMW=gMgAiNWQlOGaoP7n1PX:2Q8B7RHT00XV=S00@Rhj>Rhn?Rhn?
RXj?RHj>R8f=QX^<Q8V:PHN8OhF6O8:4N7n1MGenLGYlKWIiJW=f6Oooo`0?K6maIVU[H6=UFUeOE5MI
CE5CAd]=@DE7>Si1=3Pj;C8d9b`_8BHY6b4T6R0S008Q9bX07bX^<C4e=cHj?3Tm?ca0@cm4B4A9C4Y>
DDeBEE9FFEIIGEUMH5iQHf=UJ6MYJfa^L71bM7IhNG]mOgj0PX63Q824QX>9RX^@TI6FV9ZNX:NYZ[>c
/kfl_<O5a=;@c`02dm;B013=cLc7alO2`/:l_;fg]kNa/[:[[:fVYjNPXJ:JW9bDUYN>T9:9Rhb3QHMm
P85hNW`Hoooo00^5OWf2NgYnMgMkM7AgLG5dKVmaK6a^JFY[IfQYIFIWI6D00VISI@07IVAVIVAWIfEX
IfEXIfIZIVM[IVQ/009TIf`06V5VKF1WKV5XKf1XL61YLF1ZLV5[M6=]MFI`N6UcNfegOg5kPWJ0Qgb6
SH:;TXN?UHbDVI>KX9jUZJR]/K>g^/73aM3?d=gKfn[Vi_KclP;elo804>_YjN?Qh=_If=CAd<g:bLK2
`[nl^kVe]K>_[ZfXZ:NRXZ:MW9fGUYRATI><Rhj7QQWoool03l6UTl:XU/>ZV/B]WLJ`XLRcYLZgZ/bl
/<o1]]?6_MS=aMgEc^;MfN[WiN_Yj002i>7O01oKemKBclg;bLO7a<;1_[bj]kFd/Jn]ZjZXYJFTXJ2P
WIfMVYZKV9RJV9RJUiRJV9RKVYZMW9bRX:2WYJB]ZZVe/[2l^[S4`/3<b/SCdLoLf]SUi>7_k^chmoKm
ool00__mo@0@l_;`k>SUi^3Kh=WBg=;:elc2e<Jld<6ecKb`bkR[bKBVak6RaJjN`j^J`ZRG`JJC8?oo
o`007_ooo`0?HV]]GFEXF61RDeYLCEAFB4i@@TM9?452=CXk;S<d9b//82<T61/L41<D1`T:00862@X0
7a0C4a/L72HV9B`[:S4_;SHd<cdk>DA2?dU7A51<BEIBCe]FDf5KEfIOFfYSGfiWHW1ZI7A]J7QaKGUc
KgQcKgAbKWAbL7=cLG=dLW=eM7IhN7QkNg]nOWf0P8:5Q@02PhN70124R8V5RHZ5RXZ5RXZ4RHZ3R8V1
QhR0QHImQ8EkPX=iP85fOGmcNge`N7Y]MWQZLgDIoooo00i]L75WJfaRIFMMH69GFeeBEEM<D597Bde1
ADLl@48f>cda=SP/<C<W;2l38BLZ01lX;S8`=CPg?3hj?d8m@TDoADU4BTi:Ce=>DeIBEeYFFUiIGV5N
HVESIVUXJfe^L75aLgAgNGUmOWn1PH:3Q8F2QHN6RX^=TI:DUiRNX:2ZZZZd/k>o_Kg6a<G:b/T00/G5
a@0@`L71_;fm^;Rh/k>d[Zn_ZJZ[Y:FVWj2QVYbLUINHT9:CRhf>QXR9PH>5O7n0MgYk6?ooo`0?QWin
PgakP7UhOGIfNWAdMg5aM6m_LVe]L6]/KVY[KFUZK6QZJfQZJfUZJfU[009/JV`07fe/Kfi^LFm_Lfi_
Lfi`M6a`MFeaMW1cNG1dNW1eNg1eO71fOG9hOgEkPGQmQ7b2Qh25RXF:SXV>TXjAUI:FVIBIW9^OXjFY
Zjna];fm_/c9b]WEe>KPgnkZjO3]k002inGT013PgMcIe]GBclk;b<O5`L6o^kZi]KBc[jj^ZJVYY:>T
WijOVYVKUIBFT8nBRhZ=QXDIoooo00o1YI?2Z9K3ZYW4[9c6[j37/ZC9]ZS<^Zg?_k?Ba;WFb/7Kd<WP
f=;Uh=_/jNH00^g[j@0OinCRh=cKfMGCe=3?d<g<blS7al?2a;nn`Kbj_KRf^;>b]K2_/Zj//Jb[/:^Z
/:b[/Zf//jj/]:n/]k6]^kJb_kZfaL2lc<S4eM7>gm_HjNGRlNk[nOOeooono?km00;em?404>k[inSR
gN?Je=kDc=W=a=K8_];3^<nn//bj[LZfZ<RcY<J`X<F]WL>ZVL:XU/6VTb3oool001koool03f9[KUiW
JEYRI5EMGe1HFTaBE4M=Cd57BCa1@cHk?30d=RT^;b<W:1`O8A@H6@032`l@01hD61TP8R8W:2P[;B`^
;bld=C@k?3]0@Cm4AD=7B4M<C4]BDDmGEUAKFUMPGU]SHEiWIF5XIfA]JfQ[JVQXJVQWJVUWJf]XKFaZ
KVi/LG9bMWIeNGYgNgakOh02OH:2011oQ8B0QHF0QHJ0QHIoQHInQ8EmPhAkPX=jP89hOh1fOGmcNgea
NG]^MgU/MGMYLWDIoooo00m]L79YK6iTJ6UPHfEKGV1FFUaBEEM=DE=8C4i4B4Xo@dHj?d4f>cdb=cT]
<cH00RT^<@0O:C0c<3Hj>3e1?T=6@4I9@TQ;Ada@CE9ED5EHE5ULEUaOFUmRGf=VI6MZJFa^Kg5bLWAe
N7UiNWamPX:2PX>4PhJ7RHb<Si6BUiVIX:6QZJVY]K>c_Kbl_[jo_;fm00:i^KX04;Ff][6b/Zf^[jVZ
ZjFVYj6RXifNWiRJViBFUi2BThb>ShN:Rh>5Qgn1PgYmOgIiNaSoool02hIoOXAmO85jNWmhN7afMWYd
M7QbLWI`LGA_Kg=^KW9]KP02LFe^02=aKFmaKW1bL79bL79dLWEdLgIgMGUgMgYgN7agN7eiNWmkO85l
OH5mOh=nP8EnP8J1PXN4QHZ7R8b:Rhj=SI6BTYBDU9NKVY^MW9jQX::ZZ:Vb/;6m^[[9aLCCc/gPfMSY
i>?XiNCRgmh00]_He`0@e=7@c/[9b<C3`[jm_KVh^;>b/jj][ZVXZJBSYInOX9^JW9JFV9:AU8j=THZ9
SHF46Oooo`0?`JFC`ZNE`jVHa:bKaJjNak6RbKBVbkRZcKb_d<2ee<Jkf<_2g=;:hMWCin7L00;^jnP0
3no]jnWVi>?OgMoKfMcHe]WFe=OBdM?=c=3:b<o8alg7aL[3`LO0_/Jo_LJn_002aKjj00k7_k_8_k_9
`Kc<a;oAbLCId<_Of=?Wh=c_j^GelNgkn?Goookmo_gfmO42kn_V013Yh]cSfmCOe<cJc/GGbKkCa;S@
_k?>^jk;^:[9]:K7/J;6[io4[9_3ZYS2YiK1YI<Poooo000Noooo00mSK6mOJ6]LI6MHH69DFei@EeU<
DUA7CU12BDXn@dDh?T0c>3X]<S@W;2hQ9RP00Q/O8@0O4QLI41HG5Q`M8RHW:Bd^;C4a;c8b<SHf=SXj
>Shn?d=3@TI6A4Q8BDe=D5=CEUQFFE]JGEiLGV5PI6ETHfETHFEUHFIVHFMXHfUYIF]/IVe^KgAdLGIg
M7UjMWal009hOWl047YoP7^0PG^1PW^1PWZ1PWZ0PWV0PGQoP7ImOgElOW=kOG5iNfmgNVefN6]dMVUb
MAWoool03fiaLfY^KfIZK6=VJ5mRI5]NH5MKGE=GFDmCED]?DTQ<CTA8Bd15Ace1A3Tn@@02=S/n01lb
>3/d>Shi?d90ADU4BTe8CU5<DEA@EEQDFEaFFeiIGV9MHFEQIFMTIfYYK6i_LG5cM7IgN7QjNg^1PH62
PX>5QXN:S8b?TY:HVIVPX:2UYZNc/[:d];Fa/[:_/;000Zf][P0@ZZ^[YjRXXjBUX:6RWIjOVI^LUYNH
TYBESY2BRhf>QhZ;Q8J7P8>4OGn1NGamMGQj6?ooo`0:QgmoQGemPgakPGYiOgQhOGIfNgEeNGAdN79c
Mg9b0WIaLP03MG5bMW9cMW=d009hM7H037YgNGmlOWmmOgmmP7mnPH20Q8B3QXR6RHV8RhR7RhV8S8b:
SP:@SI004I6>TIBATYNDUIZFUYbHVJ:NWJBPX:VUYK2/[;Vd]<>m_<g6aM?=c=oJf=oKf]SEe=??cP02
cLW80138a<?3_[jn^KVi];Bd/:n`ZjZ/YjJXXj:TWYjPViZMUiJITi:FShjCS8^?R8N<QH@Ioooo00o1
YI;1YiG2Z9O3Zi[5[Ic6[j38/Z?:]JO<^:_>_;3A`KGEa[_Hbl;MdLWRf=800^OPf`0?kn[Wm?7_l>cZ
j>?Qh]gKhMcJh]gLhmgKh]cIg]OEfm?Ag=?AgMC@f]3;e/_600;DbL@03]?9`mC9`]G:`mO<aMcAb^;H
dNWOfNoWh_K^jO[dl?gjn?[imoC`k>kXhP;Xh=T04>?IdMkCb][=`mO8_M?3]m6o//jk[/bhZ/ZeY/Rb
XlJ_WlF]W<B[V/>YUl:WUL6UTR3oool001koool03fA]L65ZK5iVJE]SIEMOHUALGU5HFTeDETU@DTE<
CT58BSe3ACTo@3@j?2le=P02:Bla01lT:R`O9BLJ8B<L8bDV;2d/<S@a=SLc>CTf?3`g?Clj@D8nADM2
BDY5Bde:D59>E5EDFEYHG5aJGUiLH61NHF9MHV=LHV=LI6ENIFIRJ6USJVYZL75^LgA`MWMbNGX00WAj
O003MGamMWenMWen009fOGl02gImOWElOWAkOG=kO79jO71hNfmgNFefN6adMfYcMVQbM00Ioooo00m_
LWA/Kg5YK6iVJF]SIVQPHfELH69IGEmFFUaCEeU@E5I=DEA:Ce58C4i5BT`00T97BP0O@4I9?dE8?dE8
@DM;BDiBCE=GDeMJEEYMF5eOFEiQGF5UH6AWHfIXI6MZJFa_KG1aLWAeMWMgNW]kOWmoPX:2QHJ6RH^;
Si6BUIJFW9fNXZ>TZ:VZYZNXY:FVXjBT00:PXZ8049jPX9bMWYVKW9NHVIBFUi6CU8j@THb>ShV;S8J8
RH>5Qh23Q7f0PGYmOgQjO7EhNASoool02XN0OhInOXAmO89kNh5jNWmiN7ihMgegMWafMW]eM@=jMGD0
8gYeMW]fMgahNGahNGijO85mOhB1PhJ3QHR5R8Z7RXf9S8j;SHn<SY2=Si>?TIB?TIB?T9>?T9NBTYRC
TiZEU9bGUZ2KVZBNWZVRXJjXY[B_[[bg]/>m_<[5a=7=c=G@clk9b<W4`lC0_`02`;^j012l]kJg/[:c
[Zj`ZZZ/YjJYXj:UWinRW9^OVIRLUYFITi:FT8nCSHbARXV>QhJ<Q8<Ioooo00o0Y9;1YYC2Z9K3ZIS4
Zi[5[Ig6[j38/Z?:]JK<^:[>_:oA`;?Da;WHbKoLclH00^3Ec@0Oi]gFk>COlNcXlNcYkNKSjN?Oj>7N
j>3MimkKimgIimcHiMWChMG>gm?;gm;9gLo6f/c3fLc2flk5g=37g];9hmO?j=kFknGOln[UmNo[n_Kc
n?C`l>WTj^;KiM_C00;QeL`04=g?aMW:_mK5^]?1]M2m/<jj[<bgZ<ZdYLRbX/N_WlF]WLB[V/>YV<:X
U/6VU<2UTR3oool001koool03fA^LF9/KV1YJeiVJE]TIUUQHeINH5=KGE5HFTiEEd]BE4M>D4A;CD17
BCe3AP02>Cm201le?3ha>3/]=3LX;c8X<3<Z<cH`>3Xg?T0h@44i@D8kA4HoAdU3BTa5CDm8D55:DUA>
EEM@F5UEFeaGG5iIGUmKGf5KH65MHfAJH65LHfASJV]XKW1[LW=]M7I_MWP00W1gN@0@LGQjLWUkLWYk
LWYkLWYlLWUkLGUkL7QkL7QjKgMiKWIiKGEhK7AgJW=fJG9eJ75d6Oooo`0?L7=dKG5bJfi`JFa^IVY/
I6MYHVEWGf=UGF5SFeiPFEaNEUYLE5QJDUIID5EG009?DeH024eBEDaAE4aAE4]@E51EF5=IG5MKGUaP
HP9NHVD0461TIf9VJ6AXJVMZK6Y^Kfe`LG5dM7AfMgUjNgamOH20P8B5QHN8RXn@TI6BTiFGU`:IVi/0
0iRJViNIVYJHV@02UIJG012CUIJATiB?TI:=Si2;SHn9Rhf7RH^5QhV3QHN1PhEoPH=mOh5jOGmhNgef
NG]dMgTHoooo00Z8P7n7Ogj5OWf4OGb3O7^2Ng^1NWZ0NGUoNGUoN7P3OWQh02=nNGUoNWZ0Ng^0Ng^2
OGf4Oh26PX>:QHJAS8fDSY2CSHnDShnFTI:GTI:GT96FT92FT96GTI:JTi>KUIBOV9JQVYRSW9^VWifY
Xj6^Z:Nb[Jbk][G1_;_4`;o4`;k0^kZm^;Ji];>f/:l00[:][00@[jZY[:JUZJ>RYZ2OXifMXI^JWYRG
W9FEVI>BUi6@UHj=Thb;THZ9ShR7SHJ5Rh>26Oooo`0?`:BA`JFC`ZND`ZRF`jVHa:^JaJfLaZnNb;6Q
bK>TbkJWcKV[ckb_d/2deLFi00;IbKl01=g?aN7Dc>KJd^cSg0;bjN<02NgSgNWNfN[Of^[NfNSKe>GG
d>;DcN;Dc>;CbP02h]?800kQd/SQd/ORe<WSe/gTfm;XgmO]iMockNSekn[`jN;Zh=SUfM3PdlWLc/<2
fLVm013FaKSC`KC@_K3>^Zc<]jS:]JG9/Z?7/:36[Yk5[9c4Zi[3ZIS2Z9K2YiG1YY?0Y98Poooo000N
oooo00mUKW5TKG1RJfiQJVaOJ6YMIVQLI6MJHVEHH69FGV1DG5iBFUa?EeY=EEM;DUD00TQ@DP08ADe@
@d]=@4Q;?TI9?DI9?DE9>T=7?TI90T59C00E@TY<@TY=ADi?Be9DCEEFCeMIDUUKDeYLEEaNF5iPFF1R
Ff5SEUeOFf5TGVEWHFQZI6]]Ifi`JG5cJg9dK7Af009]MGL00fieMfifN6ifN002KWIi0VifN009KGIh
KGEhK7EgJgAgJgAfJW=fJG9eJ79dIg5d01Woool03g1dMFmbM6eaLVa_LFY]KfU/KVMZK6IYJfAWJF=V
J65UIV1SIEiRI5eQHeaPHP02FemQ01aJGV1IGF1IGF1IGV5KGf9LHFAMHFASIVQUJ6]TIfUUJ6YTJ6]V
JVaZKFm/Kg1^LG9aM7EcMWIfN7UiNg]lOWn3Q8F3Q8J8RX^9Rhb9S8f;SHj;SXl2Rhf>01>:S8f9Rhb9
Rhb8RX^7RHZ5R8V4QhR3QHN1Q8F0PhAoPH=mP85lOh1jOGmiO7ehNWafNG]eN7UcMWP06?ooo`05R860
Qh1oQgmnQWinQGim00:4OG`00h=lO8=lNh9kN`03PW]k02>2O7b3O7b3OGf3OGf4OWn6P828PX::QHF=
R8R@RXZCSHbHTI2HTY6GT92HTI6GTI6FT92GT96GTI2ITY6KU9>MUYFOV9NQVYRTWYb]YZF`ZZVd[Zbb
[J^`ZjZ`ZZV^Z:N[YJBYXj:WXJ000ZFNW@0@XYbKX9ZIWYRGWIJEViBCVI:AUi2@UXn>U8f<Thb;THZ9
T8R8SXN6SHJ5S8B3RX>26Oooo`0?`:BB`JFB`JJC`JJD`ZNE`jRG`jZHa:^JaJbLaZjNak2PbK:Rb[BU
c;NXc[Z/00;A_Jl04=?0]=K4^=W8_Mg=`^3Aa^;DbNKHcNOJcnKHc^GFcNGGc^CEcN7AbMk>aMc<`]c<
`0;Mc<003Mg<`Mc<`=k?`nCGcN[Ne^WNeNGIcn;Ebn3Aa]c<`MW8^mK3]m?0/P02dKf_013?^Z_=]jS;
]JG9/j?8/J77[ik6[Ig5[9_4ZiW3ZIS3Z9O2YiG1YYC1YY?1YI;0Y94Poooo000Noooo00mVKg9UKg5T
KW1TKG1SK6mRJfiQJVePJFaOJ6]NIfYMIVULIFMKI6IJHVEIHF@00UMPH`0OEUmQEEePE5aODe]NDU]N
DUYNDEYNDU]NDeaODe]ODeaODUYND5UMDEYNDU]MDeaNE5ePEEiPEUiPEUiQF61SGVIXGfMZHFU[HV]]
I6a^IFi`IfmaJ71cJG5dJG9d009ZLWD2JW=e1FYcMP9ZLgD3JG9e00AXLWAXLGAWLGAWLG<Ioooo00ma
M7I`M7E`LgA_LWA^LG=]L79]L75/Kg5[KW1ZKFmYKFmYK6iXJfeWJfeWJV`00VIZK0=VJF/2IVY/00IW
JfeXK6iZKFm[KW1ZKW1[Kg02JVi`00e]L79_LG9`LgAaM7IcMGMdMWQfN7UhNgamOh5lOX1mOh1mP85n
P88017j1PP0COX22OH21OH21OGn1O7n0O7j0NgioNWeoNWanNGamN7]mN7YlMgYkMWUkMGQjMGQiM7Mi
LgIhLgIg01Soool00hV1P8R1P8R0O`02Qh1o00B7Ogj6Ogj6Ogj6Ogh2QWin0XEnOP:6Ogh2QWmo00N7
P828PH29PX6:Ph>;Q8B=QXF>QhH00i29R0:ARXT02Y:<RYJ>SIN?SIRASiVBT9ZCTI^DTYfEU9nHUj6J
V@:NUiH01ifGUYfFUIbEU9^DTiZCTYVBTIRAT002Ui2?012FShjESXfDSHbCS8^BRhZARXV@RHR?R8N?
QhJ>QXF=QXF<QHB<Q8>;Ph::Ph::PX4Ioooo0/2TT@0=`:BB`JFB`JFC`JJC`ZJD`ZNE`ZRF`jVGa:ZH
a:^IaJbKaZfLajnN00;8/:001lZbX/^dY<ffY/jhZM2jZm6l[=:m[P03dkj_00KC_k3D`;7G`kCHaKGI
aKOIaKP2fLJh00gJakWJb;_KbKcHaKSE`KCD`;;C_[3A_:g@^Z_>^:S<]JK;/j?9/Z400/R`W`0>ajnN
aZfLaJbKaJ^Ia:ZH`jVG`jRF`ZRE`ZNE`ZJD`JJC`JFC`JFB`:BB0/2TTB3oool00?oooonAoooo003o
ooooTOooo`00oooooi7oool00?oooonAoooo0013oooo0`0005_oool30000Eoooo`<0001Koooo0`00
03Coool004Koool00`000?ooooooo`1Koooo00<0003oooooool0Eoooo`030000oooooooo05_oool0
0`000?ooooooo`0aoooo000boooo0P0000Coool400000_ooo`<00003oooo0`0000?oool20000?ooo
o`<00002oooo0P0000Coool400000_ooo`<00003oooo0`0000?oool20000>Oooo`<00004oooo0P00
00Coool400000_ooo`<00003oooo0`0000?oool20000=oooo`D00002oooo0P0000Coool200001?oo
o`@00002oooo0`0000?oool300000oooo`80000^oooo000aoooo00@0003oooooool00002oooo00@0
003oooooool00002oooo00<0003oooooool00oooo`040000oooooooo0000AOooo`040000oooooooo
00000_ooo`040000oooooooo00000_ooo`040000oooooooo00001Oooo`040000oooooooo0000@?oo
o`050000oooooooooooo000000;oool010000?ooooooo`0000;oool010000?ooooooo`0000Goool0
10000?ooooooo`0003koool01@000?ooooooooooo`000002oooo00@0003oooooool00002oooo00@0
003oooooool00002oooo00@0003oooooool00005oooo00@0003oooooool0000coooo000aoooo00@0
003oooooool00002oooo00@0003oooooool00002oooo100000;oool010000?ooooooo`0004;oool5
00001?ooo`040000oooooooo00000_ooo`030000oooooooo00@00002oooo00@0003oooooool0000o
oooo0`0000;oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool400000_ooo`040000
oooooooo0000?_ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00@0003oooooool00002
oooo00<0003oooooool0100000;oool010000?ooooooo`0003?oool0037oool010000?ooooooo`00
00?oool300000oooo`800004oooo1000047oool010000?ooooooo`0000?oool200001?ooo`<00003
oooo0P0000Coool40000?Oooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`<00003
oooo0P0000Coool40000?Oooo`030000oooooooo00Coool010000?ooooooooooo`800004oooo0`00
00?oool200001?ooo`@0000boooo000aoooo00@0003oooooool00005oooo00<0003oooooool0COoo
o`030000oooo000000?oool00`000?ooooooo`05oooo00<0003oooooool0B?ooo`040000oooooooo
00000_ooo`040000oooooooo00001Oooo`030000oooooooo04Soool01@000?ooooooooooo`000002
oooo00D0003oooooooooool000001oooo`030000oooooooo03goool003;oool200001Oooo`80001@
oooo0P0000?oool300001?ooo`80001;oooo0`0000?oool200001Oooo`800019oooo0P0000Coool2
00001?ooo`<00004oooo0P0003ooool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonA
oooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonA
oooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00M?ooo`<0000coooo0`00
06Woool30000Moooo`00Moooo`030000oooooooo03?oool00`000?ooooooo`1Yoooo00<0003ooooo
ool0M?ooo`00J?ooo`<00004oooo0`0000?oool300000oooo`800003oooo1@0000;oool200001?oo
o`80000:oooo0P0000?oool400000oooo`<00003oooo0`0000?oool3000000?oool0000000000_oo
o`8000000oooo`0000000003000000Coool000000000000:oooo0`0000;oool300000oooo`<00004
oooo10000004oooo0000000000001?ooo`<00003oooo0P0000Coool300002Oooo`<000002?ooo`00
00000?ooo`000?ooo`000?ooo`D00002oooo0`0000?oool300000_ooo`<0001[oooo001Yoooo00<0
003oooooool01?ooo`050000oooooooooooo000000;oool00`000?ooooooo`08oooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00coool010000?ooooooo`0000?oool00`000?ooooooo`04
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool01@000?ooooooooooo`000002
oooo00<0003oooooool0100000?oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`030000
oooooooo00?oool00`000?ooooooo`02oooo00@0003oooooool00005oooo00<0003oooooool00_oo
o`030000oooooooo00;oool200000oooo`030000oooooooo00_oool02P000?ooooooooooo`000?oo
o`000?ooo`000?ooo`@00002oooo00@0003oooooool00002oooo00<0003oooooool01_ooo`030000
oooooooo06Soool006Woool00`000?ooooooo`04oooo00D0003oooooooooool000000_ooo`030000
oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool03?ooo`040000oooooooo00000ooo
o`030000oooooooo00Coool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`050000
oooooooooooo000000;oool00`000?ooooooo`03oooo00D0003oooooooooool000003?ooo`030000
oooooooo00;oool00`000?ooooooo`03oooo00<0003oooooool00_ooo`040000oooooooo00000_oo
o`<00005oooo00D0003oooooooooool000000_ooo`030000oooooooo00@0000:oooo00T0003ooooo
ooooool0003oool0003oool000001?ooo`040000oooooooo00000_ooo`030000oooooooo00@00002
oooo0`0006_oool006Woool200001?ooo`800004oooo100000Woool00`000?ooooooo`02oooo0P00
00ooool010000?ooooooo`0000;oool400000oooo`800004oooo100000;oool200000_ooo`@00004
oooo0`0000?oool00`000?ooooooo`09oooo0P0000Coool00`000?ooooooo`03oooo00@0003ooooo
ooooool2000000?oool0000000000_ooo`@00003oooo0P0000;oool200000_ooo`800002oooo0P00
00[oool200000_ooo`<000000oooo`000?ooo`02oooo0`0000?oool400000_ooo`800003oooo1000
06[oool006Woool010000?ooooooo`0001Goool00`000?ooooooo`02oooo00<0003oooooool03_oo
o`040000oooooooo00009oooo`030000oooooooo00ooool00`000?ooooooo`03oooo00<0003ooooo
ool0/_ooo`00J?ooo`D00003oooo00<0003oooooool03_ooo`800004oooo0`0000ooool200002ooo
o`030000oooooooo00Woool00`000?ooooooo`0=oooo0P0000coool010000?ooooooooooo`800004
oooo0P0001;oool00`000?ooooooo`0Eoooo00<0003oooooool0Qoooo`00oooooi7oool00?oooonA
oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {199, 0}} -> {-0.251066, -0.0488477, \
0.0112836, 0.0112836}, {{22.25, 104.688}, {194.625, 112.188}} -> {-29.8025, \
-5.86047, 0.973745, 0.973745}, {{112.938, 195.375}, {194.625, 112.188}} -> \
{-118.109, -5.86047, 0.973745, 0.973745}, {{203.563, 286.063}, {194.625, \
112.188}} -> {-206.385, -5.86047, 0.973745, 0.973745}, {{294.25, 376.75}, \
{194.625, 112.188}} -> {-294.692, -5.86047, 0.973745, 0.973745}, {{22.25, \
104.688}, {103.938, 21.5}} -> {-29.8025, -94.167, 0.973745, 0.973745}, \
{{112.938, 195.375}, {103.938, 21.5}} -> {-118.109, -94.167, 0.973745, \
0.973745}, {{203.563, 286.063}, {103.938, 21.5}} -> {-206.385, -94.167, \
0.973745, 0.973745}, {{294.25, 376.75}, {103.938, 21.5}} -> {-294.692, \
-94.167, 0.973745, 0.973745}}]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "Similar to that of the shadowed color images, we generate the 16 illusive \
color image data by the three-dimensional wavelet transform.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
zillusion=Table[illusion[[j,i,k,l]],
\t{i,dim[[1]]},{j,rotation},{k,dim[[2]]},{l,dim[[3]]}];
wMat[[1]]=waveletMatrix[rotation,base[[1]]];
zSpect=Table[waveletND[zillusion[[i]],wMat,3],{i,dim[[1]]}];
aSpect=Table[0.,{dim[[1]]},{angle},{dim[[2]]},{dim[[3]]}];
Do[aSpect[[i,j]]=zSpect[[i,j]],{i,dim[[1]]},{j,rotation}];
wMat[[1]]=waveletMatrix[angle,base[[1]]];
wMatTrans=Table[Transpose[wMat[[i]]],{i,Length[base]}];
angleInc=Table[waveletND[aSpect[[i]],wMatTrans,3],{i,dim[[1]]}];
incIllusion=Table[imageNormalize[angleInc[[i,j]]],
\t{j,angle},{i,dim[[1]]}];\
\>", "Input"],

Cell[TextData[{
  "\t",
  StyleBox[
  "After converting the image data into color graphics one, we can get the 16 \
illusive color images as shown in Fig. 16.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
incIllusionG=Table[Show[convertRGB[incIllusion[[i]]],
\tPlotLabel->StringForm[\"``deg.\",Round[360*(i-1.)/angle]],
\tAspectRatio->dim[[2]]/dim[[3]],
\tDisplayFunction->Identity],{i,angle}];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[
\tTable[Table[incIllusionG[[i+j]],{j,0,3}],{i,1,angle,4}]],
\tImageSize->{400,400},PlotLabel->\"Fig.16. Increased illusive images\"];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0238095 0.238095 [
[.5 1.0125 -101 0 ]
[.5 1.0125 101 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Fig) show
81.000 12.813 moveto
(.16) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Increased) show
171.000 12.813 moveto
(illusive) show
225.000 12.813 moveto
(images) show
261.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.245293 0.245293 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(270) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
848483858484858584858584858585858685868685868686868686868786868787868787
878887878888878888878989878989878989878A8A878A8A878A8B878B8B878C8C888D8F
878B8B878A8A878A89878A8A888989888A89888A89898A8A898B8A898A8A8A8B8A898A89
898A8989888789888688868587858487858386848286838185818084807D837E7C827C79
807975827D7A837F7D83807E84817F848180848180848280848281848281848381848382
848382848382848383848483
858484858585858685868686868786868787878888878988888989888A8A888A8A898B8B
898C8C898C8D8A8D8D8A8E8E8A8E8F8A8F8F8A8F908B90918B91928B92938B93958B9497
8A92938A91918A90908B90908B8F8F8C8F8F8C90908D91908D91918D91908E91908E908E
8D8F8D8D8D8B8C8B898B89878A878589858388848187827F867F7C847C7882787480746F
7E726D807773827A77827C79837E7B837F7C847F7D84807E84817F84817F848280848281
848281848382848382848383
858584858685868786878787878888888989888A8A898B8B898C8C8A8D8D8A8D8E8B8E8F
8B8F908C90918C91928D92938D93948D94968E95978E96988E97998E989B8E999D8E9B9F
8D989B8D97988D95968E95958E95958F9595909696919695909695919695919594919392
9092908F8F8D8F8E8B8E8B898D89868B86838A838088807D867C7884787481746E7D6E67
7D6F697F746F817773827976837B78837C79837E7B847E7C847F7D84807E84807F84817F
848280848281848382848382
858584868686878887878888888989898B8B898C8C8A8D8E8B8E8F8C90908C90918D9293
8E93958E95968F96978F979990989A90999C919B9D919C9F919DA0919EA291A0A491A1A6
909EA1909C9E909B9C919A9B919A9B929A9A939A99939A99929A99939998949897939695
92959292939091918E918D8A8F8A878D86838B837F897F7A867A7584767080706A7D6A63
7E6E6780716C81746F827772827975837A77837C78847D7A847E7B847F7C847F7D84807E
84817F848280848281848382
858585868786878888888989898B8B8A8C8D8B8E8F8C90908D91928E92948E94958F9697
90979991999B929A9D929C9E939DA0949FA294A0A494A2A695A3A894A5A994A6AB93A7AC
93A3A793A1A493A0A2949FA0949E9F959E9E959D9D969D9D969E9D969D9C979C9B969A98
95979595959394928F938F8C918B888F86828D837E8A7E7987797384736D806D667D6860
7F6C6580706981736D827570837772837974837A76847B78847C79847E7B847F7C84807D
84807F848180848281848382
858685878787888989898B8B8A8C8D8B8E8F8C90918D92938E94958F959790979991999B
929B9D939D9F949FA295A1A496A3A697A4A898A6AA98A8AD98AAAF98ABB097ACB196ACB2
96A8AD96A6A996A5A797A3A597A3A398A2A298A2A299A2A199A2A199A1A0999F9E999D9C
999B9998989697959296928E948C899287848F837E8C7E7988787285716A806A627E675F
806B64816F6782716B82746E837570837772837974847A76847B78847C79847E7B847F7C
84807E84817F848280848382
868685878888888A8A8A8C8C8B8E8E8C90918E92938F949690969891989A939B9D949D9F
959FA296A1A497A3A798A5A999A8AC9AAAAE9BACB19CAEB49DB1B69CB2B89BB2B998AFB6
98ACB198AAAD99A9AB99A8A99AA7A79BA7A79BA6A69CA6A59DA6A59DA5A49DA4A29DA2A0
9C9F9C9C9B999B9894999490978E8B94898591837F8E7E7989777185706881695F80685F
816B63826E6682706983726C83746E837671847873847975847A76847B78847D7A847E7C
847F7D84807E848180848381
868686878988898B8B8A8D8E8C90908D92938F949590979892999B939B9E959EA096A0A3
97A3A699A5A99AA8AC9BAAAF9DADB29EAFB59FB2B8A0B5BBA2B8BEA4BBC29BB5BD98B0B6
99AFB39AAEB19BADAF9CACAD9DABAC9EABAB9FABAB9FABAAA0ABAAA0AAA9A1A8A7A1A6A4
A1A3A0A09F9C9E9A979D96929A908D978A8693847F8F7E788B777087706882685F826960
826B63836D66836F6883716B84736D84756F847671847873847975847B77847C79847D7A
847E7C847F7D84817F848281
868686888989898C8C8B8E8F8D91928F949590969892999B949C9E959EA197A1A498A4A7
9AA7AA9BA9AD9DACB19EAFB4A0B2B7A1B5BBA3B8BEA4BBC2A6BFC6A7C0C896B2BA98B1B8
9BB1B69CB1B49EB0B39FB0B1A0AFB0A1AFAFA2AFAFA3B0AEA4B0AEA4B0ADA5ADACA5ABA8
A4A7A4A3A19FA29D99A098949D928E998B87968680917F788D787089716984695F846A61
846C63846D65846F6784716984726B84746E847570847772847874847A76847B78847D79
847E7B847F7D84817F848281
868786888A8A8A8D8D8C90908E929390959792989A949B9D959EA197A1A499A4A89BA7AB
9CABAF9EAEB2A0B1B6A1B4B9A3B7BDA5BAC1A6BDC4A8C1C8ABC5CD9EBBC494B1BA9AB4BA
9DB4B99FB5B8A0B4B7A2B4B6A3B3B4A4B3B3A5B3B3A6B4B3A7B5B3A8B4B1A9B1AFA8ADAB
A7A9A6A6A4A1A59F9BA39A969F938F9B8D889786819380798F79718A726A866B62866B61
856C63856D64856E6685706885716A84736C84746E847670847772847974847A77847C79
847D7B847F7D84817F848281
868787898A8A8B8E8E8D91918F9495919799939A9C959EA097A1A499A4A79BA8AB9DABAF
9FAEB3A1B2B7A3B5BBA5B9BEA6BCC2A8BFC6A9C3CBADC8D0A3C1CA98B7C09AB7BF9DB7BD
A0B8BDA2B8BCA3B8BBA5B8B9A6B7B8A7B7B6A8B8B6A9B8B7ABBAB7ABB8B5ACB5B2ABB0AD
AAABA8A9A5A2A8A09DA59B96A194909D8D8898878194807A917A738C746C8A6F65876B61
866C62866C63866E65856F6785706985726B84736D84756F847671847873847A75847B78
847D7A847E7C84807E848281
878787898B8B8B8F8F8E929290959792999B959C9F97A0A399A4A79BA7AB9DABAFA0AFB3
A2B2B7A4B6BBA6BABFA8BDC4AAC1C8ABC5CCADC8D0A8C6CF9CBCC59DBCC49FBBC3A1BBC1
A3BCC1A5BCC0A7BCBFA8BBBCA9BBBBAABBBAABBCBAACBBB9AEBCB9AEB8B5AFB4B2AEAFAC
AEABA8ACA6A3ABA19EA79B97A394909F8E8999878196817A927B738E766D8C7067896C62
886B61876C62876D63866E65866F6785716985726B84746D847570847772847974847B77
847C79847E7B84807E848280
878887898C8C8C8F908F9394919798949B9D969FA198A2A59BA6AA9DAAAEA0AEB2A2B2B7
A4B6BBA7BAC0A9BEC4ABC2C9ADC6CDAFCAD2B1CED7A3C3CEA0C0CAA0BEC7A2BEC6A4BFC4
A7C0C5A9C1C5ABC0C2ABBEBFACBEBDADBEBDADBEBCAEBBBAB0B9B7B1B6B5B0B0AFB0ADAB
B1ACAAB0A7A4AEA19EA99B97A59490A08E899B878197817A937C7491776E8E72688B6E64
886A5F886B60886C62876D63866E65856F6785716A84726C84746E847671847873847A76
847C78847E7B84807E848280
8788888A8C8C8D90918F949592999A959C9E98A1A39AA5A89DA9AC9FADB1A2B1B6A5B6BB
A7BABFAABEC4ACC2C9AFC7CEB1CBD3B3D0D8ADCCD79EBFCAA1C0CAA3C1C9A5C0C7A7C2C7
AAC4C8AEC5C8AFC4C5AEC1C0B0C1BFB2C0BFADB9B8AEB7B6AFB3B2B0B1B0B1B1AFB3AFAD
B4ADAAB3A6A3B2A39FAC9D99A69490A08E899B8780978179947C7492786F90736A8E7065
8B6C618A6A5F896B60886C62866D64856E66856F6884716A84736D84756F847772847975
847B78847D7A847F7D848280
8788888A8D8D8D9192909697939A9C969EA099A3A59CA7AA9FACAFA1B0B4A4B4B9A7B9BE
AABEC4ADC2C9B0C7CEB2CBD3B4CFD8B7D4DDA6C7D2A0C1CBA2C1CBA5C3CBA7C2C8AAC4C9
ADC7CBB1C8CBB2C6C7B3C4C3AFBBBBADB6B6A9B1B0AEB2B1B0B1B0B2B2B1B4B3B2B4ADAB
B4ABA8B4A8A4B4A6A2AF9F9AA79591A18D889C8780988079957C7494797093756B907267
8E6D628C6A5D8A6A5E886B60866B61856C63846E6684706884726B83746E837671837874
847A77847D7A847F7D848180
8889888B8D8E8E9293919798949B9D98A0A29BA5A89EA9ADA1AEB2A3B3B7A6B8BDA9BCC2
ACC1C8B0C6CDB3CCD3B7D1D9B8D4DCB6D5DFA0C2CEA1C2CCA4C2CBA7C3CBA9C3C9ACC5CA
B0C8CDB4C8CBB3C5C5B3C1C0A9B4B5ABB5B5AEB5B5B0B5B4B2B6B6B5B7B6B7B7B5B6B2AF
B7B0ADB5ABA7B3A7A4AE9F9AA99893A18E899C8680987F79977C74967A7195776D937368
916F638F6B5E8C6A5F89695E86695F846A61846C64836E6783706983726D837570837773
837A76837C79847F7C848180
8889898B8E8E8F9394929899969D9F99A2A49CA7AA9FACAFA2B1B5A6B6BAA9BBC0ACC0C6
AFC5CBB3CAD2B7D1D9BED9E1BBD8E1ACCDD99DBFCBA2C2CCA6C4CCA9C4CBABC4CAAEC6CB
B2C8CCB2C4C7B0BEBFADB8B9A8B2B3ADB4B4B0B6B6B3B7B6B5BAB9B8BAB8B9BAB7B9B6B3
B9B2B0B7ABA8B5AAA5B1A29CAC9B95A3918B9B857F987F78987C74987B7298796E96756A
937064916C608D695C89685B84655C83685E836A61836C64826F6882716B83746E837672
837975837C79847E7C84817F
8889898C8F8F90949593999B979FA19BA4A79EA9ACA1AEB2A4B3B8A8B8BDABBDC3AEC3C9
B1C8CFB4CDD5BAD4DDC0DCE5B3D2DCA0C2CEA0C0CBA4C3CCA8C4CCABC4CAADC4CAB0C7CB
B3C7CBB3C3C6B0BCBEAFB9BAAFB7B7B1B6B6B3B6B6B4B7B7B7B8B8B9B8B8BAB7B6BAB3B2
BAAFADB8ABA8B5A9A4B2A29DAD9B96A6938D9C857F997E78997C749A7C739A7A6F98766B
967266946F62936D5F88655983635982655B82685F826A62826D6682706982736D827571
837874837B78837E7C84817F
888A898C8F90909596949B9C98A0A29CA6A8A0ABAEA3B1B4A7B6BBAABBC1ADC0C6B0C5CC
B2CAD2B5CFD8B8D4DDB5D4DFA8C9D49FC0CCA4C3CDA7C4CCAAC4CBADC4CAAFC4CAB2C6CA
B4C6CAB4C3C6B1BCBEB2BBBBB2B9BAB4B9B9B6B9B9B8BAB9BABCBABCBBBABDB9B7BDB6B3
BCB2AEBBADA9B7A8A3B3A09CAD9893A68F899E857F9A7E789B7D759C7D749C7C709B786C
987367977062966E5F83605381605580625880665C816960816C64816E6882726C827570
827873837B77837E7B84817F
898A8A8D9090919697969C9D9AA2A49EA8AAA2ADB1A5B3B7A9B9BDACBEC4AFC3CAB2C8D0
B4CDD5B6D1DAB6D5DFB2D2DDAECCD7AAC7D1A9C5CEABC5CCADC4CAAFC5CAB1C4C9B3C6CA
B5C6CAB5C4C6B5BFC1B4BCBDB5BBBBB7BBBBB9BCBBBBBCBBBDBDBCBFBDBCC0BCB9C0B8B5
BFB4B0BDAFAAB8A9A3B4A19CAE9993A9918AA389829E827B9D7F769E7F749E7D719D796C
9A7467997163996F5F825E517E5D517F60567F635A80675E806A62816D6681706A82746E
827773837A77837D7B84817F
898A8A8E9191929798979D9F9BA4A6A0AAADA4B0B3A8B6BAABBCC1AFC1C7B2C7CDB4CCD3
B6D0D9B7D4DEB7D6E1B6D4DEB3D0D9B0CBD3ADC7CFAEC5CCB0C5CAB2C5CAB4C5CAB5C6CA
B7C7CAB8C5C8B7C2C3B7BDBEB7BCBCB9BDBCBBBFBDBEBEBDC0BFBEC2C0BDC3BEBBC3BAB6
C1B5B0BEB0ABB9A9A3B4A19AAF9992AA928AA58B83A1847BA08278A18176A07E729E796D
9B75689A72639B7060815D507D5B507D5E537E61577E655C7F6860806C65806F6981736D
827672827976837D7A84807F
898B8A8E9192949899989FA09DA5A8A2ACAFA6B2B6AAB9BDAEBFC4B2C5CAB5CAD1B7CFD7
B9D4DDBAD8E2B9D8E2B9D6DFB6D1D9B2CAD2AFC8CFB1C6CCB2C5CBB4C6CBB6C7CBB7C7CB
B9C8CBBAC6C9BBC4C5BAC0C0BABDBDBCBEBDBEC0BEC0BFBEC2C0BEC5C2BEC5BFBBC5BBB7
C2B5B0C0B0ABBAA9A2B5A19AB09992AB928AA78C83A4867DA4857AA38277A17E729F7A6D
9C75689A72639A70618460537B594D7B5B507C5F557D63597E675E7F6A63806E6881726C
817571827975837D7A84807E
8A8B8B8F929295999A9AA0A29FA7AAA4AEB1A9B5B9ADBCC0B1C2C7B5C8CEB8CED5BBD4DB
BCD8E1BDDCE6BDDBE4BCD8E1B7CFD6B3CAD1B2C8CEB4C6CCB5C6CBB7C7CBB8C8CCBAC9CC
BBC9CBBCC7CABDC6C7BDC2C2BCBEBDBEC0BEC0C1BFC3C1BFC5C3C0C8C3C0C9C1BDC7BDB8
C5B6B1C1B1AABCA9A2B7A19AB19991AC938AA98D84A98A80A8877CA58478A38073A07B6E
9C7568987062936C5E8561537C584C78574C7A5C527C61577E655C7F69617F6D6680716B
817570827875837C7983807E
8A8B8B909393969B9B9CA2A3A1A9ABA7B1B3ACB8BBB1BFC3B5C6CBB9CCD2BCD2D9BFD8E0
C1DEE7C2E1EAC1DEE6BED6DEB8CCD3B5C9D0B5C7CEB6C7CDB7C7CCB9C9CDBBCACEBCCACD
BECACCBFC9CBBFC7C8BEC3C2BEC0BFC0C1BFC3C3C0C5C3C0C8C5C1CBC5C2CCC3BECABEB8
C7B8B2C3B1ABBFAAA2B8A299B29990AF948AAD9086AC8D82AB8A7EA8867AA48175A17C6F
9C7668967062906B5D8660527A54477452467A5A4F7C5F557D645B7E68607F6C6580706A
81746F827874827C7983807E
8B8C8C919494979C9D9EA4A5A4ACAEAAB3B6AFBBBEB4C2C6B9CACEBDD1D6C1D7DEC4DDE5
C6E3EBC7E3EBC4DDE4BED1D9B8CAD1B5C8CFB7C8CDB8C8CDBAC9CDBCCACEBDCBCFBFCCCF
C0CCCEC1CACCC1C8C8C1C4C4C1C2C0C3C2C0C5C4C0C7C4C0CAC6C2CDC6C2CEC4BECDBEB8
C9B8B2C4B1AABFAAA1B9A198B49A91B2968CB09388B09085AE8C80AA887BA68376A27D6F
9D7769977061916B5D8761527E56477B574A7B5A4F7C5F547D63597E675F7F6B647F6F69
80736E817773827B7983807E
8B8C8C929595999D9EA0A6A7A6AEB0ADB6B9B3BEC1B8C6CABECED2C3D5DBC7DCE3CAE3EB
CCE7EFCCE4EBC7DBE2BECFD6B7C8CFB7C8CEB8C8CDBAC9CEBCCBCFBECCD0C1CDD0C2CED0
C3CECFC4CBCCC3C9C9C3C5C4C3C3C1C4C3C1C7C4C1C9C5C1CCC7C3D0C7C2D1C4BFCEBFB8
CBB8B1C6B1A9C0A9A1BBA299B89D93B6998EB5968BB39387B18F82AD8A7DA98477A47E70
9F776A987162926C5D8A625382594A7E584B7C5A4E7C5E537D62587D665D7E6A637F6E68
80726D817773827B78837F7E
8C8D8C9396969B9F9FA2A8A9A9B0B2B0B9BBB7C2C4BDCACDC3D2D6C8DADFCDE2E8D2EAF1
D5EBF2D3E6ECC9DAE1BCCDD3B7C7CEB8C7CDB9C8CDBBCACFBECCD0C1CED1C4CFD1C5CFD0
C6CFCFC6CCCCC5C9C8C4C5C4C4C3C1C5C3C0C8C4C0CBC6C2CFC8C3D2C8C3D3C5BFD1C0B9
CDB9B1C8B2A9C3ABA2BFA59BBCA096BA9C91B9988DB69588B49083AF8B7EAB8577A68071
A0796A9A7364946E608C6355845D4E7E56487D594C7C5C517C60567D655C7D69617E6D67
7F726C807672827B78837F7D
8C8D8D9497979DA0A1A4AAAAACB3B4B4BCBEBBC5C8C2CED1C8D7DACEDFE3D4E7ECDAF0F6
DEEFF4D6E5EAC8D8DDB9C9D0B6C6CCB7C6CCB9C8CDBCCACEC0CDD0C4CFD1C7D0D1C8D1D1
C9D0D0C8CDCDC7C9C9C5C6C4C5C3C1C6C3BFC8C4C0CCC6C1D0C8C3D4C9C3D5C6BFD3C0B9
D0BAB2CBB3AAC7ADA3C4A89DC1A398BF9F93BC9B8FB9978AB69284B28D7FAE8779A88272
A37B6C9D75669770618E6556855D4E7D53447C574A7C5B4F7C5F557C635A7D68607E6C66
7F716C807571817A77837F7D
8D8E8D9698989EA2A2A7ACACB0B5B7B8BFC1C0C9CBC8D2D5CEDBDFD4E4E8DAECF1DFF2F7
E1EFF2D6E2E7C6D4DAB3C4CCB3C3C9B6C5CBB8C7CBBDC9CDC2CED0C7D0D2CBD3D4CDD3D3
CDD2D1CACECDC7C9C8C5C5C4C4C2C0C5C1BDC8C2BECDC5C0D2C8C2D6C9C3D7C6C0D5C1BA
D3BBB2CEB5ABCCAFA5C9ABA0C6A69AC2A195C09D90BB978AB89385B48E7FB08879AB8373
A57D6DA077679B7262906858845B4C7C51427B55477B594D7B5D537B62597C665F7D6B65
7E706B7F7571817A77837F7D
8E8E8E979998A0A3A3AAAEAEB3B8B9BCC3C4C5CDCFCED7D9D5E1E4DBE9EDE0F1F5E5F4F7
E8F2F4DAE3E6C3D1D6AEC0C8AFC0C7B3C2C8B7C4C9BCC8CCC2CCCEC7D0D0CCD2D2D0D3D1
CFD1CFCACCCCC5C6C6C4C4C2C3C0BEC2BCB9C7BFBBCCC3BED2C7C2D7C9C3D9C7C0D8C2BA
D6BEB3D2B7ACCFB1A6CDADA1C9A99CC6A496C39F91BD988BB99485B68F80B28A7AAE8474
A87E6EA378689D73638F66568158497A4E3E79524579574B795B517A60577A655D7C6A63
7D6F6A7F7470807976827E7D
8E8F8E989A99A2A5A5ACB0B0B7BBBBC1C6C7CBD2D3D5DDDEDEE7E9E4F0F2E7F5F8E8F4F6
E9EFF1D5DEE2BECCD2A8BBC3ACBDC4B0C0C5B5C2C6BAC6C9BFC9CBC5CDCDC7CDCDCCCFCE
CACDCBC3C6C6BFC0BFBCBDBCBBB8B6BDB6B3C5BCB7CCC1BCD3C7C1D8C9C2DBC8C0DBC4BB
DBC2B6D5B8ACD5B5A9D4B2A4D0AD9FCAA598C59F92BE998BBB9486B79080B48B7BAF8574
AA806FA67B6AA074638F6555805546774B3C775043775549775A4F785E5579635C7A6962
7C6E687E736F807976827E7C
8F8F8F999A9AA4A6A6AFB1B1BABDBEC5CACAD1D6D7DDE3E4E9F0F1F3FCFDECF7FAEAF2F4
E7ECEDD5DCDFBBC9CFA4B7BFA8BAC1ADBDC2B3C0C4B8C3C6BDC6C7C2C9C9C4C9C9C7CACA
C1C5C5BBBFC0B8BABAB6B7B6B8B5B3BEB6B2C5BAB5CCC1BBD3C7C1D9CAC2DCC8C0DCC4BA
DBC0B4D6B7AADAB7A9DBB6A6D1AD9FCAA597C7A192BF9A8BBB9586B78F80B58B7AB18674
AD8170AB7D6BA375638F64547D5344754A3B754F4175534775584D765C5477625A796761
7B6D677D726E7F7875827E7C
8F8F8F9B9B9AA6A7A7B1B3B3BDC0BFCACDCDD7DADAE5E9E9F7FBFBFAFFFFEEF5F7EBEFF0
E6E9E9D1D8DBB6C5CC9FB3BCA5B6BDAABABFB1BFC2B6C1C3BAC2C3BFC5C5C2C6C6C3C6C5
C1C3C2BDBFBEB9B9B8B7B5B4BAB5B2BFB6B2C5BAB5CDC1BAD4C7C0DAC8C0DCC7BFDCC3B9
DABEB3D7B7ABD7B6A8D8B4A5CAA99BC7A395C39E90B99688B69183B58C7CB68A79B48775
B18371B1806DA374628D635379534473483A724C3F72514572554B735A5275605877655F
796B667C716D7E7774817E7C
908F8F9B9B9BA7A8A7B3B4B4C0C1C1CDCFCFDBDDDDEBEDEDFDFFFEF7F9F9EFF2F3E5E8EA
DDE1E2C6D1D5B0C0C79BB0B9A1B3BAA7B6BBADBABDB3BCBFB9C0C1BDC2C2C1C4C4C3C5C3
C2C2C1BFBEBCBCBAB8BBB7B5BBB4B1C0B6B2C6BBB5CEC1BBD5C6BFDAC7BFDDC8BEDDC4B9
DBBEB2D8B8ABD7B5A7D3AFA1C6A699C3A093BE9B8DB69385B69081B88D7CB88B79B78875
B68572B5826EA173608961517651436F45376E493D6E4E426F524970584F725E5674645D
776A657A706C7D7774817D7B
90908F9C9C9BA9A9A8B5B6B5C2C3C2D0D1D0DEDFDEEEEFEEFFFFFEF8F8F8EFF0F0E3E5E7
D4DADDC0CBD0ABBCC29AAEB69EAFB6A4B2B7AAB5B8AFB8BAB4BABBB8BCBCBCBDBCBABCBB
BABABAB8B7B6B8B5B4B8B3B1BAB2AFC1B7B2C8BCB6CFC2BBD5C5BDDAC7BDDDC7BCDFC5B9
DEC0B3DAB9ACD7B5A7D2AFA1CCA89AC7A294C19B8DBC9686BC9382BC907DBC8D7ABB8B77
BC8874B8836E9F715F835D4E7651436C43356A463A694A3F6A4F466C554D6F5B5472625C
756863796F6B7C7673807D7B
91908F9D9D9CA9AAA9B6B6B5C4C4C3D1D1D0E0E0DFEFEFEEFFFEFDF8F7F6ECEDEDDFE2E3
D0D7D9BCC8CDA8B9BF99ADB59BACB3A1AFB3A7B2B4ACB4B6B1B6B7B4B7B7B6B6B6B5B5B5
B7B5B4B7B4B2B8B4B1B9B3B0BEB5B2C4BAB4CBBFB9D0C3BBD6C4BCDAC5BCDCC5BADEC2B7
DEBFB2DCBAACDAB7A8D4B0A1CFAA9ACBA495C79F8FC39A89C29684C09380BF8F7BBF8D78
C28C76B7826C9C6F5C825D4E7953446E463864423663463B654B4267524A6B58526F5F5A
736662776E6A7B7572807C7B
91908F9D9D9CAAAAA9B7B6B5C5C4C3D2D2D0E1E0DEF0EEEDFFFDFBF7F5F4EBEBEBDCE0E1
CDD4D7B8C5CAA7B7BE98ACB499AAB09EACB0A4AFB1AAB1B2AEB3B3B2B4B4B5B5B4B7B6B4
B9B6B5BAB6B4BCB7B5BFB9B5C3BBB6C7BDB8CDC1BBD2C4BCD6C5BCD9C5BADBC3B8DCC1B5
DDBEB0D9B8ABD7B4A6D4AFA0D3AB9CCFA796CCA290C89D8BC59986C2937FC1907CC48F7A
C58D76B47F6A9B6D5B865F4F77524369433657382D5B40365E473E624E4767554F6B5D58
706560756C697A74727F7C7A
91908F9E9D9CABAAA9B8B7B6C5C4C3D3D1D0E1DFDEF0EDECFEFCFAF5F3F2EBEAEADBDFE0
CBD2D5B8C4C8A8B7BD9AADB499A9AF9DA9AEA2ACAFA8AFB0ADB1B1B1B3B2B5B5B3B8B6B4
BAB8B6BDB9B6C0BBB8C3BDB9C7BFBACBC1BBD0C3BCD4C6BDD7C5BCDAC5BADBC3B7DDC1B4
DDBEB1DBBAACD9B5A7D4AFA0D0A99ACCA494CAA08FC69B89C59784C4947FC6927DC8907A
C58C75B07C689A6B59855C4D714D3F603E324F3229533A3158423A5D4A4362524C685A55
6D635F736B687973717F7C7A
91908F9E9D9CABAAA8B8B7B5C5C4C2D3D1CFE1DFDDEFEDEBFEFBF9F5F2F1EAE9E9DBDEDF
CBD2D4BAC5C8ABB9BE9EAEB599A9AE9BA8ACA1AAADA7ADAEACAFAFB1B2B1B5B5B3B9B7B5
BDB9B7C0BCB9C3BEBBC7C0BCCBC2BDCFC4BED3C6BFD7C8BFD9C6BCDBC5BADCC4B8DEC2B5
DEBFB1DDBBADDAB6A7D7B1A1D2AB9BCFA695CBA08EC99C89C99985C99682CA947FCB917B
C38A73AD79659668568159496B493C573A304830264A342C503D365746405D4F4A645853
6B615D716A677872707E7B7A
91908F9E9D9CABA9A8B8B6B5C5C3C2D3D0CFE1DEDCEFECE9FDFAF7F4F0EEE9E8E6DBDDDE
CDD2D4BDC6C9AFBABFA1B0B59AA9AF9AA6AA9FA9ABA6ACACACAEAEB1B1B0B6B5B3BBB8B5
BFBBB8C3BEBBC7C1BDCAC3BECEC5C0D2C7C0D6C9C1D9C9BFDBC8BDDDC6BBDEC5B8DFC2B5
E0BFB1DFBCADDDB7A7DAB2A1D7AD9CD4A997D2A491D0A08CCF9C87CF9984CF9680CD927B
BF8670A875619164537B55466545394F362C402B233F2C2548373151423C594C47615651
685F5C6F686676726F7D7B79
91908F9E9C9BAAA9A8B7B6B4C5C2C1D2CFCDE0DDDBEEEAE8FCF8F5F2EFECE8E6E5DBDDDC
CED2D3BFC7C9B1BBBFA3B1B59CAAAF98A5A99FA7AAA6ABABACAEAEB2B2B0B8B6B3BDB9B6
C1BCB9C6C0BCCAC3BECEC5C0D2C8C2D6CAC2D9CBC2DBCAC0DDC9BEDFC7BBE0C5B8E1C3B5
E1C0B1E1BCADDFB8A7DCB3A2DAAF9DD8AB98D7A693D5A38ED39E89D29B85D29780CA8F78
B7806BA1705D8A5F4F734F425B3F33452F2736241D35241E41322C4B3E395549455D5350
665E5A6D676575716F7D7A79
91908F9D9C9BAAA8A7B7B5B3C4C1BFD1CECCDFDBD9EDE9E6FBF6F3F2EDEAE7E4E3DCDCDB
D0D3D3C3C8CAB3BCBFA6B2B79DABB099A6AA9FA7A9A7AAABADAFAEB4B3B1BAB6B4BFBAB7
C4BEBAC9C2BECDC5C0D1C8C2D5CAC4D9CCC4DCCDC3DECCC1E0CABFE1C8BBE2C6B8E2C4B5
E3C0B1E2BDACE1B9A8DFB5A3DEB09EDCAC99DAA994D9A48FD7A08AD69C85D1967FC48B74
B07B66996A5880594A68483C50372D3A28212819142D1F1B3B2E2A473B375147435B524E
635C596C666474706E7C7A79
91908F9D9B9AA9A7A6B6B4B2C3C0BED0CDCADEDAD7ECE7E4FAF4F1F0ECE9E6E3E2DCDCDB
D2D4D3C5C8C9B6BEC0ABB4B8A1ADB09EA9ABA1A7A9A8ABABAFAFAEB6B3B1BCB8B4C2BCB8
C7C0BCCCC4BFD1C8C3D5CAC4D9CDC6DCCEC6DFCFC5E1CDC2E2CBBFE3C9BBE4C6B8E4C4B4
E4C0B0E4BDACE3BAA8E1B5A3E0B19EDEAD99DDA994DCA58FDAA18AD69B84CD927BBC846F
A774618E63527652445E403546302730211A20130F2C201C382D294439364E454258514E
625B596B666473706E7C7A79
908F8E9C9B9AA9A7A5B5B2B1C2BEBCCFCBC8DCD8D5EAE5E1F9F2EFEEEAE7E6E2E0DCDBD9
D3D3D2C7C9CABBC0C1B0B7B9A6AFB2A4ACAEA5AAABAAACACB1B1AFB8B5B2BFBAB6C5BEBA
CAC3BED0C7C1D4CBC4D9CDC6DDCFC7DFD0C6E2D0C5E4CEC3E4CCBFE5C9BCE5C6B7E5C3B4
E6C0B0E5BDACE4BAA7E3B5A3E2B29EE1AE99E0AA94DEA58FDAA08AD49981C88D77B37E69
9C6D5A835B4B6C4B3D543A2F3A28202419141A100C291F1B362C294139354C454257504D
605B586A656373706E7C7A79
908F8E9C9A99A8A5A4B4B1AFC0BDBACDC9C6DAD5D2E7E2DEF6EFECEDE8E5E5E0DEDCD9D8
D4D3D2CACBCBBFC2C2B5BABBAEB3B5ABB1B2A8ADADADADADB4B2B0BBB7B4C2BCB8C8C1BC
CEC5BFD4C9C3D8CCC5DDCFC7E0D1C8E3D2C7E5D2C6E6CFC2E6CCBEE6C9BBE6C6B7E7C4B3
E7C0AFE6BDABE5B9A7E5B5A2E3B29DE2AD99E2A994DEA58ED99E87CE947DBD8671A77562
8F64537753455F42374631282C1E19160D09180F0C271E1B342C294038364B444255504D
5F5B58696563726F6E7B7A79
908E8D9B9998A6A4A2B2AFADBEBAB8CAC6C3D7D2CFE4DEDBF2EBE7EDE6E3E4DFDCDCD9D7
D6D3D2CDCCCAC3C4C3BBBDBCB5B8B8B1B4B4ADB0B0B1B0AFB8B4B2BFBAB6C6BEB9CCC3BD
D3C7C0D8CBC3DDCEC5E1D0C7E5D3C8E7D3C8E8D2C5E9CFC2E8CCBDE8C9BAE7C6B6E8C3B3
E8BFAEE7BCAAE6B8A5E5B4A1E4B19CE3AC97E1A892DCA38CD49982C58C77B27D699A6C5A
825B4C6B4B3E533A303928212117121008061B131127201D332C2A3F39364A444255504E
5F5B5969656472706E7B7A79
8F8E8D9A9897A5A3A1B0ADABBBB8B5C7C3C0D3CECBE0DAD6EEE7E3EBE4E0E4DEDBDDD8D5
D7D3D0D0CDCAC7C5C4BFBEBDB9BAB9B6B7B6B4B4B3B6B3B1BCB7B3C3BDB8CAC1BBD1C6BE
D7C9C1DDCDC4E1D0C6E5D2C7E9D5C9EBD5C8EBD2C5EBCFC1E9CBBCE9C8B8E8C5B5E8C2B1
E8BEADE7BBA8E7B7A4E5B39FE4AF9AE2AB95DEA58FD79E87CB927CB8836FA374618C6353
7552455F42374531282B1E19170F0D0B06041A141227211F332E2B3F3A384A454355504F
5F5B5968666472706E7B7A79
8F8D8C999796A3A19FAEABA9B9B5B3C4BFBDCFCAC7DBD5D1E7E0DCE9E2DEE4DDD9DED8D4
D6D1CFD1CDCAC9C6C4C1BFBDBDBBBABAB9B7BAB7B5BBB6B3C1BBB6C7BFB9CEC2BBD6C8BF
DCCBC2E1CFC4E5D1C6E9D3C7EDD5C8F0D6C8EED2C4ECCEBFEACABAE9C6B6E8C4B3E8C0AF
E7BDABE6B9A6E5B5A1E4B19CE1AC97DEA792D7A08ACE9680BD8874A97966946A597D594A
66483D4F382E3526201E15120B06040A06041A1514282321342F2D403B394B4645555150
5F5C5A69666572706F7B7A79
8E8D8C989695A29F9EACA9A7B6B2B0C0BCB9CBC5C2D5CFCCE0D9D5E8E0DCE4DCD8DDD6D3
D7D1CED2CCC9CBC7C3C3C0BDC0BCBABDB9B6BEB9B6BEB9B5C3BCB6C8BFB9D1C3BCDBC9BF
E1CDC2E5D0C5E8D1C5ECD3C6F0D5C7F1D4C5EED0C1EBCBBCEAC8B8E8C4B4E7C1B0E7BDAC
E7BAA8E4B6A3E2B19DE0AD98DCA893D6A18CCD9782C08B77AE7E6B9A6F5E845F506D4E42
563E343E2D26261C18120D0B0301000F0C0A1D1917292524353230413D3C4C4847565351
605D5C69676672716F7B7A79
8D8C8B979594A09E9CA9A6A4B3AFADBCB8B5C6C1BED0CAC6DAD3CFE4DCD8E3DBD6DCD4D1
D7CFCCD1CBC8CCC6C3C4BFBDC0BBB8BFBAB6C0BAB6C2BAB6C4BCB6CABFB8D3C3BBDBC8BD
E0CBC0E3CDC1E7CEC1EBD0C2EED1C2EDCFC0EBCBBCE8C7B8E7C4B3E5BFAFE4BCABE4BAA8
E2B6A3DFB19EDCAB98D8A793D2A08CCB9884BE8C79B0806E9C72628863547354475C4339
44322B2D221D19131007060402010012100F201D1C2C2928383433433F3E4D4A49575453
605E5D6A68677371707B7B7A
8D8C8B9594929E9C9AA7A4A2B0ACAAB8B4B1C1BCB9CAC4C1D3CDC9DDD5D0E1D9D5DBD3CF
D6CECBD0C9C6CBC4C1C3BEBBC1BBB8C1BBB7C3BBB7C5BCB7C7BDB7CCC0B8D3C3BAD9C6BB
DDC8BCDFC8BCE3C9BDE5C9BBE7CABBE7C8BAE5C6B7E4C2B2E1BEAEDFBAAADEB7A6DDB3A2
DAAF9DD7AB98D2A491CD9E8BC59684BC8D7BAD81719E75658A675876584B61483E4A3730
3226211E18150E0B090000000806061715142421202F2D2C3B38374542414F4D4B585655
62605F6B69687372717C7B7A
8C8B8A9493919C9A98A4A19FACA9A7B4B0AEBDB8B5C5BFBCCDC7C3D5CECADDD4D0DBD2CE
D4CCC8CEC7C3CAC3BFC5BEBAC4BCB8C3BBB6C5BCB7C5BBB6C7BCB6CDBEB6D2C0B7D6C1B7
D8C3B7D8C2B6DDC4B7DDC2B5DFC3B5DEC1B3DDBEB0DBBAABD7B6A7D4B1A2D2AE9ED1AA9A
CDA695C9A08FC29989BD9382B48A7BA981729A75678A695B775B4F644C424F3C35382C26
211B18120F0E020101030303100F0F1D1B1B2827263432313E3C3B484645514F4E5A5957
6361606C6A697473727C7B7A
8C8B899391909A9896A29F9DA9A6A3B0ACAAB8B3B0BFBAB7C6C0BDCEC7C3D6CECAD9D1CD
D2CAC6CDC5C1C9C1BDC6BDB9C3BBB7C1B9B4C5BBB5C5BAB4C7BBB4CDBDB4CEBDB3D1BDB3
D3BEB2D3BDB2D6BEB2D5BCB0D6BBAED5B9ACD3B5A8CFB1A4CBAD9FC8A99BC6A597C3A192
BE9B8DB89587B28F80AC887AA38072967568876A5E775D52654F4751403A3C302C27211E
1512110504040203030E0E0E1918182422222E2D2C38373642403F4B49495452515D5B5A
6563636D6C6B7574737D7C7B
8B8A8992908F9896959F9C9AA6A2A0ACA8A6B3AEACB9B4B1C0BAB7C7C0BDCDC6C2D4CBC8
D0C6C3CBC2BEC7BFBBC3BBB7C1B8B4C1B8B3C3B9B3C4B9B2C5B8B1C9B9B0C9B8AECBB8AE
CCB8ADCCB7ADCDB7ABCDB5AACCB3A7C9B0A4C6ACA0C3A99DBEA497BBA093B69B8EB3968A
AD9084A78A7EA284789C7E7292756A846A60765F5565524A53443E4036312D27251B1917
0809080404050E0E0E1717172120202B2A293433333E3C3C4645444F4D4D5756555F5E5D
6766656E6D6C7675747D7C7B
8A8988908F8E9694939C9A98A29F9DA8A5A2AEAAA7B4AFACBAB4B1BFB9B6C5BEBAC9C2BE
CAC2BEC8BFBBC4BCB8C1B8B4BFB6B1BDB4AFBFB5AFC0B5AEC0B3ACC3B4ACC2B2AAC4B2A9
C3B1A8C4B0A6C3AFA4C2ADA2C0AAA0BDA79CB9A399B6A095B09A90AC968CA69086A38C81
9C867C978077927B718B746B806A62725F5863534D534742423A36312D2A201F1E0F1111
0607070F0F0F1818182120202929293231313B3A394342414B4A495352515B5959626160
696867706F6E7776757E7D7C
8A89888F8E8C9493919A97969F9C9AA4A19FA9A6A3AEAAA7B3AEACB8B2AFBCB6B3C0B9B6
C3BBB8C3BBB7C0B8B4BEB5B1BAB2AEB9B0ABB9B0AABAAFAABAAEA7BCAEA6BBACA4BAABA2
BAAAA1B9A89FB7A69DB5A49AB4A298B09E95AC9A91A8978EA392899E8C8498867E938178
8C7B7489787084726B7B6A636F605B625651544A46443E3B3532302626251719190C0D0E
0F0F0F1919192221212A29293231313A3939414140494847504F4F5756565E5D5C656463
6B6A6A7271707877767E7D7D
8988878E8C8B92918F9795939C9997A09D9BA5A19FA9A5A3ADA9A6B1ACA9B5AFACB8B2AE
BAB4B0BCB5B1BCB5B1B9B2AEB7AFAAB5ACA7B3AAA5B3A9A4B2A8A2B3A7A0B2A59EB0A39C
B0A29AAD9F98AC9E96AB9C94A89991A4958EA0928A9B8D8697898291847D8A7E77857973
8075707D716C776B666C615D63595657504C4844413937362C2C2C1F2121121415131314
1C1C1C2424242C2C2B3333333B3A3A4241404848474F4E4E5655545C5B5A626160686766
6E6D6C7473727978787F7E7D
8888878C8B8A918F8E9593919996959D9A98A09D9BA4A09EA8A4A1ABA6A4AEA9A6B0ABA8
B2ACA9B4AEAAB6AFABB6AEABB2AAA6AFA7A2ACA49FABA39EABA19CABA09AA99E98A59A94
A39892A29790A1958E9F938C9C918A988D87948A848F85808B827D867D788078737C7470
77706D776E6A706764665E5C5C56534F4B49403F3E3233332528281C1E1E1A1A1B222222
292929302F2F3636363D3D3C4343424949484F4F4E5555545B5A5A61605F6665646B6A6A
70706F7575747A7A797F7F7E
8887868B8A898F8D8C92908F9693929996959C99979F9C9AA29E9CA5A19EA7A3A0A9A4A2
ABA6A3ACA7A4AEA8A4AEA8A4ADA6A2AAA39EA69F9AA39C97A29A95A299949F97919C948E
9A928C978F8A968D87948C869189848D868089827E847E7A817B787B7774797471716E6C
706C696D686664605F5C5957514F4E4545453A3B3B2D30312326262424242929292F2F2F
3535353B3B3B4141414746464C4C4B5251515756565C5B5A61605F6565646A69696F6E6D
7372727777767C7B7A807F7F
8786858A89888D8C8A908E8D93918F9593929895949A98969D9A989F9B99A19D9BA29E9C
A49F9DA5A09DA6A19EA6A09DA69F9CA19B979F99959D97929C959099928D958F8A918B87
8E88848E88838D868289847F85817D84807C817D7A7D7A787A77747674737471706C6B6B
6B6A686664645F5E5D5756554C4D4D4244443C3D3D2E30302E2F2E3434343838383D3D3D
4242424747474C4C4B5150505555545A59595E5E5D6262616666656A6A696E6E6D727171
7675747979787D7D7C81807F
8786858988878B8A898D8C8B908E8D92908E9492909693929895939996959B98969C9997
9D99979E9A989E9A979E9A979D99959C979399949197928E938E8A908A868C88848A8682
88848187838084807D827F7C817F7D817F7C7D7B797A7978787675757474706F6F6C6C6B
6768686263635C5C5C5454544D4E4E4546463F3E3E393A3A3F403F4444434847474C4B4B
504F4F5353535757565B5B5A5F5E5E6262616665646968686C6C6B6F6F6E737271767574
7978777C7B7A7E7E7D818180
8685848887868988878B8A898D8B8A8E8D8B908E8D918F8E93918F949290959291969391
97949297949297949297949196939095918F938F8D918D8A8A868487848086848183817F
817F7C817F7C807F7C807F7C807E7C7D7C7A7A79787978777474747272726E6F6F6B6C6C
6768686363625F5E5D5555555150504C4C4C4B4A4B4E4E4E5151505454535757565A5959
5D5C5C605F5F6262626565646867676B6A696D6D6C706F6E727271757473777676797978
7B7B7A7E7D7C807F7F828281
8584848785858887868988878A89888B8A898C8B898D8B8A8E8C8B8F8D8C8F8D8C908E8C
908E8D918E8D918E8D918E8C908D8C8F8C8A8E8B898C89878986848784828482817E7D7C
7E7C7B7F7E7C7E7D7B7F7D7B7F7D7B7D7B7A7C7A7A7A7978777676757575727272707070
6D6C6C6464646161615D5D5D5E5D5D5F5E5E5F5F5E606060626261646463666665686867
6A69696C6B6B6E6D6D706F6E7171707373727574747776757878777A79787B7B7A7D7C7C
7E7E7D807F7F818180838282
8584838585848685848686858786858887868887868988878988878988878A89878A8988
8A89888A89888A89888A89888A89878A8887898786888685878584858483848381828180
81807F81817F81807F81807F807F7E7C7C7C7B7B7B7A7A79787878777777767676747474
7272716F6F6E727171717170717170727171727171727271737372747473757574767675
7777767878777978787A79797B7A7A7C7B7A7D7C7B7D7D7C7E7E7D7F7E7E807F7E81807F
818180828281838281848382
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0238095 0.488926 0.245293 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(292) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
6D7C7D6D7C7E6D7C7E6D7D7F6E7D7F6E7D7F6E7E806E7E806E7E806F7F816F7F816F7F81
6F80826F8082708083708183708183708184708284708285708285708386718387718588
708386708285708284718284718284718284718284718385728385728385728385728384
728283718182718081717F80707E7F707E7F6F7D7E6F7C7D6F7B7B6E79796D78786C7675
6A73726C76766C78796D797A6D7A7B6D7A7B6D7A7B6D7A7C6D7B7C6D7B7C6D7B7C6D7B7C
6D7B7D6D7B7D6D7B7D6D7B7D
6D7C7E6D7D7F6E7D7F6E7E806F7F816F7F81708082708183708184718284718385728386
72848772858773858873868973878A74878A74888B74898C74898D748A8E748B90748C91
748A8E748A8D74898B74898B75888B75898B76898C778A8C778A8C778B8C778A8B778A8A
778889768687768585748383748182738080727F7F717D7C707A796F77766D74736B706E
6A6E6C6B73726D76756D77776E78786E79796E797A6E7A7B6E7A7B6E7A7B6D7B7C6D7B7C
6D7B7C6D7B7C6D7B7D6D7B7D
6D7C7E6E7D7F6F7E806F7F8170808270818371828572838672848773858874868974878A
75888B75898C768A8E768B8F778C90778D91788E92788F9478909578919678939879949A
789297789094789093788F92798F92798F927A90927B90917A90917A90917B90907A8E8E
798C8C798A8A78888878868677858476828275807F747D7C7279787076746D726F6A6C68
6A6D6A6C716F6D74736E76756E77776E78786E79796E797A6E7A7A6E7A7B6E7A7B6E7B7C
6E7B7C6D7B7C6D7B7C6D7B7D
6D7D7E6E7E806F7F8170808271828472838573848774868874878A75888B76898D778B8E
788C90788E92798F937A91957B92967B93987C959A7C969B7D979D7D999E7D9AA07C9BA2
7C989E7C979B7C969A7C95987C95987D95977D94967D94957C94957C93947D92937C9192
7C90907B8E8E7B8D8C7B8A897A878678848377817F757D7B7379777175726E706D6B6B67
6C6E6A6D716E6E73716F75746F77756F78776F78786F79796F79796F7A7A6E7A7B6E7A7B
6E7B7C6E7B7C6D7B7C6D7B7D
6E7D7F6F7E8170808271818472838673858874878975888B768A8D778B8F788D91798F93
7A91957B92977C94997D969B7E989D7F999F809BA1809DA3819EA581A0A681A1A880A1A9
809FA5809DA2809CA0809B9E809A9D819A9C81999B81999A81989A819899819697809595
7F93937F91917E8F8E7E8C8C7C89887B8584798280777E7C757A777375716F6F6B6D6B66
6E6E6A6F716E7073707075737076757077767078777079787079796F7A7A6F7A7A6F7A7B
6E7B7B6E7B7C6D7B7C6D7B7D
6E7D7F6F7F8171818372838573858874878A76898C778B8E788D907A8F937B91957C9397
7D959A7E979C80999E819BA1829DA383A0A684A2A885A4AB85A6AD86A7AF85A8B084A8B0
83A5AB83A3A883A1A684A0A4849FA2849FA1859FA0859FA0859E9F859D9E849B9C849A9A
84989883959583939282908F808B8B7E88877C84827A807D787B77757571716E696F6C66
706F6B71726E717470717572717674717776717877717978707978707979707A7A6F7A7B
6F7B7B6E7B7C6E7B7C6D7B7C
6E7E7F70808271828473848774878976898C778B8F798D917A90947C92967D95997F979C
80999E819CA1839EA484A1A786A3A987A6AC88A8AF89ABB28BAEB58BB0B88AB1BA88AEB6
87AAB087A8AD87A6AB87A5A988A4A788A4A789A4A689A4A589A3A489A3A489A2A289A0A0
889D9D889A9A879797869493848F8F828B8A8087857D82807A7C78777671736F69726E69
73716C73736F737471737673737774737775727876727977717978717979707A7A707A7A
6F7B7B6E7B7B6E7B7C6D7B7C
6E7E8070818372838674868875888B778B8E798D917B90947C93977E959A80989D819BA0
839EA385A0A686A3A988A6AC89A9B08BACB38CAFB68EB2BA90B6BE93BAC38DB5BE89AFB7
89ADB48AACB18AABAF8BAAAE8BAAAD8CAAAC8DAAAC8DAAAB8EAAAB8EAAAA8EA8A98EA6A6
8EA4A38DA09F8C9C9B8B9897899392868E8C8389878084817D7E7A79787375716B75716C
75736E757470757572757673747774747875737876737977727978717978717A79707A7A
6F7A7A6F7A7B6E7B7C6D7B7C
6F7E8071818473848775878A778A8D798D907B90937C93977E969A80999D829CA1849FA4
86A2A888A5AB89A8AF8BABB28DAEB68FB2BA90B5BD92B9C295BDC696BFC989B3BC8AB1B9
8BB1B78CB0B68EB0B48EAFB38FAFB290AFB191AFB091B0B092B0B193B1B093AFAF94ADAC
93A9A892A5A491A09F909C9B8D97958A918F878C8A83868380817D7D7B7679756F787570
787571787671777773777773767874757875757876747977737978727978717A79717A7A
707A7A6F7A7B6E7B7C6D7B7C
6F7F8171828473858876888B788B8F7A8F927C92967E959A80999D839CA1859FA587A3A8
89A6AC8BAAB08DADB48FB0B891B4BC93B8C094BBC496BFC899C3CE8EBAC585B0BB8BB3BC
8EB4BB90B5BA91B5B992B5B893B4B794B4B695B5B696B6B697B6B698B6B598B4B398B1B0
97ADAC96A9A795A4A393A09E909A988D94928A8F8C86898583837F7F7E797C79737C7873
7B78737A7873797874787874787875777975767976757977747977737978727A79717A79
707A7A6F7A7B6E7B7B6D7B7C
6F7F8172838574868976898D798D907B91947E949880989C829CA0859FA487A3A989A7AD
8CAAB18EAEB590B2B992B6BE94B9C296BDC698C1CB9CC7D293C0CB89B5C08BB6C08EB7BF
91B8BF93B9BF95B9BE96B9BD97B9BB98B9BA99BABA9ABBBB9BBDBC9BBBBA9CB9B79CB6B4
9BB1AF9AACAA99A7A697A2A0949D9A9196948D908D898B8786868283827D817E797F7A75
7E7A757D79747C79747A7975797975787975777976767976757977747978737A78727A79
707A7A6F7A7B6E7B7B6E7B7C
6F7F8172838675878A778B8E7A8F927D93967F969B829A9F859EA487A2A88AA6AC8CAAB1
8FAEB591B3BA94B7BF96BBC398BFC89AC3CD9CC7D197C4CF8DBBC68FBBC690BBC592BCC3
95BDC497BEC499BEC39ABEC19BBDC09CBDBF9DBFBF9DBEBE9EBEBD9FBABAA0B8B79FB3B2
9FB0AF9EADAB9DAAA79BA4A2979E9C9398958F928F8C8D8988888485847F83807A827D78
807C767F7B757E7A757C7A757B7A757A7975787976777976767977747977737978727A79
717A79707A7A6F7A7B6E7B7C
70808273848675888B788C8F7B90947E959981999D849DA287A1A789A6AB8CAAB08FAEB5
92B3BA94B7BF97BBC49AC0C99CC4CE9EC9D3A2CED997C5D192C0CC93BFC994BFC896BFC7
99C1C89CC3C99EC3C79EC2C49FC1C2A0C1C2A0C1C1A1BEBFA2BBBBA2B7B8A2B2B3A1AFAF
A3B0AFA2ADACA1A9A89EA4A39A9E9C9699979193908E8E8A8B898588858086827C847F79
827C76827C76807B767F7B757D7A757B7A75797976787976767976757977747978727A78
717A79707A7A6F7A7B6E7B7C
70808273848776898C798E917D929680979B839BA086A0A589A4AA8CA9AF8FADB492B2B9
95B7BE98BCC49BC0C99EC5CEA0CAD4A3CFDA9ECCD891C0CD94C1CC96C2CC98C1CA9AC3CA
9DC5CCA0C7CCA2C7CBA2C5C7A4C5C6A6C5C5A2BDBDA1B8B9A1B4B5A1B1B2A1B1B1A4B1B1
A6AFAFA5AAA9A5A9A8A1A6A49DA09E989A989394908F8E8A8D8A858B878289847E88817B
867F78857E77837C76817C757F7B757C7A757A7975797975777976767977747977737978
717A79707A7A6F7A7B6E7B7C
708082748588778A8D7A8F927E949781989C859DA288A2A78BA7AD8EACB291B1B795B6BD
98BBC39BC0C89EC5CEA2CAD4A4CFD9A7D4DF9AC8D594C2CE96C2CD99C4CD9AC3CB9DC5CC
A0C7CEA4C9CEA5C9CCA8C8C9A4BFC1A0B7B99CB1B3A0B3B4A2B1B3A3B2B3A5B3B4A5AEAE
A4ACABA5ABA9A6ABA9A4A6A49FA09E9A9A97959590918E8A8F8B868D88838C86808B837D
898079887E75867D76837C75807B757E7A747B7975797975787975767976757977737978
727979707A7A6F7A7B6E7B7C
708083748688788B8E7C90937F9599839A9F86A0A48AA5AA8DAAB091AFB594B4BB97B9C1
9BBFC79EC4CDA2CAD4A6D0DAA8D4DEA7D5E096C5D296C3CF98C4CE9BC4CD9DC4CCA0C6CD
A3C9CFA6C9CEA6C6C9A6C2C49EB8BA9FB8BAA1B8BAA3B7B9A5B8BAA7B9BBA9B9BAA8B5B5
A8B4B4A7AFAEA4ABAAA1A4A29FA19E9B9C98979691938F8B918B87908A848F88818E857E
8C827B8B7F77897F78867D75817A747E79747C79747A7874787875767875757976737977
727978717A796F7A7B6E7B7C
718183758689798C8F7D919581979B849CA188A2A78CA7AD8FADB393B2B996B7BF9ABDC5
9DC2CBA1C8D1A6CFD9AED8E3ADDAE5A0CFDB92C1CE97C3CE9AC5CF9DC6CEA0C6CDA2C7CD
A5C8CEA5C4C8A2BDC09FB6B99CB2B5A1B5B8A4B8BAA6B9BBA8BDBEABBDBEACBDBDACBABA
ACB8B8AAB1B1A8AFAEA4A9A6A0A3A09C9D9A979591948F8B938C87938C86928A83918780
8F837C8D81798A7E76867C738178727F78727C78727A7873787874777875757876747977
727978717A796F7A7A6E7B7C
71818375878A7A8D907E939682999D869FA38AA4A98EAAAF92B0B695B5BC99BBC29CC0C8
A0C6CEA3CBD5A8D2DCAED9E4A5D1DD95C3D095C1CE9AC4CF9DC6CEA0C5CDA2C6CCA4C8CD
A7C8CDA7C4C8A4BEC1A3BABCA3B8BAA5B7B9A7B7B9A8B8BAAABABBACBABCADB9BAADB6B7
ADB3B3ABB0B0A9AFADA6AAA7A2A4A19D9D9A969390958F8B958D88958D87958B84948981
92857D91837B91837A887C748177707F77717C76717A7772797773777774757875747876
7279787179796F7A7A6E7B7C
71828476888A7B8E917F9498849A9F88A1A58CA6AB90ADB294B2B998B8BF9BBEC69FC3CC
A2C9D2A4CED7A6D2DCA1CFDC96C5D392C0CD99C4CF9DC5CFA0C6CEA3C6CDA4C6CCA7C7CC
A9C6CBA8C4C8A6BEC2A7BDC0A8BBBEA9BBBDABBBBDACBCBDAEBDBEB0BDBEB1BBBCB1B9B9
B0B6B5AFB3B1ACAEACA9A7A5A3A09E9D989597908D958C89978D88988E87978D85968A81
94867E93847B93827885776E81756E7E756E7C756F7A7670797672777773757774747876
7278777179786F7A7A6E7B7B
72828477898B7C8F92819699859CA08AA3A78FA9AE93AFB597B6BC9BBCC39EC1C9A1C7CF
A4CCD5A6D0DBA6D3DFA3D0DDA0CCD79EC8D39FC7D1A1C7CFA4C6CDA6C6CDA8C6CCA9C7CC
ABC7CBABC5C9ABC2C5ABC0C2ACBEC0ADBEC0AEBFC0B0BFC0B2C0C1B4C0C0B5BFBFB5BCBC
B4B9B8B3B5B3AFB0ADABA9A6A6A29FA19B989D9591998F8B998E889A8F879A8E85988B82
96877E96857B95837884756C80736B7E736D7C746E7A746F797570777672757673747775
7278767179786F7A7A6E7A7B
72828477898C7D909382979B879EA28CA5AA91ACB196B2B89AB9BF9EBFC6A2C5CDA5CBD3
A7D0DAA9D4DFA9D6E2A8D5E0A7D2DCA6CED7A4CAD3A5C9D0A7C8CEA9C8CEABC8CDACC9CD
ADC9CDAEC7CAAEC5C7AEC1C4AFC1C2B0C1C2B2C3C3B4C2C3B6C3C3B8C3C3B8C2C0B9BFBD
B7BBB8B4B7B3B0B0ADACAAA6A7A29EA39C98A097929C928C9C918A9D91899C8F869A8B82
98877E96857A97847884756C80736B7E726B7C736C7A736E78746F777571767672747774
7378767178787079796E7A7B
728385788A8D7E929584999C89A0A48EA7AC94AFB499B6BB9DBCC3A2C3CAA5C9D1A9CFD8
ABD5DEADD9E4ADDAE5AED9E3ACD4DDA9CFD7A7CCD4A9CAD1ABCAD0ADCACFAECACFB0CBCF
B1CACEB2C8CCB2C7CAB2C5C6B3C3C3B4C3C4B6C4C4B7C4C4B9C5C4BBC6C4BBC3C1BBC0BE
B9BBB8B7B8B4B3B1ADAEAAA5AAA39EA59E97A29891A0948DA0938CA092899E8F869B8B82
98877E96847A95837886776E7F71697D71697B716A7A726C78736E777470767572747673
7377757178777079796E7A7B
738385798B8D7F9396859B9E8BA2A691AAAE97B1B69CB9BEA1C0C6A6C7CEAACED5ADD4DD
B0DAE3B2DEE9B3DEE8B3DCE5AFD4DCACCFD7ACCDD4ADCBD2AFCCD1B0CCD1B2CDD1B3CDD1
B4CDD0B5CBCEB6CACCB6C7C8B6C4C5B7C5C5B9C6C6BBC7C6BCC7C6BEC8C6BFC7C4BFC3BF
BDBEBAB9B8B4B5B1ADB1ABA5ACA49EA89E97A69A92A59890A4968DA2938AA090879D8C82
99887E9483788E7E7482756C7E70677B6E667A6F6879716A78726C77736F767471747673
7377757178777079796E7A7B
7384867A8C8E819497879CA08DA4A894ADB19AB4B9A0BCC2A5C4CAAACBD2AFD3DAB2DAE2
B6E1EAB8E5EEB9E4ECB7DCE4B2D3DAB0D0D7B0CED4B1CED3B3CED3B4CFD3B6D0D4B7D0D3
B8D0D2B9CED1BACCCEB9C8C9B9C6C6BAC7C6BCC9C8BEC9C7C0CBC8C2CBC9C3C9C6C2C5C1
C0C0BBBCBAB5B9B4AEB4ADA6AFA59EACA099AA9D95AA9C93A89990A5978DA293889F8E84
9A897E9483788E7D7384736979685E75665D796D6579706879716B77736D767470747572
7376747178767079796E7A7B
7484867B8D8F829598899EA190A7AA97AFB39DB8BCA3C0C5A9C8CEAFD0D6B4D8DFB8DFE7
BCE6EEBEE7F0BDE3EAB9D9E0B4D2D9B2D0D6B3CFD5B5D0D4B6D0D5B8D2D6BAD3D6BBD3D6
BCD3D5BDD2D3BDCFCFBDCCCBBCCAC8BEC9C7BFCAC8C1CAC8C3CCC9C6CCC9C6CAC6C5C6C1
C3C1BBBFBBB5BBB4ADB5ACA5B2A79FB0A39BAFA198AE9F96AC9C92A9998EA5958AA19084
9C8A7F978478907F7488766B7F6C617C6C627B6D657A6F6879716A78726C76736F747571
7376737177767079786E7A7B
7484867C8E908397998BA0A393A9AC9AB2B6A1BBBFA8C4C8AECCD2B4D5DBBADDE4C0E6EE
C3EAF3C5E9F1C2E2E9BCD8DFB6D2D8B6D1D6B7D1D6B8D2D6BAD3D7BCD5D8BED6D9C0D7D8
C1D7D7C1D5D5C1D2D1C0CECDC0CCCAC1CCC9C2CCC9C4CCC9C6CECAC9CECAC9CCC7C8C7C1
C5C1BBC1BBB4BDB4ADB9AFA7B7ABA2B5A79EB4A59CB3A398B09F94AD9C90A9978BA59186
A08B809A857A9381758C786C867165816F657E6E657C6F677A706978716C76736E757470
7375737177757078786E7A7A
7585877D8E9185989B8DA2A595ABAE9DB5B8A5BEC2ACC8CCB3D1D6BADADFC1E3E9C8EDF4
CDF1F7CFEEF3C8E4E9BED8DDB9D2D8B8D2D6B9D2D7BBD4D8BDD5D9C0D7DAC2D8DAC4D9DA
C6D9D9C5D6D6C4D3D2C3D0CEC3CECBC3CDCAC4CDC9C6CDCAC9CFCBCBCFCACCCCC7CAC8C2
C8C2BCC4BCB5C1B7AFBEB2A9BCAFA5BBACA2B9A99EB7A59AB5A296B19D91AD988CA99387
A38E819D887C988579917B6F89756A826F647F6E647D6F667A706878716B76726D757370
7375727176757078786E7A7A
7585877E8F92879A9C8FA4A698AEB1A1B8BBA9C2C5B1CCD0B9D6DAC0DFE4C8E8EECFF2F8
D6F4F8D3EDF1CAE3E7BED6DBBAD2D6BAD2D6BBD3D7BDD4D8C0D6D9C3D9DAC6DADBC8DBDA
CADBDAC9D9D8C8D6D4C6D2D0C5CFCCC5CDCAC6CDC9C8CECACBD0CBCED0CBCFCEC7CDC9C3
CBC4BDC8BFB6C6BAB1C4B6ACC2B3A8C0B0A4BFACA1BCA99DB9A498B5A093B19B8EAC9689
A79083A28B7E9D877B957E718C776A846D60816D637E6E657B6F6779706977716C75736F
7374727176747078776E797A
7686887F9092889B9D92A5A89BB0B3A4BBBEAEC6C9B7D0D4BFDADEC7E4E8CEEDF2D5F4F9
D8F3F6D2EAEDC9E0E3BAD2D7B9D0D5BAD1D5BBD2D5BED4D7C3D8D9C7DBDCCCDEDECFDFDE
D0DFDDCEDBD9CAD6D4C8D3D0C6CFCCC5CCC8C7CCC8C9CDC8CDCFCAD0D0CAD1CEC8D0CAC4
CFC6BDCCC1B8CBBDB3CABAAFC8B6ABC5B2A7C3AFA3BFAA9EBCA699B8A194B49D8FB0988A
AB9384A68D80A28A7C9982738E7669856B5E816C607E6D637B6E66796F6876716B74726E
7374717176746F77776E797A
7686888091938A9C9E94A7A99EB3B5A8BEC0B2CACCBCD5D8C6E0E3CEEAEDD5F3F7DAF7FA
E0F7F8D8ECEDC8DDE0B7CED4B7CDD2B9CFD3BBD0D3BED3D5C2D6D7C7D9D9CCDBDAD0DDDA
D1DDDACED9D7CAD4D2C8D1CEC6CECAC4C9C5C6C9C5CACCC6CECEC9D1D0CAD3CFC8D3CBC3
D3C8BED0C3B9CFBFB4CEBDB1CCBAADCAB6A9C8B2A5C3AC9FBFA89ABBA395B89F90B49A8B
AF9485AA8F81A58B7C9980718D736585695B816A5E7E6B617B6D64786E6776706A74716D
7273707175736F77766E797A
7787888192948B9D9F96A9ABA1B5B7ACC1C3B7CDCFC3DADCCEE6E9D6F1F3DCF7FADFF8F9
E0F4F5D3E6E8C3D8DCB3CACFB5CACFB7CCD0BACED0BDD0D2C1D2D2C4D5D4C5D4D3C9D6D4
C8D5D3C4D0CFC2CBC9C0C8C6BEC3C0BFC1BDC4C5C0CAC9C3CECDC7D2D0C9D5CFC7D6CDC3
D7CCC1D4C5BAD5C3B7D6C2B5D4BFB1CFB9ABCBB3A5C5AEA0C1A99BBEA596BAA091B69B8B
B29686AF9282A98D7C9C7F708D716284665881695C7E6A607B6B63786D66766F6974706C
72726F7074726F77766E7979
7787898292948D9EA098AAACA3B7B8AFC4C5BCD1D3C9E0E1D7EEEFE5FEFFE4FDFEE3F7F8
E0F1F1D3E4E5C1D5D8B0C6CCB2C8CCB5CACDB9CCCEBCCECFBFCFCFC1D0CFC2D0CEC3D0CE
BDCAC9B9C5C5B7C2C1B7BFBEBABEBBBFC0BBC4C4BEC9C9C2CFCEC7D3D0C8D5CEC6D5CBC1
D5C8BDD3C1B5D8C3B6DCC4B5D5BEAFD0B8A9CEB5A6C7AFA0C3AA9BBEA596BCA090B99C8B
B59887B49584AE8E7D9E7F6F8E706184665881685C7D695E7A6A61776C64756D67736F6B
71716E7074726F76756E7979
7887898392948E9FA09AABACA6B8B9B2C5C7C0D4D5CFE4E5E3F8F9EAFFFFE6FAFAE7F7F6
E2F0EFD1E1E3BCD1D5ACC2C8AFC5C8B3C7C9B8CBCBBBCCCCBDCCCBC0CDCBC1CDCBC1CCC9
BEC9C6BBC5C2B9C0BDB8BDBABBBDB9BFBFBAC4C3BCCAC8C1CFCDC5D3CEC6D5CDC4D5C9BF
D3C5BAD1C0B4D1BFB3D3BEB0CAB7A9C9B3A5C6B0A1BFA99BBDA596BBA191BC9F8EBB9C8B
B99A88BA9885AF8E7C9D7F6F8C716284675880675A7C675D79685F766A62736C66726E69
70706D6F73716E76756D7879
7887888393948F9FA19BACADA7B9BAB4C7C7C2D5D6D2E5E6E3F7F7E3F6F6E1F3F2DEEDEC
D9E7E7C8DADCB7CCD0A9BFC4ACC1C5B0C3C5B4C5C6B8C6C6BCC9C8C0CCCAC2CDCAC3CCC8
C2C9C6BFC5C1BDC2BEBCBFBBBDBDB8C0BFB9C5C3BCCBC8C1D0CCC4D4CDC4D6CDC3D6CABF
D5C6BAD3C1B4D0BEB1CBB8ABC1B0A3C0AC9FBEA99CB9A496BAA293BDA090BE9F8EBE9D8B
BE9B88BD9985AE8C7A9B7D6D8B6F618264567E65587A655B77665D746860726A64706C68
6F6F6C6E72706D75746D7879
7887898493958FA0A19BACADA8B9BAB5C7C7C3D5D5D2E4E4E2F4F4E1F2F1DEEEEDD8E7E7
CFDFE0C1D3D6B3C7CBA7BDC1AABEC1AEBFC1B1C1C1B5C2C1B7C2C0B9C3C0BCC3C0BAC1BE
B8BEBBB6BBB8B7BAB6B7B9B4BAB9B4C0BEB7C6C4BCCCC9C1D0CCC3D4CCC2D6CDC1D8CBBF
D8C8BAD5C3B5D2BFB0CEB9ABC8B3A5C4AEA0C1A99ABEA596C0A493C0A390C1A18EC19F8C
C39E8AC09A85AD8B789679698A6E5F8263547D635778635874645B71655E6F68626E6B66
6D6E6A6D716F6D74746D7878
78878984939590A0A19CACADA8B9BAB5C6C7C3D4D4D1E2E2DFF1F0DDEDEDD8E8E7D2E1E1
CADADBBDCFD1AFC4C7A6BBC0A8BBBEACBCBEB0BEBEB3BEBDB5BFBDB6BEBBB6BBB8B4B9B6
B5B8B5B5B7B3B6B7B2B8B8B2BEBBB5C3C1B9C9C6BECEC9C1D1CBC2D3CBC1D4C9BED4C7BA
D5C4B6D6C2B3D6C1B1D2BCACCDB6A6CAB1A2C7AD9DC5AA99C4A795C4A592C4A28FC4A18C
C7A18BBF9983AA88759679698E71628667587A6054745F557060586E625B6D655F6C6864
6C6C696C706E6C73736C7778
788789849394909FA09CABACA8B8B9B5C5C5C2D2D2CFE0E0DDEEEDDAE9E8D4E3E3CDDDDD
C3D5D6B7CBCDADC1C4A5BABEA6B9BBAABABBAEBCBBB2BCBBB4BDBBB6BDB9B7BCB8B8BCB7
B9BCB7BABCB6BCBDB7BFBEB8C3C1BAC7C4BDCCC8C0CFCBC2D2CCC2D4CBC0D4C9BDD4C6B9
D3C2B4D0BDAFCFBBACCFB9A9D1B7A7CFB5A3CDB19FCAAD9AC8A996C5A591C5A38EC8A28D
C9A08ABC9580A987739A7B6A8E70608162546F564B6D59506B5C546A5F5869625D696662
696A676A6E6C6B72726C7777
7887888493948F9FA09BABABA7B7B8B4C4C4C0D1D0CDDEDDDAEAE9D5E5E5D1E0E0C9D9D9
C0D1D2B5C8CAACC0C3A6BABDA7B8BAAAB9B9AEBABAB1BCBAB4BDBAB7BDBAB9BEBABBBEBA
BDBFBABFC0BAC2C2BCC4C4BDC8C6BFCBC9C1CFCBC2D3CDC3D4CDC2D6CCC0D6CABDD6C8BA
D5C4B6D3C0B2D0BBADCCB6A7C9B2A2C8AF9EC8AC9BC5A996C5A692C5A48FC9A38FCBA28C
C99F88B8917CA7837198776688695A785C4E68514666544B65574F655B54655F5A66635F
676865686D6B6A72716B7677
7887888392948F9E9F9AAAAAA6B6B6B2C2C2BFCFCECBDBDBD8E8E7D4E3E3CFDEDDC6D7D6
BECFD0B5C7C9AEC0C3A8BBBDA7B8B9A9B7B8ADB9B8B1BBB8B5BCB9B8BEB9BBBFBBBEC1BC
C1C3BDC3C5BFC6C7C1C9C9C2CDCBC4D0CDC5D3CFC5D6D0C6D7CFC4D8CEC1D9CCBFD9CABC
D8C7B8D6C3B4D3BEAED0B9A8CCB3A3C9AF9EC7AB99C7A995C8A793CAA691CCA48FCCA38D
C69C86B58D79A27F6C91716180635570574B624D435F4E465F514A5F5650615B5663605D
646663666B6A6871706A7677
7887888392938E9D9E9AA9A9A5B5B5B1C1C0BDCDCCC9D9D8D6E5E4D1E0DECCDAD9C5D4D4
BECECEB7C6C7B0C0C2AABBBCA7B8B9A9B6B6ADB8B7B2BBB8B6BDB9BABFBABEC1BCC1C4BE
C4C6C0C8C9C2CBCBC4CECDC5D1CFC7D4D1C8D8D3C8DAD3C7DBD2C5DCD0C3DCCEC0DCCCBD
DCC9B9DAC5B5D8C0AFD4BBAAD2B7A5D0B3A1CEAF9CCEAC98CFAA95CFA892D0A68FCFA28B
C39881AF88749D7A678B6C5C795E5067504559463D54453D574B4459514C5C57535F5E5A
626461646A6867706F6A7576
7786888291928D9C9D99A8A8A4B3B3AFBFBEBBCACAC7D6D5D3E2E1CEDCDBC9D7D6C3D1D1
BCCBCBB5C5C5AFBFBFA9B9BAA7B6B7A7B5B4ADB8B6B2BBB7B7BEB9BCC1BCC0C3BEC4C6C0
C8C9C2CCCCC5CFCFC7D3D1C9D6D3CAD9D5CBDCD6CBDDD6C9DED5C7DFD3C4E0D0C1E0CEBE
DFCBBADEC7B6DBC2B1D9BEACD7BAA7D5B6A2D4B29ED3AF9AD2AC96D2A993D1A78FCB9F88
BA917BA8826F9574628265566E55495B473D4D3C34493B344F443E534C475854505B5B58
5F6260636867666F6E697576
7786878290928C9B9C97A6A6A2B1B1AEBCBCB9C8C7C5D4D2D1DFDDCCD9D8C6D4D3C1CFCE
BCCAC9B7C5C4AFBEBEA9B9BAA6B6B7A7B5B5ADB7B5B4BBB7B9BEBABFC2BDC3C6BFC8C9C2
CCCCC5D0CFC8D4D2CAD7D5CCDBD7CDDDD8CEE0D9CDE2D9CBE3D7C9E3D5C5E3D2C2E3D0BF
E2CCBBE1C8B6DFC4B2DDC0ADDBBDA9DAB9A4D8B5A0D7B19BD5AE97D5AA93D1A58DC59A83
B38B76A07C698B6B5B765B4E614C414E3D353D2F283F332D483F3A4E484453504D585856
5D605E616766656E6E697475
7785878190918B9A9B96A4A5A1AFAFABBAB9B7C5C4C3D1D0CFDCDACAD7D5C4D2D0C0CDCC
BCC9C8B5C3C2AFBDBCABB9B9A9B6B6AAB6B4AFB7B4B5BBB7BCC0BAC1C4BEC7C8C1CCCCC4
D0D0C8D5D3CBD9D7CEDCD9CFE0DBD1E2DCD1E5DDD0E6DBCDE6D9CAE7D6C7E7D4C3E6D1BF
E5CDBBE4CAB7E2C6B3E1C2AEDFBEA9DDBAA5DCB6A0DAB29BD9AE97D4A891CCA089BD937D
AA836F9473617F62546A524656433943342D3428223B312C433B37494541504E4B555654
5A5E5D5F6665646D6D687475
768586808F908A999994A3A39EADADA9B7B7B4C2C1BFCDCBCBD8D6C6D3D2C2CFCDBECBC9
BAC6C5B5C1C0B0BDBCADB9B9ABB7B5AFB8B5B2B9B6B8BCB8BEC1BBC5C6BFCACBC3D0CFC7
D5D4CBD9D7CEDEDBD1E2DDD3E5DFD4E7E0D2E9E0D1EADECFEBDBCBEAD8C8EAD5C4E9D2C0
E8CEBBE7CBB7E5C7B3E3C2AEE1BFAAE0BBA5DFB7A0DDB39BD9AE96D3A68EC89B84B58C76
A07B688A6B5A755B4C604A3F4A3A31362B242C221D362E2A3E393546423F4C4C49535453
585D5B5E6564636C6D687475
7684867F8E8F89979892A1A19CAAAAA6B4B3B0BEBDBBC9C7C6D4D2C2CFCEBFCBC9BCC8C6
B9C5C3B6C2C0B2BDBBB0BAB8B0B9B6B3BBB7B5BBB7BBBEB8C1C3BDC8C9C1CFCEC6D4D2CA
DAD7CEDFDBD1E3DED3E7E0D4EAE2D5ECE3D4EEE3D3EFE0D0EEDDCBEEDAC8EDD6C4ECD4C0
EBD0BCE9CCB7E7C8B3E6C3AEE4BFA9E2BBA4E1B79FDEB29AD8AC93CEA189BE937DAA826E
9372607E61516951445240363B2E27261C18261D19322B283B363343413E4A4A48505352
575C5B5C6464626C6C677475
7584857E8D8E879696909E9F9AA7A7A3B1B0ADBAB9B7C4C2C1CECCBFCBC9BCC8C5BAC5C3
B8C3C1B5C0BDB3BCBAB2BAB7B3BAB7B6BCB7B8BCB7BEC0BAC5C6BECDCCC3D3D1C7D9D5CB
DFDACFE4DED2E9E1D4ECE3D5F0E5D6F2E6D6F3E4D4F3E2D0F2DECCF1DBC8F0D7C4EFD4C0
EDD0BBEBCCB7EAC7B2E8C3ADE6BFA8E4BAA3E1B59DDCB097D3A68EC59982B38A749D7966
8768577257495C473C45352D30252021181427201D302A27383533403F3D4849474F5251
555B5A5B6363616B6C677374
7583857D8C8D8694948E9C9C97A4A49FADACA8B6B4B2BFBDBCC9C7BCC7C5B9C4C2B8C2BF
B7C0BDB5BEBBB3BCB8B2B9B6B3B9B5B6BBB6BBBEB8C1C1BAC9C8BFD1CEC5D8D3C9DFD9CD
E5DDD0EAE1D3EEE4D5F2E6D6F6E8D7F8E8D7F8E6D4F7E3D0F5DFCCF4DBC7F2D8C3F1D4BF
EFD0BAEDCBB6EBC7B1E9C3ACE7BEA6E3B9A1DEB29AD7AA92CA9E86B88F79A47F6B8F6E5C
795E4E654D414E3C32362A24241C181A1310241F1C2E2A273635323F3F3D4649474D5251
545B5A5B6363616B6C677374
7483847C8A8B8492938C9A9A94A1A19CA9A8A4B1B0ACB9B7B4C0BEB7C2BFB6C1BEB5BFBC
B3BCB9B2BBB8B1B9B6B0B7B3B2B8B3B6B9B4BBBDB6C2C1B9CCC8BFD4CFC4DBD5C9E4DBCD
EAE0D1F0E3D4F4E6D6F7E8D6FBEAD7FEEAD7FDE7D4FBE3CFF8DFCAF6DAC6F4D7C2F3D3BD
F0CEB9EECAB3EBC5AEE8C0A8E4BAA2DFB59CD8AC94CDA189BC937DA9836F9573617F6252
6A52455441363D3028281F1A160F0C150F0C221E1B2C2A283535333E3F3E4549484D5251
545A5A5A6363606B6C667375
7482847B898A829091899797919E9E98A5A59FACABA6B3B1ADB9B7B4BFBDB3BDBBB2BBB8
B1B9B6B1B9B5B0B7B2AEB5B1B0B5B0B3B6B0B9BAB3BFBEB6C8C5BBD1CCC0DCD3C6E7DBCC
EFE0D0F3E4D4F7E6D5FBE8D5FFEAD6FFE8D4FEE5D0FBE1CCF9DDC7F7D9C3F5D4BFF3D0BA
F1CDB6EEC8B0E9C2AAE5BCA4E0B69DD8AE96CDA38BBF957FAD87729977648467566F5648
59453A43342C2D231E1B15120F0A08171311211F1D2B2A293535343D3F3E4549484C5252
535B5B5A6364606B6C667375
7382837A8889808E8F8795958E9B9B94A1A19BA8A6A1AEACA8B3B1AFBAB7AFB9B6ADB7B4
ADB5B2ACB4B1ACB3AFABB1ADACB1ACB0B3ADB6B7B0BCBBB3C3C1B7CDC7BCD9CFC1E3D6C6
EADBCBEFDFCDF4E1CEF8E3CFFBE4CFFBE2CDF9DFCAF8DBC6F6D8C2F4D3BDF3D0B9F1CCB5
EDC7B0E9C2AAE4BBA3DEB59DD6AD96CCA38CBE9680AE88759B7967866A5972594B5C483D
46372E3026201E18140E0B080A070517151322211F2C2C2B3537363D4140454A494C5353
535B5C5A6464606C6D667375
7381827987887F8D8D8592938B9898919E9D96A3A29CA8A7A2ADACA7B2B0ABB5B3A9B3B0
A9B1AEA8B0ACA7AEAAA5ACA8A9ADA8AEB1ABB4B5AEBBBAB1C1BFB5C9C4B9D3CABDDBCFC0
E2D3C3E6D5C4ECD8C6EFD9C6F2DAC6F2D8C4F1D6C2F1D3BEEFD0BAEDCCB6EBC8B2E8C4AD
E4BFA8DFB9A2D9B29BD1AA94C8A18BBC9681AD89769C7B6A886C5C745C4E5F4B40493A31
3229221F1916100C0A0402010B09081817162323222D2E2E3639383E4242464B4B4D5454
545C5D5A6465606C6D667475
7280827886877D8B8C8290908895958D9A9A929F9E97A3A29CA8A6A0ACAAA5AFADA5AEAC
A4ADAAA3ABA8A3AAA6A3A9A5A7ABA6ABAEA8B1B2ABB6B5ADBCB9AFC4BEB2CDC3B5D3C6B8
D7C9BADACBBAE0CEBCE2CEBCE4CFBCE5CEBBE5CBB8E3C8B4E0C4B0DDBFABDBBBA7D9B8A2
D4B29DCEAC97C6A48FBE9C88B4927FA88776987A6A866C5D735D50604E434B3D35352C26
201B18110E0C02000003020210100F1B1C1B2527272F3131373B3B3F4444474D4D4E5556
545D5E5A6566616D6E677475
7180817685867B898A808E8E8592928A97968E9B9A929F9E97A2A19BA6A49FAAA7A1ABA9
9FA8A59EA6A39FA6A2A0A6A2A2A7A2A5A8A2ABACA6B0B0A8B6B4ABBFB9ADC4BBAFC8BEB0
CDC0B1D0C2B2D4C4B3D5C3B3D6C3B2D7C1B0D6BEADD3BBA9CFB7A5CCB2A0CAAE9CC6AA97
C1A491BA9D8BB29584AB8E7DA0847493796A836C5E725E52604F454C3F38372F2A221E1B
11100E0201010000000B0C0B1516161F2121292C2B313535393E3E414747484F504F5758
555F5F5B6667616D6E677476
717F817584857A88887E8C8C8290908693938A97968E9A99919D9C95A09E97A2A19BA5A3
99A29F98A19E99A09D9AA09C9CA19CA0A39EA5A7A1AAAAA3AFADA4B6B0A6B9B2A6BDB4A8
C1B6A9C3B7AAC6B8A9C7B8A9C8B7A7C6B4A5C4B1A1C1AE9EBDA999BAA595B6A090B19B8B
AB9485A48D7E9D8778967F718B76687E6A5E6F5E535E50474B413A38322D272320151513
040404000000090A0A1214141B1E1E2427272D3131353A3A3C4242434A4A4A525250595A
5660615C6768626E6F677576
707F807483847886877C8A8A808D8D8390908693938A96958C98978F9A99919B9A919B9A
919A99929A98939A97939A97959B97979C979C9F99A0A29BA4A49CAAA69DADA89EB1AA9F
B3ABA0B5ACA0B7AB9FB7AA9EB6A99CB4A799B2A496AFA093AA9C8EA6978AA091849C8C7F
9585798F7F7389796D81716776675E675C53584F4848423C383430272624161817070A0B
000102080A0A111313191C1C212525292E2E313636383E3F3F4647464E4E4C5555525C5C
5862635D696A626F70677577
707E807382837785867A88887D8B8B808D8D8390908692928894938A95948B96958B9694
8B94938A94928B93918C94918D94918F95919297929698939999939D9C949F9D94A19E95
A39E95A59E94A49D93A49D92A49C91A29A8FA0978C9D9388988F8493897F8E8479887D72
7F766D7B7269766D646C645C605953544E4946433E3736332829281A1D1C0D1010030505
060707101213181C1C202425282C2D2F3435363C3D3D4344434B4B4951524F5859545E5F
5964655E6A6B637071687677
6F7E7F7281827583847886877B88897D8B8B808D8D828E8E84908F859190869190869190
86908F848E8D848D8B848D8B868E8B888E8B898E8A8B8F8A8C908B90918B91918B92918A
94928A949189949188949188938F86918C848E8A818B867E87827A827E767C777076726B
716E686C686365615C5A5853514F4B4645423839372A2D2C1D2121111616060A0A070A0A
111414191C1D212525282D2D2F3435353B3C3B424341494A474F504C5556515B5C566162
5B66685F6C6D647172687678
6F7E7F7280817482837684857986877B88897D8A8A7E8B8B808C8C818D8D818D8D828D8C
818C8B808B897F89887F88867E87857E86837F868381878282868284878283868182857F
82847F82847E83847E83847D82827B80807A7E7E777A7A7477777172726E6E6F6A6A6B67
6566636464605D5C59535351494A483C3F3D2D3232212727141B1C0C12120B0F10141718
1B1F20222728292F2F2F3636363C3D3B434341494A464F4F4B5455505A5B545F60596465
5D696A616D6F657274697778
6F7D7F717F807381827583847784857886877A87887B88897C89897D8A8A7E8A897E8989
7D88887C87867B858479838278807F78807E777F7C777E7B777E7A787E79777C78767B77
767B767479757478737478737377727075706E726E6B6F6C686D6A6469666267645C6160
5A5F5D565B594D5352454A4A3A41412E3637252C2D192223111718121717181D1E202526
262C2D2C333332393A383F403D4546424A4B4750504B55564F595A535E5F5763645B6768
5F6B6C626F71667375697779
6E7D7E707E807280817381827583847684857785867886867986877A87877A87877A8686
7A858579848477828276807F727C7B6D77756E77756F78757078756F76726C737068706D
676F6C68706C696F6C656D6A626B69626B69626B686069675E66655B64645A6262545D5D
525B5B4C5556464E4F3E4647343D3E2A3436242D2E1921221A2021212728262D2E2C3334
31393A363E3F3B444540494A444D4F4952534D5658505B5C545F605763645B66685E6A6B
616E6F6471736775766A787A
6E7D7E6F7E7F717F80728081738182748283758384768384768484778484778484778384
768383768282748080737E7D707B7A6D777669737268727066706E656E6C636D6B626B69
616B69606A685E68675D68675E69695F6A695C67675B66675A6566586365545F60515C5D
4D585A485254414B4D3A4344333D3E2D3536262D2E232A2C2A32332F3738343C3D394142
3D4647414A4B454E504952544C5658505A5B535E5F5661625964665B67695E6A6C616D6F
6370726673756876776A797A
6E7C7E6F7D7F6F7E7F707F80717F81728081738182738182748182748182748182748182
748181738080727E7F717D7D6F7A7A6C78786975746570705E69695C67665D69685D6868
5B66655A67665B67675C68685C68685B6767596566586465556163536062515D5F4E5B5D
4B5759485153434D4E3B4445353E3F323A3B323A3C3740413B44453E4849424C4D454F51
4953544C56584F595B515C5E545F615762645965665B67695E6A6B606C6E626F70647172
6573756775776977796B797B
6D7B7D6E7C7E6E7D7E6F7D7F707E7F707E80717F80717F80717F80717F80717F80717F80
717F7F717E7F707D7E6F7C7D6E7A7B6C79796A7677677374647071616E6E5E6B6C5A6668
5A66675B68695A67685B68675D69695C68695C686A5B6769586567576466556264546062
515D5F495455454F51424C4E444E504650514751534954554B56584E595A505B5D525E5F
5560625762645965665A67685C696A5E6A6C5F6C6E616E6F627071647173657374677476
6876776977796A797A6B7A7C
6D7B7D6D7C7D6D7C7E6E7C7E6E7D7E6E7D7E6F7D7F6F7D7F6F7D7F6F7D7F6F7D7F6F7D7E
6F7D7E6F7D7E6E7C7D6E7B7D6D7B7C6C7A7B6B797A6A7778687677677476657374647273
637172637172637072637071616E705E6B6E5D6B6D5C696C5B686A5A6769596668576567
5662645461635864665864665865665965675A66685B67695C696A5D6A6C5E6B6D5F6D6E
616E6F626F706370726371736472746573746674756775766775776876786977796A7879
6A787A6B797B6B7A7C6C7B7C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0238095 0.732558 0.245293 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(315) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
4E68734E69734E69744E69744F6A744F6A754F6A754F6B75506B76506B76506C77506C77
516C77516D78516D78516E79516E79526E7A526F7A526F7A526F7B52707B52707B52707C
52707B52707B526F7B526F7B526F7A52707B52707B53707B53707B53717B53717B53707A
53707A526F79526E79526E78526D77516D77516C76516C76516B75506A734F69724F6770
4E666F4F68714F69734F69734F69744F69744F69744F69744F69744F69744F69734E6973
4E69734E68734E68734E6872
4E69734E6A744F6A754F6B76506C77506C77516D78516E79526E79526F7A53707B53707C
53717D54727E54737E557480557480567581567582567683567783567784577884567885
567784567783567783567783577782577783577884587984587984587984587984587983
58778157768057757F56747E56737D55727C55717B547079546E77526C7551697250666E
4F656D506871516A73516B75516B75516B75516B75516B75506B75506B75506A754F6A74
4F69744F69744E69734E6873
4E69734F6A74506B76506C77516D78526E79526F7A53707C54727D54737E557480567581
567682577783587884587985597A875A7B885A7C8A5B7D8B5B7E8C5B7F8D5B808D5B808E
5B808D5B7F8C5B7F8B5B7E8B5B7E8A5B7F8A5C7F8A5C7F8A5C7F8A5C808A5C7F895B7D87
5A7C855A7A8459798359798259788259778159757F58737D56717A556E77536B7351676E
51676F526A73536C75536D76536D77536D77536D77526D77526C77516C76516B76506B75
506A754F6A744F69744E6973
4E69744F6B75506C77516D78526F7A53707B54717D55737E567480577582587783597985
597A875A7C895B7D8A5C7F8C5D808E5E82905E83915F8593608694608796608897608897
5F87955F86945F86935F85925F85925F85915F848F5E838D5D828D5E828C5E818B5D818B
5D818A5C80895C7F885C7E875C7C865C7B845B79825A768059747D57717A566E76546B73
546C74556D76556E78556F79556F79556F79546F79546E79536E78536D78526D77516C76
516B76506A754F6A744E6973
4F6A74506B76516D78526E7953707C55727E5674805776825877845979865A7B885B7D8A
5C7F8C5E818E5F8290608493618695628897638A99648C9C648E9E658F9F6590A06590A0
648E9E648D9D648D9B648C9A648B98638B97638A9563899462889362879262869161858F
60848F60848E60828D5F818B5F818A5F7E885E7C865D7A845C78815B757E587179576E76
57707858717A58727B58727C57727C57717C56717B56707B55707A546F79536E79526D78
516C77506B764F6A744E6973
4F6A75506C77526E7953707B55727E5674805776825978855A7A875B7D8A5D7F8C5E818F
5F8391618694628896638A99658C9C668F9F6791A16894A46A96A76A98A96A99AA6A98A9
6996A66894A36893A26892A168929F68919E68919D68909C678F9B678E99668C97668B96
668B95658A9465889365879264859063848F62828C617F89607C865E79825B747C5A727A
5B747D5B757E5B757F5A757F5A757F59747F58737E57737D56727C55707B546F7A536E79
526D78516C76506A754F6974
4F6A75516D78526F7A54717D5674805776825979855B7B885C7E8B5E808E5F8390618593
628896648A99668D9C6790A06993A36A95A66C98A96D9BAD6F9FB171A2B471A4B76FA1B4
6D9DAD6C9BAA6C99A96C99A76C98A66C98A56C98A46C97A36C97A36C97A26C96A16C949F
6B939E6B919D6A909B6A8E99698B9768899567879365859063818B617D875F79825F7881
5E79835E79835E79845D79835C78835B77825A768159747F58737E57727D55717B54707A
536E79526D77506B754F6974
4F6B75516D7853707C55737F5776825978855B7B885C7E8B5E818E608491628695648998
658C9B678F9F6992A26B95A66C99AA6E9CAD709FB172A3B675A7BA79AEC276ABBF71A4B7
70A2B370A0B0709FAE709FAD719FAD719FAC719FAC719FAC71A0AC72A0AB729FAB729EA9
729CA7719AA57097A37095A16F929E6D8F9B6B8C98698A9567869165828D637F89637E89
627E89627E89617D88607C875F7B865E7A855C78835B77825A758058747E57727D55707B
546E79526D77516B764F6A74
506B76526E7954727D5675805878845A7B875C7E8B5E818E608492628795658A99678E9D
6991A06B94A46C98A86E9BAC709EB072A2B574A6B977AABE79AFC37BB2C674AABE73A7BA
73A6B774A5B674A5B575A5B475A5B475A5B376A5B276A6B377A8B477A9B578A9B578A8B3
78A5B177A2AD769EAA769CA87498A47295A170929E6E8F9B6C8D986A8A96688792678692
66859065838F64828E63808C627F8A607D885F7B865D79845B77825A758058737E56717C
556F7A536D78516C764F6A74
506B76526F7A55727E5776825979865C7D895E808D608391638795658A99678E9D6992A1
6C95A56E99AA709DAE72A0B274A4B776A8BB78ACC07AB0C57DB4CA75ACC36FA5BA74A9BC
76AABC77ABBC78ABBC79ABBB7AABBA7AACBA7BACBA7BADBA7CAFBB7DB0BB7DAFBB7DAEB9
7DACB77DA9B47CA6B27AA2AE799FAB779BA77498A47194A070929E6E909C6D8E9B6C8E9B
6A8B9869899568879366849064828E63808C617E895F7B875D79845B778259758057737D
55707B536E79516C774F6A74
506C76536F7B55737F5877835B7A875D7E8B608290628694658A98678E9D6A92A16C96A6
6F9AAA719EAF73A2B476A6B878AABD7AAEC27CB2C780B9CF79B2C871A8BE74ABBF77ADC0
79AEC17BB0C27CB1C27DB1C27EB1C17FB1C07FB2C080B4C080B6C181B7C281B6C181B5BF
81B3BD81AFBA81ACB77FA8B47DA4B07BA0AC789CA97699A67497A47296A37296A47094A2
6F919F6D8E9B6B8B9869899567869265838F63808C617E895F7B865D79845B768158747F
56717C546F7A526C77506A75
506C7753707B5674805978845C7C895F818E618592648997678D9C6A91A06C95A56F9AAA
729EAF74A2B477A7B97AABBE7CB0C47FB4C980B9CE7BB4CB75AEC477AFC579B0C57BB1C5
7DB3C67FB5C881B7C882B7C883B7C783B7C684B8C684B8C584B7C385B4C185B3C085B1BD
86B0BC86B0BC85B0BA84ACB782A7B47FA3B07CA0AC7A9DA9779AA77699A67598A67499A8
7398A77193A16F909D6D8D996A899668869266838F63808C617D885E7A855C778259757F
57727D556F7A526D77506A75
516C7754717C5775815A7A865D7E8B608390638795668C9A69909F6C94A46F99A9729EAE
75A2B478A7B97BACBF7EB1C480B5CA83BAD086C0D681BBD37CB5CC7CB4CA7DB4C97FB5C9
81B7CB84BACD86BCCD87BCCC88BCCB89BCCB88BBC988B9C688B4C288B0BD88ABB988A9B7
89ACB98AAFBB8AAFBB88ADB986AAB683A7B380A3B07D9FAD7B9DAA799BA9789BA9779BA9
769AA97598A77394A270919E6E8D996B899568869265828E627F8A607C875D79845A7681
58737E55707B536D78506B75
516D7854717D5876825B7B885E808D628592658997688E9D6B93A26F98A8729DAD75A1B3
78A6B87BACBE7EB1C481B6CA85BBD088C1D783BED67CB6CE7EB7CD80B7CC81B7CB83B8CB
85BBCE88BED18BC1D28CC1D08DC1CF8FC1CE8CB8C689B0BE88ABB987A7B387A8B48AABB8
8CA9B78DA8B58EABB88DAEBB8AADB987A9B683A5B280A2AE7E9EAC7C9DAB7B9DAB7B9DAB
7A9EAD799DAC7799A77495A271919D6E8C986A889467849064818C617D885E7A855B7782
59747E56717B536E78506B75
516D7855727E5978835C7D8960818E638694678C9A6A91A06E96A5719BAB74A0B178A5B7
7BABBD7EB0C382B6CA86BBD089C0D68CC5DB85BED67FB8CF81B8CE82B9CE84BACD86BBCE
88BDCF8BC0D18EC1D191C3D28FBCCB89AFBD86A9B788A9B689A8B58AA9B78AA9B78AA5B2
89A5B18BA6B28DAAB690ACB98EADBA8AABB786A7B383A3B081A1AD7F9FAC7F9FAD7EA0AD
7E9FAD7D9EAB7C9DAA7899A67494A0708F9B6D8A9669869266828E637F8A5F7B865C7883
59747F56717C536E79506B75
526D7855737E5978845D7D8A618390658996698E9C6C93A27099A8739EAF77A4B57AA9BB
7EAEC182B4C886BBCF8AC1D78DC6DC8CC6DD83BDD482BAD183BACF85BACE86BACD89BCCE
8BBECF8EBDCF8EBCCC8DB8C889B3C389B2C28BB2C28CB1C08DB1C18EB2C28FB2C18FB1BF
8EB0BE8CADBB8AA9B689A6B38CAAB58DADB88AAAB686A6B284A2AF83A1AE82A1AE81A1AF
81A1AF80A1AF7FA0AF7C9DAA7897A373919D6F8C986B889367848F64808B617C875D7883
5A758057727C546E79516B76
526E7956737F5A79855F7F8C638592678B996B919F6F96A5729CAC76A1B27AA7B87DACBE
80B2C584B8CC89BFD491C9E094CFE689C4DC7FB8CF83BACF86BCD088BCCF8ABCCE8BBCCE
8DBCCD8CB8C889B0BF86A8B885A7B78AADBC8DB1C08FB3C391B7C692B8C693B8C693B8C7
92B7C691B2C18FB0BE8CADB98AAAB68CABB78BABB688A7B387A5B186A4B185A4B085A3B0
84A2AF83A2B080A0AE7D9DAA7998A575939F708E9A6C899569859065818C627D885E7984
5B768057727D546F79516B76
526E795774805B7A8660818D648794698D9B6D93A27199A8759FAF79A5B57CAABC80B0C2
83B5C886BBCF8AC1D68FC7DD8AC3DA81B9D081B8CE85BBCF88BCCF8BBCCE8DBCCD8EBDCD
8FBCCC8FB9C98EB4C38CB0BE8DAEBC8EADBD8FAEBD91AFBE92B1C093B1C194B1C194AFBF
94AFBE93B0BE91B1BE8FAEBB8CABB98AA8B589A7B38AA7B389A6B289A6B288A5B187A5B1
87A4B186A5B189A8B583A2AF7B98A67694A0728F9A6E8A956A869166828D637E885F7A85
5B768158727D546F79516B76
526E795775805C7C8861828F6689966A8F9D6F95A4739CAB78A2B27CA8B97FAEC082B3C6
85B9CC87BDD188BFD482BAD179B2CA7DB4CB85BACF89BCD08CBCCE8EBCCD8FBCCD91BBCC
92BACA92B9C891B7C692B6C592B4C393B3C294B4C295B4C396B6C398B6C498B5C499B5C3
98B3C198B2C096AFBD93AAB98FA5B38AA0AD889EAB89A1AD8BA5B18BA6B18BA6B18AA5B1
89A5B189A5B088A4AF829EAA7D99A677939F738F9B6F8B966B869167828D637E89607A85
5C768158737D556F7A516B76
536F7A5876815D7D89628490688A986D919F7198A7769FAE7AA5B57FACBD82B2C486B8CA
89BDD08AC0D68AC2DA87C0D886BDD388BCD18BBED28EBFD190BECF92BDCE93BCCC94BDCC
95BCCB95BBC996BBCA97BBCA97B9C898B8C699B8C69AB9C79BB9C79CB9C79DBAC89DB9C7
9DB8C59CB6C29AB3BF97AFBC93AAB790A6B38EA4B08CA3AF8DA4AF8DA7B18DA7B18CA7B1
8BA5B08BA5B08BA5AF829DA87D98A37994A074909B708B966C879268838D647F89607B85
5D778159737D556F7A516C76
536F7A5977825E7E8A648592698C9A6F94A1749BA979A2B17EA9B982B0C086B6C88ABCCF
8DC2D58FC6DB90C9DF90C8DE90C8DD91C5D991C3D592C2D394C1D196C0D097C0CF98C0CE
99BFCD99BECC99BDCB9ABDCC9BBECB9CBDCB9DBECB9EBECB9FBDCBA0BDCAA1BDC9A1BDC9
A1BBC79EB8C49CB5C099B0BB96ACB793A8B491A6B190A5B090A7B090A8B190A8B18EA6B0
8CA5AF8BA4AE8BA4AE839EAA7F9AA77A95A175909B718B966D879269838E657F89617B85
5D778159737E556F7A516C76
54707B5A7783607F8B6587936B8F9C7196A4779EAC7CA5B481ADBD86B4C58ABBCC8EC1D4
92C7DB94CDE296CFE597CFE397CDE096C9DC95C7D997C6D699C5D59BC4D49CC4D39DC4D2
9DC2D19EC1CF9EC0CE9FC1CEA0C1CEA0C0CDA1C0CDA2BFCCA3C0CCA4C0CBA4BFCBA4BEC9
A3BCC6A2BAC49FB6C19DB2BC99AEB796AAB393A7B093A6AF94A8B193A9B192A8B08FA6AF
8DA4AE8AA2AC88A1AC839FAB809CA87A96A176909B728B966E87926A838D667F89627B85
5E77825A737E56707A526C76
54707B5A788461808C6788956D919E7499A67AA1AF7FA9B885B1C08AB8C98FC0D194C7DA
97CEE19AD3E89DD6EA9ED6E99DD0E39BCCDD9BCADB9DC8D99EC9D89FC8D7A1C8D7A2C8D6
A2C7D5A3C6D3A3C5D1A4C3D0A4C3D0A5C4D0A5C4D0A6C4CFA7C4CFA8C4CFA9C4CFA9C2CC
A8BFC9A6BCC5A3B8C1A0B4BD9DB1B99AADB498AAB298AAB298AAB296AAB295A9B192A7AF
8EA4AD89A0A9819BA57B96A27D99A47B96A1768F99728B956E87916B838D677F89627C85
5E78825A747E56707A526C76
54707B5B798462828D698A967093A0769BA97DA4B283ACBB89B5C48FBDCD95C5D69ACDDF
9ED6E9A2DCF0A4DFF1A4DAEBA2D2E3A1CEDFA1CCDDA2CCDCA3CDDCA4CDDCA6CEDCA7CDDB
A8CDDAA8CCD8A8C9D5A8C7D2A8C6D1A8C6D2AAC8D3AAC8D3ABC9D3ADC9D3ADC8D2ADC6CF
ACC3CCAABFC8A8BCC4A5B7BEA1B2BA9FAFB79EAFB69DAFB69CAEB69AAEB598ACB394A9B1
90A6AE8BA2AA849CA57C949D748A94728A93758D97738B946F87916C848D678089637C85
5F78825B747E56707A526C76
55717C5C7A8563838E6B8C987295A1799EAB80A7B587B0BE8EB9C894C2D29ACBDCA0D3E5
A5DBEEA9DFF1AADEEFA8D8E9A6D4E4A5D1E1A6D0DFA7D0DFA8D1DFA9D2E0ABD3E0ACD3E0
ADD3DFADD1DDADCFDAADCDD7ACCBD5ADCAD4ADC9D3AEC9D3AFCAD4B0CAD4B1CAD2B1C8D0
B0C5CDAEC2C9ABBDC3A7B8BEA5B5BBA4B4BAA3B3BAA3B3B9A1B2B89FB1B79CAFB598ACB2
94A9AF90A4AB8AA0A88399A27D929B7A9099788E97758B957188916D848D688089647C85
6078825B747E57707A526C76
55717C5D7B8665848F6C8D997497A37CA0AD83AAB78BB4C292BDCC99C7D6A1D0E1A7DAEC
ADE1F3B1E2F4B2DFF0AEDAEAABD6E5AAD4E3AAD4E2ABD4E2ADD5E3AED7E4B0D8E5B2D9E5
B3D9E4B3D7E2B3D5DFB2D2DCB1D0D9B1CED8B1CDD6B2CCD5B3CDD5B4CDD5B4CCD3B4C9D0
B2C6CDB0C2C9AEBEC5ACBCC2ABBBC0AAB9BFA9B9BEA8B8BDA6B6BCA4B4BAA1B2B79EAFB5
9AABB194A7AE8FA3AA899EA5859AA280979F7B919A778D957389916E848D698089657C85
6078815B747E57707A526C76
56727C5E7B866685906E8F9B7699A57FA3B087ADBA8FB7C597C1CF9FCBDAA7D6E5AFE1F2
B8E9FABDEBFBBBE6F4B4DDECB0D8E7AFD7E5AFD7E5B0D8E5B1D8E6B3DAE7B5DBE8B7DDE8
B9DDE8B9DCE6B8D9E2B7D6DFB6D3DCB5D1DAB5D0D8B5CED6B6CED6B7CDD5B7CDD4B7CBD1
B6C8CEB4C5CBB2C3C8B2C1C5B1C0C4B1BFC4B0BEC2AEBCC0ACBABEA9B7BBA6B4B8A3B1B6
9EAFB39AACB196A9B090A4AB8AA0A8849AA27E939B798E967489916F858D6B8189667C85
6178815C747D57707A526C76
56727D5F7C8767869170909C799BA782A5B28AB0BD93BBC89CC6D3A4D0DEADDBE9B6E5F4
BFEDFAC2ECF9BFE7F4B9E0EDB4DBE8B2D9E6B2D9E6B3D9E6B5DBE7B8DCE8BADEE8BCDFE9
BEE0E9BEE0E9BEDFE7BCDBE4BAD7E0B8D4DCB7D1D9B7D0D7B8D0D7BAD0D6BBCFD5BACDD3
BACBD1B9C9CEB8C7CBB8C6CAB8C5C9B7C5C8B6C3C7B4C1C5B2BEC2AFBBBFABB8BBA7B5B8
A4B2B6A0AFB49CACB296A8AE8FA3A98799A081949B7C8F96768A9171858D6C8189677D85
6178815C747D57707A526C76
56727D5F7D8768879272929D7B9DA884A8B48EB3BF98BFCBA1CAD7AAD5E2B3DFEDBAE7F4
BFE9F4C1E9F4BFE5F1B8DEEAB5DBE7B5DAE7B4D9E5B5DAE5B8DCE7BCDFEAC0E3EDC4E6EF
C6E6EFC5E4ECC2E1E9BFDEE5BDDAE2BAD5DDB9D2D8B9D0D6BAD0D5BCCFD5BDCFD5BDCED4
BDCDD1BDCCD0BECBCFBFCBCEBECACDBDC8CBBCC7C9B9C4C6B6C1C3B3BDC0B0BBBDACB8BA
A9B4B7A5B2B5A2B0B49DADB094A5A98B9A9F84949A7E8F95788A9172868D6D8189677D85
6278815D747D587079536C76
57727D607D8869889373939E7D9EA987AAB592B6C29CC2CEA7CFDBB1DAE7B9E5F2C0EBF7
C8EEF8C8ECF5C1E4EFB8DCE8B6DAE5B5D9E4B5D8E3B6D8E3B8D9E3BBDBE4BFDEE6C3E1E8
C7E3EAC7E2EAC3DFE7C1DDE4BEDAE1BBD5DBBAD0D6BACED4BBCED4BDCFD4BECFD4C0CED3
C1CFD2C1CED1C1CDCFC2CDCFC3CECFC3CDCFC1CBCDBEC7C9BAC4C6B7C1C2B4BEBFB2BABC
AEB7B9AAB4B6A6B1B39EAAAC95A2A58D999D869499808F95798A9073868C6E8188687D84
6278815D747D587079536C76
57737D617E886A889374949E7F9FAA89ABB695B8C4A1C6D1ADD4E0B8E1EDC0EAF6C5EDF8
C7EBF5C3E5EFBDE0EAB6D9E4B5D7E2B5D7E1B6D7E0B6D7DFB7D6DEB7D5DCB6D3DAB9D4DB
BBD6DDBBD5DCBBD3D9B9D0D6B5CAD1B5C9CFB8CBD0BACCD0BCCDD1BECED2C0CFD2C1D0D2
C4D2D3C5D1D2C7D1D3CAD3D4CBD4D4C9D1D2C6CECEC2CACBBEC7C8BAC3C4B7BFC0B4BCBD
B2BABAB0B8B8ACB4B4A3ABAC98A0A28F989A889497818F947B8A9074868C6E8188687C84
6378805D747D587079536C76
57737E617E886B899375949E80A0AA8BACB798BAC5A5C9D4B4DBE5C6EFFACCF5FFCBEFF9
C9EAF3C3E4ECBCDDE6B5D6E1B4D6DFB5D5DEB5D5DDB7D5DDB7D4DBB6D1D7B5CFD5B2CCD2
ADC6CDABC4CBACC4CBAEC4CAB1C4C9B4C6CBB7C9CDBACBCFBCCDD0BECED0BFCDCFBFCCCD
BFCACBC1C9C9C8CECDCED3D1CCD3D1C9D0CEC9D0CEC5CDCCC1C9C8BCC4C4B9C0C0B7BDBC
B5BBBAB5BAB9B2B6B5A8AEAE9CA3A492999B8A95988390947C8A8F75858B6F8187697C83
6378805D747C587079536C75
57727D617D876B889276939D809FA98CACB699BAC4A8CAD4BBE1EBC8EDF7CDF0F8D2F3FA
CFEDF4C5E4ECBADAE4B2D3DDB3D3DCB3D3DAB5D4DBB6D4DAB6D2D8B6CFD4B5CCD0B3C9CD
B0C7CBAFC3C8ADC1C5AFC1C5B1C2C5B4C4C7B7C7CABACACCBCCCCEBECCCDBFCBCCBFC9CA
BDC7C8BCC5C5BCC5C6BEC6C6BEC6C5BFC6C5BEC6C4BBC3C2BAC1C0B8BEBDB9BDBCB8BDBB
B8BCBABABCBAB5B8B5A9AFAE9EA6A6959D9E8C96988490937D8A8F76858A6F8086697B82
63777F5D737B586F78536C75
57727C617C866B879175939C809EA88CABB498B8C1A6C7D0B5D7E0BDDEE7C2E1EAC7E3EB
C7E3EABEDCE5B6D5DEB0D0D9B1D0D8B2CFD7B2CDD4B3CCD1B6CFD4B8D0D5B8CFD2B8CCCF
B6C9CBB5C6C8B3C4C6B3C3C5B4C2C4B5C3C4B8C6C7BAC9CBBDCBCCBECBCBBFCACABFCAC8
BFC8C7BEC5C5BCC3C2B6BDBDB0B8B9B2BABAB2BABAB2B9B9B5BAB9B8BCB9BABDB9BABCB9
BBBDB9BCBCB8B4B6B3A9ADAB9EA5A4969C9D8D96988590937D8A8E7684896F7F85687B81
63767E5D737B586F78536B75
57727C617C866B879075919B7F9DA68BA8B196B5BDA3C1CAB0CED7B7D5DCBCD9E0BEDAE1
BCD9E0B8D5DDB3D0D8AFCDD5B0CED5B1CCD3B1CAD0B1C8CCB0C4C8B0C3C6B1C3C4AEBFC0
ABBABCAAB8B9ABB8B9ADB8B9B0BBBBB4C0C1B8C5C5BBC9C9BECACABFC9C9BFC9C7C1CAC6
C2CAC6C1C8C5BFC5C3BBC2C0B7BDBCB5BAB8B4B8B6B5B9B6B9BBB7BABDB7BCBEB8BDBEB9
BFBFB9BEBDB8B5B5B0A6A9A79DA2A1979C9C8F9798858F927D898C7583876E7E83687980
62757D5D727A576E77526B75
57727C607B856A868F7490997E9AA389A5AE94B0B99FBCC3AAC6CEAFCBD2B2CED5B5D0D7
B5D1D8B3CFD6AFCCD4AECBD3AFCCD3B0CBD1B1C9CEB1C6CAB0C3C6AEBEC0ACB9BAAAB6B7
A9B3B3A9B2B1AAB2B1ADB5B4B2BBBBB7C2C1BBC6C7BEC9C9BFC9C9BFC9C7BDC5C3BCC2BF
BDC2BDC1C6C0C4C8C3C2C6C2BEC2BEBCBFBBBBBEBABBBDB9BCBEB8BDBEB8BEBEB8BEBEB7
C2C0B8BEBCB5B2B2ADA8AAA7A3A6A49DA1A191999A848E907B868A7381856D7C8166787E
61747B5C7179576E76526B74
57717B607B8469848D738E977C98A086A2AA91ACB49BB6BDA5C0C6A9C3C9ABC5CBADC8CE
ADC8CFACC8CFACC8CFACC8CFAEC9D0B0C9CFB1C9CDB2C7CAB2C4C7B1C1C2B0BEBEAFBCBB
B0BABAB0BAB9B1BBBAB4BEBCB7C1C0BAC6C5BDC9C9C0CBCAC1CCCAC0CAC8BFC7C4BDC3BF
BABEBAB7BBB7B8BCB7BCBFBAC1C3BEC2C4BEC1C2BCC0C1BABFC0B9BEBDB6BEBCB5C0BDB6
C2BDB5BBB7B0B2B0AAABABA6A5A5A1989A998A8F9081898B788386717E826A797E65767C
5F72795B6F77566D75526A74
56717B5F7A8368838C718C947B959D849FA68DA8AF97B1B8A0BAC0A2BCC2A5BEC4A7C1C7
A7C2C8A8C3C9A9C5CBACC7CDAFC9CFB1CACEB2C9CDB3C8CBB3C7C9B4C5C6B4C4C4B4C2C2
B5C1C0B6C2C0B8C3C2BAC5C4BDC8C6BFCBC9C2CDCBC3CFCCC4CECCC4CDCAC2CBC7C1C7C3
BEC3BFBBBFBBB8BBB7B6B8B4B5B7B2B7B8B3B9BAB4B9B9B3BAB8B1BCB9B1C0BBB3C2BBB3
C0B9B1B8B2ABAFABA5A7A39F9E9B9892929184898A7C8486747F826D7A7E68767B627379
5E7077596E76556C74516A73
56707A5E798267818A708A9278929A819BA28AA4AB93ADB39CB6BC9FB8BEA1B9BFA2BBC0
A4BDC3A5C0C5A8C3C9ACC6CCAFC9CEB1CACEB3CACDB4C9CCB6C9CBB7C8C9B8C8C8B9C8C8
BAC8C8BCC9C8BECBC9C0CCCBC2CFCDC4D1CEC6D2CFC8D3D0C8D2CFC8D1CCC7CFCAC5CCC7
C3C8C4C0C5C0BDC1BBBBBDB7B8B9B3B7B7B0B7B6AFB9B7AFBCB8B0BEB9B1C1BAB2C2BBB2
BEB7AEB4ADA5A9A49D9F9B969594908B8C8B8086867780826F797C6975796472775F7075
5B6E74586C74546B73516973
56707A5E7781667F886E878F768F977F989F87A0A690A8AE99B1B69BB2B69CB3B79EB5BA
A1B8BCA4BBC0A8C0C4ACC4C8AFC8CCB2CACDB4CACDB6CBCDB8CBCDBACCCCBCCCCCBECDCD
C0CECEC2D0CFC4D1D0C6D3D1C8D5D2CAD6D3CCD8D4CDD8D4CDD7D2CCD6D0CBD3CECAD0CA
C8CDC7C6C9C3C4C5BEC1C1BABFBEB7BEBCB5BDBBB2BFBAB2C1BAB1C2BAB1C4BAB1C4B9AE
BCB2A8AFA79FA49E9699958F8D8C88828381777C7C6E7677687274646F73606D725C6C72
596B72566A72536972506972
556F795D767F647E866C858D748C947C949B849CA28CA3A994ABAF96ACB098AEB199AFB3
9CB2B69FB6BAA3BABDA7BEC1ADC3C6B1C8CAB4CBCDB8CCCEBACECFBDD0D0C0D1D1C2D2D1
C5D3D2C7D5D4C9D7D5CBD9D6CEDBD7D0DCD8D1DDD8D2DDD8D2DCD6D1DAD4D1D7D1D0D5CE
CED1CACBCDC6C9CAC2C7C6BEC5C3BBC4C0B7C3BFB5C3BDB4C3BCB2C3BBB1C4BAAFBFB5AA
B4AAA1A8A0979C968F8F8B8681807C7576746A6E6E63696A60696B5E696C5B686D59686E
56686F546870526871506871
556E785C757E637C846A838A72899079909781989D899FA491A6AA92A7AA93A8AC96AAAD
99AEB09DB2B5A1B6B9A4BBBEA9C0C2AEC5C8B5CACCB9CDCEBDD0D1C0D3D3C4D5D5C7D7D6
CAD9D8CCDBD9CFDDDAD1DFDCD3E1DDD5E1DDD6E2DDD7E1DBD7E0DAD7DED7D6DCD4D4D9D1
D2D5CDD0D1C9CECEC5CCCBC1CAC7BEC9C4BAC8C2B8C7C0B5C6BEB3C6BCB0C3B8ACBAAFA4
AEA49AA09890918B8583807B7574716769685A5C5C565B5C58606358626656646855646A
54656C52666E51676F4F6771
546E785B747D617A826880876F868D768D927D9398859B9F8DA2A58EA3A690A4A793A6A9
96A9AC99ACAE9DB0B2A3B7B8A9BDBEAFC3C4B6C9C9BCCECEC0D2D2C4D5D5C8D8D8CBDCDA
CFDFDDD2E1DFD5E3E1D7E5E2DAE7E3DBE8E3DCE8E2DCE7E0DCE4DDDCE2DADBDFD7D9DCD3
D7D8CFD5D4CBD3D1C7D1CEC3CFCABFCDC7BBCBC3B8CBC0B4C9BEB1C5B9ADBEB2A6B3A79C
A59B91968E8687817B7875716A69665C5E5D51555551565751595C525C60525F64516167
51626950646C4F656E4E6770
546D775A737B607880667D856C838973888E798E93809498889B9E899C9F8B9EA18EA1A3
91A3A595A7A89BADAEA1B3B4A9BABAB2C3C2B9CAC9BED0CFC3D4D3C8D9D7CCDDDBD0E1DF
D4E5E3D7E8E5DBEAE7DEECE8E0EDE8E2EDE7E3EDE6E3ECE4E3E9E1E1E6DDDFE3D9DEDFD5
DCDBD1D9D8CDD7D3C8D4CFC4D2CCC0D1C9BCCFC5B8CEC1B4CABDB0C5B7A9BBADA0ADA094
9D92898D857D7E78716F6B665F5E5B505250474B4B4A4F514C54564D575B4E5B5F4E5D63
4E60674E626A4E646D4E666F
536D7659717A5E767E647B82697F866F848975898D7B8E918194968395978797998A9B9C
8E9FA093A4A498A9A99FAFAFA8B8B6B3C2C0BACAC8C1D0CEC6D6D4CCDCDAD1E1DFD5E6E3
DAE9E7DEEDE9E1EFEBE4F0EBE6F2EBE8F3EBE9F3EAE9F1E7E8EEE3E6EADFE4E6DBE2E3D8
E0DFD3DDDACEDBD6CAD8D1C5D6CDC0D4C9BCD2C5B8CEC1B3CABBADC1B2A4B4A598A4968B
92887E817A72726D67615F5B50504E4040403D3F4043494A464E514853574A575C4B5A60
4C5D644C60684D636C4D656F
526C755770795C747C61787F667C826B808570848876888B7B8C8E7D8D8E819091859495
8A99998F9E9E96A4A39DABAAA7B5B2B1BEBBBAC7C4C3D1CECAD9D6D0DFDBD6E4E1DBE9E5
E0EDE8E4F1EBE8F4EDEBF6EEEDF7EFEFF8EEF0F6EDEFF4E9EEF1E6ECEDE2EAEADEE7E5D9
E4E1D4E1DCCFDED7CADCD2C5D9CEC0D5C9BAD2C3B5CDBEAFC5B5A6B9A99BAA9B8E998C81
877D74776F6866615C5553504646453B3D3D3C3F403E4446424A4D444F5347545948585E
4A5B624B5F664C626B4D656E
526B75566F775B727A5F757C63787E687B806C7E827081847585877786877B8989808D8D
8592918B9896919E9D99A5A3A1AEABACB8B4B8C4BFC4CFCACDD9D4D4E2DCDAE8E2E1EEE7
E6F2EAEAF5EDEEF8EFF1FAF1F4FCF1F6FCF0F7FAEEF5F8EBF3F4E7F0F0E3EEECDEEBE7D9
E8E2D4E5DDCFE1D8CADED3C4DBCDBED6C8B8D0C1B1C8B8A8BDAC9DAE9E909D8F838C8076
7B72696B645D595550474543393A39333435363A3B3A40423E4649414C5044515646555B
485A60495D654B616A4C646E
516B74556D765970785D737960757B64777C67797D6A7B7D6C7B7B6F7D7C7481817A8685
7E8A8984908F8B9695929E9B9BA6A3A6B0ABB2BBB5BFC8C1CCD6CED7E1D9DEE9E0E5EFE6
ECF5EBF1F9EEF5FCF1F8FEF2FBFFF2FDFFF2FDFDF0FBFAECF8F5E7F5F1E2F2EDDEEFE8D9
EBE2D4E7DDCEE3D7C7DED1C1D9CABAD2C3B2CBBAAAC0AF9FB0A091A091848F82767E7369
6C645C5B554F4946423A38372B2A29292929313436363C3F3A43463E494D414F5444545A
46585F485C644A60694C646E
516A74546C75576E765B70775E72786173786374786575776774756A75766E7979737E7D
7983827F8987858F8C8C9693949E9A9DA6A1A8B1ABB5BDB6C3CBC2CFD6CDDCE3D9E7EDE2
EFF4E8F5FAEEF8FDF0FCFEF1FFFFF0FFFEEEFEFBEBFDF8E8FBF5E5F8F0E1F4EBDBF1E6D6
EEE1D1E9DCCAE2D4C3DCCCBBD5C5B3CCBCAAC1AF9FB3A192A392859183777F74696E645B
5C544E4A45413A37352C2B2A24242427292A2D313332393C3741443B474C3F4D52425258
45575E475B634960684C646D
506A73536B74566D74596E755B6F755D70745F7074617072626F71646F6F67716F6B7574
717A7976807D7D8683848C898B948F959D989FA7A1ABB2ABB7BEB6C4CAC1D2D6CBDEE1D5
E6EADDEDF0E2F3F4E5F7F7E7FAF7E7FAF6E4FAF3E1F9F1DFF8EEDCF6EAD8F3E6D4F0E1CF
EADBC9E4D4C2DECDBBD6C5B3CCBBAAC1AF9EB3A191A392849283768073686E635A5C544C
49443F3735312928261E1D1C1B1B1C2326272A2F3130373A353F4339464A3D4C51415157
44565D465B63495F684B646D
506973526A73546B73576C73596C725A6D715C6C705D6C6E5E6A6C5D68685F6968646D6C
6972716E7775737C7979817E828A868D948F989F99A4AAA3AFB5ADBAC0B7C6CAC0D0D3C7
D9DACDE0DFD1E6E4D5EBE8D8EEE9D8EEE8D7EFE7D6F0E5D3EFE3D0EDE0CDEBDCC9E7D7C4
E2D0BEDBCAB7D3C2AFCAB8A7BFAD9CB2A090A291849283768073686E635A5C534C49433D
36332F2625221A1918121111171717202425282E302E363A333E4238454A3C4B51405057
43565D465A63485F684B646D
4F6972516972536A72556A71566A70586A6F59696D59686B5966685964645962615B6362
616967656E6B6B73707279767B827E858C878F9690999F98A3A8A0AFB2A9BABBB0C2C3B7
C8C9BCCECDC0D5D2C4D9D5C6DDD8C8DED8C8DFD6C6DED4C3DDD1C0DACDBCD8CAB8D5C5B3
CFC0ADC8B8A6BFAE9EB6A595AA9A8B9D8E808D80737D71666C62595B524B49423D36322E
2522211716150B09090C0B0B17191A202426272E312D363A323E4237444A3B4B513F5057
42555D455A63485F684B636D
4F687251687152697153697054686E55686D56666B566568566365556061545D5D555E5C
58605E5D6462636A686B716E7278747A7F7B8489838E938C989D96A3A69DABADA3B2B3A9
B9B9ADBFBEB1C4C2B4C7C4B6CAC6B7CCC5B6CBC4B4CAC1B2C8BEAEC6BAAAC3B6A6BFB1A1
B9AB9BB1A394A99B8CA0928495877B887B70786E63685F5658514946413C34312E232120
151413080605060505101112181C1D202628272F322D373B323E4337454A3B4B513F5057
42565D455A63485F684B636D
4F687250687151687052676F53676D53666B536469536266526062515C5E4F58594F5555
505654555B595A605E606663676D69707571797E798286808B8F8795978E9B9D94A2A399
A7A89EACADA2B1B0A4B4B2A5B7B3A6B7B2A5B6B0A2B4AEA0B2AB9CAFA799ABA294A69C8E
9F9587978D8191867A897E727E746972695F645C54544E48433F3A32302D242321161615
0706060302020C0C0D1316171B202222292C2831352E393D33404537464C3B4C523F5158
42565E455B63485F684B646D
4E68714F677050676F51666E51656C51646A516368516064505E614E5A5C4C5556474E4D
454A494A4F4D505553565B595D625F6368656B706B7277717A7E7883857E8A8C8490928A
95968E999A919D9C939F9D949F9E93A09E939F9C919D9A8F9A978B979387918D828C877C
8680757F796F787269706A6266605959554F4B48433D3B372F2E2B202120121413060708
02020309090A101214171B1D1D2427242C302A34382F3B4033414738474E3C4D543F5259
42575F455B644860694B646E
4E67714F67704F666F50666D50656B5063695061674F5F644E5C604C585B495455464E4E
4146463F44424449474B504E515654575C595D625E636763696D6870736D7679727C7E77
80827B83857D85867F888881898A82898A8189898087877E84847B807F777C7A71757269
6C6A6267655E6260595957524D4D4843423F3737352A2B2A1D1F1E121414080909010000
0403030D0F1014181A1B212421292C2630352C373C303E4335444A3949503C4E5640535B
435860465C654860694B646E
4E67714E67704F666F4F656D4F646B4F63694E61674D5E634C5C604A585B485456454E50
4148493C41403B3F3D3F4543464B494C514F515552545956595E5A5E635F636762676B66
6B6F696E726C71746E73766F74777073767073756F71736D6F716B6C6E6866686361635E
5B5E5B5457544D4F4C4446443B3D3C333534282A2A1C1F2012141507090A000000020101
0B0C0E121618191F221F272A242E322A353A2E3B4133414737474D3A4C533E505841555D
445961465D6649616A4B646E
4E67714E67704E666F4E656D4E646B4E62694D61674D5E644B5C6149585C475458445052
414A4C3D4545393E3D383C3B3B403F404543454A48484E4B4B504C4F534F515753535855
555A57585D5A5B605C5D625E5E635F5F64605E645F5C625D5A605C585D5A565B59525857
4E53534B504F4449483C4040333737272C2C1C2021121617080C0D0103030202030A0C0E
111618181E211E262A232D322834392D3A4031404635454C394A513C4E563F535B42575F
445A63475E6749616B4B656F
4E67714E67704E666F4E656D4E646C4D626A4D61684C5F654B5C6249595E47565A455255
424D503E48493A4242353A39343836373D3B3B413F3E4441404543414744434946454B48
474E4B474E4B484F4C4A514E4B53504B53504A5250495150485150464E4E444D4D414A4B
3E47483A4243323A3C2A323422292B181F21111618090E100205060405060B0E1012181A
1920231F272B242E3329353A2D3A4031404635454B3849503B4E553E525941555D435961
455C65485F684A626C4C656F
4E67714E67704E666F4E656E4D646C4D636B4C61694C60664B5E64495B6147585D455459
435054404C4F3C47493840413238382D32302F3534353B3A39403E39403D373E3B353C3B
363D3C39403F3B43413942413741413944443C46473C47483B46483A46483A4548374246
3540432F3B3E293437222C2F1A2326121B1E0D1417070C0D090C0D101517161C201B2428
212B2F2631362A373D2E3C4232414835464D384A513B4E553E525940555D435861455B64
475E6748606A4A636D4C6570
4E67724E67714E66704D656F4D656D4D646C4C626A4C61684B5F664A5D64485B6146585D
4454594251553F4C503B474A374143323A3C2D34342C33332F3636303838303938303938
303A39303A3A2F3A3B303C3E334042344144344145354247364448364349334045313E43
2E3B4029353A232E321C272A172124131B1D0E13150E1316161D201B2428202B2F253136
29363C2D3C4231404734454B3749503A4C543C50573F535B41565E435861455B64465D66
48606949626B4B646E4C6670
4E68724E67714D67704D666F4D656E4D646D4D646C4C626B4B61694A5F67495E65485B62
46595F44565C4252583F4F533C4A4E3845493440432E393C2832342731332B36382D393B
2B38392B38392D3B3D2F3E41314043314043303F44303F452F3E442F3E442E3D432D3B41
2B383D283338242E321E272A181F22151C1F1921251E292D232F3427353A2B3A402F3E45
32424935464D384A513A4D553C50583E535B40555E425860445A63455C65475E67486069
49626B4A636D4B656F4C6671
4E67714E67714D67714D67704D66704D666F4D656E4C646D4C636C4B626B4B61694A5F67
485E65475C6346596044575D41545A3F50563C4D5239494E36454A334247303E442D3B41
2E3C42303E432F3E42303F4232424534444835454A34454B34444B33434A324349324249
303F4629373C243034232E3426333829363C2B39402E3E4431424834454C364950394C54
3B4F573D51593F545C40565E425861435A63455C65465D66475F6848606949616B4A626C
4B646E4B656F4C66704D6771
4E68724E67724D67714D67714D67714D67714D66704D66704D656F4C656E4C646E4C646D
4B636C4A626B496169495F68475E66465C64455A6243586042575E40555D3F535B3E525A
3E525A3E525A3D51593D50583A4E56384B54384B53374A52374A5136495136485035474E
34454C35474E384B52394C543A4D553B4F573C51593E535B3F555D41575F425861435A63
445B64455D66465E67475F6848606948616A49626B4A626C4A636D4B646E4B656F4C656F
4C66704C66704D67714D6772
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0238095 0.97619 0.245293 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(338) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
3D596C3D596C3E596D3E5A6D3E5A6D3E5A6E3F5A6E3F5B6E3F5B6F3F5B6F3F5C70405C70
405C70405D71405D71415E72415E72415E72415E73415F73415F73425F73425F73415F73
425F73425F74425F74425F74416074426074426074426074426075426174426074426074
426073415F73415F72415F72415F72415F72415E72415E71415E71405D70405C6F405C6E
405C6F405C6F405C6F405C6F405C6F405C6F3F5B6F3F5B6F3F5B6E3F5B6E3E5A6E3E5A6D
3E5A6D3E596C3D596C3D596C
3D596C3E5A6D3E5B6E3F5B6F3F5C6F405C70405D71415D72415E72415F73425F74426075
43617543617644627744637845647945647A45657A46657B46667B46667C46667C46667B
46667B46677C46677D46677C46677C46677C46687D47687E47697E47697E47697D47697D
47677B46677A46667A456679456579456579456579456478446376446275436173435F70
435F70436073436074436074436074425F73425F73415F72415E72415D71405D70405C6F
3F5B6F3E5A6E3E5A6D3D596C
3E596C3E5A6D3F5B6F405C70405D71415E72425F73426075436176446277446378456479
46657B46667C47677D48687E49697F496A814A6B824A6C834B6D844B6D844B6E854B6E84
4B6E854B6E854B6E854B6E844B6E844A6E844B6E844B6E834B6E834A6F834A6F83496E82
496C80486B7F486B7F496C80496C804A6C804A6B7F496A7E48697C48677B476678456375
456275466478466579466579456478456378446377446276436175426074425F73415E72
405D703F5C6F3E5A6E3E596D
3E596D3F5A6E405C6F415D71425E7342607443617644627745637946657A47667C48687E
4969804A6B814B6C834C6D854C6F864D70884E728A4F738B50748D50758E50758E50758D
50758D50758D50758D4F758D4F758C4F748B4E73894C72874C71854C70854B71854B7186
4B72864B71854B72854B72864C71864C71854D70854C6F844C6E824B6D814B6C7F4A6B7E
4A6A7E4A6A7E496A7E49697E48687D48677C47667B46657A456479446377436176426074
415E72405D713F5B6F3E5A6D
3E5A6D3F5B6F405C70425E7243607444627645637846657A47667C48687E4A6A804B6C82
4C6D854D6F874E71894F738B50758D517690537892547A94557C96557D97567D98557D97
557C97557C96547C95547C94547B93537A9152799052788E51778C51768B50758A4F758A
4F758A4F768B4F758B4E768B4F778C4F768B50768B50758B50758A4F73884E71864E7085
4E70854D70854D6F854C6E844C6D834B6C814A6A8048697E47677C46657A456478446276
426074415E72405C703E5A6D
3E5A6D405C70415E7242607444627645647947657B48677D4969804B6B824C6D854D6F87
4F728A50748C51768F537892547A94567D97577F9A59819D5A84A05B86A25C87A35B86A2
5A84A05A839E59839D59829C58829A588199578198578097567F96557D93557C92547C92
547C92547C93547C93547C93547C93547D94547D94557C92557B92547A9053778C52768B
52768D51768C51758C50748A4F72894E70874C6E844B6D824A6A8048687D47667B456479
436276425F73405D713F5A6E
3F5A6E405D70425F7343617645637847667B48687E4A6A804B6C834D6F864F718950738C
52768F537892557B95567D9858809B5A839F5C86A25D89A6608CAA6290AE6392B16190AE
5F8CA85E8AA55E89A45D89A35D88A25D88A15C88A15C87A05C879F5B879E5B879D5A869D
5A859D5A859D5A859C5A849C59849D59849D5A849D5A849C59829A588198587F96577E95
567E95567D94557B9353799152778F51758C4F72894D70864C6D834A6B8148687E46667B
446478436175415E713F5B6E
3F5B6E415D7142607444637746657A48687D4A6A804C6D844D6F874F728A51758D537790
557A94577D9758809B5A839E5C86A25E89A6608CAA6290AE6594B46A9BBC6A9BBB6594B3
6391AF6290AC628FAA628FAA628FAA628FA96190AA6190AA6191AA6191AA6191AA6191A9
6190A8618FA7608EA7608DA6608CA65F8CA55F8BA55E8BA45E89A35D88A25C87A15C86A0
5B859F5A849D59819B577F98567C95547A9252778E50748B4E71874C6E844A6A8048677C
466479436175415E723F5B6F
3F5B6F415E7243617645647947677C4969804C6C834E6F8750728A52758E547891567B95
587E995A819C5C84A05E88A4608BA9628FAD6492B16696B6699BBC6B9EBF6A9CBC6797B6
6696B46695B26695B26695B16696B26696B16696B06798B16799B3679BB4679DB5689DB6
689BB46799B26797B16796AF6694AE6593AE6492AD6492AD6392AD6392AE6392AE6190AC
608EA95F8BA65D88A35B859F59829B577E97557B9353778F50748B4E70874C6D8349697F
47667B446277425F733F5C6F
3F5B6F425E7344627646657A49687E4B6B824D6E864F728952758D547891567B95587F99
5B829D5D86A25F89A6618DAB6490AF6694B46898B96A9CBD6C9FC36799BD6495B66899B9
699AB96A9BB96A9CBA6B9CB96B9CB96B9DB96B9EB96C9FB96CA1BB6DA2BC6DA3BD6DA3BD
6DA3BC6EA2BB6DA0BA6C9EB96C9CB76B9BB6699AB56899B56799B5679AB7689CBA679BB9
6597B46393B0618FAB5F8BA65D87A25B839D587F98567B9453778F50738A4D6F864B6B81
48687D456478426074405C70
3F5C6F425F7345637847667C4A697F4C6D844F718851748C547891567B95597F995B839E
5E86A2608AA7638EAC6592B06796B56A9ABA6C9EC06FA4C76A9EC16496B76899BB6A9CBD
6C9EBE6EA0C06FA1C16FA2C170A2C070A3C070A4C070A5C071A7C171AAC372ABC472ABC4
72ABC372AAC372A7C172A6C071A3BE70A1BD6FA0BC6D9FBC6C9FBD6CA1C06DA4C56DA4C5
6A9FBF689BB96696B46391AE618DA85E88A35B849D587F98557B9352768E4F72894C6E84
49697F46657A436175405C70
405C7043607445637848677D4B6B814E6F8651738B53778F567A94597E985B829D5E86A2
618AA7638EAC6692B16997B66B9BBC6E9FC170A3C66B9FC2689BBD6A9DBF6C9EC06EA0C1
70A2C372A5C673A7C874A8C875A9C775A9C775AAC675AAC575A8C375A7C276A7C276A6C2
76A8C277ABC577ACC678ABC577A8C475A6C274A5C272A4C171A3C170A4C370A7C771AACD
70A9CB6DA2C36A9DBC6898B56593AF628DA95F88A25B839C587E9755799151748B4E6F85
4A6A8047667B446176405D70
405C7043607546647949687E4C6D834F718852758D557992587D975B819C5E86A1618AA6
648EAB6693B16997B66C9CBC6FA0C272A5C876AACF75A9CE6FA3C76FA2C570A2C572A4C5
74A6C876A9CB79ADCD7AAECD7AAECC7BAECC7BADCB7AABC879A5C279A1BD789EBA789DB9
7AA2BE7CA8C37CABC77CADC87BACC87AAAC778A9C777A8C675A7C574A7C774A9CA74ACCE
74ADCF72AACB6FA4C46C9EBC6998B56692AE628CA75E87A15A819A577C9453768E4F7188
4C6C8248677C446276415D71
405D7044617547657B4A6A804E6F8551738B547790577C955A809A5D849F6089A5638DAA
6692B06A97B66D9CBC70A0C273A5C877ABCF74A9CD71A5C972A5C873A6C874A6C776A7C8
78AACB7AADCE7DB1D17FB3D27FB3D181B3D180ABC97BA1BE799CB87697B17799B3799EBA
7C9DBA7E9EBA81A5C182ADC981B0CC7FAECB7CADC97AABC878A9C777A9C977ABCC78AED0
78B2D578B1D475ABCC71A4C36E9EBB6997B46591AC618AA55D849E597E9755799051738A
4D6D8349687D456377415D71
415D7144627648677C4B6B814F6F8652748C567992597E975C839D6087A3638CA86691AE
6996B46D9BBA70A0C174A5C777AACD7AAED279ACD075A7CA75A7CA76A7C977A8CA79A9CA
7AAACB7DADCE7FB0D083B4D483AFCE7B9FBC799BB77A9AB57A98B37A9AB67A99B57997B3
7898B27A9BB67EA1BD84A9C586B0CC83B1CD81AFCC7EAECB7CACCA7BACCB7AADCE7BB0D1
7BB2D47CB3D47BB1D177ABCB72A4C26D9CB96995B0648EA85F87A15B8199577B9252758C
4E6F854A697E456378415E72
415D7145627749677C4C6C8250718854768E587B945B809A5F85A0628AA6658FAC6994B2
6C99B8709EBF74A4C678ABCE7CB0D47BB0D37AADD078A9CC78A8CB79A8C97AA8C97BA9C9
7DAACA7FAACA7FA9C97FA7C77EA7C67DA6C47EA4C37EA3C27EA3C17EA4C37FA4C27FA5C2
7EA5C37CA3C1799FBC7BA1BD82A9C487B3CE85B4D082B1CE80AFCD7EAECD7EAFCF7EB2D2
7EB4D67FB6D97FB5D87DB2D277A9C771A0BD6C98B46791AC628AA45D839C587D9554768D
4F70864A6A7F466479415E72
415D7145637749687E4E6D8452738A5678915A7E975D839D6188A3658DA96892AF6B97B5
6F9CBB72A1C276A8CA7EB2D683B9E07CB0D576A8CB79A9CB7BAACB7CABCB7DAACA7EA9C9
7EA8C77DA4C27B9DBA7795B27997B57D9FBC80A2C081A6C482A9C783AAC883AAC983ADCC
83ADCC82ABC980A8C67EA8C57EA8C484AFCB88B5D185B3D083B2CF82B1D081B2D282B3D4
82B5D681B7D980B6D87EB2D37AACCB75A4C16F9BB86994AF648CA65F859E5A7E9655788F
5071884B6B80466579425E72
415E724663784A697F4F6F8553758C577B935C80996085A0648BA66790AD6B95B36E9AB9
719FBF73A3C476A8CB79ADD07AADD178A8CB77A6C87BA9CA7DABCA7FABC980AAC881AAC8
81A8C581A7C481A4C17F9FBB809DBA819EBB829FBC83A0BD83A1BF84A2C184A3C184A2C1
84A3C384A7C683A9C781A9C780A9C780AAC785AFCC88B4D086B3D085B3D184B3D284B5D4
84B7D785B9DA88BEE186BADC7DAECE78A6C4719EBA6C96B1668EA86187A05C8098567990
5172894C6C8147657A425F72
425E724764794B6A8050708755768E597C945E829B6288A2668EA96A93B06E99B6719EBD
74A2C275A5C774A6C86D9FC2689ABD72A1C47BA8CA7FAACB81AACA82ABC983ABC884A9C6
84A7C484A7C385A8C586A7C586A5C286A4C187A5C287A5C288A6C388A7C489A7C589A8C6
89A8C689A9C789A8C787A5C484A3C181A1BE82A4C086ABC888B1CF87B3D087B4D287B5D4
87B6D687B8D886B8D887B8D881B1D07AA8C574A0BC6E98B36890AA6389A25D8199587A91
52738A4D6C8248667A425F73
425E7247657A4C6B8151728856788F5B7E9760859E658BA56991AD6D97B4719CBA75A2C1
77A6C779A9CB78AACF76A9CD77A7C97BA9CA80ADCD83AECD85ADCB87ACC988ABC788ABC6
88A9C588A9C58AACC88BAECB8BACC98BAAC78CAAC78CAAC78CA9C78DAAC78EACCA8EADCB
8EADCB8EADCB8DACCA8CABC989AAC788A8C687A9C788ACC889B0CB8AB3CF89B5D289B6D3
88B7D588B8D788B9D988B8D682B1CF7CAAC776A2BE709AB56A92AC648AA35E839B597B92
53748A4E6D8348667B425F73
425F7348667A4D6C8253738A587A915D80996387A1688EA86C94B0719BB875A1BF79A6C6
7CABCC7EB0D280B2D581B3D683B4D785B4D587B3D188B2D08AB1CE8BB0CC8CAFCB8DAECA
8DADC88DADC88DADC98FB0CD90B1CE90B0CD90B0CC91B0CC91AFCC91AFCB92AFCB92B1CD
92B2CD91B1CC90B0CB8FADC98DACC78BABC78BACC78BAEC98CB1CC8CB4CF8CB5D18AB5D2
89B6D388B6D487B7D68ABADA86B5D57FACCA78A3C0729BB66C93AD668BA460849C5A7C93
54758B4E6E8349677B435F73
435F7349667B4E6D8354748B5A7C9360839B658AA36B91AB7098B4759FBC7AA5C37EACCB
82B1D284B7D987BADD89BBDD8BBBDC8BB9DA8CB8D78EB7D58FB6D391B5D291B4D092B3CF
92B1CD92B0CC93B1CD94B3D095B5D195B4D095B2CE95B2CD95B2CD95B2CC95B2CD96B2CD
95B2CD95B2CD94B2CC93B1CB91AFC88FADC68EACC58EAEC78FB2CC8FB4CE8EB4D08CB5D1
8AB5D287B4D284B3D288B9D989B9D881AFCC7AA5C1739CB76D94AE678CA561859C5B7D94
55768C4F6E8449677B436073
43607349677C4F6E8456768C5C7D9562859D688CA66E94AF749BB779A3C07FAAC883B1D1
88B8D98CBEDF8FC2E492C3E592C0E191BDDC92BCDA94BBD995BBD896BAD697BAD598B9D5
98B8D398B6D198B5D099B6D19AB7D39AB8D49AB7D399B7D29AB6D19AB6D19AB7D29BB7D1
9AB6D099B5CF98B3CD97B3CD96B2CB94B0C893B0C893B1CA93B3CC92B4CE91B6D08FB6D1
8CB5D087B2CE7EACCB7CADCC84B4D384B1CE7BA5C0759DB76F95AE698DA663869D5C7E95
56768C506F844A677C436073
4360744A687C516F8557778E5E7F976487A06B8FA97197B2789FBB7EA7C484AFCD8AB7D7
8FC0E194C8E998CCED99CAE999C5E39AC1E099C0DE9AC0DD9BC0DD9CC0DD9DC0DC9DC0DB
9EBFDA9EBED89EBCD69DBAD49EBAD49EBBD59EBCD69EBCD69EBCD69EBCD69FBCD69FBBD5
9FBBD49FBAD39EB8D19DB7CE9BB4CC9AB4CC99B5CD98B6CE98B8D097B9D295B9D292B8D2
8FB7D28AB4CF84AFCB7DA9C578A3BF79A3BE7AA3BE769DB77096AF6A8EA664879E5E7F95
57778D516F844A687C436074
4460744B687D52708659798F6081986789A26E92AB759AB57CA3BE83ACC88AB4D290BDDC
96C5E59BCBEB9ECCEB9FCBE99EC8E69EC6E39FC5E1A0C4E0A0C5E1A2C6E2A3C6E2A4C6E2
A4C6E1A4C5DFA4C3DDA3C2DBA3C0D9A3BFD7A2BDD6A2BDD6A2BDD6A2BDD6A3BED6A3BED6
A3BED6A3BDD4A2BAD1A0B8CF9FB7CE9FB9D09FBAD19EBBD29DBCD39CBCD49ABCD497BCD4
94BAD390B8D18BB5CF87B1CC83ADC880A9C47DA5BF789FB87297B06C90A766889E5F8096
58788D5170854B687C446074
4460744B697E5371875A7A9061839A698BA47194AD789DB880A7C288B0CC8FBAD797C4E3
9FCBECA4CEEEA7CFEEA7CEECA6CCE9A5CAE7A5CAE5A5C9E5A6CAE6A7CBE7A9CDE8AACDE9
ABCDE7ABCDE6ABCBE4AAC9E1A9C6DFA8C4DDA7C2DBA6C1D9A6C0D7A6C0D8A6C0D8A6C0D7
A6BFD6A6BED4A6BDD3A5BDD3A6BED4A5BFD5A5C0D6A5C0D7A3C0D7A1C0D79FBFD79DBED7
9ABDD697BBD592B9D28EB7D18CB6D188B2CC81A9C27BA1B97599B16E91A867899F608196
59788E5270854B687C446074
4461754C697E5472885B7B9163849B6B8DA57397B07CA0BA84AAC58CB4D095BEDB9FCAE8
A9D4F4B1D9F8B4D9F5B1D4F0ADD1ECABCFEAAACEE9AACEE9ABCEEAACCFEBAED0EBB0D2EC
B2D3ECB2D2EBB1D0E8B0CDE6AECBE4ADC8E0ABC6DDAAC3DBA9C1D9A9C1D8A9C1D8AAC2D8
AAC2D8AAC2D8AAC2D7ABC3D8ACC4D9ADC5DBACC5DBABC4DAA9C4DAA8C2D9A6C1D8A3C1D8
A0C1D89DC0D89AC0D996BED892BCD78CB7D286ACC57FA3BB789BB27192A9698AA0628197
5B798E5371854C697C446074
4561754D6A7E5473885D7C9265859C6D8FA77699B27FA3BD88AEC891B8D39AC2DEA3CCE9
AFD7F3B7DCF7BADCF6B9DAF3B3D5EEB1D2ECAFD0EBAFD0EBB0D0EBB1D2EBB4D4ECB6D5ED
B8D6EEB9D8EFB9D8EFB7D5EDB4D1E9B1CDE4AFC8DFADC5DCACC4DAACC3D9ADC4DAADC4DA
AEC5DBB0C6DBB0C7DBB2C8DDB4CADFB4CBDFB3CBE0B2CBE0B0C9DEAEC7DDABC6DCA9C5DB
A6C4DBA4C4DCA2C3DB9FC3DC99C0D892B8D18AAFC682A5BC7B9CB27393A96B8BA0638297
5C7A8E5471854C697D456074
4561754D6A7F5573885E7D9366879D6F91A8799BB383A6BF8CB1CB96BCD69FC6E1A7CDE7
ADD2EBB6D8F1BBDBF4BBDAF2B7D6EFB5D4EDB3D2EBB2D1EAB3D2EBB6D5EEBAD9F2BEDCF5
C1DEF6C1DDF4BEDBF2BCD9F0B9D6ECB5D0E6B1CAE0AFC6DBAEC4D9AEC3D8AFC3DAB0C5DB
B2C7DCB4C9DDB7CBDFB9CDE1BACFE3BACFE4BACFE3B8CEE3B5CCE1B2CBDFB1C9DEAEC8DD
ACC7DDAAC7DDA8C8DDA6C8DEA0C3DA97BBD28EB0C786A7BD7E9EB37595AA6D8CA0658397
5D7A8E5572854D697D456174
4561754D6A7F5674895E7D9367879D7192A97B9DB586A9C191B5CE9BC0DBA5CBE6ACD1EC
B5D7F0BDDCF3BFDCF3BEDAF1B9D6EDB7D4EBB5D2E9B3D0E7B3CFE5B4D0E6B7D2E9BCD6EB
C2DAEFC4DBF2C2DAF0BED8EEBCD7ECB7D1E7B3C9DEB0C5D9AFC2D7AFC2D6B0C3D7B2C5D9
B5C8DDB7CBDFB9CDE0BBCFE2BED2E5C0D5E7C0D5E7BED3E6BAD0E4B7CEE2B6CDE1B4CBE0
B2CADEB0C9DEADC8DCA9C6DAA3C2D69BBBD092B2C689A8BD809FB37896AA6F8DA1678497
5E7B8E5672854D697D456174
4561754D6A7F5674885F7D9368879D7292A97D9EB589ABC395B9D2A2C7E0ABD0EAB1D4EE
B3D4ECB8D6ECBCD8EEBDD8EEBAD5EAB8D2E8B6D1E6B5CFE4B3CCE0B0C9DDAEC6DAAEC6DB
B2CADEB6CCE0B9CCE0B7CADDB3C5D9B2C4D8B1C4D7B0C2D5B0C1D3B0C1D3B1C3D5B3C6D8
B7CBDDBBCFE1BED1E3C3D5E7C7D9EBC7D9EBC5D7E9C3D6E8C0D4E7BCD1E4B9CFE2B7CEE0
B6CDDFB5CDDFB4CBDEB0C7DAA8C1D39FBBCD96B2C68DA9BD83A0B47A97AA718DA1688497
5F7B8E5672854E697D456174
4562754D6A7E5673885F7D9268869C7291A87D9EB58AACC49ABDD6ADD3EDB9DEF7B9D9F1
B8D5ECB9D5EABDD6EABED7EBBBD4E8B9D1E5B7D0E3B6CEE2B4CBDEB0C5D8ADC2D4A8BDD0
A3B8CBA4B7CAA8BBCEABBCCFAEBED0B0C1D2B0C2D3B0C1D3B0C1D2AFC0D1AFC0D1B0C1D2
B1C1D1B5C4D5BCCBDAC4D3E2C7D7E6C7D7E7C8D9E9C7D9EAC3D7E8BFD3E5BBD0E1BACEDF
BACEE0BACFE0BACEDFB7CCDDAFC5D7A5BED09AB5C790ABBE86A1B47C97AA738EA1698497
607B8E5772854E697C466174
4561744D697D5572865E7B8F67859A718FA57C9BB28AAAC19DBFD8ACCEE7B9D8EFC2DFF4
C1DBF0BED7EBBCD4E8BCD4E7BBD2E5B9D0E2B7CFE0B7CEDFB5CADCB2C5D6AFC0D0ABBCCB
A9BAC9A8B8C7A9B7C6ABB9C8AEBBCBAFBDCDB0BFCFB0C0D0B0BFCFAFBECDAFBDCCAFBDCD
AEBDCDAEBECFAEBFD0B0C2D2B7C7D7BACCDBBBCDDCBCCEDDBBCDDDBACCDCBACDDCBBCEDE
BCCEDEBED1E0BED1E0BACDDDB4CADBAAC3D59FB7C993ADBE89A2B47E98AA748EA06A8497
617B8E5872854F697C466174
455F734C687B5470845D798D6582976F8CA17997AC85A3B991AFC69FBCD3AAC5DBB5CDE2
BAD1E6B9D1E5B9D0E3BBD2E4BAD0E2B8CDDFB6C8D9B4C5D5B5C7D7B5C8D8B4C4D4B2C0CF
B1BDCAB0BBC8AFBBC8B0BCC9B1BCC9B0BBC9B0BDCCB0BFCEB0BECEAFBDCCAFBDCAAFBECB
B0BECCB0BECDAEBDCCA7B7C7A5B6C6AABBCBADBFCFB0C2D1B5C5D4B9C9D7BBCBD9BBCCDA
BECEDCBFCFDEBFCFDEBBCCDBB5C9D8ADC4D4A2B9CA96AEBF8BA3B48098AA758EA06B8496
617B8D5872844F697C466173
445F734C677A536F825B778B637F936C889C7591A67E9AAF87A3B995B0C5A2BACFABC2D5
AFC6DAB4C9DCB8CBDDBBCEDFBBCEDFB8CBDBB6C7D6B2C2D0AFBCC9ADB9C6ACB8C3A9B3BE
A5AEB8A4ACB6A6ADB7A8AFB9ABB3BEAEB8C3B0BBC8B1BECBB1BECBB0BCC9AFBBC7B0BDC8
B3C1CBB4C2CDB2C0CDAFBECCADBCCAACBAC8AEBCC9B2C0CDB7C4D0BAC8D3BCCBD6BECDD9
C0CFDCC1D0DCC0CEDBBAC9D6B5C6D4B1C5D4A6BCCB99AFBF8DA3B38198A9768D9E6B8495
617A8C5871834F697B466073
445F724B6679526D80597488617C8F688397708B9F7892A67F99AC8AA3B695ADC09FB6C8
A8BDCFAEC3D4B4C7D8BACCDCBBCDDDB9CBDAB7C7D6B4C2CFB1BCC8ADB5C0A8AEB8A5AAB3
A4A7AFA3A5ADA4A6ADA8AAB2ACB2BCB0B8C3B2BCC8B3BDCBB3BDCAB0BBC8ADB7C3AAB4BE
ACB6BFB2BDC6B7C3CDB7C4CEB5C2CDB4C1CCB4C1CDB7C3CFB9C6D1BBC9D4BCCAD5BDCCD6
C0CFD9C1CFDABECBD6BDCBD6BBCAD7B8CBD9ADC2D19BB0BF8DA2B28197A7768C9D6B8293
61798B5871824F687A466073
435E714A6477506A7D5771845E788B657E916C8598728B9E7990A38298AA8CA1B395ABBD
9EB3C4A7BBCBB0C2D2B7C9D8BACCDABACBD9B8C8D6B6C4D1B4C0CCB1BAC5AFB5BFADB2BA
ACB0B8ACAFB7ADB0B8AFB3BBB1B7C0B3BCC6B5BFCAB5C0CCB5C0CCB3BEC9B0BAC5ACB6C0
A8B1BBA5B0B9A8B3BCB0BBC4B7C2CCBAC6CFBBC6CFBBC7D0BCC7D1BBC7D0BBC7D1BEC9D3
BFCBD4BFCAD4BEC9D3C0CBD4BEC9D3B4C2CFA9BAC79AADBB8DA0AF8095A4758A9A6A8191
6178895770814E687A466072
435E704963764F697B556E815B7486617A8C677F916D849672899B7990A18399A98EA2B3
97ABBBA1B4C3ACBECCB6C7D5BCCCDABCCCDABBCAD8B9C7D5B7C4D0B6C1CCB4BEC8B3BBC4
B3B9C1B3B8C1B4BAC2B5BCC4B7BEC7B8C1CAB9C3CDB9C4CEB9C3CEB7C2CCB4BFCAB1BCC6
AEB8C2ABB4BEA8B2BCA6B1BAA8B2BCACB7C0B0BBC4B2BDC6B4BEC6B8C2CABCC5CEBEC7CF
BDC6CFBBC5CDBBC3CCBBC1CBB8BFC8B0BAC5A6B4C098A9B68B9DAA7E91A0738797697E8E
5F7686566E7F4E6778455F72
425D704862744D6679526B7D5870825D7587637A8B687E906D8394758B9C7D92A2879AAA
92A5B49DAFBEA9BAC8B5C5D2BCCCD9BECDDABDCCD9BCCAD6BBC8D4BAC6D0B9C4CEB9C3CD
B9C2CBBAC1CABBC2CBBCC4CCBDC6CFBEC7D1BEC9D2BEC9D3BDC9D2BCC7D0BAC5CEB7C2CC
B4BFC8B1BCC5AEB9C1ACB6BEAAB4BDAAB4BCACB5BDB0B9C0B4BDC4B8C0C8BBC3CBBDC5CD
BBC3CBB8BFC7B4BCC3B1B8C0AFB6BFAAB4BEA3B1BC96A6B28798A57B8D9B708492677B8B
5E7484556C7D4D6677455F71
425C6F4660734B647650687A556C7E5A71825E7585637989687D8D708392788A998193A1
8C9DAA9AA9B6A6B5C1B2C1CCBBCAD6BFCEDBBFCEDABECDD9BECCD7BECBD6BECAD4BFC9D3
BFC9D3C0CAD3C1CAD4C2CBD4C3CCD5C4CED7C4CFD8C4CFD8C3CED7C2CDD6C0CBD3BDC8D0
BBC5CDB8C1CAB5BFC6B3BCC3B2BAC1B2BAC1B3BBC1B5BCC3B8BEC5BBC0C7BDC2C8BDC2C8
BABFC5B4B9BFB0B5BBABB1B8A7ADB5A2AAB29AA5AF8F9CA882909C7787946D7F8D647886
5C7180546A7B4C6476445E70
415B6E455F714962744E657752697A566C7C5A707F5E73826276846A7D8B7283917B8B98
8595A191A1AC9FADB8ABB8C2B7C3CDBECCD6C0CFDAC1CFDBC1D0DBC2D0DCC3D0DBC4CFD9
C5D0D9C6D0DAC7D1DAC8D2DBC9D3DCCAD4DDCAD5DDCAD5DDC9D4DCC8D2DAC6D0D8C4CED5
C1CBD2BEC7CEBCC4CBBAC2C9B8C0C6B8BFC5B8BFC4B9BFC5B9BFC5BAC0C6BBC0C6B9BEC3
B3B7BCADB2B7A8ADB2A2A7AC9BA0A7949BA28E959E848E987A879271808C697A87617382
596E7D5268784B6374445D70
405B6D445D6F4860714B62734F6575526877566B7A5A6D7C5E707D6576836D7D89758490
808E998D9AA59AA6B0A6B2BCB1BDC8BAC8D2C1CFD9C3D1DCC5D2DDC6D4DFC8D5E0C9D6E1
CBD6E0CCD7E0CDD8E1CFD9E2D0DAE3D0DBE3D0DBE3D0DAE2D0DAE1CED8DFCCD6DDCAD3DA
C7D0D6C4CDD2C2CACFC0C7CDBFC5CABDC3C8BDC2C7BCC1C6BCC1C5BDC0C5BABEC2B4B8BC
AEB1B5A7A9AE9FA2A7979BA08F939A878D937D838A767D85717C866B78846474805D6F7D
566A79506676496172435D6F
405A6C435C6E465E6F495F704C61714F6372526574556876596B7860717D687783707F8A
7B889286929B939EA6A2ABB4AFB8C0B9C4CCC1CDD5C5D2DBC8D5DFCAD7E1CCD9E4CEDBE6
D0DDE7D2DEE8D4E0E9D5E1EAD7E2EBD7E2EBD7E2EAD6E1E8D5DFE6D4DDE4D2DAE1D0D7DD
CDD4D9CBD1D6C8CED3C6CBCFC4C8CCC2C6CAC0C4C7C0C2C5BFC0C3BBBDC1B6B8BBB0B1B4
A7A8AB9E9FA395979C8D8F9485888D7D8187767C826F767E6A747D64717C5F6E7A596B78
5367764E6373486070425C6E
3F596C425A6C445B6C465C6C485D6D4B5E6D4D5F6D4F606D52626F5A697562707B6A7781
737F887F8A938D979F9CA5ACABB3BAB9C1C7C3CDD4C8D4DCCBD7E0CEDBE5D1DEE8D4E1EC
D6E4EFD8E6F1DAE7F1DCE9F2DEE9F2DEE9F1DFE9EFDEE8EEDDE6ECDBE3E8D8DFE5D6DCE0
D3D8DDD0D5D9CCD1D5CACED1C8CBCEC6C9CBC4C6C8C3C3C5C0C0C2BCBCBDB5B4B5ABAAAC
A1A0A39697998D8E918486897B7D817174786B7075676E75636C755F6B755A6974556673
5064724C6170475E6F425B6D
3F596B40596A42596A445969455A68475A674859664A59654B5A6552606A5B6771647078
6F79827B858C889198979EA4A7AEB3B7BEC3C3CBD1CAD4DBCFD9E1D2DEE7D6E3ECD9E6F0
DCEAF4DFECF6E1EDF6E3EEF6E4EFF5E5F0F6E6F0F5E5EEF3E4EBEFE2E8EBDFE4E8DCE1E4
D8DDE0D5D9DCD1D5D7CED0D3CBCDCEC9C9CBC7C6C8C4C3C4C0BEBFB9B7B7AFACADA4A1A2
9896978D8C8E83838578797C6D6F726263665E60645E646B5C656D59656E55646F52626F
4E606F495E6E455C6D415A6C
3E586A3F586940576741576642566443556243546044535E44515B4A565E545E665D676F
677178737C8282898E91979CA1A7ABB2B7BAC1C5CACCD3D9D2DCE2D7E1E8DBE6EEDFEAF2
E2EEF6E6F1F8E9F3FAEAF4FAECF5FAEDF6FAEEF5F9EDF3F6EBF0F4E9EDF0E5E9ECE2E5E7
DEE0E2DADCDDD6D7D8D3D2D3CFCECFCBC9CAC7C5C4C2BFBFBCB8B7B3AEAEA8A4A39C9897
8F8D8C8482827978796E6E706565685F60645A5D62585E64565F67545F69515F6A4E5E6B
4B5D6B475C6C445B6C405A6B
3E57693E56673F55653F54633F52603F515D3F4E5A3E4C563E4A53434D554B545B565E64
61686D6C73787A8085888E92979CA0A8ACAFBABEC1CACED1D4DBDEDAE4E9DFEAEFE4EFF4
E9F3F8ECF6FAEFF8FCF2FAFEF4FAFEF5FAFDF6FAFCF4F8F9F2F5F6EFF1F2EBEDEEE7E8E8
E3E3E3DFDEDEDAD9D9D6D4D3D2CECDCDC9C7C6C3C1BEBAB8B5B0AEAAA4A29D9896918C8B
8682817A77766E6B6C62606258585A55565953565A52575D5059614F5A634D5B664B5B67
485B68455A69435A6A40596B
3D57693D55663D53633D51603C4F5D3C4D593B495439454F364047384147424A504D5459
575D6262686D6F75797E83868D91939DA0A1AEB0B1C1C3C3D0D4D5DBE1E3E2EAEDE8F0F3
EEF6F9F3FAFCF6FDFFF8FEFFFAFFFFFDFFFFFEFEFEFCFCFCF8F8F8F5F3F2F1EFEEECEAE9
E7E4E3E2DEDEDDD9D7D7D2D0D1CCC9CAC4C1C2BCB9B7B1AEABA4A19E9895918B89847F7D
7873726C6867605C5D5653544C48484846484B4D514B51574B535B4A555F495762475864
4658664458684158693F586A
3D56683C54653C52623B4F5E3A4C5A394955374550344049313A4131383E3A4045444A4F
4F54585A5E62676A6D74777A8184878F92939FA1A1B0B2B2C1C3C3D0D2D2DEE1E1E8ECEC
F1F4F5F7FBFBFAFEFEFDFFFEFFFFFEFFFEFCFFFCFAFFFAF8FDF8F5F9F4F1F4EEEBF0E9E6
EBE4E1E6DEDADED7D3D7CFCACFC7C2C5BDB8BAB1ADADA4A09F9793918A86837D7A76706E
6964625D5857514D4D49454545424243424444474B464B51464F5646515B46535E455561
4356644257664057683F586A
3C56683B53643A5060394D5C384A5736465234424C313D462E373E2B32362F3438393E42
44484B4E52555A5D60686A6C757778838485919393A0A2A2B0B1B1C0C1C0CFCFCEDBDCDB
E4E7E5EDEEECF3F4F1F7F7F3F9F6F2FAF5F0FAF4EEFAF3EDFAF1EBF8EEE8F4EAE3F0E4DF
E9DED8E2D7D1DBD0CAD2C7C1C7BCB7BBB0ABAEA39E9F9591908884817A77736D6A65605D
5853514B4746413D3C3A35353936363C3C3E3F424641474D424B52424E5742505B42525F
4154624055653F56673E5769
3C55673B5263394F5F384C5A364855344450313F4A2E3A432B333B262C31262B2F2F3337
393D4043474A4D5052595B5D686A6B767879858787959696A3A5A4B1B3B2BDBFBEC9CAC8
D3D2D0DCDAD6E3E0DCE9E5E0EBE6E0ECE6E0EFE6DFF0E5DEF0E4DCEFE2DAECDFD7E7D9D1
E1D3CBDACCC4D1C4BCC7BAB3BBAEA8ADA19B9F948F908681807873716A66635C59554F4C
46413F3A3634322D2B2D2726302C2C3636393A3D423C43493E474F3F4B55404E5940505D
4052603F54633F56663E5769
3C55673A5263384E5E374B5935475432424E2F3D482C374128313823292F1F2327242729
2E3134383B3D4345474F50525D5E5F6B6C6C787979868787939392A09F9EADABA9B7B5B2
BFBDBAC6C4C0CDCAC5D4CFCAD8D2CDDAD3CEDBD3CCDCD2CBDCD0C9DACDC5D7CAC1D3C6BD
CEC0B7C6B8B0BDAFA8B2A59FA79B959A8F898B817D7D746F6E6663605956514B49433D3C
36312F2B2624231C1A241E1D2C2A2B323336363A3F3940473B454D3D49533D4C583E4F5C
3E515F3E53633E55663D5768
3B55673A5162384E5E364A5934465331414D2E3C472A363F262F3721282E1C20241C1F22
2426282D2F3138393B4545475050515B5C5C68686876767684848390908F9B9A98A4A2A0
ACAAA7B4B1ADB9B6B2BEBAB5C2BDB7C5BEB8C6BDB7C5BCB5C5BAB3C3B7B0C1B4ACBCAFA7
B6A9A1AFA29AA699939C908A928781857B76776E6A69615D5B54514D47453E3938312C2B
2721201D15131C14122320202A292B2F313533383E363E4639434C3A47523C4B573C4E5B
3D505F3D53623D55653D5668
3B5567395162374E5E354A5933455330414D2D3B4629353F252F3720272D1A1D2216161A
191A1C2223242C2C2E3637384242434E4E4F595A5A6566657271707D7C7B8786848F8E8C
9695939D9C9AA3A19EA8A4A0ACA7A3ADA8A3ADA7A1ADA6A0ACA49DAAA19AA69D96A19790
9A918A9389838C827C847B757A716D706763635C58564F4D4742403A35342F2B2925211F
1A131117100E1D1919232223292A2D2D313631383E343E4637424C3947513A4A563B4D5B
3C505E3C52623D54653D5668
3B5567395162374E5E354A5933455330414D2D3B47293640242F371F272E191E23101114
0D0C0E1515161F1F202A292A3434343E3E3E4748475252515D5D5C67676572716F7A7978
817F7F8785848C8A88908D8B918E8B93908C94908C948F8A928D888F8A858B8580857F7A
80797479726D726C686B6461615B5957524F4B47453F3B3934302E2925241D1A19151010
140F0E1814141E1C1D232426282B302C3238303840333E4636424C384652394A563A4D5B
3B505E3C52623C54653D5668
3B5567395163374E5E354A5933465430414E2D3C482937412530392029301A202613161A
0B0A0C0807071110101C1C1C2626272F2F303737383F3F3F4848475151505A5A59626261
6868676D6D6C7170707574737977767A79777B7A777B79767A7774777471746F6C6C6864
64605C5F5B58595754514F4D4845453F3D3C3734342C2A2A221F1F1A1716130F0D0F0805
120C0A1917171F1F2124262A282D332C343B303942333E4835434E374753384A573A4D5B
3B505F3B52623C54653C5668
3B5567395263374E5F354B5A3347553043502D3E4A2A384426323C212B341C242B161B20
0F11150706070504040D0D0E18181922222329292A2E2F2F3536363C3D3E4344454B4B4B
5151515557565A5B5A5D5E5E60616062626163636263636162626061605F5D5C5B585857
5253534A4A4B4343433B3B3C3434352E2E2E2625261E1D1E1614140E0B0A0A04010D0704
1412121B1B1D202326252A2F2930372D363E303B4432404A35444F374754384A58394D5C
3A505F3B52633C54663C5668
3B5567395264384F60364C5C3348573144522E404D2B3B47273540232F391E2830192127
13181D0D10130605060403040B0B0C1414151C1D1D2222222626262B2B2B303132333636
373A3A3C3F3F414445454848484B4B4B4D4D4C4F4F4C4F4F4B4E4E4A4D4E4A4D4F484B4E
44464A4043453B3D3F3335382C2D2F2223251A1A1B1312130C0A0B0702010A0503110E0F
17181A1D202422272D262E342A343C2E3942303D4833424D354552374956384B5A394E5D
3A50603B52633C54663C5669
3B56683A5365385061364D5D344A593246553042502D3E4B2A394526343E222E371D272F
18202712181D0C0F130504050302020A0A0B1212131718181A1B1B1D1E1E202222252828
282C2C292E2E2C30312F343533373934393B353A3C373C3E373C3F363C3E363C3F353B3F
32383C2D3337262C30202529191D201214170D0E100908090501010703020F0D0E161619
1B1F2320262C252D3429323B2C38412F3C4731404C344450354754374A58384D5B394F5F
3A51613B53643C55663C5669
3C56683A5465395162374F5F354C5C3349583145542F424F2C3D4A29394526343F222E38
1D283118212813191F0D11150406070000000405050E0F10141617151818151717141718
161A1B1A1E1F1E23241D23251D232620282C252D31283034283035293136293138293137
272F35222A301C242A171D2211161A0B1013080A0D07050609070710101215181C1B2025
20272E242D3528333C2B38422E3C4731404C334450354754364958384C5B394E5E3A5060
3B52633B54653C55673C5769
3C56693B5567395264385061374E5E354B5B3349583146542F42502D3F4C2A3A47263641
23313B1F2B351A252D151E2510161C0A0E120406090406080A0D0F0D1214101415101516
12171912181B121A1D151E231822281B252B1C272E1F2932222D36232E37222C34212B33
1F29301B242B161E2411171C0D12160B0F110708090A0B0D121519181D221D242B212A32
25303928353F2B39442E3E4931414E334451344755364A58374C5B384E5E3950603A5262
3B53643B54663C56683C576A
3C576A3B56683A5466395264385061374E5F354C5D344A5A3247573045532E414F2C3E4B
293A4726364223313C1F2C361B262F162028111A210A1117060B10050B100B12170F171C
0F171B0F181C111C2114202618232A18242B18252D19262F1A26301B27311C28311C2730
1B242D1A2028161D2312171C0C0F120B0D1110151A171E241C252C202B3424303A273540
2A39452D3D4930414E324451334755354958364B5A374D5D394F5F3950613A52633B5364
3B54663C55673C56693D576A
3C57693C56683B55673A54663A5365395263385061374F5F364D5D344B5B334958314656
2F44532D414F2B3E4B293A4726374323333E1F2E391C293419263017232D131E29121D26
141F2915212A15212916222A19262E1D2A331F2C361F2D381F2E391F2D381F2D38202E39
1F2C361A242D141C24151D2519232B1C27301F2C3523313B263541293A462C3D4A2E404E
304351324654344857354A5A364C5C374E5E384F603951613A52633A53643B54653B5567
3C55683C56693C57693D576A
3D576A3C576A3C57693C56693B55683B55673A54663A5365395264395163385062374F60
364E5F354D5D344B5B3349593147573045552E43522C41502B3F4E2A3D4C283C4A283B4A
283B4A283B4A283A4927394724364523354323344223344123344123344122334022323E
22323D253642283A472A3B492B3D4B2D404E2E4250304453324756334958344B5A364C5C
374E5E384F603850613951623A52633A53653B54653B54663B55673C55683C56683C5669
3C57693C576A3D576A3D586B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.267442 0.245293 0.488926 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(180) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
A3918BA3918AA3918AA3918AA2908AA2908AA2908AA2908AA2908AA29089A19089A19089
A18F89A18F89A18F89A18F89A08F88A08F88A08F88A08F88A08F89A08F89A08F8AA0908B
9F8F89A08E88A08E87A08E88A08D87A08D87A08D87A08D87A08E87A08D87A18D87A08D87
A18E87A08D87A18D87A08C86A08C86A08C85A08B85A08B85A08B849F8A839F8A839E8982
9D877F9E89829F8A839F8B84A08C85A08C86A08C86A18D86A18D87A18E87A18E88A28F88
A28F89A29089A3908AA3918A
A3918BA3918AA2908AA2908AA29089A18F89A18F89A18F89A08F88A08E88A08E889F8E88
9F8E879F8D879E8D879E8D869E8C869D8C869D8C869D8C869C8C869C8C879C8D889C8E8A
9C8C879C8B859C8A849C8A849D8A849D8A849D8A849D89839C89839D89839D89839D8983
9D89839D89839E88829D87819D87809C867F9C857E9C847E9C847D9B837C9B827B9A827A
9981799A827B9B847C9C857E9C867F9D88809D88819E89829F8A839F8B84A08C85A08D86
A18D87A18E88A28F89A3908A
A3918BA2918AA2908AA18F89A18F89A08F89A08E889F8E889F8D879E8D879E8C869D8C86
9D8C869C8C859C8B859B8B859B8A849A8A849A8983998983998983988984988A85988B87
9889839888829887819987819987819A86809A87819A87829A87829B87819B86819C8681
9C86819C86809C857F9B837D9A817B998079987F78977E77977D76977C74967B73967A71
967B73967C74977E75987F779981799A827A9A837C9B847D9C867F9D87809E89829F8A83
A08C85A18D86A18E88A29089
A3918AA2908AA1908AA18F89A08F889F8E889F8E879E8D879D8D879D8C869C8C859C8B85
9B8A849A8A84998983998982988882978781968781968680958680948681948682948783
94858094847F95847E95837D96837D97847E98857F9A86819A87829A87829B86819B857F
9B837E9B827C9A817B997F79987D77967B74957A7394787194776F93756D92736A907067
92736A93756C93776E947971957B73967D75987F779981799A827B9B847D9C867F9D8881
9E8A83A08C85A18D87A28F89
A2918AA2908AA1908AA08F899F8E889E8D879E8D879D8C869C8C859B8B859A8A849A8983
99898298888297878196868095857F94857F93847E92837D91827D90827D90827D90837F
90827C90817A91807A92807A92807A93807B94817C95827D96837E97847F98847F98837D
98817B988079987E77977C7596787294766F92756D91726A906F678F6E658D6C628C6A5F
8D6C628E6F6590716891736A92766D93786F957A72967C74977F769981799A837B9C857E
9D88809F8A83A08C86A28F88
A2918AA1908AA08F899F8E889E8D879E8D869D8C869C8B859B8A849A8A83998983988882
97878196868095857F94847E93837D91827C90817B8F807A8D7E798C7D788B7D788B7E79
8B7D788C7D778D7C768E7C768F7C768F7D77907D77917D78927E79937F7A94807A947F79
947D76947B7493797293776F92746C9070688F6E668D6C638B69608A665D89655B886459
89665B8A685E8C6B618D6D638E706690736992766C93786F957B72977E759880789A837B
9C867E9E8981A08B85A18E88
A2908AA18F89A08F889F8E879E8D879D8C869B8B859A8A84998983988882978781968680
95857F94847E92837D91827C90817B8E7F7A8D7E788B7C77897B75877873857670857671
8778738879738979738A79728B79738B78738C78738D79738D79738E79738F78738F7872
8F77708F756E8F736C8E71698D6E668C6B628A675D88645B876258855F54835C51845D52
855F5486625688645989675D8B6B608D6E648E716790746B92776F947B72967E76988179
9B847C9D87809F8B84A18E87
A2908AA18F899F8E889E8D879D8C869C8B859A8A8499898398888297878195868094857F
93847E91827C90817B8F807A8D7F798C7D778A7C75887A7486777182736D7D6F6A81736D
83746F85757086757086756F87746E88746F88746E89736D89736D89726D8A716B8A706A
896F69896D67896B64896A6287675E86645B856158845E53825B5080584C7F54477F5549
80584B825B4E835E5285615687655A89695E8B6C628D706690746A92776E947B73977F77
99837B9C867F9E8A83A18D87
A2908AA08F899F8E879D8C869C8B859B8A8499898398888296878195868094847F92837D
91827C8F817B8E7F798C7E788B7C76897B7588797386777184756F82736E7A6C687F716B
81726C82726C82726C83716B83706A84706A84706B856F6A856E68856C66856964846762
84666084665F83655D83635B826158825E55805B517F574C7D53477B4F42794A3C7A4D3F
7C50427D53467F574B815B4F835F5486635888675D8B6C628D706690746B927870957D74
9881799B857D9E8982A08D86
A2908AA08F899E8E889D8C869B8A849A898398888297878195868093847F92837D90827C
8F807B8D7F798B7D788A7C76887A7487797385777184756F83756D82746D80736C7E706A
7E6F697F6F697F6E687F6E67806D67806C66806C66816B66816A6480686281656080625E
7F605B7F5E597E5D567E5C547C5A517C574E7B544B7B5146794D4177493B744233754334
774739794C3E7B50437D55487F594D825E5285635888675D8A6C628D716790766D947A72
977F779A837C9D8881A08D86
A1908AA08F889E8D879C8C869A8A8499898397878295868094857F92837E90827C8E807B
8D7F798B7D78897C76877A7486787284777082756F80726B81736D82756F7F726C7D6F69
7C6E677C6C667C6B647C6A637C69627C69627C68627D68627E66617D635E7D605C7D5D59
7C5A567B58537A575279554F78544C775148764F45754C4175483C724335703D2D6F3A2A
713F2F74443576493B794E417B53477E594D815E5284635888685E8B6E648E736A92786F
957D7499827A9C8780A08C85
A190899F8E889D8D879C8B859A8A8498888296878194857F92847E90827C8E817B8D7F79
8B7D78897C76877A7485787283767081746E7F736C8376707F736D7E716B7C706A7B6E67
7A6C65796A6378686178665F78655E78655E78655F79655F7A67617A66607A645D79615A
795D5877575276534E74514B724F48724D44714A4071483C7144386F40326E3B2B6B3524
6C36246F3C2C71423374483A774D407A53477E594D815F5485655A896A608C706790766D
947B739881799C867F9F8C85
A190899F8E889D8D869B8B8599898397878295868093847F91837D8F817B8D7F7A8B7E78
897C76877A7585787382767180746E7E726C7B706A756A64796E677A6E68796D67786C66
786B6476696175655E74635C74625B73625B74635C75645D776861786A63786A63786861
77645C745B5472544E704F486E4B446D49406C463C6C44386C42356C3E306B392A693524
6831206A35246C3B2B6F413373473A764E417A54487E5B4F82615686675D8A6D648E736B
937971977F789B857E9F8B84
A190899F8E889C8C869A8A8498888396868194857F91837E8F827C8D807B8B7E79897C77
877B7585797382777180746F7E726D7B6F6A7B706A766C67766C67776C67766B66766C66
756A6474676172645C6F5F596F5F596F5F596D625B746A63776C667A716A7A6F68786861
76686073635B6F5B536A4F4869484168453D684339684136693F33693D2F683829663423
642E1C642E1C6734236A3A2B6E413372483B764F437B564B7F5D5284645A886B618D7168
91786F967E769A857D9F8B84
A18F899E8E879C8C86998A8497888395868192847F90827D8E817B8C7F7A897D78877B76
8579748377728075707E736D7B706B796F6A716965736B66746B66746C66746A65746B65
746B6573696371655E6D60596B6059736C65736D66746F68757069766E67787069796E66
7A6C657767607360596A544D64484163423B634037643E33653D31663B2E663829643323
622E1D612B1A612E1E643324683B2D6D4336724B3E7752477C5A4F81615786685E8B6F66
90766D957D759A847C9E8A84
A18F899E8D879B8C86998A8496878294858091837E8F817C8C807A8A7E79887C77867A75
8478738176717F746F7B716B786D68786E6A6D6662706964716A66726C67726B66726C66
726C67736C66716B64726A626D635C70655D71665F71675F72696173685F74675F74645B
75635A77625878635A745C546950485F413A5F3C33603A30623A2F633A2D633728623223
602D1C5F29175D2A185E2C1D623426693D306E463A744E4379564B7F5E5484665C896D64
8E746C947C7499837B9E8A83
A08F899E8D879B8B8598898395878192857F90827D8D807B8B7E7A887D78867B76847974
8277738076717E746E796F69716761726A657069656F6966706965706965706A65706C67
726E69736F6A75736D77766F73716A706B646F69626F665E6F655E70645C70635B705F56
715C54705A51725C5272574E6F534A64473F5B3A325D382F5E382D60382B6135275F3223
5E2D1D5D29175C28175C2B1A5E2F2164392B6A4235704B3F7653487C5B51826359876B62
8D736A937B7298827B9E8A83
A08F899D8D879A8B8597888394868191847F8E817C8B7F7B897D79867B77847A75827873
8077727F76717F75707F7571776F6A706B67706B686E6A666D69666D69676D6A676E6C68
6F6E6A6F6D686E6B666F6E686F6E676E6D666E6C656F6C646F6C64706A6270696070675E
6F645A6F5E546E5B516F574D6E5248694C425F3F365A372E5C372C5E372B5F35275E3122
5C2D1D5B28185723115322115A2C1D603427673E326D473B7450457A594E806157866960
8C716992797197817A9D8982
A08F899D8D879A8A8596888393868190847F8D817C8A7E7A877C78847A76827874807672
7E75717E7570807873877E79857C7676706C6F6A676C69666B6A666B69676B69676B6C69
6D6E6A6D6D696A67636A67616A68626A69626B68626B68626B68626C67606C665E6C635B
6B60586A5D54695B5069594E6A574C695348644A405D3F355B392E5C372B5D35285C3224
5B2E1E5A2A1A5A29185021115528195D3224643B2E6A4438714D4277564C7E5F5584685E
8A70679178709781799D8982
A08F899C8C87998A849587829285808F827E8B807B887D79857B778278757F76727D7471
7B736F7A726E7B746E7B736E78726E716C6A6B6865686765686765676866676967686A68
696C6A696B6867656165625C65635D66645F67655F67655F68666069665F68635C685F58
675D55665A5264574E64544A645147624D4260473C5D41375B3B315B382D5B35295B3124
5A2E205A2B1C5929184D1F11522518592E2160382B6742366E4B4075544A7C5D5382665D
896F6690776F9680799D8982
A08F899C8C86988A849587829184808D827D8A7F7B867C788279767F77737C747179726F
77706D756E6B736D6A716B676E67646A6462666362656362646462636563636664636766
64696765686664656262605C615E5962605B63615C64615C64625D65635D65615B645D57
645A5364585062544D605249604E465F4B425D463D5B40365A3C3259382E5A362A5A3226
5A2F225B2D1E5C2B1B4B1D0E4E2112562B1D5D3528653F336C493E7352487A5B5281645B
886E658F766F967F789C8881
9F8F899C8C8698898494868290847F8C817D887E7A847B778078757C757279726F756F6C
726C6A6F6A676C67646A646266615F645F5D615F5E605E5E5F5F5E5F60605E62615F6362
5F65636065636063605E5F5B5D5B575E5D585F5F5A60605B61605C62615C625F5A625D57
6159536056505E524C5D4F485B4B455B49425B463E594139583D3457392F58362B583327
5930235B2F205F2F1E4E2010491C0E52271A5B3226623D316A473C715046785A507F635A
866C648E766E957F779C8881
9F8E889B8C869789849386818F837F8B807C867D79827A777E767479737175706D716C6A
6D696769656465615F625E5C5E5B5A5D5B5A5C5B5A5B5B5A5A5B5B5A5C5C5A5D5D5A5E5E
5A5F5F5A605F5B605E5A5D5B595A565A5A565B5B575C5C585E5D595F5D595F5C575E5954
5D56515C544E5A514A594D4657494256464056433D564038553D3455393055362B563328
5731255B30226233235D2C1B4E20114D2215593124613B3068453A6F4F4576584F7E6259
856B638D756D947E779C8881
9F8E889B8C869789849286818E837E897F7C857C798079767B757376716F716D6C6C6968
676564635F5F5E59595B5657575555555757555757555757555757555757545858545959
555A5A555A5A555B5A565A595558565658555758555858555A5A565B59565B59545A5551
58524E574F4B554D4853494452464052443D51403A523E36523A3251372E52342A523127
542F23562D215A2F225C2F215B2E1F572C205931255F3A2F6643396D4D4374574D7C6058
846A628C746C937E769B8781
9F8E889B8B869688849285818D827E887F7C837B797E787579747273706E6D6B6A686766
6262635D5D5E5858595353545151525052535053545053545053545053544F53544F5354
4F54544F5454505454505353505453525554545755555856575956585856585754575450
55504D524D49514A475048434E443F4D403B4C3D374D3B344D38314D352D4D32294E2F26
4E2C23502A20522B1F52281A51251753291D5730245D382D6341376B4B4272554C7A5F57
8269618B736C937D769B8780
9F8E889A8B869688849185818C827E877F7B827B787C7775767371706E6E6A6969636464
5B5F5F555A5B4F54554A4E50494C4F494D4F4A4E504A4F514B4F514B4F504A4F4F494E4F
494E4F494D4F494E4F4A4D4E4B4E4E4D50504F5352525554545756565755565553545250
524F4C504B484D48454B444049403C483C38483A3447373148352E48332B483027482D24
482A2149271D4B271C4B2317491E114C2216522C2159352B603F3668494070544B795E56
81686089726B927D769B8780
9F8E899A8B869688849185818C827F867E7C817B787B76757472716E6D6D6768695F6264
55595A4A5153424B4F3F474B40474B42494C444A4D454B4E464C4E464C4E464C4D444B4D
434A4C42484B43484B44494A454A4A484D4D4B504F4E535251565453575553545251514F
4F4C4A4C484649444246403D443C3942383542363242342F42322D42312A422E27422B23
43271F42241B432218431D12441B0F461C104E281D5532295D3D3465473F6E524A775C55
7F676088726A917C759A8780
9F8E899A8C869689849186828B827F867F7C807B797976757371716C6D6D6568695D6366
53595C454E523B464C343F463842483C454A3F484B41494C424A4D424A4D414A4D3F494B
3E474A3C44473C42453D42443F4446434849484D4D4B51514F54535055545053524E4F4E
4C4A4848454345413F413C3A3E38353D34323C322E3C302C3D2F2A3D2D273D2B253D2922
3D251E3C21193C20173B19103C180E40190E48241B512F26593A3262453D6B5049745B54
7E665F87716A907C759A8680
9F8F899A8C879689859186828C8380867F7D807B797976757171716A6C6D6267695C6468
565D6247505538454B2E3C44323F453743483A454A3E484D3F494D3E484B3D4649394346
364145343F44353E43373E423A3F423E4445444A4C4950514D54544F55554F53524D4F4D
494948454442413E3D3C3A3839353337312F372F2D362D2A382C28392A26382823382620
38231D372019371D1633160F34130B39150C4321194C2D255638305F433C694F47725A53
7C655E867069907B74998680
9F8F899B8C87968A859187838C848186807E807C7A787776707171676B6C5F6568596164
515A5F404C5333424A293A432E3D4533414838444A3B484D404C51414D51404C503C494D
364449304045303E42333E42363D413A404342494B4850514C55564F56574F54544C4F4F
484948434241403E3D3C3938373332332E2D322B2A31292732292634282434262133241F
32221C331F19331D173018122F130C34120B3E1F17482A2351362F5C413B664D46705852
7A645D846F698F7B7499867F
9F8F899B8D88978B869388858D8583888280817D7C7978786F717264696B5B6367565E62
535C6044505733434C2639432B3D4630414935444B39484F3E4D534452584854594A555A
4451553C4B5037474C38484D3C494D3E484C434C4E4851544C56584F57594F55564C4F50
484949403F403D3C3C373636312F302D2B2A2D29282C26252D252330252231242131221E
2F201B2E1D192C1A1628151128120D2E110C391D174328224D342E58403A634B456E5751
78635D836F688E7A7499867F
A08F899C8D88988C88948A868F88858A858383807F7B7A7A7072736065674F575C4E595E
4E585E424F5731434D233843283C462E404933444C37474F3C4C5342525947565C4E5B60
515D624D5A5F465458415055404E52414C50444E514852554C565950585B515859505455
4F5252484949414244393A3B3031332E2C2E2A28292723242923232C23213024212F231F
2D201C2B1C182718141F110E1F0D09270E09331A153E252049312C543E38604A446B5650
77625C826E688D7A7498857F
A0908A9D8F8A9A8E8A968C89928B888D8886888584808080747677656B6D505C61445259
4351583B4B542F424D223844273C472C404A31444E35454F394A523F505844565E495A61
4A5A6249596146575E435359415056424F544450544853574C575B50595D525A5C525758
515554504F4E504D4C4E49483F3E3E3A3636363233302C2C302A2A3028273126242F2321
2C211E2A1D1A2215131B0F0C1807051F08052C161238221E452F2B513C375D4844695550
75615C816D688C797498857F
A1918C9E908C9B908C988F8C958E8B928D8B8D8B8A89898985888972787B606C704F5E64
46565D3B4D562F434E223845263C472B404B314751364B55384B553A4D553E515941555D
42576041555E40545C3F51593E4F574251584552574854594C585C50595D525A5E52575A
5053554E5050504F4E56514F514C4B4A4443443D3C3C3636373131332C2B312928302624
2D22202B1F1C211614190E0E1508071A050326120F331F1C402D294D3A365A474367544F
73615C806D688C797397857F
A1928C9F928D9D928E9B928E99928F9692909492919292929094947D83866A74795A676D
4D5D643D515A2E4551213A47243B472A404B2F4650364C573D535D405660435963465D67
4B616A4A606A485F68465B6444575F44555C45555B48555B4C585D505A5F525B6052585D
4E52564B4D504B4C4D4C4B4B4B48484A46464541413D393A383334352E2F322A2B302626
2E23222A1F1E1E1616160F10150B0A1403021F0E0C2D1C1A3C2B284A393658464365534F
72605C7F6D688B797397857F
A2928DA1938E9F94909E94919D96939B97959A9897999A9A9A9D9E8A8F91777F83657176
53636A41545E314753223C49223A47273E4A2D434E32495439505B3F5862455E6848616C
4A646F4B65704A646F47606A455A6343565E44565C46565C4A585D4F5A5F535E61576063
565C604E5156484A4E444549444446434143413E3F3C393A383435352F30332B2C322829
3025252A1F1F1F1718120D0F1008090E0000140505281918382927483835564643645350
71605C7E6D688B797497857F
A3938DA29590A19692A19894A09997A09B9AA09E9DA0A1A0A1A4A592989A81898D6E797F
5C6B72485B64344B57253E4C213A48253C4929414C2F4551344B5639515C3D5661405A65
425C68435D68435C68425A6642586242555D43555C45555B48555B4C575D505A5F555D61
5A5F635B5D6157575B4C4E514344483E3E423C3B3E39373A373436363133362F30342C2D
342A2A2A22221E181A100E120B080B0F0607120708251818362827463836554643635350
71605C7E6D688A797497857F
A3948EA39691A49894A49B97A49D9AA4A09EA5A3A2A6A6A6A8AAAB9B9FA08B9195768186
6371784E606A394F5C27414F203948213A47263D492B414D2F4551334A55374E593A525D
3B54603D55613D56623D55603E545F3E525C40525A42525A44535A47545A4B555A4F575C
54595D565A5D58595C5757595352544C4B4D474446423F41403C3E3B3638383234362F30
362E2E2D2527221D1F1716190E0F120E0A0D11090B23191A342929453837544745635451
70615D7E6D698A7A74978580
A4948FA59792A69A96A69D9AA7A09EA9A4A2AAA7A6ACABABADAFAF9FA3A491979A7E888D
69777F54656F3E54602A43521F39481F3745233A47273E4A2B414D2E4551314854344B56
354D59374E5A384F5B384F5B394F5A3A4E583B4E583D4E57404E56424F56465057495257
4D5358505458525457525356525154504E514C4A4C464446423E403E3A3B3B3637393233
362F302F292B2722251F1C1F161518110E12110B0D211819342A2B453A39554847635653
71625F7E6E6A8B7A75978680
A5958FA69894A89C98A9A09CABA4A1ADA8A6AEACABB1B0B0B3B5B5A5A9AB979DA1858F94
717F86596C76435A662F4857203B4A1C3544203745243A47273D492A3F4B2C434F2E4551
304752314854324955334A56344A56354A54364A54384A533A4A533D4A52404B53434D53
464E54494E544B4E534C4E534B4D514A4A4E48474A444346403F413D3B3D3B383A3A3537
363133302C2E29272A2221251C1B1F16151A161316231C1E362E2F473D3D564B4A655855
7264617F6F6C8B7B76978680
A59590A79A95A99E9AACA29FAEA7A4B0ABA9B3B0AFB5B5B5B9BABBABAEB09CA3A68C969B
79868E63747E4D626E38515F2742521D37471E3644213745243946263B47283D4929404C
2B414E2C43502D44502E44512F455130455131455033454F35454F37464F3A464F3C474F
40484F43495044494F46494E46484D45474B444449434246413F42403C3F3E3A3C3D383A
3A35373430332E2B2F29272B2423271F1F241F1E222924273B34364B4242594E4D675A58
73666380716D8C7C77988781
A69690A99B96ABA09BAEA5A1B1AAA7B4AFADB7B4B3BAB9B9BDBFC0B0B4B6A2A8AC929CA1
808D956B7C855469753F57652E4857213C4B1D36441F3643213744223844243845253A46
263C49273E4B273F4C283F4C29404C2B404D2C414C2D414B2F404B31404A34414B37424B
3A434C3D454C3E454C40454B41444A414449414247414145403F433F3D403F3C3F3F3B3D
3B373A383538333135302E322C2B2F28282D2A292D363235423C3E5047485D5352695E5C
75686681736F8D7D78988782
A69791AA9C97ADA19DB0A7A3B4ADAAB8B2B0BBB8B7BFBDBDC2C3C3B4B8BAA7ADB098A1A6
87949B74838D5D727D465F6D324E5E2541521E38481D35441E35431F3543203642203642
213744223845223947233A47233A47243A47263B47283B47293C472B3C472E3D47313F48
3440483741493941493B41493C42493E42483F42473F40463F4044403F43413F42403D41
3F3C3F3C3A3D39383B3535393232362F2F342E2C313C393C494345554D4E6157566C615F
786B688375718E7E7A998882
A79791AB9D98AFA39FB3A9A5B7AFACBBB6B4C0BDBBC5C4C3C9C9CABBBEC0AEB3B69FA7AC
909BA27C8B946679845067753955652846571E394A1B34441B33421C33411C32401C323F
1C323F1D323F1D33411D34411D34421E35421F36432135422236422537432839442B3A45
2F3B45323D46353F47373F47393F473B3F473C40463D40463D40453E3F44404045403F44
403F433E3D423C3B4039393F36373D36373C37353A4440434F4A4B5A5353655C5B706563
7A6E6B8577738F807B998883
A79792AC9E99B0A4A0B5ABA7B9B2AFBEB9B7C4C0BFC9C8C7CFD0D0C3C6C8B5BABDA6AEB3
96A1A883929A6E808B586F7C415C6C2E4C5D1F3D4E1A344519324218313F182F3D182E3C
182E3B172E3C172F3D18303E18303F18303E19303E1A303E1C303E1E3240213440253541
2937422C3944303B45333C46353E46383E463A3F463C40463D40463F4147414348424348
4343484343474142474040453E3F443F40454544494C494C5650526058596A6060736967
7D716E87797590817C9A8984
A89892AD9F9AB1A5A1B7ADA9BCB4B1C1BCB9C7C4C2CECCCCD5D6D6CBCED0BCC2C5AEB5BA
9FA9AF8C9AA37789946177844C65753754652544561A3749173142152F3F142D3D142C3B
132B3A122B3A112A3A112B3A122C3C112B3B122B3B132B3B142C3A172D3B1A2F3D1F323F
2333402736412B38432E3A44323C46353E473940483C41493F434941444B43464C44474C
45474D47484D46474D44464B4244493F40454B494D5450535C5758655E5E6E6564776C6B
807471897B7792827E9A8A84
A89892AD9F9AB3A6A2B8AEAABEB6B3C4BEBCCBC7C5D2D0CFDADADAD3D5D7C6CBCEB6BEC3
A7B1B896A3AB82929D6D818D5A717F466070304E5F1F3E51173446142E40122B3C10293A
0E28390D27380C27380B26380B27390B27390A26380B27380E2738112838142B3A192E3C
1D313E2133402635422B38442F3B46333E483840493E444C41464E444950484B52494C52
494C534A4D534B4D534A4D524B4C5148484C5251545B575A635D5F6B6364736A697B706E
8377748B7D7993847F9B8A85
A99893AEA09BB4A7A3B9AFABC0B7B4C6C0BDCDC9C7D5D3D2DFE0E0DEDFE1D0D3D6C1C7CB
B1BBC0A2AEB58F9DA67A8C98687D8A546D7C415D6E2C4A5D1E3D50143246112C3F0E293C
0B26390824370723360623360624370424370322350422340624350A26370E2839132A3A
182E3D1D313F2335422938442F3C4834404B39434D404750464C544A4F564D51584F5359
51545A52555B52555B51545A52555B57575C5C5A5D625E60696364706869776E6D7E7472
8679778D7F7B9485819C8B86
A99993AEA09BB4A8A3BAB0ACC1B8B5C8C1BECFCAC9D7D5D4E1E1E0E5E7E8DADDDFCAD0D4
BBC3C8ABB7BE9AA8B18697A2768995647A88546C7C405B6D2F4D5F224054173549112E42
0A283C0624380422360322360323370223380123370022360122350524360927390F2A3B
132D3E19303F2034432739472E3E4B36434F3D4853454D574B525A50555D54585F575A61
595C625B5D635B5E635A5D6256585E5E5E626462656965676F696A756E6D7C7271827775
897C798F817D9686829D8C86
A99993AFA09BB5A8A3BBB0ACC2B8B5C9C1BFD0CBC9D8D5D4E1E0DFEAEBEBE5E7E9D6DADD
C7CED2B8C2C7A8B4BB94A4AD8495A0748894647A88546C7B445E6E3551632946591F3D4F
173548102F430B2A3F08283D08293E06293F05283F03273D03263B04263C08293D0D2C3F
133042193445203747293D4B3243503B4A55434F5A4C555E525962585E655D6167606369
63656B65676D66686D64676C63646868666A6C696B706C6D756F6F7A7272807675857A78
8B7F7C91837F9788839D8C87
A99993AFA09BB5A8A3BBB0ACC2B8B5C9C1BED0CBC8D9D5D3E2E0DFECECEBEEEFF0E1E4E6
D3D7DBC4CBD0B6BFC6A5B1B993A2AB83949F738693637886546B7A475F6F3D5566334D5E
294658213F521A3A4E15354A1435491234490F32480C30460B2F450B2E440E3045133347
1836491F3A4C263E4F2F4453384A5843515D4B5761535D665B616A61666D666A706A6D72
6D6F757071777172776F7176707074716F727470727772737B74747F7776847A78897D7B
8E817E9385819889849E8D87
A99993AFA09BB5A8A3BBB0ABC2B8B4C9C1BDD0CAC7D8D4D2E1DEDDEBEAE9F3F4F4EDEFF0
DEE1E4D0D5D9C1C9CEB1BBC2A1AEB6919FA983949E748692667B885A707F4F6676465E6E
3E5768355062304C5E2946592543562341542140541E3E521C3D511D3D511F3E52234053
2743552D4758344C5B3D515F4556624F5C6757616B5F676F656B736B6F7670737874767B
77787D7A7B807C7D817B7B8079787B7976797B76787D7778807978847B7A887D7B8C807D
9083809587829A8A859E8E88
A99892AFA09AB5A7A2BBAFAAC1B7B3C8BFBCCFC8C5D7D2CFE0DCDAE9E7E6F3F3F2F5F5F6
E9EBECDBDFE2CDD3D7BDC5CBAFBAC0A2AEB695A3AC8595A07788946C7E8A617582586D7B
506675475F6F435B6B3D5667395364355063334F61324E60304D5F304D5F324E5F365061
3A52633F5665455A684D5E6B54626E5B6771636C756B717971757C76797F7C7D827F8084
818286848589848488818083807D80807C7D817B7C837C7C857D7C887E7D8B807E8F8380
9385829788849B8B869F8E88
A99892AE9F9AB4A6A1BAAEA9C0B5B1C7BDBACEC6C3D5CFCDDED9D7E7E4E2F1F1EFFAFBFA
F3F4F5E6E9EBDADEE1CCD2D6BEC6CBB0BAC0A5AFB798A4AD8A98A27F8F997585906C7D89
6576835D707D566B785166754D63724A6070485E6F465D6E455C6D465C6D475D6D4C606F
5063715566745A6A76606D7865707A6A737C70777F777C827D808682848885858986868A
89898D8A8A8D88878A87848686828486808186808087807F89807F8C82808E8381928582
9587839889859C8C87A08F89
A89892AE9E99B3A5A0B9ACA7BFB3AFC5BBB7CCC3C0D3CCC9DBD5D3E4E0DEEDEBEAFAF9F9
FEFEFEF4F5F6E6E9EBD9DDE0CCD2D5C0C7CCB6BEC4ABB4BB9FA9B195A0A889969F808E97
79879172818C6B7C8667788364758160717E5D6F7C5C6E7B5B6C7A5C6D7A5E6E7B63717D
65737F6A76816F7983747C85787F867D828882858B87898E8B8B908E8E92929093929193
8E8C8F8E8C8F8D8A8C8B87898B85868A84848B83838C83828D83828F8482918583948784
9789859A8B869D8D88A08F89
A89791AD9D98B2A49EB8AAA5BDB1ADC3B8B4C9C0BCD0C8C5D7D1CEDFDAD8E8E5E3F2F0EF
FDFCFCFFFFFFF5F5F6E7E8EADADCDFCFD3D6C6CBCEBDC3C8B3BABFAAB1B79FA7AF969FA7
8F99A089939B838F977E8A9279858F75828C727F8A717D886F7C876F7C86707D8776808A
7C858E808790838890878B918C8E938F909491919594939798969998979A98979A98979A
969497939092918D8E908A8B8F89898F87878F8685908685918684928784948884968985
998A869B8C879E8E88A08F89
A89791AC9C97B1A29DB6A8A3BBAEAAC0B5B1C6BCB8CCC3C0D3CBC8DAD4D1E2DDDBEAE7E5
F3F1F0FDFCFCFFFEFEF5F4F4E7E7E9DBDCDED2D5D7CCCFD2C5C8CBBDC0C3B5B8BCABB0B5
A4A9AF9DA3A9989EA4939AA08E969D8B929A888F97858D95848B94828992838A91858B92
898D9490939896979B98989C9B9A9D9C9A9D9D9B9D9E9C9EA09EA0A2A0A2A09FA29E9C9E
9A9698979294958F90948D8D938B8B928A89928987938886948886958986968986988A86
9A8B879C8D889F8E89A1908A
A79690AB9B95B0A09BB4A6A1B9ABA7BEB1ADC3B7B3C8BEBACEC5C2D5CDCADBD5D2E3DDDB
EAE6E4F2EFEEFCFAF9FDFBFBF3F1F1E8E7E8DDDDDED7D7D9D2D2D5CCCDCFC5C5C8BFBFC2
BABABEB4B5B8AEAFB2A8AAAEA3A6AA9EA1A79B9EA3989BA1979AA095989D929599929498
95969A99989C9B9A9D9E9C9FA29FA1A5A1A4A6A3A4A7A4A5A8A5A6A9A6A8A4A2A4A09D9E
9D98999A9495989191978F8E968D8C958C8A958B89968A88968A87978B87998B879A8C87
9C8D889D8E889F8F89A1908A
A7968FAA9A94AE9F99B2A39EB6A8A3BAADA8BFB3AEC4B8B4C9BFBBCEC5C2D4CCC9DAD3D0
E1DBD9E8E3E1F0ECEAF9F7F6FAF7F7F0EEEDE6E4E4DFDDDEDAD9DAD7D6D7D2D0D2CBC9CB
C6C4C6C3C0C3C0BDBFBBB9BBB5B4B6B1B0B2AEACB0AAA9ACA8A7AAA6A4A8A5A3A5A2A0A3
A5A2A4A9A4A5ACA6A7AEA8A9B0AAAAB2ACACB2ACADAFABACAFABADACA9AAA7A3A3A39D9D
9F99999D95959B93929A908F998F8D988D8B988D8A988C89998C889A8C889B8C889C8D88
9D8E899F8E89A08F8AA2908A
A6958FA99993AD9C97B0A09BB3A59FB7A9A4BBAEA9BFB2AEC3B8B3C8BDB9CDC3BFD2C9C6
D8CFCCDED6D4E4DEDCEBE6E4F4F0EFF7F3F2F1EDEDE6E2E1DEDADADBD7D7D9D6D7D8D3D4
D4CFD0D0CBCBCBC5C6C9C4C4C8C2C2C3BDBDBDB6B7B7B2B3B5AFB0B2ADAEB1ABABADA8A8
AFA9A9B1AAAAB4ACABB6AEADB7AFAFB8B0B0B8B1B0B2AEAFB0ACADACA6A6A8A1A1A49D9C
A199989F96949D93919C918F9B908D9B8F8C9B8E8B9B8D8A9B8D899C8D899C8D899D8E89
9E8E899F8F89A1908AA2908A
A6948EA89791AB9A94AE9E98B0A19BB3A59FB6A8A3BAACA7BDB0ACC1B5B0C5B9B5C9BEBA
CEC4C0D2C9C6D8CFCCDDD6D3E3DCDAE9E3E0EFE9E7EDE7E6E5DEDDDFD8D7DAD5D4D8D2D2
D6CFCFD5CECDD3CAC9CFC6C4CBC2C0C8BFBDC4BBB8C0B7B5BAB2B0B8B0AEB7AFAEB5AEAD
B5AEACB7AFADBAB1B0BCB3B1BCB4B3BAB2B3BBB4B5B5AFAFAFA8A7ABA3A2A89F9DA59B99
A29896A096939F94919E928F9D918D9D908C9D8F8B9D8F8A9D8E8A9D8E8A9E8E899F8F89
9F8F8AA08F8AA1908AA2918A
A5938DA7958FA99892AB9B95AD9D97AFA09AB2A39DB4A6A0B7A9A4BAACA7BDB0ABC0B3AF
C3B7B3C7BBB7CBC0BCCFC5C1D3CAC6D8CFCBDCD3D0E3DBD7E5DCD9E3DAD7DDD4D1D6CDCC
D6CCCBD5CBCAD2C8C6CFC4C1CBC0BEC9BEBCC7BBB9C5B9B6C2B7B4C0B5B2BCB3B0BBB2AF
BAB2B0B9B2B0BBB3B1BBB3B2BFB8B8BEB7B6B7AFAEB2A8A7ADA3A1AA9F9DA79C99A59996
A39794A29591A09390A0928E9F918D9F908C9E908B9E8F8B9F8F8A9F8F8A9F8F8AA08F8A
A0908AA1908AA2908AA3918B
A5938DA6948EA79690A89791AA9993AB9B95AD9D97AF9F99B0A19BB2A39EB4A6A0B6A8A3
B9ABA6BBAEA9BEB0ACC1B4AFC3B7B2C6BAB6C9BDB9CCC1BCCEC3BED0C4BFD2C7C2D0C6C1
CDC3BECDC2BECCC1BFCCC1BDC9BDBAC3B8B5C1B5B3BFB3B0BDB2AEBDB1ADBBAFACB8AEAA
B8ADAAB9AFADBFB6B3BBB2AFB7ADAAB4A9A7B1A5A2ADA19EAA9E9AA89B97A69995A59793
A39591A2948FA2938EA1928DA1918CA0918CA0908BA0908BA0908BA0908AA1908AA1908A
A1908AA2908AA2918AA3918B
A4928CA5938CA5948DA6948EA7958FA79690A89791A99892AA9993AB9A94AC9B96AD9D97
AE9E98AF9F9AB1A19BB2A29DB3A49FB5A6A0B6A7A2B8A9A3B9AAA4B9ABA5BAABA6BAABA6
B9ABA5B9ABA5B9ABA6BAACA7BDAFA8BCAEA8BCAEA9BBADA9BAACA8BAACA8B9ACA8B9ACA8
B8ABA7B2A5A1B0A39EAFA19DAD9F9BAC9D99AA9B97A89995A79893A69691A59590A4948F
A3938EA3938DA2928DA2928CA2918CA2918BA2918BA2918BA2918BA2918BA2918BA2918B
A2918BA3918BA3918BA3918B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.267442 0.488926 0.488926 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(202) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
968E8B968E8B968E8B968E8B968E8B968E8B968E8B958E8C958E8C958E8C958E8C958E8C
958E8C958E8C958E8C958E8C958E8C958E8D948E8D948E8D948F8D948F8E94908F949192
948F8E948E8D948E8C948E8C948D8B958E8C958E8C958E8C958E8C958E8C968E8C958E8C
968E8C958D8A958C8A958B89948A88948A8794898693888593878492868392858191837F
8F807B918480928682928783938885938985938986948986948A87948A87948B88958B88
958C89958C89958D8A968D8A
968E8B968E8B968D8B958E8B958E8C958E8C958E8C958E8C958E8C958E8D948E8D948E8D
948F8D948F8D948F8E948F8E938F8E938F8E938F8F938F8F929090929091929192929395
929191928F8F928E8D928E8D938D8C938E8D948E8D948E8C938E8D948E8D958D8C948D8C
948D8B948B89948A8893898692878492868391848190837F90817D8F7F7B8E7D788C7A74
8A78728D7C778E7F7A8F817C8F827E908480918481918582928683928784938885938986
948A87948B88958C89958D8A
968E8B968E8C958E8C958E8C958E8C958E8C958E8D948F8D948E8D948F8E948F8E938F8E
938F8E938F8F938F8F929090929090929090919090919091909092909193909295909497
8F9193908F90908E8E908E8E918E8D928E8D938E8E938F8E928F8E938E8E948D8D948D8C
948C8A948B899489879286849184818F827F8E807C8D7D798C7B768B787389756F88716A
88736C8976708A79738B7B768C7D788D7F7A8E807C8F817D90837F908480918682928784
938885948A87948B88958C89
968E8B958E8C958F8C958E8C958E8D948F8D948F8E948F8E948F8E93908F938F8F93908F
9290909290909190909190919190919090919090928F91928E91938E92948E93968E9499
8D91948D90918E8E8F8E8D8E8F8E8E908E8E928E8F938F8F939090939090958F8F948D8C
948B8A94898893878592848290817E8E7E7B8C7B788B787489756F88726B856D66836860
846C6586706987736C88756F8978728A7A758B7C778C7E798D7F7B8F817D90837F918581
928783938885948A87958C89
968E8B958E8C958F8D958E8D948F8D948F8E948F8E938F8F93908F939090929090929090
9190919190919091929091928F91938F91938E91938D91948C91958C92958B92978B9499
8B91948B8F918C8E8F8C8D8E8D8D8E8E8D8E8F8E8E908E8F918F90929090938F8F938D8D
938B899289879286849183808F7E7C8D7A778B777388736E866F69846B6481665E7F6259
81665E826A62846D6685706986736C88756F8978728A7A758B7C778D7E7A8E807C8F837F
918581928784938986958B88
968E8C958E8C958F8D948F8D948F8E948F8E938F8F93908F929090929090919091919191
9091929091928F91938F91938E92948D92948D92958C92958A9196899196889196879298
889094888E91898D908A8D8E8B8D8E8C8C8E8D8D8E8E8D8E8F8D8E908E8F908D8E918C8B
9089889087858F83818F807D8D7C788A767288726E856E6982696380645D7D5F577C5E54
7E61587F645C806860826B63836E6785716A86736E8876718978738B7B778C7E7A8E817C
90837F918682938885948B88
968E8C958E8C958F8D948F8D948F8E938F8F93908F929090929091919191919192909193
9091938F92948E92948E92958D92958C92968B92968A9297899297869196848F95838D94
858E92868D91878D8F888C8E898C8D8A8B8D8B8B8D8B8B8D8C8B8C8D8B8C8D8A8B8E8989
8E86868D83828C807E8B7D7A8A787588736F856D688269637F645D7C5E5679584E79594F
7A5C527C5F567D625A7F665E806962826C65846F6985736D8775708978738B7C778D7F7A
8E817D908480928784948A87
958E8C958E8C948F8D948F8E938F8E93908F9290909290919191929191929091938F9294
8F92948E92958D93968D93968C93978B93988A93988993988793988591987D8B927F8B91
828C91848C90858C8F868B8E878A8D878B8D888A8C898A8B8A898B8A888A8A86888A8586
8A83838A7F7F897C7A887876867471846F6A826A647F645E7B5E5678594F755247765449
77564C785A507A5D547B60587D645C7F6860816B64836F6885726C8776708979748B7D78
8D807C8F837F928783948A87
958E8C958E8D948F8D948F8E938F8F9290909290919191919191929092938F92948F9295
8E93968D93968C93978C94988B94988A949989949A88949A87959B86949B78888F7E8B91
808B90828C90838B8F848B8D848A8C85898C86898C87898A87888A878688888385878082
867E7E867B7B85787784747282706D806A667E65607B5F59775951745349714B40724E43
73504675544A76584E785B527A5F577C635B7E6760806B64836F6985736D8777718A7A76
8C7E7A8F827E918682948A87
958E8C958F8D948F8E938F8F938F8F9290909191919191929092938F92948F93958E9396
8D93978C94988C94988B94998A959A89959B88959C88969C88979E8392997D8C937E8C91
7F8B90808B8F818A8E828A8D82898B83888B84888A84888A858789858587858184857E80
847A7B83767782737381706E7E6B697C66627A615C785B5575554D714E446E463B6E473B
6F4A3F714E4373524875564D775A52795F567B635B7E6760806B6583706A86746F887873
8B7D788E817D908581938986
958E8C958F8D948F8E93908F9290909290919191929092938F92948F93958E93968D9497
8C94988C94998B959A8A959B89959C88969C87969D87979E84949C8091987E8E957E8D92
7E8C917F8B8F7F8A8D80898B80888A81878A81878A82878A84878A838386838082837B7E
8277798172747F6F707D6B6B7B676578625E765D5874585172524A6E4B416B4338694033
6B44386D483D6F4C4271514773554C765A52785F577B635C7E6861816D6784726C877671
8A7B768D7F7B908481938986
958E8C948F8D94908F93908F9290909191929091939092948F93958E93968D94978C9498
8C95998B959A8A969B89969C88969D87979E86979F8798A180929A7E90977E8E957D8D93
7D8C917E8B907D898D7D888A7E87897E86897F878980868982888A828587828284817D7F
80797B7E72737D6D6E7A6868776362755F5C72595570554E6F4F486C4A406A4338673D30
673C2F6942366B473B6D4B4170504773554D755A527860587B655E7F6A64826F6985756F
8979758C7E7A8F8380938885
958E8C948F8E93908F9390909291919191929092938F92958E93968D94978D94988C959A
8B959B8A969C89969D88979E87979F8597A08498A1798E987C8F987C8F977C8E957D8E94
7D8D937D8C917C898D7B868A7B86887C86887C86887E868880878981888A808586808282
807E7F7D75757A6D6E776666746060715C596E56516D524B6C4D466A493F684238663D31
64382B653C2F6741356A463B6C4B416F514872564E755C5479615A7C6761806D6784726D
8778738B7D798F837F928885
958E8C948F8E93908F9290909191929091938F92948F93958E93978D94988C95998B969B
8A969C89979D88979E87989F8698A08498A18297A1788E98798F977A8F977B8E957C8F95
7C8E957D8D927B8A8E7985887985887984887683857C888A7F888A828B8C82898A818384
8082817D7B7A797373736867705E5D6D59576B544F6A4F49694C4468483F674338643D31
62372A613629633B2E65403568463C6B4C426F5249725850765E577A645D7E6A6482706B
8676718A7C788E827E928884
958E8C948F8E93908F9290919191929092938F92958E93968D94988C95998B969B8B969C
8A979E89989F8898A08699A18599A2849AA4778F9B778E98788E97798F977A8E957B8F96
7C91977D90957B8C8F78878A7583867B898B7A87897C8A8B7E8A8B80898A828B8C838686
838484827F7E7E7978746C6B6B5F5E69565567514E664C47664A4367473F664338633D32
61382B5F34265F362A603A2F63403667473D6B4E456F544C745B5378615A7C6862806E69
85746F897B768D817D928784
958E8D948F8E9390909291919191939092948E93968D94978C94998C959A8B969C8A979D
89989F8999A1889AA2869AA38399A2839AA5708A96748D97768E97788F98798F967A9097
7C92997D92977C90937D8D8F7582847883867985867A85867C87887E86878086877F8181
80807F817C7B827B797D7270716664655655634E4B624A4564484165463E644339623E33
60382B5E33245C33265B35295E3A306342386749406C5048715850755F587A655F7F6C67
83736E887A758D807C918784
958E8D948F8E9390909191929092938F92958E93968D94988C959A8B969B8A979D89989F
8999A1899BA3899CA5879CA67F96A07A939E728B97748D97758E97778E97788F96799198
7C949A7D93987E93967F9294798B8D79888A7987897985877B86887D85877D85857D7F7F
7D7C7C7D77767E77757B706D7769676A5C59604C4A60474461464063463E634339613E33
5F392C5E33265B31235A332559352A5F3D3364453C694D446E544D735C5578635D7D6A65
82716C8778748C807C918783
958E8D948F8F9290909191929092948F93958D93978C94998B959A8A969C89979E8898A0
889AA2899CA58A9FA88DA2AD8199A3738E9A748D99748E98748E98758E98768F97789199
7A939A7A9096788C90798C8F788C8E788A8C798A8C7A8A8B7B8A8C7D898A7D88887D8584
7D807E7B79787A767479706D76696670615D63504D5E47435F454062453E62433A613E34
5E392D5D3427592F21512B1D5631265A392E6041386649416B514A71595276615A7C6863
81706B8677738B7F7B918683
958F8D93908F9291919191938F92948E93968D94988B959A8A969B89969D88979F8799A1
879AA3889CA68BA1AA90A5B0899FA879919C748E99738E98738E97748E98758E97769199
78939A78909775898E75888B75888B76888B77888B78898B79898B7B888A7B86877B8383
7A7F7E797A7876767375716D736B6770645E695953614C485F474161463F61443A603F35
5E3A2E5D36295D34264D271B502D2157352B5D3E3463463E694F476F574F745F587A6761
806F698576728B7E7A908683
958F8D93908F9291919192938F93958E94978C94998B959A89969C88979E8698A08599A1
859AA3859BA6869EA8849CA78098A379929D738E99718C97718D96728E97728E97749098
769199768F9673898F71848972858873868A75878A76878A77898B79888A798586798182
787D7D767977737371706D6A6E67636B605B675853624F4A604A4460474061443C604036
5E3B305E382B5D34264A25194D291E5332275A3B3160433A664C446C544D725D5678655F
7E6D688475718A7D7A908582
958F8D93908F9291919092948F93968D94988B95998A969B88969D86979F8598A08398A2
8299A4819AA57F9AA67D97A279929D748E99708B976F8A956F8A956F8B95708C96718E97
728F98738D95728A907084896F828671848872858974858975868977878A778587778082
757B7C7477777171706E6B696B6562685F5B65585361504B604C4660494260453D5F4137
5F3C325F392D60372947231749251A502E2356372D5D40376449416A524B715B5477635E
7D6C678374708A7D79908582
958F8D9390909291929092948E93968D94988B959A89969C87979E8597A08398A18198A2
7F98A47D98A57A96A37793A0738E9A7089946C88946C86926C87926C88936C8A946D8B94
6E8D956F8C946F89906D848A6C80856E828670858872858973858976868A768487758182
737A7B7276766E6F6F6B6967676361665E5B64585461524D604E485F4A435F463E5F4238
5E3D335F3B2E633A2B4C271A4420154C2A1F53342A5B3E3562473F6850496F595275625C
7C6B6582736F897C788F8582
958F8D9390909292929093958E94978C95998A969B88979D86979F8498A18198A27E98A3
7B97A47897A57592A0728F9C6D88956A86926985916884906884906986906987926A8892
6A89936B89926C88906B848A6A80856B80856D82876F8387718488738588748386727E80
70797A6E75756B6E6E68686664615F625C5961575460534E5F4F495E4B445D463F5C4239
5C3E345E3B2F633B2D583022492316462419513228593C3360453D664E476D575174615B
7B6A6481736E887C788F8581
958F8E9391909292939093958E95988C969A8A979C88979E8598A08298A27F98A37C98A4
7897A57594A3708E9D6C889766829064838F64828E64828E65828D65838E66848F66848F
67858F67858F68848D688289687F86697F856B81866D81866F8387718287728184707C7F
6E77796A7173686C6C636564615F5D5F5A585E56535E534E5D4F495B4A445B463E5A4139
593D3359382E5B372C593225532B1E4D291E513127573A315E433B644D456B564F725F59
79686380726D887B778F8481
958F8E9391919292949094968E95998C969B8A979E8798A08599A28199A37E99A57A98A5
7598A67194A36C8D9C668392617E8C5F7E8C607F8C60808C61808C62808C62818C62818C
63818C63818B638089647E86647D84667E846980866B81866D83877082877080846E7B7E
6B7578676F71656A6B6164635E5E5C5C59575B55525B524E5A4E49594A4457453E564039
553B3354362C533429502D214C25194D2A1E50302655382F5B4139624B4369544E705E58
7867627F716C877A778E8481
958F8E9391919293949095978F969A8D989D8A999F8799A1849AA3819AA57D9AA67899A7
7297A66C92A16589985E7F8E5A7A895A7B895B7B895C7D8A5D7E8A5E7E8A5F7E8A5E7E8A
5F7E895F7C885F7B865F7A83607981637B82667D83697F856C82876E82876F7F836D7A7E
6A7477666E706168695D61615B5C5B59575658545257514D574D4955494454443E523F38
503A324F342B4E32284B2A1F46221647251A4C2D2352362D593F3760494267524C6F5C57
7666617E706C867A768E8480
95908E9492929394959196988F979B8D999E8B9AA1889BA3859BA5819CA77C9CA9779BAA
7094A4668C9C5B8292537889527686557786577987597A885A7C895B7D895C7D895B7C88
5A7B875A79855A77835A76805C767E5F7880627B82667E846A81876D82876D7E836B797D
677376636C6E5F66675B6060585A5A565655555251544F4D534C4851484350443E4E3E38
4C38314A322A482F2744261C432116421F1448291F4F332A563D355D474065514A6D5B55
7565607D6F6B8579758E8380
95908F94929293959692979A90999D8E9AA08C9CA3899DA5859DA8819DAA7D9EAC799EAF
7196A662899A547D8E4871834B71824F7484527686557987577B88597C89597C89587B88
577A8655768254737F55717C57727B5A747C5F7880647C836980866B81866C7E8369787D
667275606B6D5C6466585F6055595952545451504F4F4D4B4F4A474D46424C423D4A3D37
48373145322B432E273E241B3C1F153D1B1143261C4B3028523A335A453E624F496B5954
73645F7C6E6A8479758D8380
95908F95939394969793989B929A9F909CA28D9EA58A9FA8869FAA829FAC7E9FAE7AA0B1
7599AA648A9A517A8C416C80456D7F4A71824E7484527887567A88577B88577B88557985
5276834F73804F707D506E7A526D785670795C767E627B826880866B81876C7E8369787D
6572755F6A6D5B6365565E5F5258594F53534D4F4F4C4B4A4B48464B454149403C473C37
44373042322B3F2D2638231B351B1236170D3E221A462D254E383157423C5F4D47685853
71625E7A6D698478748D8380
96918F969494959798959A9D939CA1929FA58FA0A88CA1AB88A1AD82A1AE7DA1B0799EAE
7498A96087994B778A3A687D406B7E466F814B7283507786567C8A597E8C5A7F8C587D89
5278854C7380496E7B4C6D794E6B76516B755A737B617A826780876B82886C7F8569797E
6573755E6A6D5B6466575F605158594D52524A4D4E474948474644474340463F3B433B36
4136303F322C3D2E2735241D2F191131140B391F17422A234A352F53403A5D4B46665651
6F615D796C688377748C827F
96919097959597989A969C9F969FA395A2A893A4AC8FA5AE8AA4B083A2B07CA1B0789CAC
7699A861879949758936657A3C697D426D804771824E7686547B8A5B818F5F828F638490
5D7F8C5378854D727F4D717D51707A536E785A747C617A826781886C83896D81866B7A7F
6775785D696C5B6567565F604E5759495051474C4D43474743444344413F443F3B423A36
3E36313C312C382C262E211B2917102B120A341D163D282146332D503E39594944635550
6D605C786B688277738C827F
979190989596989A9B999EA199A2A698A5AB97A8B094AAB38FA9B585A5B37399AA7297A8
7094A45F869746738831627838677B3F6B7E4570814B7484517888587F8E5D8290658693
6585915F808C58798453758053727C56717B5B757D617B826881886D848A6F83886E7E82
6D7A7D656F71616A6D5A63654E585B495153454C4E3F4546404242413F3E433E3A413B36
3E37323B322D342B25271D181F120D240F082E1A1337251F41302B4C3C3756474361534F
6B5F5B766A678176738B827F
9892919997979A9C9D9BA0A39CA5A99DAAAF9DAEB59CB1BA98B2BE8BABB9759BAB6A91A2
668D9E5781934371862F607736657A3C6A7D436F814871834D7585547B8A5A818F5E8391
5F82905C7F8D597B8855768254747E57747E5B767F627C846881896D848B70848A708084
6E7B7E6C74756C72726B6E6E5860615357584E525345494A44464643424144403C433C38
3F38333D332E312924221B17180E0A1C090427151032211C3C2D294839355345415E514E
695E5A756A668076738B827F
9893929A98989C9E9F9EA3A6A0A9ADA2AEB4A4B4BBA5BAC2A9C2CC96B3BF83A6B47197A7
668D9E537E91406F842D5F763363783A687B426F814873854C7585507787547C8A577F8D
587F8E567C8A54798752758253737F5775805C7881627D856882896D848B70848B708085
6D7B7E6B75776C73737072716769695F61605959584F50504A4A4A47454346423F453E3A
423A363F36312F28241F1A17140E0A16060120110D2C1D1A372A264337334F43405B504C
675C597369667F75728A817F
9994929C9A9A9EA0A1A1A6A8A4ACB0A7B3B8AABAC0AEC1C9B4CBD4A0BBC68CABB8799DAB
698F9F537F923E6F842C607630617638667A3F6C7E4772844E7989537C8B577E8D59818F
5D83915C818F5A7F8C577B885777835978835D7B84627E8768818A6D848B71858B718288
6D7A7F697377687172676D6E6468686063635A5C5B5254534D4E4D4A484648444246403D
443C383F37322C27241A191714100D100300190D0A2519163227243F34314C413E594E4B
655B587268657E75728A817E
9A94939D9B9BA1A2A3A4A8AAA8AFB3ACB7BCB0BFC5B5C7CFBCD1DAABC3CD96B2BE81A2B0
6C92A25580933F6F842D60772D5F753463773B687B426E7F4A7485517B8A577F8D58818F
5B83925C83915C82905A7F8C597B875A7B855D7D87617F886781896C838A71858B75868B
7481856D777C66707460696C5F65675D6162595B5B5355554F504E4C4A484A4644494240
483F3B3F36322B2724161716110F0D0B02000C04021E15132D24213B322F49403D564D4A
645A587067657D74728A817E
9A95939E9C9CA3A4A5A7ABADACB2B6B0BABFB6C3C9BCCCD3C2D6DEB2C9D39FB9C489A7B5
7397A65983954271852F62792C5E733160743865773E6A7B446F804A74844F7888527B8B
557D8D567E8D577E8D577D8B587C8A5A7B875D7D88617E886580886981886E8288738488
778487767F8273797B686F725F6668596061575A5B5356565051504E4C4A4D49474D4643
4D433F3E37332A27251619190C0E0E0A050406010018111028211F38302E463E3C544C4A
625A576F67647C747189817E
9B9594A09D9DA5A5A6AAADAFAFB5B8B5BEC2BAC7CCC1D0D7C8DAE1B9CDD6A7BFC98FADB9
799BAA5F879947748931647B2B5D732E5D723461743A6577406A7B456E7E4972824D7685
507888527A89537B8A557B89567B89587B885B7C875F7D87627E87667E866A7E856E7F84
727F83737E80747B7D7176776C6F706568685F60605A5B5A57565452504E514C4A504946
4F46413F38352D2A281B1D1D0D1010060606020000130F0E241F1E352E2D443D3C534C4A
6159576F67647C747189817E
9B9694A19E9EA6A6A7ACAFB1B2B8BAB8C1C5BFCACFC5D3DACCDDE4BDD0D8ACC3CC96B2BE
7E9FAE658B9C4C788C36677D2A5C732B5B6F305E713662743C6677416A7A456D7D487080
4B73834D76854F7887517887537987567A87597A875C7B865F7B84627B83657B82697B81
6C7B7F6E797D6F777A6E74766C6F70696B6B6465645E5F5D5B595757545255504D534C48
4E46423F39362F2C2A21201F1113130507080000000E0B0C211D1D332E2D433D3C524B4A
6059576E67647C747189817E
9C9695A29F9EA8A8A8AEB1B2B5BABCBCC3C7C2CDD1CAD7DCD1E1E8C1D3DBB1C6D09CB7C2
85A5B36B91A1527E913B6C812C5E7528586E2D5B6F335F713862733D6676416A7A446D7D
476F7F4A72824C74844E75855077865377855578855879845B78825E788161787F64777E
67777D69767A6A73776A7173686D6F66696A6364645F605F5C5B59595654575350554E4B
4C46423E3A37302E2C222222141616070A0C0103040C0A0B201D1D322E2D433D3C524C4A
605A586E67657C747289817E
9D9795A3A09FAAA9A9B1B2B4B8BCBEBFC6C9C6CFD4CEDADFD6E4EBC6D7DEB5CAD3A2BCC7
8DABB87498A75B849743728732647A28596F2B596D315C6F355F713A62733D667641697A
436C7D466F804871814B73834D74844F758452768354768257758059747E5C747D5F747B
627379647277657074656D71656B6D6368696264646060605D5C5A5C58565B5552574F4C
4D46423F3B38312F2D2424241719190B0F100508090D0D0E22202033302F433F3E524D4C
615A596E68667C747289817F
9D9795A4A0A0ABAAAAB2B4B5BABEC0C2C8CBC9D2D6D1DCE1D9E7EDCADAE1B9CDD6A8C0CB
94B0BD7D9EAD628A9C4B788C39697E2C5D732B596D2F5B6D335E6F3760713A63733D6676
40697A436C7D456E7F4770804A72814C73824F738150737F52727D55717B58717A5A7079
5D7076606F75616D72616B6F61696B6166686163646060605E5D5C5D59575B5653564F4C
4B4542403B3933302F2626251A1B1B0F12130A0C0D161516262424363332454140544F4D
625C5A6F68677C757389817F
9D9795A5A1A0ACABABB4B5B6BCBFC1C4CACCCDD4D8D5DFE3DDE9EECEDDE3BED0D8ADC4CE
9BB6C284A4B26C91A2537F923E6E843162782C5B6F2E5A6E315D6F355F703861723B6374
3D66773F697A426C7C446D7D466F7F486F7E4A707E4D6F7C4E6F7B506E79536E77566D76
596D745B6C725D6B705E696D5F676A5F65675F63645F60605E5E5D5E5A585C5653544E4B
4B45433F3B393432302727271B1D1D1114150A0B0D1B1B1B2A292939363648444356514F
635D5C706A687D76748A827F
9E9796A6A1A0AEACABB6B6B6BEC0C2C7CBCDD0D7DAD9E2E6E2EDF1D3E0E7C4D4DBB3C8D1
A2BBC68CAAB87598A85D869846758936687D2D5D722D5A6E305C6E335D70365F71386172
3A63743C66773E6879406A7B426B7C436C7B466D7B486C79496B774C6A764E6A74516A73
55697257697059696E5B676C5C65695D64665E62635E60605D5D5D5C5958595452514D4A
4844423D3B393231312727281B1D1E1216170F10112020202F2D2D3D3A3A4B4746585352
655F5E716B697E77748A8280
9E9896A6A2A1AFACACB7B7B7C0C1C2C9CCCED2D8DBDDE4E7E7F0F4D9E5EBC9D9DFB9CCD5
A8C0CA94B0BD7D9EAD678D9F507C903E6F843061772D5B702F5C6F315D70345E70366072
3862733964753B66773D68793F697A4069794169784368764467744666734966724C6771
50666F53666E55666C58656A5A64685B63665D61635D60605C5D5C5A58575653514E4B4A
4643423D3B393332312828281D1F1F1517181B1B1C272627343232413E3E4E4A495B5655
676160736C6B7F78758A8380
9E9896A7A2A1AFACACB8B7B7C1C2C3CBCDCFD5D9DBDFE6E8EAF3F6E0EBF0D0DEE4C0D2DA
B1C6CF9DB7C287A6B47195A55C859748778B37687E2F5E732E5C70305D71325E70345F72
3560733762743763753965763B67783B66773C65763D65743F637141627044636F47636E
4B636D4E636C51636A5463695763675962655C61635D60615C5C5C5857575351504B4A49
4342413C3B3A3232322728291C1F201315162121222D2C2C3A3837464342524E4D5E5957
696362756E6C8079768B8381
9E9896A7A2A1B0ACACB9B7B7C2C2C2CCCECFD6DADBE1E6E9EDF4F7E7EFF3D8E4EAC8D8DF
B8CCD5A7BEC892AEBA7D9DAC6A8FA057819343728635657A305F74305E72315D71325E72
335F7234607335617435627437647637647637627338617139606F3C5F6D3E5F6C42606C
46606B4A61694E60685160675461665761655A60625C60605A5C5C5757565151504A4A49
4242413A3A3A31323227292A1F2222191A1A2727273432323F3D3C4B4746565250615C5A
6C666476706E817A788C8481
9F9896A7A2A0B0ACABB9B7B6C2C2C2CCCDCED7D9DAE2E6E8F0F5F7EFF6F9E1EAEFD1DFE5
C1D2DAB2C6CF9EB6C189A6B37799A8658B9C547E9142708438687C326277315F73325F73
325E72315F73315F73326073346274336274315F71315D6E335C6C365C6B395C6A3D5C69
425E69465E684A5F674E5F66536066566165585F635B5E605A5B5C5656565150504A4A49
4343423B3B3B323333272A2B222425252525302F2E3A3938454242504C4B5A5654645F5D
6E6867787270827B798C8482
9F9895A7A2A0B0ACABB9B6B6C2C1C1CCCCCDD7D8D9E2E5E6EEF2F4F5FBFDEAF1F4DAE5EA
CAD8DFBBCDD5A9BFC994AFBB85A2AF7496A5668B9C557E904874873E6D8138667A366477
336175305F73305E72315F733261743261742F5E712D5B6E2E5A6A315969345A69395B68
3D5C68415C66465D664C5E66515F665561655860635A5E60585B5B5556565151504A4A4A
4444443C3D3D3435352B2D2E2324242E2E2D383636413F3E4B48475551505E5958686261
716B697A7472847C7A8D8582
9E9795A7A19FB0ABAAB9B5B4C2C0BFCCCBCBD6D6D7E1E3E3ECEFF0F8FCFDF3F8FBE3ECEF
D5E0E5C6D4DBB5C7CFA0B8C291ABB783A0AD7596A4688B9B5B8192507A8B497385436E80
3E6A7D396679356377356276366376346276326073305D702E5B6C2F596A325A69375B69
3B5C68405D67445C664A5E665060665561655760635A5E60585B5C5657575252524C4C4B
4645453F3F3F3838383031312D2C2C373635403E3D494645514D4C5A5554625D5C6B6564
746D6C7C7573857E7B8D8683
9E9795A7A19FAFAAA9B8B4B3C1BEBECAC9C9D4D4D4DFE0E0EAECECF7F9F9FBFEFFEDF2F5
DEE6EACFDBE0C1CFD6AFC1CA9EB5BE91AAB583A0AC7695A36A8C9B6084945A7E8E537989
4C7586467081426D7F3E697B3E697B3C6779396577366274345F70335C6D355C6C395D6B
3D5D6A415E69465E684B5F685161675662665860635A5F61595B5D5758585353534E4D4D
4847464342413E3C3B3636353B3938413F3E484544504C4B5753525F5A596761606E6967
76706E7E7775867F7C8E8684
9E9794A6A09EAEA9A7B7B3B1C0BCBBC9C7C6D2D1D1DDDCDCE7E8E8F3F4F4FDFFFFF7FAFB
E7EDF0D9E1E5CAD6DBBAC9D0ACBEC69DB3BC92AAB585A0AC7A98A471919E698A98638492
5D7F8E567A895378874C72824A7080476E7E456C7C4268783F66763E6473406371426370
45626E48636D4C636C52646B55646A5A64685B63655C61625B5D5E595959555454504F4E
4A494847454443403E423F3E4543414A4746504C4B5652515D5857645F5D6B6564726C6A
79737180797788807E8F8784
9E9694A59F9DADA8A6B6B1AFBEBAB9C7C4C3D0CECDDAD8D8E4E3E3EFEFEEFAFBFAFDFEFF
F0F3F4E2E8EAD4DDE1C5D1D6B8C7CDACBDC4A2B5BD94ABB488A1AC819AA578939F718E99
6B899563839060808D5B7B895879875476845173814F707E4C6D7B4A6B784B6A774E6A75
5069745269725569705A696F5C686D5E676B5F65676063645E5F605C5B5B58565553514F
4E4B4A4B47454A46444C48464F4B49534F4D5853525D5857635E5C6963626F6967756F6D
7C7573827B7989817F8F8785
9D9693A59E9CACA6A4B4AFADBCB8B6C4C1BFCDCAC9D6D4D3E0DEDDEAE9E8F6F5F4FFFFFF
F8F9F9EBEEEFDFE4E6D2D9DCC4CED3B8C5CBAFBEC4A4B5BC98ACB490A5AD879DA68098A1
7A929C738D976E899369859065818D617D8A5F7A875C788459758058737E59717C5B717B
5D71795E7078617076646F74656E71646B6E64686A646666626262605E5D5B5857555250
514C4A504B49524D4B54504E5752515A56545F5A58635E5C6863616E6866736D6B797270
7E7775847D7B8A8280908885
9D9593A49D9BABA5A2B2ACABB9B5B3C1BDBBC9C6C4D2CFCDDBD8D7E4E3E1EFEEECFCFAF9
FFFEFDF6F5F5E9EBEBDCE0E2D0D6D9C5CED1BDC7CBB3BFC5A9B7BCA1B0B696A7AE8FA1A8
889CA383979F7D929A788E96758A937086906C828C6A808A677C86667B84667981697981
69787F6B777E6E777C6F767A6F74766D71726C6D6E6B6A6A686665646160615C5A5B5654
544E4B58524F5A54525C57555E5957625C5A65605E6963626D6866726C6A77706E7C7573
817A78867F7C8B8481918986
9C9592A39C99A9A3A1B0AAA8B7B1AFBEB9B7C5C1BFCDC9C8D5D2D0DEDBDAE7E5E3F1EFED
FCF9F7FEFCFAF4F2F1E7E7E7DADDDED0D5D6C8CED0C1C8CBB8C0C4B1BABDA7B2B69FABB0
98A5AA93A0A68D9CA188979D8393997F8F967A8B9277878F74848B728188717F86747F85
7680857980847A7F827A7C7F797A7B777777747271706E6D6E6A69696563635E5D5F5957
5E58555F5957615B59635D5B65605D6862606B65636F6866726C6A76706E7B74727F7876
837C7A88807E8D8582918987
9C9491A29A98A7A19EADA7A5B4AEACBAB5B3C1BCBAC8C3C2CFCBC9D7D3D2DFDCDAE8E4E2
F0EDEBFAF6F4FCF8F6F1EEEDE4E3E3D9DADAD0D3D3CCCECFC5C8C9BEC2C3B7BBBDADB4B6
A7AEB1A0A8AC9BA4A796A0A3919B9F8C979B889398848F94818C917E888D7C85897C8487
7E83878386888586878382838280807F7C7B7A767575716F726D6B6F696769626067605D
67605D67615E6862606A64616C66636E6866716A68746D6B77706E7A74717E7775827B78
867E7C8A82808E8683928A87
9B9391A09996A69E9CABA4A2B0AAA8B6B0AEBCB7B5C2BDBBC9C4C2D0CBC9D7D2D0DEDAD8
E6E1DFEDE9E7F6F2EFF7F2F0EDE9E6E2DFDED7D6D6D2D1D1CDCDCDC9C8C8C1C2C2BBBBBC
B6B7B7AFB1B3AAACADA4A8A99FA3A5999EA1959A9D9096998E93978A8F92868A8D84898A
85888A888889878687868484868281847F7D7F7A787B757376706D746D696F67656E6764
6E67646E68656F6866706A67726B69746D6B766F6D7972707B74727E7775817A78857D7B
88807E8B84818F8784928A88
9A92909F9795A49C9AA8A19FADA6A4B2ACAAB7B1AFBCB7B5C2BDBBC8C3C1CEC9C7D4CFCD
DBD6D3E1DCDAE8E3E1F1ECE9F1EBE8E8E3E0DDD9D7D6D2D1D2CECDCFCCCAC9C6C5C1BFBE
BDBABAB9B7B6B6B3B3B1AFAFABAAAAA6A5A6A1A1A29C9D9E999A9B9596979393948E8E8F
908E8F928E8E918C8C908A898E87858B848187807D8079777C74717A726E776F6C766E6B
756E6B756E6B766F6C77706D78716E7972707B74727D7674807876827B78857D7B87807D
8A82808D8583908885938B88
9A928F9E9693A19A97A59E9CA9A2A0AEA7A5B2ABA9B6B0AEBBB5B3C0BAB8C5BFBDCAC5C2
D0CAC8D5D0CDDBD5D3E2DBD9E9E3DFEBE3DFE4DDDAD9D4D1D2CDCACEC9C7CCC7C5C8C3C1
C4BFBDC1BBB9BCB6B5B9B4B2B6B1AFB2ADABABA7A5A5A2A2A29E9E9D9B9B9C9898969393
979392979190978F8E968D8B938A888F86848D8380837B788179757F77747D76727C7472
7C74717B74717C74727C75737D76747F7775807976827A78847C7A867E7C88807E8A8280
8C84828F8784918986948B89
99918E9C94919F9795A29B98A69E9CA9A2A0ADA6A3B0A9A7B4ADABB8B1AFBCB5B3C0BAB7
C4BEBCC9C2C0CEC7C4D3CCC9D7D0CDDCD5D1E0D8D4DED6D2D5CDC9CFC7C3C9C2C0C7C0BD
C4BDBAC3BBB8C0B7B4BBB4B0B7B0ADB5AEABB0A9A6ACA5A3A6A09EA29D9C9F9A999D9896
9B96949B94929B939099908D978E8B92898690878489807D867E7B857C79837B78827A77
817A77817A77817A77827A78837B79847C7A857D7B867E7C87807D89817F8B83808C8582
8E8684908885928A87948C89
98908D9B92909D95929F9895A29A98A49D9AA7A09DAAA3A0ADA5A3AFA8A6B2ACA9B6AFAC
B9B2AFBCB5B3C0B9B6C3BCB9C7BFBCCAC2BFCEC5C1D3CAC5D1C8C3CFC5C0C9C0BCC2BAB7
C1B8B5C1B7B5BEB4B1BBB1AEB7AEABB4ACA9B1A9A6AFA6A3ABA3A0A8A09EA49D9AA29B99
9F99979D97949C959299918E9B928F988F8C9289858E85828B83808A817E88807D877F7D
877F7C877F7C877F7C877F7D88807D88817E89817F8A82808B83818C84828E86838F8784
908886928987938B88958C8A
988F8D99918E9B92909C94929E9693A09895A19A97A39C99A59E9BA7A09DA9A29FABA4A1
ADA6A3B0A8A5B2AAA8B4ADAAB7AFACB9B1ADBBB3AFBDB4B0BDB4B0BEB4B0BFB6B1BBB2AE
B8B0ABB8B0ACB8AFACB8AEAAB5ABA8AFA7A4ACA4A2ABA29FA8A09DA79E9CA49C99A19A97
9F98959D9592A199959C949099908D978E8B948B889189868F87848E86838D85828D8482
8C84818C84818C84818C84828D85828D85828E85838E86848F8784908885908886918987
928A87938B88948C89958D8A
978E8C988F8D98908D99918E9A928F9B93909C94919D95929E96939F9794A09895A19996
A29A97A39B98A49C99A59D9AA69E9BA79F9CA8A09DA9A19DAAA19DAAA19DAAA19DA9A09C
A89F9CA8A09CA89F9CA9A09CABA19DA9A09CA89F9CA79E9BA69D99A59C99A49B98A39B98
A198959B93909A928F99918E988F8C968E8B958C8A948B88938A88928A87928987918986
918986918986918986918986918986928987928A87928A87928A88938B88938B88948B89
948C89958C8A958D8A968D8A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.267442 0.732558 0.488926 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(225) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
908B8A908B8A908B8A908C8A908C8A908C8B908C8B908C8B908C8B908C8B908D8C908D8C
908D8C908D8C908D8C908D8D908D8D908E8D908E8D908E8E908E8E908F8F909090909293
8F8F8F8F8E8D8F8D8C908E8D908D8C908D8C908E8C908E8D918E8D918E8D918E8D918E8C
918E8C918C8B918C8A908A898F89878F88868F88868E87858E85838D84818C83808B817D
897D798B817E8C83818C85828D86838D87848D87848E87858E88868E88868E89878F8987
8F8A888F8A888F8A898F8B89
908B8A908C8A908C8A908C8B908D8B908D8B908D8C908D8C908E8D908E8D908E8D908E8E
908F8E908F8F908F8F9090909090909090909091919091929092928F92948F9496909698
8F93948F91918F9090909090908F8F91908F91909092908F91908F92908F93908F928F8E
928F8D928D8B928C8A9089878F88858E86838D84828D827F8C807D8A7D79887A76877771
84756F877A75897D798A7F7B8A807D8B827F8B83808C84818C85828D85838D86848E8785
8E88868E89878F8A888F8A89
908C8A908C8B908C8B908D8B908D8C908D8D908E8D908F8E908F8E908F8F90908F909090
9091919091919092929092939092939093949093959094958F95978F95988F979A8F999D
8E95988F94958F929390929290929291929292929393939292939293939294929194908F
938F8E938D8C928C8A9189868F86838E83808C817D8B7E7A897A7687777285736D826E67
826F6984736E867771877975887B77897D79897F7B8A807D8B817E8B83808C84818D8583
8D86848E88858E89878F8A88
908C8A908D8B908D8C908D8C908E8D908E8E908F8F909090919090919191919192919292
9193939193949194959194969195969095979096989097998F979A8F989C8F999E8F9BA0
8E989B8E96988F94968F9494909394919394929494949595939595949594959494949291
94908E938D8C938B899288859084818D807D8B7D7989797587757085716B826C657E665D
806A63826E6783716B84746F867772877974877B77887C79897E7B8A807D8B827F8C8380
8C85828D86848E88868F8A88
908C8B908D8C908E8D908E8D908F8E908F8F919090919191919292919293919394919495
91949691959791969891979991979A91989B90999C90999D8F9A9E8F9A9F8E9BA08E9DA3
8D9A9D8E989A8E96988F9596909596919596929595939696949696949696959595949392
94908F948E8C938B8892878590827F8D7E7A8B7A7688757085706A826B647F655D7C6057
7E655D7F6962816C66826F6983726D857570867772877975887B77897D7A8A7F7C8B817E
8C83818D85838E87858F8987
908C8B908D8C908E8D908F8E908F8F919090919191919292919394919495919596919697
91969891979991989A91999C919A9D919B9E919B9F909CA08F9CA18E9DA28D9DA28C9DA4
8C9A9F8D999C8E979A8F97988F9697909697919696929696939696949696949595949493
94918F948E8B938A879287838F817E8C7B778A767286726C836C6580665E7C5F567A5D53
7C61587D645C7F6860806B64816E6883716B84736E857671867874877B77887D798A807C
8B827F8C84818D86848E8987
908C8B908D8C908E8D908F8F919090919191919293919394919495919597929698929799
92989B92999C929A9D929B9F929CA0929DA1919EA2919FA4909FA58E9FA58C9EA58A9BA2
8B9A9F8C999D8D989B8E98998F9798909798919797929797929696939696939595949392
93908E938C8A9288869184818F7F7B8C797588736E856E688167607D605879594F79594F
7A5D537B60577D635B7E675F7F6A63816D6782706A83736E847570867874877B77897E7A
8A807D8B83808D86838E8886
908C8B908D8D908F8E91908F91919191929291939491949592969792979892989A92999B
929A9D929B9E929DA0929EA2929FA392A0A492A1A692A2A791A3A990A3AA879CA3879AA1
8A9A9F8B9A9E8D999C8E999A8F9899909899909798919797929797939696939494939291
938F8E928B8991868490827F8D7D798A777287716B836A637F635B7B5C5377544977564B
78594F795C537B5F567C625A7D665E7F6962806C6681706A83736D847671867975887C78
897F7C8B827F8C85828E8886
908C8B908E8D908F8F91909091919291939391949592969792979992989A929A9C939B9E
939C9F939DA1939FA393A0A493A1A693A3A893A4AA93A5AB93A7AD92A7AE8198A0869AA1
899B9F8B9B9F8C9A9D8D9A9C8E999A8F989A909899919898929898929696939394929090
928D8B9188879084828E807D8B7A7689746F856E688167607D5F5779584E745044755247
76544A77584E785B527A5E567B625A7D655E7E6962806C6681706A83736E857772867A76
887D7A8A817E8C84828E8886
908D8B908E8D91908F91919191929291949492959692979892989A939A9C939B9E939DA0
939EA293A0A493A1A693A2A794A4A994A5AB94A7AD94A8AF95ABB28CA3AB849BA3879CA2
899CA08B9CA08C9B9E8D9A9D8E9A9B8F999A90999A91999A929999929797939394928F8F
918A8A9086858F81808D7D7A89777487716C836B6580645D7C5D5477554B734D41734D41
74504575534876574D785A51795E557B625A7C655E7E6962806D6782716B837570857874
877C7889807D8B83818E8785
908D8C908F8E91909091929291939392959692969892989A939A9C939B9E939DA0949EA2
94A0A494A2A694A3A894A5AA94A6AC94A8AF94AAB195ACB38FA7AF88A1A9889FA6889EA4
8A9EA28B9DA18C9C9F8D9B9D8E9A9C8F9A9B909A9B919A9B929B9B929797939394928E8E
9189898F83838E7F7E8B7A78887571846E6A8168627E625A7B5B52765449734C4070483B
714B3F734E4374524775564C775A51785E557A625A7C665F7E6A64806E6982726D847772
877A76897F7B8B83808D8785
908D8C908F8E91919191929292949592959792979993999B939B9E939DA0949EA294A0A5
94A2A795A4A995A5AB95A7AD95A9B095AAB295ACB493ACB589A3AC89A2AA89A1A88AA0A5
8B9FA48C9FA38C9DA08D9C9D8D9B9C8E9B9B8F9B9B909B9B929C9C939999939595928F8F
918B8A8F83838D7E7D8A787686726F826C687E655F7B6058795A51755349734C416F4639
6F4538704A3D724E4273524774564C765A51785E567A635B7C67617E6C6681706B837570
867975887E7A8B827F8D8784
908D8C908F8F91919191939392959692969893989A939A9D939C9F949EA294A0A495A2A7
95A4A995A6AC95A8AE96AAB095ABB395ADB595AFB887A4AD88A3AC89A3AA89A2A98AA2A7
8CA2A68DA1A58D9FA18C9C9E8D9B9C8E9B9C8E9C9B8F9A9B929B9A939A9A929695929291
928F8E8F86858D7E7D897775846F6D806A667C635D795E56775850755349724C4170473A
6D42346E45386F493D704D4272514774564D765B52785F587A645D7D69637F6E6982736E
857874877D798A817E8D8684
908D8C918F8F91919291939492959792979993999C939B9E949EA194A0A495A2A695A4A9
96A6AC96A8AE96AAB196ACB396AEB696B0B992AEB885A2AC87A3AC88A3AB89A2A98BA3A9
8DA4A98EA4A78EA1A38C9C9D8D9B9C8E9B9C8A98988E9B9B919999939A9A949998949493
949290918A888E8381877876826E6C7D67657A615B775B5476574F745349724D4270473B
6C41346C40326D44376E483D6F4D4271524873574E765C5478615A7B67607E6C6681716C
847672877B788A817E8D8684
908D8C91908F91929292949592969893989A939A9D949DA0949FA395A1A695A4A996A6AB
96A8AE97ABB197ADB497AFB697B0B998B3BD87A6B184A2AD86A3AC89A4AC89A3A98CA5AB
8EA7AC90A7AA8FA3A58E9F9F8998998D9B9C8B98988E9A9A909A9A929999959B9B959594
969391958E8B928986887C7A7F6F6C7B6562775F5A75595374564E745349724E4370483C
6D43356B3E2F6A40336A44376C483D6E4E4470534A735950765E5779645D7C6A647F6F6A
837570867A7789807D8C8683
908E8D91909091939392959692979993999C939C9E949EA194A0A495A3A896A5AB96A8AE
97AAB198ADB499B0B799B1BA97B2BB96B3BD80A0AD83A2AC86A3AC88A5AC8AA4AB8CA6AC
8FA9AE91A8AC90A5A791A2A28795968A96978C97988E979790999A929999949998949391
95918F958D8A958B888F817D847571786662745D5872575173544C735249734F44704A3D
6E43366B3E2F693E30673F326743386A493F6D4F4671554D745B5477625B7B68617E6E68
82736F857976897F7C8C8583
908E8D91909091939392959693989A939A9D949DA0949FA395A2A695A4A996A7AD97A9B0
98ACB399B0B79BB3BB9DB6BF95B1BA8CABB680A0AC83A2AC86A4AD88A4AC8AA4AB8CA7AD
90AAAF91A7AB90A5A790A2A38A9B9C8B999A8D999A8E9898909A9A939999949998939391
94908E9289879289858F817C8A79757D6B67725B5771555071534B735349734F44714A3E
6E44376C3F30683C2D663D2E633D3267453A6A4B426E5249725951755F5879655F7D6C66
81726D847874887F7B8C8582
908E8D91919092939492969793999B939B9E949DA194A0A495A3A896A5AB96A8AF97ABB2
98AEB69AB2BA9DB7BFA2BCC694B1BB82A3AF82A2AE84A3AD86A4AD88A4AC89A4AC8CA7AD
8FA9AE8FA5AA8C9FA28C9EA08C9D9E8C9C9D8E9B9C8F9C9C919D9D939C9C949A99949795
93918F928B889088838E817C8A7974826F6A745E596F544F70534B73534A735045714B3F
6E45386C4032693C2D5F3628603A2E63403567483E6B4F466F564E745D5578635D7C6A64
80716C847773887E7B8C8582
908E8D919191929494939798939A9C949C9F949FA295A1A695A4A996A7AD96A9B097ACB4
98AFB89AB3BC9DB8C1A0BBC695B2BC86A5B084A4AE85A4AD86A4AC88A4AC89A4AC8BA7AD
8EA8AE8EA5AA8A9DA08A9C9E8B9B9D8C9C9D8E9B9C8F9C9D919D9D939C9C939A99949695
92928F918D898D87828B807B87797482706A79645E72585371544C73534A735146724C40
6F47396E42346D40305A31235C3529603D3264443A694C436D534B725A5376615B7A6863
7E6F6B837672877D7A8B8482
908E8D919191929495939799949A9D949DA095A0A495A3A895A5AB96A8AF96ABB296ADB6
97B0B998B3BD99B6C096B4BF91AFB98AA8B386A4AE85A3AD86A3AB87A4AC88A4AC8AA6AD
8DA7AD8DA5AA8A9EA2899A9C8A999B8B9B9C8D9B9D8F9C9D919D9E939D9D939A99939594
92918F908C888C8681887E798476717F6E687A655F755C5673574F73554C745247724D41
70483B6F44356F4131572F215832265D392E62413766493F6B5048705850745F59796761
7D6E69827571867D798B8481
918E8E91929292959693989A949B9E959EA295A1A695A4A996A7AD96A9B096ACB496AEB7
96B1BA95B3BD94B3BF92B0BB8EABB689A6B085A3AE84A1AB85A1AA86A2AA87A3AB89A4AC
8BA6AC8BA4AA8BA0A4899A9D89989A8B999B8D9B9D8F9B9C909C9D939D9D939A9A939695
91908E8F8B888A8480867D788275707E6E687A665F755E56745A5174574D745348724E42
71493C704537724333552D20542E2259362A5F3E3364463C694E456E564E735E5778655F
7C6D68817470867C798B8481
918F8E92929293969794999B959C9F959FA396A3A796A5AB96A8AF96ABB296ADB695AFB9
95B1BC94B3BF91B1BD8FAEBA8BA8B387A3AD83A1AB839FA9849FA885A0A986A2A987A3AA
89A4AB8AA3A98AA0A5889B9E8897998A999A8C9B9C8E9B9D909C9D939D9D939A9A939695
90908E8E8B8889837F847B7780736F7C6D67796660766058765C5475584F745449724F43
714A3D714638744535593123502A1D5632265C3A3062433A674C436C544C715C5576645E
7B6C6780746F857B788A8381
918F8E929393939697949A9C959DA096A1A596A4A997A7AD97AAB197ADB496AFB895B1BB
94B2BE92B3C090AFBB8DACB787A3AE83A0AA829FA9829DA7839EA7849FA785A0A886A1A8
87A2A988A1A889A0A5889B9F87979A89989A8B9A9B8E9A9C909C9D929D9D939A9A929594
8F8F8D8C898788827F837A757E726D7A6C6678666077625A765E5574595073554A714F44
6F4A3E6F4638714536633829542B1E512C2059382D6041376549416A524A705A5375625C
7A6B6580736F857B788A8381
918F8E929393949798959B9D969FA297A2A697A6AB98A9AF98ACB397AEB796B1BA95B3BD
93B4C091B3C08EAEBA89A6B3829EAA7F9DA8809CA6809CA5819CA5829DA6839EA7849FA7
859FA7869FA6879EA3869A9F86979B88989A8A999B8D999B909C9C929C9D939A99919493
8E8E8C8A878586807D8078747C706B796B6577666077635B765F56745A5172554A704F44
6D4A3E6B4437694134643A2B5B3022542E2159362B5E3F3564483F6950486E595274615B
7969647F726E847A778A8380
918F8F939494959899969C9E97A0A398A4A899A7AD99ABB199AEB598B1B997B3BD96B5C0
93B7C390B4C08BACB984A1AD7F9AA67C9AA57D9AA57E9BA47F9BA4819CA5829DA5829DA5
839DA5849CA3849BA185989D85969A87979A8A999B8C9A9B8F9C9D939C9D939999919393
8D8D8C888684847F7C7F77737B706B796B6577676077635C755F57735A5170554B6E4F44
6B493D674236643F325E3628572C1E56302359362A5D3D3362463D674E466D575072605A
7868637E716D847A768A8280
92908F94949595999A979DA098A2A59AA6AA9AA9AF9BADB49BB0B89AB3BC99B6C097B8C3
93B8C48FB3BF88A9B57F9CA97997A37997A27A98A27C99A37E9AA47F9BA4809CA4819CA4
819BA38299A181989E82959A82949885959888979A8B999B8F9C9D929C9D939999909392
8D8C8B888582827D7A7D76727A706B786B6577676176635C745F57715B516E554B6C4E44
68483D644135613D315B3426552B1D542C205733285B3B3160443B654C456B554E715E58
7767627D706C837976898280
92908F949595969A9B989FA19AA3A79BA8AC9CACB19DB0B69DB3BB9CB6BF9BB9C49ABCC8
95B8C48DAFBC81A3B07697A47493A07594A07896A17A97A27C99A37E9BA4809BA47F9BA3
809AA17F979F7F959C7F93988092968393978696988A989A8E9C9D929C9D939998909392
8C8B8A878381827C797D76727A706B776B6676676174635C735F57705A516D554B6A4E44
66473D6141355D3D31583125532C1E50271B54302558392F5E4139634A4369544D6F5D57
7566617C6F6B82787589827F
929090959696989B9C9AA0A39CA5A99EAAAE9FAEB4A0B2B9A0B6BE9FB9C39EBDC89EC0CD
9ABAC68CACB97C9EAC6D909F6E8F9D71919E7494A07896A17B99A37D9AA47F9BA37F9BA2
7E99A17D969D7C91997B8F957D8F9480909484939689979A8E9B9C929C9D939998909292
8C8B89868380827C797D76727A706B776B6675666172625B715E566E59506B544A684E44
64483D5F41365B3C325431254F2B1E4C2317502D2255362C5B3F3661484167524B6D5B56
7465607B6E6A82787589817F
939190969797999C9E9CA2A49EA8ABA1ADB1A2B1B7A3B6BCA3B9C1A2BDC6A2C0CBA1C3CF
9FBCC88DACB8799BA9658B9B688B9A6D8F9C71929E7695A17B99A37D9AA37F9BA47E9AA1
7C989F79949C778F97778C93798B907C8C908291948896998E9B9C929C9D939999909392
8D8B89868381827C797E777379706C766B6574666171615A6F5D566D58506A534A664E44
62483D5E42375A3D3250312549261A471F134C291F523329573D345E463F6450496B5A54
72635F796D6981777488817F
9391919798989B9E9F9EA4A6A1AAADA4B0B4A6B5BAA7BAC0A7BDC5A6C0C9A4C3CEA3C2CD
A0BDC88CAAB77497A65E8697638898698C9A6E8F9C7494A07B99A37F9CA5829EA6829CA4
7D98A076939B738D95748B9275888E77878C808E918795978E9B9D939D9E949A9A929493
8E8D8A888481847E7A8078747A716D766B667365606E605A6D5C556B585069534A654E44
60483D5D4238593E334E3126442319411C1047261C4E3027543A325B443D624E48695853
71625E786C6980777488817F
9492919899999D9FA1A1A6A8A4ADB0A8B3B7ABB9BEACBEC5ACC2CAAAC4CDA5C4CFA3C1CB
A2BCC68BA9B57094A45982945F8596658A986B8D9B71929E7898A2809DA6849FA789A1A8
839CA379949D738D95728C9374898F77878C7F8D908794978E9B9D949E9F969B9B949594
92908D888381867F7C827A757B726E746A6571645F6C5E596A5A5469574F68534A644D44
60483E5D4338573D32492E243E21173C190F43231A492D2550373057423B5F4C46675651
6F615D776B687F767387817E
9592919A999A9FA1A2A3A8AAA8B0B3ACB7BBB0BEC3B3C4CAB4C9D0B1CAD3A1BFCBA0BCC7
9DB7C289A7B36C92A2547E915A8293618796688C996E909C75949F7C9AA4819DA688A0A8
859EA57F98A0789098738C9374898F79898E7F8D918794978F9B9D959E9F989D9D979896
9694908E87848D8480887E797B736F756B66716560695D5868595367554E685249654E44
61493F5E4439553C31432B22361D1436160D3E2018442A234C352E533F395C4A44645550
6D5F5B756A677E757287807E
9593929B9B9BA1A3A4A6ABADACB3B6B1BCBFB7C4C8BCCCD1C1D4DAB9D0D8A4C0CB9AB6C2
95B1BC82A1AF688F9F507B8E5780915E8594668B996C8D9A71919C7896A07D9BA4819DA5
819BA47D979F79929A758C94768B917A8B90808E928895988F9B9E959E9F989E9E989997
969490938C8794898493867F8077727A6E697669646B5F5A695B5568564F69534A674F46
634B4161473B533A303F29212F1911301209371D153F272047312B4F3C3758484361534E
6A5E5A7469667D757286807E
9694939C9C9CA3A5A6A9AEAFB0B7B9B7C0C3BECACEC6D4D9D0E1E6BFD3DBAEC7D09DB8C3
92AEB97B9DAB648C9C4D798D547D8F5B82926489966B8D9A70909B74929D7996A07C99A2
7C98A17A949D779199758D94758A907B8C92819094889699909B9D969D9F999E9E999998
969391938D88938A84948780897D7782756F7B6D6771635D6D5E576C59516B564D6A5148
674D4364493E50392F3B28202B1911290E0631181139231D422E294B3A355545415E514D
685D597268657C7471867F7D
9794939E9D9DA5A7A7ACB0B1B4BABCBBC4C7C4CFD2CDDADED8E8ECC7D9DFB5CAD2A2BBC5
90ADB9789BAA60899A4C798C507B8C587F8F608592688B986F909C74939E79959F7A97A1
7C98A17B959F79939C788F97788C937C8F9482939789979A909B9D969D9E999E9E9B9B9A
979392928C899188838E837E897D778477717E6F6975676072615A705C546E584F6C544A
6C5045664A3F4E382F35251F2B1A13240B052A140E321F193C2B2646373251433F5B4F4B
665B587067647B7371857F7D
9795949F9E9EA7A8A9AFB2B3B7BCBEC0C7CAC9D3D6D3DFE3DEECF0CFDFE4BBCED6A6BEC8
91AEBA789BA95F88994C798C4D7889547C8B5C818E6386936B8B9771919B76939D77959E
7A96A07B959F7B959D7A929A7B90977E919784959989989B8F9A9C959C9D999E9D9D9D9C
9C9896968F8C9188858A817D867B768376717F706A79696376645C735F56715A5170574D
71544965493E4C372E31241E2A1A14210B051E0B072A19153627234134304D413D584D4A
645A576F66647A7370857F7D
989594A09F9FA9AAAAB1B4B5BABFC1C3CACCCDD6D9D8E2E5E3EFF3D4E3E8C1D2D9ABC1CB
94B0BC799CAA61899A4D7A8D4B7688517888587D8B5F818E6686926C8A95708E9873909B
76929C78939C79939D7B939C7D939B80939985969B89989B8E999B929A9B969B9A9B9B99
9E9A979C9491998E8A8F8581887D7883767180706A7B6B6478665E756057745D53755A50
75574C63483E4B362E3326212619141F0D081405022315113023203D312E493E3B554C49
6159566D6563797270847F7D
989695A1A0A0AAABABB3B6B7BDC1C2C7CCCED1D8DBDCE5E8E7F1F5D8E5EAC7D7DDAFC5CD
98B3BE7E9FAD658C9C4F7C8E4A75874E7585557A885C7D8A62828D6785906C8993708C96
738F9976909A78929C7A939B7D949B80959B84969B89989B8C989A909899949897979896
9A96949A94909A908B968A8590837D897B7585746D7F6E677D696079645A796056795D52
77594D63483F4C3830372823241915180B080E03001C110E2A201D382E2C463C3A534A48
6058556C6563787270847E7D
999695A2A1A0ACACACB5B7B8BFC3C4C9CED0D4DBDDDFE7EAEAF4F7DBE6EBCAD9DFB4C8D0
9CB6C083A2AF6A8F9F547F904974864B7383527685587A875F7E8A64828D6986906D8993
718C96748F9877919A79929B7D939B80959B84969B88979B8B96998E9697919695949593
97939197918E978D8995898492847E8E7E78897870847169816C637F685E7E63597C5F54
76584C62483F4C3831392924241A16140B09090100150C0A251D1B352C2A433B39514947
5E57556B6462777170837E7D
999695A3A2A1ADADADB7B8B9C1C4C5CCD0D2D6DCDEE2E9EBEDF6F9DDE8ECCDDBE1B8CCD3
A2BAC488A7B37094A35A83944B76884971814F74825678845C7B87627F8966838E6B8691
6F8993728D97758F9979919A7C939B7F949B83959B8696998995978B94958E9393919291
94918F948F8B948B8793878290837D8E7E778B797188746B846E65826A6081665C7F6156
73564B5E473E4B3831382924241A17110C0A0702010E0807211A19322B2A413A394F4947
5D56556A6462777170837E7D
9A9795A4A2A1AEAEADB8B9BAC3C5C6CED1D3D9DEE0E4EBEDF0F8FAE0EAEED0DDE3BDCFD6
A8BFC890ACB87799A7608898517A8C4871824D72815475825A7985607C8765808B69848F
6D8892718B95748E977790997B929A7E939A81949A8494988793968992948C91918E908F
908E8C928C8991898591858190827C8E7E778C79728A756D877067866C6285685D7F6156
70544A5C463D493730362924221A17100C0C0503030B07071F1A1A302B2A403A394E4947
5C5755696463767170837E7D
9A9795A4A2A2AFAEAEB9BABAC4C6C7CFD3D4DBDFE1E6ECEEF2F9FBE3ECEFD2DFE4C1D2D9
ADC3CC97B1BC7D9EAB678D9C577F904C74854D71805374815978845E7B86637E8968828C
6C8690708A94738D96768F977A91997D92998093998293978491948790918A8F8F8C8E8D
8E8C8A8F8A878F87848F84808F817B8E7D778D7A728B756D897268886D6385685D7C5F54
6C52485A443C46352F3327232019170E0C0C0302030E0C0C201C1C302C2B3F3B3A4E4948
5C5756696463767170837E7D
9A9796A5A3A2AFAEAEBABBBAC5C7C7D1D3D4DDE0E1E9EDEFF5FAFCE5EEF1D5E1E6C5D5DB
B4C7CF9EB6C085A4B16F93A25C83945179894F73825374815877835E7A86627D8867818B
6B858E6F8892728C95758E967990987B90977E9197819095828F92848E90878C8D898B8B
8B89888D88858D85828D827E8E7F7A8D7D768D7A728C766D8B7269896E6384675D775C52
684F4754413A42342E2F25221C17160B0B0B000001111010211F1F312E2E403C3C4E4A4A
5C5857696564767270837E7D
9A9796A5A3A2B0AFAEBBBBBAC6C7C7D2D4D4DEE1E2EBEFF0F8FCFDE8F0F2D9E3E7C9D7DD
B9CBD2A4BBC48EAAB57899A7648999577E8E5176855374825877835D7A85627D8866808A
6A848D6E8790718A93758C95778E967A8F957C90957E8E93808C90828B8E848A8B868989
8987868A86838B84818C817D8C7F798D7C758D79728C766D8A7269866C627F645A71584F
614C444F3E383D312C2B232117151408090A010203141314242223333031413E3E4F4C4B
5D59586A6665777271837F7D
9A9796A5A3A2B0AFAEBBBBBAC7C7C7D3D4D4DFE1E2ECEFF0FAFEFEECF2F5DDE6E9CEDADF
BECED5ACC0C996AFBA82A0AC6E909E608594557A895475845878845D7B86627D8866808A
6A838D6D868F718991748B94768D95788D947A8D937C8C907D8A8D7F888B818789838687
86858487838189827F8B7F7C8B7E798C7B758D78718C756D8971688369607960576A544C
5A48414A3B36382E2B26201F121212040608090A0B181819272626353434434141514E4D
5E5A5A6B6766777372837F7E
9A9795A5A2A1B0AEADBBBABAC7C7C6D3D4D3DFE1E1EDEFEFFBFEFEF1F6F8E2EAECD3DEE3
C5D3D9B3C5CD9FB5BF8BA6B17A98A66A8C9B5C808F5779875A79865E7B87627E8966808B
6A838D6D868F708890728A92758C94778C93788B9179898E7A878A7B85887D8486808485
82828284817F877F7D887E7A8A7C778B7A748C78718B756D876F667D665D725C54625049
52443E443834322B29201D1C0D0F100002040F10111D1D1E2B2A2B383737464444535050
5F5C5C6C6867787473847F7E
9A9795A5A2A1B0AEADBBBAB9C7C6C5D3D3D2DFE0E0ECEEEEFBFDFDF5F9F9E8EEF0D9E3E6
CBD7DDBBCBD1A8BCC495ADB785A1AC7695A26789975E7F8D5D7C895F7D89637E8A67818B
6A838D6D858E6F8790718891748B92768B9275888E76868B7684887882867981847C8182
7F8080817E7D847D7B867B78887B7689797389766F88736B826B6377625A6B58515C4C46
4C403C3D34312C2826191A1A0C0E100205071314162122232F2E2F3C3B3B494747555352
615E5E6D6A6979757484807F
9A9695A5A2A0AFADACBAB9B8C6C5C4D2D1D1DEDEDEEBECECFAFBFBFAFCFDEEF2F4E0E7EA
D1DCE0C4D1D6B2C3CA9FB4BD91A9B3839EA97693A069889664849063818D65808C69838D
6B838D6D858E6F868F71879074899175899072868C718389728186747F83767F82797D7F
7C7D7E7E7C7B817B79837A7786787487777285736D836F687C6760715E5764544E554844
463D3A37312F262424141719080D0F0B0E10191B1C262728333334403F3F4C4A4A585555
6360606E6B6A7A767585807F
9A9695A4A1A0AFACABB9B7B6C5C3C2D0CFCEDCDCDBE9E9E8F6F6F6FFFFFFF4F7F7E6EBED
D8E0E3CBD6DABBC9CFA8BAC29CB0B88EA5AF859EA879949F718D996C89956C86916E8690
6E868F6E868F6F858E71878F74899074888F71858C6E81876E7E83707C81727C80757B7D
787B7C7A79797D787780777582767383757081706B7D6A6574635D6A5A545D504B4F4541
403A38312E2D212223131619060B0D1316182021232C2D2E3838394443434F4E4E5A5858
656362706D6C7B7776858180
9A9694A4A09FAEABAAB8B6B5C3C1C0CECDCCD9D9D8E5E5E4F2F2F1FFFFFEFBFCFCECF0F1
DFE5E8D2DBDEC4CFD4B2C1C8A5B6BE9AAEB691A6AF889EA87F97A17A939D789099788D96
768C94738A9272889074888F76899074878F72858C6F81886D7E836D7B806F7A7E737A7C
75797A7778787976757C75737D74717E716D7A6C687667626D5F5A635652574C4949413F
3B36352C2B2C1F21221116190D11141B1E2027282A3233343E3D3E4847485351515D5B5B
686564726F6E7C7877868280
999594A39F9EADAAA8B7B4B3C1BFBECBCAC9D6D5D4E2E1E0EEEDECFBFAF8FFFFFFF3F4F5
E6E9EBD9DFE2CCD5D8BCC8CDAFBDC3A5B5BC9CAEB593A6AE8BA0A8879BA385989F82959C
7F929A7B8F967A8D94788A91798A9177898F74868D7182886F7F846D7B816F797E71797C
72777A74777775747477737278716F786E6B7468656E635F655B575C524F504947433E3D
35333328292B1E202213181A191C1F2426282F303139393A4343434D4C4C575555615E5E
6A67677470707D7978868281
999593A29E9DABA8A7B5B2B1BFBCBBC9C6C5D3D1D0DEDCDBE9E8E6F5F4F2FFFEFDFAF9F9
ECEEEEDFE3E5D3D9DBC5CED1BAC5C9AFBCC1A8B6BB9EAEB497A8AF93A3AA909FA58C9BA1
89989E84949A8493997F8E957E8D937C8B917A888E76848A738186717D82717B7F737A7D
73787A747677747474767271756F6D736B696E666368605D5F5755564F4D4A45443D3B3B
2F303127292A1D1F221C20222527292D2F303637384040414948495251515B5959646261
6D6A697672717E7B79878381
989493A19D9CAAA6A5B3B0AEBCB9B8C5C3C1CFCDCBD9D7D6E4E2E0EFEDEBFAF9F7FEFCFB
F2F1F1E5E7E8DADDDFCDD3D5C2CBCEB9C2C6B3BDC1A9B6BAA1AFB49EAAAF99A5AA95A1A5
919EA28B999E8B979C869398849195818D937E8A8F7B878C778387758084747D81757B7E
75797B747678737474757271726E6D6F6968696361635D5B5A5553504C4B444242383839
2D2F30242628222527282A2C2F31323637393E3F404646474F4E4E5756565F5D5D676564
6F6D6C777473807C7B888382
989392A09C9AA8A4A3B0ADACB9B6B5C2BFBECBC8C7D4D2D0DEDCDAE8E6E5F3F2F0FDFBFA
F6F4F3EBEBEBE0E2E2D5D8DACACFD1C1C8CBBCC3C6B4BDC0ACB6B9A8B1B4A1AAAD9DA7A9
99A2A5949EA2919B9E8D979B8A9497869094838C9180898D7B8589798286787F82787D80
777A7C767879757576757272716E6D6B67676561605E5B5A5553524B4A4A404041343637
292C2D27292B2D2F3032343538393A3F3F404646474D4D4D5453545C5A5A6361616B6868
726F6E7A7675817D7C888483
9793919F9B99A6A2A1AEAAA9B6B3B1BEBBB9C6C3C2CFCCCBD8D5D4E1DFDDEBE9E7F6F3F2
F9F6F5F1EFEEE6E6E5DCDCDDD2D4D5C9CDCEC4C9CABEC3C4B7BCBEB2B7B8A9B0B2A5ABAD
A0A7A99CA3A5979EA0949B9D90979A8C9396878F92848B8F80878A7D84877A80837C7F81
797B7E78797B787778767474716E6E6A68676361605C5A5952515248494A3F4041343638
2B2C2D3132343637393C3C3D4142424747484D4D4D5453535A5959615F5F6865656E6C6B
7572717C7877827E7D898583
9692919D9998A4A09FABA8A6B2AFADBAB7B5C1BEBDC9C6C4D1CECDDAD7D5E2DFDDEBE8E6
F4F0EEF6F2F0EDEAE8E2E1E0D7D8D7CFD1D1CACCCCC5C7C8BEC1C1BABCBCB3B5B6ACB0B1
A7ABACA3A7A89EA2A39A9E9F969A9C9196988C9194888E9084898C8085887D81847D7F81
7C7E807C7D7E7B797A777575726F6F6B696962616159595952525247494A3D3F41353739
3636383B3C3D4040414545464A4A4A4F4E4F5554545A5959605E5E6664636C6969726F6E
7874747E7A7984807F8A8584
9691909C9896A29E9DA8A5A3AFABAAB5B2B0BCB9B7C3C0BECAC7C5D2CECDD9D6D4E0DDDB
E8E4E2EFECEAF1EDEBE8E4E3DDDBDAD4D3D2CDCDCCCAC9C9C5C5C4C1C0BEBABAB9B3B3B3
AEAFAEA8A9AAA4A5A5A0A2A29B9D9E96999A9194968C9092888C8E8387897F82847D8081
7C7E807F7E7F7E7C7C7876767371716C6A6A62616258595A515252494B4C3F41423E3E3F
4242434545464A494A4E4D4E5251525756565C5A5A605F5F6663636B6868706D6D757271
7A7776807C7B8581808A8685
95918F9A9695A09C9AA6A2A0ABA7A6B1ADACB7B3B2BDBAB8C3C0BEC9C6C4D0CCCBD6D3D1
DDD9D7E3DFDDEAE6E4EAE6E4E2DDDBD9D5D3CFCECCCBC9C8C8C6C4C5C2C0BEBCBAB8B6B5
B3B2B1AEADACAAA8A7A5A5A4A0A0A09A9B9B9597989092938D8E90878A8B8284867F8183
7E7F81807F7F7C7B7C7776767371716C6A6B6262635A5A5B5152534B4C4D4747484A494A
4C4C4C504F4F5352525755565A59595E5D5D6261606765646B69686F6D6C747170787574
7D7A79827E7D8682818B8785
94908E9995939E9A98A39F9DA7A4A2ACA9A7B2AEACB7B3B1BCB8B7C1BEBCC7C3C1CCC8C6
D2CECCD7D3D1DDD9D6E3DFDDE3DEDBDBD6D4D1CDCBCBC8C6C7C4C2C5C1BFC0BCBAB9B6B4
B5B2B1B1AEADAEABA9AAA7A6A4A2A19E9E9D9A99999494959191928B8C8E89898A818385
8283838381827F7D7D7B78787573736D6C6C6665655B5C5D545555535352535253555454
5756565958585C5B5B5F5D5D6260606664636967676D6A6A706E6D7471717875747C7978
807C7B84807F8884828C8786
948F8D9793919B9796A09B9AA4A09EA8A4A2ACA8A6B0ACABB5B1AFB9B5B3BEBAB8C2BEBC
C7C3C1CBC7C5D0CCC9D4D0CEDAD5D2D9D4D1D4CFCCCBC7C4C5C1BEC1BDBABEBAB8B9B6B4
B5B2B0B3AFADAFAAA9ABA8A5A7A4A3A3A19F9E9B9A9896979492928F8F908D8C8C858687
858585838282807E7E7C79797674746F6E6E6B69695E5E5E5C5B5B5D5C5C5E5D5D5F5E5E
615F5F6361616563636865656A68676D6A6A706D6D73706F7673727976757C79787F7C7B
827F7E8682808985838C8886
938E8D9691909995939C9896A09B9AA39F9DA6A2A1AAA6A4ADA9A8B1ADABB4B0AFB8B4B2
BCB7B6BFBBB9C3BEBCC6C2BFCAC5C2CCC7C4CEC8C6CCC6C3C3BEBBBEB8B5B7B4B2B5B1B0
B3AEADB1ADABAEA9A7AAA6A4A7A3A2A5A19FA09C9A9B98989693939290918E8D8D8A898A
8787878584848280807E7B7B7977777270716E6C6C676565686666686666686666696767
6B68686C6A696E6B6B706D6D726F6E7471707673727975757B78777D7A79807C7B837F7E
8581808884828A86858D8987
928D8C94908E9792919995939C97969E9A98A19D9BA39F9DA6A2A0A9A4A3ABA7A5AEAAA8
B1ACAAB3AFADB6B1AFB8B4B2BBB6B3BDB8B5BEB9B6C1BCB8BDB7B5BAB4B1B5B1AEAFABAA
ADA9A7ADA8A7ABA6A4A8A4A2A6A19FA39F9D9F9B9A9D9998989595959292918E8E8D8C8C
8A89898785858482827E7C7C7E7B7B7A777775727173707072706F72706F73706F737070
7471717572727673737875747976757B78777D79787E7B7A807D7B827E7D84807F868281
8884828A86848C87868E8988
918D8B938E8C94908E9692909893929995939B97959D98979E9A99A09C9AA29E9CA49F9E
A6A19FA7A3A1A9A5A3ABA6A4ACA7A5ADA9A6AEAAA7AFAAA7AEA9A6ADA8A5AEA8A5A8A4A2
A6A29FA6A2A0A5A19FA6A19FA49F9D9F9B999C99989A9695979493969291928F8F8F8D8C
8D8A89878584898685848180827F7E817D7D7E7B7A7D7A797C79787C79787C79787D7979
7D7A797E7B7A7F7B7A807C7B817D7C827E7D837F7E84807F858180878381888482898584
8A86858C87868D89878E8A88
908C8A918D8B928D8C938E8D948F8E94908E95918F9692909793919894929994939A9594
9B96949B97959C98969D99979E99979E9A989F9A989F9A989F9A989E9A979E99979C9896
9B97959C97959B96959C98959D98969A969499959497939296929195919094908F928F8E
908C8B8A87868B87868A8685898584888483878382868381868281868281868281868281
8783818783828783828884828884838985838985848A86848A86858B87858C87868C8887
8D89878E89888E8A888F8A89
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.267442 0.97619 0.488926 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(248) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
8C89888C89888C8A888C8A898C8A898C8A898C8A898C8B8A8D8B8A8D8B8A8D8B8B8D8C8B
8D8C8B8D8C8B8D8C8C8D8D8C8D8D8C8D8D8D8D8D8D8D8E8D8D8E8E8D8F8F8D8F908E9193
8D8F8F8D8E8D8D8D8C8D8E8D8D8D8C8E8D8C8E8D8D8E8E8D8E8E8D8F8E8D8F8E8D8F8E8C
8F8E8C8F8C8A8F8B8A8E8A888D89878C88868C87858C86848B85828A838089817F887F7B
857C7788807D89827F8984818A84828A85838A85838A86848B86848B87858B87858B8786
8B88868B88868B88878B8987
8C89888C8A898C8A898C8B8A8D8B8A8D8B8B8D8C8B8D8D8C8E8D8C8E8E8D8E8E8E8E8E8E
8E8F8F8E908F8F90908F91918F91918F91928F92928F93938F93948F94968F95978F979A
8E94968E93938F92928F92928F9191909191919292919392919392929392929291929290
92918F918F8D918D8B8F8B898E89878D87848C85838B83808B807D887D79867A76847670
82746E857974867C78877F7B88807D89817E89827F8983808A84818A85828A85838A8684
8B87858B87858B88868B8887
8C8A888C8B898D8B8A8D8B8B8D8C8C8E8D8C8E8E8D8E8F8E8F8F8F8F90908F90908F9191
90929290939390949490949590959691969791969891979991989A90999C909B9E909CA1
90999C909899909697919696919595929696939696949796939796949796959695949493
93929093908E928F8C918C899089868E86838D83808B807C897C7887787384746E816E67
816F6983746E857772867A76877C78877E7A887F7C88807D89817E8982808A83818A8482
8A85838B86848B87858B8886
8C8A898C8B8A8D8C8B8D8C8C8E8D8D8E8E8E8F8F8F8F9190909191909293909393919495
91959691969792979892989A92999B929A9C929B9D929C9F929DA0929EA2929FA491A1A6
919EA1919C9E929A9B92999A93999A949999959999969A99959A99959A98969897969695
95949295929094908D938C8A9189858F85818D817D8B7D7888787386746D826E677E685F
806C6582706983736D847671857874867A76877C78877D7A887F7C88807D89827F898380
8A84828A85838B87858B8886
8C8A898D8B8A8D8D8C8E8D8D8E8F8E8F9090909191909293919394919595929697929798
93989A93999B939B9D949C9E949DA0949EA1949FA394A0A494A2A694A3A793A3A992A5AB
92A1A5929FA2939E9F939D9E949C9D959C9C969C9C969C9C979D9C979C9B989B9A979997
97969496949196908E958D8A92888590837F8D7F7B8A7A7587756F8570688169617D645B
7F6960816C6582706983736D847570857772867975867B77877D79887E7B88807D89827F
8983818A85828A86848B8786
8C8A898D8C8B8E8D8C8E8E8E8F909090919190939391949592969692979893989A939A9B
949B9D959D9F959EA195A0A296A1A496A2A696A4A896A5AA96A6AB95A7AD94A7AD93A8AE
93A4A993A2A594A1A395A0A1959FA0969F9F979F9F989F9E989F9E999E9E999D9C999B9A
99989698959397918E968E8A94888591837E8E7E798A797387726B836C647F645B7D6258
7F665D806961816D6582706983726C84756F857772867974867B76877D79887E7B88807D
89827F8A84818A85838B8785
8C8B898D8C8B8E8E8D8F8F8F90919190939391949592969793989993999B949B9D959D9F
959EA196A0A397A2A597A3A798A5A998A7AB99A8AD99AAAF99ABB198ACB295ACB393A9B0
93A6AB94A5A895A4A696A3A497A2A398A2A298A1A299A1A19AA1A09AA1A09B9F9E9B9D9C
9A9A989A969499928F978E8A95888592837E8F7C778B77718670688368607E60567D6056
7E645A80675E816A62816D65826F6983726C84746F857771857874867B76877D79887F7C
88817E8983808A85838B8785
8C8B8A8D8D8C8E8F8E8F9090909292919495929697939899949A9B959C9E959EA096A0A2
97A1A498A3A798A5A999A7AB9AA9AE9AABB09BADB39BAFB59CB1B79CB3BA93ACB491A8AF
93A8AD95A7AB96A6A997A5A798A4A699A5A59AA4A49BA4A49BA4A39CA3A29CA1A09C9F9D
9C9C999B97959A9390988E8B96888493827D8F7C768B756E866D6582665D7D5E537D5F55
7E62587F645B80675F816A62826D65826F6983726C84746F857771867974867B77877E7A
88807D89827F8A84828B8785
8D8B8A8E8D8D8F908F909191919394929596939899949A9B959C9E969EA097A0A398A2A5
99A5A899A7AB9AA9AD9BABB09CADB29CAFB59DB2B89EB4BB9FB7BE9FB8C08DA8B191A9B0
94A9AE96A9AD97A8AB98A8AA99A7A89AA7A89BA7A79CA7A69DA7A69EA6A59EA3A39EA09F
9D9C9A9C97959B9390998E8B96888393817C8F7B758B736C866C6482655B7D5C517D5E53
7E60567E62597F655C80675F816A62816D66826F6983726C84756F857772867A75877C78
887F7B89817E8A84818B8684
8D8B8A8E8E8D8F909090929291949593979894999B959C9D969EA097A0A398A3A699A5A9
9AA8AC9BAAAE9CACB19DAFB49EB1B79FB4BA9FB6BDA0B9C0A3BDC497B3BC8EA9B292ABB2
95ACB097ACB098ABAE9AABAD9BAAAB9CAAAA9DAAAA9EAAAA9FAAA9A0A9A7A0A5A4A0A2A0
9F9C9A9D97959C92909A8D8A96878393807B8F7A748B736B876B6382645A7D5C507D5B50
7D5D537E60557F62597F655C80675F816A63816D6682706983736D847570857874867B77
877E7A88807D8983818A8684
8D8C8B8E8E8E8F9191919394929596939899959B9D969DA097A0A398A3A69AA5A99BA8AC
9CABAF9DADB29EB0B59FB3B9A0B5BCA1B8BFA2BBC2A4BFC79CB8C192B0B993AFB695AEB4
97AFB399AEB29AAEB19BADAF9CACAD9DACAC9EADACA0ADACA1AEADA1ABA9A2A7A6A1A3A1
A09D9B9F97959D92909A8C89968682937F7A8E78728A726A876B6282645A7F5D527C594D
7D5B4F7D5D527E5F557E62597F655C806860806B63816E6782716A83746E847772857A76
877C7988807C8983808A8684
8D8C8B8E8F8E909292919494939798949A9B969C9E979FA298A2A59AA5A89BA8AC9CABAF
9DAEB39FB1B6A0B4B9A1B6BDA2B9C0A3BCC4A3BFC7A0BEC794B3BD95B3BC96B2BA97B2B7
99B2B79BB2B69CB1B39DAFB19EAFAF9FAEAE9FAFAEA1AFAEA3B0AEA3ACABA3A8A6A2A2A0
A29E9CA097959F928F9B8B88978581927E798D77718A7169876B6283655B805E537D584D
7C574B7D5A4F7D5D527D5F557E62597F655D7F6860806B64816F6882726C847570857874
867B78877F7C8982808A8684
8D8C8B8F8F8F909292929596939899959B9D969EA098A1A499A4A89BA7AB9CABAF9EAEB3
9FB1B6A1B4BAA2B7BEA3BAC1A4BDC5A5C0C8A6C3CD97B8C296B6BF97B5BD98B4BC9AB4BA
9BB5BA9DB5B99EB4B69EB1B29FB0B0A0B0B0A0B1AFA2AFAEA3ADACA5ACABA4A6A5A4A3A1
A4A19FA29997A092909B8B88968380927D798D7670897068876A6284655B815F547E5A4E
7B55487C574B7C5A4E7C5D527D5F567D62597E665D7F6961806C6681706A83736E847772
867A76877E7B89827F8A8583
8D8C8B8F908F919393929697949A9B969C9E97A0A299A3A69BA6AA9CAAAE9EADB29FB1B6
A1B4BAA3B7BEA4BBC2A5BEC6A6C1CAA8C5CEA2C2CC93B5C096B6BF98B6BF99B6BC9BB7BC
9EB8BDA0B9BCA1B7B8A0B3B3A1B2B2A3B2B19EACABA1ACACA3AAA9A5A9A8A5A8A7A6A5A3
A7A2A0A49B98A295929B8C8996827F917C788C756E896F67866A6185655B826055805B4F
7D56497C54477C574A7B5A4E7B5C527C60567D635A7E675F7F6A63806E6882726C837671
857975877D7A88817E8A8583
8D8D8C8F9090919494939798959B9C979EA098A1A49AA5A89CA9AC9DACB19FB0B5A1B3B9
A3B7BDA5BBC2A6BEC6A8C2CAA9C5CEAAC9D398BBC794B6C096B7C099B8C09AB7BD9DB9BF
A0BBC0A3BCBFA3B9BAA3B5B59FADAEA0ACAD9CA7A7A0AAA9A3A9A8A5A9A8A7ABAAA8A4A2
A8A29FA79E9AA69A979E908C9583808F7A768B746E886D6686696185665C846256815D51
7F574A7C53457B54477A564A7A594E7A5C537B60577C645C7E68617F6C6681706A83746F
847874867C7988817E8A8583
8E8D8C909190929595949899969C9D979FA299A3A69BA7AA9DABAF9FAEB3A1B2B8A3B6BC
A5BAC1A7BEC6A9C3CAABC6CFABC8D1A9C9D491B5C294B6C197B7C19AB8C09CB8BE9FBAC0
A2BDC2A5BDC0A4BABAA5B5B59AA8A99DA9AA9FAAAAA1A9A9A4ACABA6ABABA8ACAAA8A6A3
A9A4A1A89F9BA79C98A1928E9888848E7B778A726D876C6586686086665D856358835E52
80584B7E54457B534678534677554A78594F795D547B61597C665E7E6A63806E6982736E
847773867C7888807D8A8482
8E8D8C90919192959694999A969D9F98A1A39AA5A89CA9AD9EADB1A0B1B6A2B5BAA4B9BF
A6BDC4A9C2C9ACC7CFB1CDD6ABCAD39FC1CD90B4C094B6C198B8C19BB8C09DB9BFA0BBC0
A3BEC2A4BABEA2B6B7A1B1B29BAAAB9FAAABA1ABABA3ABABA5AEADA8ADACA9ADABA9A8A5
A9A4A2A79D9AA79C98A3948E9D8C8792807A88716B866A6486685F87675E876459856053
825A4C7F55477B524378514374504676554B775A51795F567B635C7D68617F6D6781716C
837672857B7787807D898482
8E8D8C909291939696959A9B979EA099A3A59BA6AA9DABAF9FAFB4A1B3B8A3B7BDA5BBC2
A7C0C7AAC5CDAFCBD3B5D1DBA6C7D193B7C393B5C196B7C199B9C19CB8C09EB9BFA1BBC0
A4BDC1A4B9BCA0B2B4A0AFB1A0AEAEA1ADADA3ACADA5ADADA7AEAEA9AEADAAACABAAA9A6
A9A4A1A89E9BA59C96A2948E9E8C8796827C89726D85696486686088685E88655A866154
835B4E8157497F5445744C3F724D4273524775574D775C537961597C665F7E6B6580706B
827570857A76877F7C898482
8E8E8D919292939797969B9D98A0A29AA4A79CA8AC9FADB1A1B1B6A2B5BBA4B9C0A6BDC5
A8C2CAAAC6CFAECCD5AECDD8A1C2CE94B7C396B7C298B8C29AB8C09DB9C09FB9BFA1BBC0
A4BCC0A4B9BCA0B1B3A1AFB0A1AEAFA3AEAFA4AEAEA6AFAFA8B0B0ABB0AFABADABACAAA7
AAA5A2A9A09CA59B95A2938E9D8B8596817B8E766F876B6587696189685F89665B886255
855D4F84594A8356466F47396F4A3D704E4373544A755950785F577A645D7D69637F6F69
82746F847975877E7B898481
8E8E8D919393949798969C9E99A1A39BA6A99EAAAEA0AFB3A2B3B8A4B7BDA5BCC3A7C0C7
A8C4CCAAC7D1AACBD5A7C8D4A2C2CD9CBCC79AB9C39AB8C19CB8BF9EB9BF9FB8BFA1BAC0
A4BBC0A4B9BCA2B3B6A1AFB0A2AEAFA4AFAFA6B0B0A8B0B0AAB1B1ACB1B0ADAFADADAAA8
ACA6A3AAA19CA59A95A0928C9B8A8496817A9078718B6F68896B628A6A608B685C896356
865E50865A4B8557476D45376B463A6E4B4071514773574E765D5479625B7B68617E6D68
81736E847874867E7B898381
8F8E8D929393949899979D9F9AA2A59DA7AA9FACB0A1B1B5A3B5BBA5BAC0A7BEC5A8C2CA
A9C6CFA9C9D3A8CAD6A7C7D2A3C2CD9FBDC79BBAC39BB8C09DB7BF9EB8BFA0B9BFA2BABF
A3BBC0A4B9BDA4B5B8A2AFB1A3AEAFA5AFAFA7B1B1A9B1B1ABB2B1AEB3B1AEB0AEAEACA9
ADA6A2AAA19CA49994A0918B9B898396817A9179728D72698C6F658C6C618C695D896457
885F51875B4C8859486B44366943376B483D6E4E4471544B745A527760597A665F7D6C66
80726D837874867D7A898381
8F8E8E92949495999A989FA09BA4A69EA9ACA1AEB2A3B3B8A5B8BEA7BCC3A8C1C8A9C4CD
AAC8D2AACBD6A8CAD6A7C7D2A3C1CB9FBBC49CB9C29DB7BF9EB7BE9FB8BEA0B9BFA2BABF
A3BABFA5B9BDA5B6BAA4B2B3A4AEAFA6AFB0A8B1B1AAB1B1ACB2B1AFB4B2B0B1AFAFADAA
ADA6A2AAA19CA498939F908A9A888296817A927A728F746B8F71678E6E638C695E8A6558
885F52865C4D885A4A6F47396540336845396C4B4170524873584F765F5779655E7C6B65
7F716C827773857D7A888381
8F8F8E939595969A9B99A0A29DA6A8A0ABAEA2B0B4A5B5BBA7BAC0A9BFC6AAC3CBABC7D1
ABCBD5ABCDD9A9CAD5A7C7D2A1BEC89DBAC29DB8C09DB6BE9EB6BEA0B7BEA1B9BFA2B9BF
A4BABFA5B9BDA6B7BAA5B3B5A4AFAFA6B0B0A9B1B1ABB2B1AEB3B2B0B4B2B1B2AFB0ADA9
ADA6A2AAA09BA498939F90899A8780958179937B7292776E9173698F6F648D6A5E8A6558
876052845B4C835849744B3C6740336440346A483D6E504672564D755D5578635C7B6A63
7F706B827672857C79888380
8F8F8E939595979B9C9BA1A39EA7AAA2ADB0A4B3B7A7B8BDA9BDC3ABC2C9ADC7CFADCBD4
ADCFDAADD0DBABCBD6A6C3CEA0BAC39CB8C19DB6BF9EB6BE9FB6BDA0B7BEA2B9BFA3B9BF
A4B9BEA5B8BDA6B7BAA5B2B5A5B0B1A7B0B0AAB2B2ACB2B1AFB5B3B2B5B3B3B3B0B1ADA9
AEA6A2A99F9BA598929F8F8899877F968179947C7494797092756B8F71658D6C5F8A6659
86605282594B7E5547754C3D6A4032633E3169473B6D4E4471554B745B5377625B7A6862
7E6F6A817571857C79888280
908F8F949696989C9D9CA3A5A0A9ACA4AFB3A7B5BAAABBC0ACC0C7AEC6CDB0CAD3B0CFD8
B0D3DDAFD1DCABCAD4A4BEC99EB7C19BB5BE9CB5BE9EB6BD9FB6BDA1B8BEA2B9BFA3B9BF
A4B9BEA6B8BCA5B6B9A5B2B4A5B0B1A8B1B1AAB3B2ADB3B2B0B6B4B3B5B3B4B3B0B2ADA9
AEA6A2A99E9AA597919E8E879A877F97827A967E75957B7193776C9072678D6C60896659
85605280584B7B5446734A3B6A3F306942346A463B6D4D4270534A735A517661597A6761
7D6E69817570847B78888280
90908F9597979A9E9F9EA5A6A2ABAEA6B2B5AAB8BCADBEC3B0C4CAB2C9D1B3CFD7B4D3DD
B3D5DFB1D1DBAAC7D2A1BAC59BB4BE9AB4BC9CB4BC9DB6BD9FB7BEA1B8BEA3B9BFA4B9BE
A5B9BDA6B7BBA5B5B8A5B1B3A5B0B0A8B0B1AAB2B1ADB4B2B1B6B4B5B6B4B5B3AFB3ADA9
AFA6A1AA9E98A496909F8E879B888199847B988077967C7294786D9173678D6D6189675A
855F537F584A7A544673493B6B40316941336A45396C4B406E5248725850755F58786660
7C6D68807470847B78888280
9190909698989B9FA0A0A6A8A4ADB0A9B4B8ADBBBFB0C2C7B3C8CEB6CED5B8D3DCBAD9E3
B9D8E1B4D1DAA8C4CE9CB6C198B1BB99B2BB9AB3BC9DB5BDA0B7BEA2B9BFA4BABFA5BABE
A6B9BDA5B6BAA5B3B6A4B0B2A4AFB0A7AFAFAAB1B0AEB3B2B2B6B4B5B6B4B6B3AFB4ADA9
AFA6A1AA9E98A59690A090889D8A829B857D998178977D7395796E9174688E6E6189675A
8460537E594B79554772493B6C4334663D2F6843366A493E6D504670574E745E5677655E
7B6C677F736F837A7787827F
9191909799999DA0A1A2A8AAA7B0B2ACB7BAB0BEC2B4C5CAB8CCD2BBD2D9BDD8E0C0DFE8
C0DBE3B4CED7A5C0CA95B1BC93AEB996B0B999B2BB9CB4BCA0B7BEA3B9BFA6BABFA6BABE
A7B9BDA5B6B9A4B2B5A2AEB1A3ADAEA5ADADA9B0AFAEB3B1B3B6B4B6B7B4B7B4B0B5ADA9
B1A6A1AB9E98A79790A3918AA08C839D877E9B8279987E7396796E9274688E6E6289685B
8461537F5A4D7A564871493B6A423464392B66403368473C6B4E446E554C725C5576635D
7A6B667E726E837A7687817F
929191989A9A9EA2A3A4AAACAAB2B4B0BABDB5C2C6B9C9CEBDD0D6BFD6DDC2DCE4C5E1EA
C4DCE4B5CDD5A2BDC78DABB88FABB693AEB897B0B99BB4BCA1B8BEA5BABFA8BCC0A9BBBF
A8BABDA5B6B9A2B0B4A0ADAFA1AAACA3AAAAA8ADADADB1B0B3B6B3B8B7B4B9B4B0B6AEAA
B3A7A1AE9F99AA9991A6938BA28D859F887E9C837A987E7395796E9274688E6F628A695C
856254805C4E7B5749704B3D663F31613628633D30664439694C426C534A705A5374625C
796A647D716D82797687817F
929291999B9BA0A4A4A7ACAEADB5B7B4BEC0B9C6CABECED2C2D5DAC5DBE1C7E0E8C8E2E9
C9DEE5B6CCD49EB9C387A7B48BA8B38FABB594AEB79AB2BAA1B7BEA6BBC0AABDC1ACBCBF
A9B9BCA3B4B89EADB19EACAE9EA8AA9FA5A6A6AAAAADB0AFB4B5B3B9B7B4BBB5B1B9AFAA
B6A9A2B0A199AD9B93A9958DA58F86A189809D847A977D7395796E9374688F6F628A695C
856355815D4F7C584A6F4B3C623C2E5D3224603A2E6342376649406A51496E595173615A
7768637C716C81797586817E
9392919B9C9BA2A5A5AAAFB0B1B8BAB8C1C4BFCBCEC5D3D7CADBE0CBE0E6CBE3EBCAE1E7
CADCE2B4C9D199B5C081A2B086A5B18CA8B392ACB598B0B89EB5BBA5B9BFA8BABEAEBDBF
A9B9BCA0B1B69BAAAE99A8AB9AA4A69CA2A3A5A8A7ADAFADB4B5B3BAB8B5BDB6B2BBB1AB
BAADA5B2A199B19D95AF998FA99289A28A809D847A977D7394796D9274689070628B6A5C
866456835F507C58496C483B5E392C592F225C382C603F3563473E674F476C5750715F59
7667627B706B81787586807E
9493929C9C9CA4A7A7ACB1B1B5BBBCBDC5C7C5D0D2CDDADDD3E3E7D7EAEFCBE2E9CADEE4
C6D8DEB2C6CE95B2BD7C9EAC82A1AE89A6B08FAAB395AEB59BB1B7A2B6BBA5B8BCAABABD
A6B6B9A0B0B49AA9AD97A5A898A2A49EA3A3A5A7A6ADAEADB5B5B3BBB8B5BEB7B2BDB2AC
BCAEA5B6A29AB7A197B59D92A99389A28A809E857B967D7393786D907367906F628D6A5C
8866578660517D5849694639583629552D2159352A5C3D3260443B644C4569554E6E5D57
7466617A6F6B80777486807E
9493929D9D9DA6A8A8AFB3B3B8BEBFC2C9CBCBD5D7D6E1E4E1EFF2DFEFF3CEE2E7C7D9DF
C2D3D9ACC2CA91AEBA789AA97F9EAB85A3AD8DA9B193ABB397ADB39EB1B7A2B5B9A5B6B9
A3B3B7A0AFB39BA9AD98A4A79AA3A49FA4A4A6A8A7ADAFADB5B5B3BBB8B4BEB7B2BEB2AC
BCADA5B9A59CB9A399BAA095A89289A38B819F867B947C7292776C9072669170628F6C5D
8C67588B63537C5748664538533328502A1E543227573A305C4239614A4266534C6C5B56
726460786D6A7F777485807E
9594939E9E9EA8AAAAB2B5B5BCC1C1C6CDCED1D9DBDEE7E9EDF8FAE0EEF1D3E4E8C6D6DC
BBCDD4A3BBC58BAAB67598A67B9BA882A0AA8AA5AE91A8B096ACB29BAEB4A0B1B6A2B3B7
A2B1B59FADB19CA9AC9AA5A89BA2A4A0A5A5A6A9A8AEAFADB6B5B2BCB7B3BFB7B2BFB2AC
BDADA5B9A69DB9A398B79E93AB948AA58D829F867B957D7294786D947467937163926D5E
906A5A8E66557955476243364F33274B261B4E2E2452362D573E365D474063504A695954
70635E776C697E7673857F7D
969493A09F9FAAABABB4B7B7BFC3C3CAD0D0D6DDDEE3EBEDF2FBFDE5F0F3D7E4E8C7D6DC
B6C9D09EB8C287A6B27396A47898A47F9CA686A0A98DA5AD93A9AF98ABB09DADB19CADB2
9EADB19CAAAE9BA8AB9AA5A79BA2A4A1A6A6A8ABAAAFB1AEB6B4B1BCB6B2BFB7B1C1B4AD
BFAEA6BAA69DB7A298B39C92AD958BA88F84A2877C9B8074997B6F987769977365967060
966D5C9067567754455B40344F3328462419482A214C3229523B3358443D5F4E48665752
6E615D756B687C7572847F7D
969594A1A0A0ABACACB6B8B8C2C5C5CDD2D2DADFE0E7EEEFF6FDFEEAF2F4D9E4E8C7D6DC
B4C8CF9CB6C085A4B07296A47495A17B98A3829CA589A0A88FA4AB95A7AC98A8AD98A9AD
9BA9AE9BA8AC9CA8AB9CA6A99FA6A8A4A9A9AAAEADB0B1AFB6B3B0BBB5B0BEB5AFC1B4AD
C1B0A7BDA89FB9A399B29C91AE958AAA9085A68A7EA184779E7F719C7A6B9A76669A7363
9B705F906655745244583F3450342946261B3E231B452D254C373053413B5B4B46635551
6B605C736A677B7472837F7D
969594A1A1A0ADADADB8B9B9C4C6C6D0D3D4DDE1E1EAEFF0F8FEFFECF3F5DBE5E9C8D7DC
B4C7CE9BB5BF85A4B07396A472929F78959F7F99A1869CA38CA0A691A3A894A5A997A6AB
99A8AC9BA8AC9DA9AC9FA9ACA3ABACA6ACACACB0AEB1B2B0B5B3B0B9B4AEBDB3ADC0B2AA
C2B0A7BFAAA1BCA59BB59D93B1978CAC9185A98B7FA48679A181739E7B6C9D78689F7565
A073618D64537351435C41364D332942251B331B143D272045322C4E3D3857484360534F
695E5A7169667A7471837E7C
979594A2A1A1AEAEADB9BABAC5C7C7D2D5D5DFE2E2ECF0F0FAFEFFEDF3F5DEE7EAC9D8DC
B5C8CE9DB6BF87A5B17597A472919E76929D7C969E8399A0899CA28E9FA492A2A796A5A9
99A7AB9CA8AC9EAAAEA1ABAEA5ADAEA9AFAFADB1B0B2B3B0B5B3AFB8B3ADBBB2ABBEB1A8
C0AEA5BFAAA1BEA69CB9A095B3998DAE9286AA8C7FA58779A48273A17D6DA27A6AA37766
A173618B62527351435D41364930273A21192B171035221C3F2E29493A355346415D514D
665C59706865797370827E7C
979594A3A2A1AEAEADBABBBAC7C8C8D3D5D5E0E3E3EDF1F1FBFFFFEEF4F5E0E8EACCD9DD
B7C9CFA1B8C08CA7B37A99A671919D73909A7A939C81969D87999F8C9DA291A0A595A3A7
99A6AA9CA9AC9FABAEA3ADAFA6AFB0AAB1B1AEB2B1B2B4B1B5B3AEB8B2ACBAB1AABDAFA7
BEADA4BEAAA0BDA59BBAA095B59A8EB29588AD8E81A9897AA88475A78170A77D6CA67A68
9F7260896051714F425C3F34452E26331F1825140F2C1C173829254436324F433F5A4F4C
645B586E6764787270827E7C
979594A3A2A1AFAFAEBBBBBBC8C8C8D4D6D5E1E3E3EFF1F1FCFFFFEFF3F4E1E8EACFDBDE
BBCBD1A5BBC291ABB57E9CA873929E718E987891997F949B85989D8B9BA0909FA495A3A6
99A6A99DA9ACA0ACAFA4AEB0A8B0B1ACB2B1B0B3B2B3B4B0B5B2AEB8B1ACBAB0A9BCAEA6
BDACA3BDA99FBCA49ABAA094B79B8FB49689B29183AF8C7DAD8777AC8373AB806EA97B69
9B6F5D845D4E6E4D40593D33422D252D1D171F120E2316123225223F34304B413E574E4B
625A576D6664777270817D7C
979594A3A2A1AFAFAEBCBCBBC8C9C8D5D6D5E2E4E3F0F1F1FDFFFFF0F3F4E2E8EAD1DCDF
BFCED3ABBEC596AEB7839FAA7795A0708D98768F987E939A84969C8A9A9F909EA295A2A6
99A6A99DAAADA1ACAFA5AFB0A9B1B2ADB3B2B0B4B2B3B4B0B5B2AEB8B1ABBAAFA8BBADA5
BDABA2BDA89EBCA499BA9F94B99C8FB79789B59284B38E7FB08979B08574AE816FA87A67
956B5A805A4C694A3E533A303C2922271A15190F0C1C110E2D221F3B322F493F3D554D4A
6059576B656376716F817D7B
989594A4A2A1B0AFADBCBBBAC9C9C8D6D6D5E3E4E3F0F1F0FEFFFEF1F4F4E2E8EAD4DDE0
C3D0D5B1C1C89AB1BA88A3AD7B98A373909A768E977D929984969C8A9A9E909EA195A2A5
9AA6A99EAAACA3ADAFA7B0B1AAB2B2AEB3B3B1B4B2B4B4B0B5B2ADB7B0AABAAEA7BBADA4
BCAAA0BDA79DBCA398BBA094BA9C8FB9988AB79485B58F7FB48B7AB38775AE816FA37664
8F66567A574962453A4C352D35251E2116121109061A110F2A221F39312E473F3C534C4A
5F59576B656376716F817D7B
989594A4A2A0B0AEADBCBBBAC9C8C7D6D6D4E3E3E2F1F1F0FFFFFDF1F4F4E3E9EAD6DEE1
C8D3D7B5C4CAA0B5BC8FA7B07F9BA578939D788F987E929985969B8B9A9E919EA296A2A5
9BA6A9A0AAACA4AEB0A8B0B1ACB3B3AFB4B3B2B5B2B4B3AFB5B1ACB7AFA9B9ADA6BAABA3
BCA89FBCA69CBCA398BB9F93BB9B8EBA988AB99485B79080B68C7BB28674AB7E6C9C7160
8961537151445B41364430292E201B1A110E0B04031B13122A222038312F453F3D524C4A
5E59576A656375716F817D7C
979594A3A1A0B0AEADBCBBB9C9C8C6D6D5D3E3E3E1F1F0EFFFFFFDF1F4F3E5E9EAD8DFE1
CBD5D8B9C7CCA7B9C096ACB4869FA97F98A17B929B7F929A86979C8C9B9F929FA298A3A5
9DA7A9A1ABADA5AFB0AAB1B2ADB3B3B0B4B2B2B4B1B4B3AFB6B0ABB7AEA8B8ACA5B9AAA2
BBA79EBBA59ABBA297BB9E92BB9B8EBA9789BA9485B99080B68B7AB08472A67A69946B5C
805C4E694B40533B323D2B25261A16120C0A0903031A15132A2322383230453F3E524C4B
5E59576A6564757170807D7C
979594A3A1A0AFADACBBBAB8C8C7C5D5D4D2E2E1DFF0EFEDFFFEFCF3F4F4E7EAEADBE0E1
CED6D9BFCBCFADBDC39EB1B78FA5AD879EA77F969E81949B87989D8E9CA094A0A399A4A7
9EA8AAA3ACADA7AFAFABB1B1AEB4B2B1B4B2B3B4B0B4B2ADB5AFA9B6ADA6B7ABA3B8A9A0
BAA69DBAA499BBA195BB9D91BB9B8DBB9789BB9384B9907FB48A78AB806F9D74648A6556
75554960463B4A362E3325201B14110804030C07071C17162A252438333245403F524D4C
5E5A586A6664757270807D7C
979593A3A19FAFADABBBB9B7C7C5C3D4D2D0E1DFDDEFEDEBFDFCFAF6F5F4E9EBEADDE2E2
D2D9DBC4CED0B5C1C6A6B5BB99ACB28FA4AB869BA385979E8A9A9F909EA296A1A49CA5A8
A1A9AAA5ACADA9AFAFACB1B1B0B4B2B2B4B1B4B3AFB4B1ACB4ADA8B5ABA4B6A9A1B7A79F
B9A49BB9A297BA9F93BB9C90BB9A8CBB9687BA9283B78E7DB08675A47A6A946D5E7F5E51
6A4E43573F36413029291E1B130E0D030000100D0C1E1A192C2827393534464241534E4D
5F5B596A6665757271817D7C
979493A2A09EAEABAAB9B7B6C5C3C2D2D0CEDFDDDBEDEAE8FBF9F7F7F5F3ECECEBE1E4E4
D6DBDCCAD1D3BBC5C9ADBABEA2B1B698A9B08FA2A88B9CA38E9DA293A0A498A3A69EA7A8
A3AAABA8ADADABB0AFAEB2B0B2B4B2B4B4B1B4B1ADB3AFAAB3ACA6B3A9A2B4A79FB6A59C
B7A399B8A095B99D92B99A8EBA988AB99486B79080B38A7AA980709A736488665874574B
60473E4C39313629241E18150D0A0A020000120F0F201D1D2E2B2A3B373748444354504F
5F5C5B6B6766767371817E7C
979492A29F9DADAAA9B8B6B4C4C1BFD0CDCBDCDAD7E9E7E4F7F4F2F9F6F4EFEEECE5E6E5
D9DCDDCFD4D5C2C9CBB4BEC1AAB6BAA1AFB49AA9AE94A3A894A3A797A3A79CA5A7A2A9AA
A6ABABAAAEADADB0AFB0B2AFB4B4B1B6B4B0B3B0ACB2ADA8B1A9A3B2A7A0B2A59DB4A29A
B5A097B69E93B69B8FB7988BB79587B69283B18C7DAC84759F796A8F6C5E7D5E52695045
55413941312C2A211E151111050404060405151313242121312E2D3D3A3A4A4645555251
615D5C6C6867767372817E7D
969392A19E9CABA9A7B6B4B2C1BFBDCDCAC8D9D6D3E5E2DFF1EEEBFAF7F4F3F0EEE8E7E6
DDDEDED4D7D7C8CDCEBAC2C4B1BABDA8B3B7A4AFB39EAAAE9CA8AB9CA8AAA1A9AAA7ACAB
ABAEADACAFAEAFB0AEB2B1AEB6B3AFB6B2AEB3AFAAB0AAA6AFA7A1AFA49EB0A29BB2A097
B29E95B29B90B3988CB39588B29184B08D7FAA8677A17C6E93716483645871574C5D483F
4A3933352A26201B190E0D0D0000010D0C0C1A1919282525343231403E3D4C4948575453
625F5E6D6A68777473817F7D
969391A09D9BAAA7A6B4B2B0BFBCBACAC7C5D5D2CFE0DDDAECE8E5F8F4F1F6F2EFEAE8E7
E1E0DFD7D8D8CDD0D0BFC5C7B6BDBFB0B8BAABB4B6A7B0B2A4ADAFA5ADAEA8ADAEACAFAD
AEB0AEAEB0ADB0AFADB2B0ACB5B1ADB4AFABB1ACA8AFA8A3ADA59FACA09BAD9F98AF9D95
AE9A91AE978DAD9388AD9084AB8C80A7867A9F7E7195746886685D765C52644F46514039
3D312D292320181515070909030305121212201E1F2C2A2A3836364441414F4C4B595756
6461606E6B6A787574827F7E
9592919F9C9AA8A6A4B2AFADBCB9B7C6C3C1D1CECBDCD8D5E7E3E0F2EEEAF7F3F0EEEAE8
E4E2E0DADAD9D0D2D1C4C8C8BCC1C2B7BCBDB3B9BAAFB5B6ACB3B4ACB1B1AFB1B0B1B1AF
B1B1AFB0B0ADB2AFACB2AEAAB4AEAAB2ACA8B0AAA5AEA5A1ABA29CA99E98A99B94AA9991
A9968DA99389A68E84A58A80A1857A9C7F7392766B876C6278605769544C584640453833
302926201C1B1210110406070C0C0D19191A2625253130303D3B3A474545524F4F5C5958
6663626F6D6C79767582807E
9592909E9B99A7A4A2B0ADABB9B6B4C3C0BDCDC9C6D7D3D0E1DDDAEBE7E3F5F0EDF1ECE9
E6E3E1DCDBD9D3D3D2C9CBCAC3C5C5BDC0C0BABDBDB5B9B9B2B6B6B3B5B4B4B4B2B4B2AF
B4B2AEB1AFACB4B0ABB1ACA8B1ACA7B0AAA5AFA7A2ABA29DA89F99A59A95A49791A4958E
A39189A18E859D89809B847B967E7490776D866E657A645B6B58515C4C464B3E3A38302D
2522201817170B0B0C0B0C0D1617172221222D2B2C37363641403F4B49495553525F5C5B
686564716E6D7A777683807F
9491909C9A98A5A2A0ADAAA8B6B3B1BFBCB9C8C4C2D1CDCBDBD6D3E4E0DCEFEAE6F2EDEA
E8E3E1DFDBD9D7D4D3CECDCCC7C7C6C1C2C1C0C0BFBBBCBBB8B9B8B9B8B5B7B5B2B6B3B0
B6B2AEB3AFABB4AFAAB1ABA7B0AAA5AEA6A2ACA39FA89F9AA49B96A197919F938E9F908A
9C8C8598888194837B927E768C7770846F6879665F6D5C555F514B4F44403E36342C2927
1D1C1C1010110E0E101717182020212A292A3433333D3C3C474545504E4D595756625F5E
6A686773706F7B787783817F
93918F9B9897A3A09EABA8A6B3B0ADBBB8B5C3C0BDCCC8C5D4D0CDDDD9D5E6E1DEEFE9E6
E9E3E0E1DCD9D9D6D3D1CFCDCAC8C7C6C5C3C4C2C0C0BFBDBDBBB9BDB9B6B8B5B1B8B3AF
B6B1ADB4AEAAB2ADA8B0AAA5AEA7A2ABA39FA79F9BA49C979F97929C938E998F8A988C86
94878190827D8D7E788A797283726B7869636E5F5A615550534946443D3B34302F242323
1515161112131A1A1B2121222A292A3231323B3A3A4342424C4A4A5452525D5A5A656262
6D6A697472717C7A78848180
93908E9A9795A19E9CA8A5A3AFACAAB7B3B1BEBBB8C6C2BFCEC9C6D6D1CEDED8D5E6E0DD
E8E2DEE3DDD9DBD6D3D3CFCCCDCAC7C8C5C3C6C3C0C3C0BDC0BCB9BEB9B5BAB5B1B8B3AE
B5B0ABB4ADA9B1AAA5AEA7A3ABA49FA7A09CA39C989F98949A938F978F8B928A86928782
8C827D897E7A867A7582746F796C686E635F635955564F4C4843413A38372C2C2C1E1F20
1414151C1C1D2423242B2B2B3332323A393A4241414A484852504F595757615E5E686665
6F6D6C7674737D7B7A858281
928F8E9896949F9C9AA5A2A0ACA9A7B3AFADB9B6B3C0BCB9C7C3C0CEC9C6D5CFCCDBD5D2
E1DBD8E2DCD9DCD6D3D5D0CDCEC9C6C9C5C2C6C2BFC4C0BCC0BBB8BFB9B4BBB5B0B7B1AC
B4AEA9B1ABA6AEA7A3ABA49FA8A19CA39D999F98959B9491968F8C918A878C858289817D
857D7A847B788176737A6F6C716764665E5C5A54524D4948413F3E3434342728291D1E1F
1F1E1F2726272E2D2E3534343C3B3B434141494848504F4E5755555E5C5B6563626B6968
72706F7876757F7C7B858381
918F8D9794929D9A98A39F9EA8A5A3AEABA9B4B0AEBAB6B4C0BCB9C6C1BFCCC7C4D1CCC9
D6D1CDDBD5D2DCD6D2D6D0CCCFC9C6C9C4C0C4C0BCC3BDBAC0BAB6BEB7B2BAB3AFB5AFAA
B2ABA7AEA7A3ABA4A0A8A29DA49E9A9F99969B959296918D918C898C878486817E827D7A
7F7A797F78767B7371736B696B6462615C5A5451504746463C3C3C313233252627252525
2C2B2C3231323837383E3D3D4543434B4949514F4F5755555D5B5A6361606967666F6D6C
7572717A7877807E7C868382
918E8C9693919B9896A09D9BA5A2A0AAA6A4AFABA9B4B0AEB9B5B3BEBAB7C3BFBCC8C3C0
CCC7C4D0CBC7D5CFCCD5CFCBCFC8C4C8C2BEC2BDB9BFBAB6BDB7B3BCB5B0B7B0ACB2ABA7
AFA8A4ABA5A1A8A19DA59F9AA09B979C969397928F928D8B8E8A88888483827F7D7E7B7A
7B78777C777577716F6F6A686863615D5959504E4E444445393A3A3132322D2D2D333232
3837373D3C3C4342424847474D4C4C5351515856565D5C5B6361606866656D6B6A72706F
7775747C7A79827F7E878483
908D8C9491909995949D9A98A19E9CA6A2A0AAA6A4AEABA8B3AFACB7B3B0BBB7B4BFBAB7
C3BEBBC6C1BECAC4C1CEC8C4CDC6C2C7C1BCC0BAB6BBB5B1B9B2AEB7B1ACB3ACA8AEA8A3
AAA4A1A7A19DA59E9AA29C979D9894989390938F8D8E8B898B8886858282827F7E7A7979
7A7877787574726E6E6B686763605F5857574F4E4E4243443A3A3A3938383C3A3B403F3F
4443434947474D4C4C5250505655545B59595F5E5D6462616866666D6B6A716F6E767472
7A78777F7C7B83807F878583
8F8C8B93908E9693929A97959E9A99A19E9CA5A19FA8A5A3ACA8A6AFABA9B3AFACB6B2AF
B9B5B2BCB7B4BFBAB7C2BCB8C4BEBAC1BBB7BEB7B4B8B2AEB4AEAAB1AAA6ADA7A3A8A39F
A59F9CA39D9AA19A979C989498949296928F928E8B8C8A88888684848282817F7F7A7979
797877757373706E6D6A6766615F5F5857585251514444454342424746454A48484D4B4B
504F4F5452525856565C5A595F5D5D6361616765646B68686E6C6B72706F767372797776
7D7B79817E7D848281888584
8E8C8A918E8D9491909794929A97959D9A98A09C9BA39F9DA5A2A0A8A4A2ABA7A5ADA9A7
B0ACA9B2AEABB4AFADB6B1AEB7B2AEB8B2AEB7B1AEB5AFABAFA8A5AAA49FA4A09DA29E9B
A09B989F9A979C979398949196939095928F908D8B8D8A89888685858383807F7F7C7B7B
787878747373706E6D6967676362625B5A5A5653534F4E4E5251515553535755555A5858
5C5B5A5F5D5D6260606563636866656B69686E6C6B716F6E7472717775747A78777D7B79
807D7C83807F868382898685
8E8B89908D8B928F8D9491909693929995949B97969D9A989F9C9AA19D9BA39F9DA5A19F
A7A3A0A8A4A2AAA5A3ABA6A4ACA7A4ACA7A4ACA7A4ADA7A3A7A19EA39E9AA09C999C9896
9A969399959398949297939095918F928F8D8F8C8A8C8988888685858383817F7F7D7C7C
7A797976747472706F6A68676765656361605F5D5D605E5E615F5F636160646362666464
6866666A68686D6B6A6F6D6C716F6E7371707573727875747A78777C7A797E7C7B817E7D
83807F858281878583898785
8D8A898E8B8A908D8B918E8D93908E9491909693919794929895949A97959B98969C9997
9D9A989F9B99A09C9AA09C9AA19D9AA19D9AA19D9AA09C999E9A979D98959B9794959290
94918E95928F94908F94908E94908D908D8B8E8B8A8C8988888685878484848281817F7F
7E7C7B767574767473716F6E706E6D706E6D6F6D6C6F6D6C706D6D706E6D726F6F737170
7472717673727775747876757A78767B79787D7A797E7C7B807D7C817F7E83807F848280
8683828785838986858A8786
8C8A888D8A898E8B898E8C8A8F8C8B908D8C918E8C918E8D928F8E93908E93908F94918F
95919095929095929196939196939196939196939196929095918F94918E93908E918E8C
908D8B908D8B908D8B918D8B908D8B8D8A898C89888A8887898685888584868483858382
82807F7D7B7A7F7D7C7F7C7B7E7C7B7E7B7A7D7B7A7D7B7A7E7B7A7E7C7B7F7C7B7F7D7C
807D7C817E7D817F7E827F7E83807F838180848280858281868382868483878583888584
8986858987858A87868B8887
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.511074 0.245293 0.732558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
7B7B7C7A7B7B7A7A7B7A7A7B7A7A7A7A797A79797A797979797979797879797878797878
787778787777787777787676787676787676787575787575787574787474787373777270
787474787575787576787575777676777576777576767575767475767575757475767576
76757676777876777977797A787A7B787A7C797B7D797C7E7A7E7F7B7F827C81837D8386
7F868A7D82857C80827C7F817B7E807B7E7F7B7E7F7B7D7F7B7D7E7B7D7E7B7C7E7B7C7D
7B7C7D7B7C7D7B7C7C7B7B7C
7A7B7B7A7A7A7A797A797979797879797878787777787677777676777575777575767474
76737376737275727275717175717075707075706F746F6E746E6D746D6C746C6A746B68
756D6C756E6E756F6F746F6F747070737070736F6F726E6F726E6E726E6F716E6F716F71
72707272727473747674767875787A767A7C777B7E787D807980837B83877D878B7F8B90
818D927F888C7D85887D83867C81847C80837B80827B7F817B7E807B7E807B7D7F7B7D7E
7B7D7E7B7C7D7B7C7D7B7C7C
7A7A7B7A797A797879787878787777777676777575767474767373757272757271747170
74706F736F6E736E6D726D6C726C6B726B69716A68716967716866716764716662716460
726764726867726A69716A6A716A6A706A6A6F69696E696A6F696A6E696A6E6A6B6E6C6D
6F6D6F70707270717471747672767974797C757C7F777F827983877B878B7E8B91829198
829096808B907E888C7D86897C84877C83867C81847B81837B80827B7F817B7F807B7E80
7B7D7F7B7D7E7B7C7D7B7C7D
7A7A7B797979787778787777777676767474767373757271747170736F6F736F6E726D6C
716C6A716A697069687068666F67656F66636E64626E63606E625F6E615D6E5F5B6E5E59
6F615E6F63616F64636E65646E65646D65656C65666C65666D65666C66676B67686C696A
6D6A6D6D6C6F6E6E716E727570757872797C747C8076808579858A7B898F7F8F9582959C
8191987F8E937E8B907D888D7D868A7C85887C83877B82857B81847B80837B80827B7F81
7B7E807B7D7F7B7D7E7B7C7D
7A7A7A797879787777777676767474757372747170736F6F726E6D716D6B716B6A706968
6F68666E66646D65626D63616C625F6B605D6B5F5B6B5D596A5C576B5A566B59546C5853
6C5C586C5E5B6C5F5D6B605F6B61606A61616A6262696262696162696263686364696567
6A686A6A6A6C6B6D706C70736E747770797D727C8175818678868C7B8C927F929982979F
80939A7F8F967E8C927D8A8F7C888D7C868B7C85897B84877B83867B81847B80837B7F82
7B7F807B7E7F7B7D7E7B7C7D
7A797A787878777676767474757372747170736F6E726D6C716B6A706A686F68666E6664
6D64626C62606B605D6A5E5B695C59685B5767595567575267555067544F68534E69534D
695752695956695A58685C5A685C5C675D5D675D5D665D5E665D5E665E5F666061666263
666466676769686A6D696D716B73766D787B707C8173818677878D7A8E957F959D8198A0
7F949B7E90987D8E947D8B917C8A8F7C888D7C868B7B85897B84877B83867B81847B8083
7B7F817B7E807B7D7F7B7C7D
79797A787777777575757373747171736F6E716D6C706B696F69676E67656C64626B6260
6A605D695E5B685C58675A5666575365555164534E63514B624E49634D47644D46675049
67534E67555266565466575665585864585864595963595A62595A625A5B625B5D625D5F
63606363646664676B666B6F6871746B767A6E7C8071818676888E7A8F977E96A07F97A0
7E949C7D91997D8F967C8D937C8B917C898E7B878C7B868A7B85897B84877B82857B8183
7B80827B7F817B7E7F7B7C7E
797979787677767474757271736F6F726D6C706B6A6F68676D66646C64616A615F695F5C
685C59665A5665575364555062524D61504A604D475F4A445D47415B443D644A42674F49
66504C65514E6452506353526254536154546054546054555F54555F55565E57585E595B
5E5C5F5F606361656862696D656F726875796C7B8070818774888F788F977D97A07D969F
7D949C7C92997C90977C8E947B8C927B8A907B898E7B878C7B868A7B84887B83867B8285
7B81837B80827B7E807B7D7E
797979777676767373747170726E6D706B6A6F69676D66646B63616A615E685E5B675B58
65585564565262534E61504B5F4D485E4A445C47415B443D594039583F37694D45674E47
644E49634E4B614F4C604F4E5F504F5E50505D50505C4F515B4F515B4F525A52535A5457
5B585B5C5E605D62665F676B626D7166747869797F6E808772878F768E967B96A07B959E
7B939C7B929A7B90987B8E967B8D947B8B917B8A8F7B888D7B878B7B85897B84877B8286
7B81847B80827B7E807B7D7E
797879777575757272736F6F716D6C6F6A686D67656B64626A615E685E5B665B57645854
63545061514D5F4E495E4B465C48425A453E59423B573E37543A3261443B6B4E45654B45
624B46604A475F4B485D4B495C4C4B5B4C4C5A4C4C594B4C584A4C574B4E564E50575254
585659595B5E5A60645C6569606C7064727768797E6C7F8670868E758D9579949D79949E
7A939C7A929B7A91997A8F977A8E957B8C937B8B917B898F7B888D7B868B7B85887B8386
7B82847B80827B7E807B7D7E
797878767575747171726E6E706B6A6E68666C65636A615F685E5B665B58645754625450
60514C5E4D485C4A445A464159433D574039563C3452372F5C3E3567483F654840624842
5F47425D47435C47445A474659484758484957474956474854454854474A534A4D544F52
555457565A5D575F625A64695E6B6F62727767787E6B7F856E858C738B9375909A78949E
79939D79939C79919A7A90987A8F967A8D947B8C927B8A907B898E7B878C7B858A7B8487
7B82857B81837B7F817B7D7E
787878767474747070716D6D6F6A686D66646A6360685F5C665B586458546254505F504C
5D4D485B494459454057423B553E37543A3352372F57393063433A62433B60443C5E443E
5C433E5A433F58434057444356444455444554434553444651434651474A504B4D515053
51545753595C545E615864685C6B6F60717666787E697E856D848C718992738F9876939D
77949E78939D78929C79919A7990987A8E967A8D947B8B927B8A8F7B888D7B868B7B8488
7B83867B81847B7F817B7D7F
78777876737373706F706C6B6E68676B646269605E675D5A6459556255515F514D5D4D48
5B494458453F56413B543D3652393250352D4E31285C3C315F3F355F41385D41395B403B
583F3A563E3A543F3D5441405341425241425241435144454F46484E494A4F4F504F5254
4E53554F585B515E615664685A6B6F5F717664787E687E856C838B6E8891718D9774919B
7795A077949F77939D78929C79919A7A90987A8E957B8D937B8B917B898E7B878C7B8589
7B83877B81847B7F817B7D7F
787777757373726F6E706B6A6D66656A6361675E5C655A5762565360524E5D4E495A4944
58454055413B533D365038314E342C4C2F275233286140355E3F355C3E365A3F38583D38
553B37513A37503B3A513E3F4F3E404D3F40524647514849504C4D4F4E4F4E4E504C5052
4B52554C595C4D5C60536266596B6F5F717664787F687E866B838B6D87906F8C95718F9A
74939E7595A076949F77939D79929B7A91997A90977B8E957B8C927B8A907B888D7B868A
7B84877B82857B80827B7D7F
787777757272726E6D6F69686C656369615F665C5A6358556053505E4F4B5B4B46584641
55413B523D364F38314D342C4B3027482B2259382D5F3E345D3E345A3C34583D37553B36
5238344E37344D39384C3B3C504444524949564E4F514D4E4F4E4F4D4D4E4B4C4D4B5254
4B54574B575B4B595D506065586A6E5E727763787F677F866A838B6B868F6C8A946F8D98
71929D7395A27595A177949F79949E7A939C7B91997B8F977B8D947C8B917C898E7C878B
7B85887B82857B80827B7E7F
777677747271716D6C6E68676B6462675F5D645A576156525E514D5C4C4859474256433D
533E374F39324C332C482E26472B23492A205F3D315E3D335B3D34583C34563C36533A35
4F37324B37344C3A3A4C3E3F564B4A544A4A514A4A4F4A4B4D49494A484948484A494D50
484F524A54584C585B51606556676C5E717663797F67808668838B69858E6A88926C8C97
6E909C7094A17395A07696A17996A07B959E7B939B7C91987C8F967C8D927C8A8F7C888C
7C85897C83867B80837B7E7F
777676747171706C6B6D6766696260665D5B6358556053505D4E4A59494556443F533F39
503A344C352D482E2641261E44271E5332266240345D3D33593B33563B34543B35513934
4D37334D3B384F4140524746574D4C524B4B4F49494C48494A454647454746454846494C
464D4F4854574A555A4E5D6353646A5C6E74647A8067808767838B67848D678691698A95
6C8F9B6E939F7296A37697A47B9AA37C97A17C959E7C939B7D90977D8E947C8B917C898D
7C868A7C83867B81837B7E80
7776767370706F6B6A6C666468605E645B586156535E514D5B4C4757474254423C513C36
4E37304B322A452B223F231A4C2D235F3D315F3F345B3C33573B33543B35523B354F3834
4C38344C3C394F43415046455048484E49494C49494B4848484747464747454849454C4D
4550524754574A565B4D5D62526469596C72637A8066818766838B65838C658590678994
698D996B909D6C92A0779AA67C9CA67D9AA47D97A07D959D7D92997D8F967D8C927D8A8E
7C878B7C84877C81837B7E80
77757673706F6F6A696B6463675F5D6359575F54515C4E4B58494455443E523F394F3A33
4D352D4A3027472B224A2B2057362B603F335B3C32583B33553B34523B35503B354D3935
4B39354B3C394E43414D44444D46454B464649464647454645434543444542464842494C
434D5144525648575C4C5F6352676C597076617A8065818764828A63828B63838F648793
678C98688F9D6991A07C9FAC7E9FAA7F9DA77F99A37E969F7E939B7E91977D8D937D8A8F
7D878C7C84887C81847B7E80
767575726F6F6E6968696362655D5B6157555D524E5A4C4856464253413B503C354D372F
4B322A492E25492A204D2D2251332855382E563A31543A33523B35503A354E3B364C3935
4A39354A3B394A403E4B43424A44444844444643444443444242434042433F43463F474A
404B4F42505547565C4B5E6351666C566E755C767D617D8462808961808B61828E628693
658B98668E9C6690A07DA1AE81A2AE809FA9809CA57F98A17F959D7E92997E8F957D8B91
7D888C7C85887C82847B7E80
767575716E6E6D6867686260645B595F55525B4F4C57494554433E503E384D38324B332C
492F26482B2148291E492B214C2F264F342C523830513A334F3A354D3A354B3A354A3935
483835473A37483D3C4842414843434642434440424141423F40413D3F423C41443C4549
3E4A4F414F5446565C4B5E6550666D556D755A747C5E7B845F7D875E7E895F818D618692
648A97658D9C648F9F7EA2AF82A4AF82A1AC819EA8819AA380979F7F939A7F90967E8C92
7D898D7D86897C82857B7F80
767475716E6D6B676667605F625A575D5350594D4955464251403B4D3A354A352E483028
462B2245271D46271D462920492E264D352D5037304E39334D3A344B3934493834483834
463734453936443B3A453F3F454242434142413F413F40413D3F413A3D413A40443A4448
3D4A4F3F4F5445565D4A5E654F666D546D7558737C5B79825B7A855C7D885E818D608592
638A97658D9C658F9E7B9FAC84A6B284A4AF83A0AA829CA68198A180959C7F91977E8D93
7E8A8E7D868A7C82857B7F81
757474706D6D6A6665655F5D6058555B514E564A4652433F4E3D384A373147312A442B24
43271E42231942241B43271E4830294C352E4D37314B39334A3934483834473733453633
443634433835423938423D3D434142413F413F3E403C3E403A3C3F373C3F363E42384247
3A494E3E4E5543565D485E654E666E536C7556727B56757F5778835A7B875C7F8C5F8491
638A97678F9D6C93A17A9EAC83A7B387A8B385A3AD839EA8819AA380969E8092997F8E94
7E8A8F7D878A7C83867C7F81
7574746F6C6C696464635D5C5E5654584E4C5347444E403C4A393446332D432D2640271F
3E21183D1E153E211941292147332C4A362F4A3831493832483833463632443531433532
413533403634403837413C3D413F403F3E403C3C3F3A3C3F373A3E343A3D333C41354147
38474D3C4E5440555D475D664D666F506B75526F7953727D5475815779855B7E8A5E8390
638997698F9D6F94A2799FAD85ABB88BADB985A5B083A0AA829BA481979F80939A7F8F95
7E8B907D878B7D83867C7F81
7473736E6B6B686362615B5A5B5351554C495044414B3D39463531422E293E28213B221A
391C14381C143B221B412E2647352E4A3730483732473732453632433531423430403330
3F33313E35333E37373E3B3B3E3D3F3C3D3F3A3B3F383B3F35393D32393D313B41324147
36474D3B4E5540555E465E674B656E4D69734F6C774F6F7A51737F557784597C895D8290
628896688F9E6E94A2789EAD81A9B884A8B584A5B083A0AB829CA68198A080949B809096
7F8C917E888C7D84867C7F81
7473736D6A6A6662615F595859514F5249464C413E47393541312D3C2A2438231C351C14
331810331B1438241D41302948373048373147373245363143343041332F3E322F3D312F
3C31303B34333C36363C3A3B3C3C3E3B3C3E383B3E363A3E33383C2F383D2E3B40314047
34474E394E563F565E445D6647626C4966714A69744C6C784E707D527582567B885B818F
608895678E9D6D93A2759DAC7DA6B581A7B483A5B183A1AC829DA78299A281959C809197
7F8D927E888C7D84877C8081
7372736C69696460605D5756564F4D4F4644483D3B4235323C2D29372520321D172D150E
2A140D2C191336251E43322C48383147383246373244353041332F3E312E3B302E3A302F
3930303933333A36373B3A3B3B3C3E3A3C3F373B3F34393D30373C2D373C2C3A402E3F46
32464E374D563C545D405A64435F6945636E466772496A774B6F7C507481547A88597F8E
5F8695658C9B6B919F739CAA7BA2B181A9B782A6B383A3AE839FA9829AA382969E819298
808D937F898D7D84877C8082
7372726B6868625F5E5B5555534C4B4B4341443A373D312E37282531201C2B1813250F09
21100B291A1537272246362F4939334839334637324335313F322F3B302E382F2E372E2E
362F2F3732323836363A393B3A3C3E393C40373B3F33393E2F373C2B363C2A39402C3F46
2F454D344C5538525C3B57623E5C6740606C436470466875496D7B4D7280517886577D8D
5C8493628A99688F9E719AA97AA2B182ACBB83A8B583A4B083A0AA839CA582979F819399
808E937F8A8E7E85887C8082
727172696767615D5D5853534F4A4847403E3F3634372D2A3124202B1B1725130E200D08
1E100D291D18392B254C3B334C3C36493A344738344236323D312F382F2D342C2B322C2C
322D2E3531323836373A3A3B3B3D3F3A3E42373D41323A3F2D373D29363C28393F2A3E45
2C444D314A5433505A36545F3959653D5E6A3F626F446875476C7A4B71804F7786547C8C
5A82925F8898648D9D6F97A77BA4B383AEBD84AAB884A6B284A2AC849DA68399A082949A
818F94808A8E7E85887C8082
7171716866675F5C5C5551514C4746433C3B3A32303128262A1E1B2416121F0E0A1A0B08
170D0B251C193C2E29513F37503F384C3D37483B364337333D3331382F2F332D2D2F2C2E
302E303533333A39393B3B3D3C3F413D4346384044333C412D383D28363C26383F273D45
29414C2D4853304E5932525E365663395B693C606E426774466B7A49707F4D7585517B8B
5781915C8797628C9C7099A97EA7B685B1C186ADBA86A8B486A4AE859FA8859AA283959C
829095808B8F7F86897D8182
7170716765665D5A5A534F4F4844443E3938342D2C2A22212118161B0F0D180A07170B09
16100E2A211D41332D57443C53423B4F3F3A4A3D394539364036343A3232383232333031
3532343C3939403F4043424344474942494C3A4348333E432C383E27363D24373F243B44
243D492A47532A4A562B4D5B2F5260355A673A606D416674446B79486F7F4B7484507A8B
557F905984955F8B9C709AAA7FAAB988B4C388AFBC88AAB688A5B087A1AA869CA385969D
839197818C907F86897D8183
7070706665655B5959504E4E4542413A35352E2928221C1B160F0E0C0302130805150D0B
1813122A23204436305B484057453E52423D4C3F3B473C394239383D36363B3636383535
3E3A3A44403F474545494849474A4C41494D3A454A333E442C383E26353D23373F233B45
243F4B2948552548562449592E5260355A68385E6D406574446A7948707F4A74854E798B
527E8F5482945C8A9C709BAB82ACBB8AB5C48AB0BE8AACB88AA7B289A3AB889DA586989E
849298828D9180878A7D8183
7070706464655958584E4C4C423F403532322825251A1616080404050000110A0814100F
1916162E2724493A33604C435A49425545404E403D493E3C453D3C403A3A3D39393C393A
3E3C3D424041464647484A4B454A4D40494D3A454A323E452B383F25373F233840233C46
25414C284854284957274B5A355664385C6A3C616F466977496E7C4A73834975864B788A
4E7C8E4E7F925C8B9D729CAC86ACBB8CB7C58DB3C08DAEBA8DAAB48CA5AD8A9FA7889AA0
869499838E9281888B7E8183
6F70706464645857584C4B4B3F3E3E323030242222141212020001080606100D0C1A1715
221E1D392E2A4F3F38644F465E4C455849445245424C4340463F3E423D3D3E3B3B3C3A3C
3D3D3E40414343454744484A444B4E3F494D39444A313E442A3940253840223741223B46
24414D274754284A582C505E3959663C5F6C416472496C7A496F7E47728347748648778A
497A8D4A7D915E8C9F769EAE89AEBC90BAC891B6C291B1BD90ADB68FA7B08DA1A98B9BA2
88959A858F9382888B7E8284
6F6F706363645656574A494A3D3C3D2F2E2F212021111011000001070707100F0F1C1A18
2B25223F342F54433D6551496150495B4D48554A475047454B4544474343434243454344
454545474849474A4B474C4E454D503E484D374349303D442A3A42253842223843203A46
213F4C254653284A582D505E335765385D6B3E6472436979436C7D436F82437285447488
43778B477C91608EA07CA2B189AEBC93BCCA95B9C596B5C095B0B993AAB290A4AB8D9DA3
8A979C86909483898C7F8284
6E6F7062626356555649494A3B3B3C2E2E2F1F1F20101011000102070809131212201D1C
2F282643373257464066524A64534C5E504C584D4B534B494E49484B48484949494A4A4A
484A4B484B4D474B4E464C4F414A4D3B454B3440462F3C44293B43253A43233A45213D48
21404D2345532548572B4F5E305565345B6A3860703C65763D697B3F6C7F407084407287
3D7389487D936390A37DA2B186ACBB91B9C79BBDC99CB9C49AB4BD98ADB594A7AD90A0A5
8C999D889195848A8D7F8384
6E6F7062626355555648494A3A3B3C2D2D2F1E1F210F1112000204080A0B141414231F1E
322B28473A3558484167534B66554F61534F5B504E554E4D514C4C4D4B4B4A4A4B48494B
46494A45494B43484A40464A3C4449384247323E442D3B43293A43263A45243C47233E4A
22414F264754284B592B505F2C5463305869335D6F3762743A66793D6C803E6F833B7085
3A72894B80956492A479A0B088ADBC96BCC9A8C7D2A4BFC9A1B8C19DB1B898AAB094A2A7
8F9A9F8A9396858B8D808385
6E6F706162635455564748493A3B3C2C2E2F1E20210F12130103050A0C0D14151524201F
342D2A473B3757484265524B6656506256515D535057504F524E4E4E4C4D4A4A4C47494B
4547494246493F44473C4246384045343E442F3C432B3942283A43253A45243C48223E4B
22414E244553264A582B505F2F5665335B6B355F703964763A687B3B6B80396D82376F85
3A738A4F83976594A67AA3B28EB2C09FC1CDB0CDD6ACC5CEA7BDC5A2B5BC9DADB397A5AA
929CA08C9497868C8E808385
6E6F7061626354555747484A3A3B3D2C2E301E20221012140104060A0D0E151616242120
342D2B453A3754464161514A6656516457535E55525852515350504E4D4E4A4A4C46484A
4246483F43463C4144383F43343D42303B412C3940283740263943243A45233B47213D4A
21404E224452254958284E5E2D546430596A345F7136637636667A36697D356B80346E84
3C758C52869A6997A97EA6B694B6C3A8C5CFB7CFD9B5CBD3AFC2C9A8B9BFA2B0B59BA7AC
949EA28E9598878D8F818485
6E6F7061626354565747494A3A3C3D2C2F301E21231013160205080B0F11161719242221
322D2B4239365045405E4F4A6556506559556056545953535351514E4E4F494A4C44474A
4044473C4144383E42353C41313A3F2D383F29363E263640243742223944213A47203D4A
1F404E204352224858254D5E2852632B56682D5B6E2F5F7330637830667B30697F326D84
40798F578A9E6E9BAC84AAB99ABAC6B0C9D3BFD4DCC0D3DAB7C8CEAEBDC3A6B3B89EA9AE
97A0A3909799898D90828486
6E6F7061636455565748494B3A3D3E2D30321F222411151703070A0D101317191A242223
312D2C4038364E44405C4E4A635550675A566058555954545351514D4D4F47494C424649
3E4346393F43353C41313A3F2D373D29353D26343D24353F2236412038441F3A471E3C4A
1E3F4E1E4352204758234C5D25506227546728596C2A5C712C61762D647A2D687F357087
487F945E8FA275A0B08CB0BDA4C0CCBAD0D8C9DBE2CADBE1BECDD3B4C1C6AAB6BAA2ACAF
99A1A592989A8A8E90828586
6E6F70626364555758484A4C3B3E402E313320242612161904090C0D1215181B1C232324
2F2C2C3C37354C4340594D4862544F6659556058565855545250514B4C4E45494B404548
3B4145363D41323A3F2E373D2A353B26333B23323C21333E1F35401E37441D39471D3B4A
1C3F4E1D42531E4657204A5C214F6123536625566B265B70285F7529637A2E69803B748B
4F84996695A77FA6B597B7C3AFC8D2C5D7DED7E6EBD2E0E4C4D1D5B8C4C8AEB8BCA4ADB1
9CA3A693999B8B8F91838586
6E6F70626465565859494B4D3C3F412F323521252813181B050B0E0F1316191C1D232324
2D2B2C3A373649413F544B475E524F6156545E5856575454505051494C4E43474B3D4347
383F43333B402E373C2A353B26323923313920303A1E323D1D34401C36441B39471B3B4B
1B3F4F1B42531C45571E4A5C1F4E6121526622566B235A70255E7529647B326D84437B90
588B9E719CAD89ADBBA1BFCAB9CFD8CFDEE5DFECF0D3DFE3C7D2D6BBC6C9B1BABDA7AEB1
9DA4A694999B8C8F91838586
6F707163646556585A4A4D4E3D414330343723272A151A1E060D10111518191D1F232426
2C2C2D383635443F3E4F484659504D5B53515A55545553534E4E50474A4D4045493A4145
353C412F383E2B343B263239223038202F391D2F3A1B313C1B33401A36431A39481A3C4B
193F4F1A42531B45581C4A5C1D4D611E51661F556B215A70255F752B667E3772884C8196
6392A57CA4B493B4C2ABC5D0C5D7DFDBE6EBE5EFF3D6E0E4C9D3D6BEC6CAB3BABDA8AFB2
9FA4A7959A9C8C8F91838586
6F7071636566575A5B4B4E503F4245323639252A2D181D2109101312171A1A1F21232627
2B2C2D353434403D3D4A4544514C4A544E4D5752525252524B4D4F44484B3D4347373E43
313A402B363C27333A2230381F2E371C2D381A2D3919303D193341193644193948183B4C
183F501942541A46581A4A5D1C4D621D52661D566B215A71266178316B8242798E588A9D
709BAC88ACBAA0BDC8B9CED7D3E1E6E9F2F6E7F0F3D8E1E4CBD3D6BFC7C9B4BBBDAAAFB2
A0A4A7969A9C8D9091848586
6F7172646667595B5D4D505241454735393C282D301B21240D141812191C1B2023232628
292C2D3233353C3B3C4442434A47474E4B4B524F4F4E4F50474B4D404549394146333C42
2C383F27343C22313A1E2F381A2C37182C37172D3A16303D173342173645183949173C4C
17405118435519475A1A4B5E1B4E631C53681E576D235C732B667D3A73884D82966593A5
7DA4B394B4C1ACC5CFC6D7DEDEE8EDEFF7F9E4ECEED8DFE2CCD3D5C0C6C9B5BBBDAAAFB1
A0A4A6969A9B8D8F91848586
7071726567685A5C5E4F525444474A383C3F2C31341F252911181C141B1F1B212422272A
282C2F2F3235383A3B4041424645464948494B4B4C494C4E43484C3C4247353E442E3941
28363E22323B1E2F391A2D38162A36142A37142D3A14303E163443163747173A4A173D4E
17415218445718485B1A4C601B50651D546A215A70286178346D83477C905C8B9E739CAC
8AADBAA0BDC8BACED7D4E1E6E8F0F2F4F9FBE5EBEDD8DEE0CCD1D4C0C5C7B5BABCAAAFB0
A0A4A697999B8D8F91848586
7072736668695C5E60515456464A4C3B4042303538242A2E181F23161D211B222621272B
292E302E323536393B3E404242444545464845484A44494C3E4449384046313D44293740
23343D1E303B1A2E39162C38122A370F2937112D3B133140153545163949173B4C173F50
1842541946591A4A5E1B4E631E536821586D285F7531697F42778B5686996B95A682A6B5
99B7C2B0C7D1CAD9DFE1EAEDF4F9FBF5F9FBE5EAEBD7DCDECBD0D2BFC4C6B4B9BAAAAEAF
A0A3A596999A8D8F90848586
71727367696A5D6061535658494D4F3F4346343A3D2A30331F262A171F231B232722292C
282E312D333634383C3C3F423F434542464941464941464A3C43493740462E3C43243640
1E323D1A2F3A172E3A132C390F2A380E2B3A112F3E143443153747173B4B183E4F184253
1845571B495C1D4E621F526723576C295E7332687D3F74885181946590A17BA0AF92B1BD
A9C1CBC1D2D9D9E3E7EDF2F4FCFEFFF0F3F5E2E6E8D6DADBCACDCFBEC2C3B3B7B8A9ACAE
9FA2A39698998D8E90848586
727374686A6B5F616356595B4C505243474A393E412F3539252C301B23271C2429232B2E
2830332E343733393C3B40423F44474045493F45493D45493B43493540472C3C44243742
1F343F1C323E18313E142F3D112E3D12303F143443173847183B4C1A40501B43541B4557
1D495C204E6123546727586C2D5F7334677B4173864F7F91638D9D779CAB8CABB8A3BCC6
BBCDD4D2DDE2E6ECEFF8F9FBFDFEFFEDEFF0DFE2E3D3D6D7C7CBCCBCC0C1B2B5B6A8ABAC
9FA1A29597988C8E8F848485
7273746A6B6D616365585B5D4F5355474B4E3E4346353B3E2C3236222A2F1E262A242C30
2931342F3639343B3E3C41443E44473E44483C44483A4348384248333F472C3C45263944
2237432037431C36421A36441835441837451A39481B3D4D1E4151204555214859224C5D
2550622854672D5B6E3261743A697B437284527E8E618A9A7598A789A7B49EB7C1B5C8CF
CDD9DEE1E7EAF1F4F6FFFFFFF7F9F9E8EAEBDBDEDFD0D2D3C4C7C8BABDBEB0B2B4A7A9AA
9D9FA09496978C8D8E838485
7374756B6C6E6365675B5E605356584B4F5142474A3A404332383C2A3135222B2F242D31
2B333731383C353C403A41453B43473C44493A43483A44493843493241492D3F48293E48
273C48273D49223B48223D4A203C4A213E4C22414F2445542849582B4E5D2D51612E5565
32596A365F703D6676426C7D4B7584567E8D658A987596A488A4B09BB3BDB0C3CAC7D3D9
DEE4E7EDF0F1FDFEFEFCFCFCEFF0F0E2E4E4D7D8D9CBCDCEC1C3C4B7B9BAAEB0B1A5A6A8
9C9E9F9395968B8C8D838485
7374766C6E6F6567695D606256595C4F5355474C4F404548393F4231383C293135262E32
2D3539323A3E363E423942463C44483E464B3A444A3A454B38444B32424B31424C2E424C
2C414D2C424D29414D2A434F2944512A46532C4A57304E5B345260375664395A683C5E6D
416472476A784D707F5377855C7F8D698A977895A188A2AD9AB0B8AEBFC5C3CFD3D8DEE1
EAEDEEFAFBFBFDFCFCF1F1F1E6E7E7DBDDDDD1D2D3C7C8C9BDBFC0B4B6B6ABADAEA2A4A5
9A9C9C9293948A8B8C828384
7475766D6F7067696A606365595D5F5357594C5153464B4E3F4548383F4232393D2B3437
2F393C343D413840443C44483E474B3E474C3C464C3B464D3A474E36464F364751344751
334752334852324854324A55334C58364F5B39535F3C5662415B68445F6C4964714C6975
526F7B5875815D7B8763818D6D8A957B959F89A0AA9AADB5ACBBC1BFC9CED2D8DAE4E6E8
F7F6F7FBFBFAF1F1F1E8E8E8DEDFDFD4D5D6CBCCCCC1C3C3B9BABBB0B2B2A8A9AAA0A1A2
98999A919293898A8B828384
7576776F7071696B6C6365675D6062575A5D5155584B5053454B4E4046493A4145363D41
353D413740443B43473E474B40494E424B50404A503F4A513F4C533C4B533D4D553B4D56
3C4E573B4F593C505B3D525D3F555F425863465C66495F6A4F656F536973596F795C737E
637983687F886D848E748B947F959D8DA0A79CACB2ACB8BDBDC5C9CED2D5DFE0E1F0EEEE
F9F8F8F0F0F0E7E7E7DEDFDFD6D6D6CDCECEC4C5C6BCBDBEB4B5B6ACADAEA4A6A69D9E9F
9697988F909188898A818283
7576777071736B6C6E6568696063655B5E6056595C5155584C5153474D5043494C3F4649
3C44473C44483F474B414A4E454D51464F54464F5545505545515843515944535B45545D
45555E4657604859624A5B654B5D674F616A53656E5768715C6D7661737B6779816C7E87
73848B76878F7B8D9484959C909FA49DA9AEABB5B9BBC1C4CACDCFD9D9DAE8E6E6F3F2F1
F0F0F0E6E6E6DDDEDED5D6D6CDCECEC5C6C6BEBEBFB6B7B8AFB0B0A8A9A9A1A2A39A9B9C
9495958D8E8F878889818282
7677787173746D6E70686A6C6366685F62645A5E60565A5C5256594E53564A5053474D51
454B4F434A4E434A4E464D514850554A53584C555A4C565B4D575D4C585F4D5A614F5C63
4F5D6552606753616954636B57666E5B6A715F6D7564727968767D6E7B827581887A868C
7F8A8F828E93889499939EA29CA6A9A8AFB3B7BBBEC6C8C9D3D3D3E0DEDEEDEBEAECECEB
E3E3E3DBDBDBD3D3D4CCCCCCC4C5C5BDBEBFB7B7B8B0B1B1A9AAABA3A4A59D9E9F979899
9192938B8C8D868787808182
7777787374756E70716A6C6E66696A6265675F62645B5F61575B5E54595B5156594F5457
4D53564B51554950544951544D555950585D535B60545C61545E63545F655661675A656B
5C676D5D686F5E6A71606C73636E756772786B757B707A7F747D827982877F878C838B8F
888F928891958F989B99A1A3A3A9ACB0B4B6BFC0C1CDCCCCDAD7D7E3E1E1E5E5E4DDDDDD
D6D6D6CFD0D0C9C9C9C2C2C3BCBCBDB6B6B7B0B0B1AAAAABA4A5A59E9FA0999A9B949595
8F8F908A8A8B858586808081
7778797475767072736D6F70696C6D66696A6366686063655D61635A5E61585C5F565B5D
54595C53585B51575B51575B52595D555C615960655C63685D656A5D666B60686E636B71
656D736870756972786B73796E767B72797F767D817B81857E848784888B868B8E8E9193
8F93969297999B9FA0A3A6A8AEB0B1BABABAC5C4C4D2CFCEDCD9D9DBDBDBD6D6D6D0D0D0
CACACAC4C4C4BEBEBEB8B9B9B3B3B4ADAEAEA8A9A9A3A4A59E9FA09A9A9B959696909192
8C8D8D8888898384857F8080
78797A7576777273756F71726C6E706A6C6D676A6B6567696265676064665E62645D6163
5B60625A5F62595E61595F625960635E646860666A62686D636A6F666D726A70756E7478
71777B71777C72797D767B807A7E827B7F837E828582858785888B898B8C8B8E8F939494
949597999B9BA0A1A2A8A9AAB3B2B2BDBBBBC3C2C2D1CFCFD1D0D1CBCBCBC7C7C7C2C2C2
BDBDBDB8B8B8B3B3B4AEAFAFAAAAABA5A6A6A1A1A29D9D9E99999A9595969191928D8E8E
898A8B8686878282837E7F80
78797A7677787475767273746F71726D6F716B6D6F696C6D676A6C66696A646769636668
62666861656761656861656862666A63686C666B6E686D716C71756F757973777B75797D
777B7E787C7F7B7F827D80837E80827E808382848685868787898A8A8B8B8F9090939394
9897979D9C9CA3A3A3ABABABB2B1B1BAB9B9C0C1C1C6C5C5C0BFC0BBBBBCB7B8B8B3B4B4
AFB0B0ACACACA8A8A9A4A4A5A0A1A19D9D9E999A9B9697979393949090918C8D8E898A8B
8687888384858181827E7E7F
797A7B7778797677787475767274757172746F71726E70716C6E706B6D6F6A6D6E696C6E
686B6D686B6D686B6D686B6E696C6F6A6E706C70726E727575797B787B7F797B7E7C7E80
7E80837E80837F80837F80837F81838283858586878687888B8B8B8D8D8D919090949393
9897979C9C9DA0A1A2AAAAAAAEAFAFB3B3B3B4B5B4B1B1B1AEAEAFABABACA8A8A9A5A6A6
A2A3A39FA0A09D9D9D9A9A9B9798989495969292938F90918D8D8E8A8B8C888989868687
8484858182837F80807D7D7E
7A7B7B787A7A7778797677787576777475767374767274757173747072737072736F7173
6F71726E71726E71726E71736F727370737571747673767876797B787B7D7B7D7E818283
8183848081838182848082848082848284858385858586878889898A8A8A8D8D8D8F8F8F
9293939B9B9B9E9E9EA2A2A2A1A2A2A0A1A1A0A0A19F9F9F9D9D9E9B9B9C99999A979798
9596969394949192928F90918E8E8F8C8C8D8A8B8B88898A878788858687848485828383
8181827F80807E7E7F7C7D7D
7A7B7C7A7A7B797A7B79797A78797A777879777879767778767778767778757678757677
75767775767775767775767775767875777876787977797A787A7B7A7B7C7B7C7E7D7E7F
7E7F807E7E807E7F807E7F807F80818383838484848585868787878888888989898B8B8B
8D8D8E9090918D8E8E8E8E8F8E8E8F8D8E8E8D8E8E8D8D8E8C8C8D8B8B8C8A8A8B89898A
8888898787888687878586868485858384858283848282838181828081817F80817E7F80
7E7E7F7D7D7E7C7D7E7B7C7D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.511074 0.488926 0.732558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(112) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
92838292838192838192828091828091828091817F91817F91817F90807E90807E90807E
907F7D907F7D8F7F7C8F7E7C8F7E7C8F7E7B8F7D7B8F7D7A8F7D7A8F7C798E7C788E7A77
8F7C798F7D7A8F7D7B8E7D7B8E7D7B8E7D7B8E7D7B8E7C7A8D7C7A8D7C7A8D7C7A8D7C7B
8D7D7C8E7E7D8E7F7E8E807F8F81808F818090828190838290848491868692878793898A
958C8D938989938786928685928584928584928584928583928483928483928483928483
928482928482928482928482
92838192828091828091817F90807E90807E8F7F7D8F7E7C8F7E7B8E7D7B8E7C7A8D7C79
8D7B788D7A788C7A778C79768C78758B78758B77748B76738B76728B75718B746F8B736E
8B75718B75728B76748B76748A77748A7674897673887573887573887473887574887575
887776897978897A7A8B7C7C8B7E7D8C7F7F8D80808E82838F8586908889928B8C948F91
959193948C8D92898A928888918787918686918685918584918584918584928483928483
928483928483928482928482
92838191828090817F90807E8F7F7D8F7E7C8E7D7A8D7C798D7B788C7A778B79768B7875
8A77748A767389757189747088736F88726E87716D87706B876F6A876E69876C67866B65
876D68876F6B876F6C87706D86706D86706D856F6D846F6E856F6E856F6E846F6F857171
867373867575877777877979887A7B897D7D8A7F808B82838D86878F898B928D90959397
959295938E90928B8C91898A918888918787918686918685918585918584918584918483
918483928483928483928482
92828191817F90807E8F7F7D8E7D7B8D7C7A8C7B788B79778B78758A7774897672887471
87736F87716D86706C856E6A846D69846C67836A6583696482686282666182655F83645D
836761836864836965836A67836A67826A68826B69826B6A836B6A836C6B826D6C836E6D
836F6F847171847273847576857879877B7C887E808A82848C86888E8A8D918F92949498
939195928E91918C8E908A8B90888A908788908787908686908686908585918584918584
918483918483928483928482
91828090817E8F7F7D8E7E7B8D7C798C7A778B78768A777489757288747087726E86706C
856E6A846D68836B668269648167628066607F645E7F625C7E615A7E5F597E5E577F5E56
7F605A7F625D7F635F7F64617F65627E65637E66647E66657E67657E67667E69687F6A6A
806C6C806E6E817071817373837677847A7B867D7F8881838A85888C8A8E909094929499
919195908E918F8C8F8F8A8C8F898A8F88898F87888F86878F8686908585908585908584
918484918483928483928482
91828090807E8E7E7C8D7C7A8C7A778B787589767388747187726F85706C846E6A836C68
826A658168637F66617E645E7D625C7C5F597B5D577A5B547A59527958507A574F7B574F
7C5A547C5C577C5E597B5F5B7B605D7B605E7A605F7A605F7A61607A62617B64637B6565
7B67677C6A6A7C6C6D7D6F707F7474817778837B7D857F828784888A8A8E8E9196909399
8F90948E8D918E8B8F8E8A8D8E898B8E88898E87888E86878F86878F86868F8585908584
908484918483918483928483
9181808F7F7D8E7D7B8C7B788B787689767388747086726E856F6B836D69826A66806863
7F66617E635E7C615B7B5E58795C5678595377575076544D74514A744F47754E45775149
78554F785752785954785A56775B58775B58765B59765B5A765C5B765C5B765D5D765F5F
776262776565786868796B6C7B70707D74757F787A827D7F85838788898E8C90968D9196
8C8E938C8C908C8B8E8C898C8C888B8C888A8D87898D86888E86878E86868F85858F8585
908484918484918483928483
91817F8F7E7C8D7C798B79778A777488747186726E846F6B836C68816A657F67627E645F
7C615C7A5F59795C5677595376564F74534C735049714D456F49416C453C724A41765048
76524B75534E755450745551745552735553725553725554715554715555715756715959
715B5C725F60736364746768766C6D7971737C76787F7B7E82818586878C8A8E948A8E93
8A8C918A8B8F8A8A8D8A898C8B888B8B878A8C87898C86888D86878E86878E85868F8585
908585908584918483928483
90817F8E7E7B8C7B788A787588757286726F846F6C836C688169657F66627D635E7B605B
795D57775A5476575074544D725149704D456F4A426D463D6A4239694036764C43754E46
744E48734F49714F4B71504C70504D6F504E6E504F6E4F4F6D4F4E6C4E4F6C50506B5253
6C56576D5A5B6E5F606F636472686A756E707873757C797C7F7E82828489868A90878A8F
878A8E87898E88888C88888C89878B8A878A8A87898B86888C86878D86878E85868E8585
8F8585908584918483928483
90807E8E7D7B8C7A7789777487747085706D836D69816A657F66627C635E7A605A785C57
76595374554F72524B704F476E4B436C473F6B443B694037663C3171453A7A4F44744C43
714B446F4A456E4A466D4A476C4B486B4B496A4A4969494968494967494A674B4C674E4F
6852536956586A5B5C6C5F616F6567726B6D75707379767A7C7C8080818683868C83878C
84878C85878C86878B87878B87878A88868A8986898A86888B86888C86878D85868E8586
8F8585908584918484928483
90807E8D7C7A8B797689767286726F846E6B816B677F67637D635F7A605B785C56765852
73554E71514A6F4D466D49416B463D694239673E3463382D6C3F34764A3F74493F714840
6E47406C46406A464169464268464467464566454565444464424364444563464863494B
644E50655355665859685D5F6B62656E696B726F7276747879797D7C7D827E818680858A
81858A82868B83868B85868A86868A87868A8886898986898A86888B86878C85878D8586
8F8585908584918484918483
90807E8D7C798A787588747185706D826C698069647D65607A615B785D5775595373554E
70514A6E4C456B484069443C674037653C3263382E683B307244397044396F443A6D433C
6A423B68413B66413C65413E64423F6342406240406241416141426045455F4748604C4D
604F50615254625558645B5D6861636C676A706D7073727677777B7A7B807C7F857D8287
7F838980848A81858A83858A84858A85868A8786898886898986888B86888C86878D8586
8E85868F8585908584918483
8F7F7D8C7B798A7774877370846F6B816A667E66627B625D785E5876595473554F70514A
6D4C456B484068443B653F36633B3161362C5D3126683A2E6D3F336C40366B4037694038
663E37633C36613C38613D3B603E3D5F3E3D5F3E3E5E41405D44445D48475D4D4C5E5050
5C4F505D52535E5657615B5C6561636966686E6C6F71717574767A777A7F797D837B8086
7D83897D83897F848980848A82858A84858A8686898786898986898A86888B86878D8587
8E85868F8585908584918483
8F7F7D8C7B7889767386716E826D697F68647C645F795F5A765B5573565070524B6D4D46
6A484167433B643F36613A315F352B5C30256133276E3F326B3E33693D33673E35653C35
623A335F38335D38345D3A385B3A39593A3A5D42425E47465E4B4A5E4E4D5E4E4E5B4E4E
5950505A55565A56575E595B625F616765676C6B6F70717572757A74787D767B81777E84
7980877A81887C83897E838A80848A83858A85868A86868A8886898986888B86888C8687
8E85868F8585908584918483
8F7F7D8B7A7788757285706D816B687E67637A625D775D5874585271534D6E4E486A4942
67443C643F37613A315D352B5B3026582B2065372A6B3D31693D32663B32653C34623A33
5F38315B36315A36335737365B403E5F4846634E4C5F4C4B5D4E4C5C4D4C5A4C4B5A5151
5B53545A54565954565B595B605F616565686A6A6F6E717570747972777C73797F747C82
767F8677818A7982897C838A7F848A81858B84868A86868A87868A8986898A86888C8687
8D86868F8585908584918483
8F7F7C8B7977877471836F6C806A667C6560795F5B755A5572554F6E504A6B4B4468463E
644038613B325D352B592F25572B21582A1F693A2D693C30673B31643B32623B335F3932
5C3630593631593936593D3B6147456047455E47455C48465A4745584644564645574A4A
574B4B5850515B54555E5B5D605E6164636768696E6C70746E74786F757B70777E717A81
737D8474808876808779828A7E858B81868B83868B85878B87878A89878A8A86898C8688
8D86878E8586908584918483
8E7E7C8A7976867370826E6A7E68647B635E775D5873585270524C6C4D4669484065423A
623D345E372E59302651271C52251A5F30246D3E31683C31653A306239315F39325D3832
5A37315A3B375D423F604946634D4A5E4A475B4745594644574241544241534242534545
534747554E4E5750515B56595F5C5F636265686A6E6B70746C73786C73796D757C6E787F
707C83727E8675818979838C7E878D80878D83878D85878C87878B88878A8A87898B8688
8D86878E8586908585918483
8E7E7C8A787585726F816C697D666279605C755B567155506D4F496A4A4366443D633F37
5F39315C342A572D2351261B5A2E226A3C2F6A3E31653B306239315F3A325D39335B3732
583732583B375B413E5C45435C47455A4846584846574745554544534543524645524948
524C4C544F4F5650525955585D5B5E626265696C6F6A70746A72776A72786A747B6B767E
6D7A826E7C846E7C8577838B7E888F80888E83898E85888D86888C88888B8A878A8B8789
8D86878E8686908585918483
8E7D7B89777584716E806B677B6560775E5A7359546F524D6B4D46674740644139603C33
5D362D5B3128592D235E3023693A2C6D3F32663B30623A305F39315C39325B3933583833
563934573B3759413D58423F5744415644425444425343425142414F42414E44434E4646
4F494A504C4E53515356585A5C5F6162676A686F726A737668727767717868727A69757E
6B79816C7B846C7D877A88917E8A91818A91838A9085898F86898D88888C8A888B8B8789
8D87888E8687908585918484
8D7D7B88767483706D7E69667A635F755C587056516C504A68494364433C613E365E3830
5B332A592F24592C205C2F225F332861372C60382E5E38305B3932593932573933563833
543834543A36543D3A543F3D53413F52413F51403F4F403F4D3F3E4B3F3F4A40404A4343
4B46474C4A4C504F52545659595D605E6467626A6E66707466717765707865717A67747D
697881697A846A7C877B8A937F8C94818C92838B91858B90868A8F88898D8A898C8B888A
8D87898E8687908585918584
8D7D7B887673826F6C7D686478615D735A556E534E694D476546406140395D3A325A342C
582F25562B2056291D572A1F582D235931285B352C5A362F583731563731543732533632
523632513835513A38513E3B503E3D4F3E3D4D3C3C4B3D3C493C3C473C3C473D3F464042
4844474B484C4F4F52535559585D615C63675F686D636D73636E75626E7663707965747D
677881697A85687B877B8A937F8C94818D94838C93858C91878B90888A8E89898D8B888B
8C87898E87878F8686918584
8D7C7A877572816D6A7B6663765F5B7158536B504B66494462433C5D3C355A362E563027
542A2152261B52251A51261C532B2256302858332B56352E54352F5235305135304F3430
4E35314D37334D38354D3A394C3C3C4B3C3B493B3B483B3B463A3B44393B443C3E443F41
46444748474B4C4E5251555A555C615A61685D676E5F6B725F6C735F6D7661707964747D
677881697B856A7C87798891808E96828E96848E95858D93878C91888B8F898A8D8B898C
8C888A8E87888F8686918584
8C7C7A867472806C697A6461745D596E5551684E496346415E3F3959383155312A522B22
4F251C4D21164C21174C231A502B2353302853322B52342D50332E4F332E4D322E4C322E
4B322F4A3431493533493837493B3A483A3A46393944383943383941373940383B403C40
42414546474B4A4E524E545A535B6157616859656D5A676F5B69725D6C755F6F7862737D
6677816B7C8771818B7D8A93818F98849199859097868E95878D93888C90898B8E8B898C
8C888A8E87888F8686918584
8C7B798573717E6B6878635F725B576B524E654B465F433D5A3B3555342D502C254D251D
491E15471A11461B1348231B4D2C254F2F284F312B4E312C4C312C4B302C492F2B482F2C
472F2D46312E4533314637364639394538394336374136383F34373D34363C36393D3A3E
3F3F4443454A464B514B5259505A61535F6655626A55636C57666F5A68725D6C7760717B
6576816B7C8771828C7B8C968697A18A99A286929A868F97868E94888C92898B8F8B8A8D
8C898B8E87898F8686918584
8B7B798472707D6A6776615E6F585568504C6247435C3F3A563731502F294B2720472018
43191141180F421C1546261F4B2D264D2F294C302A4A2F2B492F2A472D29452C29442C29
432C2A422D2C4230304233344335374136384035373E35373C33363933363935393A393E
3C3E4440444A444B524A535A4D58604F5C64505E6751606953636D5666715A6A755E6F7B
637580687B876F808B77899480939E83939D84929A859097868E95878D93898C908B8A8E
8C898C8E88898F8687918584
8B7B7983716F7C6866745F5C6C5653654D495E4440573B3751332D4B2A2445221B3F1911
3C150C3A160E3D1D16432720492D27492E29482E29472D29452C28432A274129263F2827
3E28283E2A2A3E2D2E3F31323F33353E33363D33363B333639313536313536333837383E
3A3E443E444B424B5246505848545D4A58614B5A634C5C674F606B52636F5668745A6E79
5F747F657A856C7E8A738793798E9A7E909A81919A839098858F96878E93898C918A8B8F
8C8A8C8E888A8F8787918585
8A7A7882716E7A6764725D5A6A5451624A475A413D5337334C2E294525203E1C1637120B
320E0830110C371B16412722462D27472D29462D28442B27422A263F28253D27253B2625
3926263A29293B2C2D3C2F313C31343C32353B323639323536303434303533333835373D
373D433B434A3E4850414D5643505A44535D465661485A654A5D694E626E526773566C78
5C717E627783677A866E8490768A957D909B80919B829099858F97878E94898D928A8C8F
8C8A8D8E898A8F8787918585
8A7A7881706D786563705B5967514E5E4744563D3A4E332F4629253F201B371711300D07
290B072C120E351C18412924452D29452D29442C28422B273F29263C2625392524372425
35242536262737292B392D2F3A30333A3235393236373135342F34312F3430313832363C
343B4237404939454E3B49533D4C573F4F5B40535E435662465B674A5F6C4E6471536976
586F7C5D74816278846A818E7388957B929F7E929C81919A849098868F96888E938A8C90
8C8B8D8E898B8F8788918685
897977806F6D7764626D5A57644F4C5B4441513936482F2B402521381B1731120D2A0B06
270C092D1512361F1C452D28462F2A452E2A442D2A412B283C2726382423332121302021
2F202231242635292B372C2F3930333A33373833373632373230352F2F352E31372F353B
303942333E4734424C3545503749543A4D583C505C405561435966475E6B4B62704F6775
546C7B59727F5D7583667D8C7189967A94A17E939F81929C849199869097898E948B8D91
8C8B8E8E898B908888918685
8979777F6E6C7563616B5856614C4A57413F4D3533432A27391F1C3115122A0C08250805
1F080727131237221F48312B48322D46302C442F2C412C2A3D29283826263324252F2225
2E2225312628352B2D372E313931353B363A39363A3533393131362E2F352C30372C343C
2C37412F3C4630404B31424E334552354956374D5A3C5360405765445C6A47606F4B6574
506B7A55707E5A7483667F8E728C9A7A96A47E95A181949E84929B879198898F958B8E92
8D8C8F8E8A8C908889918685
8878777E6D6B7462606956545E4A48533E3C4832303C2523311916290E0C230805200706
1F0B0A2C19173C27234C35304A353048332F45312F422F2D3E2D2D3B2A2B3A2B2C36292B
372A2C3B2F303D34363F3739413C3F403E423B3A3F35363C3132382D2F362A303829323C
28333E2B3A452A3C48293D4A2B404E304654344C5A3A515F3E5664415A69455F6E496474
4D6979506D7D56728363808F728E9D7B99A77E96A381959F84949C8792998990968B8F93
8D8D908F8B8D908889918686
8878767D6D6B72615F6755535C4847503B3A432E2C361F1E2811101A01001B02011C0807
1F0E0E2C1B1A3E2A274F39334D37334A35324633314331304030303E2F303D2F313C2F31
423536463A3A483D3E484041454144403F443B3B4136363D3031382C2F372A31392A343E
2A37422C3E4A273C49233B4A2A41502F4756314A5938505F3C5564415A69435F6F466374
4A67784B6A7B517182618090718F9E7B99A77E97A38296A185959E88939B8A92988C9094
8E8E918F8B8D90898A918686
8778767C6D6B71605F6554535947464D3A383F2B2A301B1A1C0706150000190505180809
1D0F102E1E1C432E2A533D37503A374C38364734344433334233343F32343E32343E3336
413639443A3D463F424742454442464040453B3C4335373E30323A2C31392A323B2A3640
2C3A452E3F4B2E404C2C414F354856364C5A394F5E405664425A69445E6E436071446374
46657745677A507183628090738E9D7B98A77F98A58398A28697A089959D8C93998D9196
8F8F92908C8E91898A928786
8778777C6C6B70605E6453525846454B38383D2A292D1A191C08081C09091E0C0D211213
26181837252348332F56403B533E3A4F3C3A4B3A394739394336373F33353D32353C3337
3D3639403A3E423D414340444242473F40463A3C4334373E2F333B2B323B29323C293540
2A39452C3E4B2F414E3447543E4F5C3F5360415663465B69455D6C425F6F416071416274
41647742667A51738564829274909E7D9BA9819AA7859AA48899A28B979F8D959B8F9397
909093918D8F928A8B928786
8778767B6C6A705F5E6453525746454A38383C2A2A2D1B1B1D0B0B1E0D0E211112271818
30201F3E2C294C383458423E55413E51403E4E3E3E4A3D3E483D3F463C3F433C3F453E41
47414449444748454948464B45464B3F4148393B4333363E2F333C2B333D29323E273440
2737452A3C4A2D404F314654374C5A3B515F3E5665415A693F5B6C3F5C6F3E5E713E6073
3C61753F657A5274876986967591A07D9CAB829CA8879CA78B9BA48E9AA190979D919499
929195928E90928B8B928787
8778767B6C6A6F5F5E6353525746454A39383C2B2B2E1D1D200E0F2212122717182D1E1E
35252442302E503B3859443F5744415343414F41414C41424A40424941444944474B4649
4A474A4A484C49484D47474D41444A3C3E4636394131363E2E343D2C343E2B36412B3845
2A3B49293D4C293E4E2D4353324959354E5D3852623A55663B586A3B5A6D3B5D703B5E73
385E7440667C55778A698696718E9D7998A7859FAB8BA0AA8F9FA7919DA4929AA093979B
939396938F91938C8C938887
8778767B6C6B6F605F6354535747464A3A3A3D2D2D301F1F2211122516172B1C1C322222
3C2A29483432523E3B5A45415946445545445143444D43444B4244494246484347474348
4643484543494342484041473C3E45383B4233373F30343D2D333D2B343F2B36422B3946
2C3D4B2F42503044533046562E4858304A5C324E603552653756693A5A6E3A5C71375D72
365F75436A7F56788C658495718F9F7E9DAB90A9B492A6AF94A3AB95A0A7969DA296999D
969598959193948D8D938888
8778777B6C6B70605F6454545848474B3B3B3F2E2F3221222515162A1A1A2E1F1F362626
3F2E2D4A3735533F3C5945425847455546465145454E43454B4245484245464145444145
424045403F453D3D433B3B4237394034363E30343D2C323C2B323D29333F293542293745
2A3B492C3F4D2F4452334958364D5D3750613753643A56693A596D3A5B70365C70345D73
366077476E83587C8E6788997796A587A3B197AEB999ABB49AA8B09AA4AB9AA0A5999CA0
98979A979294958D8E948988
8778777C6D6B7061606555555949494D3D3D4030313424242717182B1C1C302122392829
41302F4A3836513F3C5744425847465648475246474E44474A4346474146444044413E43
3E3C423C3A4039383E36363D32343B2F323A2C303A292F3928303B27313E263340263543
273847293C4B2C41512F4657334C5C36506138546638566A37586C35596E335B70335C72
3963794A72865D80936E8E9E7F9CAA8FA8B49DB2BCA0B1B9A0AEB5A0A9AF9EA4A99C9FA2
9B999C999495978E8F958988
8778777C6D6C7162616556565A4A4A4E3E3F423233362627291A1B2E1F213325263A2B2B
4131314839384F3F3D5544435847465649495247484D4447494246454045413E433E3B41
3B393F37363D34343B31323A2E30382B2E37272C37252C38242D3A232F3C23313F233342
233646253A4A273F502B44552D485A2F4C5E31506331536730556A30576D2F5970305D74
3C677E50778B6285987493A386A1AF98AFBAA6B9C2ABBAC2A8B4BBA6AEB3A3A8ACA0A1A5
9D9B9E9B9597988F90958A89
8879777D6E6D7263626657575B4C4C50404144353538292A2C1D1E3123243628293C2E2E
4334344A3A3A504040564645584948584A4B5247494D4448484146433E433F3C413B393F
37363D33333A3030382C2E36292C35262A34232934222936212A38202C3B1F2F3E1F3141
203445213849243D4E2641532845582A495D2B4D612C50652D53692D566C2E5870346077
456E84577D906A8B9D7D9AA991AAB6A4B8C2B2C3CBB6C4CBB0BBC1ACB3B8A7ABAFA4A4A7
A09D9F9C9798999091968A89
8879787D6F6D7364636859595D4E4E5143434637383A2B2D2E2022332627392B2C3E3031
433536483A3B504141564645594948584A4A52484A4B4448464145403D423C394037363D
33333A2F30372B2D35282A332428322227311F26321D26341C28361C2A3A1C2D3D1C2F40
1D33441E3749203B4D223F5224425625465B274A5F284E642A51682A556C2E5A723A657C
4C74895F83967494A489A4B19EB3BEB1C2CAC2D0D7C0CCD2B7C0C5B1B7BBACAFB2A7A7A9
A29FA19E98999A9191968B8A
887A787E6F6E746564695B5A5E5050544546483A3B3C2E2F30232535282A3B2D2F3F3233
4336374A3C3D50424354464656494955494B50484B4A4448433F453E3B4138373E33333B
2F2F372A2C342628312326301F242E1D232E1A222F192432192635182938182B3C192E40
1A32441B35481D394C1E3D5120415622455A23495F254D642651682B576E335F76426C82
557C906B8C9E809DAB95ADB9A9BCC6BCCBD2CBD7DDC4CED3BCC4C8B6BABEAFB1B4AAA9AB
A5A1A2A0999A9B9292978B8A
897A797F706F7566666B5C5C6152525648484B3D3E403234342729392C2D3D3032413436
45393A4A3E3F4F424352464654484A50474A4D4649474347413E443A394035343C2F3038
2A2B3426283121242E1D222C1A202B181F2D161F2E152130142434152737152A3B162D3F
1731441834481A384C1C3D511E40551F445A20485F224C642651692C597137647B4A7389
5F84977594A58AA4B39FB5C0B5C5CEC9D4DBD3DDE2C9D1D5C1C6CAB9BDC0B3B3B6ACABAC
A7A2A4A19A9B9C9392978B8A
897B798071707668676D5E5E635555594B4C4F4142443638392B2D3D3031403436433739
463A3C493D3F4D42444F45474F46494C44484A44484441473E3C4237363E3031392B2D35
25283120242E1C212C181F2B151D2A131C2B111C2C101F2F11223411253712293B132B3F
142F4316334818374C193C511B40561D445B1E4860214D6527536C315E76416C82557D91
6C8D9F819EAE96AEBBADBFC9C4D1D8D9E3E7D9E2E6CDD4D7C4C9CCBCBEC1B5B5B7AFACAD
A8A3A4A39B9B9D9393988B8A
8A7B7A8172717869696F61606558585C4E4F524546483B3D3E313340343643373A453A3C
473C3E4A3F424C43454D45484C4548494348474348413F453A394132333C2C2E38262A34
2025301B212D161E2B131C2A0F1A290D19290C1B2B0C1D2F0D21330E24370F283B102B3F
122F4414334815384D173C521940571B455C1E4A62234F682C59713A667D4C758B628699
7897A88DA8B6A3B8C3BACAD2CFDADFDEE7EBD8DFE2CFD5D8C7CACCBFC0C2B7B6B8B0ADAE
AAA4A5A49C9C9E9493988C8B
8A7C7A827372796B6B716363685B5B60525357494B4D404243363843383A463B3D473D40
483F424A41444C43474D46494C464A4944494441473E3E453637402E313A272C36202632
1A222F151E2C111B2A0D192909172807172807192B081C2F0A20330B24380D273C0E2B40
102F4512344914384E163C531841591C465E214D6528556D3561794770865B80947091A3
86A1B19AB2BEB1C3CDC9D5DBDBE3E7E5ECEFDBE0E3D1D5D8C9CACDC0C0C2B9B6B8B2ADAE
ABA4A5A49C9C9E9493988C8B
8B7C7B8375747B6D6C7365656B5E5E6356575B4E4F5346484B3F41483D40493E414A4043
4C43464D44474E46494F484C4D474C49464B4442493D3E463337402B303B242A361B2432
151F2E0F1C2B0B192908172904152801152802182B041C300720350925390B283D0C2C42
0F314611354C143A51173F571B455D204A6327536B325E76436C82567C906A8C9E809DAD
95ADBAABBEC9C2CFD7D7E0E5E9F0F3EAF0F3DDE1E4D3D5D7CACACCC1C0C1BAB6B7B2ADAE
ABA5A5A59C9C9F9493998C8A
8B7D7B8476757D6F6E7668686E6161675A5A605354594C4E5246484B40424C42444D4447
4E46494E464A4F484D514A4E4F4A4F4C494F46454C404149373A442E333F232C39182433
101F2F0C1B2B08192A04172A00152900172B011A2F041E3306223808263C0A2B400C2F45
0E324911374F163D551A435B1F4962275169325C74406A8052788D66889B7B98A990A9B7
A6BAC5BCCBD3D2DCE1E4EAEDF0F5F7E8ECEEDEE0E2D4D5D6CACACBC2C0C1BAB6B7B3ADAD
ACA4A4A59C9B9F9493998C8A
8C7D7C8577767F7170786A6A7164646B5E5E6457595E5153574C4E50454850464952484B
524A4D534B4E534C50544E52534E534F4C5249484F43444C3C3E4832384326303E1C2939
1524341020320B1E31071C30041B30041D3206203507243909273D0B2C420C2F460E334A
12384F163D551B445C214A62295269335C7341697F51778A6486987995A68DA6B4A3B7C2
B9C8D1CFD9DFE1E7EBF1F4F7F5F8FAE8EAECDDDEE0D3D3D4CAC8C9C2BEBFBAB5B6B3ACAC
ACA4A3A59B9B9F9392998C8A
8C7E7D8678778072727A6D6C7467676E6162695C5D6357585D5253584D4F544A4C564C4F
564E51574F535851555A5357565257514E544B4A5144454E3E404A363B462C354224303F
1D2C3C192A3B1327391026390D25390D273B0E293D0E2C41102F4512334914374D173B52
1B405720465D264D642E556B375E7443697E5276896384957793A38BA3B1A0B4BFB6C5CE
CDD6DDE0E6E9EFF3F5FBFDFEF4F6F7E7E8E9DCDCDDD2D1D1C9C6C7C1BDBDB9B4B4B2ABAB
ABA3A2A59B9A9F9392998B8A
8D7F7D8779788274737D6F6F776A6A7265656D6061685C5D6357595F53555A50525A5153
5B52555C54575C55595C565A5854595451574E4D54494A524346503B414D323C4A2C3947
2836452534451F31431D31431B30431A31441A34471C374B1F3B4F22405424445826475D
2B4D62315368395B704163774B6D805778896785957993A28CA2AF9FB1BCB4C2CACAD3D9
DFE4E7EEF1F3FDFFFFFCFDFDEFEFF0E4E3E4DAD8D8D0CECEC8C4C4C0BBBBB8B2B2B1AAA9
ABA2A1A59A999E9291988B8A
8E7F7E897A798476757F71717A6D6D7568697164656D6061685D5E64595B6055585E5456
60575A61595C60595D5F595D5D585D5A575D5453594F4F57494B544046523B445037414F
323F4E2F3D4D2B3B4C2A3C4C293C4D283E4F2941522C445630485A334D5F355163395568
3E5B6E4562744D6A7B5471825F7B8B6C86957C93A18DA1AD9FB0BAB3C0C7C8D0D5DDE1E4
EEEFF1FDFEFEFFFFFFF4F3F4EAE9E9E0DEDED6D3D4CECACAC6C1C1BEB8B8B7B0AFB0A8A7
AAA0A0A499989E9291988B89
8E807E8A7B7A8577778173737D6F6F796C6C7568697165666E62636A5F61685D5E645A5C
665D60675E61665F62655F63635E635F5C615A585E55555C50525B494F59464D59424B57
3E49563C4855394756384756374858394B5A3B4E5E3E5161425666455A6A495F6F4E6474
546B7A5B728162788769808E7489978195A190A1ACA1AFB8B4BEC5C7CDD2D8DCDFEAEAEC
FBFBFBFFFFFFF6F5F5EDEBEBE4E1E1DBD8D8D2CECECAC5C5C3BDBDBCB5B5B5ADADAFA6A5
A99F9EA398979D9190988A89
8F807F8B7C7B8779788375757F72727C6F6F796C6C75696A7367687065666E64656E6465
6E65666D65676C65686C65686A64686863686360665F5D645B5B635559625257614E5560
4C545F4A535F4854604855614956634B58664D5B69505F6C5563715968755F6E7B637380
6A7A8670808C7686927E8E988998A198A3ACA7B0B7B7BDC3C7CBCFD8D9DBE9E7E8F8F5F4
FFFEFDF7F5F5EEECECE6E3E3DEDADAD6D1D1CEC9C9C7C1C0C0B9B8B9B1B1B3AAAAADA3A3
A79D9CA296959D908F988A88
8F817F8C7D7C887A798577778274747F72727C6F6F796D6D776B6C756A6B74696A74696B
746B6C756B6D746C6E736B6E726B6E706A6E6D686D69676C66666C62636B60626B5E616A
5C616A5A616B5B626C5B626D5B636E5D65705F6873626C7767707B6C7680717B8677828D
808992848D9689929B939BA39FA6ACABB1B6B9BCC1C8C9CCD7D6D7E5E2E3F2EFEFFCFAFA
F9F8F8EFEDECE7E3E3DFDBDAD7D3D2D0CBCAC9C3C2C2BCBBBCB4B4B6AEADB0A7A6ABA1A0
A69B9AA195949C8F8E978988
9081808D7E7D8A7C7B8779788477768274747F72727D71717B6F707A6E6F796E6F796E6F
796F707B71727B72747B7274797174777174767175747075736F746F6E746E6E746D6E75
6B6D756B6E766B6E776B6E776C70796E737B71757E747981787D857D818983888F898D94
8E919793979C9A9EA3A5A7ACAEB0B4B9BABDC7C6C8D5D2D3E2DEDEEEE9E9F9F5F5F8F5F5
EEEBEBE6E3E2DEDADAD7D2D2D0CBCACAC4C3C4BDBCBEB6B5B8B0AFB3AAA9AEA4A3A99E9D
A49997A093929B8E8D978987
9081808D7F7E8B7D7C897B7A8679788477768275758174747F73737E72727E72727D7273
7E73747F747680767780777981787A81797C80797C7E787D7D797D7B787D7C797E7D7A80
7D7B807D7B817C7B817C7B827D7D847F7F8581818885858B88888E8D8D91919095959498
9A999C9B9B9FA2A3A6ACACAEB6B5B7C3C0C2D2CDCDDED8D8EBE4E3F3EDEDF4F0EFEBE8E7
E4E0DFDDD8D7D6D0D0D0C9C9C9C3C2C4BCBCBEB6B5B9B0B0B4ABAAAFA5A4ABA09FA69B9A
A296959E92909A8D8B968887
9082808E807F8C7E7D8A7C7B887B7A877978857877847776837676827575817576817676
827777837879847A7B867C7D877F80877F81888083888184888185878186888387898488
8984898B868A8B878C8B878C8C888D8F8A8F918D919490939792959B96999D989BA39E9F
A5A0A2A9A4A6B2ACADBAB5B5C5BEBED1C9C8DAD3D2E6DDDCEEE8E7EDE8E8E7E2E1DFDAD9
D9D3D2D3CCCCCDC6C5C7C0BFC2BAB9BDB5B4B8AFAFB4AAA9B0A6A5ACA1A0A89C9BA49897
A094939D908E998C8A968886
9182818F817F8D7F7E8C7E7D8A7C7B897B7A887A79877979867978857878857878857979
857A7A867B7B887D7D897F808D838492888A91888A90878A8F878A90898D938C8F978F92
989093978F939690939A92959D94969D94969D94979F9698A1999AA49B9BA59D9DABA2A2
ADA4A4B3AAA9B9B1B0C1B9B8CBC2C1D5CBC9DBD2D1E6DEDDE5DFDEDED8D7D9D2D1D3CCCB
CEC6C5C9C1C0C4BBBABFB6B5BBB2B0B6ADACB2A9A7AFA4A3ABA09FA89C9BA49997A19594
9E91909B8E8C988A89958785
9182819081808E807F8D7F7E8C7E7D8B7D7C8A7C7B897C7B897B7B887B7B887B7B887C7B
897C7C897D7D8B7F7F8C81828F8485928889968C8D978D8F998F919A91939C92949D9496
9E94969F9597A19798A29798A19696A09596A39898A49998A59A99A79C9AABA09FAEA3A2
B2A7A5B7ADABBEB4B2C5BCBBCCC2C1D2CAC9D9D2D1DCD5D3D5CDCCD0C8C7CBC3C2C6BEBD
C2B9B8BEB5B4BAB1AFB6ADABB3A9A7AFA5A4ACA1A0A99E9DA69B99A49896A195939E9290
9C8F8D998C8A978988958685
9183819082809081808F807F8E807E8D7F7E8C7E7D8C7E7D8B7E7D8B7E7D8B7E7D8B7E7D
8B7E7E8C7F7F8D81808E8282908585938787968A8B9A8F8FA19696A39899A29697A29797
A4999AA59899A49898A39797A39797A49898A69A99A79B9AAA9E9CAC9F9DAEA2A0B1A4A2
B4A8A6B7AEACBCB2B1C4BBBACAC1C0CDC5C4CDC5C3C8BFBEC4BBBAC1B7B6BDB3B2BAB0AE
B6ACABB3A9A7B0A6A4AEA3A1ABA09EA89D9BA69A99A49896A195949F93919D908F9B8E8D
9A8C8A988A88968886948684
9284829183819182819082808F81808F817F8E807F8E807F8E807F8E807F8E807F8E807F
8E80808E81808F8281908382918584938686958988988C8B9B8F8E9E9191A19493A59997
A59998A49796A59897A49798A29696A39796A39795A49896A79A98A89B99AA9D9BAB9F9D
AEA2A0B6ABAABAB0AEBDB3B1BBB1AFB9AFAEB8AEACB6ABAAB4A9A7B1A6A5AFA4A2ADA1A0
AA9F9DA89D9BA69A99A59897A39695A19593A093919E91909D8F8E9B8E8C9A8C8B988B89
978988968886958685948583
928482928382928381918381918281918281908280908280908280908280908280908281
908281908281918382918482928483938584948685958887978988988B899A8C8B9B8D8C
9C8E8D9C8E8D9C8F8D9C8F8E9E918FA19491A29492A39693A49795A59896A69997A89A98
A99D9BAB9E9CA79B99A79B99A79A99A69A98A59997A49896A39695A29593A19492A09291
9E91909D908F9C8F8D9C8E8C9B8D8B9A8C8B998B8A988A89988A88978987968886958786
958785948684948583938483
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.511074 0.732558 0.732558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(135) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
B1978CB1968CB1968BB1968BB0958BB0958AB0958AB0948AAF9489AF9489AF9388AF9388
AE9388AE9287AE9287AE9186AE9186AD9185AD9085AD9085AD9084AD8F84AD8F84AD8F83
AD8F84AD8F84AD9084AD9084AD9085AD8F84AD8F84AC8F84AC8F84AC8E84AC8E84AC8F85
AC8F85AD9086AD9186AD9187AD9288AE9288AE9389AE9389AE948AAF958CB0968DB0988F
B19990B0978EB0968CB0968CB0968BB0968BB0968BB0968BB0968BB0968BB0968CB1968C
B1968CB1978CB1978CB1978D
B1968CB1958BB0958AB09489AF9388AF9388AE9287AE9186AD9186AD9085AC8F84AC8F83
AC8E82AB8D81AB8C81AA8B7FAA8B7FA98A7EA98A7DA9897CA9887CA9887BA8877BA9877A
A9887BA9887CA9887CA9887CA8887DA8887CA8877BA7867BA7867BA7867BA7867BA7867C
A7887EA8897FA88A80A98B81A98C82AA8D83AA8E84AB8F86AB9188AD938AAE968DAF9991
B09A92AF978EAE958CAE948AAE948AAE948AAE948AAE948AAF948AAF948AAF958AB0958B
B0968BB0968BB1968CB1978C
B1968CB0958BAF9489AF9388AE9287AD9186AD9085AC8F83AB8D82AB8C81AA8B7FA98A7E
A9897DA8887CA7877BA7867AA68578A58477A58375A48274A48173A48072A47F72A47F71
A47F72A48073A48074A48174A48175A48075A38075A38075A38075A37F75A38076A48278
A5837AA5857BA6867CA6867DA6877DA6887EA68A80A78C82A98E85AA9188AC948CAE9891
AE9890AD958CAC938AAC9289AC9288AC9288AC9288AD9288AD9388AE9389AE9489AF948A
AF958AB0958BB0968BB1968C
B1968BB0948AAF9388AE9287AD9085AC8F84AB8E82AA8C81A98B7FA88A7DA7887CA6867A
A68578A58376A48275A38073A27F71A17D6FA17C6EA07A6C9F796B9F78699F77689F7768
A0786AA0796BA0796CA07A6DA07A6DA07A6EA07B70A17C72A27D72A17D73A17E74A27E74
A27E75A37F76A38077A38178A38379A3847BA4867DA5897FA68B82A88E85A99189AB948C
AB938BAA9289AA9187AA9086AA9086AA9086AB9086AB9186AC9187AC9287AD9288AE9389
AE9489AF958AB0958BB1968C
B0958BAF9489AE9287AD9186AC8F83AA8D81A98B7FA8897DA7887BA68679A58477A48275
A38073A17E71A07D6F9F7B6C9E796A9D77689C75669B73639B71619A70609A6F5F9A6F5F
9B71619B72629B72649B73659B74679C74689C756A9C766B9D776C9D786D9D796E9E7A70
9F7B709F7B719F7D72A07E74A07E75A08177A18379A2857BA3877EA48A81A78E86A89189
A88F87A78E85A78D84A78D83A88D83A88E83A98E84A98F84AA8F85AB9086AC9186AD9287
AE9388AF9489B0958BB1968C
B0958AAF9388AD9186AC8F84AA8D81A98B7FA8897DA6877AA58578A48275A28073A17E70
A07C6E9E796B9D77699C75669A7363997060986E5E976B5B956958956756956655956756
966959976B5C976C5D976D5E976D60976E61976E62976F63987064987166997368997469
99746A9A756B9A776C9A786D9B7A6F9C7B709D7D739E80769F8379A1867DA48B83A58D85
A48B82A48A81A48A80A58A80A58A80A68B80A78C81A88C82A98D83AA8F84AB9085AC9186
AD9287AE9389AF958AB0968B
B0958AAE9287AD9085AB8E82A98B7FA8897DA6867AA48477A38174A17F71A07C6F9E7A6C
9D77699B7566997263986F5F966C5C956A5993675692645290604E8E5D4B8E5B48905E4B
92625293645593665693665893675993675A93675B93685C93685C93685D93695E936B60
946C61946E62956F6495716696746897766A98786C9A7A6F9C7E749E8278A0867DA0877E
A1867CA1867CA1867BA2867CA3877CA4887DA5897EA68B80A78C81A88D82AA8E84AB8F85
AC9186AD9288AF948AB0968B
B0948AAE9287AC8F83AA8C80A8897DA6877AA48477A38174A17E719F7B6E9D796A9B7667
9A7364987060966D5D946A599366559163528F604E8D5C498A584586513D8954408E5B48
8F5D4C8F5F4F8F60518F60528E60528E60538E60538E60538E5F538D5F548D60548D6156
8D63588E655A8F685C8F6A5E906D6192706494736796756A98796E9A7D729C80769C8176
9D81769D81769E82779F8378A08479A1857AA3877CA4887DA58A7FA78B81A88D82AA8F84
AB9186AD9288AE9489B0958B
AF9489AD9186AB8D82A98A7FA7877BA58478A38174A17E719F7B6D9D786A9A7566987162
966E5F946B5B9367579164538F614F8D5D4A8B594688554186503C844D398B55418C5845
8C59488B5A498B5A4A8A5A4B8A5A4B8A5A4C895A4D89594C88574B88564A87564A87574C
875A4E885D528961558963578B675B8D6A5E8F6D6191706493726795756997786D98796D
997A6F9A7C709B7D719C7F739D80759F8277A08479A2867BA4887DA58A7FA78C81A98E83
AA9085AC9287AE9389B0958B
AF9489AD9085AA8D81A8897DA68679A38276A17F729F7C6E9C786A9A7566987162966D5E
936A5A9166558F62518D5F4D8B5B4889574487533F854F3A824B358A533C905A458B5643
895543885443875443865444855445855345845345845245835044824F44825044825146
82534882564B83594D855D518660548864588B675B8E6B5F8F6D61916F63927164937164
95746796766A97786C997B6F9B7D719C7F739E8176A08478A2867BA4887DA68A7FA88C82
AA8F84AC9186AE9388B0958B
AF9389AC9084AA8C80A7887CA48578A281749F7D6F9D796B9A7567987162956D5E936959
9065558E61508C5D4B89594787554285513D834D387F4630864D378E57418B544088523F
86513E844F3D834E3D824E3D814E3E804E3F804D3F7F4B3F7F493E7E483D7E493E7E4A40
7E4C427E50457E534880574B825B4F845F538763568966598B685B8D695C8D695B8F6B5D
906E6092716494746796766A98796D9A7C709C7F739E8176A08479A2867BA4897EA78B80
A98E83AB9085AD9388AF958A
AF9388AC8F84A98B7FA6877BA38376A07E719E7A6D9B7668987263956E5F936A5A906555
8D61508B5D4B885846855441834F3B804B367F4631844B348A513B88503A864F3A844E3A
824C39804A377E48377D48377C48387C48397B47397B473A7B483C7A4B3E7A4C3F7A4E42
794F43794F437A4F457B53487D584B805C4F835F538562568865588966598A67598B6657
8C67588E6C5E906F6292726695766997796D997C709C7F739E8277A1857AA3887DA68A80
A88D82AA9085AD9288AF958A
AE9388AB8E83A88A7EA58579A281749F7C6F9C786A997365966F60936B5B9066568D6151
8A5D4B875846845340814E3B7F4A357C452F793F297E442C834A33834B35824B36804A36
7E48347B4532794332784333774334764334774436774639774B3D774F42775446775648
7653467550447550447752467955497C584C7F5C4F826052846255866456876456886456
8965568A67588C6B5D8F6E6191726694766A97796D9A7D719D80759F8378A2867BA5897E
A78C81AA8F84AC9287AF948A
AE9287AB8E82A7897DA48477A17F729D7A6D9A7668977162946C5D9067578D62528A5E4C
875947845341814E3B7E49357A442F773E287C41298349318148327F48337E48347C4734
7A443177412E743E2D733E2F723E30703E31734739764F4177544678584C78574B755447
73564872574A7154477251447552467856497C5A4D7F5D51816153836254846254846254
8561528662538866588B6A5D8E6E6291736795776B987B6F9B7E739E8277A1857AA4887D
A68B81A98E84AC9187AF948A
AE9287AA8D81A6877CA382769F7E719C796B987365956E5F91695A8E64548B5F4E875A48
845442814F3C7D493579442F763F29733A247A41298047307E47317D46317B4532794431
774230743F2E713E2E6E3C2D70433476504279564877564976574A755648755648755A4D
765A4E74594D7255496F534671524575544879584C7C5C4F7E5E52806053806052815F52
8160528261548362558766598B6B5F8F706492756996796D997D719C8075A08479A3877C
A68B80A98E83AC9186AF948A
AD9287AA8C81A6877BA282759E7C6F9A7669967163936C5D8F66578C6150885B4A855644
81513E7D4B37794430753E287239237339227C422B7D452E7C45307A4531794532764331
744130714230714333724737764C3C764D3D744D3D734E3F724E3E714D3D704D3E704E40
714F4173524475564976594C73554A72524775554979594D7B5D507C5E517D5E517E5E50
7E5E507F5E50805F5083625587685C8C6E6290736794776C987B709B7F749E8378A2877C
A58A7FA88D83AB9186AE9489
AD9186A98C80A5867AA080739C7A6D987466946E6090695A8D6353895E4D855847825341
7F4D3A7B473376402B6E361F6B3019763B238047307C453079432F774330754331744331
724332734737764F407957477A5848755243724E3F704C3C6E48396D47396C47396C4738
6D48396E4D3E704F4173524675554973544874544977584C785A4E795B4E7A5B4F7A5C4F
7B5D507C5D4F7F5F5182625586675A8A6C608F716593766A967A6F9A7E739D8277A1867B
A4897FA88D82AB9086AE9489
AD9186A88B7FA485799F7E729B786B967264926C5D8E66578A6050865A4A8355437F4F3D
7C4A37794430753E29703822753C257E462F7E47317A4430774330744331724332714232
704333704636714B3C734F417251437152427051426E50416D4E3F6C4E3E6B4E3E6B5040
6B50416C4F416E4E4170514473544675574A76584C75584C76594D76594D775A4E785A4E
785B4E795A4E76574A7C5D50846759896B5F8D706591756A95796E997D729C8177A0857A
A4897EA78D82AB9086AE9489
AD9186A88A7FA383779E7D70997669957062906A5B8C6354875D4D83574680513F7D4C39
7A463378422E77402B7D452E864D35824B347A453076432F7343317143327043326E4433
6D45356D46376E48396D493A6D4B3C6C4C3D6B4B3D6A4B3C69493C67493B674A3B664A3C
674C3E674D3F6950426C5546705A4C755F52776154765E52745A4E74594E74594E755A4E
765A4E765A4F775B507D6155826659886C608C706490746994796E987D729C81769F857A
A3897EA78C82AA9085AE9489
AC9085A7897EA282769D7B6F977567926E608E6758896051855A4A8053427D4D3B794735
76422F753F29753D25783F2779422C77432E74412D71402E6F41306D42316C43336B4233
6A43346A4436694435684435684637674739664739654638644638634638624537624638
62473A63493D654C406850436C55486F594C715B4F735C50725B5072584E72584E73584E
745A4F745A4F745A507D625782675C866B5F8B6F648F746993786D977C729B80769F847A
A2887EA68C82AA9085AE9389
AC9085A6887DA181759B7A6D967365906B5E8B6456865D4E8156467D4F3F794937754330
723D2A7039246F36206F37216F37226E3A266E3C2A6D3D2C6B3E2E693F2F683F30673F31
6640326641336642346542336441346342346241346141346042345F42355E42365E4236
5E443861473B634A3F664F446953486C574B6E594E6F5A4F6F584F6F574E6F574E71594F
735A50745B51745B517C6155806558856A5E8A6F648E746992786D967C719A80769E847A
A2887EA68C81AA9085AE9389
AB8F84A5887C9F80749A786C9470638E695B886153835A4B7E5242794B3A754433713E2B
6D38246B321D69301A68301C68321F6936236A3826683929663A2A643B2B633B2C623B2D
623D2E613E30613F31603E315F3E315F3F325E3F325D40335C3F335B3F345B40345B4136
5C43395D453B60493E624D4366514869554C6C584F6C59506B574E6C564E6D574F705950
725B51755D53775E537C60547F635785695E896F648D746991786D957C729980769D847A
A1887DA58C81A98F85AD9389
AB8F84A5877B9E7F7398776A926E618B6659855E508056477A4E3F754736703F2E6B3825
68311E652C17622915612916622F1C6433226435246237266136276037285E37285D3729
5D382A5C392C5C3A2E5B3C2F5B3C2F5A3B2F5A3B2F593B30583B30573B30563B30563D33
57403659433A5C473E5F4B42624E4665524B67554D67554D67554D69554D6A564E6D5850
715B52765F567E645A84695D82665B84695E8970668D746A91786E947C729880769D837A
A1877DA58B81A98F85AD9389
AB8F84A4867B9D7D729675698F6C5F896456825B4D7C5344764A3B7042326A3A29653220
6129165D230F5B200E5B25145D2D1C5E31205E33225D33235C32235B3223593123583224
57322557332757362A57382D57392E57392D55372C55372C54362C52362C52372D523930
533C3355403757433B5A48415E4D4560504861504962504963514965514A67534C6B564E
6F5951745D557B635A836B628B756B8D756C8A72688C746B90786E937B72987F769C837A
A0877DA48B81A98F85AD9389
AA8E83A3857A9C7C719473678D6A5E8661547F584A784F417146376B3D2D6534235F2C1A
5A241156200E552110572716592B1B5A2E1E592F20582F20572E20562D1F542C1F532C1F
522C20522E2252302552322853342A52352B52362C51362C50352B4F352B4E352D4E372F
4F3A32513D3654423C5847415A4A445B4B455C4C455C4C465E4D47604E4863504A67534D
6B56506F5B54755F577C665D826D64856F668771688A746A8E776E927B72977F769B837A
9F877DA48B81A88F85AD9389
AA8E83A284799A7B709372668B685C835F527C5548744B3D6D42336638295E2F1E582513
521E0C4E1D0B4D200F51251554291A552B1C552B1D542B1D522A1C51281B4F271A4D261A
4C261B4C281D4C2A204D2D234E2F264E31274E32294D332A4C322A4B322A4B332C4B362F
4D39324F3D3651413A53433D54443F5546405646415747425949435B4B455E4D4861504A
65544E6B5851705C5576615A7A655D7F6860846E6588726A8C766E917B72967F769A837A
9F877EA48B81A88F85AD9389
A98D83A18479997A6F91706489665A805C4F78524570483A683E3060342558291A501E0D
47160542140444190B4B22134F271850281A50281A4F271A4E27194C25184A2417482217
46221746231947261D482920492C234A2E254A2F274A312949312948322A48322B48342E
4937314B3A344D3C374D3E3A4E3F3B4E403B4F413D51433F534541564844594B475C4E49
61504C65534E69564F6F5B54755F577B655D816C648671698B766E907A72947E7699837A
9E877EA38B82A88F85AD9389
A98D82A0837898796E8F6F638664587D5A4D754F426C443763392C5B2F21522416491A0B
4012053D130640180B461F124B24174D26194D26194C26194A2418472317452117432016
411F16411F1641201843241B45281F472B23482E26482F28472F28452F2944302A45322C
45342E463631473834473935473A36483A37493C384B3E3A4D413D504440544744584A47
5B4D495F504B63534D695751705C5678665F7E6B6483706989756E8E7A72937E7698827A
9E877EA38B82A88F85AD9389
A98D82A0827897786D8D6D628462577B574B714C406740345E3528552A1D4C201245180B
40160B3E160B401A0E4721154A24184A25184B261A4A251A4723184320153F1C123B1910
3919103A1B133D1E1640211A42251D452A22462D27462F29452F2A43302A42302A42312B
42322E42332F413430403431413532423734433836463B39493E3C4C423F4F4442534745
564B485A4D4A5D4F4B62524F6B5A567465607B6B6581706A87756E8D7972927E7698827A
9D877EA28B82A78F86AC9389
A88D829F827796776C8C6C6182615678554A6D493D633D315830244E2518461A0D3F1408
37110737130A3E1B1047231749251A4A261B4A271C49271C47261C44241B4021193C1E17
381C15381D153C20183E221B41251E442A24452F2945312B44312B42302B41302B3F312C
3E302D3E312E3E32303D32303C31303C32303E3432413836453B39483E3D4B41404D4543
514846554B49594E4C6155536A5D5A726662796B667F706A86756F8C7973917E7797827B
9D877EA28B82A78F86AC9389
A88C829E817795776C8B6B618060557654496A473B5E392E522B1F471E123F15093A1207
38140A3C1A10421F1549261B4A281D4A281E49281F492820482921482A23492C25462B24
442922442A23442C26462F294A352E4A363047342F45332F43322E41312D3F302D3E2F2D
3B2D2C3A2E2D382E2C352C2B342B2B362E2D3931313D3534413837453C3B48403F4B4342
4D45454F4747534B4B5C5453675F5D706765776B687E706B84756F8B7973917E7797837B
9C877FA28B82A78F86AC9389
A88C819E817794766C8A6B617F5F5574534867453A5A362B4B241A391005330A00341006
36150C3C1B134322194A291E4B29204A2A214A2A22482A22482B24492E284A302A4D332D
523932543B34533B34513B354E3B364B393448363245343043322F41312F403230403332
4035343E3636373132312C2E332C2E362F31362F313A32333E3637433B3B463F3F484243
4A44454A45464D494A575151635C5B6D6664756A677C6F6B8375708A7A74907E7896837C
9C877FA28B83A78F86AC938A
A88D829E827894776D896C627F605673534966453B57352B441E14371208320F072D0C05
30120B3A1B1345251B4D2C224C2C234C2C254A2B24492B25492D2749302B4A332F4C3632
4F3834503C37523E3A503E3A4E3D3A4B3B38483835453533433331413332403433403635
423837433A3A433A3941393941393A40393A41393B443C3D453E3F474142464243474244
4743454543454A474A5650516159596A62617369677B6F6C827570897A75907F7996847D
9C8880A28C84A79087AC938A
A88D839E837994786E8A6C637F615773544B67473E59382F4A281F4221183D1E15381C14
381C1541231A492A214F2F264E2F274D30284D322B4C332E49302B472F2A47302D473330
4936344A39374C3B394C3C3A4B3D3B4A3C3B473938453634423433413434403535403537
403738413A3A433C3D4942424F47464D45454D45454D46464A4546474346454246454346
4442464343474B494C565254615A5B6963627269677A6F6C827571897B7690807A97847E
9C8981A28C84A79087AC948A
A88D839E837994786F8A6E6480625974574E694A425C3E354F3128482A2343261F41251E
43261F472A224C2F2750322A4F312A4E332C4E352F4E37334F3B374F3C394E3C3B51403F
5445435547465447465247464F44444B3F3E473A3A4436364135354036364036383E3539
3D35393E373A403A3C443D3F4842434A45474B47494A4649464448454248434147424146
4040464142474A4A4F595658625D5E6863637068677A706D8276738A7C7891817C97867F
9D8A82A28D85A89188AD948A
A88D839F847A9579708B6F6681655C765A516B4F4660433C55393150342D4D312A4A2F28
4A2E274C302950332B51342C50332C4F342E4E36314E39354F3C3951413F534645554948
564C4C564D4E554D4E524A4B4D4444483D3E443938413636403636403638423A3C433D40
423D423E393F3B373C3D393D413D41434044444145444246434147424147414147414148
3D3F4741434A4D4D525755585C595B625E5E6E66657B716F8479758C7E7A92837E998781
9E8B84A38E86A89189AD948B
A88E849F847B967B728C716883675F795D556E534B6449425A3F39563C36543A34523731
52373053373053373053373051362F4F36304E36324D38354D3B384E3E3D4F4141504344
4F45454F45464E44454B4143483E3F45393A4236363F34353E33353F353740383B423C40
4541454844484743484340453E3C413D3B413E3D433F3E45403F4641424941434A3F4249
3D424A44484F4D4F555454595A5A5E67656675706F7E7674877C798E817D9586819A8983
A08D86A49088A9928AAD958B
A98E84A0857C977C738E736B846A627B6059725750684E475F453F5D433D5A413B583E38
583D37573C36563A345338325036304E35314D36324C37344C38364B3A394B3B3B4B3D3D
4A3E3F493D3F473C3D453A3B4237394034363D32343C30333B31333B32353D34383E383C
413C4044404447444849474B4A484D48474C46454B46464C45474E43464E3F444C3D444C
3F464E474D5450545A585C606164676D6D6E7B7675837B798B807D9285819789849D8C86
A18F88A69189AA938BAE958C
A98F85A1867D987E758F756D876D657E645D755B546C524C6349436047415E46405D443F
5B423C5A3F3A573C365339335036314E35314C35324B3633493634483736473737463737
4537374336374134363F33343D30323B2E31392D30372C2F372D30372E333830353A3338
3C373B3F3A3F423E4444424847464C48484F48495046485043474F41464E3E454D3D444D
4148514B525A565B626064696A6B6F7473747F7979887F7D908683968A869B8D88A08F8A
A4918BA7938BAB948CAE968C
A98F85A1887E998077917870897068806760785F596F5751664E49644D49634C48614A45
5E47435B443F573F3B533B375037334D35324B3532493432473432453333433333413232
3F31313D2F303B2E2F392C2E372A2D35292C33272B32272B32282D33292F342C31352F35
37323839363C3B3A413E3E4540414841434A42444D40454D3E454E3D454E3B454E3B4651
434D575058605B6169666A707273777D7C7E888383918988978D8B9B908C9F928DA3938D
A6948DA9958DAC968DAF968D
AA9086A289809B8179937A728B736B836B647B635D735C566B545069534F67514E66504C
634D496049455C454258413E523C394E37354B3432473331453130422F2F3F2E2E3D2D2E
3A2C2D382A2B36282A3426293124282F23272E22272D22272D23292E252B2E282E2F2A31
312E3534323936353D3839413A3C443B3F483C404A3C424B3C434D3C444E3B4550404A55
4B555E575F686369707074797E7F838A898B9591919C96959F9694A19693A49792A69791
A99790AB978FAD978EAF978E
AA9187A38A819C837B957C758D766F866F687E676276605B6E59556D58556C5753695552
66514F624D4A5E49465B4441563F3D513A374A3533463231422F2E3F2C2C3B2A2A382829
3526273324263022252E20232C1E222A1E22291D22281E24281F2528212829232B2B262E
2D2A322F2E3631313A33343E353841363B45373D47383F4A39414C39434F3C475345505B
515B655F676F6E747A7C7F848A8B8E989697A5A3A3A9A4A3A79F9CA79D99A99B97AA9B95
AB9A93AD9991AE9890B0988E
AB9187A48B829E857D977F7890797289726D826C677A6460725D5A715C596F5B586C5956
695653665351624F4D5C4847564241503C3B4936364331313F2D2D3B2A2A372727342325
3020222D1E202A1C1E281A1D25181C24171C23171D23181F231B22231D2524202826232C
2827302A2B342C2E382E313C303540323844343C47343F4B36414E3A4652414D594C5863
5A646E697179787E84878A8E959699A3A1A2AEAAAAAEA9A8AEA6A3ADA39FADA09BAE9E98
AE9D96AF9B93B09A91B1988F
AB9288A58C849F877F99827A937C768C777186716C7F6B6777646176636074615E715E5C
6E5C5A6A58576452515E4C4B5645454D3C3D463536412F303C2B2C3726283322242F1E20
2B1A1C28171A2415182113171F12171D12181C12191C131B1C161E1E1922201C2621202A
23242E262732282C372B303B2D333F2E3643303A47313E4B35424F3A485644525F525F6B
626D76727A8281878E909499A0A1A4AFADAFB8B4B4B5B0AEB3ABA9B2A8A4B1A4A0B1A29C
B19F98B19D95B19B92B19990
AC9289A68E85A189819B847D968079907B768A767284716E7E6B697C6A68786866756463
71605F6C5B5B6756566050505747494C3D3F4535373E2F3139292B3323252E1E202A191C
2516182112161E10141B0F14190D14170C14160C15160E1817111C1915201B19241D1C27
1F202C222531242935272E3A29323F2B36432D3A47313E4C3544523E4D5B4B5A675B6974
6D77817E858D8D92989EA0A4AFAFB1BFBFBFC2C0BFBCB6B5B9B1AEB7ACA8B5A8A3B4A59F
B3A29BB39F97B29C93B29A90
AD938AA88F86A38B839E878099837D947F7A8F7B778977748473718272717E6F6E7A6B6A
756666706161695B5C625455584A4D4E414445383B3C2E313526292F2024291B1E24161A
1F12171B0E14170B121409111208101007110F0912100B16110E1913121D151521181A26
1B1E2B1E2330212835232D3A26313F2A36452D3C4A3241503A4A5946566455647166737E
78828B889097999EA3AAACAFB9B9BAC4C2C2C3C0BFC1BBB9BDB5B2BBB0ACB8ABA6B7A7A1
B5A49DB4A099B39D94B29A91
AD948AA99088A48D85A08A839C878197847F93817D8F7E7B8A7A788879788476767F7272
7A6D6E7467696E6162665A5C5E515453474B473B403B303532262B2B1D2325171D1E1118
190D15150A121107100E050E0B030E09030F0805110A07140C0B180F0F1C111321141826
171D2B1A22301E2735212C3B2432412937472F3E4E37475742536251616F62707C737F89
848D96949BA2A6AAAFB8BABCC6C5C6CCCBCAC9C5C4C5BFBDC1B9B6BEB3AFBBAEA9B9AAA4
B7A59FB6A29AB49E95B39B91
AE948BAA9289A68F87A28C869F8A849B88839886829584829384849082838B7E7E85797A
8175767B6F7074696A6D616464595C594F544D444A40373E332931281E2621161F1A1019
130A140E06110A030E07010D04000D02000D02020F040513070A180A0E1D0D1221101726
141D2B1822311C2838212E3E2635452D3C4D3445553F50604F5F6E5F6E7B707D89818C96
939BA3A4AAB0B6B9BDC5C7C8D4D5D6D6D6D6CECBC9C9C3C0C5BCB9C1B6B2BEB0ABBBABA5
B9A7A0B7A39BB59F96B39B91
AE958BAB938AA89189A48F88A18D879E8C879C8B879A8A88988B8A958A899186868C8182
867C7D8076787A707373696C6B616562595E574E544A42493C343D302932231C2618121D
100B170A051107020F03010E00000F000111010414020717040A1A070F1E0B14240E1929
111E2E1623351D2B3C2333442A3A4C3343553E50604C5E6D5C6D7A6E7C88808B96919BA4
A3ABB1B5BABEC5C8CAD3D4D5DBDBDBD8D6D5D2CECCCDC6C3C8BEBBC4B8B3C0B2ADBDADA7
BAA8A1B8A49CB69F97B39B92
AF958CAC948BA9928BA6918AA4908AA28F8BA08F8B9E8F8D9D908E9B9090988E90948A8B
8E8586897F8282797C7B7376746B706A626760585E544D544841493B353E2D2934211E2A
191522120F1D0C0B1A08081805081805091B050C1E060E200711230915270C192B0F1E30
1524361B2B3D213244293A4C3344553E50614C5E6E5C6D7B6D7C897F8C97919CA5A3ABB3
B6BBC0C8CACED6D7D9E1E2E3E4E4E3DCD9D8D5D0CECFC8C5CAC0BCC6B9B5C2B3AEBEAEA8
BBA9A2B9A49CB6A097B49B92
AF968CAD958CAB948CA8938CA6938DA5928EA3938FA29391A19593A29797A096979B9293
968D8E91888A8C8386867E817D7579726B706760665B555C504A52453F4839353F2F2C38
2625321F202E191B2A1417271116271117281018290F1A2C101C2F121F3214233618283B
1D2F412435482C3D503547584052634D5F6F5D6E7B6D7C897F8C97919CA5A3ACB3B6BCC2
C9CCD0D9DADDE5E6E7EDEEEEE8E8E8DFDBDAD7D1CFD1C9C5CCC1BDC7BAB5C3B4AEBFAFA8
BCA9A2B9A59CB7A097B49B92
B0968DAE968DAC958DAA958EA9958FA79590A69692A69794A69997A69B9BA69D9EA49C9D
9E96989A9194948C8F8D8689847D817A737870696F6660675C575F504D5645444F3D3C48
37364331323F2A2D3B262A39222737212737202939212B3C222E3F2532432735472A3A4C
303F52374759405161495A6A55657462717F727F8C828E99939DA6A4ADB4B6BDC2C9CDD1
DADDDEE8E9EAF4F6F6F3F4F4E8E6E5DFDBD9D8D1CED2C9C5CDC1BDC8BBB5C4B4AEC0AFA8
BDAAA2BAA59CB7A097B49C92
B0978DAE978EAD968EAC968FAB9791AA9792A99994A99A97A99C9AAA9F9EABA2A2AAA1A3
A79FA1A29B9D9C9597948E918D878B8580847B767C716C736762695C596254525C4D4C56
46465240414E3B3D4B383B49353948333A49343B4B353E4D3741513945553C4959404E5E
4654644E5C6B5664735F6D7B6A788477848F87919C97A0A9A7AEB6B9BEC3CBCED1DCDEDF
EAEBECF7F9FAF9FAFAEFEEEDE7E3E2DFD9D7D8D0CDD2C8C4CDC1BCC8BAB5C4B4AEC0AFA8
BDA9A2BAA59CB7A097B49C92
B0978DAF978EAE978FAD9890AC9892AC9994AC9B96AC9D99AD9F9DAEA3A1B0A7A6B0AAAA
AFA9ABAAA4A6A59FA19F999C9892968F8A8E8681867D797F7470786A687164626B5D5C66
58576153525D4E4F5B4B4D5A484C59484D5A494F5D4B515F4D5463505866545D6B596371
606A7868727E6E798576818D818B968D96A09BA3ABABB1B7BCC0C5CDCFD2DBDCDEE9E9EA
F8F9F9FCFDFDF3F3F2ECE9E8E4DFDDDDD6D3D7CECAD1C6C2CCBFBAC8B9B3C4B3ADC0AEA7
BDA9A1BAA49CB7A097B49B92
B1978EB0988FAF9890AE9991AE9A93AE9B95AE9C97AE9F9BAFA19EB1A5A3B3AAA9B8B1B2
BAB5B6B5B0B2AFAAACA9A4A6A29DA09C979A948F948D888E8581877C7A8175737B6F6D75
6A697166656E62636C60626B60616C5F616C60636E626570656874686C786E727D737883
797F8A808690878D968F959D999FA6A6AAB0B4B7BCC2C4C8D0D1D4DFDEDFEDEBECF9F8F7
FDFDFCF6F6F5EFEDEBE8E4E2E2DBD8DBD3CFD5CBC7D0C4BFCCBEB8C7B8B1C3B2ABC0ADA6
BDA8A0BAA49BB79F96B49B91
B1988EB0988FB09990AF9992AF9A94AF9C96AF9E98B0A09BB1A39FB3A7A4B6ABAAB9B1B1
BEB9B9C0BBBDBBB6B8B4AFB1AEA9ABA8A3A6A29DA19C989C9692978F8C9289868D838188
7F7D847C7A827A798077777E76757D76757E76767F7878817B7B847F808883858E8A8D96
93959D989AA19D9FA6A6A8ADB2B2B7BCBDC0C8C8CAD5D4D5E2E0E1EDEBEBF7F6F6FEFFFF
FBFCFCF2F0EFEBE7E5E4DEDBDED6D3D9CFCAD3C8C3CFC1BCCABBB5C6B6AFC3B1A9BFACA4
BCA79FB9A39AB79F96B49B91
B1988EB1988FB09990B09A92B09B94B09C96B19E98B2A19CB3A39FB5A7A4B7ABA9BAB1AF
BEB7B6C3BEBFC4C0C2C0BABCB9B4B6B3AEB0AEAAADABA6A9A6A1A5A19CA09C989D989499
949096918D938E8B918C89908B888F8C898F8C8A908E8C92908E9493919799979C9E9CA1
A4A1A4ABA8ABB2B0B3BBB9BBC4C2C3CCCACBD7D5D5E3E0DFEDEBEAF8F6F5FFFFFFFDFEFE
F4F3F1EDE9E7E6E0DDE0D8D5DBD1CDD5CAC5D1C4BECCBEB8C8B8B2C5B3ACC1AFA7BEAAA2
BBA69EB9A299B69E95B49B91
B1988EB1988FB19990B19A92B19B94B19D96B29E98B2A19BB4A39EB6A7A3B8ABA7BBAFAD
BEB5B3C2BABAC6C1C2C7C3C4C4BFC0BFBABCBAB5B7B7B1B4B4AFB3B0ACB0AEA8ACACA7AA
AAA5A8A7A2A5A49FA3A29DA1A19CA0A09B9FA19BA0A39DA2A59FA3A7A2A5A9A4A6ADA7A8
B1ACACB4AFB0BBB6B7C3BFBFCCC8C8D8D3D3E3DFDEEDE9E8F7F3F2FEFCFCFDFDFCF5F3F1
EEE9E7E7E1DEE1D9D5DCD2CDD7CBC6D2C5BFCEBFB9CABAB3C6B5AEC3B1A9C0ACA4BDA8A0
BBA59CB8A198B69E94B49A90
B1988EB1988FB19990B19A92B19B93B29D95B29E97B3A09AB4A39DB6A6A1B8A9A5BAADAA
BDB2AFC1B7B6C5BDBDCAC5C6CBC7C9C8C2C4C4BEC0C1BBBEBFBABCBEB8BBBCB6B9BAB4B7
B8B1B4B8B1B4B7B0B3B5AEB1B4ACAFB4ACAFB5ADAFB6AEAFB7AEAFB9B1B1BBB2B2BEB5B4
C1B8B7C5BDBCCDC5C3D5CDCBDDD6D4E7E0DEEEE9E7F6F1EFFDFAF9FBFAF9F4F1EFEDE7E5
E6DFDCE0D8D4DBD1CCD6CAC5D2C5BFCEBFB9CABAB4C7B6AFC4B1AAC1ADA6BEAAA2BCA69E
BAA39AB7A097B59D93B39A90
B1988EB1988FB19990B19A91B29B93B29C94B39E96B39F99B4A19BB6A49EB8A7A2BAABA6
BCAFABBFB3B0C3B8B6C7BFBECDC7C7D2CDCFD0CACBCAC4C5C6BFC1C6BFC2C8C1C4CAC3C4
C9C2C3C6BFC0C4BCBEC6BDBEC8BEBEC6BBBBC3B9B8C3B8B7C4B9B7C5B9B7C5BAB7C8BDB9
CABFBCD0C4C1D6CBC8DDD3D0E5DCD9EDE4E1F2EBE8F8F3F2F6F3F2EFEAE8E9E3DFE4DBD7
DED4D0D9CEC9D5C8C2D1C3BDCDBEB7CAB9B2C7B5AEC4B1AAC1ADA6BFAAA2BCA79EBAA49B
B8A198B79F95B59C92B39A8F
B1988DB1988EB1998FB29A90B29A92B29B93B39D95B39E97B4A099B5A29BB7A49EB9A7A2
BBABA6BDAEAAC0B3AFC4B8B5C8BEBCCDC5C3D2CBCBD3CCCCD0C9C9CFC7C7CFC6C7CFC6C7
CFC5C6CFC5C5D0C5C4CFC3C1CCBFBDCBBEBBCBBEBACABDB8C9BBB7C9BCB6CCBFBACEC1BC
D1C4BFD6CAC5DCD1CDE3D8D5E8DEDBECE4E2F1ECEAF1ECE9E9E2DFE4DBD7DFD4D0DACEC9
D6C9C3D2C3BDCEBFB8CBBAB4C8B6AFC5B3ABC3AFA8C0ACA4BEA9A1BCA79EBAA49BB9A299
B79F96B69D94B49B91B3998F
B1978DB1988EB2988FB29990B29A91B29B92B29B93B39D94B49E96B5A098B6A19AB7A49D
B9A6A0BBA9A3BDADA7C0B0ACC3B5B1C7BAB6CBBFBCD1C6C3D7CDCBD8CECCD4C9C7D2C6C4
D4C7C6D4C7C6D2C4C2D0C1BECEBFBCCEBFBCCFC0BBCFC0BAD0C1BBD0C1BBD1C2BCD2C4BE
D4C7C2D7CCC7DBD1CDE1D8D5E7E0DDEAE3E0E6DEDAE1D6D2DCD0CBD8CAC5D4C5BFD0C1BA
CDBDB6CAB9B2C7B5AEC5B2AAC3AFA7C1ACA4BFAAA1BDA79FBBA59CBAA39AB8A198B79F96
B69D94B59C92B49A90B3998E
B1988EB1988EB2988EB2988FB2998FB29990B29A91B39B92B39C93B49D94B49E96B5A098
B7A19AB8A39CB9A69FBBA8A2BEABA5C0AFA9C3B2ADC6B6B1C9BAB5CCBDB8CFC1BBD2C4BE
D1C3BDCFC1BCD0C1BDCFC0BDCDBDBACBBBB7CABAB5CBBAB4CBBBB4CCBCB5CDBCB6CDBDB6
CFC0B9D6C8C3DBCFCBDCD1CBD9CCC7D6C9C3D4C6BFD1C1BBCEBDB7CBBAB3C9B6AFC6B3AB
C4B0A8C2AEA6C0ABA3BFA9A1BDA79EBCA59CBAA39AB9A299B8A097B79F96B69E94B59D93
B49B91B49A90B3998FB2988E
B1978DB1988DB2988EB2988EB2988EB2988EB2998FB2998FB29A90B39A91B39B91B39B92
B49C93B59D94B69E96B6A097B8A199B9A39BBAA59DBCA79FBDA8A1BFAAA2C0ACA4C1ADA5
C1ADA5C1ADA5C2AEA6C2AFA7C5B1A9C7B4ABC7B4ACC8B5ADC8B5AEC9B6AEC9B7AFCAB8B1
CBBAB3CAB8B1C7B4ADC6B3ABC5B2AAC4B0A8C3AEA6C1ACA4C0AAA2BEA8A0BDA79EBCA59C
BBA49BBAA299B9A198B8A097B79F96B79E95B69D94B59D93B59C92B49B91B49A90B39A90
B3998FB3998FB2988EB2988D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.511074 0.97619 0.732558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(158) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
C2A693C2A693C1A692C1A592C1A592C1A591C0A591C0A491C0A490C0A490C0A38FBFA38F
BFA38FBFA28EBFA28EBEA18DBEA18DBEA18DBEA18CBEA08CBEA08CBDA08CBDA08CBEA08C
BDA08CBDA08BBDA08BBDA08BBE9F8BBD9F8BBD9F8BBD9F8BBD9F8ABD9E8BBD9F8BBD9F8B
BD9F8CBEA08CBEA08DBEA08DBEA08DBEA08DBEA18DBEA18EBEA18EBFA28FBFA390BFA391
BFA390BFA390BFA390BFA390BFA390BFA390C0A490C0A490C0A491C0A491C1A591C1A592
C1A592C1A693C2A693C2A693
C2A693C1A592C1A491C0A490C0A390BFA38FBFA28EBEA28DBEA18DBEA08CBDA08BBD9F8A
BC9E8ABC9E89BB9D88BB9C87BA9B86BA9B85BA9A85B99A84B99984B99983B99983B99984
B99984B99883B99882B99883B99883B99883B99782B89781B89681B89681B89682B89682
B89884B99885B99985BA9986BA9A86BA9A86BA9A86BA9B87BB9C89BB9D8ABC9E8CBCA08F
BCA08FBC9F8CBC9F8BBC9F8BBC9F8BBDA08CBDA08CBEA08DBEA18DBEA28EBFA28FBFA390
C0A490C1A591C1A592C2A693
C1A693C1A592C0A490BFA38FBFA28EBEA18DBDA08CBD9F8ABC9E89BB9D88BB9C87BA9B86
B99A84B99983B89882B79781B69680B6957EB5947DB5937CB4927BB4927BB4917AB4917B
B4917AB4917AB4917AB4917BB4917BB5917BB4917BB4917CB4917CB5907CB5907CB6917D
B6937FB79480B79480B6937FB6937FB5937FB59480B69581B79683B79884B89987BA9C8A
BA9D8AB99B87B99A86B99A86BA9B87BA9C87BB9C88BB9D89BC9E8ABD9F8BBDA08CBEA18D
BFA28FC0A390C1A591C1A692
C1A692C0A591BFA390BEA28EBDA18CBD9F8BBC9E89BB9D88BA9C86B99A85B89983B79781
B6967FB5947EB4937CB3927AB39079B28F77B18D75B08C74AF8B72AF8A71AF8A71AF8A72
AF8A72AF8A72AF8A72B08A72B08A73B08B74B18C76B38D78B38E7AB38F7AB48E7AB48E79
B48D79B48E7AB48D7AB48D79B38E79B38E7AB28F7AB3907BB3917DB4927EB49380B59481
B59581B59581B69581B69681B79782B79883B89984B99A85BA9B86BB9C88BC9E89BD9F8B
BEA18DBFA28EC0A490C1A592
C1A592C0A490BFA38FBDA18DBC9F8BBB9D89BA9C87B99A85B89983B79781B5957FB4937D
B3927AB29078B18E76B08C74AF8A72AE896FAC876DAB856BAA8369AA8268A98267AA8268
AA8368AA8369AB836AAB836BAB846CAC856EAD866FAD8771AE8873AE8974AF8A75B08A75
B08A75B08974B08A74B18974B08873B08974AF8974AF8A74AF8A75B08C77B18E79B18F7A
B18F7AB28F7AB2907AB3917BB3927CB4937EB5957FB79681B89883B99A85BA9B87BB9D89
BD9F8BBEA18DBFA38FC1A592
C1A592BFA38FBEA18DBD9F8BBB9D89BA9B86B89A84B79882B6967FB4947DB3927AB29078
B08D75AF8B73AE8970AC876DAB856BA98268A88065A67E62A57B5FA4795DA3785CA4795D
A57B5FA57C61A67C62A67D63A77D65A77E66A87E67A87F68A98069AA826CAA836DAB836D
AB836DAB836CAB836CAB836CAB836CAB826BAB826BAA836DAA846DAB856FAC8873AD8974
AD8972AE8973AE8A73AF8B75B08D76B18F78B3917BB4927DB5957FB79782B89984BA9B86
BC9D89BDA08CBFA28EC0A591
C0A591BFA28FBDA08CBC9E89BA9C87B89984B79781B5957FB4937CB29079B08E76AF8C73
AD8970AC876DAA846AA98267A77F64A57C60A3795DA276599F73559D6F519C6D4E9E6F51
A07357A1755AA1765BA2765CA2775DA2775EA3775EA3785FA37860A47861A47862A57962
A57A62A57A62A57A63A57B63A67B62A67B62A57B62A57B63A67D65A77E67A78069A8816A
A9816AA9826BAA846CAC866EAD8870AE8A73B08D76B28F79B3927CB5947EB79781B99984
BB9B87BC9E8ABEA18EC0A491
C0A491BEA28EBD9F8BBB9C88B99A85B79782B5957FB3927BB29078B08D75AE8A72AC886F
AA856BA88268A77F64A57C61A3795DA176599F73559D6F519A6B4B9564439564449A6B4C
9C6E509D6F539D70559D70559D70559D70569E6F559E6F559E6E559E6E559E6E559E6E56
9E6F579E70589F71589F72599F7359A0735AA0745AA1745BA1765CA2775DA3785EA3795F
A47A60A57B62A67E64A88067A9836AAB856DAD8871AF8B74B18E78B3917BB5957FB79883
B99B86BC9E8ABEA18DC0A490
C0A490BEA18DBC9E89BA9B86B89883B6967FB3937CB19078AF8D75AD8A71AB876EA9846A
A78166A57E63A37B5FA1775B9F74569D70529B6D4E996949966443946140956343986849
99694B996A4D996A4D996A4E99694D99694E99694F98674E98664C98644B98624A976249
97644B98664D98684E986950996B519A6C519B6D529B6D529C6D529C6D519C6D519E6F53
9F7156A07459A2775CA47A60A67D64A88168AA846CAC8870AF8B74B18F78B3927CB69680
B89984BB9D88BDA08CC0A390
C0A490BDA18CBB9D89B99A85B69781B4947DB29179B08D76AD8A72AB876EA9846AA78066
A47D62A2795DA076599E72549B6F50996B4B97674695634293603C9866429B6A49976646
966546956446956345946346946346946246946146936046935E44925D43925C42925C42
925C43915D44925F4593614693634894644996654A97664A98664A986548976345986446
9A684B9C6C4F9E7054A07459A2785DA47C62A78067A9846BAC8870AF8C75B29079B4947E
B79782BA9B87BD9F8BBFA38F
C0A390BDA08CBA9C87B89983B59680B3927BB08E77AE8B73AB876EA9846AA68066A47C61
A1795D9F75589C71539A6D4F98694A95654593613F905B3895613E9B6948976644956342
936141915F3F905E3E905D3E8F5D3F8F5C3F8F5B3F8F5A3F8E583E8E553C8D543B8D543B
8D543C8D553C8D583E8D593F8E5C418F5E42905F43926043936042935E3F925B3A925B3A
95604097644699694B9C6E519E7257A1775CA47B62A78067AA846CAD8971B08D76B3917B
B69680B99A85BC9E8ABFA38F
BFA38FBC9F8BBA9C87B79882B4947EB19079AE8C74AC8870A9856BA68167A47D62A1795D
9E75589C7153996D4E96684994644391603E8F5C3994603D97644295624093613F915F3E
8F5D3C8D5A398C58378B57378A56388A56388A55398A553A8A573C8A583D89583D89593D
89573D88543A88533987543A88573B8A593D8B5A3D8D5B3E8E5C3E8F5B3C8F58388E5532
8F5634925D3C95624397674A9A6C509D7256A0775DA47C63A78168AA866EAE8B74B1907A
B5957FB89984BB9E89BFA28F
BFA38FBC9F8AB99B86B69781B3927CB08E77AD8A72AA866DA78268A47E63A1795E9E7559
9B7154996C4E966849936343905F3D8D5A378955308A5631905C38905D3A8F5D3A8D5B3A
8B5937895634865232855132855133845133845234855437865A3D865E42876145876246
855D4183573C8354388352378453378555388756388857398A583A8B58388B56358B5331
8B52308D5534905B3B93614396674A996D519D7358A1785EA57E65A8836BAC8971B08E77
B3937DB79883BB9D89BEA28E
BFA28FBB9E8AB89A84B5957FB1907AAE8C74AB886FA8836AA57F65A27B609F765A9C7255
996D4F9568499263438F5F3D8C5A378854308B56328E5A368D5A378C59378B5938895837
875534855231824E2E804C2D804C2E7E4C2E7F5436845E4186634789684E88664C866145
8362458161457E5A3E7D52367E4F3380513483523685543787563888563688543387512F
874D2A874E2B8A54338E5B3C91614496684B9A6E539E755AA27B61A68168AA866FAE8C75
B2927CB69782BA9C88BEA28E
BEA28EBB9D89B79883B4947EB09079AD8B73A9866DA68168A37C629F785C9C7357996E51
96694B9264458F5F3E8B5A3888553285512D86532F8A58358A5835895836885735865635
855534825231804F2F7C4B2B7C503184604386644885654A85674C85654985664A86684C
87674D856449815E427B563A794F337C4E327E5033815134835335845334855231844F2E
844D2B834C2B844E2E8854348D5B3D926346966A4F9B7157A0785EA47E66A8846DAD8A73
B1907AB59681BA9C87BEA18D
BEA28EBA9D88B69883B3937DAF8E77AB8971A7846BA47F65A07A5F9D75599A7053966B4D
9366478F61408B5B39875431834F2B844F2C85522F875633875734865736855736845636
82553580553580563680583881583982593B815B3C815C3D815C3E815B3C805B3D805A3D
815A3C835C3E866043845E427D563B784C317A4B2F7D4E317F5032815132815030814D2D
814B29804926804A27824D2D8856388E5F4293674B986E539D755BA27C63A7826AAB8972
B08F79B59580B99B86BEA18D
BEA28EBA9C88B69781B1927BAD8C75A9876EA58168A27C629E775C9A7256976D5094684A
9063448D5E3D895735814D297C461F834F2A895734865634845534835434825535815636
815738825B3D846245886A4D86684A8260437F5D3F7E593B7D56387C55377C55367C5233
7C52337D54367F573981573A81573B7B5034774A2E7A4C2F7C4D307D4E2F7E4D2D7D4C2B
7D4A297E48267F4927814D2C8553348A5B3E906447966B509B7359A07A61A58169AA8770
AF8E77B4947FB99A86BDA18D
BEA18DB99C87B59680B0907AAC8A73A8846CA37F669F7A5F9B7459986F52946A4C916546
8E60408C5C3B89573486522F85522E8757348859378456358254358054367F55377E5537
7E573A7E583B7E5B3E8060447F62457E61447D60437C5F427C5E407B5D3E7B5C3E7B5D3E
7B5C3C7B58397C56387E56387F56387F55387A5033774B2F794C2F7A4C2E7B4C2D7B4A2B
7B48287A462577411E79452382513187593B8E614593694E9971579E785FA37F67A9866F
AE8D76B3937EB89A85BDA08D
BDA18DB89B86B4957FAF8F78AA8971A6836BA17D649D775D997156956C4F9166498E6142
8B5D3D8A5A388B593792603D9765428D5E3B8457358055347E55357D54367C54377B5639
7B583B7B583C7A573A79583A795A3D795B3E785A3D785A3D77593C77583B76583A765739
765739765638765738785A3B7B5C3E7E5E417D5B3F795437774E30784C2F784B2D784A2B
7849297847277947277847277E4E2F85573A8B5F4391674C976F559C765DA27E66A7856E
AD8C75B2937DB79985BDA08C
BDA18DB89A85B3947EAE8D77A98770A481689F7A619A745A966E5292684B8E63458A5D3E
8859388656348755308956328858368456357F52327C51327A5234785336775438775439
77563A77563A755337745134745336745538735538735538735638725538715335715234
715234715234725335735436765538775739785638775337764F34754C30764A2D76492C
77482A7747287746267747297D4E30835538895D418F654A956D539B755CA17C64A6846D
AC8B75B1927CB79984BDA08C
BDA08CB79985B2937DAC8C75A7856EA27F669C785E977157936B4F8E64478A5E40865939
835433814F2D7F4D2A7E4C297C4B287A4B2A784C2E774D2F754E31744F33735034725135
725237725237725236704F326F4E316F4F326F4F336E4F336E50336E50346D50346D4E32
6D4D326E4E336F4F34705236725338745438745338745136734E33734B30734A2E754A2D
76492C77492B784829754525794A2A805335875C3F8D6449936C5299745B9F7B63A5836C
AB8A74B1917CB69884BCA08C
BCA08CB69984B1927CAB8B74A5836C9F7C649A755C946E548F674B8A6043855A3C815334
7D4E2D7B482678452276442274442374462573472871482A70492C6E4A2D6E4B2F6D4C30
6D4E326D4F336C4E326B4C2F6A4A2E6A4B2F6A4D316A4D326A4D326A4D336A4D32694D32
6A4D326A4D326B4D336C4E346E503770523971533A715138704D33704B31714B2F734A2E
754A2D784B2D7B4C2D7746267646277E5033855A3E8C6348926B5198735A9E7A63A4826B
AA8973B0917BB69884BC9F8C
BC9F8CB69883B0917BA98973A3826A9D7A62977359916B508B6448865C3F8055377C4E2E
774726734120703D1B6D3C1A6D3F1E6E42236D43256B44266A442769452968452A67462A
67472C67492E674A2F66492E65482C65472B65482C66482D65492E65492E65482D64482E
65492F664A30674C32684C32694D346B4F376C4F376C4E356C4C336D4B316E492F70492E
734A2F784D318153348352337B4B2C7B4E31845A3F8A6248906A519672599C7962A3816A
A98973AF907BB59883BC9F8C
BC9F8BB59783AE907AA88871A180689B785F9470568E684D87604481583B7B5032754828
703F1E6B3716673312663516663A1C653E1F663F21653F22643F22633F22623F23623F24
61402561412761432962452B61452B61442A61432961432961432961432960432960442A
60442B60452C61472E624831644B33654B33664A3267493167472F68462D6A462D6D472D
70482D754B307B503482563A875C40865C41855C418962488F69509571599B7861A1806A
A88872AE907BB59783BC9F8B
BB9F8BB49782AD8F79A686709F7E6798765D916D548A654A835C417C5337754B2D6F4223
693A1A64341461331460341661371961391C603A1E5F3B1F5F3A1E5D391D5C391D5B391D
5B391E5B3A205B3C225C3D245C3F265C40285D42295D42295D42295D42295C41295C4129
5C41295C422B5D452E5F473060483160462F60452E61442D62432C63432B65432B68432B
6B452C6F472E744A30784E337C52377F563B825A408760478D684F936F58997761A07F69
A78772AE8F7AB49783BB9F8B
BB9F8BB49681AC8E78A5856F9E7C6596745B8E6B528762477F583D774F33704528683B1C
6034135B31115830115831135933165A35185A351A5A361A593519583418563217553216
54321854321954341B55361E563920573B22583D24593E26593F28593F27593F27593F28
59402959412B59422C5A422C59412B5A402A5A3F295A3F285C3F285E3F28604028624128
65422968442A6D462D71482E73492E774D337E563D845E468A664E916E579876609F7E69
A68771AD8F7AB49783BB9F8B
BB9E8AB39681AB8D77A4846E9C7B6494725A8C684F835F457B553A734B2F6A4124603517
562B0B4E26074B260A4E2B0F522E13543015553116553116543115533014512F144F2D13
4D2C134D2D144E2F174F321951341B52371F543922553C24563E26563E27563E27553D27
553D27553D27553D28543C27533B26523A24533A24543B25563B25573D26593E275C3E27
5F3E27623F27653F266941276D432873482D79533A805C4487644D8E6D5696755F9D7E68
A48671AC8E7AB39683BB9F8B
BA9E8AB29581AB8C77A2836D9A7A6392705889664D805C427751376E472C653D215C3316
50280C48230845230946250C4C2A114E2D13502F14502F144F2F144E2D144B2B13492A12
472911462710462710482A124B2E164E321B503720523A23533B25533C26523B25523B25
513A244F39244F38244D37224B35204B34204C341F4D341F4F3621513822543923563A24
593B245B3B235D3C24603C23663F276D472E7550397D5A4384634D8C6C5694745F9C7D68
A38571AB8E7AB39682BA9F8B
BA9E8AB29580AA8C77A1826C997862906E5786644C7C5940734E3469432960391E583218
522D1449270E44240B44250D4829104A2B124C2D144D2E154C2D14492A1145260D41230A
3E21093E220B41240D43260F4629134A2F194E351F503924513B26513C27503C254F3A24
4D38234B362248342046321E45301C45301B45301C47311C4A331E4D34204E3621513722
5338225538225737225937215F3C2568442D714F3879584281614C8A6A5592735F9A7C68
A28571AA8D7AB29682BA9E8B
BA9E8AB29580A98B76A1826C9878628E6D5684624A79563E6E4A31643F245A3419532E13
4A280F42230C40230C41250E462912482B144A2D164C2F184C301A4B2F19482D16432914
3D25103B240D3D250F412711432813482E184C36214F3A26503D28503D294F3C284D3A26
4A372248342046321F44301D412D1A3F2A183F2A18412C19452F1B48311D49321E4B341F
4D35214F36215237235639255C3D2964442F6D4D397657427F604C87695590725E987B68
A18471A98D7AB29682BA9E8B
BA9E8AB29580A98B77A0826C9778628D6D5682614A76543C6A462D5D381F542F154E2B11
4C2B13472913432711422711452A15472D17492E194A301B4C331F4F3622513925513924
4D352149331F46331F4835224C3A264D3B274E3B284F3D2A4F3E2C4F3E2C4E3C2A4C3927
48342244301E412E1C3C2A183826143826143A28163C29173F2B18432E1B46301D48311F
4932204A32204B34214F3825573E2C604432694D397256427C5F4B8568558E725E977B68
A08471A98D7AB19682BA9E8B
BA9D8AB29581A98C77A0826D9779638D6E5782614A75533B654229522C1246210846260E
472A13462A15422915412814442B17462E1A482F1C49311D4B34214F3A27523D2B57422F
5C47345B483557443154433051412F4F3E2D4F3D2C4F3E2C4F3E2D503F2E503F2E4F3E2D
4E3E2E4A3B2A4334253B2C1D3828193828183726163826153C2817402C1A442F1E453120
45311F45301F453120483322503A285A412F654A386F5441795E4B8368558C715E967B68
9F8471A88D7AB19683B99E8B
BA9E8BB29682AA8D79A18470987A658E705A83644D75553E6240275331184627103D200B
3E240F412814432B17432B18442D1A462F1D48301F4831204A35234D3A29503F2F544334
5645365747385648395446375144345042324F40304F3F2F4F4030504132504233504232
51423251413051402F4F3D2D483828453324443223433122443222453323453223443121
433121412E1F412E1F4532224B3524553C2A6048366C5241765D4B8167558B715F957B68
9E8471A78D7AB09683B99E8B
BAA08CB39784AB8F7BA286729A7D6890735E8668537A5C466E503960432C553A244A321D
452E19462E1A462F1C442D1B452F1D4732204937264B3A2A4A38284A37274B3B2B4D3F30
4E42354F44375044374F43364E43364F44364F42334F40314F4131504233504235504134
4F41334F41325142335848385A49395544345240304F3D2E4A3A2B463628443426443325
4131234030214030214433244A3627523B2B5D4635695140745C4B7F67558A715F947B69
9E8472A78D7BB09683B99E8C
BBA08CB39885AC907DA488749C806C9377638A6E59816550785C466A4F3A5D4530543D2A
5039254B36234734224431204431204734244938294D3D2F50433652463953473C564C41
5A51475B5349595248575046544C4151473C4F44374E41344E41344F43365044384F4237
4C3E344B3D324D3F325041335243355345375143364D3F32483B2F45372C433429413226
3F30233E2F233F31244536294A392B4E3A2B594334665040725C4C7E6756897261947B6A
9E8573A78E7CB09684B99F8C
BBA08DB49986AD927FA68B779E8370977C688F7460876D59806653755C496A523F604937
574230513C2B4B38274533234432224634254838294B3D304E4337524A3F5751475A554C
5B58505C5A525B595257554D534D434F473C4D43374C42344C42354F443752483C554B41
5349404D4239483C32483B314A3D324B3E334B3E32483C3046392E44362B43352A423329
3F30263E3025413429423429443528473426523D2E644F40725D4D7E6858897362947D6C
9E8674A78E7DB09785B99F8C
BCA18EB59B88AF9582A88E7BA187749A816E937A678D7461866F5C7D6755735E4C6A5442
614C3B5844344F3D2D483627453325453426473729493B2E4B3F334E453A504A40524D45
534F47535048524F47504C444E483F4C43394A40354A3F334A3F334C41364F453A53493F
574E445A4F46574C434F443B483D3345393044393044382F43382E44382F44382E41362C
40342B40352B41362C3F342B41362C4B3D30564538655244725F507F6A5B8A7565957E6E
9E8776A88F7EB19785B99F8D
BCA18FB69C89B09684AA917EA48B799E857398806E927B698D7664866F5E7C6656715D4C
6854445E4B3C53413349382A43332543332544352746382A483B2F493E334B41374C443B
4C463E4C473E4B453D4A433B484138473E35463C32463B31463C31483D334B40354E4339
51473D544B41574D43594E45574D4353483F4F443B4D42394B4139473D35433A31413830
423930443A32443C33443E344740374F453A594B3F675649746255816E5F8C7868968171
A08979A99180B19887BAA08D
BDA28FB79D8BB29986AD9482A78F7DA28A789C857497816F927C6B8A7463826D5D786555
6D5A4B6250415645374A3A2D43332641322542332643352944372B45392F463B31463C32
463D34453E35443D34433B3342393041382E41362D41362C42362D43382F453A31483D33
4B40374E433A51463E534941554B42554B43534A424F463F4B423B473F37443C34423A32
443C344740384B433C4E473F504940554B415C4E4369594D78675A8472648F7B6D988474
A18B7BAA9382B29988BAA08E
BDA390B99F8CB49B89AF9785AA9381A58E7DA18A7A9C86769782728F7C6D8775667E6C5E
736255655649594A3E4D3E3344352940312440312541322641332841342941352B40362C
40362C3F352C3E352B3D342B3C332A3B31283B30273B30273C31283D32293F342C42372F
443A32473E354A40394C433C4D453E4D453E4C443E4A433C47413A443F38423D37423D37
45403A4B46404F4A44544E4758524A5D554D655A507063577D6F6388786B9280729B8779
A38E7FAB9584B39B89BBA18F
BEA491BAA08EB69D8BB19A88AD9685A99383A58F80A18C7D9D897B9582748D7C6E847467
7A6A5E6E5E5360524754473D483C324133293F30253E30243E2F243D2F233C2F243B3026
3A2F26392F25382E25372D24362C23352B22352A22352A22362B23372D25392F273B312A
3E342D413831433B34453D36473F3947403A47403B46403A46403A453F39443F3946413C
4C4843524D4857524D5D5853645F586B645D716A617B716785786D8E7F739685789E8C7D
A69182AD9787B49C8BBBA28F
BFA492BBA290B79F8EB49D8CB09A8AAD9788A99485A59283A18F829A897C9282768A7B6F
7F716672655A65594F594D434E423745372D3E30263C2E233A2D22392B20372A1F36291E
34291F33281F32271E30261D2F251C2F241C2F241C2F251D2F251E312720332922352C25
382F293B322D3D35303F3832403A35423C37423D38433E39433E3A423F3A45413D4B4743
514E4A585651605D5868645F706C6578726C827C7589827A8E837994877B9B8B7FA29082
A99586AF9989B69E8DBCA290
BFA593BCA391B9A190B6A08FB39E8EB09C8DAD9A8BAA9789A694879F8E8297887C8F8075
84776D796D646C61595D544B50473F463B333E322A3A2D24372A2035281E33261B312419
2F22182D21172B1F162A1E15281D14281D14281D15291E172A20192B221B2D251E2F2822
322B26342E2937312C3934303B37333D39353F3B383F3D3A403F3C44423E4947444F4E4B
58575461605C6A686372706B7A7772827E7889837D908981958B829B8E83A09185A69487
AC9889B19C8CB79F8FBDA391
C0A693BDA593BBA493B9A393B7A292B4A192B2A092B09F92AD9D90A5968A9D8F8495887E
8C807780756C726860635A53544C45463E383C322B372B2334281F31241A2E21172B1E13
291B1027190E25180E23160D21160D21160E201610211711221913241C1727201A29231F
2C27222F2A26332E2A35312E3734313936343B39373C3C3A3F3F3D4343424A4B4A545553
5E5F5C69686672716E7B797684827E8E8B87948F8A98918A9C938AA0948AA5968BAA998C
AF9B8DB39E8FB8A190BDA492
C0A694BFA695BDA695BBA696BAA597B8A598B7A699B5A69AB4A59AAD9F95A4988E9B8F87
90867D847A73776E6768615B58514C48413C3C342E352B2430261E2D2118291C1326190F
23150B2013091E12091C11091B100A1A0F09190F0A1A110C1B14101D1714201B17231E1B
27221F2A26232E2A28312F2C3432313636343839373B3C3B3F41404648485053525B5E5D
6769687273717C7C7A87868392908D9D9C99A19F9BA19B94A39A92A69A91AA9B90AD9D90
B19F90B6A191BAA392BEA593
C1A795C0A796BFA898BEA899BDA99BBCAA9DBCAB9FBBACA1BBAEA4B5A9A1ABA199A29890
988E878C837D7D76716E68635E58544D48453E3A35332C262D231D281E1724191120150D
1D1109190E07160C05150B05130A05120905110A06120C09140F0B16120F1A16131D1A18
211F1D2523222928272C2D2C303130343635383A3B3D40404347484C5151575B5C636768
7072737B7D7D86878691918F9A9A97A09F9BA5A29DA7A19BA9A098ABA096AEA095B1A194
B4A294B8A393BBA493BFA594
C1A896C1A998C0AA9AC0AB9CC0AD9FC0AEA2C0B1A5C1B3A9C1B5ACBCB2AAB4ABA4A9A19B
9E9792938C87857F7A77716D68635F57535045413E35312E2B2421251B162015101B100B
160C071309051007030D05010B05010A05020905030B07060D0A09100E0D141211181717
1C1C1C202121252626292B2C2D3132323638393C3E4145474A4F51555B5D6267696E7374
797D7E8588899194939D9F9DA7A7A5AAA9A6ACA9A5ADA8A2AFA69EB0A59CB2A499B4A498
B7A497BAA596BCA595BFA694
C2A896C2AA99C2AC9CC2AE9FC3B0A2C3B2A6C4B6ABC6BAB0C9BFB8C7BEB8BDB5AFB2ABA6
A8A29D9D9792908A86817C79726E6C625F5E514F4E3E3C3C2F2B2A241E1C1D1512170F0C
1109060C05030902000701000500000200000101010303030707070A0C0D0E1011131516
181B1C1D2121222628282D2F2E3336353B3E3D4346484E51545B5E61676A6E74767B8082
878C8D9397989FA3A2A9ACABB3B7B7B7B9B7B4B2AEB4AEA8B4ACA4B5AAA0B6A89DB8A79B
B9A799BBA797BEA796C0A795
C2A997C3AB9AC3AD9DC4B0A1C5B3A5C6B6AAC8BAAFCBBFB6CEC5BECEC7C1C5BFBABBB5B0
B0ABA7A5A19D9895928B88857E7B78706D6C605E5E4F4D4D3E3C3C2F2D2D211E1E171313
0E0B0A08040405010102000100000100010300030500050702070A060B0E0B11140F1619
141B1E19212521282C28303530383D3A4247454E52525B5F60686C6E75797C8285898F91
969B9DA2A7A8AEB2B2B6BABABABDBDBCBDBBBBB8B4B9B4AEB9B0A9B9AEA4B9ACA1BAAA9E
BCA99BBDA899BFA897C0A795
C3A997C4AC9BC5AF9FC6B2A3C7B5A8C9B9ADCBBDB3CEC2B9D1C8C1D4CDC9D0CBC7C6C1BD
BBB7B4B1ADAAA5A29F9795938A88877C7B7A6E6C6C5F5D5D4F4E4E3F3E3F303031242324
1B181A1211130C0B0E08080C06090D050A0F050B11050C12050E140711170B151C0F1B20
1621271D282E242F352D383E384348444F54515C61606A6E6F777B7E85888C92959A9FA2
A7ACAEB4B8B9BEC2C3C5CACAC6C9C9C3C3C1C0BDB9BEB8B2BDB4ADBDB1A8BDAFA4BDADA0
BEAB9DBFAA9AC0A998C1A896
C3AA98C4AD9CC6B0A0C7B3A5C9B7AACBBBAFCEC0B5D1C5BCD4CCC4D9D3CED9D4D0D0CCC8
C6C2BFBCB8B5B2AFADA6A4A29795948987867A78786A69695C5A5B4E4C4D424041363537
2C2D2F2325291C1F23161A1F14191F13191F1019200F1A210F1B23101D2513202818262E
1E2C3425333B2E3B4338454C445157525E64606B706F797E7F878C8E95999CA3A6AAB0B3
B9BEC0C5C9CBCDD2D4D2D8D9CFD3D3C9C9C6C5C2BDC3BCB6C1B8B0C0B4AABFB1A6BFAFA2
BFAD9FC0AB9CC0A999C1A896
C3AA98C5AD9CC7B1A1C8B4A6CAB8ABCDBDB1D0C2B7D3C8BED7CEC7DCD6D0E0DCD8DBD8D6
D1CECBC7C4C2BCBAB8B0AFADA2A1A09493938786867978786C6C6D5F6061525456484A4D
404245393B3F32353A2B3035272D32252C31242C33232D34232F3625323A28353E2C3942
313F4839474F4250574D5A6058646A657076747E82828B9091999C9FA6A9AEB4B6BCC2C3
C9CED0D4D9DBDCE3E5DBE1E2D3D5D4CDCCC9C9C5C0C6BFB8C4BAB2C2B6ACC2B3A7C1B0A3
C1AEA0C1AC9CC1AA99C2A897
C4AA98C5AE9DC7B1A1C9B5A6CBB9ACCEBEB2D1C3B8D5C9C0D9D0C8DED7D1E3DFDBE3E0DD
DBD9D7D2D0CEC7C6C4BABAB8AFAFAEA4A3A39797978989897B7B7C6F6F706465675B5D5F
5355584B4E5246494D41454A3D42483A41473942483A434A3A454C3C484F3E4B53435058
49565E505D6559666C636F756D787E7A8489889195969EA2A4ABAEB2B8BAC1C6C7CED3D4
D8DEDFE2EAECE3EBEDDCDFDFD5D6D4D0CECACCC7C1C9C1B9C6BCB3C5B8ADC3B4A8C3B1A4
C2AFA0C2AC9DC2AA9AC2A997
C4AA98C6AE9DC8B1A1CAB5A6CCBAACCFBEB2D2C4B9D6CAC0DAD0C8DFD8D2E5E2DDE9E9E5
E6E5E3DDDCDBD3D3D1C9C8C7BDBDBCB1B1B0A6A5A59A999A8D8E8F82838478797B707173
696A6C6263655C5E61575B5F53585C52575C52585E52595F535B62555E655962695E686F
656E756C767C737D837B848A858E928F989C9CA3A7A9B0B2B8BDBFC5CACBD0D4D6DADEE0
E5ECEEE8EFF1E2E6E6DCDDDCD6D5D2D2CEC9CEC7C1CBC1B9C8BDB3C6B8AEC5B5A9C4B2A4
C3AFA1C3AD9DC2AB9AC2A997
C4AA98C6AE9DC8B1A1CAB5A6CCBAACCFBEB2D2C4B8D6C9BFDBD0C8E0D8D1E6E1DCEFEEEB
F2F3F1EAEAE9E0E0DFD5D6D5CBCBCBC1C1C1B8B7B8ADADAEA2A2A398989A8D8E90858687
7E8080787A7B7375776F72746E71746C6F736B6F736B70756D727770757A747A7F7A8085
7F868B868D928D9397949B9E9EA4A6A8ADB0B4B8BAC0C4C6CBCFD1D6DADBE2E5E6EAEFEF
EBF0F1E7EBEBE1E3E2DCDBD9D7D4CFD3CDC7CFC7BFCCC1B9C9BDB3C7B9ADC6B5A9C5B2A4
C4AFA1C3AD9DC3AB9AC2A997
C4AA98C6AE9CC8B1A1CAB5A6CCB9ABCFBEB1D2C3B7D6C8BEDACFC6DFD6CFE5DFD9ECE9E5
F4F5F3F7F8F8EEEFEFE3E3E3D9D9D8D0D0CFC8C8C7C0C0C0B7B7B8AEAEAFA5A5A69D9D9E
9797989292938E8F8F8A8B8C86888985868884858884868985888B888B8E8B909393979B
9B9FA3A0A4A7A6A8ABAEB0B2B7BABAC0C2C3C8CBCBD3D5D5DDE0E0E5E8E9ECF0F2F0F7FA
EDF3F5E6E8E8E0E0DEDBD9D5D7D2CCD3CBC4CFC6BDCCC1B7CABCB1C8B8ACC7B5A8C5B2A4
C4AFA0C4AD9DC3AB9AC3A997
C4AA98C6AD9CC8B1A0CAB4A5CCB8AACFBCAFD2C1B5D5C7BBD9CDC3DED4CBE3DBD4E9E4DF
F0EEEAF8F9F8FAFBFBF2F2F1E7E7E6DDDDDCD6D6D5D1D0D0CAC9C9C3C2C1BCBBBAB4B4B4
AEAEAEAAA8A9A5A4A5A2A1A19F9E9F9D9D9E9C9C9D9C9C9E9D9D9F9E9FA0A2A3A4A7A7A8
ADACACB5B5B4BCBCBCC4C4C3CBCBCAD1D1D1D9DAD9E1E2E1E9EBEBF1F4F5F5FBFEF2F8FB
EBEDEDE4E4E2DFDCD9DAD5D0D6CFC8D2C9C1CFC4BBCDBFB5CABBB0C8B8ABC7B5A7C6B2A3
C5AFA0C4AD9CC3AB99C3A997
C4AA98C6AD9BC7B09FC9B3A3CCB7A8CEBBADD1BFB2D4C4B8D8CABFDCD0C6E1D7CFE6DED8
ECE7E2F2EFECF9FAF9FBFCFBF4F4F3EBEBEAE3E2E2DDDDDDD9D9D9D4D4D4CFCECDCCC9C9
C8C5C5C3C0C0BEBBBABAB7B7B7B4B4B4B2B2B3B0B0B3B0B0B4B1B1B5B2B1B5B2B0B7B4B1
BBB9B5BFBCBAC4C2C0CCCAC7D3D2D0DDDCDAE5E5E4ECEDECF3F5F4F8FDFEF5FAFCEEF1F0
E8E7E5E2DFDBDDD8D2D9D1CBD5CBC3D1C6BDCFC2B7CCBDB2CABAADC8B6A9C7B4A5C6B1A2
C5AF9FC4AD9CC3AB99C3A996
C4A997C5AC9AC7AF9EC9B2A2CBB5A6CDB9AACFBDAFD2C1B4D5C6BAD9CBC1DDD1C8E2D8D0
E7DFD8EDE7E2F3F0ECFAFBFAFCFDFDF5F5F4EDEDECE8E7E7E5E4E4E2E1E1DFDDDDDAD7D7
D7D3D3D6D1D1D3CFCED0CBCACCC8C6CBC6C4CAC5C3C8C3C1C8C3C0C9C3C1C9C3C0CAC4C0
CDC7C3D2CCC8D9D3CFDFDAD6E6E2DFEDEBE8F2F1EFF6F7F6FAFEFEF8FCFDF0F2F1E9E9E6
E4E0DCDFD9D3DAD2CBD6CDC4D3C7BED0C3B8CEBFB3CBBBAFCAB8ABC8B5A7C7B2A4C6B0A0
C5AE9EC4AC9BC3AA99C3A996
C3A997C5AB9AC6AE9DC8B0A0CAB3A3CCB6A7CEBAABD0BDB0D3C2B5D6C6BAD9CBC0DDD1C7
E2D7CEE7DED7ECE6E0F2EEEAFBF9F8FFFFFFFBFAFAF1F0EFEBE9E8EAE7E7EAE8E8EBE8E7
E9E5E4E5E1E0E1DCDBE2DCDAE2DCD9DFD7D3DAD2CED7CFCBD7CFCAD6CEC9D6CEC7D6CEC8
D8D0CADDD5CFE3DBD5E8E2DDEEE9E5F4EFECF7F5F2F8FAF9F6F8F8EFEFEDEAE7E3E4DFDA
DFD8D1DBD2CAD7CCC3D4C7BDD1C3B8CEBFB3CCBBAFCAB8ABC9B6A7C7B3A4C6B1A1C5AF9F
C4AD9CC4AB9AC3AA98C3A896
C3A996C4AA98C6AD9BC7AF9EC8B1A1CAB4A4CCB6A7CEB9ABD0BDAFD2C0B3D5C5B8D9C9BE
DCCEC4E0D4CAE5DAD2EAE1DAEFE9E3F5F1EDFBF9F6FBF9F7F5F2F0F2EDEBEFEBEAEFEAE9
EDE8E6EDE7E4EDE5E2EAE1DCE7DDD7E4DAD4E3D8D1E0D6CDDDD2C9DCD1C8DDD3CBDED4CC
E0D6CFE4DBD4E9E1DBEEE8E3F2EDE9F4F0EEF8F7F6F5F4F2EDEAE6E7E2DDE2DBD4DED5CD
DACFC6D7CAC0D4C6BBD1C1B6CEBEB1CCBBAECBB8AAC9B5A7C8B3A4C7B1A1C6AF9FC5AD9D
C4AC9BC4AB99C3A997C3A895
C3A895C4A997C5AB99C6AD9BC7AF9EC8B1A0CAB3A2CBB5A5CDB8A8CFBAACD1BEB0D3C1B4
D6C5B8D9C9BDDCCEC3E0D3C9E4D9D0E9DFD7EEE5DEF5EEE8F9F4EFFAF4EFF4EDE8F0E8E3
F0E8E4F0E7E3EEE3DEEBDFD9E7DCD5E7DBD4E7DAD2E6D9D0E5D9CFE4D8CEE3D7CEE3D8CF
E4DBD2E5DFD7E9E2DCEDE8E3F3F0EDF4F2EEEFEAE5E8E1DBE3DAD3DFD4CBDBCFC5D8CABF
D5C6BAD2C2B6CFBEB1CDBBAECCB8AACAB6A7C9B4A5C8B2A2C6B0A0C6AF9EC5AD9CC4AC9B
C4AB99C3AA98C3A996C2A895
C3A896C3A997C4AA98C5AB99C5AC9AC6AD9CC7AF9EC8B0A0C9B2A2CBB4A4CCB6A7CEB9A9
D0BBACD2BEB0D4C1B4D6C5B8D9C8BCDCCCC1E0D1C6E3D6CBE6D9CFE8DCD2ECE1D6EDE2D9
EBE0D6EADED5EADED6E9DDD5E6D9D1E2D5CCE0D3C9E0D2C7E0D1C6E0D2C7E0D2C7DFD1C6
E0D3C9E5DBD2EBE3DBEAE2DAE6DCD4E3D8CFE0D3CADCCEC4D9CABED6C5B9D3C2B5D1BFB1
CFBCAECDB9ABCBB7A8CAB5A5C9B3A3C8B1A1C7B09FC6AE9EC5AD9CC5AC9BC4AB9AC4AA98
C3AA97C3A996C3A896C2A895
C2A895C3A895C3A896C3A996C4AA97C4AA98C5AB99C5AC9AC6AD9BC6AE9CC7AF9DC8B09F
C9B1A0CAB2A2CBB4A4CCB6A6CEB8A8CFBAAAD1BCADD3BEAFD4C0B1D5C2B3D7C3B5D7C4B5
D7C4B5D7C4B5D7C5B6D8C6B8DBC9BADCCABCDCCBBDDCCBBEDCCBBEDCCBBEDDCCBFDDCDC1
DDCDC2DAC9BDD7C5B8D5C4B6D4C2B4D2BFB1D1BDAFCFBBACCDB8A9CCB6A7CBB4A5C9B3A3
C8B1A1C7B09FC7AF9EC6AE9DC5AD9CC5AC9AC4AB9AC4AB99C4AA98C3AA97C3A997C3A996
C3A896C3A895C2A895C2A794
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.754707 0.245293 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
69.000 12.813 moveto
(deg) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
5C6E745C6E755C6E755C6E755D6F755D6F755D6F755D6F755D6F755D6F765E6F765E6F76
5E70765E70765E70765E70765F70775F70775F70775F70775F70765F70765F70755F6F74
6070765F71775F71785F71775F72785F72785F72785F72785F71785F72785E72785F7278
5E71785F72785E72785F73795F73795F737A5F747A5F747A5F747B60757C60757C61767D
62788061767D60757C60747B5F737A5F73795F73795E72795E72785E71785E71775D7077
5D70765D6F765C6F755C6E75
5C6E745C6E755D6F755D6F755D6F765E70765E70765E70765F70775F71775F7177607177
607178607278617278617279617379627379627379627379637379637378637277637175
63737863747A63757B63757B62757B62757B62757B62767C63767C62767C62767C62767C
62767C62767C61777D62787E62787F637980637A81637B81637B82647C83647D84657D85
667E86657D84647B83637A8163798062777F62777E61767D60757C60747B5F737A5F7279
5E72785E71775D70765C6F75
5C6E745D6E755D6F755E70765E70765F70765F7177607177607278617278617379627379
62737963737A63747A64747A64757B65757B65767C66767C66767C67767B67757A677478
67767C67777D67787E66787E66787E65797F65787E65787D65787D64787E64797E63797E
63797E63797F637A80647C82657E84667F8667808768818868828968838B69848C69858E
69848C69838B68818A678088667E86657D85657C83647B8263798062787F61767D60757C
5F737A5E72795E71775D6F76
5C6E755D6F755E6F755E70765F707760717760717861727862727862737963737A63747A
64757B65757B66767C66767D67777D68787E69787E69797F6A797F6B797E6B797D6B787C
6B7A7F6B7B806A7B816A7C82697C82687B81677A8065797E65787D65787D64797E647A80
647C81647D83657E8466808667828869848B6A858C6B878E6B88906C8A926D8C956F8F98
6D8C956C8A936C88916B868E6A848C69828A678088667E86657D84647B8263798062777E
61757C5F737A5E72785D7076
5D6E755D6F755E6F755F707660717761727861727862737963737A64747A65757B65767C
66767D67777D68787E69797F6A7A806B7A806C7B816D7C826E7D826F7D826F7D826F7C80
6F7D836F7E856E7F856D7F856D7F856C7F846B7E836A7D82697C81687B80677B80677C82
677E84677F8667818868838A69878D6B89906D8A926E8D956F909870919A72939D7395A0
72939D71909A6F8E976E8C956D89926C87906A858D69838B688089667E86657C84637A81
62777F60757C5F73795D7077
5D6E755E6F755F707660717761727861727962737963747A64757B65757C66767C67777D
68787E69797F6A7A806B7B816C7C826E7D836F7E84707F85728186738287748287748186
7482877382887283897183897083897082886F82886E82876D81866C80856B7F856B8086
6B82896B848B6C868D6C88906D8B936F8F9770919972939C74969F7599A2769AA4779BA6
7699A47597A173949E72929C718F996F8C966D89936C87906A848D68818A677F87657C84
63798161767E5F747A5E7177
5D6F755E70765F707760717861727862737964747A65757B66767C67777D68787E69797F
6A7A806B7B816D7C826E7D836F7E8471808572818774838876848A78878C7A898F7A898E
78878C77868C76868C75868D74868C74878C73878C72868C72868C71868C70878C70878D
70888F708A91708C93718E9672919973949D7598A2779BA4789DA77AA0AB7CA3AE7BA2AD
7AA0AB799DA9779BA67698A274949F72919B718E986F8B946D88906B848D698189677E86
647B8362787F60747B5E7178
5D6F755E707660717761727862737963747A65757B66767C67777D68787E6A797F6B7A80
6C7B816E7D836F7E84707F8572808673828875838A77858B79888E7D8C928290957E8C92
7C8B907A8A8F798A8F798A90788B91778B90778B91768C92768C92768D92758E94758F95
76909676929876949B76959D7898A1799BA47A9EA77BA1AC7DA4AF7FA7B380ABB880AAB6
7FA7B47DA4B17CA1AD7A9EA9789AA57696A174939D728F996F8B956D88916B848C688088
667C8463798061757C5E7278
5D6F755F707660717862737963747A64757B66767C67777D69787E6A797F6B7B806D7C82
6E7D83707E8471808673818774838976848A77868C79888E7B8A907D8C91859397808E94
7E8D937D8D937D8D937C8E947C8F957B8F957B8F947A90957A91977A93997A969B7B989D
7B999F7B99A07C9AA27C9CA47D9EA77DA1AA7FA4AE80A8B382ACB884B0BD86B5C385B2C0
83AFBD82ACB980A8B47EA4B07CA0AB799CA77798A274939D728F996F8B946D878F6A828B
677E86647A8261767D5F7279
5D6F755F707661717762737964757B65767C67777D68787E6A797F6C7B806D7C826F7D83
707F8472808674828775838977858B78868C7A888E7B8A907C8A927D8B927F8C93818F95
8190968090968091978091987F92987F93997F93997E94997E959B7F979D7E9A9F7F9DA1
809FA480A1A681A2A981A3AB83A5AE83A8B184ABB484AEB986B2BE88B6C48BBDCC8ABCCB
88B8C686B3C184AFBC82AAB780A6B27DA1AD7A9CA77798A275939D728E986F89926B858D
688088657C8362777E5F7279
5E6F755F707761727863737965757B66767C68787D6A797F6B7A806D7C816F7D83717F84
72808674828776838978858B79878D7B888F7D8A907F8D947E8C927D8A90808D93829096
83919883939983949B83959C83969D83969D83979D82979D81999E829CA1829FA382A2A6
83A5A984A7AC85A8AD86AAB087ABB388AEB789B0BA8AB3BE8AB7C38DBCCA8FC2D290C5D5
8EC0D08BBBCA89B6C486B1BE84ACB881A6B27EA1AD7B9CA77797A174919B718C956D8790
6A828B667D8563787F5F737A
5E6F7660717762727863747A65757B67777D69787E6B7A806D7B816F7D83717E84728086
74828776838978858B7A878D7C898F7E8B91808C937C898F808C92818E94838F95849198
85939A86959C87979E8799A0879AA1879AA1879AA0869AA085989E85999F859BA2869EA5
86A2A788A8AD89ACB18BAEB48DB0B78DB2BB8EB5BF8EB7C38EBBC790BFCD91C4D494CADB
93C9DB90C3D38EBDCC8BB7C588B2BF85ACB881A6B27EA0AB7A9AA576959F738F986F8992
6B848C677E8663798060737A
5E6F7660717762727964747A66767C68787D6A797F6C7B806E7C82707E84728085748187
76838978858A7A878C7D898E7F8B91818D93848F958A959B869198859197869298879399
87949B89969E8A9AA18B9CA38B9DA48C9DA48B9CA38A9BA288979E87959C87959C87979E
889BA38BA4AB8DABB18FB0B791B4BB92B6BF93B9C393BBC793BDCA93C1CF94C6D596CADB
97CEDF95CADB93C4D490BECC8CB8C589B1BE85ABB781A4B07D9EA97998A275929B718C94
6C868E688087647A8160747B
5E6F7660717763737965757B67777C69797E6B7A806E7C81707D83727F84748186768388
78848A7A868C7D888E7F8B90818D92849095848F95899398899398889398899499899399
8A959B8B989E8D9BA390A0A690A0A690A0A6929DA48B959C889399858E9585909787979E
89979F8C9CA490A4AC95B0B796B7BE97BAC297BCC697BEC996C0CC96C2D097C7D699CBDC
9BD1E39BD1E398CBDC95C5D491BECC8DB7C489B0BC84A9B480A2AD7B9BA577949E728E97
6E8790698189657A8260747B
5E707661717863737966757B68777C6A797E6D7B806F7D82717E84738085768287788489
7A868B7C888D7F8A8F818C92848F948690958E969A8C94998B94998B93998B959A8B949A
8B949A8C969C8E9AA1929FA6949FA68C939A8C92998B90978A8F96899198878F96869199
85939A88989F8C9FA695ABB29BB7BE9CBDC49CBFC89BC1CC9AC2CE99C4D199C7D69BCCDC
9DD1E29ED4E59ED1E19BCCDB97C4D292BCC98DB4C188ADB883A5B07E9EA87997A1749099
6F89926A828A657B8361757B
5E707661727864737966757B69787D6B7A7F6E7C81707E83737F8575818677838879858A
7B878C7E898E808B90848E9487929787919592999D8F969B8E95998D93988D94998D9399
8D93988C93998E949B8D959D929CA38F9AA28E99A08E98A08D969E8C97A08B98A08B9BA4
8A9CA5889DA7879CA58BA3AB96AFB7A0BEC5A0C3CC9FC5CF9DC5D09CC5D29CC8D79DCDDC
9FD2E3A0D6E8A2D5E7A1D3E29DCBD996C2CF91B9C58BB1BC86A9B480A1AB7B99A376929B
718B936B838B667C8461757C
5F707661727864747A67767C6A787E6D7A806F7D82727F847481857782877984897B868B
7D888C7F898E818B918690968E989E8D959A8F969A9096998F969A8F969A8F959A8F9398
8D91968C90958A8C928889908C8E958F949B90969D9099A1909AA18F9BA38F9CA48FA0A9
8EA3AB8FA5AE8DA3AD8DA8B190ACB59BB8C0A4C5CDA2C7D0A1C7D29FC7D49ECAD8A0CDDC
A1D2E2A2D6E8A3D7E8A3D4E5A1D0DE9BC6D495BDCA8FB4C089ACB783A4AE7D9CA678949D
728C956C848D677D8461757C
5F707662727865747A68777C6B797E6E7B80717E837480847682867984887B858A7D878C
7F888D80898E808A8F808A8E8890958F94988F9497919599929699929698929598919397
90919590929791949990919790919891929991939A90939B90939B8F959D8F969F8F98A1
909BA590A1AB91A4AE90A8B291ADB796B3BDA0C0C9A5C8D1A3C8D3A1C8D4A0CAD8A1CEDD
A3D2E2A4D7E7A8DCEEACDDEEA5D3E29FCBD898C1CD92B8C48BAFBA85A6B17F9EA879969F
738E966D868E687E8562767D
5F707662727865757A69777C6C797E6F7B80727E837581857883877B85897D878B7F898D
818A8E818A8F7F878C7881867A8389898F93909598939699949599949698949698949396
92919592929695989C95989E95979D95969D94979D94979D94979D93989F9399A1939CA4
949FA795A2AB96A4AF96A6B195A8B396ACB79BB5BFA2C0CAA4C6D1A3C8D4A2CAD7A3CDDB
A4D1E1A5D5E5A5D6E7AFDEEEAAD7E6A2CDDB9BC4D195BBC78EB2BD88A9B381A0AA7B97A1
758F986E878F687E8662767D
5F707663737866757B6A787D6D7A7F707D81747F847782867A84887D878A80898D828B8E
848C90858D91848B91848C91878D918E939594979A97989A97989A989799989698979597
969395969497989A9E9A9DA39A9CA2999BA0989AA0989AA097999F9699A0979CA397A0A7
98A2AA99A5AD9BA8B19BABB59BAEB89DB2BD9FB8C3A2BEC8A4C4CEA4C7D2A4CAD6A4CEDB
A5D1DFA5D4E3A6D6E7B2E0EEADDAE7A6D1DE9FC7D498BDC991B4BF8AABB583A2AC7D99A2
7690996F8890697F8662767D
5F707663737967757B6A787D6E7B7F727D827580847983877D868980888C838B8E868D90
888F928A91948C92958E949891989B959B9D999C9D9A9C9D9B9B9D9C9A9C9C999B9C9899
9B96989A97999B9A9D9D9FA39EA1A69D9FA49C9EA39B9EA39B9DA29A9CA29A9EA49BA2A8
9BA5AC9BA7AF9DABB29FADB69FB1B9A0B4BDA2B9C2A4BFC9A5C3CDA6C7D1A5C9D5A5CDD9
A5D0DDA4D2E1A3D4E4B4E2F1B1DEEDA9D4E2A2CAD79AC0CC93B6C18CADB785A4AD7E9BA4
77919A70899069808763777E
60707663737967767B6B797D6F7B80737E827781857B84887F878A838A8D868D908A9093
8D939590959893989B959B9D999EA09BA0A29EA0A19FA1A1A0A0A1A09F9FA19D9EA09C9D
A09A9C9F9A9C9F9C9FA1A0A4A2A4A8A1A2A7A0A0A59F9FA49E9FA39D9EA39DA0A59DA2A8
9EA6AC9FA9AFA1ADB3A2B0B7A4B4BAA4B6BDA4B9C1A6BEC6A7C2CBA8C6D0A7C9D4A7CCD8
A6CFDCA4D0DFA0D0E1B1DFEFB6E3F1ADD8E5A4CDD99DC2CE95B8C38EAFB987A5AF809CA5
79939B7189916A808863777E
60717764737968767B6C797E707C80747F837982867D858881898B868C8E8A8F928E9395
929698969A9B9A9EA09DA1A3A1A4A5A2A4A5A3A4A5A4A4A5A5A4A4A5A3A3A5A2A2A5A1A1
A5A0A0A59FA0A49FA1A5A2A4A6A5A9A5A5A9A4A4A8A3A3A7A1A2A6A0A2A6A0A3A8A1A6AB
A2A9AEA3ABB1A5AEB5A6B2B9A8B6BDA9B9BFA9BCC2A9BFC7AAC2CBAAC6CFAAC9D4A9CCD7
A8CEDAA4CFDD9DCCDCA2D3E4B1DFEEB2DDEAA6CEDB9EC4CF97BAC590B0BA89A7B0819DA6
7A949C728A926B818863777E
60717764737968767B6D797E717C817680837A83867F8689848A8C898E908E9293939697
989A9B9CA0A0A1A6A6A4A9A8A8AAAAAAA8A8AAA8A8AAA8A8AAA8A8AAA8A8ABA7A7ABA6A6
AAA5A5AAA5A5AAA4A5A9A5A6AAA7A9A9A7AAA8A7AAA7A7AAA5A5A9A4A6A9A4A6ABA5AAAE
A7ADB1A8B0B4AAB2B7ACB6BBADB9BFADBBC2AEBFC5ADC1C9ADC5CDAEC8D1ADCBD5ADCED8
ABD0DCA9D2DEA5D0DDA3D0DEA4D1E0A8D3DFA6CEDAA0C5D099BCC692B2BC8BA8B2839FA7
7B959D738B936C818964787E
60717764747969777B6D7A7E727D817780837C848681878A868B8D8C8F91929495979899
9D9D9CA2A2A1A7A7A6ACACABAEAEADAFADACAFACABAFACABAFACABAFACABB0ACABB0ACAB
B0ABABB0ABABAFABABAFACACAFABACADAAABABA8AAAAA7A9A8A6A9A7A7A9A7A8ABA8ABAF
AAAFB2ADB2B6AEB5B8AFB7BCB1BBC0B2BFC4B3C2C8B2C4CBB2C7CEB2CAD2B2CDD6B1D0D9
B1D3DCAFD5DFADD4E0ADD7E5AEDAE8ACD6E2A8CFDBA2C7D29CBEC894B4BD8DAAB385A0A8
7D969E748C936C828964787F
60717765747969777B6E7A7E737D817880847D848783888A898C8E8F91919596969C9B9B
A4A0A0AAA5A4B0ABAAB5B1AFB6B3B0B6B2B0B5B1AFB5B0AEB4B0AEB4B0AFB5B0B0B6B1B0
B6B1B0B6B2B0B6B1B0B5B2B1B4B1B1B2AFAFB0ACADADAAABABA8A9A9A8AAA9AAACABADAF
ADB0B3AFB4B7B2B7BAB4BBBFB6BFC3B7C3C7B7C5CBB8C8CEB7CAD1B7CCD4B7CFD8B7D2DB
B7D5DEB6D8E2B4D8E3B4DCE8B6E1EEB3DDE9ADD3DEA6CAD49FC0C997B6BF8FABB486A1A9
7E979F768D946D828964787F
60717665747969777B6E7A7E737D807981837E848784898A8B8D8E919292989796A09D9B
AAA6A5B5AEACBDB4B0C0B8B4BFB8B4BDB6B3BBB5B2BAB4B1B9B3B1B9B3B1B9B3B2BBB4B2
BCB5B3BDB7B4BCB7B4BBB6B5BAB5B5B7B2B2B4AFB0B1ACADAEA9ABACA8AAACABADAEAEB0
B0B3B5B3B7B9B6BBBDB9BFC2BBC3C6BDC7CABDC9CDBDCBD0BDCDD2BDCED5BDD1D8BDD4DC
BCD8E0BDDBE4BCDDE7BCE2EDBBE4F0B9E3EFB1D7E2AACDD6A2C2CB9AB8C091ADB588A3AA
80989F778D956E838A65787F
60717665737969767B6E797D747D807980837F848686898A8C8E8E9392929A9796A29C99
ACA6A3BAB1ADC4B9B3CBC0B9C7BDB7C3BAB5C0B7B4BEB6B3BDB5B2BDB5B2BEB5B2C0B6B4
C1B8B5C3BBB8C3BDBAC2BDBBC0BBB9BCB7B6B7B2B2B4AEAEB0ABACAFAAABAFACADB1B0B1
B3B5B7B7BABCBABEC0BEC3C5C1C7CAC2CBCDC3CDD1C3CFD3C2D0D5C2D2D8C2D4DAC2D6DD
C2DAE1C3DEE6C3DFE8C4E6EFC3E7F1BFE6F1B7DBE4AED0D9A6C5CD9DBAC294AFB68BA4AB
8199A0788E956F838A65797F
60707665737869767A6E797D737C7F7980827F848686898A8E8E8E9593929D9896A39B97
A9A29DB8AFAAC7BAB4D1C3BBCDC0BAC8BCB7C5BAB5C1B7B2C0B6B2C1B7B4C2B9B6C6BCB9
C9BEBACBC0BBCAC1BCC8C1BDC5C0BDC1BBBABBB5B3B6AFAEB2ABABB0AAAAB0ACADB2B0B2
B6B6B7BABBBDBEC1C2C3C5C7C6CACCC8CED0C8D0D2C9D2D5C7D3D7C6D5D9C7D7DCC7D9DF
C7DCE2C8DFE6C8E2E9CCE9F0CBECF4C6EAF3BCDEE6B3D2DAA9C7CFA0BCC396B0B88DA5AC
839AA1798F966F848B66797F
60707664737869757A6E787C737B7E797F817F83858788898F8E8E989493A09A97A69E9B
AEA5A0BFB3ACCCBDB5D6C5BCD1C2BACCBEB7C7BBB5C4B7B2BFB3AEBEB2AEBFB3AFC3B6B2
C9BBB6CFBFBACFC1BDCCC1BDC9C2BEC5BFBCBDB6B4B7AFAEB3AAA9B0A9A8B0ABABB3B0B0
B7B6B7BCBDBEBFC1C2C3C6C7C8CCCDCCD1D2CDD4D5CED6D8CDD6D9CBD7DBCBD9DECCDBE0
CDDDE3CCE0E6CCE2E8CFE7EDD0ECF3CBEDF4C1E0E8B7D5DCAEC9D0A3BEC499B2B98FA7AD
859BA27B909670848B667980
6070766472776874796C777A727A7C777D7F7E8283868787908E8D9B9694A49C98A9A19D
ACA39FBBAFA8CCBCB3D9C6BCD4C2B9CFBEB6CABBB4C6B7B0C1B2ACBBADA7B7ABA6B5AAA5
BBAEAAC3B4AFC8B8B3C7B7B2C3B6B2C1B7B3BCB3B1B7AEABB3A9A7B0A8A6B0AAA9B3B0AF
B7B6B6BFC0BFC2C3C3C8C9C9CED0CFD2D4D5D2D6D7D3D9DAD2DADCCFDADDCEDBDECEDDE1
D0DFE4D1E2E6D3E5E9D7EAEED7EDF2D1EEF3C6E2E8BCD7DDB2CBD1A7BFC59CB4BA91A8AE
879CA27C909771858B667980
5F70766372776773776B757970777A757A7C7C7F808485858F8D8C9F9A98B0A8A3B1A6A1
B1A7A1BDB0A8CEBCB2DCC7BCD7C3B9D1BFB6CCBBB3C8B8B0C3B3ACBDADA6B8A9A3B1A49F
AEA29DB2A5A0B9ABA7BEAFAABFB1ADBEB3AFBBB1AEB7ADAAB3A9A6AFA7A4AEA7A6AFABAA
B0ADADB7B6B6BEBDBBC6C5C4CFCECCD1D3D1D5D7D6D8DCDBD6DCDCD3DCDECFDBDED0DCE0
D2DFE3D4E3E7D8E7EBE0EEF1E0F2F6D8F1F6CCE5EAC1DADFB6CED3ABC1C79FB5BB94A9AF
889DA37D919772858B677A80
5F6F756270756571756973766D7477727779777A7B7F7F7F8B89889A9492AFA39EBBADA6
BCAEA7C4B4ABD0BDB2DDC7BBD8C3B8D3BFB5CEBBB1CABAB0C6B5ADC0AFA7BBA9A1B6A59E
B5A59DB6A69EB9A8A1BCACA6BEAFA9BDB0ABBBAFABB7ACA8B3A8A4AFA6A2ADA5A3ADA8A7
AEAAABAFB0B1AFB2B3B1B6B7C0C1C1C5C9C9C9CDCCCFD3D3CFD5D5CFD7D8CED9DBD0DCDE
D3DEE1D5E2E5DDEAECE4F0F3E7F8FAE0F7FAD3E9EDC7DDE1BAD0D4AEC3C8A2B7BB96AAAF
8A9EA37E929773868B677A80
5E6E73616F73646F736770736A71746D72747274757676767A77768D87849F938FB0A19B
B9A9A2C4B2A9D0BCB1DDC7BAD9C3B8D4BFB4CEB8AEC9B4AAC7B4AAC5B2AAC1AEA6BEAAA2
BDA89FBEAAA1BFABA3C0AEA6C1B0A8BDAEA7BAADA8B7ABA6B3A7A3AFA6A2ADA5A1ADA8A5
AFACAAB1AFAFAFB0B1A9AEB0AEB3B4B5BBBCBBC2C3C3C9C9C8CECECCD3D4CED6D7CFD9DB
D2DDDFD4E0E3DEE9EBE6F1F1EAF7F8E5FAFCD9EDF0CCE0E3BFD2D6B2C5C9A5B8BC98ABB0
8C9EA37F929773868C687A80
5E6D73606D72626D71646D71666D70696D6F6B6D6E6D6D6D6F6B6B827C79958B86A59892
B2A29BC2AEA5D1BAAEDEC5B8DBC4B8D5BFB4D0B9AFC9B3A8C2ACA2BFA99FBCA69CB9A298
B49E95B59F95B7A097B9A49BBBA8A0BBAAA3BAAAA4B7AAA4B3A7A2AFA5A0ADA49FADA7A2
B1ADA9B4B2AFB4B3B2B3B4B4B4B7B7B5B9B9BABEBEC2C6C5C7CCCBCAD1D0CDD5D4CFD9D9
D1DCDDD5E0E1E1E9E9E9F0EFEAF4F5EBFCFDE0F1F3D2E3E5C3D4D7B5C6C9A7B9BC9AACB0
8D9FA380929774868C687A80
5D6D725E6C71606B6F616B6E62696C64686A65676866656565626175706E88807C9A8E89
AC9C95BEABA1CEB8ACDDC3B6DDC5B8D8C1B5D2BCB1CDB6ABC6AFA4C0A79DBAA197B79E93
B59B90B49A8FB59B90B89F95BAA59CBCA9A1BBA9A3B9A9A3B5A7A2B0A5A0ACA19EA89F9C
A9A39FB1AEA9B7B5B1BBBAB6BBBBB9BCBEBCBEC1C0C3C6C5C7CBCACAD0CFCCD4D3CDD7D6
CFDADAD5E0E0E0E8E7EDF2F0EFF7F6F1FFFFEBFAFAD7E6E7C7D6D8B7C7CAA9B9BC9BACAF
8E9FA381929774868B687A80
5C6C725D6A6F5E696D5E676B5F66685F64655F61625F5E5F5E5B5A6D67657E7672918680
A3948DB7A49BCBB4A8DAC1B3DEC5B7DAC3B6D6BEB3D0BAAECBB4A9C6AEA3C2A99EBFA59A
BDA397BCA297BCA397BDA599BDA79DBDAAA2BCAAA3BAAAA4B7AAA4B3A8A2AFA5A0AAA29E
A5A09CA4A29EA8A8A4B3B1AEBCBBB7C1C1BDC3C4C1C6C8C5C8CBC9C9CECCC9D0CFCBD3D2
CBD5D5D5DDDDE1E7E5EFF1EDF4F7F4F0F9F8EDF8F7DAE7E7C9D7D8B9C7C9AAB9BC9CACAF
8E9FA381929775868B687A80
5C6B715C696E5B676B5B64685B62655B5F615A5C5D59595957555464605F746E6A897E79
9C8E87B19F95C6B0A3D8BEB0DFC6B7DEC5B8D9C2B6D4BEB2D0BAAECCB5AAC8B1A6C5ADA2
C4AB9FC2AA9EC2A99DC2AA9FC1ABA0C1ADA3BFADA5BDADA5BBACA5B8ABA5B4AAA5B0A8A3
ABA6A2A9A5A2A7A6A3A8A8A6ACADABB3B4B2B8BBB9BDC0BEBFC3C1C4C9C7C7CDCBC9D0CF
C9D1D1D2DAD8DDE2E0E8E9E6F1F0EDF1F5F2EEF6F4DCE6E5CBD6D6BAC7C8ABB8BA9CABAE
8F9EA281929675858B687A7F
5B6B705A686D596569596265585F61565B5D555859535454525050605C5B6E6865817772
968880AB9A90C1AB9FD5BCADE0C6B7E0C8BADCC5B8D8C1B5D4BEB2D1BAAECEB7ABCBB4A9
CAB2A6C8B1A5C7B0A4C7B0A4C6B0A5C5B1A7C4B1A7C2B1A8BFB1A9BDB0A9B9AFA8B6ADA8
B2ACA7AFABA7ADABA8ADACA9ADAEABAFB1AEB3B5B3B9BBB9BDC1BFC1C5C4C4C9C8C6CDCC
C9D0CFD0D6D4D8DDDAE0E3E0E9EAE7EEF1EDEEF4F2DEE7E6CBD5D4BAC5C6AAB7B89CA9AC
8E9DA081919574858A68797F
5A6A7059676B576367565F63545B5E5257595153544E4F4F4C4A4A5A565468625E7A706B
8E8079A69389BCA599D0B7A8DFC4B5E3CABBDFC8BADBC5B8D8C2B6D5C0B4D3BCB0D1BAAE
CFB8ADCEB7ABCDB6AACCB5A9CBB5A9CAB5ABC9B5ABC7B5ACC5B5ACC2B5ADBFB4ACBCB2AC
B9B1ABB6B1ABB4B1ACB3B1ACB4B2AEB5B5B1B7B8B5BBBCB9BFC0BEC2C4C2C4C7C5C5CAC8
C9CECCCFD3D1D6D8D5DDDEDAE3E4E0E9EAE5E9ECE9DCE3E1C9D1D0B8C2C2A9B4B59AA7AA
8D9B9E80909374848968797F
5A6A6F58656A566165535D6051585B4F54564C4F504A4A4A46454454514F635C59736964
8679719C8B81B29D91C7AEA0D8BDADE2C8B8E1C9BBDEC8BADBC6B9D9C4B8D7C2B6D6BFB3
D4BEB1D3BCAFD2BBAFD1BBAED0BAAECFBAAECEBAAFCCBAB0CABAB0C8B9B0C5B9B0C3B8B0
BFB7B0BCB6AFBBB6B0B9B6B1B9B7B2BAB8B4BBBBB6BCBDB9BEC0BDBFC3C0C1C5C3C2C7C5
C5CAC8CBCFCCD1D4D0D6D8D4DBDCD8E0E0DBE0E1DDD6DBD8C4CBC9B4BDBDA6B1B298A5A7
8C999C7F8E9273838867787E
59696F566469545F64515A5E4E55584B5052484B4C45464642403F4F4B495D57536D635E
7F726A94837AAB968AC0A89AD1B7A8DEC3B4E2C9BBE0C9BCDEC8BBDDC7BBDBC7BADAC5B9
D9C3B6D8C1B4D8C0B3D7C0B3D6BFB3D4BFB2D3BEB3D2BEB4D0BFB4CEBFB5CBBEB4C8BDB4
C5BCB3C2BAB3C1BAB3BFBAB4BEBBB5BEBBB6BEBDB8BEBEBABFC0BCC0C2BFC0C3C0C0C4C2
C4C8C5C7CAC7CCCECACFD1CDD3D4D0D7D7D2D5D6D2C9CDCABDC3C1AFB8B7A2ACAD96A1A3
8A97997E8C9072828767787D
59686E556368525E624F585C4B5255474D4F4447484042423D3C3C4B474558524F675E59
786B648B7C72A28D82B9A092CDB1A1DABEADE1C7B7E2CABBE1CABCE0CABCDFC9BDDFC9BD
DEC8BBDDC7BADDC6B8DCC5B8DCC5B8DBC5B8D9C4B8D7C4B8D6C3B8D4C3B8D1C2B8CEC0B7
CBBFB7C8BEB6C6BEB6C4BEB6C3BDB6C1BDB7C0BDB8C0BFB9C0BFBBBFC0BCBEC0BDBFC2BE
C0C3C0C3C5C2C6C7C4CACAC6CDCDC9D0D0CBD1D3CEC3C6C3B6BCBAAAB2B19EA8A9939EA0
8794977C8A8E71818566777D
58686E546267505C604C565A48505344494B3F42443A3B3C36363544413F514C49605853
6F645D83746B99867BAF988AC6AA9AD7B9A8E1C6B5E4CBBBE4CCBDE3CCBEE3CDBFE3CDC0
E3CDC0E2CDC0E2CCBEE2CBBEE2CBBDE1CABDE0C9BCDECABDDDC9BDDAC8BCD7C6BBD4C5BA
D0C4BACDC2B9CAC0B8C8C0B8C6C0B8C4C0B8C3BFB9C2BFB9C2BFBAC1C0BBBFBFBABFC0BB
BFC0BCC1C2BDC3C4BFC6C6C0C9C8C2C9C8C3C8CAC5BBBFBCB0B5B4A5ACAC9AA3A48F9A9C
8591947A888C707F8466777C
58686D5361664F5B5F4A5458464D504146483B3F40363738302F2F3C39374A454259514C
695E577C6D65917F74A79083BEA393D1B3A2E0C2B1E5CBBAE6CDBDE7CEC0E7D0C2E7D1C3
E7D1C4E8D1C3E8D0C2E7CFC1E7CFC0E7CFC1E6CFC1E5CFC1E3CFC1E1CDBFDECBBFDACABE
D6C8BDD3C6BBCFC4BACCC3B9CAC1B9C7C1B9C5C0B9C3BFB9C2BFB9C0BEB8BEBCB7BDBCB7
BCBCB7BCBCB8BEBDB8BFBFBAC1C0BBC0BFBABABBB6B3B6B3A9AFAD9FA7A6959F9F8C9698
828E9178868A6F7E8365767B
57676D5260654E5A5E485256434B4E3E4346383B3D3133332A292934312F433D3A514A45
60565073655C88766B9E887BB39A8AC8AB9ADABBA9E5C8B6E8CEBDEAD0C0EBD2C2EBD3C4
ECD4C5EDD4C5EED5C5EED4C5EDD3C3EED4C4EDD4C4ECD4C4EBD3C5E8D2C4E5D0C2E0CDC0
DCCCBFD8C9BED4C7BCD1C5BBCDC3B9CAC1B8C6BFB7C3BEB6C0BCB6BEBBB4BCB9B3BBB8B3
BAB8B2B8B7B2B9B8B2BBB9B4BDBBB6C0BFBAB4B6B2ABAFACA3A8A79AA1A1919A9B889394
7F8B8E7684886D7D8165757B
57676D5260654C595D47515541494C3B414334383A2D2F302525252C2A2839343149413C
584E47695C547D6D62927E72A58E80B99F8FCFB1A0E0C1AEE8CBB9EBD1BFEDD4C3EFD6C5
F1D7C6F2D8C7F3D8C7F4D9C7F4D8C6F4D8C6F5D9C7F4D8C7F1D8C7EED7C7EBD4C5E6D1C3
E2CEC1DECCBFD9CABDD4C7BBD0C4B9CCC1B7C7BFB6C1BBB3BEB9B1BBB6AFB7B4ADB6B3AD
B6B3ACB5B2ACB4B2ACB5B2ADB4B3AEB7B7B3ADAEABA4A8A59CA2A0949C9B8C9596848F91
7C888B7482866C7B8064757A
56676C515F644B585C4650543F484B393F423236382A2C2D201F1F21201E2F2C293E3834
4E443F5D514A706259857367978275AB9283BEA291D3B5A2E1C2AFEBCDB9EED3C0F1D6C3
F4D9C6F7DBC8F8DCC9F9DCC9F9DBC8FBDBC8FCDDCAFBDDCBF9DBCAF5D9C8F1D7C6ECD5C5
E7D1C2E2CEC0DCCABDD6C7BBD0C3B7CBBFB4C6BCB2BFB8AFB9B3ABB5B0A9B2AEA7B0ACA6
AEABA5ADAAA4ADAAA4AEABA5ADAAA4A8A8A3A3A5A29DA19F969C9B8F9796889192818B8D
7986887280846B7A7E637479
56666C515F644B575C454F533E474A373E41303536282A2B1E1E1F1A1817252220352F2B
443C3754484165574E79685D89766A9B8577AB9383BFA492D0B2A0DDBFABE8CAB6EED1BD
F5D7C3F9DBC7FBDDC9FCDDC9FCDCC8FDDCC7FEDCC8FFDDC9FEDDCAFADBC9F6D8C6F0D5C4
ECD2C1E6CFC0DFCBBCD8C6B8D1C1B4C9BCB0C2B7ACBAB2A8B4ADA5AFAAA2ABA7A0A8A59E
A6A39DA4A29CA4A19CA5A29DA9A7A1A1A19D9B9D9A969A989096958A9192838D8E7D888A
768386707E8269797D627379
56666C505F644A575C444F533D474A363E402F3436272A2B1E1F201514141A1816292522
38312D473D38574B446B5B527B6A5F8B776B9B8577AB9384BBA191CAAE9CD6B9A6E0C2B0
E8CAB7EFD0BCF4D5C0F7D7C2F7D6C1F9D6C0FAD7C0FCD8C2FCD9C4FBD9C3F7D6C2F2D3C0
ECCFBDE6CBBADFC8B8D6C2B4CDBCAFC4B5AABCB0A5B3AAA1ADA69DA7A19AA29E989F9C96
9C9A949A98929997929B98939C9B979799959396948F93928A9090858D8D7F898A7A8587
7480836E7C8068777C627378
56666C505F644A575C444F533D474A363E412F3437262A2C1D1F2013131411100F1E1B19
2C28243B342F4940395A4E466C5D547C6B608C796C9C8779AB9485B8A090C2AA99CCB2A1
D6B9A7DEC0ADE5C5B1EACAB5EBCAB6EDCBB6F0CDB7F3CFB9F4D0BAF4D1BBF1CFBAECCCB8
E7C9B6E0C5B3D9C1B0D0BBACC7B5A7BCAEA2B4A89EACA299A49E959E999299958F95928D
92908A8F8E888E8D88908E898F8F8B8E908D8B8F8D888D8C848B8B8088897B8587768284
717E816C7A7E67767B617278
56666C505F644A575C444F543D474B363E422F3538272B2D1E21221415160C0B0B12100F
211E1B2F2A263E36314E443D5E51496E60567C6B618B796D998477A58F80B09989B9A191
C1A897CAAF9DCFB3A1D6B9A6DABCA9DCBEABDEBFABE1C1ADE3C2AEE2C2AEE0C1ADDCBFAC
D8BCAAD2B8A7CBB3A4C2AEA0BAA99DB0A398A89E94A098909A948C9490898F8C878B8984
88878285847F83827E84847F8687848689868489878288877F86877B8485778284737F82
6F7C7F6A787D65757A617177
56676D505F654A585D4450553E484C37404330373A282D301F23251618190C0C0D0A0A09
16141324201D322C28423A3450453F5D51496A5C537A6A5F88776B9381759E8A7DA79284
AF998AB8A090BCA494C2A998C6AC9BCAAF9CCCB09ECDB19FCFB2A0CFB2A0CDB1A0C9AF9E
C5AD9CC0A99ABAA597B2A194AB9D91A4988E9C938A948E868E8A8389868083827D807F7B
7E7D797B7A767B7B777E7F7C7F827F7F83827E84837C83837A8283778182747F81707C7F
6C7A7D68777B647479607177
56676D5160654B595E4551563F4A4E38424531393C2A3032212628181B1D0E0E10050405
0C0B0A19161425211E332D294139344F453F5A5048675B5275675D8070668A7A6F938276
9A897CA28F82A99487AE998AB29C8DB59F8FB7A190B9A291BAA392B9A392B8A292B39F90
AF9C8EAA998BA595899F92879A8F85958C838F888088837D827F797D7B777A7A76797975
767672757572777875787B79797D7B797F7E797F7F787F80767F80737D7F717C7E6D7A7D
6A787C67767A6373785F7076
57676D5161664C5A5F465358404C503A4448333C3F2C3336242A2C1B1F21121415050606
0101010B0A0919161426221F332D2A3F383349413B544B4460564E6A5F577669607F7168
86786E8D7E7394837998877C9B8A7E9F8E81A29083A39184A49385A39285A191849C8E82
9A8C8095897E90867C8B837A878079827D777D7A7478767174746F71716D6D6F6C6D6E6C
717370717370727573747876747A79757B7B747C7C737C7D727C7D707B7D6E7A7C6B787B
68767A6574796272775F7076
57686E5262674D5B6147555A424E523C474B363F432F373A282E31202527171A1C0D0F10
0203030000000A0A09181715252320302C29393431423C374C4540554E48605850696058
70665F766C647C706881756D867A708A7D738D80758E82779083789083798F8278897F75
837A717F786F7C776F78746E73716C706F6B6E6E6A6B6C68676966676865676865676865
696B686C6F6D6E72716F757470767670787870797A6F797A6E797B6D787B6B777B69767A
6675796473786171775F7076
57686E5363684E5D6249575C4451553F4A4E394347333C3F2C3437252B2E1D222415181A
0C0E0F0203030001010A0B0B1818162423212D2A2833302D3A3734423F3C4A4743544F4A
5B5650625C5667615B6C655F716962746D657770687A726A7B746B7D766D7C756E7A746D
76726B6F6C676968646767636465626365626264626163615F615F5D5F5D5F605D616361
656967686D6B6A706F6B72726C74746D75766D76786C77796B77796A7679697679677579
6574786372776071765E6F75
58696F54646A4F5F644B595E465458414E523C484C374145313A3D2A3235242A2D1C2224
15191B0D10110305060204040C0E0E1718172222212828262D2D2A3332303A3A3740403D
4545414B4A4751504D5755515C5955615E5864615C67645E68655F6A67626D6A666D6B67
6A69656667636465626163605D605E5A5E5B595C5B585B5A575A595659575B5D5B5F6261
626766656B6A676E6E6870716972736A73756A7476697577697578687478667478657378
6372776271776070765E6F75
58697055656B5160664D5C6149575C455257404C513B474B364044313A3D2B3336252C2F
1E2426171C1E0F13150608090508080F1112191B1B2022212526252829282D2F2D343634
393B393C3F3C3F42404446444A4B494E4F4D51534F555653575855595B575A5C5A5D5F5C
5A5D5B565B5A5359585157564F55554D53534D5352505453505452535655585C5C5C6262
606666626A6A646C6D656F70667072677274677275677376667377657377647377637277
6271766071765F70755D6F75
596A7056666C5263684F5F644C5A6048565B445156404D513C474C374246323C402D3639
27303321292B1B212314191B0B0F10080C0D0E1212191D1E212525242828262928272C2B
2B302F2F3434343A39363B3B373D3D3C4242424948484D4C4A504F4D52514E5454525757
5056564E55554B5354495152485050474F4F474E4F4D51504F5352535959575E5E5B6263
5E666760696B626C6E636E70646F72647073647174647275647276637276637276627176
6171766070765E6F755D6F75
596B7157686E54656B5161674F5E644C5A6049575C455358424F533E4A4F3A464A364145
313B3F2D363927303322292C1C2325161C1F1016181218191A2122202728252A2B272D2D
2930302A31322C353630393B343D3F3740423B44473F484A454D4F474F514850514A5152
4A5153485052454E4F434C4E434B4C454D4C444B4A4A5050505758545C5D5760625A6466
5D67695F696C606B6E616D70626E72626F73627074627075627175627175617176607076
6070755F70755E6F755D6E75
5A6C72586A7056676D54646A526268505F654D5C624B595F48565B455358424F543F4C50
3C484C384448343F43303A3E2C3539273034232C2F1C24281A23261C2528222B2E293233
2933342A34352D3739303B3E343F413641433844463A46493D484B3F4A4D434C4F444D50
454D4F464D4F444C4E444C4D4047474148494850514D5758525C5E5560625863665A6669
5C686B5D6A6E5F6C6F5F6D71606E72606F73616F746170746070756070756070755F7075
5F6F755E6F755D6F755C6E74
5A6C72596B7158696F57686E55666C54646A5262685060664F5E644D5C614B595F49575C
465459445156414F533E4B503C484D394549364246333E43313C412F3B402D383D2F393E
323C41323D41333E40333E423642453C474A3E4A4C404C4F424D51424E52445053475155
47525546505240494C444D504852554B56584E5A5D525E6155616557646859666A5A686C
5C6A6E5D6B705D6C715E6D725E6E735F6E735F6F745F6F745F6F745F6F755E6F755E6F75
5E6F755D6F755D6E755C6E74
5B6D735A6C735A6B72596B71586A7058696F57686E56676D55666C54656B536469526268
5161675060654E5E644D5D624C5B604A595F49585D47565C46555B46545A455459455459
46545A46545A465459455358425057435157435156445256455357455357465357465357
4754584D5A5E4F5C61505E6252606453626655646857666A58676C59696E5A6A6F5B6B70
5C6C715C6C725D6D725D6D735D6E735D6E745D6E745D6E745D6E745D6E745D6E745D6E74
5D6E745C6E745C6E745C6E74
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.754707 0.488926 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(22) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
6971746971746971746971746971746971746971746A71736A71736A71736A71736A7173
6A71736A71736A71736A71736A71736A71726B71726B71726B70726B70716B6F706B6E6D
6B70716B71726B71736B71736B72746A71736A71736A71736A71736A71736971736A7173
6971736A72756A73756A74766B75776B75786B76796C777A6C787B6D797C6D7A7E6E7C80
707F846E7B7F6D797D6D787C6C777A6C767A6C76796B76796B75786B75786B74776A7477
6A73766A73766A7275697275
6971746971746972746A71746A71736A71736A71736A71736A71736A71726B71726B7172
6B70726B70726B70716B70716C70716C70716C70706C70706D6F6F6D6F6E6D6E6D6D6C6A
6D6E6E6D70706D71726D71726C72736C71726B71726B71736C71726B71726A72736B7273
6B72746B74766B75776C76796D787B6D797C6E7B7E6F7C806F7E8270808471828773858B
75878D728388718085707E83707D816F7B7F6E7B7E6E7A7D6D797C6D787B6C777A6C7679
6B75786B74776A73766A7275
6971746971736A71736A71736A71736A71736A71726B70726B71726B70716B70716C7071
6C70716C70706C70706D6F6F6D6F6F6D6F6F6E6F6F6E6F6E6F6F6D6F6E6C6F6D6A6F6B68
706E6C6F706F6F71716F71716E71726D71726C71716C70716D70716C71716B72726B7273
6B73756B74766B76786D797B6E7B7E707D80717F8372828673848974878C768A90778E95
778C9376898F75868C748489738287728085717F83707E826F7C806F7B7F6E797D6D787B
6C777A6B75786B74776A7376
6971746A71736A70736A71736A71726B70726B70716B70716B70716C6F706C70706C6F70
6D6F6F6D6F6F6E6F6F6E6F6E6E6F6E6F6F6E6F6F6D706E6D716E6C716D6B716C69716B66
726E6B726F6E7171707172717071716F71716D71706C70706C6F6F6C6F6F6A70706B7273
6B74756B76776C787A6D7B7D6F7E8171818473848774878B768A90778D947A92997C979F
7B939A798F96788C93778A9076878D75858A748388738186728084707E826F7C806E7A7E
6D787C6C777A6B75786A7376
6971746A71736A70726A71726B70726B70716B70716C70706C6F706C6F6F6D6F6F6D6F6F
6E6F6E6E6F6E6F6E6D6F6E6D706E6C706E6C716E6C726E6B736E6A736D6A746D68746B66
746E6B74706E7371707372717272717172717071716F71706E706F6D6F6F6C70706C7272
6C74766D76786D797B6E7C7F70818372858874888C778C917990967B949B7E99A1809DA6
7E99A17D959D7B92997A8F96798C93778A9076878D75858A748388728185717F83707C80
6E7A7E6D787B6C76796A7477
6971736A71736A70726B70726B70716B70716C70706C6F706D6F6F6D6F6F6E6F6E6E6E6E
6F6E6D6F6E6D706E6C706E6C716D6B726D6B726D6A736D6A756E69766E69776E69786D67
776F6B77716E76726F7572717472717373717272717172717072716F71706F72716E7374
6F76776F787A707C7E707F8272838775898D778D917A91967D969C7F9BA282A0A883A1AB
819EA7809BA37F979F7D949C7C91987A8E95798C9177898E76878C748488738185717E83
6F7C806E797D6C777A6B7477
6971736A71736A70726B70726B70716C70706C6F706D6F6F6D6F6E6E6E6E6E6E6D6F6E6C
6F6E6C706D6B716D6B716D6A726D6A736D69746D69756D68766D68796E697B706A7C726B
7A716D79726E787270777371767372757472747472747472737473727473727574717676
717979727C7D737F8174828575878A778C907A92977D969C809BA283A1A986A7B186A6B0
85A3AD83A0A9829DA58099A17F969D7D939A7B90967A8C92788A8F76878C748388728085
717E826F7B7F6D787B6B7578
6A71736A71736B70726B70716C70716C6F706D6F6F6D6F6E6E6E6D6E6E6D6F6E6C706D6B
706D6B716D6A726C69726C69736C68746C67756C67766C67786C677A6E6782746D80746E
7D736E7B736F7A7370797471787572787472777573767574757674757775757977757A79
757C7C758080768385778789798B8E7B90957D959B809BA184A1A987A6B08AADB889ABB6
88A9B387A5AF85A2AB849FA7829BA380979F7E949B7C90977A8D9378898F76868B748287
727F83707C806D787C6B7578
6A71736A71726B70726B70716C70706D6F6F6D6F6E6E6E6E6E6E6D6F6D6C706D6B706D6A
716C69726C69736C68736B67746B67756B66766B65776B65786A64796B6487777081746E
7F746F7D736F7C74707B74727B75737A7673797673787675787775787977777C7A787F7D
7981817984847A87887B8B8D7D8F927F9599819A9F84A0A688A6AE8BACB68EB4BF8DB1BC
8CAFB98AABB589A7B187A4AD85A0A8839CA481989F7F949B7C90967A8C9278888E758589
738185707D816E797D6B7578
6A71736A70726B70716C70706C70706D6F6F6E6E6E6E6E6D6F6D6C706D6B706C6A716C69
726C68736B67736B67746B66756A65766A64776A637769637768617C6D6682736C81736E
80746F7F74707E75717D75727D76747C77747B77757B77757A78767A7A787A7E7B7A817F
7B85847C89887D8C8C7E8F9181949683999D859EA387A4AA8AAAB28EB1BB91B9C491B8C4
90B5C08EB1BC8CADB78AA9B288A5AD86A0A9849CA481989F7F949A7C8F95798B9077878C
748287717E826F7A7E6C7679
6A71736A70726B70716C6F706D6F6F6D6F6E6E6E6D6F6D6C706D6B706C6A716C69726B68
736B67736B66746A65756A64766A637769637869627868617B6B637F6E6781716A81726D
81736E8074708075727F76747F77757E78757E78757D78757B78757C7C797C7F7D7C8481
7D88867E8D8B80908F82949484989A879DA189A2A78BA7AE8DADB591B4BE94BCC796BFCC
94BBC792B7C290B3BD8EAEB88CAAB389A5AD87A0A8849CA381979E7E92987B8D9378898E
7584897280846F7B7E6C7679
6A71736B70726B6F706C6F706D6F6F6E6E6D6F6E6C6F6D6B706C6A716C69726B68736B67
736A66746A6575696476696377696278686179686078675E7F6D65816F6881716A82726C
82736E81746F8276728277758178768179768078767F79767D77757D7A787D7D7B7E8280
7F8684818D8C829291859797889C9D8AA0A38DA6AA8FAAB190B0B793B5BF95BCC798C2CF
98C3D096BDC994B8C492B4BE8FAFB88CAAB28AA5AD879FA7849AA180959B7D90967A8A90
76868A738185707C7F6C777A
6A71736B70716C6F706C6F6F6D6E6E6E6E6D6F6D6C706D6A716C69726B68726B67736A65
746A647569637669627768617868607A685F7B675E86716783706783706883716A82716B
82726C82736E8376728479758479778379778379778179777F78767E77757F7A797F7D7D
7F8180828A8A8592918899998B9F9F8EA3A691A9AE92ADB493B2B995B6C097BDC799C2CE
9BC7D49AC3D098BECA95B9C493B4BE90AEB78DA9B18AA3AB869EA583989E7F92987B8D92
78878C748286707C806D777A
6A71736B70716C6F706D6F6F6E6E6D6F6E6C706D6B706C6A716C68726B67736A66746964
75696376686277686178676079675F7B675E7D685E87716786706885706884716A83706A
83716A82726D847571867A77867A77867B77897C7A8377758077757D74737D76757E7C7B
7F7D7E828485868C8C8C97988FA1A292A6A894ABB095B0B696B3BB97B7C098BCC79BC2CE
9DC8D59EC9D69CC4D19ABFCA97B9C394B3BD90ADB68DA7AF89A1A8859BA281959B7D8F94
79898E758387717D816D777B
6A71736B70716C6F706D6F6E6E6E6D6F6D6C706D6A716C69726B67736A66746964746963
75686176676077675F79665E7A665D7B655B88706488716787716886706885716A847069
836E68826F6A8473708778758A7C798476748578768375748175747F76757D74737C7979
7C7B7B7D80818186878B939494A0A196A9AA98AEB199B3B899B5BC98B8C099BCC79CC2CD
9EC7D4A0CBD9A0C9D59FC5D09CBFC998B8C294B1BA90ABB38BA4AC879EA583979D7F9196
7A8B90768489727E826D787B
6A71726B70716C6F6F6D6E6E6E6E6C6F6D6B716C69726B68736B66736A65746963756862
76676076665E77655D79655C7C665D7C655A8F75698B7268897168877067867069856F68
836D66826D68836F6C8272708A7D7B877C79867A79857A798378778179787F7978807E7E
7F7F807E83847D8486828D8F8E999B9AA9AA9CB1B49DB5BA9BB7BE9AB9C19BBCC69DC1CC
9FC7D4A1CCDBA3CCD9A4CAD6A1C5CF9CBDC798B6BF93AFB78EA7AF8AA0A7859AA0809398
7C8C9177858A727F836E787B
6A71726B70716C6F6F6E6E6D6F6D6C706D6A716C69726B67736A65746964756862766760
76665E76645C76635A78635980695F856C618D74688B72688A7168887168877069866E67
836B65826C67816C69806D6B867472867775867876867A78847977827A78827A7A828080
82838382888981888A848F9288969895A3A69FB3B59FB8BB9EB9BF9CB9C19CBCC69EC1CC
A0C6D3A1CCD9A4CEDCA5CCDAA6CAD5A0C2CC9BBAC396B2BB91ABB28CA3AA879CA282959A
7D8E9378878B737F836E787C
6A71726B70706D6F6F6E6E6D6F6D6B706C6A726C68736B66746A6575696376686177675F
77655D76635A756057725D527E665C8C71658B72668B71678B71678A7167897068876E66
856C65856F6987736F867370877371877573867573857574847573827675827777827A7B
827F8184868785898B868F928996998F9EA29CAFB2A1B8BCA0BABF9DBAC19DBCC59EC1CB
A1C6D2A2CBD8A6D0DEAED4E2A9CED9A5C6D19FBEC799B6BE94AEB58EA6AD899EA583979C
7E8F9479888C7480846E797C
6A70726C6F706D6E6E6E6E6C706D6B716C69726B67746A6575696476696277686078665E
78655C776359745E556F5A4F766057866E638B71668C71678C71688B71678A7168896E66
876C65876F688A76718A77748A7774897774887774877674867674847775847978847C7C
85808186858789898C8A8E928C94988F9BA196A6AC9EB3B7A0B8BE9EB9C09EBBC59FC0CA
A1C5D1A2C9D6A2CBD9B2D8E4AFD2DEA8CAD4A2C1CB9CB9C196B0B890A8B08BA0A785989E
7F90967A898D7481856F797C
6A70726C6F706D6E6E6E6D6C706C6A716B68736B66746A6576696377686179675F7A665E
7A655C7A64597961577B63587F675C866D628C71668E73688E72698D71688D71688B6F67
896E668970698C76708E7B768D7A778C79758A7875897875887674867775867A79867E7D
8782828986888C8C8E8F929591989C949FA498A7AC9DB0B59FB5BB9FB8BF9EBBC39FBFC9
A1C4CFA1C7D4A2CBD9B5DAE6B2D6E1ACCDD8A5C4CE9FBCC599B3BB93ABB28DA2A9879AA0
8192977B8A8E7582856F7A7D
6A70726C6F706D6E6E6F6D6B706C69726B67746A667569647769627968607A675F7C675D
7D665B7E655A80655982685D866D628B71668F746890756A90756A90746A8F73698E7168
8D70678C726A8D756F8F7B76907D798E7B778D7A768B7A768A7976887875887A78887F7D
8A84838B88888E8E8F919496949A9D97A0A49AA7AC9EAFB49FB3B99FB6BD9FBAC2A0BEC8
A0C3CDA0C6D29FC8D6B8DCE8B6DAE5AFD1DCA9C8D2A2BFC89BB6BE95ADB48EA4AB889CA1
8293987C8B8F7582866F7A7D
6A70726C6F6F6D6E6D6F6D6B716C69726B67746A657669637868617A685F7C675E7E675D
80675B82675A85695C886C5F8C71658F766B93776B93796D93786D93776C93756B92746B
91726A90736B90766F927B75937F7A917D798F7A778D7A768C7A76897975897B788A7E7D
8C85848D8989919090949698989C9E99A1A49BA7AB9EADB29FB1B7A0B5BCA0B9C1A0BDC7
A1C2CCA0C4D19CC5D4B3D8E5BBDFEAB3D5E0ACCBD5A4C1CA9DB8C097AFB690A6AD8A9DA3
83949A7D8C90768387707A7D
6A70726C6F6F6D6D6D6F6C6A716B68736A667569647768627968607B675E7E675D81675C
84685B87685A8A6D5F8D706392776A95796D967A6E977B6F977B6F96796F96786D95776D
95766C94766D93776F947B75957F7A947F7A927D78907C788E7B778C7A778B7C798D817F
8F8685918A8A9491919797999B9EA09DA3A69EA8AB9FACB1A0B0B6A1B4BBA2B9C0A3BDC6
A3C1CBA1C4D09CC4D2A7CFDDB6DCE9B9DBE6AECDD7A6C3CC9FBAC299B1B892A8AE8B9EA4
84959B7E8C91778387707A7E
6A70716C6E6F6D6D6C6F6C6A716A677369657568637768617A675F7D675D80675C83675B
87685A8A6B5C8F7162937768997D6F9B7C709B7D719B7D719A7D729A7C71997B70997B70
987A70987A70977B72977D7697807996807A947E79927E79907C788E7D788D7E7B8F8380
918886958E8C9793939C9A9B9EA0A2A0A5A7A1A9ACA1ACB1A2B0B6A4B5BBA4B9C1A5BEC6
A6C2CCA6C7D1A4C8D3A6CDDAACD4E1B2D6E1AECED8A8C5CEA1BCC49BB2BA94A9B08DA0A6
86979C7F8D92778488707B7E
6A70716C6E6E6D6D6B6F6B69716A6673696475686178675F7A665D7E665C81665A85675A
8A67598E6B5C937263997C6D9E8173A081739F80739F7F739E7F739D7F739D7E739D7E73
9C7E739C7E749C7F769B81799B827B99817B967F79947E79927C788F7D788F7F7B918481
948A8798908E9A95949E9B9CA1A1A3A3A6A8A4AAADA4ADB1A5B1B6A6B5BBA8BAC1A9BFC6
AAC4CCABC9D3ACCBD6AFD2DEB3DAE6B2D5E1AFCFD9AAC7D0A4BEC69DB4BC96ABB18FA1A7
87989D808E93788588717B7E
6A70716C6E6E6D6C6B6F6A6870696572676275666078665E7B655C7E655A826559876658
8D6859936D5E9A7667A18071A58576A58476A48476A38275A28175A18175A08175A18175
A08176A08377A08479A0857C9F867E9C847D99827C96807A937D78917D7890807C928581
958B8899918F9E9796A29E9EA4A3A4A6A8A9A7ABADA8AEB2A8B2B6AAB6BBABBBC1ADC0C7
AFC5CDB0CBD4B1CDD7B4D5E0B9DDE9B8DAE5B3D2DCADC9D2A6C0C89FB6BD98ADB390A3A8
89999E818F93798589717B7F
6A6F716B6D6D6C6B6A6E696770686472666174655E77645C7A645A7E6358836356886455
8F6B5B997363A47D6DAC8776AD8979AA8879A88678A68577A58376A48276A38276A48377
A58478A5867AA5887CA5897FA38981A0877F9D847D99817B957E78927D7892817C948682
988C899C9391A09998A49F9FA7A5A5A9A9AAAAADAEABB0B2ACB3B7AEB7BCAFBBC1B1C1C7
B3C7CEB5CDD5B7D0D8BBD9E3BCDEE9BDE0EBB7D6E0B0CCD5A9C2CAA2B8BF9AAEB592A4AA
8A9A9F8290947A868A717C7F
6A6F706B6D6D6C6A696D68656F666271655F73635C76625A7A62577E6255826153866150
8E69599D7665AB8271B78E7CB48E7DB08B7BAD8979AA8678A88477A68376A68376A78477
A88579AA897DAB8C80AA8E83A88D84A58B83A0877F9B837C967F79947E7993817C968782
998D8A9F9492A39B99A7A09FAAA6A6ADABABAEAFB0B0B2B4B0B5B8B2B9BDB3BDC2B5C2C8
B7C8CEBACDD4BCD1D8C1DBE4C3E0EAC2E4EEBCD9E3B4CFD7ADC5CCA5BAC19DB0B694A6AB
8C9BA08391957B868A727C7F
6A6F706A6C6C6B69686C67646D65606F635D72615A7560577960557D6053816051855F4E
8A66559B7565AE8573BE937FBA9280B58E7DB18B7BAD8778A98577A88477A88477AA867A
AD897CB08C7FB08F82AF9185AD9287A98F86A389819D847D977F79947E7893817C968782
9A8D8AA09592A49C9AA9A1A0ADA7A6B0ACACB2B0B0B3B4B5B4B7B9B4BABEB6BFC3B8C3C8
BBC8CFBDCDD4C0D2D9C7DCE4CAE4EDC9E8F2C1DDE5B9D2DAB1C7CEA8BDC3A0B2B897A7AC
8E9DA18592967B878B727C7F
696E70696B6B6A68676A65626C635E6D605A705F57735E54775E527D5E51825E4F866151
8B67569F7866B48875C59782BF9481B9907EB48D7CAF8879A98375A68173A58073A78276
AD877AB38C7FB69184B39286B19489AE948AA58C849E857D987F78947D7793807A968681
9A8C8AA19592A49B99A8A09FAEA7A6B2ADADB5B2B1B8B6B7B8B9BBB8BCBFB9C0C4BCC4C9
BEC9CFC0CDD3C2D1D8CADBE2D0E6EECEEBF4C6E0E8BDD5DCB5CAD0ACBFC5A2B4B999A9AE
909EA28693977C888B737D80
696E6F686A6A68676569636069605C6A5D576C5B53705A51755B4F7C5D4F835E4F876353
8966579E7866B68A76C99A85C39682BD927FB88E7DB18979AB8475A47E70A07D709C7B6F
A28073AC877AB28D80B28E82AE8F85AC9187A58B839E857D987E77937C76927E79948580
988A87A29693A49A98A9A09FB1A8A6B6AFAEB8B3B2BCB8B8BCBBBCBBBEC0BBC0C4BDC5C9
C1C9CEC3CED3C7D3D9D1DEE4D6E8EFD4EDF5CBE2E9C2D7DEB9CCD2AFC1C6A6B6BB9CAAAF
929FA38794977D888C737D80
686E6F676A6967656466615E665D59675A5468574F6B554C70564A7A5A4C8C66558D6857
8F6B5BA07968B98C77CE9D87C79884C09481BA8F7EB48B7BAE8777A78071A27D6F9A796C
9A7A6EA07F73A7867BAC8A7FAC8D83A98E84A48A829E847D977E77927B75907C7791817D
9285829A908E9E9592A59C9AB1A7A4B6AEACBAB3B1C0BAB9BFBDBDBEC0C1BCC1C5BEC4C9
C1C8CDC4CDD2CBD4DAD8E2E7E0EDF2DBF0F7D1E5ECC8DAE0BECFD4B3C3C8A9B8BC9EACB0
94A0A48995987E898C747D80
676D6E666868656362645F5C635A5662555062514A634E45674D417454468A6454956E5D
997261A87E6CBC8E79D09F88C99A85C39582BC907EB78E7CB28A7AAB8475A57E70A17C6E
A07D6FA38072A68477AA897DAB8B81A88B81A489809D837B977E76927B748F7B758F7F7B
918481938B8A938D8D949191A79F9EACA8A7B1ADACBAB6B5BBB9B9BCBDBEBBBFC3BCC3C7
C0C7CCC2CCD1CED6DBDDE4E8E7F1F5E3F6FBD8EAEFCDDEE3C3D2D6B7C6CAACBABEA1AEB1
96A1A58A95997F898C747D80
676C6D656767636160615C595F56525D514B5B4B445A453D563D33694C407C594B8E6858
997261AC816EBF907BD2A089CC9C87C59784BD907EB78C7AB38A7AAF8878AB8375A88072
A78071A98375AB8678AD8A7DAC8C80A88A7FA3877E9D827A977D76927B748F7B748F7F7A
928481948A88938C8C8F8D8E989696A09E9FA6A6A7B0AFAFB5B5B5B8BABCB9BDC0BAC1C5
BDC5C9C0C9CED0D7DBE0E5E8EBF1F5E9F9FEDFEEF2D3E2E5C8D5D9BCC8CCB0BCBFA4AFB3
98A3A68C9699808A8D757E80
666B6D636565615F5E5E59575B534F584C4755453F513E364B342B5F4439735447866254
967060AC806DC1907BD39F89CF9E89C79985C09381B88D7BB18676AC8374A88172A67E70
A27C6EA37E70A58073A88477A8887CA6877CA2847B9D8178977E75927B748E7A748E7D77
928580968C88978E8D9892919B97979F9C9CA5A3A4ADABACB2B1B2B5B7B9B7BBBDB9BFC2
BBC3C7C0C8CDD3D8DBE5E6E8EBEFF2EFFCFFE6F2F5DAE6E9CDD8DBC0CBCEB3BEC1A6B1B4
9AA4A78D979A818A8D757E81
656B6C6264645E5D5C5B575557504C5348434F403A4A3830432E25543C32694D417E5D4F
936D5DAA7F6CC0907BD29F88D2A08ACB9C88C49784BD9180B58B7AAE8475A88072A77E70
A47C6DA37C6EA37D6FA58073A68478A5847AA282789E8077987E76937C758E7A748A7974
8B7E7A928883998F8B9F9693A09A98A29E9DA6A4A4ACAAAAB0AFB1B3B5B7B5B9BBB6BDBF
B7C0C4C0C9CDD4D8DBE9E8E9EEF0F2F4FDFFF3FBFDE1EAECD2DBDEC4CDD0B6BFC2A9B2B5
9BA5A78F989A828B8D757E81
656A6C6163635C5B5A585452534D494F4540493C3643332C3D29214D362C60463B76584A
8C6859A67C6ABD8E7AD09D86D3A18CCE9F8BC79A88C19584BB907FB58B7BB08777AD8474
AA8272A98172A88172A88274A78375A58478A282779E81779A7F77967E77917D778C7B77
887B7889807D8C868497908DA09997A69F9EA8A5A4ACA9A9AFAEAFB1B3B5B2B6B8B2B9BC
B2BCC0C1C8CCD5D8DAE9E6E6F3F1F1F5FAFBF9FEFFE7EEEFD7DEE0C7CFD1B9C1C3ABB3B5
9DA5A890989B838B8E767E81
646A6B5F62625A5A59555250504A474A413D4538333E2F2837251E463229584036705246
866455A07866B88B76CE9B84D4A28CD1A28DCB9E8BC59A88BF9584BA9181B68D7DB2897A
AF8777AD8576AC8475AA8476A98476A78477A48378A082789D817899817995817A91807B
8D807C8C817F8B84828E898893908F9A9797A09F9FA5A4A5A8A9ABADAFB1AEB3B5AFB6B9
B0B9BEC0C7CAD2D5D7E4E2E2F2EFEFF9F9F9FDFFFFECF0F1DBE0E1CAD1D2BBC2C3ACB3B5
9EA6A890989B838B8E767E81
64696B5E616159595853504E4D4745473E3A4035303A2C2533221B422F27533C33694D41
8160519A7463B38773C99882D5A38CD4A490CFA18EC99D8BC39988BE9585BA9282B78F7F
B48C7CB2897AB08778AE8778AC8678A98578A68578A38479A0847B9D847C9A847D96847E
938480918682908885918B8993908F9694949B9A9BA1A0A2A4A6A8A8ABADAAAFB2ACB3B7
B1B9BDC0C6C9D0D3D5DEDFE0EEECECFAF8F7FFFFFFF1F4F3DEE2E2CCD1D2BCC2C3ADB4B5
9FA6A891989B838B8E767E81
63696A5D6061575757514E4D4A4543433C383D322E3528232E1E173E2C244E392F63483D
7A5A4C946E5EAD816EC4937ED3A18AD7A791D2A490CCA08EC79D8CC29989BE9585BB9282
B89080B58D7DB38B7BB18A7AAF8879AC887AAA877AA7867BA4877DA1877E9E87809B8881
988882968985958C88958E8C9792909996959C9B9BA09FA0A3A4A6A6A9ABA8ACAFAAB1B4
B3B9BDC1C5C8CFD1D3DDDDDDEBE9E9F8F5F3FEFCFBF3F5F4DFE2E2CDD1D2BCC2C3ADB3B5
9FA5A791989A838B8D767E81
62686A5C5F605556564E4D4B47434140393639302B312520291B143928214A352C5D4338
7254478B6758A47B68BC8D78CD9B85D7A690D4A692CEA390CAA08EC59D8CC29989BE9685
BC9382B9907FB78E7EB48C7CB28B7BB08A7BAD897CAB897DA88A7FA68B81A38B82A08B84
9D8C869B8D889A8F8B9A928E9A94929C97969D9B9B9F9F9FA2A3A5A3A7A9A4AAADA8B0B3
B2B9BDC0C4C7CED0D2DBDBDBE8E6E6F4F0EFFAF7F6F2F2F1DDDFDFCCCFD0BCC0C1ADB2B3
9EA5A6919799838B8D767E80
62686A5B5F5F5455554D4B4A45413F3D3734362D292E231E26181235251E463229573F34
6B4F428261529D7563B48773C69681D3A28CD4A692D0A492CCA190C89F8EC59C8CC29989
BF9685BC9382BA9180B88F7FB58D7EB38C7DB08C7EAF8C80AD8D82AA8E84A78E85A58F86
A28F899F908A9E928D9E94909E96949E99979E9C9B9F9F9FA1A2A3A2A6A8A4A9ACA9B0B3
B4BABDBFC4C6CCCFD0D9D9DAE5E4E4F0EDECF5F3F2E9EAE9D9DBDBC9CCCDBABEBFABB0B2
9DA3A5909798838A8C767E80
62686A5A5E5F5354544B4A4943403E3B3533322B272A201C22161131221C412F27523B31
64493D7B5B4D936E5DAC806DC1917BCE9D87D3A490D1A591CEA290CAA08FC79E8DC49C8B
C29988C09685BD9383BB9282B99080B79081B58F81B29083B19084AF9186AC9188A99289
A6928BA4938DA2948FA19692A09895A09A98A09C9BA09F9FA1A1A2A1A5A7A3A9ACABB1B4
B4BABCC0C4C6CBCDCFD8D8D8E4E2E2EEEBEAF5F4F2E4E4E4D5D6D6C6C9C9B7BBBCA9AEB0
9CA2A38F959782898B757D80
616869595E5F515354494949413F3D3834322F2825261D191D120E2C1F183B2B244C372E
5D44397355478A6757A27967B98A76C99782D2A28DD2A591CFA391CCA28FC9A08EC79E8D
C59C8BC39988C19786BF9584BD9483BC9384B99284B79386B69488B39589B1958BAE958C
AA968DA8968FA69691A49893A39A96A29B99A19D9CA19F9FA2A2A2A3A6A7A6ABADAEB2B5
B7BBBDC2C4C6CDCECED8D8D7E4E2E1EDE9E8F0EFEEDFDFDFD0D2D2C2C5C5B4B8B9A7ACAD
9AA0A18E949681888B757D7F
616769595D5E5053534848483F3E3D3633312D2724221B18180F0B261A1436262046332A
573F356B4F42826152987260AF836FC1907BCF9E88D2A48FD0A390CEA28FCBA18FC99F8D
C79D8CC69B8AC49988C29786C09685BF9686BE9687BC9789BB988BB9998CB6998DB3988E
AF9990AC9991AA9993A79A95A59B97A49C99A29E9CA29F9FA3A2A3A5A7A8A9ACAEB1B4B5
B9BCBDC2C4C6CCCDCED7D7D7E2E0E0EAE8E7E4E4E3D8D9D8CBCDCDBEC1C1B1B5B6A4A9AA
989E9F8C939480878A757C7F
616769585D5E5053534748483E3D3C3432302A2624201917150C091F140F2F211B3F2D25
4E393062483D78594B8E6A5AA37A68B78874C89781D0A18CD1A38FCFA28ECDA18FCBA08D
CA9F8CC89D8BC89C8AC69A89C49887C49988C39A89C29A8BC09C8EBE9D8FBB9C90B89C91
B49C92B19C93AE9C95AB9C96A89C98A69D9AA39E9CA29F9EA3A3A3A7A8A8ACAEAFB4B5B6
BCBDBEC3C4C5CDCDCDD8D7D6E3E0DFECEAE9DEDEDDD2D3D3C5C7C8B9BCBDADB1B2A1A6A8
969C9D8A91937F8689747C7E
616769585D5E4F53534648483D3D3D3331302925241E1916120B0818100C271B15372720
47332A5841376D514582625395705FA87E6CBC8D79CA9A85CFA08BCFA18DCEA28ECDA18D
CCA08DCB9F8CCA9E8BCA9D8BC89B89C89B89C89D8CC79E8EC69F90C3A092C1A093BD9F93
B99F94B59E96B19F97AE9F98AB9E99A89E9AA59F9DA39F9FA5A3A3A8A8A9AEAEAFB5B5B6
BDBDBEC5C5C5CECDCDD8D6D5E0DDDDE6E5E5D8D8D8CBCDCDC0C2C3B4B8B9A9ADAF9EA3A5
93999B898F917E8587737B7E
606769585D5F4F53544648493D3D3D3332312826251D19170F0A081009061E15102E201A
3E2D254D393061493E76594C8866579A7463AB816EBD8F7BC79783CD9D88CEA08CCDA08C
CDA18DCEA08CCEA08CCD9F8CCB9D8BCC9D8BCEA08ECEA291CCA393C9A394C6A395C2A396
BDA196B9A197B5A098B1A099AC9F99A99E9AA7A09CA4A19FA5A4A3A9A9A9AEAFAFB5B5B6
BCBCBDC4C4C4CDCCCCD8D5D4DDDBDADADADACFD0D1C5C6C7BABDBDAFB3B4A5A9AB9BA0A2
919798878D8F7D8486737B7D
60676A585D5F4F53544649493D3E3E3333322827261D1A19110D0B0A0402150E0B251A15
35272044322A5640366B50447A5D508B695A997463AA816FB78B78C1927EC79985C99B88
CC9E8ACFA08CCFA18DCEA08CCD9E8BCD9E8BD0A18ED2A491D1A595CEA696CBA596C6A497
C2A397BEA399B9A299B3A199AEA099AA9E9AA79F9CA5A19FA7A4A4AAA9A9AEAEAFB5B5B5
BBBBBBC3C2C2CBCACAD4D2D1DCDBDBD1D1D2C7C9C9BEC0C1B4B7B8AAAEAFA1A6A7979D9E
8E9496858B8D7B8385727A7D
61686A585E604F5455464A4B3D3F403334342929281E1C1C13100F0703020C07041C1310
2A1F1A392B244A38305F473D6E54487C5F528A695B977464A47E6DAF8574B68C7ABC917F
C19582C69986CA9C88CA9D89C99C89CB9D89CD9F8CCFA28FD1A493D0A695CDA596C8A496
C4A397BFA298BBA399B5A199AF9F99AA9E9AA89F9CA5A19FA7A4A3A9A8A8ADADADB3B3B4
B9BABAC0C0C0C7C7C7CFCECED2D3D3C8C9CABFC1C2B6B9BAAEB2B3A5AAAB9DA2A3949A9B
8B9293838A8C7A818472797C
61686A585E60505556474B4C3E41413536362B2B2B201F1F151313080606040100120D0A
21191530241F3E3029503E35614A416E554A7C5F53896A5C9573649F7B6BA58171AC8676
B38A79B98F7EBD9280C19684C19684C39886C69A88C99D8BCBA08FCCA392CAA393C6A294
C2A295BEA196B9A197B4A097AE9E98A99D99A79F9CA5A09EA6A4A2A8A7A7ACACACB1B2B2
B7B8B9BCBDBEC1C3C4C9C9CAC4C6C7BEC0C1B7BABBAFB3B4A8ACADA0A5A6989E9F919698
898F9181888A79808371797B
61686B595F61515658484C4E3F43443638392D2E2E2223231817170C0B0B020000080504
18120F261E1A35292445362F534139624C436D554A7A5F5385675B8E6E619675679C7B6D
A28071A98576AC8778B38D7DB58F7FB89181BA9383BD9787C09989C19B8CBF9C8EBD9C8F
BA9D91B79C92B39C93AD9B94AA9B95A59B97A49C9AA39E9DA4A2A1A6A6A6AAABABAFB0B1
B5B6B7B8BABBBCBFC1BDC0C1BABCBEB5B8B9AFB3B4A9ADAEA2A7A89BA0A2949A9B8D9395
868C8E7F8688777F8170787B
61696B5A6062525759494E50414546383B3C2F31322527271B1C1C101011050405020100
0F0C0B1D17152B221E3A2E2947383253423B5D4A426B544B775E537E655A876C608E7166
94766A9C7C6F9F7F72A48476A78678AB897BAE8C7EB08F81B39284B59487B49588B1958A
AF968BAD968DAA968FA59690A39792A19894A09A989F9C9BA1A09FA3A4A4A7A9AAACAEB0
B1B4B5B4B8BAB5B9BBB3B7B9B0B4B6ACB0B2A7ACADA2A7A89CA1A3969C9D9096988A9092
838A8C7D8486767E8070787A
62696C5A616353595B4B50524347493B3E40323536292B2C1F2122151617090A0B000000
070606141110201B192D26233B312C473A3450413B5B4A4367534B6F5A527862597F675E
856D638C726891766C967A6F9A7E729E8275A08578A3877BA68A7FA78C81A68E83A48E84
A28E86A18F879E8F899B908B9A918E9B94919B97959B99999D9D9D9FA1A2A4A7A8AAADAF
AEB3B5AFB4B6ADB2B4ABAFB1A8ADAEA5A9ABA0A5A79CA1A3979C9E9197998C9294868D8F
81888A7B8284757D7F6F777A
626A6C5B6264545A5D4D5354464A4C3E424436393B2D30322427281B1C1E101113030506
000102090A0A161414231F1D2F29263A312E4238344C403A5648435E4F49695851705E57
77635C7C6860826D658771698A756C8F796F937D73957F7598837999847B99867E96867E
968780948881918883908985908B89928E8D93929194959597999A9B9E9F9EA3A5A4A9AB
ABB1B4A7ADB0A5ABADA3A8AAA1A6A89DA3A59A9FA1969C9D9297998D9395888F91838A8C
7E8587798083747B7E6E7679
636A6D5C6366565C5E4F5557484E504146483A3E403236372A2D2F212425181A1C0E1012
0306080103050B0D0E1818182522212F2A2937312F3E3734473F3B4E4542584D4960544F
675A556C5F5972635E7768627C6C6680706985746D8878708B7B748D7E778E80798B807A
897F7A867F7B85807D8583808685848888888B8D8E8F9192919596969A9C9CA1A2A0A6A8
A1A7AAA0A6A89EA4A69CA2A49A9FA2979D9F949A9C9097998D9395898F91848B8D808789
7C8385777F81727A7D6E7678
636B6E5D6567585E6152585A4B5153454A4C3E4345373C3D303436282C2D202325171B1D
0F121405090B0307090E11121B1C1C2625252F2C2C3331303A3736413D3C484442524B49
58514E5F5753645B58695F5C6E6460736864776C677B706B7E736E817772837A76837B78
817C787C79777A79787C7D7C7D7F7F80838485898A8A8E908D9294909698969D9F989FA2
989FA2989EA1979D9F959B9E93999C9197998E95978B9294888F91858B8E81888A7D8487
798183757D7F71797C6D7578
646C6E5F6669596163545B5D4F5557494F5143484A3D4244363B3D2F3436282D2F212527
191E20121618090D10080D0F1216191D20212829292D2E2E3232323637373E3D3D444443
494848504E4C5553525B5756605C5A66615E6A65626F6966716C6875706D7975727B7675
7A7775777776787978797B7B797D7E7B8082808587848A8C898F928B929690989A91989B
91989B91979A9097998F95988D94968B9294899092868D8F848B8D81888A7E85877A8284
777F81747B7E70787B6D7577
656D6F60686A5B6365575E6052595B4D5355484E5043484A3D4244373C3E3136382B3032
24292C1E2325171C1E0E13160E1417171C1F222628292D2E2D313230333536393A3E4041
424545464849494C4C4E5050545555595A595E5E5D6362616665646A69686C6C6B717170
6F71706D71716E73736F757671787A747B7E787F827F8688838B8E858D91889093899194
8A91948A9194899093888F92878E91868D8F848B8D82898B7F87897D84877A8284787F82
757D7F727A7C6F777A6C7477
656D7061696C5E65685A6163565D5F51585A4D5456494F51444A4C3F45473A4042353A3D
2F35372A2F32242A2C1D2426161C20141C201B2225262B2E2D323531363833383A373C3E
3B40423E444643494A464B4D494E504D525454585A5A5D5D5D6161626464636767696C6C
686C6D686E6F6870716972746C757770797B727C7F7C84877E868A80888B82898D838B8D
838B8E848B8E838B8D838A8C82898B80888A7F86897D85877B8385798183777F81757D7F
737B7D70787B6E76796B7476
666E71636B6E60686A5D6467596163565D5F52595C4F56584B5254474E50434A4C3F4548
3B4143363D3F31383B2C3336282F32232A2E1F272B21292D2A323630383C363D3F383F42
3B42453C44473F484B444B4F484F524A51544F5659535A5C595F615D6263606566626769
64696B646B6D646C6F666F726871746D76796F787B767F827981847A83867C84877D8588
7E85887E85887E85887D85877C84867B83857A8284798183787F82767E80747C7F737A7D
71797B6F777A6D75786B7376
676F72646D6F626A6D60676A5D65675B6265585F62555C5F525A5C5057594D5356495053
464D50434A4C3F46493C4346384043353D40313A3E2C353A2E373C303A3F363F433D4548
3E474A3E484A414B4E444E514851544B53564E565950595C545C5F575F615B62655D6466
60666862686B636A6D666E71646D706770736D767A717A7D747C7F757E81777F82788082
788083788083788083788082777F82777E81767E80757D7F747C7E737B7D71797C70787B
6F77796D76786C74776A7375
677072666E71646D6F636B6D61696C5F676A5E65685C63665A6164585F62565D60545B5E
52595C4F575A4D55574B5255485053464E52444C50424B4F424B4F414B4F40494E444D51
474F54474F534750534751554A545750585B535B5D545D60575F625861635B63665E6568
60676A626A6D5E666A636B6F666F726871746B74776E767970787B71797C727A7D727B7D
737B7E737B7E737B7E737B7D727A7D727A7D717A7C71797B70787B6F777A6F77796E7678
6D75786C74776B73766A7275
687173677072676F72666E71656D70646C6F636B6E626A6D61696C60686B5F676A5E6669
5D65685C64675B63665A6265596164586063575F62565E62555E62555E62555E62565F63
576063575F63576063565F63545E62565F635760635861645962665A63665B64675C6467
5E676A646C6F656D70666E716770736971746A73756B74776C75776D75786D76786E7679
6E76796E76796E76796E76796E76796D76786D75786D75786D75776C74776C74776B7476
6B73766A73756A7275697275
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.754707 0.732558 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
6F74756F74756F74756F73756F73756F73746F73746F73746F73746F73746F72736F7273
6F72736F72736F72736F72726F72726F71726F71726F71716F71716F70706F6F6F6F6D6C
7070707071727072736F71726F72736F72736F71736F71726E71726E71726E71726E7173
6E71736E73746E73756F757670767870777970777971787A717A7C727B7E737C7F747E82
768286747E81737C7E737A7D72797C72787B72787B71787A717779717779717678707678
707577707577707576707476
6F74756F73756F73756F73746F72746F72746F72736F72736F71726F71726F71726F7171
6F70716F70706F70706F6F6F6F6F6F6F6F6F6F6E6E6F6E6D6F6D6D706D6B706B696F6967
706C6B706E6E706F6F6F6F6F6F70706E6F706E6F6F6D6F706E6F706D6F706C6F706D7071
6D70726D72746D73756F767870777A71797C727B7D727D80737F8275828677858978888E
7B8A9078858A768286758084757F82747D80747C7F737B7E737A7D727A7C72797B71787A
717779717678707577707576
6F73756F73746F73746F72746F72736F72726F71726F70716F70716F70706F6F706F6F6F
6F6E6E6F6E6E6F6D6D6F6D6C6F6D6C6F6C6B6F6C6A6F6B6A706A68706A67706865706662
716A67706B6A706D6C6F6D6D6F6D6D6E6D6D6D6D6C6C6C6D6D6C6D6C6C6D6B6D6E6B6F70
6C70716C72736D73756E767970797C717C7F737E8274818576858978888D7A8C927D9198
7D90967B8C9179888E78868A778488768286768084757F82747E81747C7F737B7E727A7C
72797B71777A717678707577
6F73756F72746F72736F72736F71726F71716F70706F6F6F6E6F6F6E6E6E6E6E6D6E6D6D
6E6C6C6E6C6B6E6B6A6E6B696E6A696F6A686F69676F686670686570676370666170645F
716764716967706B69706B6B6F6C6B6E6C6B6D6B6B6B6A6A6C6A6A6B6A6B6A6B6B6B6D6E
6B6F716C72736C74766D777A6F7B7E727F8274828676868A788A8F7A8E947D939A8199A2
7F959C7D91987C8E947B8B9079888D78868B788488778386768184757F82747D80737C7F
737A7D72797B717779707577
6F73746F72736F71726F71726F70716F70706E6F6F6E6E6E6E6D6D6E6D6C6E6C6B6E6B6A
6E6B696E6A686E69676E68666E68656E67646F66636F666270656170656071645F71625C
726562716765716967706A696F6A696E6A696D6A6A6C69696B69696B69696A6A6A6B6C6D
6B6F706B71736C74776D787A6F7D80728185748589778A8F7A8F957D949B809AA2839FA8
819AA280969D7E93997D90967C8D927A8A8F79888D78868A778488768285758083747E81
737C7E727A7C71787A707678
6F73746F72736F71726F70716F70706E6F6F6E6E6E6E6D6D6E6C6B6E6B6A6E6A696E6968
6E69676E68666E67656E66636E65626E64616E64606F635F70635E71625D72625D73625B
7365607266637168657068677069686F69686E69696D69696C69696B69696B6A6A6B6B6C
6B6E706B71746C75786D787C707E8173848875898D798D937C939A7F99A183A0A985A2AC
839EA7829BA380979F7F949B7E91977C8E947B8C917A898E79878B788488778286757F83
747D80737B7E72797B717678
6F73746F72736F71726F70706E6F6F6E6E6E6E6D6C6E6C6B6E6B6A6E6A686D69676D6866
6D67646D66636D65626D64606D635F6D625E6E615D6E605B6F605A71605A73615A75645D
7465607366627267647167667068676F68676E68686D68686D69696C69696C6A6A6B6C6D
6C6F716C73756D77796E7B7E70808473868A778C917A91977E989F829FA786A6B086A6B0
85A2AC849FA8829CA48198A080959C7E92987D8F957C8C917B8A8F79878B788488768185
757F82747C7F72797C717779
6F73746F72726F70716E6F706E6E6E6E6D6D6E6C6B6E6B6A6D69686D68676D67656D6664
6D65626D64616D625F6D615D6D605C6D5F5B6D5E596D5D586E5C566F5C5578635C78655E
7565607465617266637166657067666F67666F68676E68686D68686C69696C6B6B6C6D6E
6C70716D74766E797B6F7D8072828675888D788E947C959C809CA484A3AC88ABB688A9B4
87A6B086A3AC84A0A9839DA58299A180969D7F93997E8F957C8C927B898E79868A778387
768083747D80737A7D717779
6F73746F71726F70706E6F6F6E6E6D6E6C6C6E6B6A6D69686D68666D67656D65636C6461
6C63606C625E6C605C6C5F5B6C5E596C5C576C5B556C5A546C58526D58517E675F79655E
7664607464607365627265637166657067656F67666E67676D67676D69696C6C6B6D6F6F
6D72746E77786F7B7D717F82748589768B907A91977E989F82A0A886A7B18BAFBB8AADB8
89ABB588A7B187A4AD85A1A9849DA5829AA181969D7F93997E8F957C8C917A888D798589
778285757E81737B7D717779
6F72746F71726E6F706E6E6E6E6D6D6E6B6B6D6A696D68676D67656C65636C64616C625F
6C615D6C5F5B6C5E596C5D586B5B566B5A546B58526B57506A544D735C547B645C78635D
76635F74635F7364617265627165647066656F66656E66656D66666D68686C6C6B6D7070
6E75756F797A707E7F72828576888B788E937C949A7F9BA283A2AB88AAB48CB2BE8CB2BE
8BAFBA8AACB789A8B287A5AE86A1AA849DA5839AA181969D7F92987D8E947C8A8F7A878B
788387767F82747C7E71787A
6F72736F70716E6F6F6E6D6D6E6C6C6D6A696D69676D67656C65636C64616C625F6B615D
6B5F5B6B5D596B5C576B5A556B59536B57506B554E6A534C705850775E5677605977615B
75615D74625E7363607264627165637065646F65646E65646D64646D68686C6C6B6D7171
6E7676707C7C718081748587778A8E7B91957E979D819DA584A4AD89ABB68CB3BF8FB7C4
8EB4C08CB1BC8BADB88AA9B388A5AE87A1AA859DA58399A081959B7F91967D8D927B888D
788589768084747C7F72787A
6F72736F70716E6E6E6E6D6D6D6B6A6D6A686D68666C66646C64616C625F6B615D6B5F5A
6B5D586A5B566A5A546A58526A564F6A554D6A534B6C534A765C53765D55765E57755F5A
74605B73605C73625F7263627264637164647064646F64646D63636C66666C6A6A6D7070
6E7475707C7C728182758789798D907D9397819AA0849FA786A5AE8AACB68CB3BE90B9C6
90BAC78FB5C28DB1BD8CADB88BA9B389A5AE87A1A9859CA483989E8193997E8F947C8A8F
79868A778185747D8072787B
6F72736F70706E6E6E6E6C6C6D6A696D69676C67656C65626C63606B615D6B5F5B6A5D58
6A5B566A59536A575169554F6A544C6A524A6A5047785B52775C53765C55765D56755D58
735D59725E5A72605E7363617264637164637163647065646D64656C65656D696A6D6D6E
6D707170797A72818276888A7B90927F9599839CA286A1A988A7AF8AACB68DB3BE8FB8C5
92BDCB91BAC790B6C28FB2BD8DAEB88BA9B289A4AD87A0A7859BA282969C8091967D8C91
7A878B788286757E8172797B
6F72736E70706E6E6D6E6C6B6D6A686D68666C66636C64616B615E6B5F5B6A5D596A5B56
69595369575169554E69534C695149694F466D51477A5D53785C53775C54765D56745C56
725B56715B58715E5C7363627264637164637567677164646E66666C65656B66676B6B6C
6B6D6F6E7577717C7E7887897D919382989A859EA488A4AB89A8B08BACB68DB2BD8FB8C4
93BECB93BFCD92BBC891B7C290B2BD8EADB78CA8B189A3AB879EA584989F8193997E8E93
7B898D788487757E8172797B
6F72736E6F706E6D6D6D6B6A6D69676C67656C65626B625F6B605C6A5E596A5B56695954
69575168544E68524B685049684F46674C4278594E7B5D52795C53765B53765C56735A54
7158536F5855705C5A7160607667667264637467677165656F65656D66666A64646A6A6B
696C6E6A71746D7679778385809093849A9D88A0A58AA6AC8BA9B18BACB68DB1BC8FB7C3
92BCCA94C1D095BFCC95BBC893B7C291B1BB8FACB58CA6AF89A1A8869BA283959B809095
7C8A8F798588767F8273797C
6F71726E6F6F6E6C6C6D6A696D68666C66636C63616B615E6B5F5B6A5C57695A54695751
68554E67524B664F48664E45684D44694C427F5F527C5D53795C53775A53755B54735953
7056516E57536F5A586E5D5D786A697569687368677168686F66656D66666B66676B6C6E
6A6E706A72756A7477707E827B8A8E87999D8BA2A78DA8AE8CABB38CADB68CB0BB8FB5C2
91BCC994C1D096C1CF98C0CD98BCC795B6C092B0B98EAAB28BA4AB889DA484979E819197
7D8C907A8689768083737A7C
6F71726E6F6F6E6C6C6D6A696C67656C65626B625F6B605C6A5D596A5B5669585268564F
67534C664F48644C446249406A4E457354497F5F537C5D53795B52775B53755B54735852
6F55506E58546F5A586F5D5C7564637466657266657167676F65656C66666B66676C6C6E
6B6F716D76786D767A707E8375868A8294988DA4A88EAAAF8EACB48CACB68CB0BB8EB5C1
91BBC893C0CF97C3D299C2D19CC2CD98BAC595B4BD91ADB68DA6AE8AA0A7869AA0829399
7E8D927B878B778084737A7D
6F71726E6E6F6D6C6B6D69686C66646C64616B625E6B5F5B6A5C57695A5469575068544D
675149654D456248405D43396B4E447D5C507D5D517B5C52795B52775B53765B53735852
705651705A5573605D73615F7362617363627164637063636E62626C63636B65666B686A
6C6E706D74776F777C717E8375868B7D90958BA1A690ABB08FACB48CACB58CAFBA8EB4C0
91BAC793BFCD96C3D2A0C9D79FC5D19CBFCA98B7C194B0B990A9B18BA2AA879CA283959B
7F8E937B888C778184737A7D
6F71726E6E6E6D6B6B6C68676C65636B63606B605D6A5E596A5B5669585269564F68534B
675047654C4362473E5F44396A4D43795A4F7B5B517A5B52795B53775B53765B53745852
715751715A5575625F7563617464627363627164637063626E62626C63636C65666B696A
6D6D706E727672787D747F8478868B7D8F95869BA18DA7AC8EABB38CACB58CAEB98DB3BF
90B8C691BDCB92BFCFA5CEDCA3CAD69FC2CD9BBBC596B3BC92ACB48DA5AC899EA485979C
8190947C898D788285747B7D
6F71726E6E6E6D6B6A6C68666B65626B625F6A5F5B6A5C576A5A5469575069544D695249
684F46674C4266493F694B406E504675574C795B517A5C52795C54785B53775B53755952
725852725A5575615D7665637566647464637264627063626E62616C62626C65666C6A6B
6D6E706F737773797E7781867B898E809197859AA08AA3A98CA8B08CAAB38BADB88DB2BE
8FB7C490BBCA90BECEA8D0DEA7CDD9A2C6D19DBEC899B6C094AFB78FA7AF8BA0A686989E
8291967D8A8E798286747B7E
6E71716E6D6D6D6A696C67656B64616A615D6A5E596A5B5669585269564F69534B695148
694E456A4C426B4C406D4F4471544976594F7A5C517B5E547A5E55795D55785C54765B53
745953745B55745F5B7665627667657466647264627064636F63626C62626C65656C696A
6E6F71707477757B7F7982877D8A8F8191978599A08AA1A98BA5AE8BA8B28BACB78DB1BD
8EB6C38FBAC88DBCCCAAD2DFABD1DDA6C9D5A0C1CC9BB9C396B1BA91A9B18CA1A8879AA0
8392977E8B8F798386747B7E
6E70716D6D6D6C69686B66646A63606A605C695C58695A5469575069544D6952496A5046
6A4E436B4C406E4E4270514574574C785C527C5E547C60567B60577A5F56795D56785C55
765B54755C56755F5A7764617768667566657364637164626F63626C62626C65656C696A
6F6F71717477767C807B84887F8C9083929886999F899FA789A3AB8AA7B08BABB68DB0BC
8EB5C28EB9C78BBACAA6CEDCAFD5E2A9CDD9A3C5CF9DBCC598B3BC93ABB38EA3AA899BA1
8493987F8B907A8487757C7E
6E70716D6C6C6C69686B65636A625F695E5A695B5668585268554E68524B6950476A4E44
6B4D416D4C3F6F5044725348785C517C5F557D60567D62587C61587B60587A5F57795E57
785D56775E57765F5A7764607868657667657465647165636F63626D62626C65656D6A6B
707072737678777D807C858A818D9285939987999F889DA589A1AA8BA6AF8CAAB58EB0BB
90B5C190B9C78EBAC99CC7D6ABD4E1AED3DFA6C7D29FBEC89AB6BE95ADB58FA5AC8A9DA3
85949A7F8C907A8487757C7E
6E70716D6C6C6B68676A646269605D685D5968595467565067534C685148694E456A4C42
6C4B3F6E4C3F71514576594C7D61558062577F63597F635A7E635A7D62597C61587B6058
7A605879605978615C7965607968647767657566647266646F63636D63626C65666E6B6C
71717375787A797F827F878B838F9486949A88999F889CA489A0A98BA5AE8DAAB58FB0BB
92B5C194BBC896BECB9BC5D4A4CFDDABD1DEA6C9D4A1C0CA9BB7C096AFB791A6AD8B9EA4
86969B808D917B8588757C7F
6E70706C6B6B6A6766696361685F5C675B5766585266544E66514A674E46684C42694A3F
6C483C6F4B3F7453467B5E5280655983655A82655A81645B80645B7E635A7D625A7D625A
7C625A7B635C7B645E7A67627A69657868657566647365647063626C63626C66666E6C6C
72727377797B7B808380888C848F9486949A88989F889CA38AA0A88CA5AE8FAAB491B0BB
94B6C298BDC99BC0CDA1C9D7A8D3E1A9CFDCA6C9D5A2C2CC9DB9C298B1B992A8AF8D9FA5
87979C818E927B8589757D7F
6D6F706B6B6A6A666568625F675D5A65595565565064524B644F47654C4366493F68473C
6C473B704C4077564A80635686685C86685D85675D83665C81655B80645B7F635B7E635B
7E645C7D665E7E67617D6A657D6B677A6A677768657466647063626D63626C66666F6C6D
727374777A7D7D828582898D858F9487949A88989E899CA38BA0A88EA4AE91AAB493B1BB
97B7C29BBECA9EC2CEA4CBD9AAD4E2ABD3DFA8CCD7A4C4CE9FBBC49AB3BA94AAB18EA1A7
88989D828F937C8689767D7F
6D6F706B6A6A69656467605E655C5864575363534E624F49624C4463494064463B654337
6A473B7250437E5C4F89685B8B6C5F8A6B5F87695E85685D83665C81645B7F645B80645C
7F655E806860806A63806C677F6D697C6C687969677567657163626D63626C66676F6C6D
737475787C7E7D838682898D858F9488949989989E8B9CA38CA0A88FA5AE92AAB495B1BB
99B8C29EBECAA2C2CEA7CEDAACD3E1AFD8E4ABCFDAA7C6D0A1BEC69CB5BC96ABB290A2A8
8A999E8390947D878A767D80
6D6F6F6A6969676463655F5C635A5661555160514B5F4D465F494160463C614237613F32
654539735346836153926F609170628E6E618B6B5F87695E84665C82655B80645C80645D
81665E826962836E6684706A82706B7F6F6B7B6C697668657164636D63626C66676F6D6D
737476797C7F7D838682898D858F948894998A999E8D9DA48EA1A991A6AF94ABB597B1BB
9BB7C2A0BEC9A4C3CDABCEDAB0D4E1B3DCE8AFD2DDAAC9D3A4C0C99EB7BE98ADB492A4A9
8B9A9F8491957D878A767E80
6C6E6F696868666361635D5B6157545E524E5D4E485C49435C463E5D42395D3F345E3C30
6043377253478664569A74649774659270638E6D61896A5E84665C82655C80645B81655E
836760866B6388706888736C86746F83736F7D6E6B7769667164636D63626C66666F6C6D
727476797C7E7D838681888C868F9389949A8B999E8E9EA590A2A992A7AF95ACB599B1BB
9DB7C2A1BDC8A5C2CDAFCEDAB6D9E5B8E0ECB3D6E0ADCCD6A8C2CBA1B9C09BAFB694A5AB
8D9CA08692967E888B777E80
6C6E6E686767646160615B595E55525B4F4B594A4558453F58423A593F365B3C315C3D32
5F42377355488B6859A179689C77679673659170638B6B5F84665C80635A7D61597D635B
82675F896C648C726A8B746D8A77718878737F716E786A687164626C62616B65656D6B6C
717275777B7E7B81857F878B858E928994998C9A9F919FA592A3AA94A7AF96ACB59AB1BB
9FB7C2A2BDC7A6C1CCB1CED9BBDCE6BEE3EFB8D9E3B1CFD8ABC5CDA4BBC29DB1B796A7AC
8E9DA18793967F888B777E80
6B6D6E67666662605E5E59575B524F574C4854464153413A533D35553B325A3B305C3E34
5D433974564A8F6B5BA67D6BA07A699A75679472648E6D6187675D7F62597B6058765E57
7C635C866B628C726A8D736C8B767088787380726F786B687164626B61606964646B6A6B
6D6F72777C7E7980837D858A848D918B959A8E9BA093A1A695A5AB96A8B097ACB59BB2BB
9FB7C1A2BCC7A8C2CDB6D1DBC1DEE8C3E6F0BCDCE5B6D2DAAFC8CFA8BDC4A0B3B998A9AE
909EA288949780898C787E81
6A6D6E656665605E5D5C5755574F4C5348444F413C4C3B354B362F4E352C5E40345F4338
62483D76584C936D5DAB816EA57D6C9E7869977366916F638A6B6083655B7E6259775F57
7A615A80675F876F678C736C8B767086767180726E786B687064626A6160676262686769
696B6F71787B727B7F778186848C908A94998E9A9F96A2A797A6AC98AAB197ADB69AB1BB
9EB6C0A1BBC6AAC3CEBCD4DDC9E2EBC9E9F2C1DFE7BBD5DCB3CAD1ACC0C6A3B5BB9BAAAF
92A0A48A9598818A8D787F81
6A6C6D6464645E5C5B595452534C494E4340483B3743332E3E2B25462F275B3F3465493D
6A4E437D5E50977060AF8471A87F6EA17A6B9974669372658E6E6387695F82645B7E625A
7E645B826860866D658A736B89746E85746F7F716D776A677064616A6160676161676668
696B6F6C73786B767B6C79807F888D85919689969B94A0A596A4AA97A9B096ACB598B0B9
9CB4BE9EB8C4ACC5CFC0D6DED0E6EECFEDF6C8E2EAC0D8DFB8CED4B0C3C8A7B7BC9EACB1
95A1A58B9699828A8D797F81
696B6C6363635C5A595651504F4846483F3C413531392B262F1E19402C2451382F62473C
6D51468462549B7363B28672AB8270A47D6D9B76699472658F6F648B6D6286695F83665D
83675E856B62886E668A726B8A756F84736D7E6F6B7769666F6462696260666161666667
696C6E6C72776C757B6B787F7682887D8A908492988E9CA292A1A893A6AE94A9B295AEB7
98B2BC9BB6C1AFC6D0C4D7DFD4E6EED6F1F9CEE7EEC6DCE2BDD1D6B4C5CAAABABEA1AEB2
97A2A68D979A838B8E798082
686B6C6162625A5858534F4E4B4543443B383B302D3225212717133826204A352D5D443A
6F52468764559F7665B38673AF8473A780709F7A6D977467906F638B6C61866A6085685E
83675E846A60866C6387706887736C83706B7D6C687668656F6462696261666161646465
686C6D6D73766E777C717C817682887B888E8190968A989F8D9EA58FA3AB91A7B093ABB5
93AFBA99B5C0B1C7D0CADAE0D4E5ECDBF4FAD5EBF1CDE0E6C3D4D9B9C8CDAEBCC0A4B0B4
99A4A78F989B848C8E7A8082
686A6B606161585756504D4C4843413F3835362C292C201C21130F30201B443129594137
6E5145876456A07766B38673B28776AB8374A37E719C796C9474688E6E64896C62886A61
85695F846A60846A62856D65846F68816E687B6A667667647065636A6362666162626263
6367696970736E777A757E827984897C898E808F9586969C899BA38CA0A98EA5AE8FA8B2
8EABB69AB6C1B3C8D1CEDBE1D5E5EBDEF4FAE1F4F8D5E6EAC9D8DCBECBCFB2BEC2A7B2B5
9BA5A890999B858C8F7A8082
676A6B5F60605655554E4B4A45403E3C3533322926271D1A1C100C2B1C173E2D26543E34
6B4F438663559E7665B28572B48977AE8777A78274A07E7199796D93756A8F71678C6F64
896D63876C63866C62846C63826C647F6C667A69647667647166646D6564696465646466
616568636B6E667175707A7E7782877C898E7F8F9584949B8799A18A9FA88BA2AC8AA5AF
8AA8B39CB7C1B4C9D1CCD9DED9E6EBE0F2F7EBFAFDDCEAEECFDCDFC2CED1B6C1C4AAB3B6
9EA6A9929A9C868D8F7B8082
67696A5E5F5F5554544C4948423E3D3833312E2724231A17180E0A271A15382822503A32
674C418160529A7363B08371B58A78B18A7AAA8577A382759D7D72987A6F93766C8F7369
8C7066896F65876D63856C64826B647F6A647B69647667647367656F67666B6768686769
65696B656B6F656F7469757A6F7C8276848A7A8B9280919882969F869BA5869FA986A2AD
88A6B29CB7C0B3C7CFC8D7DCDBE6EAE7F4F7F1FCFFE3EEF1D5DFE2C7D1D3B9C3C5ACB5B7
9FA7AA939A9C878D8F7B8182
66696A5D5E5F5353534A4847403C3B36312F2B2422201815150B082419143526204B372F
63493F7C5D50957060AB806FB68B79B48C7CAD897AA78578A081759B7D7296796F92766C
8E73698B7067886E65866D64826C647F6A647B69647768647469667169686E696A6B6A6C
686C6E686E716872766A767B6D7B8171818776878F7B8E967E939C8097A1819CA683A0AB
89A7B39DB7C0B3C7CEC6D6DBDBE5E9EBF4F6F6FEFFEAF3F5DAE2E4CAD3D5BCC4C6AEB6B8
A1A8AA949B9D888E8F7C8182
66696A5C5D5E5252524847463E3B3A332F2D2923211D161412090622171332241E47332C
5D453B77584C8F6B5CA57C6BB48977B68E7EB08B7DA9877BA384789D8076997C7194796E
90766C8D72688A7066866E65836C64806B647C6A64796966766A68746B6A716C6C6E6D6E
6B6E706B70746B74786C787D6F7C8271818874868E778B947B919A7D959F7E99A3809EA9
8CA9B4A1B8C1B4C7CEC7D6DBDBE5E8EEF3F5F8FDFEF1F7F8DEE5E6CDD4D5BEC5C6B0B6B8
A2A9AA959B9D888E8F7C8182
65686A5B5D5E5151524746453C3A39312E2C26211F1B14120F07051F15112F221C423029
5740376F53478866589F7767AE8573B78E7DB28D7EAB8A7DA5867A9F83789A7F74967B70
92776D8E746A8B7168886F66846D65816C657E6B657B6B67786C69766D6B736E6E716F70
6F71736D73766E767A6E7A7E6F7D8371818873868D758A92788F9879939D7A97A2809EA9
8FABB5A3B9C2B6C8CFC9D6DBDDE5E8EFF3F3FAFCFCF4F8F8E0E5E5CFD4D5BFC5C6B1B6B8
A3A8AA969B9C898E8F7C8182
65686A5B5D5D5051514645453B3938302C2B24201E1913110D06041C13102D201B3E2D26
523C33684E43826154987263A8806FB38B7AB28E7FAC8B7EA6877BA184799C8176977D73
93796F8F756B8C7269897068856E66826D667F6C667D6C687B6E6B786F6E757070737172
71737570757870787B707B7F707E8471828872858D748A92768D9777929C7A97A283A0AB
93ADB7A5BBC3B9CAD0CCD8DCDFE6E8F1F3F3FCFDFCF1F3F3DFE3E3CFD3D4C0C4C5B1B6B7
A3A8A9969B9C898E8F7C8182
6568695A5C5D5051514544453A38382E2C2B221F1E1612100A05031A110E2A1E193A2A24
4B383061493F7A5B4E906C5DA37C6BAE8676B08C7DAC8B7EA7887CA185799D8277987E74
947A7190776D8D736A8A7169866F67846F68816E687E6F6A7D706D7B716F787372767474
74767772777A727A7D727D8171808572828972858D738992748D9676919C7B98A288A3AD
97B0B8ABBEC5BDCBD1D0DADDE3E8E9F4F4F4FFFFFEEEEFEFDEE0E0CED1D1BFC3C3B1B5B5
A3A7A8969A9B898D8F7C8182
6568695A5C5D4F50514444453938382D2B2B211E1D14100F070302170F0D261C18362822
46342D5B443B71554A8766589B7666A88171AE897AAC8B7DA7887CA2857A9D8277997F75
957B7291786F8E756C8A736A88716985706A836F6A81716C7F736F7D74717B7574797676
76787975797C747B7E737E8273808672838A72868D738992758D9679939D809BA58EA7B0
9EB3BBB0C1C7C2CED3D4DCDEE8EAEBF7F6F5FEFDFCEBECEBDBDDDCCCCFCEBEC1C1B0B3B4
A2A6A795999A888D8E7C8082
6568695A5C5D4F50514444453838382C2B2B201E1D13100F050101130D0A221916312520
41312A533F366950457D5F53916F619F7A6BAA8576AB8A7BA7877BA284799D8277997F75
957C729279708E766E8B746B89726A87726B85726C83736F8275728077747E78767C7978
797A7B787C7E767D8074808374818673848A72878E738A92768E977C969F869FA895ABB3
A5B7BEB5C4C9C7D1D4D9DFE0EDEDEDFBF9F7F6F5F4E7E7E6D8D9D9CACBCBBCBEBEAEB1B2
A1A5A5949899888C8D7C8081
65686A5A5D5E4F51524445453838392C2B2C201E1E1210100401010E09071D15132C211C
3A2C264C3A32604A4074594E856759957364A37F70A88678A58679A184789D8176997F74
957C729279708F776F8D756D8A736B88736C87746E867671857875847A77827B797F7B7A
7D7D7D7B7E8078808277818575838874858B73878E748A927890998299A28DA3AB9DAFB6
ADBBC1BBC7CBCDD4D6DFE2E3F2F0EFFFFDFBF0EFEEE2E2E1D4D5D4C7C8C8B9BBBBACAFAF
A0A3A3939798878B8C7B8081
65686A5A5D5E4F515244454638393A2C2C2D201F1F1311110402020A060617110F261C19
34282244342E57433B6A52487A5E53896A5D987668A18072A28376A082769C8175987E74
957C72927A7190786F8E776E8B746D89746D8A7771897974897B77877D79867E7B837E7D
807F7F7E81827B828479848777848976868C768990778C947D949C889DA594A7AEA3B3B9
B3BFC3C2CBCED3D7D9E6E5E5F3F1EFFDFAF8ECEBE9DEDDDCD0D1D0C3C4C4B6B8B8AAACAD
9EA1A1929596868A8B7B7F80
65696A5A5D5F505253454647393A3B2D2E2E212121141313050404050302110D0B1F1815
2E231F3B2E294D3C35604B426E564C7C6156896C5F9677699B7B6F9C7E729A7F73967C72
947C72927A719079708E786F8B766E8A766F8D79738E7C768D7E798B807C89807D868280
8382818183847E84867C858879878B78888D7A8C927C909783989F8EA1A89BABB1AAB7BB
B9C2C5C8CED0D9DBDBEBE8E6F7F2F0F4F1EFE6E4E3D9D8D7CCCCCBBFC0C0B3B5B5A7AAAA
9C9F9F91949585898A7A7F80
65696A5B5E5F5053544648493A3C3D2F30312323241616170909090000000B0808191412
271F1C34292544363057453D634F47715A507A6157866B608E726693766A93796E91796F
917970917970907A718E78708B766F8B77708E7A73917E7891817C8F837E8D837F8A8482
8784838586868287887F888A7D898C7C8A8F7E8F9482959A8B9CA295A5ABA2AFB4B0BABE
BFC5C7CED1D2DEDDDCECE9E6F9F4F2ECE9E7DFDEDCD3D2D1C7C7C6BBBCBCB0B1B1A5A7A7
9A9C9D8F92938488897A7E7F
65696B5B5F6051545547494A3C3E3F3132332626271A1A1B0D0D0E000001040303130F0E
201A172D24213B302B4D3E375A49416551496E595077615780685E856C62876F66877269
89736B8C756D8D776F8B777089766F8B78708D7A73907E7792817C92847F9085818C8583
8A868588878786898A838A8C828B8E818E9285939789989D92A0A59CA9ADA8B3B6B6BEC0
C4C9CAD3D4D3E0DEDDEEE9E6F2EEEBE4E1DFD8D7D5CDCCCBC1C2C1B7B8B7ACAEAEA2A4A4
979A9B8D9091838788797D7F
666A6B5C6061525557484B4C3E4041343536292A2B1D1E1F1112130405070000000C0B0A
19161426201D332A2743373250423C5A4A4363514A6C5951745F5778645C7A67607D6A63
806D6584706985726B87756E86756E8876708B79728E7D7790807B92847E9086818E8683
8D88858B88888A8B8B888C8D878E908791948B979A919CA09AA4A8A3ADB0AFB6B8BCC1C2
CACCCCD7D6D4E1DFDDECE7E5E6E3E0DBD9D7D0CFCEC6C6C5BCBCBCB2B3B3A8AAAA9EA1A1
9598988B8F8F828687797D7E
666A6C5D61625457584A4D4E40434436393A2C2E2F2123241617190A0B0D000102050606
131111201C1A2C26243A312E453A3650433E57494461514B6857506C5C556F605A73645E
7667617B6B657B6C6680716A81726C83746E857771897B758C7E798E827D8E84808C8582
8C87858B89888B8B8B898D8E8A90928C949691999C979FA2A0A8AAA9B0B2B5BABBC2C4C4
D0CFCED8D6D5E2E0DDE3DFDDDAD8D6D2D0CFC9C8C7BFBFBEB6B7B6ADAEAEA4A6A69B9D9E
929596898D8E818486787C7E
676B6C5E626355595A4C4F514346473A3C3E3032342628291B1D1F101214050608010304
0D0E0E1A1817252220322C2A3D3431463D394C423E5649455E504B615550665A556A5E5A
6E615D746661746863796C677B6E6A7E726C817570847873887C788A7F7B8B827E8A8481
8A86848B89878C8B8B8A8D8E8D9192909697969C9E9CA2A4A5AAACAFB3B4BBBDBDC7C7C6
D2D0CFDBD9D7DDDAD8D7D5D3D0CECDC9C8C6C1C0BFB9B9B8B0B1B1A8A9A9A0A2A2989A9B
909293888B8C7F8384777C7D
676C6D5F6365575B5C4F525346494A3D40413437382B2D2F21232517191A0C0D0F020405
090B0C1414141F1D1D2A272535302E3E3734433C394B423F534946574E4B5E5552625856
665D5A6B615D6E6461726864756B68796F6B7C736E7F7672847A76867D7987807D87827F
8885838987868A8A898A8D8D8E91929498989A9E9FA1A4A5AAACADB4B5B5BFBFBECBC9C8
D6D3D2D8D6D4D2D0CFCDCBCAC7C6C5C0C0BFB9B9B8B2B2B2ABACABA3A5A59C9E9E949797
8D909185898A7E8283777B7C
686C6E606466595D5E515556494C4E414446393C3D303334272A2B1E2022141618090C0D
06090A0E101119191A2323222D2B2A3632313B3635413C3B4843414D4847564F4D5A5452
5F5856635C5A68615F6B64626F6865736C6978706D7B74707F7875827B78857F7C83807E
868481878684878887898B8B8E91919597989C9E9FA3A5A6ADAEADB7B6B5C0BFBECBC9C7
D4D3D2CECDCBC9C8C6C3C3C2BEBDBDB8B8B7B2B2B2ABACACA5A6A69EA0A0979A9A919394
8A8D8E8387887D8182767A7C
696D6E6266675B5F605457594D505245484A3E414236393B2E313225282A1D2022141719
0B0F11090D0F1215171D1E1F282728302E2E3533333A3837413E3E4543434C4A49534F4E
5854535C5857615D5C6561606965636E6967736E6B77716F7B76737F7A77827E7B82807E
83817F838281848685888A8A8D90909496969D9E9EA6A6A6ADADADB8B6B5C2C0BECAC8C6
C9C9C7C4C3C2BFBFBEBABAB9B5B5B5B0B1B0AAABABA5A6A69FA1A1999B9C9396968D9091
878B8B8185867B7F80757A7B
696E6F6367695D6162575A5C5054554A4D4F4346483C3F4135383A2D313226292B1F2224
171B1D1013150E1214171B1C2224252B2C2D3232333536363A3A3B3E3F414545464C4C4C
5150515756555B5A5A5F5D5D6462616966656E6B69736F6D7773717C7876807D7B827F7E
83817F8081808183838789898C8E8E9395959D9E9DA7A6A5AEADADB6B4B3C0BEBDC1C1C0
BDBDBCBABAB9B5B6B5B1B2B1ADAEADA8A9A9A3A5A59FA0A0999C9C9497978F92928A8D8E
8588897F83847A7E7F75797A
6A6E7065696A5F6365595D5F5458594E5253484C4D4245473C3F4136393B2F3334292C2E
2226281C202215191B15191B1D2224262A2C30313334363737393B3A3D3F41434547494A
4C4D4E5152535557585A5A5B5F5F5F6564646A68676F6D6C72716F7875747D7B79807E7C
81807E7F80808384838889898C8E8E9395949D9D9CA5A5A4AEADACB4B3B2B8B8B7B5B6B5
B3B3B3AFB0B0ACADADA8AAA9A5A6A6A1A2A29D9E9F989A9B9496979092938B8E8F878A8B
8285867D8182797D7E74787A
6B6F71666A6C6165675C6062585B5D5356584D5153484C4E4347483E4143383C3E333739
2D3133282C2E2226291C20221C212424292B2E3234343739383B3D3A3E403F434546494B
4A4D4E4E51525154565558595B5D5E6161626566666B6B6A6E6E6D7473717676757E7C7A
7D7C7C7C7E7D8082828487878A8C8C929393999A9AA4A3A2ABAAAAACACADACADACAAABAB
A8A9A9A6A7A7A3A4A4A0A2A29D9F9F999B9C9698989295958F91928B8E8E878A8B838687
7F83847B7F80777B7D737879
6B7072686C6E6468695F64655B5F61575B5D5357594F53544A4E50464A4C4145473D4143
383C3E34383A2F33362B2F31252A2D262B2E2B303334383B3A3E413E424541454746494B
4A4D4F4C505250555654575A585B5C5C5E606164656769686B6D6D70706F7273737A7978
7A7A7A7C7D7D7F8181838686898B8B909191949696A1A1A1A3A4A4A2A3A3A1A2A2A0A1A1
9EA0A09C9E9E9A9C9C979A9A9597989295958F92928C8F90898C8D86898A838687808384
7D8081797D7F767A7C737779
6C7172696E6F666A6C6367695F64655C6062595D5E55595B5256574E52544B4F50474B4D
4348494044463C4143393D40353A3D33383B31373933393C3C414441474A484B4D4A4E4F
4C51524E525451565855595B585C5D5A5E605F6365646767696C6C6D6F6E717272757675
7878787A7B7B7D7F7F8184848688888D8F8E919393989A9A979999979999979999969898
9497979395969194948F92928D90918B8E8F898C8D868A8A8487888285867F83847C8081
7A7E7F777B7D75797A727678
6D72736B6F71686D6E666A6C6368696165675E62645C6062595D5F565B5C54585A515557
4E53554C5052494E50474B4D44494C42474A4146493E434742484A454B4E4A4E51505455
52565852575854595B575B5D595E605C6062606465626667676A6A6A6D6D6E7171727373
757676787A7A7B7D7D8183838184848588888A8D8E8C8F8F8D8F908D8F908C8F908C8F8F
8B8E8E8A8D8D898C8C878A8B86898A8487888286878184857F82847D81827B7F80797D7E
777B7D75797B737879717677
6E72746C71736B6F71696D6F676C6D666A6C64686A6267686165665F63655D61635B6061
595E60585C5E565A5C54595B53585A52565951555850555851565952575A51575A575B5D
595D60595D5F5A5E60595E605B606260646663666765696A686B6C696D6E6D7070707273
727576787A7B76797A7B7E7F7D80817E8282818485828586838687838687838687828686
8285868184858084857F83847E82837D81827C80817B7F807A7E7F787C7E777B7D767A7B
75797A737879727678717577
6F73756E72746D72736C71726B70716B6F716A6E70696D6F686C6E676B6D666B6C656A6B
64696B64686A636769626668616668616567606567606567606567616568616668636769
64686A63686A64696A63676A62676965696B666A6B686C6D696D6E6A6E6F6B6F706D7071
6F737475787974787975797A767A7B777B7C787C7D797C7E797D7E797D7E797D7E797D7E
787C7E787C7D787C7D777B7D777B7C767A7C767A7B75797B75797A74787A737879737778
727678717677717577707576
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.754707 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(68) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
737677737677737577737576737576737576737576737475727475727475727474727374
72737472737472737372727372727372727272727272717272717172707072706F716E6C
727070727172727273727172727273717273717272717172717172707172707172707173
70717370737570747571757772767873777973787A73797B747A7D757C7F767E80778084
7A8388777F82767D80767B7E757B7D757A7C757A7C75797B74797B74787A74787A747879
747779747779747778747678
737677737576737576737475727475727474727374727273717273717172717171717171
717070716F70706F6F706E6E706E6E706E6D706D6D706C6C706C6B706B69706A68706865
716B69716C6C706D6D706D6D706E6E6F6E6E6E6D6D6E6C6D6E6C6D6D6C6D6D6D6E6D6D6F
6D6E706E70726E727470747671767872787B737A7C747C7F747F827782867985897B898F
7D8B917A868B798387788084777F82767E81767D80767C7F757B7E757A7D757A7C75797B
74787A74787A747779747778
737577737476727475727474727373717273717172717071707070706F6F706F6F706E6E
6F6D6D6F6C6C6F6B6B6F6B6A6F6A696E69686E69676E68666E67656F66636F64616F635E
6F66636F67666F69686E69696E6A6A6D69696C69696B68696C68696B68696A696A6B6B6C
6C6D6F6C6F716D70736E73766F767971797C727C7F747F8376838778878C7B8B917E9198
7E90967C8B917A888D798589788387788185778083777F82767E81767D7F757C7E757B7D
757A7C74797B74787A747779
737576737475727374727373717272717171707070706E6F6F6E6E6F6D6C6F6C6C6E6B6A
6E6A696E69686D68676D67656D66646D65636D64626D63606D625F6D615D6D605B6E5E59
6E615E6E63616D65646D66656C66656B66666A66666965666A65666A656769676869696A
6A6B6D6A6D6F6B6F726C73756E767A707A7E727E8274828777878C798B927D91988197A0
7F939A7D8F967C8C927B898E7A878B798589788387788285778083777F82767D80767C7F
757B7D757A7C74787A747779
737576727475727273717272717071706F6F6F6E6E6F6D6C6E6C6B6E6A6A6D69686D6867
6C67656C66646C64626B63616B625F6B615E6B605C6B5F5B6B5D596B5C586C5C566D5A54
6D5E5A6D605D6C61606C62616B63626A6363696363696363686263686364676465686668
68696B696B6E696F716A72756D777A6F7C8072808475858A788A907A8F977E969E829BA4
80969F7E939A7D8F967C8C927B8A8F7A888D79868A798488788286778184777F82767D80
767C7E757A7D75797B747879
737576727374717273717171706F6F6F6E6E6F6C6C6E6B6A6D69696D68676C67656C6564
6B64626A62606A615E6A5F5D695E5B695D59695B57695A556959546A58526B58526C5751
6C5B566C5D5A6B5E5C6A5F5E6A605F696060686060676061676061666161666263666465
666769676A6C686E716971756B777A6E7C8171818675868C788D947C939B809BA4829DA7
8099A27F969E7E929A7D8F967C8D937B8A907A888D79868B798489788286778184777F82
767D80757B7E757A7C74787A
7374767273747171727070706F6E6E6F6C6C6E6B6A6D69686C67666C66646B64626A6260
6A615E695F5C685D5A685C58675A5667585466575266555066544E67534D6A534C6C564F
6C59546B5A576A5B59695C5B685D5C675D5D675E5D665E5E655E5F655E5F646061646263
65656765696B666D706871756A777A6D7C8170838874888E798F977C979F819FA9829FA9
819BA57F98A17E959D7E929A7D90967C8D937B8B907A888E7A878B798489788286778083
777E81767C7F757A7C74787A
737475727273717071706F6F6F6D6D6E6B6A6D69686C67666B65646A63616A615F695F5D
685E5B675C58675A5666585465565165544F64524C64504A634E48634C456C534B6E5750
6C57526A5854695956685A58675B59665A5A655B5B645B5B645B5C635C5D635E5F636062
63636664686A656C6F67717469777B6C7D82708389748A9179929A7D99A282A1AC82A0AA
819DA7809BA47F98A07E959D7D929A7D90967C8D937B8B907A888E79868B798488788185
777F82767D80757B7D74787A
727475717272706F706F6E6E6E6C6B6D6A696C67666B65646A636169615F685F5C675D5A
665A5766585465565264544F63524D63504A624D47614B4460484160473F72574E6E564F
6B565169565268575467575566585765585764585863585962585961595A615C5C615F60
62636563686A646C6F66717469777C6C7E8370848A748C9379939B7D9AA482A3AE82A1AC
819FA9819DA6809AA37F98A07E959D7E92997D90967C8D937B8A907A888D79858A788387
778084767E81757B7E74797B
727475717172706F6F6F6D6D6E6B6A6C68676B66646A636269615F685F5C675C59665A56
65575364555163534E62504B614E48604B456049425F463F5C423B684C4371564D6D544D
6A534F68534F6754516554526455546355556255556155556055565F56585F5A5B5F5D5F
60636562686A636D6F65727569787C6C7F8470858B748C9478949C7D9BA582A3AF82A4AF
82A2AC819FAA809DA6809AA37F98A07E959C7E92997D8F967C8C927B8A8F7A878B798488
788185777F82767C7E75797B
727374717171706E6E6E6C6B6D6A696C67666A646269625F685F5C675C59655A56645753
63545062524D614F4A604C465F4A435E47405D443D5B403863473E6D4F466C50496A514B
68504C66514D65514E6452506353526253536152535F52535E51525E54565D58595E5C5E
5F626460686A626D6F65737669797D6C808571878D758D9578949D7D9BA580A2AD83A6B2
82A4B082A2AD81A0AA819DA6809AA37F979F7F949C7E91987D8E957C8B917B888D7A8589
788386777F83767C7F75797B
7273747170716F6D6D6E6B6B6C68676B656469636168605D675D5A655A57645753635450
62514C604E495F4B465E49425D463F5C433B5C40385F41386B4C426A4C43694D45684D48
664D48644D49634E4C62504E6150506051516050515E50515C4F515C53545C57595D5D5F
5D61635F686A606D70647477687A7E6D818672888E758E9678949D7C9AA47FA1AC82A7B2
83A8B482A5B082A2AD82A0AA819DA6809AA280979F7F949B7E90977D8D937B8A8F7A878B
798487788083767D7F75797B
7273747070706F6D6D6D6A696C67666A646269615F675E5B665B5764585463545061514C
604E495E4B455D48415C453E5B423A5A3F37593C3268473D694940684A42674B43654B45
644A45624A46614B49614E4D604F4F5F4F4F5F4E505D50515C52535A53545B595A5B5C5E
5B5E605D66685F6D6F647477697C7F6D828672898F768F9778959D7B9AA47EA0AB81A5B1
84AAB783A8B483A5B183A2AD82A0A9829DA68199A280969E7F93997E8F957C8C917B888D
798589788184767D80757A7C
727374706F706E6C6C6D69686B6564696361685F5D665C5964595563555161524D604E49
5E4B455C48415B443D5A4139593E35573A315D3D336C4A3F694940674940664943644843
6147425F46435E48475F4C4C5E4D4D5C4D4E6153545E53535C55565A56575A5758595A5C
585D5F5B64675D6A6D647376697D806E8387738A9176909879959E7A9AA47D9FAA7FA4B0
82A9B683ABB883A8B584A5B184A3AD839FA9829CA58198A080959C7F91977D8D937C898E
7A868A788285777E81757A7C
727273706F6F6E6B6B6C68676A646368615F675E5B655A5763565362534E604F4A5E4C46
5C48425A443D594139573D35563A3155362C6744386B493F69483F66473F654842624640
5F443F5C43405C46455C4A4A6052515F53526358585F55565C56575A5657585455575B5D
575D60586165596568616F736A7C7F708589748B9177929979969E7A99A37B9DA97EA2AE
80A8B583ACBA84ABB885A9B585A6B185A3AC849FA8839BA381979E8093997E8F957C8B90
7B878B798386777E81757A7C
7172736F6E6F6D6A6A6B676669636268605D665C5964585562545060514C5E4D475C4943
5A453E584139563C3554393054372E56362B6E4A3D6B493E68483E65473F63474160453F
5D423D5A423F5B45455A4A4A6557566256556055555E56565B535459545457535557595C
565B5E5760645863675E6D7167777B718488758D9278939A79979F7999A27A9CA77CA1AD
7FA7B481ABBA84ACB987ACB988AAB587A6B086A2AB849EA68399A181959C7F91967D8C91
7B888C798387777F82757B7D
7172736F6E6E6D6A696B6665696260675E5C655A5763565261524E5F4E495D4A455B4640
59423B563D365338304E322954352C603E326F4B3F6B493E67473E64473F6246405F443F
5C413D5B45415D49485E4E4D6455546055545E54545C54545A515257525356525456575A
565B5D5862655863675C6B716273786D7F85778E9479959B7997A07898A1789BA67A9FAC
7DA5B380AAB884ADBC87AEBC8BAFB989AAB488A5AE86A0A9849CA382979E8092987E8E93
7C898D7A8488787F82767B7D
7172736F6D6E6C69696A656468615F665C5A64595562545060504B5E4C475C48425A443D
583F38553A3250342C4A2E2459382E6C483C6C4A3E69483E66463E63473F6146405E443F
5B423E5B46435F4D4B5F504E5F51515E52525C53525A5252585151565152555354555659
565B5E5761645A63695D6B71617378697D83768D927A969B79979F7797A1779AA5799EAB
7CA4B17EA8B680ABBA8BB3C08DB2BD8CADB88AA8B288A3AC869EA68399A081949A7F8F94
7D8A8F7A8589788083767B7D
7171726E6D6D6C6868696462675F5D655B5863575360524E5E4E495D4A445B463F59423A
573D3555393051332A5132275E3D316B483C69483D67473D65473F62463F6046405E443F
5B433F5B46435F4E4C5E504F5E51505C51505B5151595050574F4F544F50545254535558
555A5D565F635A646A5D6C7162747A697E8471899078949A78969E7697A07699A4779DAA
7AA2B07BA6B57CA9B990B8C690B5C28FB1BC8CABB58AA6AF87A0A8859BA282969C809096
7D8B907B868A788184767B7E
7171726E6C6C6B6867696361665E5C6459566155515F504C5D4C475B48425A433C583F38
573B3355382E55342A58372B5D3D3263433865463C65473E6347406146406047405E453F
5B443F5B46435D4C495E504F5D51505B5050594F4F574F4F554E4E534E4F525052525557
53595C555E635A656A5F6D7364757B697E856F878E74909776949D75959F7497A3769CA9
79A1AF79A5B47AA8B892BAC894B9C591B4BF8EAEB88CA8B189A2AB869DA484979E819297
7E8C917B878B798184767C7E
7071726D6C6C6B6766686260655D5A62585560534F5E4E4A5C4A445A453F58413A573D35
56393056362C57352958382D5C3D3260423864453C64473F6248406147405F46405D4540
5C443F5B46425B4A475D504E5C51505A5050584E4E564E4E544D4E514C4E514F51515356
52595D555E635B666B5F6E7464767C697E856E868D728D9673909A73939E7396A2769BA8
77A0AE78A4B377A6B794BBC996BCC894B7C291B1BB8EABB48BA5AD889FA68599A0829399
7F8D927C878B798285767C7E
7071716D6B6B6A666567605F645B596156535E514D5C4C475A474158433C573E37563B32
55372D55342957352958382D5C3E3460443B63463D6248406148416047415F46405D4540
5C45405A46425A49455B4D4C5B515059504F574E4E554E4E534D4E504B4D4F4E50505255
52595D555E635B676C606F7565777D697E856D858D708B94708E9871919C7396A1759AA7
77A0AD79A3B277A5B590B8C69ABFCC97BAC693B4BE8FADB78CA7B089A0A8869AA183949A
808E937D888C7A8285777C7E
7070716C6A6A696564665F5D6259575F54515D4F4B5A4A4458453F564039553C3454382E
54342A54322656352A58382D5E413762453D62473F6249416149415F48415E46405D4640
5B45405A46425948455A4C4A5B5050594F4F564E4E544D4E514C4D4F4B4D4E4D504F5256
52595D555F645B676C606F7665787F6A7E866C848D6D88916E8C9670909B7295A1759AA7
789FAD7BA4B37CA7B68BB4C398BFCC9BBFCB95B7C291AFB98DA9B28AA2AA879CA384959C
808F947D898D7A8386777C7F
7070716C6A6A686463645E5C6158555D524F5B4C4858474256423C543D3652383052342B
523025522F24543429593C315F453C63473E6249406149416049425F48415D46405C4640
5B46415A47425948455A4D4A5A4F4E584F4F554D4D534D4E504A4C4D4A4C4C4C4F4E5256
51595D5660645A676D607077667880697E866B838B6B868F6D8A94708E9A7293A07599A6
799FAD7DA6B481AAB88AB3C295BFCD9CC1CE96B8C492B1BB8EAAB48BA4AC889DA485979D
8190957E8A8E7A8386777D7F
6F70706B6969676362635C5A5F56535B504C584A4555443F533F385139324F352C4F3027
4F2C22502E2354352B5B413661483E644A41634A416149426049425E47415D46405C4640
5B46415947435A49465A4D4B5A4F4E574E4E554C4D524C4D4F494B4C4A4C4B4C4F4D5256
51595D5661655A686E617178657880687D8569818A6A848E6C88936F8D9872939F7699A6
7A9FAD7FA7B484ABB98CB5C495C0CF96BDCB95B9C492B2BD8FACB58CA5AE899EA685989E
8291967E8A8F7B8487777D7F
6F6F706A6868656160615A595D5451594D4A55474352413C4F3B354D362E4C30284B2C22
4C2A204E2E2455382D5E453A644B41654B43634B436249426048415E47415C46405B4641
5A46425948445A4A475A4E4C5A4F4F574F4E554D4E524B4D4E494B4A494B4A4C504C5256
50595E5561675B696F60717864777E667B84677F8869838D6B87926E8C9872929E7698A5
7AA0AC80A7B585ABB98CB6C494BFCE96BECC95BAC693B4BF91ADB78DA7AF8AA0A787999F
8392977F8B8F7B8487777D7F
6E6F6F69676764605F5F59575B524F564B475244404F3D384C373149312A472C2345261C
46271E4B2E25573B3163493E674E44664D44654C43624A425F48415D46405B45405A4541
5946425A49455A4C495B4F4D5B504F585050554E4F514C4D4D494B4A494B494C504B5256
50595E5561675A696F5F6F7762757D647A82667E8768828C6A86916E8B9771919E7698A5
7B9FAC81A6B486AAB88DB6C493BCCB99C2D097BCC995B6C192AFB98FA8B18BA1A9889AA1
849398808C907C8588787D80
6E6E6F686666625F5E5D5755584F4D5348454F413D4B3A3547332D442D2642271F3F2017
3F241C4B31285A3F356A4E436C5146694F46664D44634B435F48415C4640594540594541
5846425A49465B4D4A5D514E5C52515A5252564F50514C4E4C494B49484B484B4F4A5256
4E595E54616758686F5C6E755F737C627881647D8667818C6986916D8B9771919D7697A4
7B9EAC80A5B285A9B78EB6C495BDCB9BC6D499BFCC97B8C394B1BB91AAB38DA3AA899CA2
859499818D917C8589787E80
6D6E6E676565615D5C5B5553554D4B4F45424A3D39463631422F294029223D231B3A1E15
3B231B4A322A5D42387254477054496C5147684F46644B435E47415A454057433F564440
5745425A49465D4F4B5F52505E55535C5555575252524E4F4C494C47484B464B4F495155
4C585E51606655666E596C745D727A607781637C8567818C6A86916D8B9771909D7596A3
7A9DAB7FA3B184A8B68FB4C299C0CE9EC9D79CC2CF99BBC696B3BD93ACB58FA5AC8B9DA3
86959B828E927D8689787E80
6D6D6E6664645F5B5B585351524A484B413F46393541312D3D2A253A241E381F17371D16
36211A49332B61463C78584B74574C70544A6B5148654D455E484159443F55423E534340
5646435C4B4761524E615351615755605A59595555524F504B4A4C46484B444A4E465055
49565D4F5E6652646C566A725A70795E767F627B8568828C6A86916C8B9770909D7596A3
7A9CAA7EA2B083A7B590B4C39DC3D1A2CDDB9FC5D19CBDC899B6BF95AEB691A6AE8C9EA5
88979C838E937E868A797E81
6C6D6E6463645D5A5A55504F4E4745473E3B4034313A2C2835241F341F19341C14351E18
35231D4B362E664A3F7E5D4F795A4E73574C6D534A674F47614A445A4640574541514240
5646435F4E49645551665754655B59635D5C5A57585250524B4A4C45474A42494D444E54
45525A4D5E664E626A506670566D765D757F627B8568828C6B86926D8B976F8F9D7495A3
799BA97CA0AF83A7B693B7C4A1C6D3A6D0DDA3C7D39FC0CA9CB8C198B0B893A8AF8EA0A6
89989D848F947E878A797F81
6B6C6D6363635B5858534E4E4A4443423A383A2F2D3225222C1C18281510341D1635211B
3927214D39316A4D428361537D5E5176594F70554C6A514A644E485D49445A4743554542
5949465F4F4B655652685A57675D5B615C5C5A58595251524A4A4C44474A41484D424D53
43515A495D65485E684A626D566C765D757F617A8469828C6C87926F8C986F909D7295A3
7799A8799FAE82A7B696B9C6A7C9D6AAD2DEA6CAD5A3C2CD9FBBC49BB3BA96AAB191A2A8
8B999E8590947F888B797F81
6B6C6D626262595757504C4C4741403D3634342A28291E1B1E100D20100C311D18382620
3D2C26533D356E51458765568061547A5C5272564E6C544C68524C614E485D4A465A4946
5C4C485F504C645652675B58655C5B605B5B5957585250524A4A4C44474B41484D414D53
43525A465A63465C66455F6A576D765C747E6079846B838D6D88936F8D996E8F9D7093A2
7398A7749CAC83A8B799BAC7ACCCD7AFD5E1ABCDD8A8C5CFA3BDC69EB5BD99ACB393A4A9
8D9B9F87929580888B7A7F81
6A6B6C6161615755554D4A4A433E3E3932312E26242118161207051F110E2C1B17392923
44322B5C443A7455498A67598464577D5F55755A516E574F69534D64514B5F4E495D4C48
5D4E4A60524E635653655A57645D5B5F5A5A595657515052494A4D43484C40484D404D53
42525A465962465C6748616C546B755A727D6079846A828D6B87926B8B986C8E9C6D92A1
6F95A57199AA86AAB89DBCC9B0CCD8B4D9E4B1D1DBADC9D2A8C1C9A2B8BF9CAFB596A6AB
8F9CA188939681898C7A8082
696B6C5F60605554544B4848403C3C352F2F2922211C14120D04021A0F0C281B17382923
49362F61473D78594D8C695B87675B806359795F56725A526C565067544F62524E63524D
61524E635551645754655A58645D5B5E5959575455504E51494B4E43494D40484E3E4B52
405159455962485D674C636D526A7457707B5D7883647F8B668490678896688C9A698F9F
6992A36F98A988ABBAA4BFCBB0CCD7B9DBE6B7D5DEB3CDD6ADC4CCA7BBC2A0B1B799A8AD
919EA28A9497838A8D7B8082
696A6B5E5F5F5453534947473D3A3A322D2D25201F181110090201150D0B261B17382923
4B373063493F7A5B4F8D695B8B6A5E84675C7D635A765F57705B546A5853675752675652
6456516457536357546359566059575B56565551524F4E50494C4F444A4F414A503E4B52
3E4F58425760465C664D636E516A75556F7A5975815E7B8861808E638594658999658C9C
648FA06F99AA8BADBBA7C0CBAFCBD6B9D9E4C1DCE4BAD2DAB3C8CFACBEC4A4B4B99CAAAE
949FA38C9598848B8D7C8082
696A6B5E5E5F5252524746463B39392F2C2B221E1E15100F070100130C0A241A16372823
4B3831644A407A5B4F8C695B8D6D60876A6080665E79635C735F596E5C576B5A56685954
6657536457536256536056535C5453595353534F514E4D4F4A4C4F464B51424C523F4D55
3D4F5840555E435A644A626C4E6873536E7A5674805B79865E7E8C618493628797608A9A
5F8C9E729BAC8CAEBCA3BEC9B2CCD6BDDAE4CCE4EBC2D8DFBACDD3B1C2C7A8B7BC9FACB0
96A1A58E9699858B8E7C8183
686A6B5D5E5E5151524645453A38382D2A2A201D1D130F0F050100120C0A211815362723
4A3731624940785A4E8A685B8D6E61896D628369617C665F76635D71605B6D5D58695A56
6658546357536155515E54515A5251565050524E4F4D4C4F4A4C50474C52444D54414E57
3F515A40555E415963465F6A4C6672516D795573805A78865B7D8C5E82925D85955C8899
5E8C9E749DAD8CAEBCA2BEC9B6CFD8C5DEE6D4E8EFCADDE3C0D1D6B6C5CAACB9BEA2AEB2
99A3A68F979A868C8F7D8183
686A6B5C5D5E5151524544453837372C2A2A1F1C1C120E0E040000110B0A1F1715332622
4836305E473F73584C8566598E6E628C6F65856C637E696278666073625D6E5F5A6A5C58
6659556356536054515C525059504F554E4E514D4E4D4B4E4A4C51474D53454E55425058
41525B41555F425A64455F6A4A65714D6A7752717E567685577B8A587E8F588293598597
608D9F769FAE8EB0BDA3C0CBBAD1D9CCE0E7DAEBF0D3E3E8C7D6DABBC9CDB0BCC0A5B0B3
9BA4A791989B878D8F7D8183
686A6B5C5D5E5050514444443737372B292A1E1C1C100E0E030000100C0B1E1715302421
44342E5A443D6E544A8163578C6D618E7167876E66806B647A676274645F6F605B6A5C59
6659566256535F53505B514F574F4E534D4E4F4C4D4C4B4F4A4D51474E53454F56435159
42535C425660435B65455F6B4864704B69764D6E7C507382527888537C8C547F91568496
6490A27BA2B191B2BFA6C2CCBDD2DAD2E2E8E0EDF1DCE9EDCDDADDC0CBCFB4BEC1A8B1B4
9DA5A892999B888D8F7E8283
686A6B5C5D5E5050514343443736372A292A1D1B1C0F0E0E0200000F0C0B1D17152E2320
40312C54413A6951487C6055886A5F8F7267897067816C657B69637565606F615D6A5D59
6659566255525E53505A504F564E4D524C4D4F4B4D4C4B4F4A4D51474E5445505744525A
42545D425761435B6645606B4663704868764A6D7B4C71804F76864F7A8B517E90578598
6A94A57FA5B396B5C1ACC5CFC3D6DDD8E5EAE6F0F3E3EEF1D2DDE0C4CDD0B6C0C2AAB2B5
9FA6A8949A9C898E907E8284
676A6B5B5D5E4F505243444536363729292A1C1B1C0F0E0F0100010E0B0B1D17152B221F
3C2F2A4E3E37654E45775C5284675C8C6F65897168826D667B69637565616F615E6A5D5A
6559566155535C5250584F4E554D4D514C4C4E4B4D4B4B4F4A4D52484F5545515844525B
43555F425862435C67445F6B456370466775486B7A4A70804B74854C788A517E905C899B
7099A985A8B69DBAC5B3CAD2CADAE1DEE9EDEEF6F9E5EEF0D5DDE0C6CED1B8C0C3ACB3B5
A0A6A8949A9C898E907E8284
676A6B5B5D5F4F515243444536373829292B1C1C1D0E0E0F0000020E0B0B1C161529211E
372C284A3B355F4A4370584F80645A876C62877067816D667A69647465616E615D695D5A
6459565F55535B514F574F4E534C4C504B4C4D4A4D4B4C504A4E5348505646525945545C
435760435963435C6744606C446471456775466B7A486F7F4973844D798B548193638E9F
769EAC8EAEBBA4BEC9BBCFD6D1DFE4E5EEF1F4FBFCE4ECEDD5DDDFC7CED0BAC0C2ADB3B5
A1A6A8959A9C8A8E907E8283
686A6B5C5E5F4F5152434446363739292A2C1C1C1E0E0F100000020E0B0C1A161527201E
342A2746383358463F69534B79605680675E846D64806D657968637364606D605D675C5A
6258565E54525A504F554E4D524C4C4F4B4D4D4B4E4B4C50494F5448515747535A46555D
445861445A65445D6844616D446471456876456B7A466F7F4974854F7B8D5985966B94A3
7FA3B196B4BFACC4CDC2D4DAD9E5E9EDF3F5F6FCFCE5EAECD5DCDDC7CDCFBAC0C1ADB3B4
A1A6A8959A9B8A8E8F7F8283
686A6B5C5E5F50525344454737383A2A2B2D1D1E200F10120001030C0B0B181515241F1E
31292640343052423C614E48705A527861588069617E6B6478676271635F6B5F5C665B58
6157555C5352585050544E4E514B4D4E4B4D4C4B4F4B4D524A505649525948545C47565F
455962455B66445E6A44626E446472446876446C7B466F804B7587547F90628B9B759AA9
8AAAB69FB9C4B5C9D1CCDADFE4EBEEF7FBFCF3F8F8E3E8E9D5DADBC7CCCDBABFC0ADB2B3
A1A5A795999B8A8D8F7F8283
686A6C5C5E60505254444648383A3C2B2D2F1E2022101214020305090A0B161415221D1D
2D26243B312F4A3E39594A4466534D705B5479645C7A68617565606F615D695E5B635A57
5E56555A5352565050534E4E4F4B4D4D4B4E4B4C504B4E534B52574A545B49565E485860
465B64465D6845606C44636F446573446978456D7C4871824F798A5B85956B92A180A1AE
95B1BCA8C0C9BECFD6D6E1E4ECF1F2FCFFFFEFF2F3E1E5E6D3D7D8C6CACBB9BDBEACB1B2
A0A4A695999A8A8D8E7E8283
686B6C5D5F615154554648493A3C3D2D2F31202224121517040608080A0C1313141E1B1B
292423352E2C443A365245415D4E4967564F705D5774635C71625D6C5F5B675C59615857
5C5554575252544F50514D4F4D4B4D4B4B4E4B4E524C50554C53594C565D4B5860495A63
485C66475F6A46626D466571456775466B79486F7F4C7585567F8F658C9B7799A78BA8B4
9FB8C1B3C6CEC9D6DBE1E7EAF2F5F5FDFFFFEDF0F0DFE2E2D1D4D5C4C8C8B7BBBCABAFB0
A0A3A4949899898C8E7E8183
686B6D5D606252555647494B3B3E402F323423252816181B080B0D06090B1011131A191A
262322302B2A3D36344B413E5549455E504B6556516B5C576B5C58685C58635A585D5655
595454555152524F504F4D504B4B4E494B4F4C4F534D52574E565C4D585F4D5A624B5D65
4A5F6849616C496470486774486A78496D7C4E7382537B8A6086957093A182A1AD96AFBA
AABEC6BECED3D5DEE1EAEEEEFAFBFBF9FBFAEAECECDBDEDECED1D2C2C5C5B5B9BAAAADAE
9EA2A3939798898C8D7E8182
696C6D5E6163545658494B4D3E404232353726292C1A1D200E111405080B0C0F11171819
2221212B2828373231453D3B4E4542574C485B504C6155516357546357555E5655585354
545152535051504F514D4E51494C50494D514C50554F555950585E505B614F5D644D5F68
4D616A4D646F4C67734C6A774D6E7B4F72805579885E83916C8E9B7C9BA78EA8B3A2B7C0
B5C6CCCAD5D9DFE4E6F1F2F2FFFFFEF2F3F3E5E6E6D7DADACBCDCEBFC1C2B3B6B7A8ABAC
9DA0A1929597888B8C7E8082
696C6E5F62645558594B4D4F40434535383A2A2D301F222513171A070B0E090D10151718
1E1F20282727322F2F403A384942404F4745544B49584F4D5B52505A5251575251535052
514F51514F524F50524D4F534A4E524B50544E535750575C525A60535F6452606750626A
51656E516872526C77526F7B54737F58798560818E6A8B977997A289A3AD9BB0B9AEBFC6
C2CED2D6DCDFE7EAEAF8F6F6FCFCFAEDEDEDDFE1E0D3D5D5C7C9C9BBBEBEB0B3B4A6A8A9
9B9E9F919495878A8B7D8081
6A6D6E60636557595B4D5052434648393C3E2E313423272A181C1F0D1115080C0F111517
1B1D1F2525262F2D2E3B3737433E3D4843424C4645504A49534C4B534E4E504E4F4E4E50
4E4E504F4F524D50534D51554B51554D53574F555A515A5E545D6356616756646B55666E
566972566C7659717B5A757F5E7A8563808C6D899478939D879FA896ABB3A7B9BFBAC7CC
CFD6D9DFE3E4EDEFEEFBF9F8F3F3F2E6E6E5D9DADACECFCFC2C4C5B8BABAADB0B0A3A6A7
999C9D90929386898A7D7F81
6A6D6F616466585B5D4F525446494B3C3F42323639282C2F1E222514181C0A0F120E1316
191C1E2324262C2C2D3634353C3A3A423F3F4542424A46464D49494C4A4B4B4B4D4B4D50
4B4D514E50534B4F544E53574E53584F555A50585D545D625760665A656A5B686E5B6A71
5C6E765E717A62767F647B8469818B6F889279919A859BA494A7AEA3B3B9B4C1C5C7CFD2
DADDDFE7E8E8F4F4F3F4F3F2E9E8E8DDDEDDD2D4D3C8C9C9BEBFC0B4B6B6AAACADA0A3A4
979A9B8E91928588897C7F80
6B6E6F6365675A5D5F525557494C4E404346373B3D2E323424292C1B1F231015190D1215
171C1E202426282B2C3132333838393E3D3E3F3F4044434447464746474A484A4D494C4F
494D514C50544B50554E54584F555A51595D535C605760655B64695E686E606C71606F75
63737A67777E6B7C846D818973888F7B90978699A092A3AAA0AEB4B0BBBFC1C9CBD3D6D8
E2E3E3EFEFEEF1F1EFE8E8E7DFDFDED5D6D5CBCCCCC2C3C3B8BABAAFB1B2A6A8A99DA0A1
9597988C8F908487887C7E80
6C6E706467685C5F615457594C4F5244474A3C3F4233373A2B2F3222262A191E21101619
161C1F1E232626292C2E3032353738393A3C3B3D3F3F4042424446424649474A4E474C50
494E524B51554D52574F555A51585D545C605860645B636860686D636C71667075677379
6B787E6F7D8272818775868D7C8D9487969C91A0A59EAAAFACB6B9BBC2C4CBCFD0DBDCDC
EAEAE9EEEDECE5E5E4DEDEDDD5D6D5CDCECDC4C5C5BCBDBDB3B5B5ABADADA2A5A59A9D9D
9295968B8D8E8385877B7E7F
6C6F7165686A5E6163575A5C505355484C4E414447393D40313639292E3121272A191F22
171D211C222624292C2C3033323538373A3C393C3F3C3F423F434641464A454A4E474C51
4A4F544B52564E555A51585C545B60585F635C636760676B656C706870746D75796D787D
737D8276818579858A7D8B90869397919CA09CA6AAA9B0B3B7BCBEC5C7C8D3D3D3E1E0DF
EBEBEAE3E3E2DBDCDBD4D4D4CCCDCDC5C6C5BDBEBEB5B7B7ADAFB0A6A8A89EA1A197999A
909293898B8C8284857A7D7E
6D707167696B6063655A5D5F5356584C505246494C3F4346383C3F3136392A3033242A2D
1E24271D232623292C2A2F32313639363A3D393D403B3F433F444740464B444A4F484E53
4B51564E545951585C545B60575E635C626660676A646B6E6970736E7578737A7D767E82
7A82857B84877E898C8590938E989B99A1A3A5ABADB2B6B7BEC0C1CBCBCBD8D7D6E2E1E0
E0E1E0D8D9D8D1D2D1CACBCBC3C4C4BCBEBEB6B7B7AFB0B1A8AAAAA1A3A49A9C9D949697
8D8F9087898A8083847A7C7E
6E7072686B6D6265675C6061575A5C5154564B4F5145494B3F4346393E4033383B2E3336
292E32242A2D23292D292F33303639363B3F3B3F433C42453F454941484D454C504A5055
4D545851585C545B5F575D625B6165606669646A6D696E726E737673787B797E817D8285
808586808789848C8E8C9496949B9D9EA3A5ABAEAFB8B9B9C3C3C3CECDCCDAD9D8DADADA
D3D4D3CDCECDC7C8C7C1C2C2BABCBCB4B6B6AEB0B0A8AAAAA2A4A59C9E9F969899909293
8A8D8E8587887F8183797C7D
6E7173696C6E6467695F62645A5D5F55595B5054564B4F51464A4C4145483C4043373C3F
33383B2F34382A30332A303430373B373D413D424640454942484C434A4F484F534D5458
50575B545A5E575E625A60655F646863696C686D706D7274717577777B7C7D8082818485
84878883888A888E90909597979C9EA2A6A6AFB1B1BBBBBAC6C5C5CECDCDD2D2D2CCCDCD
C7C8C8C2C3C3BCBDBDB7B8B8B2B3B3ACAEAEA7A9A9A2A3A49C9E9F97999A9294958D8F90
888A8B8385867D8081787B7C
6F72736B6E6F666A6B6265675E6163595D5F55595B5154574C5053484C4F44484B404548
3C4144393E41353B3E31373B32393D383E433F4549444A4E464D51484E534C535751575C
555B5E585E625A61655D636862676B676C6F6C70727174767477797A7D7D7D8081858686
858788878A8B8D91919497989C9FA0A7A8A8B0B1B1BDBCBBC5C5C5C6C7C7C3C5C4BFC0C0
BBBCBCB6B8B8B2B3B3ADAFAFA9AAABA4A6A6A0A1A29B9D9E9799999294958E9091898B8D
8587888083847C7F80787A7C
7073746C6F71696C6D65686A6165665E61635A5E60575A5C5357595054564C5053494D50
464A4D43484B4045483D43473B41453E444841484B474D514B51554E555952585C575C60
5A60635C62655E656863676B676B6D696D706D717473757777797B7B7D7D7E8080858686
8687888A8C8C8F91929598999EA0A0A7A8A7ADAEAEBBBBBABCBDBDB8B9BAB5B7B7B2B4B4
AFB0B0ABADADA7A9A9A3A5A6A0A2A29C9E9E989A9B9497979193948D8F90898C8D868889
8284867E81827B7D7E777A7B
7173756E71726B6E6F686B6D65686A6265675F63645C60625A5D5F575B5D54585A525658
4F53564D51544B5052494E51484D51474D51484E514A505450575A555B605B5F625D6164
5F646760656863686C676B6E696C6F6A6D706F727472757677797A7A7C7C7F8080838484
8787878B8C8C8F91929698989C9D9DA4A5A5A9ACACB0B1B1ADAEAEAAACACA8AAAAA5A7A7
A3A4A5A0A2A29D9F9F9A9C9C97999A9496979193948E90918B8D8E888A8B858788828486
7F82837C7F80797C7D76797A
7174766F72746D70726B6E6F696C6D666A6B6468696265676063655E62645C60625A5E60
585C5F575B5D555A5C54595B53585B53585B53585B52585C585E615C61655F6366636769
65696C666A6C676B6D686C6F6A6E706D707270737573767777797A7A7C7C7E8080828383
858686898B8B8D8F90959798989A9A9C9E9FA0A2A29FA1A19EA0A09C9E9F9B9C9D999B9B
9799999597979294959092938E90918C8E8F8A8C8D878A8B8587888385868183847E8182
7C7F807A7D7E787A7C76787A
7275767174756F72746E71726C6F716B6E6F696C6E686B6D676A6B65686A646769636668
6265676064665F63655F63655E62655E62655E62655F636661656862676A64686B6A6D6F
6B6E716A6D706B6F706B6F716B6F726F727471747573767777797A787B7B7B7D7E7E8080
818384898A8B898B8C8E90918F91928F91929092939092938F92928F91928D90908C8E8F
8B8D8E898C8D888A8B87898A8587898486878285868183847F82837E80817C7F807B7D7F
797C7D787A7C76797A757879
7375777275767174767173757073746F72736E71736E71726D70716C6F716C6F706B6E70
6A6E6F6A6D6F6A6D6E696C6E696C6E696C6E696C6E696D6F6A6E706B6E716C6F716E7173
6F72746F72746F72746E72746F727472757673767775777876797A777A7B797B7C7A7C7D
7D7F80828485808283808384818384818485828485828485818485818384808384808283
7F82837E81827E80817D80817C7F807C7E7F7B7D7F7A7D7E797C7D797B7C787A7C777A7B
76797A76787A757879747778
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T1P00`40o`000?l0003ooooooi7oool0
0?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool0
0?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`006_ooo`07Q8B3
QHB4QHF4QHF4QHF5QHJ5QXJ500:6QXH01HJ7QXJ7QhJ7QhJ7QhN8Q`02QhR80hN9R@:7RXX02HN:RhN;
RhN<S8R=ShN;RhN:RXN:RHN:RXR9R@02R8Z90XV:RP03RH^:RHZ:RX^:00:9RXT048V8QhV8QXR6QHN5
Q8N5PhJ4PXJ3PHF1P8B0OH=nO89lNH1iMH9mNX=oOH>0OXB1O`>4PH0018B2P8B2PHB2PHB3P@>4Ph80
0hB3PhB4Poooo`0Ioooo00A]O7e]O7i]O7i]OGl2KWeo0finP0A_Oh42Kh2200E`P8=`PH=`PH=`PHA`
PX@00W22Q@06L8>6LH>7LHF8L8>6L8:5L8:41762Q09aPhD3LX>500EbPhAbPX=aPH9aP85aOh000W1n
O`0:KgenKgamKg]kKWUiKGQhK7IeJW=bK7IfK7QiKGUj16ejN`03KGYlKG]lKG]l009]Ng`4KG]m6_oo
o`05CVQcCVUcCVUdCVUdCfYd009?JWD00dm[ME1[MU1[MP03D6ag00=AK7MAKGQAKGP00U5^N@04DVij
DVmjDVmjDVmk0U9`N`03DW1lDW1kDW1k009BKg/00e9_NU9`Ne9`N`03Dg1k0U=aN`9CL7X01E9_NE9^
NE9^N59]Me5]M`02DFaf00IAJgE@JW=?JG9?Ig1>IVm?J742CfUc1dmYM003CfUcCVUcCVUc009>J7<0
0diXL_ooooooo`0Hoooo0SeIK006?UU]?UY]?UY]?UY^?eY^?e]^0SmKK`8oG702@5a`0T1ML@=1GW80
0d5NLd5OLd5OL`02@Umc00=1Gg=2Gg=2Gg@00T9OM003@F1d@V1d@V1d0092H7@01T9PMD9QM49PM49P
M49PLd5OL`A1Gg801T5NLT5NLD5NLD1ML41LKd1LKPM0G6l2?e]_0SmKKP04?UY^?UY]?UY]?UU/0SeI
K1coool001[oool02HF4Q8F5QHF6QHJ6QXJ7QXJ7QhN8R8N9R8R9R@03R8Z:01B9Rh^9S8b9S8f:SHf:
SXj:SXn:Shn:Si2;T96;TI:;TY>;TiF;U9N:TY>:TI6:T92;T92;Shn<Shn<T902SI6@01F=TI6=TI2>
TI2>T8j=Shf=SH^<RhV;RHN:QhF9QH>8Q867PWn6Ogb4O7R2N7B0M6mnLVf0Mg>2NWN2O7V3OW/00X=o
O005Q7mmQ81nQ85oQ85oQ8:000:4PX42Q8>200>4Ph?oooooool06?ooo`04KGanKGeoKWeoKWj00Vmo
P@04L822L863L864LH:40W63Q@0?LX>6LXB7LXF7LhF8LhJ9LhN:M8N:M8R;M8V<M8V=M8Z>M8^@M8bA
M8Z>M8Z=009dRH/00gF8RgF9RgJ9S003MhZ<01AgRhagRX]gRXYgR8UfQXMfQHEdPh=dPH9cP81bOgma
OGa`NWU_MgI]M7=[L6iZKVa[Lg9]MWE]MgM^N7P2KWUi00A^NGY^NW]^NW]^NW/4KG]l0VekOA[oool0
14iYLdiZM4mZMDm[MP9@K7L0155]N55^NE9^NE9_NP9CL7/015=`O5=aOEAbOUAcOP9EM80025IePEIe
PUIfPeIgPeIgQ5MhQ5IhQEIgQ0=FMh<00eMgPUMgPeMhQ005F7V4011HNH=HMh5GMX1GMGmFM7iFLgeE
LWaELG]DL7UDKWMBK7EAJG9@IVi?IFe@J75AJW<6DF]e0U1[M@06D6YeCfYdCfUdCfUdCVUcCVQc6_oo
o`0:?EU/?UY]?U]^?e]_?ea_@5a`@5ea@Eeb@Eib@Emc0T9OM00:@V1e@f5e@f5fA69gA6=hAFAiAFAj
AFEjAVEkAVIk0TIVO096IW/00dIWO4IWODIWO002AVMl00=6J7e7J7i7J7h00TMYOP97JGd014MWNdIW
NTIVNTEVN@=5IGT014ETN4ASMTARMD=QL`93Gg0014=PLd=PM4=PM4=PM0=2Gg<02D5OLT5NLT5MLD1M
L41LKcmKKciJKSiJKCeIK00Loooo000Joooo00Z5QHB5QXF6QhJ7QhN7R8R8RHV8RXZ9Rh^9S8b:SHd2
RXf>012;SXn;Si2<T96<TI:=TY>=TiB=U9J>UIN>UYR>UiV>V9^>VIf>Vin=V9^=UiR=UIH2SYFE01V?
UIF@UYJAUYFAUYF@UYFAUYFAUIBATi:@TY2?Shf?SX^>RhV=RHJ;QX>:Ph28P7f6O7R4N7B1M6imKVMm
KfUoM6n1Mg>2NGJ3NgP00X=lN@08PgikQ7ilQ7mmQ81nQ81oQ85oQ8:0Q8:10XB3PQ[oool02VelOVim
OfmnP6moPG20PW21Pg62QG:3QW:4Qg>5R09dQXT04GB7RWF8RgF9S7J:SWJ;SgN<T7N=TGR>TWR?U7R@
UGRAUWRCV7VDVWRBUgR@U7R@TgR?TP02NHnB00=jT99kT95kT9400WZ@T@0CNi2@NXj>NHb<NHZ:N8R8
N8J6MhF4MX:2MH1oM7elLWUhL7IdKG9_JVaXJVeZK75_KGAcKWIeKWMg009^N7P00fiiNFiiNVijNP02
KWYk0VikO09]Ng`00fekOOooooooo`0Hoooo00Y>JG=?JWA@JgI@K7MAKGQBKWUBKgYCL7aDLWeDLgh2
EGB001=FMH5FMX9GMh=HN8AHNHEINXMJNhQJO8YKOH]KOXaKOheKP8eKP8iKP8eKOhaKOh]KOX]KOXYK
OhX015aoRP0CG82:G7n9Fgf7FWb5FWZ4FGV3FGV2FGR2FGN1FGEoF7=mEW5jEFigDf]cDFM^DFM_DVYc
DfaeDfef00ACKGL02E9]Me9/Me5/MU5[MU1[ME1ZMDmZM4mYM4iYL`0Joooo00XnFF`nFVdoFfm0G710
GG51GW92Gg=2H7E3HGI4HWL2A6=h00U5I7U6IG]6IWa7Ige8J7i9JGm9JX5:Jh9:K8<00T]]Q003Bfj5
Bfj4Bfj5009;KXD2Bfj400=:KXA;KXA;KX<00T]^P`9:Kh<014U^PTU/P4Q[OdQ[O`99K8002DY/P4Y[
OdUZOTQYO4QWNdMVN4ESMDERMDITN002AVEi00e5I7Q5HgQ5HgQ4HgM4HWI3HGE2H7A2Gg=1GW90GG0o
G6lnFVhnFFd07?ooo`006_ooo`0:QHF4QXJ6QhR7QhR8R8V9RH^;RHb<RXf>Rhj?S92@0Xb@T@0@SI:C
SY>ESYFFSiJGSiNIT9RJT9VLTI^MTIbOTIfPTIjRTJ2TTJ6VT9jQT9bNT9^L0Y6JV`0ITYZJTiZITiZI
TiZITYZITiVHU9RGTiJETYFBTY>@TI6>THf:ShZ7SHJ3Rh=oRGmjQWYeQ7I`P71ZOFYSOViWP75/PGA_
PWMbPWUe00:3NWL02X=lN8AmNXAnNhAoO8AoOHB0OXB1OhB2P8B2PHB3PQ[oool02VemOVinP6moPG20
PW62Q7:3QG>4QgB6R7B7RWF8R`9fRHd047N;SWR<T7R>TWV?TgZAUG^BUW^CV7bEVWbFVgfGWGfIWWfJ
X7bKXWbHWWbGVgbFVP9lUIP06GfEUgfDUWfDUGfDUGbDUGbCU7fBTgbATWb@T7^>SW^=S7^:RGZ7QWR4
PgN1OgEmNg=iMg5eLVi`KF][Ifa^JVeaKVicLFmeM6mgM@02KgQg00A_N7Q_NGU_NGU_NWX2KWYk0Vik
O003KG]lKG]moooo01Woool02TiYM4m[ME1/Me5]N59_NU=`NeAaOEEcOUIdP5MePP9HMh<02eUiQEUj
QeYlRE]mRUaoS5f0SUj2T5j3TEn5Tf26U627UP02H8RG00=OQiEOQYAOQY<00Un5TP0GGhFAGhB?GX>=
GX>=GH:=GX:<GX6;GH6;GH6:G829G7n8G7j7G7b6G7^4FgV2FWJ0FGAmEg5jEVifE6]cE6adEFefEFih
00AEKgT02UA_NEA^NE=^N5=]N59]Me5/MU5[MU1ZMDmZM4iYLa[oool02SiIKCmJKT1LKd5MLD9NLd9P
M4=QMTARMdESNDIUNP97IW`02TQXOTUYP4Y[PD]/Pda]QDa_QTe`R4ibRTmcRe1dS@9@MHh4D7F=00A?
MHe?MHa?M8]>LhT2C7:7011<LHE<L8E;LHE;LHI;LXI;LHE;LXE;LXI<LHI<LHE=L8E<KhA<KX9;KH5;
K7m:Jgh2BVYn00=9JWi9JGi8J7d00TQWO00:AfIkAVEjAFAiA6=g@f5f@V1d@Eib@5ea?e]_?UY]7?oo
o`006_ooo`0:QHF5QXN6QhR8R8V9RH^;RXb=Rhj?S92@SI6BSY:D0XjDU@0DSiJGT9NITIVKTYZMTYbN
TifPU9nRU:2TU::VUJ>XU:FYU:J[TjN/Tj>WTj6TTj2RU9nPU9jOUIjNUIfM0YJMW@0EUYjMUYfLUibK
UYZHUINEUIFCU9:?Thn<TH^8ShJ2SH=nRWiiQgUcQ7=]P6eVOFQPOfaUP71YPG=]PWE`PgMb00:3NG@0
2X=jMXAkN8AlNHAnNhAoO8B0OHB0OhB1P8B2PHB3PQ[oool02VimOfmnPG20PW61Q7:3QW>5R7B7RGF8
RgJ:SGN;S`9hSI4057V?TgZAUG^BUgbDVGfFVgjHWGnIWh2KXH2MXh6NYH6PYX6QZ82QZH2OYH2MXX2L
X82KWX2JWH6JW86IV`:1VIX05H6HVX6HVH6FUh2EUGnCTgnATGj?SWj<S7b9R7^5Q7V2P7MnO7EjMg=e
LFm_Jfe[IVi^JVmaKW1cL71eLg1fM@02L7Mf00=`N7M`NGQ`NGT00VmjNP05KgYkKW]kKW]lKG]lKG]m
01[oool02TmZM51[MU5]N59^NE=`O5EbOUIdP5MfPUQgQ5UiQP9JNhP02e]mRUaoS5j1SUn2T624Tf66
UF:8Uf>:VFB<W6B>WVF?W`02II2P00MTSYiTSIeTSI]TS9YTRiQSRiMSRYD00V>9U00EHXRCHXNBHXJA
HHF?H8B?H8B>H8:=Gh6;Gh6:Ggj8GWb6GGZ4G7R1FgEnF75iEfifEg1hF75jF79kF79lEg9l009GLG`0
2UIaNeI`NeE`NUA_NE=^NE9]N55/Me1[MTmZM4iYLa[oool02SiJKCmKKd1LL49NLT=PM4ARMTESN4IU
NTMVO4QXOP9:JX0054]/PTa]QDe_QdiaRDmcRe1eSE5fT5=hTUAjU5ElUUEmUeImV5EmUeElUeElUUAl
UEAlU5AkTe=jTE9iT09BN8h00e5gS55fRe1eRP02CgF:00Y?MX]?MH]>MX]?Mha?MX]@MX]@MH]@MHY?
LhQ>LHH2CW2500A=L8E=KhE<KXA<KH<2Bfb100Y:JX18JGi7Iga6IGY5I7Q4HWI2H7A1GW90G70nFVdL
oooo000Joooo00Z5QXF7QhN8RHV9Rh^:S8f;SXn<T96=TY>>U9F?UIL2T9NI01:AVI^BVifCWInDWj:E
XJBFXjJGY:RHYZZHZ:fHZZnHZk2G[;6F[;:FZ:fFYZVFYJNGXjFGXj<2V::R0iVRX@0DVJ6PVInNVIfL
VI^IV9RFUiFBUY:>U8b9TXN4Sh=nS7iiR7QbQG5ZP6YROVMOP6]TPFmWPW5[PWA^PgE`0X=gLP0:PgUd
Q7YfQ7]hQ7aiQ7ikQ7mlQ81nQ85oQ8:0Q8>26_ooo`0:KWeoKgn1LH63LX>5LhF8M8N:MXV<Mh^>N8f@
NXnC0W^AU@0CO9>GOIFJOYNLP9VNPI^QPYfSPj2VQ::XQJB[QJJ]QZN_QJR`Q:R`PjF[Pj>XPj6VQ:2T
Q9nRQ9nQ00>5Wj005HFNWhFMWXBKW8BJVXBHV8>EUH>CTX:@Sh2;Rgj8Qgb4PWZ0OGQkMgEeLG5^JFm/
IW1_Jg5bKW5dL75eLW5fM002LGMf00MaN7MaNGQ`NGQ`NGU`NWY_NW]_Ng/00VikO003KG]loooooooo
01Soool02TmZME1/Me9^NE=`NeEbOUIdP5MfPUUhQEYjQe]mRP9MOh`055j1Sen3TF66U6:8UV>:VFF<
W6J?WfNAXFRDY6ZFYfZHZFZIZVZHZFVFYVRDXfRCXVRBXFRBWfRAWVRAW@9XT9`04fN?VfN>VFJ<UfJ;
UVJ;UFF:U6F8TfF7TVB5T6>4Sf:2S65oRF1lQUiiPU]dO5YbNU]dOE]eOU]eO`02FWEo0UUdO`0:F7=n
Eg=mEW9lEG1kE6mjDfiiDVehDFafD6YeCfUd6_ooo`0:?UY]@5a`@Eib@V1dA69fAFAiAfEkB6MmBFV0
Bf^20Ta]Q@0DCFn7Cg::D7B<DGJ?DgRBE7ZDEWfGEgnJFH6MFXBPFhJRG8NSFhJRFXBPFX>NFH>MFH:L
F8:JF86IEh6H0UN0U`03EWnFEGfCEGbB009DO984E7bC0UAmU00:EGbBEG^BE7Z@DgN<DWJ;DWJ=DGJ<
DGF<D7B:Cg:90Ti`Q`0:C6j4Bff2BVZ0B6QmAfIkAFAi@f9f@Umc@5ea?eY^7?ooo`006_ooo`0:QXJ5
QhR8R8Z:RXb<Rhj>S92ASY:CSiBFT9JHTIRJ0Y>KW@0DU9fOUInRUZ6TUj>WV:FYVJR/VZZ^VjbaW:jd
WK6fW;:hVk:iV:nfV:baV:Z]VJV[VJRYVZNWVjNWVjJV0YbVY@0EWJJUWJFTWJBRWJ:PW9nLW9^IViRD
VIB@Uhj;U8V5TH=oSWiiRGMaQG1XPFUOP6QOPF]SPViVPW1YPg9/PgA^00:3MW402XAhLhAiMHAjMXAk
N8AmNXAnO8AoOHB0OXB1P8B3PA[oool02VinOg20PW62Q7>4QgB7RGJ9S7N;SgV=TGZ@U7bBUP9mUIT0
4GnGW82IWX6LXH>NY8BQYhJSZHNV[8RX[hV[/X^^]H^`^8Za^XR^]XNZ/8NX[HNVZhNUZ@02R:BW00>9
Y:J9Y:F9Y:D00XVSY00CRJ:RRJ2PR9fMR9ZJQiNGQYBCQ8n?PX^:P8N5OH:0NWahMgIaLfmYLViYLg5/
Lg=_LgAaLgIcLgMd009cMgD0179hMW9iMg5iN75iN@9`NWX016mkNfikNfikO6ekO1[oool02TmZME5]
N59_NUAaOEIdP5MfPUUiQE]kR5anRej0SP9OPi005665Tf:8UVB:VFJ=W6N@X6VCXfZEYVbHZFfK[FnO
/G6R]76T]fnQ]6fM[FbKZVbIZFbIYfbHYVbHYFbHY0=/Uj<03fbGXVbFXFbDWf^CWV^AWFZ@VfZ>VFV;
UfR9UFN7TfF5T6>1Rf5mQemiPUmhP@02GWV300=NNHAMNH=LN8<00U]gPP0:FWJ1FGAoF7=nEg9mEG5k
E71jDfiiDVegD6]eCfUd6_ooo`0:?eY^@5e`@Umc@f5fAF=hAfIkB6QnBVZ0Bfb3CFn60TmaR@0DD7><
DWJ?DgRBEG^EEWfHF82KFX>OG8JRGHVVH8bZHY2^Hi:aHI2^GhbXGXZUGXVTGHVSGHRRGHRQG8RQ0Ub7
X004G8NOFhNNFhNMFXJM0UZ5W@0?FXFLFXBLFHBMFHBMFXBMFXBLFH:JF86HF7nFEgjEEWjEEWfDEG^C
DgVADWN?009AMH`02TmbRDe`QTa]PdY[PDQXOTIVNdATN4=QMD5NLCmKKQcoool001[oool02XJ6QXN9
R8V;RhZ=SXb@T8fBThnDUI2GV9:IVi>KWP:EWZ0059JPXiNSYYVUZIZX[9^Z[if]/Yj_]Inb^:2e^j:h
_ZBk`Y^e_IR`]YV_/iZ^/I^][ib/[If[[9j[Zin[Z`:OZjX05J2[ZZ2ZZJ6XYj6VY:6SX:2OW9jJUifF
TYZ@SIN:QY>4OhmnN8]gL8M`J89XGh9YH89[Hh=]IX=_J8=aJhAcK@02Q7E_00Z4MW64N7>4NGF4NgN4
O7V4OGZ4OWb4Ogf4PGn4PX4Joooo00Y^OX1`PH=bPhIdQXQeR8]gRhiiSI5kT9AlTiMnUIX2P9RM01B1
Vj23WZ>5X:J6XjV8YZb9ZK2;[;><[kJ>/[Z@][jC^/>=]Kj9[kN9[KB:[;6:Zjn;ZZj;ZZf<ZZb=ZZ`2
SJZ[01F>ZZ^>ZZZ>Z:V>YZJ>Y:>=X9n<W9^;V9N9Ti:6SXb3RHN0Q85mOWYiN7=eLF]eLFaeLfieM71e
MG9eMW=dMg@00WAhM@0:LgQfLgUgLWUhLGUhLGYiL7YjKgYjKgYkKW]lKG]l6_ooo`0:Cf]eDFehDg1l
EG=oEgJ2FGR5Fg^8G7j;GX6>H8BA0V:6U@0BI8VHIHbKIhnOJI:RJiFVK9VZKYb]L9naLZ>fMJNjNJk2
MZ^oLJBgL::cL:2`L9n^L9n]LIn]176O[00@LJ2/LZ2[LYn[LYjYLYbWLIZUL9NSL9FQKi:NKHnKJhbH
JHZEIhJAIH:=Hgn9Hgj90V9nR@03HGf8H7b7Gg^6009NNXD02UahPe]gPUYeP5QdOUMbOEE`NeA^NE9]
Me5[MTmZM1[oool02SmKKT5MLD9PM4ASMdIUNTQXODYZP4a]Q4e_QdmbRP9AMHd03e=gT5EjU5MmUeR0
VeZ3WUb6XUj9YV2<ZV:@[VFD]6ZK_6ZK^fFD/f>A[f:@[003HXnZ00ARSjUQT:YQT:YQT:X3HI6Z019Q
TJUQT:QQSjMPSZMPSJIPS:IOS:EORjENRjANRJ=MR:9LQj5LQZ1KQImJQ9eIPI]GOiQFO9D2E7ZB00YB
Mhi@M8]>LHM<KXA:JX18Iga6I7U3HGE1GW8oFflLoooo000Joooo00Z6QXJ7RHR9Rh^:SHj<T92=TY>?
U9F@UiRBVI^CVih2UIjP01BFX:>GXjJIYJVJZ:bKZZnM[K:N[kFO/[RP]K^R^;jT^l:K]KfH/;JI[k>J
[[6K[JnL[:fMZjbNZj^OZj/2Wj^Z01FPZjZPZZVQZ:NQYZBQXj2PWibNVYNMUY:JT8fGRXJCQ7n?OWR;
Mg27L6R2J5n2JF22Jf>3KFJ3KfR3LF^4Lfd00XAeK`0:Q7IaQ7QcQ7UeQ7]gQ7aiQ7ejQ7ilQ7mmQ85o
Q8:16_ooo`0:KWj0L863LX>6M8J8MHR;Mh^>NHfANi2DO9>GOYFJ0X2HW@0DPI^PPijSQJ2VQZ>YR:J/
RJV`RjbcS:nfS[:jT;JnTk[3SKFnRJngRJfdRZbaRZ^_RjZ^RjZ]S:Z/SJZ/0XfZZ`0ESZZ[SZZZSZRY
SZJVSZBSSJ2OS9bKRiRGRI>BQXj<PhV7P8B1OGijNGQcMG5[MG5/MG=^MGA`MGEbMGIcM7Md009dN7D0
2W=hMW=iMg9iN75iN75jNG1jNVmjNVmjNfikO6ekO1[oool02Tm[ME5]N5=`O5EcOeMfPUUhQE]kR5an
Rej1SV24T@9RQYD04VB9V6F<VfN?WfVBXV^EYVbIZVjL[G2O/G:S]WFW^WV^`WJ[_g6T]g2R/g2P/72O
[W2O[G6O[@AaWj`0476P[7:PZg:OZg:NZG:LYg6JYG2GXg2EXFnBWVf?Vf^<V6V:UFN6TFF2SF=oRF=n
R@9ROXT00f5mR61lQemkQP02GWZ500YLN8=KMh9JMH1HM7iGLWeEL7]DKWUBKGMAJgI?JW@Joooo00Xo
Ffi1GG52H7A4HgM6IGY8J7e:JX1<KHA=KhM?LXX2DGF=00mCMi1ENYAGOIMHP9]JPiiLQZ9NRJIPS:YR
T:iUU;AZVkaZVk]UU;=STJmRT:`00f:?ZP04HXnYHI2ZHI2ZHI2Z0f6AZP0BHI6YHI2XHHnWH8jWH8fV
H8bVGhbUGh^UGX^TGXVSGHRRG8NQG8JPFhFOFXBMFH6KEgnHEWbE0UAjTP0:DWN>D7B;CW67C6j4BVZ0
B6MlAVAi@f5e@Eib?e]_7?ooo`006_ooo`0:QXJ6R8V9RHb<Rhj?SI6BSiBET9JHTYVKU9bNUIjQ0YNQ
Y00DV:BWVZNZVjV]WJbaWZndX;:gXKFkXkRnY;_2Y[o6Yl38U[:jV;6hVk6fW;6dW[2cWk2aX:n`XJn_
XZn_0Z>`[P0EY;2^Y;2]YJf/YJ^XY:NTXj6OXYfIX9RDWI:>VH^7UXJ0TGmhSGQ`RG5YQ6UOQ6YQQ6aS
Q6eUQ6mWQ75YQ79[00:4M6h02XAeL8AgLXAhM8AjMXAkN8AmNHAnNhAoOHB1OhB2PA[oool02VmnP761
Q7>4QgF7RWN:SGV=T7^@TgbCUgjFVX2IW@:2W:4058BOY8JRZ8RUZhVX[h^[/Xf^]Xnb^Y2e_I:i`YFm
aYJobHVc_8Za^H^a]hb`]Xj`]8j_/hn_/Y2_/I6_/0:A/;004Y:`/I>a/9>_[iB][9>YZ9:UY96PWi2L
VhfGUHZAShN<RX>6Ph21OGekMWUeKgQeL7QeLGQfL@9gMg<03GIhM7EhMGEhMGEhMWAiMg=iN79iN75j
NG5jNW1jNVmjNfikO6ekO00Joooo00Y@JgIBKWUDLWeFMH1HN8AJNhMLOX]NPHiPQ99RQiD2IHZI011W
SYeYTJ1[U:A/V:Q^Vja`W[1bX[EdY[UgZ[ii[l=k//IdZ[icYkYcY[MdYKIdYKD2MJFd01UeYK=fYK9f
Y[=fY[=gZ;AgZKEhZKEhZ;=hYK5gXZefWZYfW:QdV:AbUJ5`TYi^Si]/SIQZRYIXQi9WQY9VQI1UPhmT
PXiSP8aROhX00V1mR00:Gg^6GGV4FgN2FWF0F7=nEW5lEFmjDfehDFafCfYd6_ooo`0:?e]_@Eib@f5f
AFAiAfMlBFV0C6b3CVn7D7::DWF>0UAhT@0>EW^EF7jIFX6LG8BPGXRTH8^YHXn]I9:aIYJfJI^lJijo
JYblIiNfIYJd0VJE/P04IYFaIYJbIYJaIYJ`0VNH/@0:IiVcIi^dIifeJ9ffJ9^dIiVbIiNaIiJ_IYB^
II>^0VBB[@09Hi:]Hi:^Hi:^HI2/H8jYGh^VGHRSFhFOFH:K009GOYL02UEkTe=gSe1dRdi`Qda]PdUY
OdMVNdARMd9OLcmLKacoool001[oool02XJ7QXR:RXZ=SHb@T8jBTi2EUi:HVYBKWIFNXINQY0:IY:P0
59^WZib[[ij^/Z2a]Z6d^J>g_JFj`JJma:S1b:_5cIjka9Ba^YZd^Yfd^Ine^:2d]j:d]Z>c]:Bc/jFc
/`:V];<05JNe/jRd/JVa[jR]ZjNYYZJTXJFOVj>JUYnCSi^=R9N6PI>0NHmiLHYbJXI[HXI[HHE/HhE]
I8E^IXE`J8EaJP02Q7=/00Z4M6j4MW24Mg:4NGB4NWN4O7V4OG^4Ogf4PGn4PX4Joooo00Y_Oh5aPXAc
QHQfR8]hRhmjSi9lTYInUIZ0VIf3W:42QInU01B7XjR9YZb;Z[2=[KB?/;RA];bC^<2D^lBF_lRI`lj>
^/F5/;^;/kb>];^@]KZA]KVB]KRC];ND];JE]KH2U[Jf01FG][JH][FH];>H/K2G[JbFZJNEY:>CX9j@
VYR=U9::Shb6RHF3PgmoOWUlNG=lN7=kN7=jN7=iN7AhN7AhN7D00WMiM@0:MWUfMGUgM7UgLgUhLWYi
LGYiL7YjKgYkKW]kKG]l6_ooo`0:D6]fDVmjEG9nEgJ2FGV6G7f9GX2=H8>AHhNEIHZI0VN>W@0DJI:Q
K9FUKYVZL9f^LZ2bM:BgMZRkN:c0N[35OKC:MJc3KjFjM:VlMZZlMj^lN:^lNJ^kNZ^jNZbjNjbj0W^]
^P0EO:nkOK2kOJnkOJjiOJbgOJVdO:JbNZ:^NIn[Mi^WM9RTLIBPL9:NKY2LKHjKK8jKJX^HJHVEJ8NC
IXB@I8:>009SP8`02V5nREmkQeeiQ5]gPUUeP5McOEE`Ne=^NE5/MdmZM1[oool02SmKKd9NLdARMTIU
NTUXOT][PTe^QTmbRE9eSEAhT@9FNiD045QoVE^2WEf6XUn9YV6=ZfB@[fJD]6RH^FZL_FbO`fNI_FBE
]VRI^FVJ^FZK^FZL^P9[W;T01V^M^F^N^FbO^FbO^FbQ^ffR_09]Xkd04FfS_6jR^ffP^VbN^FbL]f^K
]VVJ]FRI]FNI]FNJ]fRL^VNK^FFG]6>C/66?Zen;YUf7XP02Fh>M00YHOiQFNiACMhm@LhY=KhI;Jh58
J7e5I7Q2H7A0G70Loooo000Joooo00Z6QhN9RXZ;SXj=TI6?U9FAUiVCVYbEWZ2GXJBIY:L2VjR[01BM
ZjnO[[>Q/[NS]K^U^KjV_<:X_lJY`l^]b=2S`LZH]l2J]knM]kfP^;fR^;bS^;^U^;VV]kRW]kJX^;H2
ZKRg01F[^[N[^;F/]K:[/:fZZjRYYJ:XX9fUViJQU92MSHRHQh6DP7ZANW><M6b:KfF7Jf66K6:6K6>6
KVF5KfN5L6T00XEbJ`0:Q7=]Q7E_Q7IaQ7QcQ7YeQ7]hQ7ejQ7ilQ81nQ8:16_ooo`0:Kgn1LX>5M8J9
MXV=NHf@Ni6DOYBHP9RLPYbPQInT0XNSZ@0DRJN]S:ZaSZjeT;:iT[JnU;W2U[g6V<7;W<OBTl3;RKG0
RkK0S[NoTKRoTkVoUKVnU[VmUkVkV;VjVKZj0YZk^`0EVkflVk^jW;VgW;JdVk6_VZbZVJNVUj:PU9fJ
TIJDSI2=RH^7QXJ2Ph9mPGiiOgYeOWYeOGUdO7UdNWUeNGUe009hNGD02WMiMWIiMWEiMgAiN7=jN79j
NG1jNVmjNfikNfikO1[oool02U1/MU=_NeEcOeQgPe]jQeenRf22T6:6U6F:V6N>W@9ZTZ4056bFYVnJ
ZW6N[g>R]7JV^7RZ_GZ^`Wbbah2icgVbb76X_WB[_gN]`7V^`G^``Wba`Wfa`Wja`Gna`7nb`0:0]<00
5H2f`H6g`X6f`H6e_h6c_H6_^X6/]gnX]7fT/7^P[7RLZGJIYWBGY7:FXg:FY72DXVnAWff>Vf^;V6V9
UFN6TP02IH>?00YSP8aQOXUONhIMNHAKMX5HM7mFLGaDKgYBK7M@JWDJoooo00XoG6m2Gg=5HgQ7IWa:
JGm<KHA?LHQAM8aDN95FNiD2FGnI01AKPiiNQZ9PRZMSSZaUT[1WU[EZV[Y/W/1_Y<MZW/5TU[MXVK]Z
W;e/W[i^X<1_XL5_X/5`X/1`Xl1`Y<02L:G000iaYl5aZ/=bZlAbZlAbZl=bZ/=bYl5bY/1aXki`XKe_
X;a]Wka/Wke/XL02KJC500EZWkmXVkUVU[ASTJiQSJP00Uj8X`0:FhBMF7nHEG^CDWJ>Cg:9C6j4BFUo
AVEj@f5e@5a`7?ooo`006_ooo`0:QhN7RH^;Rhn?SY:BT9FGTYVKUIbOUj2SVJBWVjN[0Yf[[`0DX:nc
X[:gY;JkY[ZoZ;g4Z/78ZlG<[LS@Z<K?W;c5WKc4Wk_3XK_1Xkc1YKc0YkboZ;^lZK^kZ[^jZkbj0Zbk
^@0E[[bi[[Re[kBb[Zn/[Z^X[:JSZj6NYi^GXiB@Whj9VHN1UX5jTW]cSWI]S71WRFaRR6]QQfaRQfeS
QViUQVmW00:5LFT02XEbJhAdKHAeL8AgLXAiM8AkMhAlNHAnNhB0OXB2P1[oool02VmoPG:3QWF7RWN;
SWZ?TWfCUWnFVh:JWhFNY8NRZ0::YZ`058bZ/Hn^]I6c^YBg_iJk`iRob9[3cIc7dIO4chfkaXnkaY2k
aI:l`iFma9Nna9Vn`iZn`I^m`9bm_ifo_`:M_[h05Ijn_Inj^Z2h]inc/Yn`[ij]ZifZYi^TXYNNW9>H
UHnBShb=RHR8Q8F4Oh>0NX9mN81lMWmkMGijMGajMG]jM@02NWUe00YhNGIgNGIfNGMdNGMcNGQbNWUa
NWU`NWY_NW]^Ng`Joooo00Y@K7MCL7]FM81IN8ALO8UOPHiQQI9TRIMWSIaZTJ02K9FU01A_VZYbWZmd
X[AgYkUjZkil/<Ao]<V0^Lik]<]e[/Ag[lEi/<Ek/LEm/lIo]LR1]lR2]lR3]lN3]lJ4^<H2Q;S500B4
]l>5]<65/l25/Kd2Q[2l00n5/;Z4[;N2YkAoXk1lX:ajWJUgVZMfVJIeV:IdVJQcV:MaTj5_T9e]SIUZ
RIH00VR6TP0:IX>?Hh2<HGf8GWZ5G7N2FGEoEg9mEFmjDVegD6Ye6_ooo`0:@5a`@f1dAF=hB6MmBf^1
CVn6DG>;DgN?EWZDFGjH0U^2W@0AGXJRHHZWHhj/IY:aJINfJi^lKYo1L:?6Jio2J9^mJYfoK9k0KZ31
L:;3LZG6LjO8M:S8009eZLL067FZaWFZaGFZaGFX`gFW`WJW`WJV`WJX`WN[aGN/aWR[aGNXa7FV`WBU
`W:T`G6S`G2T`g2Wag6ZcG2YbffR`fZM_6RH]FFC[`9RSJT02Un8XU^3W5QnUeEiTE5dRdi_QDYZP4MV
NdAQMT1ML1coool001[oool02XN8QhV<S8b?T8nCU96GV9BKWIJOXIRRYI^VZYfZ[P:P[[805::b]jBf
^jNj`:Vna:_2bJg6cJo:d[7>ej?3cZ30bZ2naj:naZBoa:O0aJW1aJ_0`Z^n_jbn_Jfn_Jfn_0:^^kX0
5K2i]k6f]K2`[k2]Zk6/Z[2WY:jQWZVKUjFDT:2>RI^7PIN1NY=lM95gKXibJ8]^I8QZGhQ[H8Q/HXM]
HhI^I@02QFmW00Z5LFZ4LVb4M6j4MW64N7>4NWJ4O7R4OW^4P7j4PX0Joooo00Y`P89cQ8IeR8]hS8mk
T9AnUIV1VIf4WJ:7XJN9YZ/2S:Z`01B?[[FB/kZD]knG^lBJ`<VLa<jNbM>Rc]VGaM6B`<bC_lVD_lRF
_lNI`LRL`lVN`lNN`/BO`L:P`L:P`L42XKjo012R^k^R]kRR/[>Q[jnS/:nR[JbQZJRNY:>JWYbFVINA
Ti2>SXZ;RHF8QH26PWb4OgT2PWaf00>0NgIoNgEmNWD00W]jM@0:NGUfN7UfMWUfMGUgM7UhLWYhLGYi
L7YjKgYkKW]l6_ooo`0:DFagE75lEgF1FWZ6GGj;H8>@HhNEIXbJJI2OK9BT0VnIZ@0DLYj^MJ:dN:Ni
NjboO[74P;G:Pk[@Q/3FPK_CO;G<O;C:OKC9OkG9PKO;Q;[=Q[c=Qkc<R;c;RKc;R;_90XRiaP05R;C2
R;2mR:^iR:VgRJbi00::[k/03XR]^HJZ]X>W/h2S/7fO[G^MZWVKZGRKZGNKZGJJZGFHYg>DXW2AWVj=
V@9[RID02VR6TVF2SV9oRV1lQeeiQ5YfPEQcOUE`Ne=]N51[MA[oool02T1LL4=PMDITNDUXOTa]Pdma
R59eSEEiTUQmUe^1W09NQZ40566:YVB>ZfJC/FVG]VbL_6nP`W:Ub7JZcgFYcVnSafnRaG2RaG:TaGBV
b7JYbgV]cGZ^cGZ^c7^^c7^]b`9jZlP05GVU`WVQ_GRN^WRM^GZR_WbX`gb[agb]b7^/b7ZZagRYagNX
aWFWaGBWagBYbWB/cWB]cg:ZbfnTa6bN_6VH]@02IY:^00YRS:MNQj5JPIYGO9ACMXi?LHQ<K898Iga4
HWI1GG4Loooo000Joooo00Z7R8R:S8b=T96?U9FBVIZEW9jHXJ>JYJRMZJbO[K42X[6f01BU][^W^[nZ
_/B/`/V_aljabm>cd=R]c=NN_lZQ`<ZS`LVU`<NW`/NZa<R^aLR_a<F^`L2``Knb`;n]^KP2[[Nf01F_
/k:`/K2a/Jnc[jfd[JZcYZ>bXin/WIVVU92PSXVKQh2GPGVDO7BBN6n@LfZ>L6F;K66:JUn9Jf28K6:6
KF@00XE^IP0:QFmXQ75ZQ7=]Q7E_Q7MbQ7UeQ7]hQ7ejQ7mmQ8:06_ooo`0:L822LhB7MXV<NHjAOI:F
P9NKPi^PQZ2URJBZS:V_0Xn]]00DT[:iUKNnV;c4Vl39W/G>X<[DXloJW/cHTL3=U<7<U/;<V<7:V/?:
WLG<X<O<X/O;X/G7Y<G6Y/G5X[fm0Z6h^@0EXKBeXK6bXK6aY;6aYZn_YJZYYJVXXJJTWJ2NV9ZHTiB@
Shj:SHZ5RhN2RHAnR85kQWmhQGigPgafPGaeOg]e009lNWD02WYiMGUiMGMiMWIiMgAiMg=iN75jNG1j
NVmjNfikO1[oool02U5]N5AaOEQfPU]kR5j0SF:5TVF9UfR>WF^CXVnHZ09bWJd057FQ/gRV^7^/_Wja
a86fbXFkd8S1eh>neWbfcWjgcH2gc86gbh>hbhFkcXRndH_1dXc1d8g1cho1cXbhaP:9/;h03XR[^HNW
/hNX]8Z[^8bY]hfX]Hj[^8f^^hZ]^HNY]X>U/X2R[WjN[7bMZ`9kWJ/01GZN[GVM[7NIYgBEXW6AW@02
KXbH00YZR9AWQ91TPHaQOHQNNXEKMh9IM7iFLG]CKWQ@JgDJoooo00Y0GG14HGE7IG]:JX1>KhEALh]D
Mi1GO9EJP9YMQ9l2H8VU01ASSJYVT[1ZUkI]W;a`X<9cYLQgZlmdZLeaYLUbYLQcY/QdY/MfYlQhZ/]j
[Lim/M5o/m9o/m61/m60ZlT2Nj6n01EiW;QfUk5gVK=iW[YlWKYnW[Z1YL62[LV1/<ao[/]l[LUjZlQh
ZLMgZLUgZlah[]1h/]Eh/MAeZlaaY<=^W[/00VVG]00:II6/HHZUGHBNFGjGEGV@DG>:CFf3BFQmAF=g
@Eea7?ooo`006_ooo`0:QhR8RXf=SI6BT9JGTiZLUYjPVJ>UW:NZWjb_XK2d0ZBd^@0DYkVnZ[k4[L;9
/<O>//_C]<oH]mCMY/OBX<7;X/7;YL?;Yl;8Z/C9[LO;/LS;//K7/lC3[k^k[KJfZK6`0Zjb/@0E/;6`
/[:a];>b]:f[]:^X]:RT]:JR[inJYiFAXHf8W8N0V81iUGadU7U`TgE[T79WSVeRS6YMRVYNR6]PQV]Q
00:5K6<02XA^IXA`J8AbJh=dKX=fLH=hM8AjMhAmNXAoOHB1P1[oool02W20PWB5R7N:SGZ?TWjDUh6H
W8FMXXRRYh^W[Hj//P:A/KL059Ff_IRk`i_0b9k5cZ;:e:C?fJODgi[8eIC2cYK2cIW4cI[3big5c:37
cZC9cZG9c:S8bJBo`J2g^Iba/`:P/k@05J:a/j>b/jFc]:F^[ZB/ZjF[ZJJ[ZJBVY9nPWYZJUiFET96>
RXn;QXf8Phb6P8^3OHV0NHQnMHImMX=lMH1kM@02OWYd00YkNGEiNGEhNGEfNGIeNGMcNGQbNGU`NWY_
NW]^Ng`Joooo00YAKGQELWiIN8=LOHUPPHiSQYAWS9YZTJ1^UZEaVj/2M:2a01AhYKMkZken/<>2]/Z6
^m29`=J<aM^5_]Io^<n1^<j2^Lj4^/f6^lj8_Ln;`=6>`M6A`m:?_<^9[kf6ZKL2R:Vf01F9Z;F:ZKN:
ZKN:YK:9YK6;Y[:=Z[J@[;V>[KZ:ZkN6Yk>3Xk21XJeoWjaoWjenX:enWjemWZ]lWJYhVJIdU:000W2?
V`0:KHZFJHJBIX:>Hgn:Gg^6G7R3FGAoEW5lDfiiD6]e6_ooo`0:@EeaA69fB6MlBf^1Cfn6DWB<EWVB
FGjGG8>MH8NS0V><Z008IY6^JIJdKI^jL:31M:G7Mj[=NZkBNJc@0WFWbP0:MZO9MjS:NJW:NZ[;OJg>
Ok3@PkCDPjo>NinlNI^g0WZJ]@0ENYRcNYZfNYVeNINcN9RbNY^fOZ6mQ:W5Q[3<Pk7=PJo<OZk;O:c:
Njc;NZg>Nk3ANk;DO;?DNk7AMj_;LZC2009]W;T02VVE/6B>Z5n7XE^1VEMkTU9eS4i_QDYYOTESN45N
LQcoool001[oool02XR9R8^=SXjBTi6GV9BKWIRPXY^UZ9jY[J6^/Z>c]`:V^;d05:Vl`Zc1b;36cK?<
dkOAfKSDg;KEgj32cZ72c:C2bjO3bjW3bJc5b[38cKC8bk?5aK?1`:Vd]J^e]Jje]@:`]K@05K:f][Fg
][Ng]KJb[kN`[KF[Yk>WY:jOVZVHTj6>RIb6P9QoNIMlM9IjLIEgKI=cJ95_Hhm[GXaZGhUYGXIYG`02
Q6YQ00Z4K6B3KVN3L6V3LVf3MG23Mg>3NWJ3O7V4Ogb4PH0Joooo00Y`P8=dQXQhRhilT9=oUIV3VYn6
X:B:YJZ=Z[2A[kD2U;Bk01BG^L6K_lNNa<fRb]BVd=ZXe=jWeN2FaM:F`lnHa<jKa<fMa<bPa/fSbLnV
bLjVa/VV`/BN^;ZO^;ZQ^;X2XkNi01FU^;ZW^K^Y^KZX]KFX];BW[jjTZjZQY::OXIjKW9RGUY6CSh^A
RhN@RXB?R86>QGj<PW^;OgN9OgR6OGF1NW@00WiiM00:O7UdNWQdN7QeMWQeMGUfLgUgLWUhLGYiKgYk
KW]l6_ooo`0:DVehEG=nFGR4GGf:HH>@IHVFJHjLK9>RL9VXLij_0WNT]@0DNZVkOZk1P[C8Q[_?R/7G
SLKLS<KMPkgDP[[APk[?QK[>Q[[=RKc>Rkk?S[g?S[c<SKS8RK?3RK;2Rk;20Xba`00?SK71S[;2Sk;1
Sk6oS[2nS:fkRZVfRJJcS:ZeSJfhRZZfQZJbQ::_Pj6^PZ6^00:1XJl0182Q[gnP[gbMZWRGX`9cTId0
2Vn<V6^8TfN4SfB0Rf5lQeehPeYeP5MbO5A^NE5[MQ[oool02T5MLDERMdUWO4a/PU1aR5AfSUQkU5^0
VUn5X6::YP9USj`056VD/VbI^72N_gBTaWR[cWb`e7^`dgZ]d7RYc7RXbgVXbGZXbG^YbGfZbWnZbWnY
bGnWagjWaWfVa7jT``9nXl805GjS`GjT`gnT`WnU`WjU`gbS`GVO_7^Q_H:Ya8NccXFdd8:acX2_cGj^
cGj_cgjbdWjdeWnffGnef7fbdWNYa`02LJ2m00Y/V;AWTJaRRZAMPiaHOIEDMXe?L8I:JWm6I7U1GW8L
oooo000Joooo00Z8RHV;SXj?TiBBV9VFWInIXZBLYjZO[:nR/KFV][X2ZK_001B/`<J_aL^cb]:gdMVn
fN6kf>6/cMVM_l^R`/bVa<bYa<^[a<Z^a/^bb<bba<N`_[n]^;VX/[>]];B`][H2/kNf01Fe^[Vh^[Ri
^[Ni][>i/[2gZjReZZFaXYb/ViFSTH^KQGnHOgRHO7BHNg:HNFjFMFZCL6BAK62=JEb9J5^4IE`00X=X
GP0:PfYQPfaTPVmXPW5[PgA^PgIbPgUePgaiQ7ilQ85o6_ooo`0:LH63MHJ9NHb?OI6EPINKQ9bQR::W
S:N]SjfcTk:i0YJg_`0DV[g5WL;;XLSAY/oI[]SS[M[UX<oKT/7>Ul?>V/G?WLK>X<K=X/O=YLS>YLC8
X[g0WkJiW;:eXKFhY;Rj0ZJi^`0EZ;fnZkfn[;fm[;Zj[;RhZ[6aZ:n^Y:VVX:>PW9fJUiFAU8n;Thb7
Thb6TXZ3THN0Sh=lSH5iRWifQWacPGQb009oN7802WahLWYhLgQhM7MhMGEhMWAiMg9iN75jNFmjNVik
O1[oool02U9^NEIcOeYiQEmoS6>5TVN;VF^AWfnFYG:L[7JQ/P9jYkP057f/_X2baHBhc8Voe979h9C?
iXW4g7nhch>jchJld8RlchZlcX^lcXflcHbhb8V`_hJX^8FW]hZ]_8fa`0:?/l<05I6gaY:haY>haY>h
ai:gaY6b`Hn`_Xb]^HZZ]Xb[]h^[]XRW/hNU/HJT/HFT/8FS/8BR[h>R/82P[WfMZWVHY@02MI>O00Y`
SYY/RIEYQI1UPHaROHQNNHAKMX1GLWeDKgUAJgHJoooo00Y1GG55HgM9J7i>KHABLhYFN95JOYMMPieQ
R:=USJT2J9:_01A[UkE_W;]bXL9fZ<Yn/]J3^N1l/=EfZ<]iZL]kZ/]lZl]mZ/YnZLUnZ<MmY<9kWKYg
UK9iUkEmWkb0X/02PJK400>2ZLN3Z/R3Z/T00X>]c00@PZ_9P:S6OZS5OZS4Q:o;R;GAQK?@Pk;?P[7@
PK;BP[?DP[GFPKOIP;KHO[;CNZc;0WFT`@0:Ki^hJIB_I8bVGhFNFWjFEGR?D768Bf^0AVEi@Uib7?oo
o`006_ooo`0:R8V9S8n?T9BETiVKUinQVjBWWZV/XJjbY;>hZ;Rm0Z^m``0D[/?9/LS?]<gE^]CM`=cU
/m;LX<;>X<3;Y<?<Z<C<ZlC:[LC:/<O;/lO;/l?6/;bn[kVj[kNg/KJf/kJf0[Bg]`0E]kRh^KRh^[Nf
^[>b^Zn]^:^X]JVT/Z:M[I^FYY>=W8EoVGihVGadVWacVWY_V7I[UW9VU6mRTfeOR6EIPf=I00:2IE/0
2X9XGh9ZHX9]IX9`JH9cKH9eLH=hM8=kN8=nO8B1Oa[oool02W61PgF7RWZ=T7jCUX:IWHJOXhZTZHjZ
[i:`]YFe_0:I^l8059c0b:36cZ?;eJSBg:kIi:GAgIG3d9G1cY[4cig6cZ35cJ;6c:C8cJO8cJO4b:Bn
`J>j_:>h^ZFg^JNg^@:X^;X05JZj^jbj_:fi^Zff]jfc/j^`/:V_[JJZYj:TXIfMVYJCT9F?RiF=R9F=
QiF;Q9B9PI:5OI63Ni63NXQlM85gL002OgMa00YlMW5jMg9iMg=gMgAeN7EdN7IbNGQaNGU_NWY^Ng`J
oooo00YBKWUGM81KNXIPPHeTQiAYSI]]Tj9aVJQeWjmiYKD2O:Zl01B0/<:3]LR6^ln:`MJ?amf:`mZ1
^M21^<j5^ln8_<n;_<j=_<f>_Lf?_<b?^LV>]<></;j=[[b>[Kf?[[d2TJnn00bB/L2C/L6D/L6D[knD
[kjC/;jA/Kj?[[^<ZkV:Z;F9Yk>:Yk<2RJJb00N8YK67YK67Y;66YK69Z;F3XZmkV:H00WJDX00:LXnJ
KXZEJXJAIX:=Hgj8GgZ5FgJ1F79mE6miDF]f6_ooo`0:@EibAV=hBVUoCfn5DgF<Eg^CG82IH8FPI8^V
Ii2]0V^E/`0DKYZiLInoLj?4MZS;NJg@NZgAN:S;MjK8NjW:OJ_:Oj_9P:[8PJ[8PJS5PJO4PJC1Oink
P9fjPIjkPYnl0X>P_@0EPj6oQ:;1Q:?1Q:;1Q:?3Q:O6PjW7PJW7P:W7P:[7QJo<R;C@Q[?@QK?AQ;?B
Q;GDQ;OGQKWJR;kQQ[[LOJk>009hY/@02W6N^VbF/FJ>Z667X5b0V5IiT55bRDa/PDMUNT9OLQcoool0
01[oool02XR:RHb?T92EUYBKW9RPXYbVZ:2[[Z>a]:Nf^jZk`@:]`<H05;35c;;:d[G?f;SDgKGDgjS9
e9o0c:C3cJO4c:[4bjg4bZo4b[;6b[C6b[C3a[6l_[:k^k:i^[Bi^KJi^@:h^[T05KZl^[bk^[fi]kff
/kbb[[^]ZKNXXk>PW:fHTjJ?RIj5OiYnN9]mMIamM9alL9]hK9QcIiM`HYI^Gh=PDh5PE@02P69H00Z0
IUb1JF21K6B1KVR2LVb2MG22N7>3NgN3OW^4PGlJoooo00YaPXAfR8YkSY5oU9R4VYn8XJF<YZ^@[K:D
/[VH^;l2Vkk601BO`lbRbM:Tc]NVd]bQcmbFaM>B`<fIa<nMaLnPa/jSa/fTa/bWalbYa/^Xa<RV_/:W
_L2X^kjY^kf[^kd2[;bm01F^_Kj`_Kja^kba^KV`][F_/k6/[ZbYYjFSX9jMV9FGT8fES8VGSHRHSXNG
SHFFRX6DQWjCQ7^CPWR5Mfj1MFh00WieKP0:O7E_NWI`NGIbMgMcMGMdM7QfLWQgLGUhKgYjKW]k6_oo
o`0:DViiEgF0G7b8HH:?IXVFJXnMKiFTLib[N::bO:Ri0Wn^`00DP[?6QKW<QkgAR;oDP[[ANK;:OKC;
QK[?RKc@S;c>S[c=Skc=TK_<T[[:T[W8TKO6T[K5T[C3Tk?2U;C20YFd``0=U[K3V;K4V;G4VKG3V;?1
V;;0UZnmTjZiSjFcRZ2]R9j[RJ6]RjFa00:;Y[401XZU/HVU/HVU/8RT[h:NZWfIYP9gTil02W>?Vfn;
UV^6TFN2SF=nRF1jQEafPEQcOEE_NU5[MQ[oool02T9NLTMTND]ZP51`QeEfSUUlU5j2Vf:8XVJ>ZFZC
/09^VKH04g6N_GBR`WFUagBVb6fO`VRJ_G:Qa7^XbWnZbh6ZbX:[bH>[b8BYaXBWa8BW`hFXaHJWaHJU
`XJT`@03QjG200>8Y/>8YlB9YlD00XVXaP0@RJW7RJS7QjG4Q:?1PJ6nPZC0QZ_8R;7?Qk?@QkCBQkGD
QkKFQkSHQ[SHQkSHPK7@0WZXa@0:M:2lKYRcJ92ZHhVRGH6IF7ZADW>:CFb2B6Ij@Umc7?ooo`006_oo
o`0:RHZ:SI2@TIJGUYbMVZ:TWZRZXZfaYK>gZKVm[;k40Zo3bP0D//S@]<gE]]7J]]GO/];M[/cGZ/OA
ZLG>ZlG<[LC:[lG:/LC9/lK:]LK:]LC6]Ko1];bm]K^k]k^k^Kbk0[^l^`0E_Kfl_kfl`;bi`;Re_kB`
_JnZ^:VS]:6L[YVCZI6:XhV2WX9kWGmfWWmdWWeaWGU/VWAWVG5SVFmOPUiAOUeA009oH5H02WmSFX1W
GX1ZHX5]IX5`JX9dKX9gLh=jMh=mNhB1Oa[oool02W:2Q7N9Rgb?TX6FVHFLX8ZSYhnY[Y>_]INf_9^l
``:N`LT05:77cjC<eJK@fjKCgj?@gJ3<eik8dio7dJ77cjC6cJK6cJS6c:W7c:_7bj_5bJ_2aJ_0`Zbn
`:fn`:jo`0:`_l005K;0`KC0`;Fo_kFl_;Bi^;>e/jn`[J^YYZJRWj6KV9fETIV?RiV>R9Z?QiZ>QIR;
PYJ7OYJ5NiF3N8AeK81cJ`02OW=]00YlM6ijM6miMG1gMW9eMW=dMgEbN7IaNGQ_NWY^NW/Joooo00YC
KgYHMX5MOHURQ91XRYQ]TImaV:MfWjijYKEo[;d2P[;401B6^<Z9_M2:`=J:`]Z7`=R6_M>8_=6;_]:>
_m6@_/nB_LjC_<bD_LbE_<^E^lVF^lZG^lZG^LRH^<JI^<H2V[W700fK^LNL^LNM^/RM^LNM^<FL]/:J
/knG[kbCZ[N@Y[>>Y;2<Xjn=Y:l00XfW/@06S:NaRjF`RjF`RjF_PYfXOIRS0WVDX00:M92KL8^FK8NB
J8>=I7n9H7^5GGN1FG=mEFmjDFaf6_ooo`0:@UibAfEjC6^1DG:8EWR?FgjGH8FNIH^UJI6]KINd0W6L
^P0=MJ;1MjK7NJW;N:[?MZW=MjO9NjW:P:g=Pjk=QJg;Qjc9R:_7R:_600:8ZLD018Z/b8^^bh^/bH^Z
a`><Z/L00hbYahfZahj/bP03SZg;00n=[<Z<ZlV9Z/N8Z<J7ZLN8[<R9/<^:/ln9]M:9]]>8]mF8^=N8
^MV8^=J2/Ll00WbZa`0:MZ:nL9ZeJY:/I8ZSGX>KFG^BDgB:CVf3B6Ik@Umc7?ooo`006_ooo`0:RHZ:
SY6ATYNHUifOVjBVX:Z]Y;2cZ;JjZkc1[l770[;7c@0D]<cC]]3I]mCN]mKQ]]CN/m3I/<_C[LO?[/G<
/<G://G:]<G:]LK:]lO:^<G8]l;3]kfn]kbl^Kfl^knm0[jn_@0E`;nn`/2m`kjk`kZf`KF`_[2[^JVS
]:6J[iVBZY::YH^3XHAkX89hXH5fX7ibWWU]VgEXVW9SVg1PPEe@OE]@009mGU<02WiQEgiUG7mXH81/
IH1_JH5cKH9fLX9iMX=mNXB0Oa[oool02W:2Q7N9S7f@Th:GVhNNXXbUZY6//IJb^9Zi_ijoaP:RaLd0
5:G;djO@fZWDgjWFhZSEh:OBg:K>ejC:djG9d:O8cZW8cZ_8cJc9cJg9cJk7bZk5ajk1a:o1`[31`[;3
``:d`/<05KK3`kS3`kS2`;Vo_KNk^;Bg/k2`[JbZYZNRWZ>LV:2GTYbBS9bARYfARIb?QYZ;PYR7OYJ5
NYN4N8AeK81cJ`02OW9[00YlLfajLfihM6mgMG5fMW9dMgAcN7IaN7Q`NGU^NW/Joooo00YCKgYIMh9N
OXYTQI9YS9Y_U:5dVjUiX[5nZKV2/<02Q[K801B:_<n=`]F?a]^@bMn@b=j@b=fAaMVA`mFB`]>D`M6F
`=2G`<nH`<jI_lfI_/bI_L^J_LbK_/^L_L^M_//2W[k;00fO_L^P_LZQ_LVQ_LVQ^lNN^<BL]L2I/;^F
[;NCZ;BAY[6@YK2@Yk000Y2X/@06SZJ`S:F_RjB^RjB^PijZOiZW0WZEX@0:MI2KLH^FKHNBJH>>IGn9
HG^5GGN1FG=nEFmjDFaf6_ooo`0:@UmcB6IjCFb2Dg>:F7ZAGH2IHhNQJ8jXK9B`LI^h0WFQ_`0=NJK6
O:_<O[3BP;;EPK?FPkCGQKCEQk?AR;;@R[7>Rk3<S:o;SJk:00:=[LP01Hf]bHn`cI2acY2`cI2`c002
TK3<01FA[lbA[l^B[l^B/LfB//fA/Lb@/<^?[LV=[<N;ZlN;[<N;[/V</Lb<]<n<]M6:]M:9]]>8]]B7
]mJ:^]Z6]MD00Wn/bP0:N:?0LY^fK9>]IX^TH8BLFWbCE7F;CVj3BFMk@emc7?ooo`006_ooo`0:RH^:
SY6BU9RIV9nPWJFXXZb_Y[:fZ[Vm[[o4//G:0[G:d@0D]loG^MCM^]SR^MSR^MKO]]7I//[B[lS?/LK<
//G;]<K;]/O;]lO;^LS;^/K9^lC5^/30^[fm_;jm_/2n0/2o_P0E`/2naL:naKnkaK^g`[F``;2[^ZVR
]J6J/9VBZi::Yhb3Y8ImY8EjXh9gXGibWgY]W7EXVW9SVW1QQ61CNeU=009kFe002WaOEGeSFGiWGWmZ
Hh1^J85bK85eLH9iMH=mNXB0OQ[oool02W:3QGR:SGjBUHBIW8VPY8jW[9B_]9Vf^ifl`j;3bP:UbM40
5:W?f:_EgZgIi:gJiJkIhjcDgJW?ejO<e:W:dJ_:d:g:cjk:ck3;ck7:c[;8c;;7b[;5a[?3`kC3a;K4
a0:ga<@05KW5a;_6a;_3`K_0_[Vk^;Nh];>a[JjZYJZSWZFNUj:HTJ2DSJ2CS:2BRIj?QY^;PYR7OYJ4
NYF3N8IgKWmaJ@02OG5Y00YkLFYjLVahLfigM71fMG9dMW=cMgEaN7M`NGU^NW/Joooo00YDL7]JMh=P
Oh]UQi=[SiaaUZAgWZalYKB1[Kf6]<D2R[_<01B>`MBBam^DcN:FcnFGcn>GcN2FbMbEamVGa]JIaMFK
a=BLa=>Ma=:M`]6N`LnN`<jO`LjP`LjP`<fQ`<d2X[o<01FS`<bT`<^T_l^T_/VS_<JR^/BO]/6M/[bI
[[NFZ[>CYk2CYZnDZ;6CZK6BZ;2?YZn=Y:j:XZb8XJb3Wj^0W:P00WZFX@0:MY2KLX^FKXNBJX>=IWn9
HW^5GWN2FW=nEW1jDVaf6_ooo`0:@emcBFIkCVf3E7B;FWbCH8>KIHZSJi6[L9RdMInl0WZU``0DOZc;
P[7BQ;OIQk[MRK_MRk_LRkWJS;SGS[OESkKCTKGBTKC@T[??T[7=T[3<Tk7=U;?@UKGAUKC@UK;>0iFb
c@03UK;<UK;=U[;=00:E//d03iBbc9>abi6_b8n]aXj/aHj^ahnbc8ndcXjdd8bedHZedXNddXBcdXRi
fHVif002PJo<00YjYL5cW;M]U:iWS:EQQIaKOIAEMXa?KXA9Ig]3H7<Loooo000Joooo00Z:Rh^?TY:E
VIZJX::OYjZT[[6Y]KV]_<2a`/Neb<h2^<kE01Bke=^lf>6mg>JmfnBlf>6gcmJcb]6bb<jda/bea/^g
al^hb<bjbLbkbL^lalZma/Nm`/:l_[fn`;k0`Kl2`l6o01G5`l38`l39`Kg7_KS5][71/JZlZJ:gXIZa
VI6/ThZYSHBYRX2XQgbUQ7RSP7>PNfjLMFRHL6:CK5j5HE=lF4`00WQGC00:NUaBO65GOVELOfUQOfeV
P75[PGE`PWQePgaiPh1n6_ooo`0:Lh>5NH^=Oi>FQI^NRj:VTJZ^Uk6fW;VnXL36Y/O>0Z[>e@0D[MCM
/=[S/]kY/mkX/mcU[mCL[<oG[<gD[L_B[lcA/<cA//gA/lgA]<g@]L_>]/[<]/O8]/C5]lG5^LK60[_7
aP0E_<O6_/S6_lO4_l>o_Kjj^KRd]K6]/J^U[:BNZ9jGYYZBYIR@Y9J=XY>:X927WHb2VHQnU8=hSWid
PWE/OW1W009kKVH02WY_J7UaJWQbK7McKgIdLGAfLg=gMG5hMg1iNFijNa[oool02UA`NeYhQ660S6N8
UFfAWWBIYWZQ[gnY^8Fa`8Zhb@:?`=4049C7fYO>hI[Cj9gFjYkFjIg@hi_<gI_:fig8fIk9f9o8ej78
ej;8eZ;7eJ?6dj?5d@:T`m02YLC@0ZK4c`0:YlC?Z<C?ZLC?ZL;<Z;o9Y[c5XkS1X;BmWK6iVZfd0iRZ
/P08UZZbUJVaTZN_SZB]RJ2YPI^UNiJROIVT0W^FX@0:MXnILX^EKXNAJh>=Ign9HWb5GWR2FWAnEW1j
DVaf6_ooo`0:@f1cBFMlCfj4EWJ<G7fEHXFMJ8bVKYB_M9^gNJ?00WnZb00DPk7AR;SIS;kOSl;TT/?U
T/3QTKgLT[cJU;_IUK_HU[[FUk[EV;WEV;SCV;KAV;G@VKKAV[OCV[SDV[OC0YVgdP:J]]404iZgdY^g
dIZfd9VeciRccINccIJbbiB`b9>`b9>abY>cc9:dcY6fd8nfdHbed8NbcWj/bgb]c8Bdd`02Q;7>00Yk
YL1eWKM_UJiYSJISQYeLOYEFMXa@KhA:Iga3H7<Loooo000Joooo00Z:Rh^@Ti>FVi^LXZ>QZJ^W/K>/
^;^a_l>ea/^ic=82_=;I01Bof>31g^O2hN[1g^Jne]jhc=>ebM2ealjfalfgalbibLfkb/jlb/fnb/bo
bL^oalRn`l:n`;o0`Ko3`l02aL?001G8aL7;aL;<`kk:_[S7^;;3/J^oZZ:hXYVbVI2_U8Z]T8J/SH:[
RWjXQWZTPGFQO6nLMVRFL6:@Jef6H59jE4L00WABAP0:NUY?O5mEOFAKOVQPOfaUP71ZPGA_PWQdPWai
Ph1n6_ooo`0:LhB6NXb>PIBGQibPSJBXU:faV[BiX;c2YLC:Z/_B0ZoCfP0D/][R]^7Z^>G^^NC/]mcT
/]?J/=3G/<kD/LkC/lkC]<oC]]3D]m3C^=3B^LkA^/c>^LS9^LK6^/O6_<W80[k9a`0E`<_8`/_9`lW6
`/G1`<2k_;Ze^KB^]:fV[jFN[:2IZYfEZYbCZ9V@YIN=XY>8Whj4VXUnU8=hSWecQ7=YNFQN009eIUd0
2WU]IGU`J7UaJgMcKGIdL7AeLW=fM75hMW1iNFijNa[oool02UA`Ne]iQ6:2SFV:UW2CX7JKZGfT/X>/
^hVea8nmc@:EaMH04i[=gikFjJ;Ll:COlJCJjj;Bhj7>gj7<gJ;<g:?=g:C=g:K>g:O=fjS=fZS<f:S9
eJS7dZS6dJS6dP03Z/SC01F[bM>]bM>]b=:]a/n/`lbZ_lRX_<BU]kjQ/[ZO[kNN[kJM[kJL[[JJ[[FH
[;>DZK6@YZj;XZZ4W:ElU9edRY@00W::T`0:MHfGLh^DKhNAK8B=Ih29Hgb5GgR2FgAnEW1jDVaf6_oo
o`0:@f1dBVQlDFn5EgN>GWnGI8NPJhnYLINbN9nkOZO40XB_c@0CR[OGSl3QU<SYV<c]VL[YVLGSV/7P
VL3NV/3MVl3MW<3MWL3LWL3KW[oJW[kHW[cFWK[DW[[DW[_E00FN_=H04inleYnkeInke9njdijhdIfg
cY^dc9Zdc9VecIRfcYRhd9NidYFidY:hdXngdXZdchB_bgfYaGRS_`02NJ>n00YjXkifWKM`UZmZSZIT
QiiNOiEGMheAKhA:J7a3H7@Loooo000Joooo00Z:Rh^@Ti>FVi^LXZ>QZJ^W/K>/^;^a_l>ea/^ic=82
_=;I01Bof>31g^O2hN[1g^Jne]jhc=>ebM2ealjfalfgalbibLfkb/jlb/fnb/bobL^oalRn`l:n`;o0
`Ko3`l02aL?001G8aL7;aL;<`kk:_[S7^;;3/J^oZZ:hXYVbVI2_U8Z]T8J/SH:[RWjXQWZTPGFQO6nL
MVRFL6:@Jef6H59jE4L00WABAP0:NUY?O5mEOFAKOVQPOfaUP71ZPGA_PWQdPWaiPh1n6_ooo`0:LhB6
NXb>PIBGQibPSJBXU:faV[BiX;c2YLC:Z/_B0ZoCfP0D/][R]^7Z^>G^^NC/]mcT/]?J/=3G/<kD/LkC
/lkC]<oC]]3D]m3C^=3B^LkA^/c>^LS9^LK6^/O6_<W80[k9a`0E`<_8`/_9`lW6`/G1`<2k_;Ze^KB^
]:fV[jFN[:2IZYfEZYbCZ9V@YIN=XY>8Whj4VXUnU8=hSWecQ7=YNFQN009eIUd02WU]IGU`J7UaJgMc
KGIdL7AeLW=fM75hMW1iNFijNa[oool02UA`Ne]iQ6:2SFV:UW2CX7JKZGfT/X>/^hVea8nmc@:EaMH0
4i[=gikFjJ;Ll:COlJCJjj;Bhj7>gj7<gJ;<g:?=g:C=g:K>g:O=fjS=fZS<f:S9eJS7dZS6dJS6dP03
Z/SC01F[bM>]bM>]b=:]a/n/`lbZ_lRX_<BU]kjQ/[ZO[kNN[kJM[kJL[[JJ[[FH[;>DZK6@YZj;XZZ4
W:ElU9edRY@00W::T`0:MHfGLh^DKhNAK8B=Ih29Hgb5GgR2FgAnEW1jDVaf6_ooo`0:@f1dBVQlDFn5
EgN>GWnGI8NPJhnYLINbN9nkOZO40XB_c@0CR[OGSl3QU<SYV<c]VL[YVLGSV/7PVL3NV/3MVl3MW<3M
WL3LWL3KW[oJW[kHW[cFWK[DW[[DW[_E00FN_=H04inleYnkeInke9njdijhdIfgcY^dc9Zdc9VecIRf
cYRhd9NidYFidY:hdXngdXZdchB_bgfYaGRS_`02NJ>n00YjXkifWKM`UZmZSZITQiiNOiEGMheAKhA:
J7a3H7@Loooo000Joooo00Z;S8bAU9BGW9fNY:FT[:jZ/kJ_^kjd`/Jib/jmdMH2`MON01C4gNG6hn_7
hn_4gNBndMVhb]6eb<ngb<fhb<fjbLflb/jmblnoc<o0c<k1b/c1b<S1a<C1`/33`/35a<02alC001G:
a/;=a/;>a;k=_[S9^;;4/JZoZZ6iXIRdVY6bUXb`ThR`T8F^S82ZR7^VPgJROFnMMfVGL66AJef7HE9n
ETL00W]GBP0:NeY?O5mDOF=IOVMOOf]TOfmYP7=^PGMcPW]iPh1n6_ooo`0:M8B6Nhf?PYFHRIjQT:NZ
UjncWKRlXl35ZLS>[m3F0[CHg`0D^=oW_>K^_^O`_N?Z^MWP]=;I/]3F/loE]M3D]]3E^=;F^]?F^m?F
_=?E_M;C_Lo?_Lc;_<[8_/W7_l[80/7:b00E`lc9a/c9a/[6aLK1`l6k_k^e^kB]]JbU/ZNO/:>K[j6H
[YnF[9bBZIV>YIF:XI24W8YoUhAhT7mdR7I[OfaQ009lK6802W]]IGY_J7UaJWQbK7IcKgAeLG=fLg5g
MW1iN6ijNa[oool02UEaO5ajQF>3SV^<V7:EXGVNZh2W]HN`_Xjib9C2dP:Jbm`05:3CiJGKkZWOlJ[N
kjSHjJKDi:GAhJK@gjO@gjSAgjWBh:_Ch:cCh:gCgjgAgJg?fZg=ejc;eJg:e:g9d`:^bM<05Jo:e;3:
e;7:d[78d;35cJk2bJ^m`jNh_ZFe^jBd^Z>c^Z>c^J6b^9na]ib_]IR//YBY[i2TZhZPZ8>IXWfBV`02
NY2I00YhSYMeRiEaR95]Q8eXP8UTO8EPN89KM7iGL7YBK7HJoooo00Y4H7A;J7eBL8IINHmPPIQWRJ9^
TZ]eV[ElXkj3[<P2R[CB01>@_MbFaNFKbn^Nc>^ObnVNb>JNa^>OaN6Pa>2PaN6Ra^:Sa^:Ta^:Ta^6T
aMnT`mfS`]^S`=VS_mL01J:meP>S_]H04:>me::jdJ2hcingcYnid9njdIjkdYfldible9Zle9Nle9Bj
di2hdH^echNac8>]b0:0ZL@02WfU_gRO^7:G/6b@YfJ8WUn0UUQhSE5`QD]XO4APM1coool001[oool0
2X^<S9:EUIVMWZ2VYjJ^/:ff^K>n`KS6b[k>d/?Ef`;7g><05<[SjlcWklcTjlOKh[k?e[O8ckO8c[S8
cK[9c[c;ckk<d<7=d<;>d<?>clC;c<?9bL?5a<?3`LC3`LO4`@;9aL405Lc7`m37`]74_ljo^<^h/LJa
ZL2YXK^RVKRMTkJIS[FFRk>CQk6?PZf:OJV4MjAnL9mgJYQaHY9/GHYRDh9IBP02OUQ;00YlFTilGU=m
HUQmIUenJV=oKVR0LVf1Mg>2NgR3OghJoooo00YdQ8IlSY23UiV;X:>CZJbJ/[JQ^knXa<R^c=:deM/2
^]gT01C0i^k3j_?5jO72h^Vlf=nfd]RfdMJgdMJhd]JjdmNleMRne]W0emS1emO1eMG1d]70c/g0c<[1
c<W2c<T2a<c901G6c/[9c/[9c<O8al75`K_1^kBm]:fi[jNgZj:eYijdYIbcXiR`WiB]W92YUh^UTHJP
Rh2JQGZCPGF<N6b6LFD00X5_I@0:OViUO6mWNW1YN75/MW=^MGA`LgEcLGMeL7QhKWYj6_ooo`0:EG5l
GG^6IHB?K8fIM9NSO:2]PjZgRkC2T[g<VLOF0Z7@h@0DYm[/[N7c/N;d/]o`[][ZZmKUZ]CSZ]CRZmCR
[MGS[]OT/=SU/]WU/mWT/mOR/mGO/];L/M3I/LkH/LgF0[;<e@0E/lgE]<gE]<cC]<W@//K=/<;9[[k5
[;c2Zk_0Z[VoZKVnZ;RmY[JlY;BjXK:gWZneVZ^aU:N^Sj>ZRIjUQIZR00:0Uil02W^AVWN=UG>9TFj4
SFV0RFElQF1hPE]dOUM`NU9/MQ[oool02TAPM4]YOU=aQeYjT663VVV;Y76D[GRM^82W`XR`c0:?^]L0
59O4hio;k:C>kZO?kZO>k:K<jJG:ijG:iJG9iJK:iZO;ijW=j:[=jJ_=ij_=iZ_;i:[9hJW6gjS4gJO2
f`:V`MT05JK0ejK0f:K0f:K0ejJoeZJne:JmdjFmdjJne:FoeJG0eZG0ej?0ej70einoeifneiZmeYNk
eI:idXjgdHbfd@02R;;<00Z1ZL9kXKUeVK5^TJQWRImPPIIIN8iBL8E;J7a4H7@Loooo000Joooo00Z<
SHbCUYJKWinRZ:VY/;:`^K^g`/Bmb/g3d]K8f]l2cN;X01CBj_7Ejo;Ci^c9f^6lcM>galjhalfib<fk
b/nnc=31c]74cm75cm36clo6c<c5bLS4aLC4`l75`l38a<02blK201G?b<?Bb<?CaKoA`;W=^K78/ZW3
Zj:oYI^lX9JjW96iV8ffUHRdT8>_Rgj[QGNVP76PNFZJLfBDKV2<HeF4GDh00WiFB00:OEU<O5aAO61F
OFELOFUQOVeWOg9/P7IbPW]hPgmm6_ooo`0:MHF7OHjAQIRKSJ:UUJ^^WKFhYKk2[<S</m7F^][O0/7S
j@0Db>gdcO7gcnkcb>CY_]SM^M;H^=;F^M;G^mCH_MGI`=OJ`]SJa=WJa]WIaMKFa=?B`m3>`lk;`lg:
a<g90/K=bP0EbLo;blo:c<c7b/S2b<:la;be`KN__[:Y_:nU^jbR^JVN]jFJ]J:F/IfA[IR<ZI>7Xhj1
WHQlV8EiTG]_RGEZ00:2Kf@02Wm^I7e_IWY`J7QaJgIbKGEcL7=eLW5fMG1hN6ijNQ[oool02UIbO5ik
QVJ5T6j?VgJIYGnS/8N]^XngaIO1cio;fP:We^D01ZoQl[SYn[g[nk_Vm;CMk;3Hi`:_enD03;3HiK7H
i[?JikGKj;OMj;WMj;WLi[SIh[OFgkKCg;GAf[G@f0:ec]H05KK>e[O=eKO=e;O;dKK8c[C5bk;3b;;1
aK70a;6oa;2n`Zjl`:bj_ZVg^jJd^:>a]Yj_/iZ//IJY/92TZhZPZ002Q9ZR00YnTi]iSYIdRI5_QHe[
PHUVO8EQN85LM7eGL7YBK7HJoooo00Y4HGE<JGiDLXQKNi5SQ9][SJEcUk1lX;Z4Z/F<]=02UKkK00NO
b^RYe?BafORdfOFae?2]dNb[cnX00Z[>j@0;ZlkZ[<o[[]3[/=;//]?//];[/M3X/<gV[/_T[LSPZlKM
00:Z`m/00jW1fJW1f:W1f003Z/;H00nZ`]N[`mR/a=V]aM^/aM^[a=ZYa=ZX`]VV`MRS`MRP`MRM`=RJ
`=VF_]RB_=L00XbgdP0:QZc5Oj>kN9^bLI:YJHZPHX6GFgV>Dg65C6UlA61d7?ooo`006_ooo`0:S8f=
U9NGWJ2QY:ZZ[;>d];bn^lG8`/kAb=OJc]oS0]CWk00Df_3fg^ode^GZb=SM^LW@]/K<]lK<^LS=_<[>
`<g@a<oAam3Ab=7AbM3@b<g=alW9aLK4aL?1a/>ob<C00/c6`@0Ed<S3e<W3eLJodl2id;Zbbk>ZajfS
a:RM`J>H_inC_9^?^IN:]Y:4/Xeo[XMiZ89bXg]/WGEVUg1QSVEFQEe>009mDd@02WaGBWaKCgaOEGaS
FWeXH7i/IWmaK81eLH5jMh=oOA[oool02WF5Qgj?TXNJW8nTYYR^/J6h^jW2aK7<d;WFf/3Oi0;8j>h0
1Lobn=Kdn=?]lL[SikkFf`02^];F00fkdmNme=S0e]W3fM[6f]_8fm[:fm[9fMS8e]C6d]35clc5cL[6
cLT00/S>bP0Ebm3;c]3;clk7cLW3blBmb;nfa[Zaa;J/`[>X`;2T_jbQ_:VM^JBH]J2C/I^>[9J9Yi23
XX]nWHMkUGiaS7MZ00:4KF002X5]Hgi^IG]_IgU`JGMaK7EcKg=dLW5fM71hMfiiNQ[oool02UIbOEml
QfN6TG2@W7VKYh:U/XZ`_I>kb9c6djC@gP:]fnT01[KUm;o]n/;/nKoWm;WPkKCKj0:bfNH01K?Ii[GK
ikSLj;[Nj;cOj@02_^3Y00FngnNlfnBjen2he=bgdMT00[O@e`0E^=3G^]3F^loE^/gC^/_A^LW>^<O;
^<K:^<G9]lG8]/?7]<75/[k2[k^oZkRkYkFhY;:fX:ndW:bbUZR^Sj>Y00:7VJ002X6DVgb?UWJ:TG65
SFb1RFMmQF5hPEadOEM`NU9/MQ[oool02TEQMDeZOUAcR5elTVF5W6f?YgJI/WnS_HR^b96hd`:J`]h0
1j?<jJoGlkOLmk[Lm[WJlk?Ek[7Bk002[m3[00F`d>^ad^^de>bfeNfhe^h00[WHk`04]mG]]=7Y/LgT
[lSO0Zg5g00E[<CJ[<?I[LCJ[LCJ[/GK/<KK/<OK//SM]<[O]<_O/l_P//_P/<WN[/OMZlKLZLGKY/CK
Y<CLX/?KWl?LVL3H00:B^=402XZ_aX:U_7^L/W>CZF^;X6>2UeajSUAaQDaYODEPM1coool001[oool0
2Xf>SIJHV9jRXZN/[;2e]kRo`L39blSBeLkKgmCTj0;Jk?405=obmn7_l]KRilKDf[?4c;?3bKK5bkS7
bkg9cL;>d<O@d/_Ce<gCdlgBdL[>cLO9b<G5a<C2`<G1_LS2_P;=aL005M;8`]K9`mO6`=G1^]>k//je
Zlb_YLV[X<JVV/:QUL2MT;^GR[RCQKB>Ok28NJ^3LjEmKJ1gIi]bHY1XF8AKC002O55200YkEDMkFDek
GE=kHUUlIUmmJfEnL6]oMG61NWN3OgdJoooo00YfQXQoT9:8VifBYJRK/;>T^kj^a/Vgd=Bof]k7i>P2
c^gb01CEm?WHloKBj^g9h>>jd]Nid=FjdMFkd]Fne=O3f=W7fmc<g]k?gmk@gmg>fmW:e]C8dm36clc5
c<S7c<P2bLg801G=cl[@d<[Ac/S@b/C?a[g<`KS;_K?:^Zo8]Z_5/ZO3[j>oZYjlYYVhXIBdWHn`V8Z[
ThBVSH2RRWbIPW>>MVT00XE[GP0:PFaPOVeSNfiVNFmXMW5[M79^LgAaLGIdKgMgKWUj6_ooo`0:EW9m
Ggf7J8NBLY:MNifXQ:RdS[>oV;o;XL[GZ]GR0[?Ok@0D^^Od_nWd`NWd_nGa^=kZ]M_W]M[W]=WU]M[U
^=cW_=oZ`>?]a>K_a^K_aNC/`^7Y_mkU_M[R^]GM^M;H0[W@eP0E^]3E_<oE_LoE_LkD_LgA_Lc@_/_?
_l_>_/[=_LS;_<O9^LC6]/73/kg0/;^m[;RjZKBgYK:eX[2dWJf`U:FY00:;VYl02XBDVWj?UGR:TG:6
SFf1RFMmQF9hPEedOEQ`NE=/MQ[oool02TEQMDeZOeEcR5imTfJ7WFnAZ7VK/h>V_hbabiJleP:Oa^40
5:O=ijgBjkKHlK_Km;_Jl[OFkkGDkK?Bjk;Aj[?BjkKEk[[Il[kLmL7Nm/7Mm;kKl[cIl;WFk;G@i[7:
h0:_a]/05Jk4fJk3f:o3f[35fk;7g;C9gKO;gkW=hK[?hk[?i;[?hkS>hkG<hK;;gk79gZk8gJc7gJ[7
gJS8gJK8gZ33fP02Uk_B00Z>/<N6YkenW[=eUJY]S:1UPiMMNXiELXE=JGe5HG@Loooo000Joooo00Z>
SXjGVIRPXj>Z[Zjc^;Vl`lC5cLo>emWEhNCKjNd2h?7e01CUm?OXl_CJhnK3dMJ^`<R_`<Nc`/Rga<Vl
b<c2c<k7d=3<d];@dm7?dLo:c<c5a/K4a<;3`;k2_;W7_k/2c<>n01GBal;GbL?Ial3H`[[F_[?B]jc?
/JK=[J79ZIc6Y9K3Wi6mV8^iU8FfSh2bRWZ^Q7BXOVjSN6RMLf>?IUJ1F4T00WY>?P0:NE95NEM;NE]A
NV1GNVEMO6YSOFmZOgA`P7UfPWim6_ooo`0:MXJ8P96CRYbNU:NYW[>eZ;k0//[<_=GHa^3Sc^[]0]Gc
m`0Df_Ojh?Ohf>c]b=gP]lkD]lgB^LoC^m3C_]?E`]KGamWIc=_Jd=gJdMgJc]WGb]CBb=7>a/k:a<W5
a/W50/[<aP0Ec/k9dM3:dlo8dl_3dlRnd<>ickndc[fac;Z]b[JYb;:U`jbO_jRJ^j>E^9n@]9Z;[iB5
ZXn1YH]lVH1aSG=U00:5JE/02X5ZGWi[HG]]I7Q^IgI`JWAaKG9cL75eLfmgMViiNQ[oool02UMbOF1m
R6V8Tg>CWWfNZHNZ]I:f`Yc2cZO?fk7Ji`:iiO805<3[mlS^n<S/mL7TkkSLj;KJiKGIi;GHhkKHhkSI
hk_Ki;oNi/?Qj<OSj/ORj/?Oil7Mi;kJhK_Efk[@eP:jc]@05K_>e;g?e;k?e<3>dl7?d/7>dL7=cl;=
cl?>cl?=cl7;cKk7bK[4a[O1`[Bn_k:j_:jg^JZd]ZJa/ijZ[9FRY@02SIVM00Z6U9V0SiEiRY1cQXa^
PHQXOHARN85MM7eHL7UCK7HJoooo00Y5HGE=JWmFM8UNOI=WQieaTZUkWKF6ZL6A]LjK`=/2YL_V01B/
dNbeeo2mg?>og?>nf_6ie^fge>^ed^Vcd>NccnFdd>Jgd^Vle^_2f^o4fo;2f_2nf>jlenbgdNNcbMh2
/<GI00V_`]N_`]J``mNbaMVeb=fgbmnicN2kcn:nd^D00/3Ei`0:_]?V^]3T]lkR]/gQ]<_P//[N/<WN
[LSLZLKJXl;F0Y^kd00:T[;6RJRmP9ncN9JZKhfQIhBGGW^>EW:5CFUmAF5d7?ooo`006_ooo`0:SXn>
V9ZIXZFU[;2`]k^k`LK7bm;CeMgNg^OYi?3b0^Oen00Dj?CfjNoaeMkR_/cBZ;_3[;g4/<35]L;6^/K9
_lW;aLg=alg=c<o>b/g;`lK6_l2o_;fl^kRf_KJcaKbg0/c1_00EdlO1f<W2flS0flBkfl:feKR/eKFY
e;:Td:fObZFHaInB_YV;^iB6]i20]8]k[hEdZX1_YW]ZX7ASSfEEP5E6009gBc`02WM@@gMEBGMJCgQN
EGUSG7YYHWa^J7icKh1iMX9nO1[oool02WN7R86BU8^MWiJYZj6e]jc1`kO=cl?Jg<kVjMKal`;LmoX0
5=ohnN3dmM?Vj<?Hg;?:ckG:ckO<d;[>d;g@d/7Bd/CEe<GDdlWFe<SEdlC@cl;;bL38a[k3`;o1_LC5
`0;:bL<05Lk=am;@bMG?amK=`mO<`MC5^]G3]mK2]MBo/LniZl^cYLF^X<6YVkjUU[ZPTKJKRk:FQZnB
PZV=O9aoL8eaHP02Q6IH00Z1JEanJV1kJf=hKFIfKfUdL6abLVm`M79_MgI^NGTJoooo00YGLgeQOXQZ
R9=dU9ioWjZ9ZkJE^<BQa]6]e>2hhNd2`>[f01C5kOS7joG3iNnmh>ZffNBeen:een6fen2femnge]jg
eMbfdmZie=^ke]fkeMbkdmVid=Jeb]6ebLnhbm02^/c@01FlcM6nc];0cm;1d=;4d]?5dM;7dM?:dmC;
e=C9dM;6c/k2b/^nalRj`lBg_l2d_;fb^[Z`^;R/];BSZjbHX:800XnHVP0:R9BGPHnDNhZ@M8J<KX68
J7b4HgR0GGAmF71iDfaf6_ooo`0:AF5eCFYoEWB8GgfCJ8NMLY:YOIjeRJ_3UKWBX/OP0Z_@jP0D/MC^
/mC/^=K/_=S^_MS^^]GZ^=;X]]7V]LoT/lcP/<WM[/KJ[/KK//[N]/cP^LcP]l[M/lGI//CH/LCG0[32
e@:``M<01[73eK?6f;O;gK_?hKkAhl?Ei`;7fN/02lGGjL?Fj<3DikcAi;W?h[O>h;K=gkG=gkC;g[37
fZS1d`02Wk_=00ZF//J=ZKf3X;AjUjYaSJ5XQ9MONhiFLXE>JGe5HG@Loooo000Joooo00Z?ShnIVYZT
YZJ_/K6j_Kk5b/[Ae]OMhnCYl?7co?d2k?Oj01CZl_CWk>gEg=nkbLnT]knX^/6]_L:c`<Bh`lJma/O2
bLW4bLW7b/[1aLFk_l2h^[Zf]kJh]K>n][;5^[D2c<6k01GCal7Ib/;Lb<3La;[K`;CF]j[J]jWK]ZKA
[Io:YIO7XI:oVX^kUHJgSh2eRgZaQWB]PG2[OF^SMF>?I5AmDd@00WE:>`0:MDm1ME=7MEQ=MUaDMf9J
NFMQNfeWOG9^OgQePWil6_ooo`0:MhN9PY:DSIjPV:Z/XkNh[lC5_=7CbN3Qenk_iOko0^CmoP0DhoOh
h?7adnCU`MGH/<K<//S<]L[=^Lc>_<k?_lo?`M3?`]3>`m3>_L[9^LG5]l;1]knn^[jk_l2ka<Bn0/W9
`P0Eclk7dm38eLk6eL_1eLRmdl6ef<>fg<BeeKj_d;RYc[FVajnP`jZK_ZFF_:2@^Ib;]IR7]9F4[Xim
WWm_SW1Q00:4IUP02X5XG7eYGWYZHGM/I7E]Ig=_Jg5aKW1dLVmfMFiiNA[oool02UMcOV5nR6^9TgFD
WX2PZX^/]iRjaJG9e;CKiLK_nP;<mOl05<__nLWZll?Tk;cMi[GFhKCFgkGEg[GEgKOEgKODfkKAekG?
eK;<dZg6cJ_4bjc4bjk4b[74bKC6bkO9c@:jbll02Kc=d;k>d;o=cko<cKo:bl79bLS>cLkCdLcCd@02
bM3>00[5cLc1bLRla<Bi`<2g_Kbe^kZe^[Vb][FX[ZjLXj@2TYVK00Z:UIR3T9AlRXmeQH]_PHMYO8=S
N81MM7aHL7UCK7DJoooo00Y5HWE=JWiFLhQOOI9XQYabTJQmW[F:[<BJ_MJ]dnd2^Mkg01BifO6heNbi
eNZme^Znen^ke>RidNFgd>>fc^:dbmj`aMR]`]BX_M2S^<^T]lZX^lj[_<n^_]2``M:``]<2/<7C01F`
`M:_`=6_`=6``M:a`M6ea=Flbm[4dn;7enK7enO8fNW7fN[3enRodnFkd>6jc]njc^2jcn2jc]ngc=f_
aML00ZFnd00:V[G7T:^nQZ6dO9NZLhjQJHBGH7^>Eg:5CVUlAV5d7?ooo`006_ooo`0:Shn?Vi^JYZNW
/K>c_L2ob/g=em[JiNWYmo_kn_oo0^kem`0Djno`i^WYdMSK]/G<Wk>lYKJmZ[Zo/Ko2]/73^/;3_lG5
`/K6`lK5`L?2_Knn^KVh]kFd^[Fb_kJbaKZe0/g1^P0Ee<O0f/S0g<Nog<>if[jcekN[ekJXf;BUbZVK
aj>E`ij@^IJ8]Y63]Hal]XYi]8Me/H=a/H1]XgARSF=CNE=4009cB3X02W9<?g9AAG9EBg=JDWEPF7MU
GgU[IWaaKGigM85nO1[oool02WR7RH>BU8jOX9Z[[:Jh^K;5al3DeLoTiN?hnN[oo`;Vn_X05>Ogm^;`
km7QhkcAeJc2b:o5b;?7bKS;bk_<c;g<bl3=bl7=bl7<bKk9a[_5`[W0_KRm^[^m^Kno^/C3_0;:b<40
5Lo=aM?>a]G=a=G9_m?5^]70]=6o/m>n/<ZgZLVcYLJ`XKnYVkfUU[^QTKbOS[^LRkVJR;ZHQJn>O9eo
KhaaHP02Q6MH00Z0IeYlIeeiJ5mfJV9cK6IbKVU`L6e_Lg5^MWE]N7TJoooo00YGLWeQOHM[R99fTif0
WjV<[;JI^/BXb]BkhN_8kOL2cO3h01CBlo[?kOC5i>bjf^BbdmfcdmbcdmZee=^fe=Zfd]RfcmBec=2c
bLf`al^_`lR]`LF_`LFa`/Fda<NgalX2^/[<01Flc<jnc<foblbobLZmalRlaLFlaLJna/Jna/Foa/Fn
a/Bk`l:j`L2h_[fi_Kbh_K^h_;Zj_;Ze^;FY[jjNYZH00YFMWP0:S9JHQ92COHZ?MXF:Kh26JG^2HgMo
GG=kF6mhDfae6_ooo`0:AF5dCFUmEG:6GW^?IhFJLHnUO9^bRZ[1WKoH[<kW0[WHk`0D`]od`M_`_]O[
_=CX_=CW^m;U^M3R]loP]lkO]L[L//GF[l3@Zkc;ZK[9Z;S7ZKO6ZkW8[[_;[kg=/;o?0[30d00A/;o?
[kk=[kg<[kg=[[g=[[k?[[o@/<;B]lOG^/cK^lgL_<kM^lgM^/cL^/gL^lkN_<kN00:ndN003[[=gKC:
fj[3eJ[3eIngbI>]_XVR]7jHZWB>X6Z4Uf5kSUQbQDmYO4IQM1coool001[oool02Y2?Si^KVjNXYk>d
]<31`Lg?cm_MgN_]kOgoo_Oin@;_l_<05>GXj]gQh/KAeK30ai^`^J6c^ZNf^jfj_K>l_kW0`Kg2`/74
a<?5`l;2`Knn_;bj^;^g]K^d/L2f//Jk]@;>`K/05MG6_m[7_mg8_]g4^M^n/]RhZmNeYm>_XLJVVL>P
TkjKSKJCQKJ@PKR=O;R;NKN8MKJ5L[F2KZ5cH8UQDGIA@`02KdDg00Y^BCe^CT9_DTU`F4mbGUIdI5eg
JVEjL6amMgB1OG/Joooo00YhQhR3TiB?Wj6K[:fW^KZdalO2eMKBiNKSmoOSm_H2hO?b01CNkNcIinO8
f]bgc=2Y_lB/`LF``lFdaLJha/JlbLS0c<[2cL[3c<S2bLJoaL6m`[jl_k^m_KS0_kW5`k`2blS101G@
c<CDcLCFcL?Fb[oEa[[C`KC@_[7;^:_1/:?0[9nnZIbiY9JjXY>mX92nWhjnWH^nVhRmVHF^S7ZKOFf;
Kf400X9TEP0:OVEHNVEKMfIMM6QPLVYTL6aXKfm/KW9`KGEdKGQi6_ooo`0:Eg9lHGb6JhNAMI>LP9jX
S:^dV;S1Y/O@]MOP_MkW0/;QjP0Dan?[an?Z_]cU]]GN/=3I/M3H//oG//gD/lcA]/oD^=3E^<oB^<c?
]/W;]LK8/lC6/l?5]<;4]L?4^<K70[[9b`09_L_<_/_;_l[:_l[8_lS7_/G5_<?2][fm/;Ri00:b^[X0
2[:i^KFj^KRl^KZm^KZl^K^m^Kbl^;Bf/jV]ZijUY0:FW9d02XfFV8F@Tgf:SWJ4RFmoQFQkPF=fOUec
NeQ_N5=[MA[oool02TEOLdaXNeA`Q5eiSFF2Ufn<XGVG[8FS^I6_aYnld`:ZaM/05;G=h[[Ai[WAiKW@
hk_Bi;[@h[S=gkK8fKC5eKG7ekG8f;C4e;;0ck6mb[2kb:nkb;2lbK6lbK2kbK2mc0:`_lh04K2ncZnm
c:nmbZnnbk2nc;2ncJjmc:NgajFfaZZkbjfock32dKG5e;W9ek_;fK_<f[k>g002_loN00jkc=^ebMR]
a=B]a=BR^LZF[[n;XkB0V:YeSZ1[Q9IQNheHLXA?JGa6HG<Loooo000Joooo00Z@T8nLW9^YZJRe][G2
`l;@dM3Ngmk^knkoookhn?P2ko3`01CSiNODf]g0bm2[_<:J[[JN[kJT/[NZ]KR_^;Zd^[^h_;bl_Kbj
_;^j^[Zh]kJh]KBh/k6j/Zo1]k;8_;H2cl:k01GEaKgJakgMakcOaKWN`;?J^JcG]JOB[j7<Z9[7XYC1
VhflUXJlTh:lT7flSGZkRgNlR7BhPfjOLEn3GDifDD<00Va3=@0:JTHjJDXoJTm6K5E=Ke]DLV9LMFQS
NFm[O7IcP7ek6_ooo`0:N8N9Q9>ESj2QVjb]Z;Vj]LO7`mGEd^CTh_CdhO;a0]k^k@0Df>OWcmoP`M?F
/lO;Ykg1Z[k1[[o1/L71]L;1]l;0^L?0_<?0^/6n^;jk][^h]kZf]kVd^[Vd`;jga/Bl0/c9`@0Ed<c3
e<c2e/g1f<^of<RjeL>ed[n`c[V[b;>Ua:jP`JVJ_ZFF`:BC`:>@`J6>`In<`ij:`9Z5[H]hUWUYRViO
00:2He@02WeSEgQSF7ATFg5UGVmXHVi[IVe^JVeaKfedM6ehN1[oool02UMbO65lQV^7T7FAVgnMYX^X
/IJe_J?1b[3>ekOEg0:lfN005;kJhKcIh;SEgK?@f:o=eK3>eK7<dk7:d;78c;34b;33a[73a:jo`:^j
_:Zh^J^h^Jfh^K2k^kC0`KS5a@:kbLT05Kk:b[o9bKo9al7:a/;:a/78aKo5`k_2`;Nm_;Fj^;Bh][Fi
][Vk]kZm]kbn^;fn^Kno^Kjm^;Fe/:JYYifRX@02UibL00Z?UiR5Si9mRHaePhM^OX=XNH1RMGeMLWYG
KWMBJgDJoooo00Y4Gg=<IgYCKh9KMh]SOi=/R9aeTJInVZn7XkVE/<D2X[[?00B[`]F_a]ZdbMbhbmd2
^lkO00jhbm^famJb`]2__<V]^LJ/^<>Y/kjU[[RT[;JV[KNX[kV[/kj^^<>`^lP3/Kk;01B`_<V_^lN`
_LRc`L^d`/fb`<f__/b]_<Z/^/R^_<Vb`<fga=2jb=>lbmJncMW0cmc1d=c0c]^jbMJea]@2/LGD00ZV
_<^I[kn=Xk>1V:UfSIi[Q9EQNXaHLH=?JG]6H7<Loooo000Joooo00ZAT8nMWIbYZZVf][G4a<?AdM3P
h=o_knkoo_ghmoH2k>g]01COh^?@emVlb<fX^KnI[KFK[;>Q[k>W/[B/];Ja][Nd]kNf][Je]KFg]KBg
];:h];6i/k2n]K;4^[C;_kT2d<>k01GFa;cJaKcLaK[N`[ON_k;L^ZcJ]jSD/:7?ZY[;Y9G7Who3VXW2
UXC0Th2oSg^oSGS2S7JgPVbLKeb2GDiiDd@00Vi6>00:I48fHdHkID]2Ie9:JeQBKemJLfIRMfiZNgEb
P7ak6_ooo`0:N8N9Q9>ET:2QW:b]Z;Vj]LK7`mCDdN;Rgo7`gNg]0]SXi`0Dd^7Qb][K_LoA[lC7Y[_0
Z;^n[;bn/;jn/kjm]Knm][jk][^h];Vf]KRe]KNc][Nb^;Rb_[^e`l6ibLJn0/k9`@0EdL_2dl_1e<Vn
e<NjeLBfe/:ce/6ad[b/cKJVb[6RajfMaJZIa:NEa:FBa::?a:6<aj6;_iV3ZXQeUWUYSW5R00:6IeP0
2WYPE7AOEG1PF6iRFfeUGfaXI6a/JFa`KVacLfagN1[oool02UMbO61kQFZ6SgB@VGjJXhVU[YB`^Inl
`j[6cZo;dP:bc]D05;G@ekGAf;??eZo<e:k;djo<dk3;dK79c[76b[33aZjn`:bi^ZZf]jVc/jVb/JZb
/Jfe];:k^kO2`K_6a`:nbLT05Ko9bKo9akg5`kc2_kg2_L76`<C8`l;6`[k2_[bo^k^n^[^m^Kbn^;fn
^;jn^;jn]l;0^;jl]K:b[JRZYj>VY002WJ6Q00ZAVIZ4SY1kQXYcPHE]O85VN7iQM7]LLGUGKWIBJg@J
oooo00Y4Gg9;IWUBKH1IM8QQO8mXPiM`RimhTZIoVJb:XkH2UJg001BO]/RX_Ln^`mBdamRjc=bkcMfi
bmZgamJd`/na_<R]]L2X[[RUZ[>TYjnSYJfTYZfXZ[://[b`^<>b_<P2/kg;01Fc_LZ`^lR]]l>Z];j/
][nb_LJg`lfga<je`/fd`Lbd`Lfg`lnia]6kbMBlb]Fmc=K0cmW1cmZnbmJmbmJkb]L00[S;f@0:[L;A
Vk2oSJ:bPINWMXbMJh:CHGV;F762CfQjAV1c7?ooo`006_ooo`0:TI2?WIfLZZZY]kJeaLC3d];@hN3N
l>k]oogkmoGd0^_[j`0Dg>3QcMCG^<G:YkNnV:bdVJZ`WZb`Y:naZ[6b[[>c/[Bd]KFd]kJd^KJe^[Jd
_;Ne_kVe`k^fakfhcL6k0];4_00Ee/FlfLFjfl>hg<6egKj`fKR[ekBVe:nPdj^LcjNFc::@b9f;aIV6
`Y=o`I1la8mjaHef]7mZVfeKQUm?Me93009Y@cH02ULh;E]0=Ui7?V9>AfMECf]MF71UH7E/JGYdLWml
NQ[oool02WR7RHBCU92OX9b[[:Rh^KG5aL;Bd/oPh=g^kM[Yj0;Dhn<05<gMgL?Ee[O;cJg1a:Fj_ZJi
^jZj^jjl^k:l^kBm^kJm^KNl^;Rl]kVl]kZl][bm]knn^<?1^/O4_Lc8`0;?bl805M;<`]C;`=C9_MC6
^M?2]=2m[lnk[<niZM6gYlneXlfaWlZ]V/RYU/FUTLFSS/RRSLVPR[bEP:V7LiYkJXi`H002PF9D00Y_
ET]]FE1[G5AZGeQYHUeYIV9YJVMZKVa[LW9/MgLJoooo00YGLG]PNhAYQ8ecSYMlV:26XZZA[;BK][fU
`<JY`lT2ZlG;00>]b<j]b<n/b<l00Zc8c`0?[/W@/<W?/LW=//O://C7/L72/;jn[kbk/;Zj/;Zi/K^j
];jl]l70^/K5_LW900;0blX05L7<b/3:b;o7a;g3_kZn^[Nk]kRl]kbo^/73_/;4_/72_<31^[o0^Kjm
][jl]L2m]/:m]K^g/;:`ZZ^[YZFUX@02V9ZI00Z:Si21RH]hPhIaOX9ZNGiUMWaOLWUKKgMFKGEBJW@J
oooo00Y3GW5:I7M@JWeGLHANN8]UOY5/QIQbRiiiT:>2V:X2S:6c01BEZkfN/lBW^l^``]:gbMRjc=Zj
bmVhb=Jfa=6d`<ba^/F_]Kn]/[Z//;R/[kN]/;R_/k^a]l2c_<Je_lX3]L3<01Bc_/V`^/F/]/2X/K^U
/;VX/kb`^lBg`/bja/nka/nkam2lam6kam2kam6nbM>obmBob]BnbM?0bmBnbM<2]<;?00ZY^/NJ[K^=
X:n0UJAeRYYZPI5QN8UGL85>J7Y6H78Loooo000Joooo00ZAT8nNWIb[ZZVh]kK5a<?CdM3Qgmk`kNcn
o?[elo82jn[Z01CKgn3;d]Fha<RX]kfJ[KBIZJnMZJjR[:nX[k2]/K6a/k:e]K>h][Bj^;Jm^KK0^kS3
_KW7_k[;`K_@`k`2e<Jm01GGaKcJaK[K`kOM`KCM_[7K^ZcI]JOD[j3@ZI[<Y9C:X8o6VhW5UhC4U7o6
TWg8T7[5S7F`O6RJJeV5G4eaCCl00V0n<P0:Cc8YDcXaF48jGDY3HU9<J5YEKF=OLf]XNG=aOgaj6_oo
o`0:N8N8Q9>DSinPVj^[YkNh]<C4`=7@cMkMf^[YeNGU0]7Ph00DbMWI`=7B]LS:[<33Y[ZmYkRjZ[Vi
[[Zj/Kbj];fj]kfj^Kjj^kjj_Knj_l2j`/:la<Bmb<JoblW1cl_20]?=``0Ee<g2e/c0e/Zme/RjeLBf
dl2bd;^]c;JWbK:Rb:nNb:bKaJVFaJJBaJB?bJ>?bj:<bIn8^95lYh=aV7MVR6UJ009hG4h02VQAAVID
BfEGCfEKE6EOFVISGfMXIFQ]JfYbLF]fMa[oool02UIaNemjPfR3S76<U7^EWHBOYXfX[iNa^:2j`::l
`P:U_/@05:O1ajO2b:S3bJW5bjc7cJo9ck7:c[;9cK?8bk?7bKC5a[C4a;C2`[G1`;K2`;S3`[[5a;g8
a[o;bL;=b`;3cl`05LC>c<C=b/;;al77`kk3_k^o^kRk]kJh];Fg/[Nh/kVj];Vi/kZh/Kbi/L2k/l:k
/l2i/KRbZjn[YJNSWijKV002TY:A00Z4RHYlQ8IdOh9]NWiXMW]RLgUNL7MIKWIEK7AAJW<Joooo00Y3
GW19HgI?JG]EKX5KM8IQNXaWOi5]Q9IbRI]iT:42PiVY00F>X[>GZk^Q]<>/_/bfamD00[c<fP0=^l[H
^LOE]lC@]/7<];k8/k_4/kW1/kS1];[2]Kc4]kk7^<7:^L?=00:ia<h05KW3c[O2c;Bob[6laZjh`Z^d
_ZRb_:Ja^ZRb_:bg`;2ka;:ma[Bna[S2b[c5c[k7ckg6ck_5cK_3c;_1bkRob002/;[500ZV]<2HZKJ;
WJYnTJ1cQiMYOXiOMXIFKWm>IgQ5Gg8Loooo000Joooo00ZAT8nNWIb[ZZRh]kG5a<;CdLoQgmg_kN_n
noWel_42j^WY01CKg]o;d]BjaLR[^KjN[[FIZJjKZ:bQZZfW[Jj/[jna/[6e]K>i]kFm^KO0_;W3_[_7
`;c;`[g?a;kCa[l2elRo01GIa[cKaK[La;SN`[GN_k7M^jgJ]ZOG/J7BZi_?YYG;X8k9W8W9VHG9UX;:
U7o;TG_3RW>]NFFFJ5J1FDU[BC`00ULj<00:B30VBS@/D3dfEdI0GDm:I5QCJf5MLFYWN79`OW]j6_oo
o`0:N8N8Pi:DSijOVZZZY[Jf//;2_lo>bm_Kf>SWe>?S0/oNg@0Da]OF_/o@]LO9[/33Z;^mYkRiZKNh
[KVh/K^h]Kbi^;ji^knk_/6l`L>m`lFoa/O1bLW2cL_4d<g5dlo50]K@aP0Eelo4f<k1fLbofLZlf<Nh
e/>ddkj^d;VXc;>SbJnNaj^IajVEb:NCbZJAc:B?c:>=aYb6]HeiXWm/TG5QP6=E009`Ed/02V9=@em>
AUmABUmFD65KEV=PGFAVHfI[JVQaL6YfMa[oool02UI`NUiiPVN1RW2:TWRBVX6KXXZTZi>]/ibf_9nh
_P:Q^Kl05::k`:Bm`jG0aJS3bJc6c:o9c[7:c[?:cKC9c;K9bkO8bKS8b;W8b;[8b;c9b;k;bL3<bl;?
cLCAc/KBc`;8dm005LSBclSAc<O?b/G<al?8a<35`;g1^k^m]kRi/kNg/;Nf[kVg[kbh/;ji/L6j//:k
/[jg[[B]YJVTWInKUYFDT002Rhb;00Z0QXIgP89_NGaYMGUTLWMOL7EKKWAHK7ADJg=AJG<Joooo00Y2
GG18HWA=IWUBJgeHL89MMHMSNX]XOY1]PiAeRi`2OI:R01B7VZZBYKBM[kjY^/ReaM:lc=VncMZmc=Vl
b]Jkb=Bja]2ia<ji`lfi`/^j`LZk`/^la<bma/nnam6nbM82_/WC01FmbM:lam2jaLjg`/bd_lRa_<F^
^L6/][jZ];fZ];b/]Kf`^L2d_LBh`<Rk`l^maLfk`l^h_lNd_<>a^<2_][l00ZZd_P0:Xk6lUZJbQiRU
NhfKL8BBIg^;GWB4EFamCFIgAEma7?ooo`006_ooo`0:TI2?WYfLZjVX^;JeaL?2dm3?hMkLkncYoO[g
m?3^0^WXiP0DfmgNcM;D_LK9[kZoXK2eVZV_VZJZWjV[YZb/[:j^/K6`][Fc^kRe_k^h`kjkal6mb/>n
c/G0d/O0e/W10]W9_`0EflRmgLJkg/Fhgl:eh;nagkb]gKNWf[:QejfLe:VGdZBAd:2<cib7ciV4ciJ0
cI9k_hI`Z7EQTFACNeE6IDDi009?=R`02T0[8cl/9DPg<E52?5U<Af5FDFQOG6mXIWIbKgekNA[oool0
2WR7R8>BThjMWYZYZJFe]K71`;g=c<WIf=KUi=7PgP;<f]T05<GDe;k>c[O6ak30`ZZk_:Nh^JVf]Zfh
]k:k^;Jm^KZo^[k1_<74_/C6`<S9`/_;a<k=aM7?amCAb=SCb0;JdlL05M_BaMc@`mc>`=c<_Mc9^M[5
]MS0[mBkZ]:gYM2cXLj_W<j/V<nZULnXT]2VSlnRRl>HPJn8M9ejIh]/G7UND002Ie1500YIASeDACeG
BdAIDDaLEe=OGUYRI65TJVQWL6mZMGHJoooo00YFL7YNMh5VOhQ^QhmfSiMoV9n7X:J@Z:jI/KJK/[H2
W;>g01BN]KZQ^;bT^l2X`<B/a<R_b<bbb/fdb/ffblfhblfjc<blc<bncLg0c/k2d<o4dM36dm78eM;:
e]?<f=@2cMSD01G=em;<e]3;dlk:d<[8cLO6bL?4aKk1`KZo_[Nn_;Fm^k:o^[;1^[72^[74^[74^Jjl
/ZR_YinTWYJIUHn=S8P00X:3P@0:MgalKWIgJ79dI6mcH6ebG6abFF]bEVYbDfUbD6Ub6_ooo`0:@Ua_
AV1cBfAfD6QjEFanFW62GWF5HgV9J7f=L8>B0WR:V@0<PI>QS9fZVZVfY[G1//7<^l[F_lkK_lkJ_/gI
_/cG_/_F_/[D0[o9d`05`<[C`L[D`/_D`lcEa<kG00?4cmP02<?>el;=e/3;dkg8d;_5cKS1b[Foa[>l
``:b^/401;>k`KFl`kRnaK_0a`:m`/P01KZoaKBi_k2e^j^a^:N]]@02XZZb00ZJYJn?W:R2T9agQiA]
OheTN8ILLH1DJW]<I7I4GW0Loooo000Joooo00ZAT8nNWIb[ZJRh][G5`l;Cd<oQg]c_k>Wmn_Odl>h2
jNSV01CKgMk=d]Bma/V_^[nQ/;FJZJnJYZZOZJ^V[:b/[Zja/K2f]K>k^;Fo^kS3_[_7`Kg:`kk>aL3B
al3FbL42fLVo01GKb;gMa[_NaKSO`[GP_k7O_:gM]jOJ/Z7G[IcDZIOBY97@X8c?W8O?VHC?UX3=TW^o
QW2XMF6AI5=kEDIUACT00Tlf;00:@2/S?b`UB3LaDD8lFDa7HEIAJ5mLKfQVMW9_OG]i6_ooo`0:N8N8
Pi:CSYfNVZVYYKFe/L70_Lg<bMWHe^GTdN3N0/cJf@0DaMCD_/k>]lK7/<32Z[^lYkRiZKJf[KRg/[^h
][fi^[nj_/6l`LBna<K0b<W2bl_4c/g5dLo7e=78f=?80][Ca`0Efm;5g=33g<k0g<bmg<Vif/Fef<2_
e;^Zd[NUd;>QcZnLcZbHcjZEcjRBd:J?cj:;`iR1[hQdWGYWRfaLNEi@009WD4D02UU6?EA5?EM;A5UA
C5aGDemNFV9THFAZJ6M`KfYeMQ[oool02UI`NUigPFIoR6j7SgJ?UgnHWhNPYY2X[YVa]Y^b]P:L/kL0
59je^Z6h_:Bk`:S0a:c4b:o8c;;:cKC:cKK;cKS;cK[<c;c<c;k=cL3>c/;@clCAd<KCdLSEd/[FdlcH
e0;=f=@05LgGd/cFd<_Cc/[@b/S=alK9`lC5_/71^[nn]kjl]Kfk/[nj//6j/L:j/LBj/LBi[[bbZ:nW
WjBNUYVEShf<R002PX>100YgO7a^MWMXLWATKg=PKG9LK79IJg9FJW9CJG9@JG8Joooo00Y2G6m6H7=;
I7I@J7YEK7iJLH9NMHESNHUXOHe`Pi82N8ZI00b1Tj6<WJZJZKJV]L6b`Lbkb]Joc]^oc]ZncMVnc=Nn
bmJnb]@2_lWC00G0b]?1b]C2bmC3c=G4c]L00lC?f008`lkG`/gF`<_C_LS@^lG=^<7:]Ko6/kc30[:j
`@04/k_1]Kc3^;k5^l370[g2b005^[o5];Vo/;FkZk6hYjfe00:RZ[802YZU[hnLZ8:@W7N7U6eoSFAh
QUaaP5AZNdaTMTANL1coool001[oool02Y6@SijLVjZYZ;Nf]<G2`M;?cN3MfnkZj?chmO;_k0;Xi^D0
5=_Mg<kBdko7bK6k_j>a]IbZ[iRUZInWZZJ[Zjb^[[:b/;Rf/kfi]/6l^LK0_<[3_/k5`=;8`]K:`]W;
`P;Kb/005Mg9_]o7^n35^>73]N70/N6l[MnhYmbcX]Z_WMR[V=NVTmFSS]>NRM:KQM:GP<Z?N;N0Jj5`
GHYOCg=?@U/o<`02ABlW00Xf91de91i1<Ra;?SUEBDEMDe1VGUY]IfEeLFmmNWTJoooo00YgQXR2TI:=
W9fIZ:RT/k>__kjkb/[7e]GCh^7>g=/2bMOF01C3dM6lbl^eaLF__knY^KZW][NW]KB]^;Jb^kNg_[Vl
`Kc0`kk4a/38bL;<c<G?clOCdLWFdl[IeL_Le//2gMK901GNeLOOdlCPd<7Pc[kObk[NakKK`[7I_ZcG
^ZOE]Z;D/YkC[i[B[9KBZI?AYho;WhRjTG^XPVnEM6:2IEI^EDT00U]7?@0:CC`dBC/dCd@nDda7F5A@
Fe]HGf9PHfQWIVm^JGEf6_ooo`0:EFmiGGIoI7j6K8F=M8bDO9BKQ9bRS:>YU:^_UZb`0YR^/@0DVJnc
W;:fWkJjXkZmYkk1[L?6/LS:]<_=^<c>^/k?_M3@`=7A`];AaM?BamGDbMOEbmWFc]_Gd=cHdMgH0];M
f00Ed]cFdM[DdMOAd=G>c]7:blg6bL[2alJnaL>ka<2g`kne`kfd`kbb`k^aa;Z__kFZ]:ZQZ:2GW9J?
Sh^6PH1l009eMW@02VY^KV=YJV1YJeiYK5]XKEUXKUIXKeAXL59XLE1XLA[oool02T5KKTEOLDURM4iU
Me9YNUI/O5Y`OeicPV9fQ6YmR`9bPi404g^;V8FEXI6Q[9n]^:^h`[O3cKk<e/3?f/7?fl7@fl;@g<?@
flC?fLG@fLK@f/OAf/SBflWCg<[Dg@03b]GM00_9e=c8d][6d=S4c]G1bm:naljla<^j`/Vh`<Jh_lFh
_l@00[Voa@08^/36^l36^Kk3/kNl[K:gZ:fbXZN/Vj2W0YBKXP0:SYFNQ8jHNXNBLH2<JGZ7HG>2FFim
DVQhBf=dA5e`7?ooo`006_ooo`0:TI2?WIbKZZRW]kFca<6odLk<gm_IkNWVnoKcl^gZ0^OTh`0Dg=cK
d=?C`lS:/kboY[:gWJ^`VJJZWjNYYjZ[[Jn^];>a^[Jd_kZga;jjbL:ncLG0dLS2eL[4fLc4g<g30]k<
`@0Eh<ZohLRkh/Jhh/Behl2ah[f/hKVXgkFSg[2Ng:bIfZVDfJB?ej2:eYb5dIIoa8]d/7]VVFYHP5U:
J4PlD3L]008j:2402RPI52dO6c/^:TLk=e57@e]BCV=LFFaVI7A`KWajNA[oool02WN6Qh:@TXbKW9NV
YZ:a/Jjl_;W8alGDd]7OgLcIf0;6e=<05<7?c[c:bKO5a:nn_ZVi^ZJf]jNe]Jfg]KBk]kVn^[o2_L?6
_lS9`/c<aM3?b=CBb]OEc=_GcMgHc^3Ic@;RfL/05N?GbN?EaN?B`^?@_n;<^n78]]o4/]g0[M^mZMZi
Y=ReX=NaVmF^UmFZTm6USLFJPk>;MZ1lJH][FgIKCV5<@@02CSde00Xm;bPo<be8?cY>B4ACD4eHF5IM
H5iQIfIUKViYM7DJoooo00YEKWQLMGiSO8AZPhYbRI1iT9N1V9f9WjBAYZZBYjX2TjR/01BFZZfI[[2M
/[FQ][VT^kjY`<:^aLReb/bicLjmd=70dm?4eMG7emK:fMS<fmW?gM[AgmcChMgEhMgFh]d2en7K01GG
h=[Gg]OFg=CDfM7BeLg@dLW>c/G<bl7:akk9a;[8`[S7`;G6_[?6_;33^:bj[jB^Y9ZPV92ARhF3P7]e
M7400VMYJ00:FUaLEU]LF61SF69VEVAXEFAZE6E/DVI^DFM_CfMa6_ooo`0:@5]]A5e_B61aBf9cCfEe
DVQgEV]jFVelGW1mIGJ30VemR@0BMHB@P8jISIZUVZJ`Y[:l/Kg8^/SB`LoI`m7LaM;Ma]COb=GPbMKQ
bmKPc=OPcMSQcmWRd=[S0]3Kh`;@f^805M3JhLkHglcFgL[Cf/O@e/C=d/;:cl37cKo5b[g3b;g2akc1
a[c1aKg0aKZn`[Bh_:ja]JNY[YnRYiNKX8nCVP02QhfC00YmPhYfOHEaO8I[N8ATM81MKgeFJWU@IWI9
HG93GFlLoooo000Joooo00ZAT8nMViZYYjJf];;3`;k@cL[Nf]O/inCjm?7`k>T2i^?R01CLg=_Be=?5
b<Vf_/2[];RQ[K2NZJ^QYjVXZj^_[jjf/k6l^;C2_;S7`;c<a;oAb<?Eb/CIcLKLc/KOclD2hLg201GR
bkoSbK_Ta[STa;CT`;3T_JcS^ZSQ]J?P/IkN[IWMZICLYHoJXH[FVhC=TW^lQ6nWM66>He9fDTAN@3E6
<2L00S0Q6P0:81<?;20L>2dYA3TfCTE2F55>HU]IJfITLg1^O7Yi6_ooo`0:MhF7PI2ARiZKUZBUXJn_
ZkZi]lG4`m7@cmcJb]OE0/CBd00D`<g<_<W8]L?2[kflZkViZKJfZ[Jd[kNd]K^g_<2j`LBnalS1c<c4
d=38eM?;fMO>g=W?h=_Ah]cAiMg@0^KKc@0Ei]W:imK7imC3i]6oiLfki<Zgh/JchL:^gkjYgKZUg;JP
f[:KfJjGe:RAc:29_I=mZX=_U7=QOf9DJU96ET<i0093=2d02S@X8S/a;4<k=dU5@E1>BeEFE5YNGEmV
IFA]KFQdMA[oool02UA^N5]dOF5jPVR0Qfn6SGJ=TWfCV8FKWhfRYHjSYP:@Y:L059>VZIJY[9V/[Yf`
/Z>g^:Vm_Zo3a;K9bKc>c/3Bd/CEeLSHf<_Lf/oOgM;QgmGShMOUh][Whm_XhmcXhP;Lin005McTgMcR
f]_OemWLdmOHcmGDbm?Aam7>`lo:_lg7^l_3^<_0]<Vn/LFi[KjbY[>WW:FKTIJ>QXN1NgQeLFYYIP02
G5iM00YAEEEAEUMAFEaBG61BGfAAHFMAHVU@I6a?IFi>Ig0Joooo00Y0FVa3G6i6GVm9Gg1<HG5?Hg9B
IGAEJ7IIJgQPLGd2J7N3015`OhYkR9:6TY^CWZJRZkB_^<2ia<c1cMG5d]_8eMo:en7<fNC>fnK@gNOB
g^SDh>WEhNX00]ORj`0Hen;Ze^7Xe^7XeMoVe=gTd][Qd=OMcMCIbm7Fb<kCa/_?a<S<`/K:`<C7`<;5
_l33^kg1][Rk/;6dYjR[WYnSUINLSHnDQHR=0Wf1Q`0:MWb2KgInJWAmI75lGfijFF]hDfMfCV=cB61`
@Ua^7?ooo`006_ooo`0:T8n>W9^JZJNU]K:a`[jlcl_8g=SEj^GQnO;_k^[W0^KRh00Dg=_Idm?BalW:
^l31/;NiYZnbY:b^YJZ[ZZb//K6_^;Fb_kZfaKjjb/>nd<O1e<_4fLg6gLo7gm36h]350^C>``0Ei<bo
iLVliLJgiL>di/2`iKf/i;ZWhkFSh[:NhJjIh:ZDgZF?fZ2:e9V1b8eg/giYW6eJPe];K4/mE3X_>RPP
008T6A@02QX@32TO6cH/:D4i=Da5@UM@CF1KF6YUHg=`KWajNA[oool02WJ5QX2?T8ZIVIBSXij][JVg
]kC2`Ko=bl_He/KCdP;2cld05;k;bK[6aKG1`;2m_:fi^J^g]Jnh]K:i][Rl^;k1^lG6_l[;`m3?amGD
bmWGc]kKdN;MdnGOe>OPd^WPd@;Zg/l05N_Kbn[Hb>[Ea>WB`>S>^nO;]nG7/n?2[^6oZ^2kYMngX=fc
VmV^U]>VS/RKQ;F<MZ1kJ8Y[FWEKC61:?dXj<@02=R/T00X/8Qdf;RXn>CE6@Sm<C4UCE5=HGE]NIFAS
K6eXM7DJoooo00YDKGMJLg]PN81VOHE/PhUcR8iiSY>0U9R8Vij9W9l2RijQ01B>XJ>AXjFEYjRK[JjQ
/kBY^[Zb`l:ib/Vnd<o3e=?8fMO<gM_@hMoDiN?Gj>GKj^ONk>SPkNSRkNOSkNH2hncT01GSjN7Qi]gO
hmWNgmGLfm7If<gGdlSDclCBc<3AbKc?aKS>`KC:_K35]jVk[J2]X9BMTXV=QGenN75_JfIOGU/00U1B
D00:Ad];BTmAC5AFCEMKCU]OCUeSCV1WCV9ZCVA]CVI_6_ooo`0:?eU/@UY/A5]/AUa/B5e]Bei]CEm]
Cf1]DV9_FVUe0V9`N`0DJWN1Lgn8OhZCSINOW:F/Zk>j^L77`lgDb=CLbmOPc]_UdMkXe>7/e^C_f>Ka
f^Oag>Wbg^Wbg^WagnW_0]kXkP0EgNK/fn?Xf=oUe]cPdmSMd=GIc=7Eb/kAb<_>a/W;a<K8`l?5`<32
_;bm]KBeZjZ/XJ2SUYNISHjAQ8J9Ngf1009aM7P02V]`MFM^MF=/MEm[MEYYM5EVLe1TLTaQL4MNKd9K
KAcoool001[oool02Y2?SYbJVJRUY;Ba[l2m^/g9a][Ed^ORg_K_k>gXi@;Uh=h05=cIf=CCd/[;bko2
`[Fj^jjc]J^a/ZR][Jf][KBb/;^g]<:l^<S1_<k5_mC9`mS<aMg?an3Ab>?BanGBaP;Vcl805NK<_^K9
^nK6]nO4/nO0[nJmZnFiYnFeX^>bWN:]VN:YU=jUS]VNQljDOKf6LJMeHXmTDgMCAEm2=dHa:2`N6@02
5Pd900XH3``W7Q/d;2U0>3I;A49ED4eOFeQYIF=bKfikNWTJoooo00YfQ8IoSXn9UiRBXJ6LZZZV];>`
_[fkbLO6e=;2clh2_l_901Blb<JiaL>f`/2b_K^`^[R`^KJc^kNe^kNk_[S1`kg8bL7?c/KDd/[JelkO
fm7Sg]?Wh=CZh]G/hmC^hm<2kn3@01G^gL_^f/S]e/C/e<3[d;cYc;OWb;?V`jkT_jWR^jCQ]ioN/Y[H
[9?>XHVnTgfZPVjCLV1nHE5YDDAB@3Hk;RL00RHL600:9QdI<R/X>cHc@d4nBTY8D5=BEeaKG6ATHVa/
IgAe6_ooo`0:DfefFG5jGWInI7^2JGn6KhB9MHV=NhjAPIBFPiFG0XNGV@0DRY^LSYnPTjBTV:VYWjn_
Z;Rf/l;0^/[8`M3>a]KDc=cJdN7OeNKSf^WWg^gYhNo[i?3[i_;[j??[jO?Z0^Wai`0Ej>kSi^[Oi>KK
h^?Hh=oCgM[>fmK:f=75e/g0e<Vld/Fhc/6cb[^]`K:T]:FHY9J;TXQnPGYbLVeWHEmKD51>0090@400
2Sdo@4=9BTI>DDQCEdYGG4]JH4aMI4aPJ4eSK4eUKa[oool02SmIJd1IJT9IJTAIJDEJJ4MJIdQIITYI
ID]JIE9PJP9KIg4056A`N6miPW^5S8RAV9NNY:N^/kNn`l?;dL[DfloIhM;NimKSk=WVl=cZm=o/m^7]
m^?^m^C_mNG`m^K`m@;Uk_<05NC[kn;XjmoTj=cQi=SMh=GIg=7Eelk@dl_=c/W9blO6b<C3a<2n_kVg
]jn/[JBQXYRFUhf<SX>3QGQiO6e_LP02HV=V00YNH6ANI6]LIFeIIFiEI6mBHVm>H6m9GVi5G6e1FV`L
oooo000Joooo00Z@SXfKVIRVY::b[jfn^[S:a/?Gd/oTg]_bjnO]i^<2i=oL01CLfMOFdm;=c<[3a<>k
_Kbe^;Ra];B]/;2a/:nh];:o^[K6_[W<`kgCal3Hbl?Mc/GQd<OUdlSWdlSXd/D2jLo201GXc;gXbK[W
a[KX`k?X_jkW_:[V^:GU]:7T/IcS[9OQZ9;LXhcDVH;5S7NbOFVJK5Z2Fda[BciC>S0i:24Q5a800Q08
1P0:6a<A9b0M<b`Z?cTfBTA2EE1>Ge]IJFETLW1^NgYi6_ooo`0:MHB5OXf>QiJFT9jOVZNWXk6`[KZi
]lC2`Lk<_l_90[c8a@0D^/G3^<?1]L2m/kbj/[Zg/kZg][bg^;bg_/2jaLJncLc3dm77fMG;gm[?i=kB
jN7Dk>?El>GFl^KFlnCD0_?Rd00El]k<lM_8l=O4kmC0kM2kjlbgj/Nbj<>]i[nXi;ZShKFMg;2GdjJ>
aIV2/hYdWGUVQfQGLUM9G4LlACD]<2DP008Q61@02RLP7C0Z9cPe<d0o?DQ9AdmBDEEKFU]SHf5[K6Mc
M1[oool02U9/MEM`NEadO65hOfIlPV^0QG24R7J8Rg^<SWf=SP:1T94058FDUHZIVHnNWYJTXif[ZZNe
/[6n^k[7a<?Ac/[Ie]3OfmKThM_YiN3]j>CajnSdkN_fk^ggknohk_3fk@;_m>T05Nkai^c]h^[Zg^OU
fNCQe>7LcmkGb]cBaMW>`=G9^];3]Lfn[lFeY[VYVjZKSYV<PHMmM7M_J6IQG5ECD4I6A@02>cdm00Xl
?d0nA4I2BTe4Ce=7E5U8F5i:Ff9;GfI<HV]=IFhJoooo00XnF6XoF6U0EfM1EfI2EVA3EF93E614Dei4
DE]:EUh2E5iV01AMIfmWLGQcO8:2RHjAUibQYj^b]k[1aL[<dmWBg>;GhNSKi^kOj_;Rk_KVlOSYlo[Z
m?[/mO[]m_[^mOT2kO?f01G[l?CYkO3UjNcRiNONh>;Jg=gFemSCd]??c/o;bL[7aLC2_knl^;Nc[ZjX
Y:>LV9N?SHb4PX9iN7U^KW1UIFP00UmPI00:FUeRF5iTEUmWE5mYDEmZCUi[Bee[Aea/A5]/@5Y[7?oo
o`006_ooo`0:Shj=VYRGYJ>Q/:f[^kReal?0dlk;h=[Fk^OSjnCP0^CNf`0DgMSEem?@d<g:alG4_kjm
^KZi][Nf];Bc][>a_;Nc`kfhb/6kdLJnelW1gLg4hM36iM;7jMG9jmG8jm;50^_?`@0EjL^ljLRhj<Fe
j<:aj;j]ik^XikNTiK>Oi:nJhZ^EgZF?eij7bi9l^8=_XgAQS6=CME95Gd8gAC4X:ahI5`l=008;1P@0
2QXD4RLQ7c<^:clj>4Y5@eE@CemKFFQVI79`KW]jNA[oool02WF3QGf<SHJDU8jLW9NTY9n][:Rf];:o
_Kc9akc7a@:ia<805;S2_kO0_KFn^k>l^;:i][>i]KJk][^n^<71^/W8_m7>aMSCbMoIcNGMd>[QdnkT
eO;Ve_KXeoSXeoSVe0;ghm005OGOc?CKao;H`o7D_no@^^g;]^_7/NW3[>NnY^>iXMjbV]NZT/ZNQ[R?
NJAoJhm^G7UNCVE=@Dhl<SHZ92@L60026Q<@00XT7a`^:RLf=C8o?ce6BDM=DU5DFeYKHf=QJfaWLg@J
oooo00YBJgEFKgMKLWYOMGaSN7iXNh1/OX9`PHAeQHMgQXL2NhV901B0SHf5TY6;V9JAWYfIYJ>Q[Z^/
^;Bha;o4cl[=fMCDh]cJj>;Qk^OVl^[ZmNg^n>oan_7do?7fo?3gn^h2mOS[01Gcm>O`l>?^k=k[imWX
h]CUgLoQf<[NdlCKcKkFb;S@`K78^:Rm[9f^WY2MSh><P7IkLVU[I5eIEE17AD<i>ST00S<d=@0:=SXk
>T12?TI9@Da@A55FAUEKB5YPBEeUBf5ZC6A^6_ooo`0:?UMY?UIW?eEU?eAS?e9P?e5M?diJ?TaF?TYC
@deE0T]DF`0DEUiTHFQ]K7=hNX25R8jBUibPZ:b_^[k1b/kAe=_Nf^CYgn[_i>odjO?hk?KjkoSll_[n
m?[nmO[mm_[l0_Chn@0El_Gfko7bjng^inSXhn?SgmkNf]WIe]CCd/k=cLW7a/?1_[Zh]K2^ZZBRWIRF
THb;QX:1NWMfKV]/HV1RF5QJ009EEUT02U=FFU9GGE1IHDmJHdeKIT]KIdQKJ4EJJD=JJT1IJacoool0
01[oool02Xn=S9VGUZ>QWjj[ZKVe/lBo_Lo:am_EdNOPg>WRgP;TgMT05=kHe=KAcm7=b/W6a<6o_Kfk
^[Zi]kZg]K^f/l6k]/No^Lk2^mK8_mc;`^7?a>GAa^WCangEb?3Fb>kBa0;/c[l05N[:^^W6]^S4/nS0
[nNmZnJiY^FeXNBaW>6/UmjWT]NPR/jFP;f8M:UiIYAZFGeIBVI8?Dlh;SDV81hE4P/610022PH400XJ
5A@X8b4d;be0>cU;ATEEDE1OG5YYIVEbL6mkNWTJoooo00YdPhAlRX^4TY><VYZDXJ6LZJRT/K2/^KNd
`;jg`[l2]/6n01Be_kbc_;Vb^kRa^KJ`]k>b^;>f^KBk_KK2`KW<b;oDclCKeLWTflgZh=7`hmCdi]Kg
j=Kkj]Onj]Omim@2nn??01Ghgl[ff/Kdel;cdkg`c[W^b[?[aJkX`:ST^Z;O]IcH[9C=XHVlTgfYPfnE
Lf5oHU9ZDTED@CHm<2PX7aXF3``00QD?300:8QhK;2XX=CDc?SlnADU8CE9AE5YJFV=SH6]/IW=e6_oo
o`0:DF]dEFefFG1hGG=iH7EkI7MlIgUmJW]mK7]kKgel0WB1P@0DNXJ5OXZ9Q92?RiJETYjKVjJSY[2[
/[^e_lS1c=K>en7Ig^WPiNoVk?G[lOW^mOcan?kbnooboOoboOg`0__jk00En?GWmO7Rl^gNknSIjn;D
img>hmO7g]71fLZjd/>bbkZZ`:nO/:2AX964Sh9fOW=YK6ALFeE?BDI2>SPg:bXY008Y:BT02S4d=SHl
?cY3ASi9CD5?E4ADFTIHGdQLI4YPJDaTKQ[oool02SeGJCeEISeCHceAH3a?GCa=FC]9E3U5CcI0AcQ1
A`92BU0054eDFEMMHV9XKFmeNGj3QXfATifPXJj`/L73`m3DeM_Qhn;ZkNS`lnkfnO?jo?KmooSnoo[o
oogoooknoP;lo?`05OShn?Gcl_7_k^cZjNOThn;Ng]gIemOBd=7<bL[4`L:l^KNa[Z^TXIjHUI6;RHAo
OGQcLVaXIf1LGEICE4a8B002B4I800Y;CE5;DEM;De]:EEm9Ef97F6A6F6I4F6Q1F6ToF6XLoooo000J
oooo00Z>SHbHUYFRWij/ZJNf/[30_;W;aL;EclcPfMGXh=`2i=cH01CMe]?GdLkBc<W;al?3`;g0_;Zm
^KJn^KJn^KG3_;K8_kWA`kcKbKoQcL;Ud<GXdLG/dlK`eLOae<G^d<42jl^l01GZb;SXa;CW`K3W_JcW
^ZST]Z?R/IgP[ISLZ9?FXHc=Uh;0RgN^OV^JKej4Ge1]CT9F?S@n;BHV71PB3@/30@000Pl<2P0:7ATG
:BDT=C8`@CdlC4Q7EU=AH5eLJFMVLW5_NgYi6_ooo`0:M8:4NhV:PY2ARINGTIjNV:FUWjb[Y[>a[KVg
];nm0[>m^`0D/[^h/KVf/KVe/;Nb[[Fa/;F`/kJ`^KZc_kjfb<FkdLc0g=?6im_<kn3@lnCDmnKEnnSE
on[FonSDo^G@0__Qc00EnMg7mmW3mMBolm2jlLffk/R`jL:ZiKbTh;JMf:jFcJ>;_iEo[HMbVGMTQ6MF
KeI8FDDj@c@/;B<N6aDB3`X8008G4a402R4O7B/Z:CDe=3do?TE9B4aBDU=KFeYSI61[K6IcMA[oool0
2U5ZM5A/MEM^MU]`MeibN65cN6=dN6EeMfMdMFYeMP9^NGT057=nOGV3PWn9QhF?S8bFTiBNVYfVXJRa
ZkFm]/?;`/oFcMcSfNO]h^odj?Gjk_Sml?cnlOool?onk_kkj`;mn>P05O_eiOS`hOC[fo7Ve^kQdNWL
b^;D`mc<^mG5/lblZ/6_Wk>QTZ>BQI63MgmdJFiTFeaDCTY5@CXg=B`[:R@T90029bTZ00X]<C<b>C`g
@D@kAd`oCE92DUQ5Eei7Ff=9H6Q<I6dJoooo00XmEVPlE6DlDV8kCehjC5XiBEDgAE0d@4Ta>T4a>3h2
>T1501A4BTm?E5QJGV9WJVedMgZ1Q8N?TY>OXJ6`/[;1`l?@d];NhN7Xk>cam?Ggno_jo_kmookoooko
o_coo?X2oo[h01Gmn?Gim?7dk^_`jNK[i>7Vg][Nem?Gcl[?al;5_KRj/Jf]Y:2OUi>ARXJ3OGYfL6iY
I69MF5MACDe9ADE5@T800T=2A00:A4M;AT]AATmFAU5KAU=NAEEQ@eIT@UMV@5MX?eQZ7?ooo`006_oo
o`0:SHb;UiFDX9jLZJJT/jn]_;Rea/6nd<[6f]??i=cH0^?KeP0Dg=CAelo<dL_8c<K3a;nm`;^h_kZf
`;Zf`[Zfa;bfb[nhdl>kflRmh<_0hlg1ilk1jm32k]72kLo0jl^l0^S7^00EilBciKn_i;b[i;ZXh[JS
gk6Ng:^Hf:NCdZ2<biR4_Xai/81^W79RR6=DLeA7G4<iA38[;B8M6A<@1`H40P40008B40l02R0M72`Y
:3Pd<d<o?Te:BEMDDf1NGFYXIg=aL7]kNQ[oool02W>2PgZ8RH2>ShNEUHjKViBQXI^XYZ6^[:Rc/Jnj
]`:_^KH05:fg]:fe/Zbd/Jbc[j^a[Jba[;2c[KJg/;bk/l?1]lg7_=W?`N?Fa^[KbnoOcOCQc_SSco_T
co_RcOWObP;hflH05OKH`_CC_O?@^O7<]Ng7/>W2Z^BkXmjeWMJ]U/bSS;jFP:j8MI]iIhIZFG9IBea8
?DHg;S0V81hH50h;20X71@025aDC00XR8Al/;2/e=cHm@D15BTU<De=CFeaJI6APK6eVLgDJoooo00Y@
JW=CJgAFKGAIKWEKKgEML7AOL7AQL79RKg5TKfl2Ig5_01A[MGAaNWUfP7emQX>4S8V;U8nEWIROYj6[
/Z^g_[K4b/7Be/_NhMGVj]g]l>;cm>GgmnOjmnOjm^Cjln42nO7O01Ghk]cfj]Sci]C`hLoZflWTe<;N
cK_FaK?<^j[1[ijcXI6STXBBPgJ0LfQ^HeYLE4a9A3lg=C4Y:2HN7A`K6a`00R<V9`0::Rla<3Lj=Cm3
>DI:?DaA@E5GA5IMAU]SBEmXBfA]6_ooo`0:?5IX>e=T>U1P>DeL>4YG=TIB=49<<Ce6;SLn:c8f0Rld
>00D>Ci2A4Q;CU9EFUePJ6Y/MGMhPhB5TI>CX::R/;6a`<70clo>fmcKi>OUkNk/loCamoOcnOKbn_G`
n_C^0_[ck@0En_7[n>kXm>[Sl>COjMkHh]OAfm3:d/O1akbg^k2[[Z>NWiFAT8R4PGYgLfeZIF1MF5=A
BdM6@Cdl>SDe>CHf008l?3h02Sm2AT57CD9;DT9>Ed9@Fd9BGd5DHT1EICmFIciGJAcoool001[oool0
2Xf<RiFDTYjLVZNTX[2/Z[Rd/L6l^L[4`M?=bMgEd0;QfMD05=_CcmK>bm39a/_4`L>n^l6k^<6k]l>k
]lFl]lNm]lc0^=?3^]W6^mg8_=o8_>?9_NG9^nO:^nO8^^G6]`;T`[805N6n[]njZ]jgY]fcX]Z_WMN[
V=:TTLfNRlFFQ;b=Njf1LIieIHYWF7IHBf58?TXg<38V8AhH5@h;2@0000P61P025aDD00XT8B0_;B`k
>3M5@T5?CD]HEUERH5m[JFQcLW5lNgXJoooo00YcPH9iQhQoSHf5TY>;V9RAWYfFXj:LZ:NR[JbW/[02
ZkFc01BY/k2Y/JjX/:bW[ZZU[:RY[JR^/J^d]Jjk^[71_kG9a;WCb[gKcl3Rdl?VeLC/f<K_fLKbf/Kb
f<Cae/82lM>n01G_d;[]c;K[b;;Xa:gT_jSO^J;I/Y_AZYC8XH^lUX6]RGJLNfZ8K5adG4iOBd19>S4b
:B8O6AH@30X40P4;2@P00QPG5P0:8b<R;Bh^=STh?T92AT];CEADE5aMFVAUH6a]IWAe6_ooo`0:D6Uc
DVYcE6]cEfacFFabFVeaG6a`GFa^GVY/GFQX0UmYJ00DI6e/JG9aKWMeLgaiNH5nPXZ6SIB?V9nIY:ZS
[kF]^/2ga/[0d=?7fM[=h=oAi^CEjnSHk^WHk^SGknOF0_3Ud`0Ekn?@kN3=jmc9imO4h]2nflZgdl:_
b[RW_jfL/Z2@XY64TX=fP7=XKV=JG5=<BD<m=S<_9RDR6QTH4Q4A5aLG008P92D02RP^<2hf>S<n@SQ5
BSa;DD1@Ed=FGDIJHdQOJ4]TKA[oool02SaEIc]BHcU?GcQ<FSI8ECA4D34oBRhj@b/c>bH/<@8V:bl0
52lc=cTm@4=7BTe@DUUKGFQZJgIhNHF7QiFFUZ>UY;6c/[fo_/W:b=?Bd=cJe^?Pg>WUh>_Vh>cVh>oV
g`;`iMh05O3Tg>oRf^cOenOIdN7Cbm[<a=74_<Nj/k^^Z:fQVinDSi26PH1hLg5ZIV=LFEE?C4I1?cXf
=38]:bdW9S0/;002=SHi00Xj?D8l@dTnAdloBeE0CUU0D5e0DV0oE6<oEVHnEfTLoooo000Joooo00Z<
RhZDTi6LVYRTXIn/ZJNd/:jm^;G5_kc=al?Ec/X2gMC@01CKd/kDc<S>al?:`ko5_[[4_;S3^kK5_;O5
^kK7_;K=_[KB`;OF`KOH`kOH`[KMa;OM`[GO`kGN`K?M_[02fkZ[01GG]ZOD/J;B[YkAZY[=YYG9X8o2
VHVmTh:dRW^YPG:JMFN:JE]gFdmTC49??3Dh;2HQ6aPB3`h20@430`<@3`l00QdK6`0::2LV=38a?S`k
B4I5DDm>FUUGHf5PK6YYM7=bO7]j6_ooo`0:LX22N8J7OH^<PY2@R9FESIZJTYnNUj>RW:RVX:bZ0ZF_
[@0DYJj/Y:fZXj^XXjZVXjVUYj^VZjjX/K:[][F]_;V_a;jbcL>edlJhelVjf/^jh<jlh/jli<nliLjk
iL^h0^?8]00Eh<B`gKn[fk^WfKRRe;:McZbGaZB?_Yb8]99oZ8MfV7YZQVaMLee@H4i3Bcde=B`V81/H
4@h<0P000`82410?008K71/02RDW9bla<CLk>cm4A4M=CDiEEUAMGUYUIV5]KVMdMA[oool02TmYLU5Y
LU=ZLUEZLEIZL5QZKeUYKEUXJeUVJ5UTI09IHV4055]SHV5YIfE^Jf]cL79iMW^2OXF<QhnFT9VOV:>X
X:nbZKZk/<;3]lS9_<k=`=GBa=WEa]gHb=kHb=oFaP;Ne<<05MgA`=[=_=S:^=G5/lo0[LRhY[n^W[JU
UJZJRif>P8f0LgeaIVaRFE]BBdU2?CHb;RDR8ALF5@/92@`;2aLI6P0282@V00XW;S4]=SXb?T8gA4Xk
Be4oD5M2EEe5FV=8GfQ;HfdJoooo00XlEFLjDV<hCUhgBeTeAe@b@Th_?DP/=d4X<CPS:Bl27b<W01@T
9bT^<C@h>ce3ADM?D59MGUm[K6ahNGV6QhNCTi:PWij]ZjVg]K:o_K[6a<3=b/GDcl[Hd/gJdlkKdl`2
g=;;01GLd<WJcLGGb/7Ca[g>`;O6^;2m[jRbYInWViFJShV;PGemM6m^IV=PFEIABdU3?C`f<Bl[9R@S
71XT7Qd/:R/00S8c=P0:=SXo>D17>dE=?DUC?DaH?TmL?U5O?U=S?UEV?EMX7?ooo`006_ooo`0:S8^9
Ti6@VYRFXYnMZJJS/:bZ^;>`_kZga/2mc/O30]K>bP0DfM7=d/[6cLG1bL6ma[fi`k^g`KVdaK^eaKZd
ak^dcKfdc[fcdKfcdkjbdkfbe[jbeKb`e[^^eKV/dkFX0/naY00EbjfOb:VKaZFG`j6B_Y^=^9F7/Xn0
[8QjXh1bUWEXQfYNMeeBIDm7DD0j?30/9b4N5A8A1@@40P<33Ph>6APH008T8R802Rh];3Pg=T90?d]9
BEABDEeKFVESHfe/JgEdLgelNa[oool02W60PGJ5QW^9RX2>SXFBTXZGUXjKVY:OWYNRXI^VY0:OZZL0
5:6[ZInXYIjVXinVXZ2VXZ:WXZFXXZ^/Y[2`Z;JdZkni[LBk[lRn/<g0/M32/]C4/mG3/mK3/]O1/=Jn
[@;C^jT05LngYLbbX<Z^W<JZUl6TTKZMRk:EQ:^>OJ24M9=iJX=/GW9NDV1?AD`o>3L_:R8N6a4@3P81
0@0000/<2aDF5P027b4Q00XY;2/a=CDi?Si1AdM8Ce1?EeQEGemKIVMQKFiWM7HJoooo00Y?J79AJ75B
JG5CJG1DJ6iEJ6eFIV]FIFQFHfEEH642E5eM01AEGUaHH5iMI69SJVQ[LFibN7AjOg^4RH>>ThbHWIJS
YYf[[J>b/jVi^Jfo_[74`[C7a;K:a[O<aKK;a;@2b/6b01G8_Zk6^Z[3]ZJo/J6iZi^aXiBYVhbPTXBE
Qg^8Ng1hKV=XGeIHDDU6@C`d<BhS8B0E51<81PD61@D@4A8H71d00R0V:00:9blb;CLk<Si3=dE:>d]A
?e1G@UIMAEYSB5mXBf=]6_ooo`0:>eEW>U5R>4iN=TYI=4IC<D5=;Sa7:SHo9Rlg8BP^0Q`P900D71lR
92HX;Bla>3TkADE7D51AFeaLJ6QXMWIfQ8B3T92?ViZHY::P[:ZW];6]^KJb_[Ze`[fgaKjha[fg0/Fl
]@0EaKZc`kN``KB/_:nW]ZVQ[j:JYYVCW92:TXN1QG]fMfiZJF5MFeAACDM5?STh<B`[9b4P7ADC71@B
8b0P:RT[008_<CD02S<h?SHnASU3C3Y7DSa;Eca>Fce@GceCHSeEICeFJ1coool001[oool02X^:RI:@
SiRFUInLVZJRX:bXY[>^[;Vd/L2j]lO0_@;=a/805=C;b=36`l_2_/No^l>k]l6h]<6h/l>i/lBi//Fh
/LVi/<Vh[/^h[/bh[Lbg[LfgZlfeZ/bcYlV`Y<J/X0;3ZId05KjTUk^PTkJKS[>FRZf@Q:N:OZ:4N9an
LY9eJXAZH7IOEFEBBU=4?T0f<BdW9A/I5`P920@41@h>3QLG5b4P8002:bXY00Xd<c<n?3a6ADA?CDeG
EUEOGUeWIVE^KFafMGAmO7/Joooo00YaOh5eQ8EjR8QnS8b2T926Ti>:UiJ>VYVAWIbEX9h2Uj:Q01BK
YJ>IXYnHXIjIX9fJX9bLXIbPXijUYj6ZZZ>_[JBf/:Ji/ZJm]:S1]ZW3]j[6^:W7^:W8]jO6]:G4/J42
`JjN01FmZIVjYIFfX92aVh^[U8FTSGjMQgRFOg6;MVQnJUi_GU=ND4M;@CXh<RdW8b0E5A<410@00009
2PXB51@K7Qh00R@W9`0:;C4a=CXj?492@dY:BU9BD5UJEV1QG6MXHVi_IgEf6_ooo`0:CfQbD6QaDFQ`
DVM_DfM]DfI[DfAYDf9VDV1RDEaN0TmHF@0DCeEED5IDEE]IFV1NH6ISIfeYL7EaNGiiPXJ0Rhn7UIN>
VifDXZ>IYjRN[:fR/K2T];:U]k>V]k:U][2R0[B^X00E/Z^L[jNIZj:DYYb>WiF7Uhf1THIjRGibOWAY
LVUOI5aDE4i8@clj<S0]92<Q5QHE1`H60`8230`=4aHG6b0R008R:B`02RPa=Bhi?C=0ACM6C3]<DSmA
F49FGTEKHdQOJ4]TKA[oool02S]EIcUAHSM>GSE:FC=5Dc11CBdkARTe?bD_=b0W;@8J7B8051HF6QTJ
728S92`/;SHg>492@di>CeUJFVEVIG9aL7elNhN6Q8n>S9JETifLVZ>QWZRTX:bWXjfXXjfWX@:]YZ00
5JbTWJZQVZJMUZ6GT9ZARY>9Phb2O8AkMGYaKG1WHf=LF5I?CDM2@3Xe=2l[:BDQ7aXC4AL@3QdI6B<R
8bTZ;@02;C4f00Xa>3hd?THg@T`iAe4jBUHkCE/lD5hlDV8mE6DmEVPLoooo000Joooo00Z:RHR@ShjF
U9>LVYRRWifXYJ:^ZZNd[jbj];6o^KH2aKjj01C9`[k:`[k8_k_4_;S1^;Bo][6m]:no]Jo0]Jk0/jc3
]:c2/Z[4/ZW3/JS4/:K3[jC2[J;0ZZ2mYibiXiT2]Z2E01F`VY2/UXbVT8JSS86LQWbGP7NBNg6;M6^0
JV9bGeQSDdeCAd92>SHa;BXP7ah?4A461`L?3`lH61PQ820Y:BT00S8a<@0:>cXi@d91BdY9De9AFeUI
HV5PJFQWL6m^MgIeOWel6_ooo`0:L7n0M8>4N8J7O8Z:P8f=Pi2@QY>CRYJES9RGSiZI0i6KVP0CTIZI
TYZHTiZGTiZGUI^GUibGW9nIX::KY:BLZZJM[JRN/JZO/j^P]JbP]j^O]jZN]ZVL]:NI/ZBF00:_X9<0
5JZLSZJGRZ2AQ9b<OiF5NHmoLhUiKH5aIgIWGVMLDeQ?B4Q2?3Pd<2LV91HH5`L:2`010PP:2Q4C4aTL
724U9@02:Bh^00Xa=SHh?SloATM6CTi<EEEBG5aHHV=MJFYRKg1WMGLJoooo00Y>J75?Ig1@IfmAIViA
IFaAI6YAHfQAH6A@GV5>FU`2C5EF01A7CTe5BTU:Cde@EE=FFeUMHUmSJ6E[L6]bMg5jOWR3QGj:S8B@
TXZEUXjIVY6MW9>OWIBOWY>PWY>OW942WIZ?01FJUh^GThNASH:<Qgb6P7EoNFmhLVU`JV9VH5UIEDm;
B4<m>cL_;R/P8B0B51<61`P20P<92@X@4Q@G6adM92L00R@/<00::S@h;c]0<d57>4M>?4eD?e9I@UMO
AE]TB61YBfA^6_ooo`0:>eEW>E5R=diN=DYI<dEC<45=;C]7:CI092lg7bL^0QTN8`0D414D3@`>5ADF
7alP:RTZ=3@d?ShnAdQ7DU9AGEeLIfMULW5_NWUhPGmoQhF4S8Z8T8f;THj;Ti2<U92<0YB?RP0ETXf8
ShZ5RhF0QGmjP7UdNG9]LVaXJfAQHE]IEe9?BdM5?c/i=30^:BDT7AXI5A0@50l>61@D7Q`M8b@V:2/`
008/<SP02S0h@3<nASI2C3Q6DSU:ESY=Fc]@GSaBHSaDICeFJ1coool001[oool02XZ9R8n>S9BCTIZG
UYnLVZBQWjVVXjjZYk>^[;Rb[`:l][<05<2i]/>k^<>k]l2h];je/KZb[[V`ZkV`Z[Z_Z[Z^Ykb^Y[^/
Y;Z[X[ZZXKVXWkNVWKFTV[BRV;2NUJbJT@:XUhh05J>BRIj<Q9R6OY>1N8akM8UhL8AbJg]ZHfmPFf9F
DEA:AT@n>cDb<2HV9ALI6@`=3Pl?3aTI6B8Q8BXY:C8a<@02>STi00Y1@D19B4M@CdmGEUINGEaUI6=[
JVYbLG1hMgInOGdJoooo00Y`OX1cPX=gQHIjR8QmRh^0SHf3T926TY:8U9>:UI@2RiJE01B;UYB;U9>:
U9:;Ti6<U96=U96?UI6BUi:FV9>IVI>MW9BOWIBQWYFSWYFUWYBTWI>TWI:TW96RVXnPUh`2WI>801FH
ShBCRGn>Q7V8OG9oMVekLVUfKFA/I5aPFE=DCTU6@chg=S<X:BPJ7A`=41031@D61`L@4Q<H71`P92DX
;2d00Rld=@0:=S`m?D=4@d];BE5BCeQIE5iOFFAUGVY[Hg1aJ7Ig6_ooo`0:CVMaCfM`CfI_D6I]D6E[
D6=YD65WCemTCUaPC5QK0TUDE@0DATi>@DI6?dA2A4U7Be1>DEIDEeaIGF9NHfMSJFeXL7=]MWUbO7ig
P89kPhEmQHIoR8R1RHZ2RHZ1RHV00XN7OP0EQ8AkP7mgO7YaMG9YK6YRIfENHV1IFEMBCDe8@d8o=cLe
:R/Z7AlN4Q@D20T90@0010<33@l@51PJ6b4T8BT/008V<3D02R`g?30n@cE4BSU9D3a>ET1CFd=HH4IL
IDQPJD]TKQ[oool02S]EIcUAHcM>GSE:FC=6E311CRdlB2Tg@BD`>B0Y<08J82H051<F6P/:30P71a4@
41`L72HV9bl_<3Lg>3lo?dQ8Ae5AD5YJFF9RHFQXIfe]K75`L7EdLgUgMWYiMg]jM`9kNGH05GYgM7Md
LGA_K6aXI6APG5mKF5UGE55?CDQ5AClm?3Ld=2`Z:R8O7aXG5Q<?3@l81A8<2QTG5alO8B@V:RP]<`02
;3@k00X`>D8c?TPe@dhgAe<hBULjCE/kD5lkDV8lE6DlEVPLoooo000Joooo00Z:RHR?SXbDTi6JUiJO
W9ZTXInYYZ>^ZZNc[Zbh/Zl2_;Jc01C0^KK3^kS3^kO0^;Bn]K6j/Zji/:^i/:Zj[jZj[ZNl[ZJk[:Bj
Zj:jZZ6iZ9ngYYfeY9ZdXYR`WYF/VY42Z9N>01FSTXVNS8BHQWjCPGR<NgB9N724LV]kJV=_H5]REU5D
BTI4?S/e<S0V9RDG6AT<3@h?3`lI6ATR8B4Z:BTb<C400SXi>@0:@D50BDQ7D4m?EeIFGUeLIFASJfYZ
LW5`N7MfOWem6_ooo`0:L7j0Lh:3MhF6NXR8OH^;P8f=Pi2@QY:BR9BCRYFD0X^FU@0DRiJDRiBCRYBB
Ri>AS9BASIBASiFATYNBUYRCVIVCWIbDWifDXIjEXijEYIjDY9fCY9fBY9bAXYZ?X9N<0YfCR00EV8n4
ThUoSXAiR7ebOgI]Ng9YMVeTK6ALH5UCE4i9AT<n=cHc:2TX6QdL3A0@0`D51PL7418C61`L82@U:2`]
008_=3D02SHl?Ce3A4=;BdUADTmHFEANGeUTIEiZJf=`LFQfMa[oool02TiWLDmWL4mVKe1VKE1UJe1S
JE1QIdmOI4iLH4aHF`99E5D054I>CT56ASm4@TA9Ad]@CU5FE5MLFEeRGV=WHfU]J71cKGIiLWanMh22
Nh>5OHF6OhR8PHV:PXV:PHV9P0:7Qgh05HB4Nh1oMgajLGEbJFaZHVMUGV9PFEUGDTe=B4=2?cLg=BX[
:QdO7Q8D50P92@4000@30`d?41@H6Q/Q924Y;0029S0e00X/=c``?T<eA4XiBE0lCUI0De]3F616G6E8
H6U;I6hJoooo00XkEFLiDF<gCUheBUTcAU@`@Dh]?4PY=d4U<3TP:C026R0V01@C5QX;2P`81`LA410L
71`V9RL_;c0g=cPo?cm8B4MADE1JFUURHV5XJ6M]KFaaL71eM7=iMgIjNGMkNWL2NgUf01EjMgAgM75d
Kfa/J6ATH5aOFeQIEeAACde8ADDo?C`g=3@/:RXR7alJ5aHC3`d?20DB30XI5aLO7b4T9RXX;C<00R`d
>`0:<3U2<ci8=D=>=dMC>4YG>TeK>e1O>e9R?5AU?5IX7?ooo`006_ooo`0:RHR7SXb;TY6?UiFCW9VG
X9fKYJ6OZJFS[JVV/JbY0[F_[00D^;:^^[B`_;Fa_;Fa^K:^]jnZ]JbW/jZU/jVT/ZRR/jNP/ZFN/:>L
/::J[InH[9jFZibDZ9VAY9F>X9::0Y^=QP0EUhV2THAmRWigQGUcP7E`OG5/Mf]VK65MHeUFEe1<B4A1
>CLf;2`/7b4Q4Q@E4a<D71`L92@T;2`[<c<c>cXj0092@D002TQ8Adm>CUIEE5aKFV9QH6QWIVi]K7Ac
LWUhN7mnOA[oool02VmnOg:1PWF3Q7R6Qg^8RGf;Rh2=SH:>SXB@ShFAT0>6TI003XJ@ShB>SHB=RhB=
RhJ>RhR>RhV>RX^?RXb@Ri2ARi6ARi:ARYBBRYBAR@:DTHP00i>?QY6<Q8j:P@02RhIn01F7PWZ2OWIl
Mg1fLV]aKVQ/J6=UHEaJF5=ACd]6AD8h>CLZ;B`M8B4A5QH62PX72PXA51@I71dQ9BDX;Bd_=3D00SDk
?00:>d93@DU:Adm@C5EFDE]LEV5RFfIXGfa]I75bJ7Ih6_ooo`0:CVMaCVM`CfI_CfE]CfA[Cf=YCV5W
CEiSC5aPBUQK0TQDEP0DADi@@DQ9?450>clm?dE3AT]9C55?DEEBE5UFFEiJGV=OHfMRIf]VJfmYKW9/
LGA^LgI_M7M`LgI`LgE_0W5cK@0EKg5[K6iXIVQSHF=NFeiKE5MDCDm<A4I4>cdl<cDd:2XZ71lP4Q@E
1`T:00000P412``>4QHH6AlR7bLZ92hb008Z=CX02Rhk@C=1AcM7CCY<Dci@F45EGDAIHDIMITUQJT]T
KQ[oool02S]EIcUBHcM>GcE;FS=7EC13D2dnBRXhA2Hb?24[=08L92/051HK80lA5@L61`D410d=3QPH
6B8R8bTY:Rh_;cDf=S`m?T=4AD];Be5ADEEGEUYKFUeNGV1QH69RHF=SHP9SHf405F9RH65PGeeLFeQH
Ee9CDdY:Bd=3@c/k?3@d=Bh^;RHU9QhM7QHD50h;2PX40@d711@B4Q/K7B0S9RDZ;bT`=`02;CHn00X`
>d@b@4XeA4lgAe@hBUPiCE`jD5lkDV<lE6HlEVPLoooo000Joooo00Z8R8N<RhZAShjETi6IUYFMVYRP
WI^TX9jXY:6[YZ@2[ZVV01B`ZjRb[:Vd[ZZf[j^f[Z^bZZJ_Yj:/Y9n[Xij[XIb[X9ZYWYRUVYBSV9:R
Ui2QUHjOThbLTHZHSHNDRX@2ShF001F;PWf6OGR0N7=lM71gL6egKVY`IfAVGUaLEU=?BdU0?chb<c<U
:2PL7QhJ6Q/R8R8Y:BT`;blf=SHm?Ca3@d800TU9B00:Cdm>EEEDFeYJHF1OIVETJfYZL71_MGEdNWYi
Ogmn6_ooo`09KgioLX21M8:3MXB5NHJ7NhR9OHZ:OX^;P8b<00>1SHd058:=S86<Rh2;RGn9R7n8QWj7
QGj6Pgn6Ph67PX:6PXB7PX>6PH:5Oh:4Oh:4OX>4OX>4OH:2Nh20NWinM`9jNW@05GMgLG9bKVi_JVY[
IfEVHfATH5eLFE=CDDU:B3`o?Bdb<R4W9a@K70`B4P/?41@G61/O828W:2T_;blf=SHl?@02>d=300Y1
BDY6Cdm;E5E@FU]DGf1II6EMJFYQKFmULWAYMgPJoooo00Y>Ig5>Ig1>IVm>IFe>I6]>HVU=HFM=GVA;
G659F5`2AeAH01A4D591BT`mADDi?Sdh?3/k@3m0AD=5BTQ8CT];D4a?DdmAEe=CF5EEFUMHGEYKH5aM
HUiNHemOI61NI5l2G69M01EJH5aHGEYFFeUBF5M>De=;D4m4BDPl@40c=cLW;2`L824B5QL830d10`<2
0P<:30hA5QPH7R4N9RXS;C8X=3T00Rdj@00:<D16=DE<>DYA?4iF?e=K@UMOA5YSAeiWBF5[BfE_6_oo
o`0:>eEW>E9T>4mP=TaL<dQG<DAB;T1=:c]79cE08bli0QhX<00C6B4W4aPM3A0C1PD610<42`/<51@E
71dM8R8R9RHV:b/[<34b<cHf=cXj?3lo@DA5ADQ8B4];Bde=00=<Cdl05D]>CTY=CTY=CdQ;CTA6BT13
AC/m?c<e>2`];b8S9AXJ6a<B4``:2`L20@X50a4>3aLH6QdP928W;BH^=2Xd?002;SU200X`?DPc@Tde
AE8gBEHhBeXiCUdjD60kDV<lE6HlEVTLoooo000Joooo00Z8QhJ;RXV?SHbBT8nFTi:IUYFLVINOW9ZR
WYbUXIh2Yj>P00>YY::[YZ>/Yj@00ZjXY00?[JJRZZ>NYYnJXibGXYZEXYVDWiNAW9B>VY:<Uhn:UXf7
U8b6THV4SHJ0RH9n00:4OWX05H5kN7]gM7UdLG5^K71/JFeXIVAPGeaIEe5?CTE5ACXk>bd`<B<V9R@T
92TY:Bl_;cDe=C/k>d51@DM6ATa<B`02DU5A00YGEUILFeYQH5mUIFAZJFU_KVecLW9gMgIlNgZ0OglJ
oooo00Y_OGmaOh1cPH9ePhAgQ8EhQXMjQhQkR8UlRHUmRXX2OXZ900mnRHUmR8QlQhIkQHAiPh9hP7mh
P7igOgagOW]gOWYhOWUgO7QfNgMfNgIdNGD00WAhL`03LgMbL7E`KW9^009[Kf`05FQ]JVAYIV9WI5aQ
H5YOGEIKFDeCDTE:BSY1@Bhf=bD/;ATR8a4G618G5aPM7R0U9RH/;B`c<c8i>SPo@3e5AP02@TY;00Y7
D51;EEI?FEYCGUmGHfAKIfQOJfaRKg5VLgEYMgTJoooo00Y>Ig5>Ig1>IVm>IFe>I6a=HVY=HFQ<GfE;
G699FEh2AeIJ00e5DUE2CE0nB4Tj@T8e>STd>3Hg?C/k@ClnA450AD=1AdA3BDI5BdP00TM>B`05B4m<
BU5>Be=@Be=@BU9@0099DE005DQAD4I>CTA=CD5:Bci7B3Y2@c8j?2Xb=28Y:aPO8A4F60T>40851P@5
1P/>418H6QTP8alW:b@^<bTe>Rdj@002<D1600XeAD/hBE0kCUDnDUU1EEe3FF55G6E8GfQ:HVa<IFlJ
oooo00XkEVPjDfDhD64fCEddBUTbAUD`@U0]?T/Z>DDV=3h28Rhg01@M9blH82LB61d<3a<510D30P8:
2P/B4Q<G61PJ6a/M7QhP8R8U:2PX;2`Y;Rh/<34_=3Dc=cTd>C/e>S`2=c`n01Dg?3lf?3hf?3le>clb
>3`]<cLV;30P9BTI7B0B51L=3Q0920T50@470`8?3@hF5QTK7b<P9R`U;C@Y<S//>4400RllA`0:<D1<
=4A@=DMD=dYH>4eK>DmO>U5Q>e=T?5EV?5IY7?ooo`006_ooo`0:QhJ5RXV8SHb:T8j=Ti6?UI>BV9FD
VYRFWIZHWi^I0Z6MV`0DXYjLY9nMYJ2MYZ6NYZ2MYYnLXI^GWiVEWINBW9F@VI:=UHn:TH^7SXR4SXR3
SHJ2RHAoQH5mQ81lPGej0WejN00ENWMdMWAcM75`K6][JfYXIVATGeiMEeIEC4e=@TA4?3dm;S0`;Rl^
=3@d>3Ph?Cdm@T92AdM7C4a;DE1@EEED009JFET02UiNGF9RHFIVIFYZJFi^KG9aLGIeM7UiN7emO860
Oa[oool02FimOW1nP7:0PG>1PWF3Q7J4QGN5QWR6QWV6Q`03NXN7015jQXIjQHEiQ8AgPX9fP7mbO7]]
MgE^MgE_N7E`N7E_MW9/Lg1XL6eWKfaXL6aYKfaUKFX00V9[J@0HHV]XH6UWH6UWGVIUFfATFV9RE5eM
DU]KC5EFATi??TI7=3dn:S@f92d^6B4R6R0Q8BLX9Rd^;3<d<CTj=Sho>dA5@4U:A4e?0TUBD`0:CEIH
D5]LE5mPEf=TFfIXGVY[HFi_I75cIgEfJWQj6_ooo`0:CVMaCVM`CVI_CVE^CFA/CF=[C65YC61VBeiT
BE]Q0TMHG@0DAEAI@e1D@4a??4M9>411<SPh;C8`;cDd=C/j>D0n>D0m=chk=C`k=Sdl>D0o>d=1>D91
=d51>DA4?4I70Sa7B00E>dI8>TI8>TE8=d96=D13;c/n:C@g8R`_6R<V4Q/N3A@G1``=2@`=41DG5Q`P
6b@X8B/_9S4f:SLm;Sa2<T58008eATd02SQ:DC]>ECiBFD1EGD=HHDEKI4MNIdQPJTYSKDaUL1[oool0
2SaFJ3YDICUAHSM?GcE<G3=9F355E2m2Cb`mBRTiA@8V=3l0528^>1dX<APQ:1<I7`dA5@@61`0000@5
1@h?41@F5aDH61DG5a@G61HJ6aXN7ahS91dS9AdS9R0X;2D]<@8X<3@05BP`=BTa=RTa>2Ta=bL_=B8Z
<1`T:QLM8Q4F6P/@4`P:3@L51PT71a0@4QDH71/P9B0W;R@]=BPc?2/h@RhlA`02<D1<00XcA50eAe@f
BEPhC5/iCUhjD60kDV<kE6DlEFLlEfTLoooo000Joooo00Z7QXF9R8N;RXV=S8^@SXfBT8jDTY2FTi:H
UI>IUYD2ViRF00>LVINMVINNVYP00YjJU`0?WIVEW9NCVIBAUi:>Thj:T8Z6S8R4RXJ2R8B1Qh>0Q81m
PWmlPGmmPGmlOG]i009jNGP05GQfMGEdM71_Kfa/JfMXJ69SHeaLG5ADE4e>CTE6ASln?STj>Sm0?dA4
@dQ7Ada;Be1?Ce=CDeMGEU]KFUmNGP02HV9Q00YVIFAYJ6Q/K6]_KficLW5fMGAiN7MlNgYnOWf1PH0J
oooo00U^OGi_OWmaOh1bP85cPH9dPX=ePhAfPhAfQ8@00gN4Q00DMh>4MX>3MX:2M820LgimL7]jKGMf
JG=bJ79`IW1^IFi/Hfe[HV]YHF]YH6YXGVQWGFQWGVUYGfYYG6MW0U]VI`0EFVEVF6=UE5mPDEaMCEQJ
B59D@D]=>T=4<cdn;CDf9Rd^8bX/:S8c;cLh=3`m>D52?DI7@DY;ADi@BE9DC5IH009@FU/02U=NGeIQ
HUUTIU]WJEiZK65]Kf=`LVIcMFQfMfYiNQ[oool02TiWLTiWLDiVL4eUKdeUKDeTK4aRJTaQJ4]OITYM
I098Ff402dIHGDADFD9AECm<D3]7BSM1@c8j?2dd=2`c<blf=S0h>002<3Th00L`>ST`>SX_>S/`?3hc
@48d@D@d@DD00SE2A`0E=TA8=T=9<d15<Ci3;S]0:CDj8bhb72LZ5b4T4a/M3Q<E3Q<F5QdP6b@X82/_
9C4f:CHl;Ca2<D17=4E;=dU@008jC5@02Sa@EcmCFd5FGT=HHDEKI4IMITQPJDURJd]TKTaVL1[oool0
2SaFJC]EIcUBI3Q@HCM>GSE;Fc=9F356E2m2D2doC08Z>TL052Hf@B<a>al[=AXU;ADN9A0F70X>4P@6
2@@620X=3`dB510D5A0E5Q8G6A8H6a8J7ADN8aPR:1/U:a`W;P8O:C805B8]=R<^=b8/=24[<alY<1/T
:aHN914G70dB5P/?4@L82@X;3A8E6APM8QdT:b4Z<RD`>BPe?b/iA2hnBC51CP02<dAA00XdAeDfBUPg
C5/hCUhiD60jDV8kDf@kE6HlEVPlEfXLoooo000Joooo00Z6QHB8QhJ9R8N;RXV=RhZ>SH^@SXfAShjC
THnDTY02UI:A00fFTi6GU9:GU9:GU9:GU96FTi2ETHnCShfASHZ:QXB7Q826Q863PGl00X5oO0:0Og`0
0h1nO7elNWYiN002NGQg01EdM7AbLW9^Kfm[K6aWJ6QSHf9OGUeEEEEAD51<C4a;BT]>CTiADE1DE5=G
EeIJFEUMG5aPGemRHV9UIFAXIfL00V]ZJ@0:KFe/L6m^LW9aMGAcMgIfNGUhNg]jOWelP7moPX:16_oo
o`06KWanKgeoKgioL7n0LGn1LX210W>1PPEdPH803gB1PG>0P79nOg5mOFmjNVahN6UeM6E`L5iYJEaW
IUeYJ5eXJ5]VIEYWIU]WI`02G6QX01UKIfMIIFIHI6EHI6EEHF=CH69AGEm>Fee;EeU8DE=3CDhkA4De
?Slb>S/b>S`g@44kA4DnB4U2C4e5Ce59DeA<EUQ?FE]AG5iDGf400UMRI00:FFEVFfMYGVY[H6a^HVm`
I75bIG=eIgEgJGMiJgUk6_ooo`0:CVQbCVMaCFM`CFI_CFE^CFA]CFA/C69[Bf5YBUmW0TUNI@0=B5]R
AUUOA5IL@U9H?dmC?4Y>>4E9=413;STl:38d9c4c:cHh;CTk008[>3T01Bdk?Bln@C50@c50@c0oA002
<3m50RlnA00C;Se3;C]1:cPm:3<h92hb7RLZ61lR5A`O6B4U7RT]8bld9cDj:cY0;ci5<T99=DI=>4YA
>TeE?51H008nDe/02T1EGT9HH4AJHdELIDMNIdQPJDURJdYSKD]UKdaVLA[oool02SaGJS]FJ3YDISUB
I3Q@HCM>GcE<GCA:FS97Ec15D`8^@Dl052`nBbTjAbHf@R<a?1l/=Q/V;aHP:14J8@XA5`H;40D;40/B
5`lG70lG6`lH714L8A@P9QPS:QPT:aPU;@8I9Rl05AXV<1/W<A`X<A`W<1/T;AXP:1HM8a8G70`?4P/=
4A0E6QLN91`U;20[=2@`>RLe@2XiABdmBC11CS94DC=7E@02=DUH00XfBeXgCEdiCeliD64jDV<kDf@k
E6HlEFLlEVTmEfXLoooo000Joooo00V5Q8B7QHF8QhJ9R8N:RHR;RXV<RhV=RhZ>S8/00hn=S00@T8j<
T8j=THj=THj=THj<T8f<Shb:SX^9S8V7RHJ4QhB2Q8:1OWelOWakOgilOWek0WmmN`0IOG]jO7YjNWUh
NWUhMgIfMGEeLW9bL71`KFa/I6ATHF5QGEeMGUeMGeiNGemNH61PHV9QI6ASIVIUJ6QWJVUYK6][KVe]
L6m^LG5`009cLg802WEdM7MfMGQhMgYiN7]kNWelO7inOH1oOh61P8>2PQ[oool01VekOFilOVimOVmm
Og1nOg1nP0MaOh004g5oOg5nOg1mOVmlOFijNfaiNFYfMfMcM6A`LF5^KUi[K5YVJ5YVIe]XJEYWJ5]X
IeeYJEaXJEaXJP02FfMY01EHIFMGI6IEHVADH69AGEm9E5E5Ce52C4i4CU16D557DE=9E5E;EUQ>FEY@
FeeBGUmEH69GHVAIIFIJIfQLJFX00UiZK00:Gfa^HFi_HW1aI75cIG=dIgAfJ7IgJGMiJWUjJgYl6_oo
o`9>Ig4024eWLDeWL4eVL4eVKdeUKTaTKDaSK4]RJ`9;HFT054YOIdQNIDMLHdIIH4AGGD5DFSm@ESa=
DSU9CSI5BS=2Ac0nA2dk@Bhl@S0n@bln@S0o@S92ACA4B3E5BP8dAD/05CA4Bc=3BS93BC92BC0oARTg
?2@`=2<^=2Hc>2Tf?2/i@2hnA352B3A5C3I9D3U<E3]?EceAFCmDG41FGT9HH@02@eYS00Y5G6E6GFI7
GfQ8H6U9HF]:HVa;I6i;IFm<IW1=Ig4Joooo00XlEfTlEVPkEFLjE6HjDfDiDV<hD64gCelfCEddBe/2
<dUH01@aAUH_A5<]@Dl[?T/Y>TLV=d<S<chO;STL:C@I9S0G8bdC7RTB7BHD7bTE8BXE8BTF8RXI9RhM
:S<O;3H27bdh01DO;STO;CPO;CPP;STO;3HJ92dD72@E7BDI8b/L9c0O;3DS<C/V=D4Y>TH/?DX^@4h`
@e4bAU@dB5LeBUXfC5`00SM>GP0:>4mP>E5Q>U9S>U=T>eAU>eEW?5EX?5IY?5MY?EMZ7?ooo`006_oo
o`05QHB3QHF4QXF4QXJ5QhJ500:8QhH3RHR70XZ9Q`F:RHP02XZ9QhZ8QhV7QXR6QHN5Q8F4PhB3PH:1
P860Oh61O`:1P7l00h1oOWalO7]kN`02NWYi00MhN7QgMgMfMWIdM7AbLW5_KfibLG400W5aL09bLG40
2W9bLG=cLWAdLgEeM7IfMGMgMWQhMgUhN7YiNG]jNP9lNgX02WelNgemO7inOGmnOX1oOX60Oh61P8:2
PH>2PHB3PQ[oool016ekOFelOFelOVilOP9^OGh6Kgeo0fmmOP0:KWamKW]mKG]lK7YkJgUjJWMhJ7Ig
IgAfIG=dI79c0V=aLP05Hg1bHg1aHFi`GV]^GF]]009LJF`01U]XJUYWJEUVJ5MUIeIRI5AQH`9HI6H0
3EQUIUUUIeYVJ5]WJEaYJUeZK5i[KEm]KV5^Kf9_L6=`LV=aLfAbM002IG=d00YVM7EWMGIWMGMXMWQY
MgUZN7UZN7Y[NG][NWa/Ng`Joooo00=>J79>Ig9=Ig400deWL@9=IW0044eUKdaUKTaTKTaTKTaTKD]S
K4YRJdUQJDUOJ4MNITILI4EJHT=HH49GGT1EGCmCF`<nDUX01CeAFCe@F3Y>ESQ;E3Q;D`02=dYB01Dg
BU4fBE4fB50eAdhdAD`eAdhhBe8iC5@jCEDkCeLlDETnDe/oEEe1Eem2F653FV=4FfA5GFI6GVM7GfQ8
H6T00TQQJP06BF9[BV9/BV=]BfA^BfE_C6E_0TaVL003CFMaCFMboooo01Woool02SeGJSaGJSaGJCaF
JC]EJ3]EIcYDISYCICUBI3UAH`8hD68033M?H3I>GcE=GCA;Fc=9FC57Ec15EBi3DRa1D2/oCRXmC2Pl
BP<X>dX01BPjBBLiAb@fAB<e@b<d@P048cA101<R<d0R<ShR<SdU=T8X>TLZ>dT[?D/]@4h^@U0`A5<b
AeHcBEPdBeXfC5`gCUhhCf0hD64iDF8jDV<00SYCI@0:>eAU>eAV>eEW?5EX?5IX?5IY?5MY?5MZ?EMZ
?EQ[7?ooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool004Koool30000FOoo
o`<0001Joooo0`0005[oool30000<Oooo`00BOooo`030000oooooooo05Woool00`000?ooooooo`1J
oooo00<0003oooooool0F_ooo`030000oooooooo02koool002Soool400001?ooo`030000oooooooo
00;oool200001?ooo`@00002oooo0`0000?oool300000oooo`80000eoooo100000;oool300000ooo
o`@00003oooo100000;oool300000oooo`<00003oooo0P0003Ooool200000oooo`D00002oooo0P00
00Coool400000_ooo`<00003oooo0`0000?oool20000=oooo`800004oooo0P0000Coool200001?oo
o`@00002oooo0`0000?oool300000oooo`80000[oooo000Xoooo00<0003oooooool01Oooo`050000
oooooooooooo000000;oool010000?ooooooo`0000;oool010000?ooooooo`0000Goool010000?oo
ooooo`0003[oool00`000?ooooooo`05oooo00D0003oooooooooool000001Oooo`040000oooooooo
00000_ooo`030000oooooooo00?oool010000?ooooooo`0003_oool010000?ooooooo`0000Coool0
1@000?ooooooooooo`000002oooo00@0003oooooool00002oooo00@0003oooooool00005oooo00@0
003oooooool0000koooo00@0003oooooool00002oooo00@0003oooooool00002oooo00@0003ooooo
ool00002oooo00@0003oooooool00002oooo00<0003oooooool00oooo`040000oooooooo0000<?oo
o`00:Oooo`030000oooooooo00Coool01@000?ooooooooooo`000002oooo00@0003oooooool00002
oooo00<0003oooooool0100000;oool010000?ooooooo`0003_oool00`000?ooooooo`03oooo0`00
00?oool00`000?ooooooo`02oooo00@0003oooooool00002oooo100000;oool010000?ooooooo`00
03goool00`000?ooooooo`03oooo00<0003oooooool01?ooo`040000oooooooo00000_ooo`030000
oooooooo00@00002oooo00@0003oooooool0000moooo00<0003oooooool00oooo`050000oooooooo
oooo000000;oool010000?ooooooo`0000;oool00`000?ooooooo`0400000_ooo`040000oooooooo
0000<?ooo`00:_ooo`030000oooooooo00Coool010000?ooooooo`0000;oool010000?oooooooooo
o`<00003oooo0P0000Coool40000>oooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool00_ooo`<00003oooo0P0000Coool40000?Oooo`030000oooooooo00;oool0
0`000?ooooooo`02oooo0P0000Coool300000oooo`800004oooo100003goool00`000?ooooooo`03
oooo00@0003oooooooooool200001?ooo`<00003oooo0P0000Coool40000;oooo`00:?ooo`040000
oooooooo00000_ooo`040000oooooooo00000_ooo`040000oooooooo00001Oooo`030000oooooooo
04Coool010000?ooooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`0000Goool0
0`000?ooooooo`15oooo00@0003oooooool00004oooo00<0003oooooool00_ooo`030000oooooooo
00Goool00`000?ooooooo`15oooo00@0003oooooool00002oooo00@0003oooooool00002oooo00@0
003oooooool00005oooo00<0003oooooool0>_ooo`00:Oooo`800003oooo100000?oool200001Ooo
o`800017oooo0P0000Coool300000oooo`800005oooo0P0004Soool200001?ooo`800004oooo0`00
00Coool20000B?ooo`800004oooo0P0000Coool200001Oooo`80000loooo003oooooTOooo`00oooo
oi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooo
oi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`006_oo
o`04Xi6;Xi6:Xi6:Xi6:1J:@RP04XY29XI29XI29XI291:6?R@BPShP2X8n900JPShZPT8^OShVPSXRP
SXNPSXP5X8f700NPSXNPSHNQSHNPSHNQSXNPSHNQSHL00Z2<QP04X8b5X8^5X8^5X8^40Yn:P`06WXV2
WHMoWXV2WhZ3Wh^4X8b50j2<QP09XHf6XHf7XHj7XHj8XXn8XXn9XY29Xi2:Xi6:01[oool7UXj;2iF>
S009UHj=U8j=U8j=U8n=U8n>U92?U96BU8n>U8j=00:DSX`00iB=RiF>S9F>S004UHj<01>FSXbESXbF
SXbESHZES8ZERhVDRXRDRXNDRHJCR8FCQhBBQX>BQH6APgn?P7^AQ82BQX:BQh>CR8D00Y>9Q@06ThV6
U8V6U8Z7U8Z7U8^8UH^80YF<R@03UHf:UXf:oooo01Woool3T8^:0Y2<RPF@S8/6T8f<0Y2=S@:@SXd2
T8j>00N@Shn@T92@TY>?Shn?SXf?SHb@SXd00Y2=S003T8j<T8j=T8j=00>ASXd2THj<00BAS8^AS8Z@
RXV?RHL2ShR600Z>QhF>QH>=Q86<Ph2;PGf9OGV;PGj<Ph6<QH:=QX<3SHN400F>QhF>R8J>R8J>RHN?
RHL00Xn:R003ShZ9Sh^9oooo01Woool2S8V800><RXR<RXV<RXT00Xb:R@03S8^:SH^:SH^:00:=Rh/3
SHb;00>=S8b=SHb=SH`00Xf=S@0<SHj=SHj>SHn?SHn@SY6CSHn?SHj=SHf<SHj=SHf<SXf<SXf=0hj>
S@:?SXd2Shj<012?S8Z?RhZ>RXR=RHN<R8J<QhF<QXB;QH::Ph29PGn8Og^5O7N8P7f9PWn9Q86:Q883
RXF300F:QXB;QXB;QhF;QhF;QhH00X^8QP03RhR7RhV7oooo01_oool001[oool01J>ARj>ARZ:@RZ:@
RZ:@R@03XHn900ZPShRPSXRPSXRPSXROSXROSXNOSHNNSHNNSHJNS8H3WHb600JLS8JLS8NLSHRLSXZL
S8NLRhD2W8Z40if:Q0:MRH<00ib9Pif9Pif9P`03WHV300nNR8:MQh6MQh2LQWnLQGjLQ7jLQ7fKPgbK
PW^JPWZIPGVJPW^KQ7bLQGjLQWl00Yf8P00:WHR1WXV2WhZ3Wh^4X8b5X8f6XHf7XHj8XXn9Xi2:6_oo
o`:FSX/00iJ=RiF>RiF>S004UHj<00BESXfDSXfDSXfDSXd2U8n=0YB?SP:CShh2Thn?00JBT92BT96B
TI:BTiFBTI6BShl2TXj=00>CSHbCSXfDSXd00YB>S00EThj=U8j=UHf<U8f<U8f;U8^9U8Z8ThV6TXN4
TXJ3THB1T8=oT85mSgmkSWehS7YdRWQbSGagSWmjSh5lSh9n00:@Q8002Y64PI65PY:6Pi:7Q9>8QI>9
QYB:QiB;R9F<RIF=RQ[oool0192;RY2<RY2<RY2<R`:@SH/2T8f<192>S@04T8j>T8n>T8n?T8n?0i2@
T00=T96AT96BT9:BSi:DSiBFT9JHSi>DSi6ASi2@T92@T8n?TI2?TI2@00:BT8l05I6@Si:@Si>@Si:?
SY:?SI:=Ri:<RY29Qhn8QHj6Phf4PXf2Ohb0OHYmNHQjMXMgLHAeKhMjMHUmNHYoNhZ0O@02Rh9o00Z;
Ph2<Q86<QH:=QH>=QXB>QhF>R8J>RHN?RXR?RXTJoooo00Z<RHR<RXV<RXV<RhZ=RhZ=Rh^=S8^=SHb>
SHb>SXd3SXj>00>>Shn>T8n?T9000XnAT@09Si6BSi:BSi>CSi>DSiBFSiFGSiNJSYBFSY>C00:?TY80
0hnATI2ATI6BTP03TI>B01BBTi:BTY6BTY2BTHnAShfASH^?RhV>RHN=QhB<QH>;Ph2;P7f8OGV6NWJ4
MW22M6j5NGB6O7R7Og^8P7d2RH5n00J9PWn9Ph2:Q86:QH::QH>:QX@2RhN500>;R8J;R8Ooool06ooo
o`006_ooo`03Xi6;XY6:XY2:00:QShT01J2?RJ2>R9n>R9n=Qij=Q`02WXb60Yf<QP06W8b5W8^5Vh^5
VhZ4VXZ4VXV30YV9P`06V8V4V8Z5V8^7V8V3V8R2V8N10YV7P@03VXJ0VXN1VXN200:JQh8059^7PI^6
PIb6PIb6PIb6P9b5Oi^3OIZ1NiV0NIQoN9MnMiMmMYMlM9IkLiIjLIIkLiIlM9MnMIQoMiV1N@:JPWX0
2YZ3O9^4OIb6Oif7P9j9PYn:Pj2<QJ6=QZ6>R::@RA[oool00iJ>RiJ>S9F>S003UHj<00>ESXfDShfD
SXd00iB?SP:CShh2Thn?0i:@T008TI2@TI2AT92BT96CT9:ET9BGSi6CT8n@0Y2>SP03THj=TXj=Thj>
00:CShh05I:?SY>>SYB=SIB=S9B<RYB;RIB9Qi:6Q964PHn2Ohj0O8emNHakMX]hLhUeKhQaJXQcK8Uf
L8YiLh]kMXamN002SGmj00Z>P7b?PGf@Pgn@Q82AQX:BQhBCR8FDRXNDRhRES8TJoooo00N@S8Z@S8^@
S8^@SH^@SHb@SHf@SXd00Y2?SP04T8n?T92?T92?T92@0Y2AT@0=T9:BT9:CT9:CT9>DT9>ET9BESiFG
SiFHSiNJSiVMSYFHSiBESi:C00:@TY806I6BTY:BTi>CTY>CTY:CTY>CTYBBTIB@Si>?SY>=S9:<RY69
QXn6Phj3P8b1OH]nNXUjMXMgLXEcKH9^Ih9_JHAcKXIgLHMiMHQkM`02RGei00Z9Og^:P7f;PGj;Ph2<
Q86=QH>=QXB>R8F>RHN?RXPJoooo00V<RXR<RhV=RhZ=Rh^=S8b>SHb>SXf>Shj?Shl00hn@T00DSi6A
T9:BT9>CT9BDT9BET9FFTIJGTIJHTINITIRJT9VLT9^NT9bQT9VLT9RIT9JGTIJFTIFETYJFTiJF0YBG
UP0ETiNFU9NFUIJEU9BCTi:@Ti2>TXn<THb9T8V6SXJ3SH>0Rh1lRGahQgQcQ7A^PFiWPFmYPgA^QGMb
QWYfQgah00:7OWX02XQoO8R0OHV1OXV2P8Z3PHZ4PXZ5Ph^6Q8^7QH^8QQcoool001[oool02Z>ARZ:@
RZ6@RZ6?RJ2?R9n>R9n>Qij=Qif=Qif<QP:LS8D059b;QI^:Q9Z:Q9V9PiV9PYR8PYN7PIJ7PIJ6P9F6
P9B6PIB6PYB7PiB5P9B4OiF4OYF3OIJ3OIN4OYR5O`:JQX42VXN201>KQX6KQGnKPgjKPWbJPG^IOgVH
OGNFNgBENW>DN76DMfnCMFfBLfZ@L6NBLfZCMFbCMfjDNG6ENg<00YImM@0:V7mgVH5iVX9kVhAmW8Io
WHR1WXZ3X8b5XHf7XXn96_ooo`06UXj;UHj<UHn<UHj<UHj=U8n=0iB?SP04Ti2?Thn?Thn?Ti2?0Y:@
T00ATI2@TI2ATI2AT92AT92BSi6BSY6CSY:DSY>FSYBISI6DSI2ASXj?SXf>Shj>T8j>TXj?00:CShl2
Ti2@01>EShnDSHbDRhZDRHRCQhFBQ8:@PGj>OW^<NgR;N7B9MFn8LV^5KFJ3J624K6F6L6V7Lfb8MFn9
N7800XYjM@0:RgagS7iiSGmkSh5mT8=oTHF1TXN3ThR5U8Z7UHb96_ooo`0:T8b:T8f;T8f<T8f<T8j=
T8j>T8n?T92@TI2@TI6A0Y6ATP0DTI:BTI>CTI>DTIBETIBFTIFFT9FGT9JHT9NISiNJSiRLSiVNSi^P
SYRKSYJHSiBFSiBDT9>DTI>DTYBD0YBEU@0ETiFEU9FDUIBDU9:AU92>Thf<Th^9TXR5T8B1SH1mRgei
RGUeQgE`QG5[PVaUOVIMP6YSPViWPg5[Q7A_QWMb00:7NG@02XMkMhQlNHUnNhZ0OH^2Ohb3P8b5PXf6
Q8j8QXn:R1[oool02Xb:RHb;RXf<Rhf<S8j=SHj>SXn?ShnAT92ATI2BT`:@Ti<0596DUI6EUY6FUi:G
V9:HVY:IVi:JW9:KWI:LWi:MX9:NXY:OY96QYY6NXI6LWY:JVi:IVY>IVYBIVIFIV@:FVYT05IFJVIFJ
V9JHUiJFUIFDTYFBT9B@SI><RY69QHn5PHf1OH]mN8QhLhIdKH9^IgiXGh1/IH9`JH=cKHAfLHEhM002
QWYf00Z7O7R7OGZ8Ogb8P7f9PWn9Ph2:Q8::QH>;QhF;R8HLoooo000Joooo00FRTHZRT8ZQT8ZPShVO
SXP00Yj=Q`03WHb6W8b5Vh^500:JRX@02YZ9PiV9PYR8PYN7PIJ6P9F5OiB5Oi>4OY:3OI62O@:@PWd0
1923Oi22O921NY60NP:BP7X06I>0NiB1O9F2OIF2OIJ3OYN4OiR4OiR3OIR1NiR0NIQnMiMlMIIhLYAf
Ki9eKI5bJY1_Ihm^IHe/HXaZGhe/HXi_II1aJ95cJY9fK@02TgQ_00ZENW:FO7BGOgJIPGVJPg^LQGjM
R82ORX>PS8JRShPJoooo00FFSX^ESXbEShfESXfDShd00YB?SP03Thn?Ti2?Ti2@00>BT902TI2A0Y2A
TP:?TI<03HjAThfAU8bAUHbBUH^BUh^DVH^AU8^?THb>Shb=SXf=SXj=SXn>SP02T8j?01FASi2BT92C
ShnCSHfCRhVBRHNBQXBAPh2?OWb=NWN;Mg>8Lfj6KfV4JfB1IUioHUV1IUj2JV:4KFJ5L6V6Lf`00XQe
K`0:RGQbRWYeRgagSGijSX1lSh=oTHF1TXN4ThV6UH^86_ooo`0:T8b;T8f<T8j=T8j=T8n>T8n?TI2@
TI6ATI:BTI:C0Y6CU00DTIBETIBFTIFGTIJHTINITINJTIRKT9VLT9VMSiZNSiZOSY^PSYfSSIZMSYRJ
SYJHSiFFT9FFTIFFTYFE0Y>FUP:DUYH04iFEUIBCTYB@SiB>S9>;R9:7QI22OhenNX]jMXQeL8E`JX9[
I7mUGGaPEgiUGGmYHX5/IX9_JH=bK@02QGE`00Z6Mg:7NGF8NgN9OGZ:Ogb;PGj<Ph6=QH>>QhF?RHLJ
oooo00Z<RXV=RhZ=SHb>SHf>Shj?T92@TI6@TY>ATiBAUID2TYJG01>BUiRCV9ZCVI^CVifDW9jDWJ2D
WZ6DWj>DX:BDXZJDXjNCXjVBYJ^BXJFBWj:CWYnCWIjDW9fEW9`00iJLW00EUifLUibKV9^JUiVGUiJD
UYBAUY2>UHf:TXR5T8=oSGmkRWYeQgE_QG1XPFUQOFAKOfUPPFaUPW1YPg=]Q7E`00:5Mg802XIiMHIk
MhMmNHQnNhR0OHV2OhV3PHZ5PXZ6Q8^7QQcoool001[oool02Z:ARZ6@RZ2?RIn>R9j=Qij=QYf<QYb;
QI^:Q9Z:P`:IRH<059R8PYN7PIJ6P9F5OiB4OY>3OI62O921Nhn0NXenNHamN8]mN8]nNH]mN8amMhel
MXilMXmlMXmmMi1mM`:AOGP05I9nNI=oNYB0NYAoNIAmMYAkM9=iLY=gKi9dK91`J8m^IXe/Hh]YH8YV
GHUUFhQTFHUVFhYXGXa[HHe]Hhi`IP02T7=Y00ZBMVbCN6nENg:GOWFHP7RJPg^LQWjNRH6PRhFQSXPJ
oooo00BFSXbESXbEShfDShd2U8n>00BCShnCT8nBT92BT902TI2A00>ATI6@TI:@TI800XnAT`0?SY:D
SI:DSI:ES9:ERY6FRI6FR96FQi:HR92DR8jARHf@RXf>Rhf>S8b>SHf>00:>SHh05Hn=SY2>Si2=SY6<
Ri29R927QHn3PHn0OHelN8YfLXQbKXE^JH9YHh1TGGeOEgaNE7iQF7mTG81XH89[Hh=^I`02QG5Z00Z6
Lfj8MW69N7>;NgN<OWZ>PGb@PgnAQX:CR8FDRhPJoooo00Z@S8^@SHb@SXf@Shj@ShnAT92ATI6ATY:A
TiBAU9D2TIFF01BAUYNAUYRAUiVAV9ZAVIbAVYfAVijAVin@W:2?W:6>WJ:=WJ:<WJB<VYn=VIb>UiZ?
UiR?UYN@UYNAUYH2TYJF01FCUYJDUYJDUIFDU9>DTHnDSX^CRXNBQh>?PGj<NgN:MW:6LVb3K6F0IUil
GeIjGE=lHEQmI5aoJ620JfB1KVP00X=aJ`0:Q7=^QGIaQWQdQg]gR7eiRX1lRh9oS8B1SHJ4SXV76_oo
o`0:S8Z9SHb;SXf<SXj>Si2@T96AT9>CTIBETYJFTYNH0Y>HVP0DTiZKU9^MUIfOUIjQUJ2RUZ6TUZ:V
UZBXUZFZUZJ[UJN]U:N]TjR^TjBYTj:UU:6SUJ2QUInPUYnOUinO0iROWP0DVIjNVIfLVI^JVIRFV9FC
Ui6>UXj:U8R5TH=nSWiiRWUcQg9[PfaTOfAKOF9HOfIMP6UQPFeUPW1YPg9/0XAeK`0:QGMbQWUdQW]f
QgeiR7ikR81mRH9oRXB1RXF3RhN57?ooo`006_ooo`0:XY2:XHn9X8n8Whj7WXf7WHb6Vh^5VXZ4VHV3
V8R20YN7P@0DUXJ0UHEoU8AnTX=mTH9lT85kSWmjSGihRgagRG]eQgQcQGI`QGIaQgQcR7UcRGUcRWUb
RgUcRgQcS7Qc0heiL`0DSWUcSgQcSgQbSgM`SgE^Sg=/SW5YSFiVS6]RRVMMR6AKQf9HQEmDPeaAQ5eB
QEmDQV9FR6AIRFMMRf]P0Xe^I00:SW5WT7A[TWM_U7]bUWifV85iVhAlWHN0Wh^4XHj76_ooo`0:UXj<
UHj<UHn=U8n=U8n>Thn?Ti2?TY2@TY2ATI6A0Y6ATP:@TI<04HnBU8jBU8jBUHfBUHbBUX^BUXZBUhVB
UhJAUXB?UH>=U8F>TXJ=THN=ShR<SXV<SHZ;S@03Rh^=01F<Rhb=Rhb=RX^>RHV>QXJ=Ph:<P7j;OGZ:
N7F8Lfn5KFR2JF=oI5elGUIiF4iiFDmjG59lGeImHUYoIUj0JF800X9/I@0:Q6mYQG=]QgE`RGQcRgag
SGmjSX5mT8B0TXN4U8Z76_ooo`0:T8b;T8f<T8j=T8n?TI2@TI6ATI:CTI>DTIBETIFG0Y:FV00DTYNI
TYRKTYVLTYZMTY^OTYbPTYfQTIjRTInTT9nUSYnUS9jURY^RRiZOS9VMSIRKSYRISiNHT9NHTING0Y:G
U`0>TYJFTiJFTiFEU9>BTi2>Thb:TXR6THB1SgmkS7UeR7=^QFiXPFMPOF1H0WUIC`05NUeCNf1GOF=K
OVMOOfYS00:1KFL02X9`JX=cKXAeL8IhM8MkMhUnNXZ0OH^3P8f6Phj8QQ[oool02Xb;RHf<Rhj>SHn?
Si2ATI2CTi6DUI:FUi>HVI>IV`:DVid059FMWiFNXIJPXiNRYINSYiRUZIRWZiVX[IVZ[iV[/IR//YF/
/i>Y/9>VZiBUZ9FTYYJSY9NRXiRRXYRQXP:IXJ42VZ6P01>KWijKWIbJVYRJUYBITXnGSXZER8FBPgj?
O7N;Mg66L6R3J61nH5ImH5InI5Z0Iej1JV:1KFF2KfT00X=bK00:Q7A_QGMaQGQdQW]fQgeiR7mlR85n
RH>0RXF3RhN57?ooo`006_ooo`0:XY2:XHn9Whj8WXf7WHb6W8^5VXZ4VHV3V8R2UhN10YF6P00DU8Eo
ThAnTH9lT85kSh1jSGmiS7egRWaeR7YdQWMaPW=]OFmZPG=]PgA_QGE`QWE`QWE_QgA^R7A_R7A^0hUc
K@0DRG9]RW5[RW1ZRFmYRFeWRF]TRFYRQfMNQVAKQF5HQ5iCPU]@P5Q<OeA7OeE9P5Q;PU]>PeiBQF5F
QfEJ0XUYGP0:RfaRSG1VT7AZTWM^U7]cUgmgVH=kW8IoWXZ3XHf76_ooo`:ESX`01YB?SIB?SY>?SY>@
Si:@T9:@T@:ATI82T96C0XnBU00BSY:ESI>FSI>FS9>GRi>HRY>HRI>HQi>HQI6HOH^BOh^APXbAQ8b@
QHb?QX^>QhZ=Qh^=R8Z<0XV:R`0ERXV;RXR:RXJ8RXF6RX>3RWmoRGajR7QfQWAaQ6mZPVYTOfANNeiF
N5U?ME97MUA9MeI<N5Y@NUeDNf1HOFAL009oJ6002X5[I8=_J8EbK8MfL8UiM8]mN8f0O8n3Oi:7PiB:
Qa[oool02Y2<Ri2=SI2?SY6@Si6ATI6BTY6CU96DUI:FUi:GV0:BV9X059:IVi:JWI:KWY:MX9:NXY:O
Xi:PY9:QYY:RYi6SZI2SZXNLXhNJXHZJWh^JWXfIW8jIVXnHVI2HVI2GV0:AUiL05I:GUi>FUY>DU9>B
TI>?SY:;RI66Q922OhemNHYgLXMaJh=ZHgmSFg]LDgMDBGMFBgQICgULDg]OEWaRFWeVGP02OfUR00Z0
K6J1L6Z3Lff4MW66NGF8O7R9Ogb;PWn<QH:>R8HJoooo00Z<RhZ=SHb>Shj?T92@TY:AU9FBUYNCV9VD
VY^EW9h2UIjP01BFX::GXJBHXjNHYJVIYj^JZJjJZk2K[K>K[kFL/KNL/kZC[;BAZ:nCZ:fEYj^FYZVG
YJNHY:JIYJFJY:@2VjBT01FKY:>LXj:LXJ2LWifLW9VKUiFJTi2HSX^FR8BCPWf?O7J;MFj6KFF2IUem
GU=mGeEnHUQoI5^0Ien1JV:2KFD00X9_J@0:Pg9/Q7A_QGMaQWUdQW]gQgijR81mRH9oRXB2RhN57?oo
o`006_ooo`0:XY2:XHn9Whj8WXf7WHb6W8^5VXZ4VHV3V8R2UhN10YF6P00DU8EoThAnTH9lT85kSh1j
SGmiS7egRWaeR7YdQWMaPW=]OFmZPG=]PgA_QGE`QWE`QWE_QgA^R7A_R7A^0hUcK@0DRG9]RW5[RW1Z
RFmYRFeWRF]TRFYRQfMNQVAKQF5HQ5iCPU]@P5Q<OeA7OeE9P5Q;PU]>PeiBQF5FQfEJ0XUYGP0:RfaR
SG1VT7AZTWM^U7]cUgmgVH=kW8IoWXZ3XHf76_ooo`:ESX`01YB?SIB?SY>?SY>@Si:@T9:@T@:ATI82
T96C0XnBU00BSY:ESI>FSI>FS9>GRi>HRY>HRI>HQi>HQI6HOH^BOh^APXbAQ8b@QHb?QX^>QhZ=Qh^=
R8Z<0XV:R`0ERXV;RXR:RXJ8RXF6RX>3RWmoRGajR7QfQWAaQ6mZPVYTOfANNeiFN5U?ME97MUA9MeI<
N5Y@NUeDNf1HOFAL009oJ6002X5[I8=_J8EbK8MfL8UiM8]mN8f0O8n3Oi:7PiB:Qa[oool02Y2<Ri2=
SI2?SY6@Si6ATI6BTY6CU96DUI:FUi:GV0:BV9X059:IVi:JWI:KWY:MX9:NXY:OXi:PY9:QYY:RYi6S
ZI2SZXNLXhNJXHZJWh^JWXfIW8jIVXnHVI2HVI2GV0:AUiL05I:GUi>FUY>DU9>BTI>?SY:;RI66Q922
OhemNHYgLXMaJh=ZHgmSFg]LDgMDBGMFBgQICgULDg]OEWaRFWeVGP02OfUR00Z0K6J1L6Z3Lff4MW66
NGF8O7R9Ogb;PWn<QH:>R8HJoooo00Z<RhZ=SHb>Shj?T92@TY:AU9FBUYNCV9VDVY^EW9h2UIjP01BF
X::GXJBHXjNHYJVIYj^JZJjJZk2K[K>K[kFL/KNL/kZC[;BAZ:nCZ:fEYj^FYZVGYJNHY:JIYJFJY:@2
VjBT01FKY:>LXj:LXJ2LWifLW9VKUiFJTi2HSX^FR8BCPWf?O7J;MFj6KFF2IUemGU=mGeEnHUQoI5^0
Ien1JV:2KFD00X9_J@0:Pg9/Q7A_QGMaQWUdQW]gQgijR81mRH9oRXB2RhN57?ooo`006_ooo`0:XY2:
X8n9Whj7WHb6W8^5VhZ4VHV3V8R2UXN1UHJ00YB4O`0>TX=mTH9lSh5kSWmiS7ihRgafRG]eR7UcQWMa
Q7E_PW=^NVaXOg5[PG9/0X9bK004Pg5[Pg1ZQ71ZQ71[0XE_JP0EQFiXQFaVQFUTQ6MRQ6IPQ6IOPfEM
Pf=KPV5HPUiEP5]AOeM<OE=7Ndm2NDXlNTdoO512OE=6OeM;PE]?PemD00:6HeP02XQWGH]/HXe`IY1d
Ji9hL9EmM9R1NI^5OIj9PZ2=QQ[oool02YF>S9F>SIB?SIB?SY>?Si:@T9:@TI6ATI6ATY2BT`:?TY@0
58nBUHjCUXfCUXbCUhbDV8^DV8ZDVHVDVXRDVXNEVhJDVgR8Sgj;TH2;T8:<T8>;ShB;SHB:S8F9S8J9
S0:7RHX05HN8RXN6R8R3QHN0PXInOXIkNhEhMhAdLX9`KH1ZIWiUH7]OFGMIDGACBG5;@79>@g=@AWED
BWIHCWQKDWYOE`02O6=K00YnIf20JfB3KfV5Lff7Mg6:NWJ<OWZ?PWjAQX:DRXLJoooo00Z@S8^@SXf@
ShnAT92ATI:ATi>AU9FBUYNBUiVBV9X2TYZL01BCVijCW9nCWJ6CWj>CX:BCXJJCXjRCY:ZCYJ^CYjfB
Yjj1V:26VZ69Vin;Vin<VYf=VYb>VIZ?V9Z@V9T2TIRH01FBV9RBUYJCTiBBT92BSH^AR8N@Q8:>P7f;
NWJ9M6n5KVR1If1mGeMiF4idD4AeDTMfE4YgF4ihFe9jGUIkHUX00WeUGP0:OVURP6aVPG1ZPg=^QGMb
QWYfR7ejRX5nS8B2SXR66_ooo`0:SH^:SXf=Si2?T96ATI>DTYFFTiRIU9ZKUIbNUYjP0YNPX`0DV::U
VJFXVJN[VZV]Vj^`W:fbW:neWK:hW[BkWkNnWkS0SJRaTJV`U:V^UZV]UjR[V:RZVJNXVZNXVjNW0YbW
YP0EWJNVWZJUWZ>SWZ2OWIbJW9NEVi>@VHj;UXR3Th5lSg]eRg=/QVaTPVEKOEaAOEiCOV1FOV9IOfEL
P6MOPFYR00:1KFH02X9_JH=bK8AeKhEgLXIjMHMlN8QoNhV1OXZ4PH^6Q1coool001[oool02Z:@RZ2?
RIj>R9f<QY^:Q9Z9PiR8PYN7PIF6P9>4O`:BPgd04Y22O8n0NheoNH]mN8YlMXQjM8MiLhEgLHAeKh=e
KH9dKH1cK7i`JWi_JGm_JGm^J7m^Ih1]I`:0K6H2PF]V01F1JVB0J6:1IF20HUioH5]oGUUnGEInG5Al
FU5lEdikE4]kDDIiCD5gBC]d@S=e@cAgAcUiC3ikD4=mEDQoFDd00X9NDP0:QF=HR6MMRVaRSG5WT7I]
U7YbUgmgVX=lWHR1X8f66_ooo`03UHj<UHn=U8n>00:CShl01I:@T96ATI6ATY2BThnBU002Si>E01>>
TiJ=TiN<U9R<U9R;U9V:UIZ9UI^8UIb8UYb8Uij3TYUmS9=nS95oRi20Rhn1RXj2RXf2RH^3R8/00hB8
RP0EQHN9QHF7QH64QGj0Q7YkPgIgPW=cPG1^OV]YO6IRNV5LN5]EMEE=LDi4KTHkKTLkKdXoLDi3Le98
MEI=MeYB009iGeH02W]SFgiWH81[IH=`JXIdKhQhLh]mN8j1OI25PI>9QQ[oool02Y2=Ri2>SI6@Si6A
TI6BTY6DU9:EUY:GV9:HVY>JW0:CVih059>MX9>NXY>PY9>QYY>RYiBTZIBUZiBW[IBX[iF[/XbSZhBK
XhNLXXVLX8^LX8bKWXfJWHjJVhnIVY2IVP:AVIX03Y:IVI:GUi>CU9:?Si6:RY26QHn1P8emNXUgM8Ma
K8=[IH1TGGaME7MEB`9cCD401GA@AGECB7IGCGQJDGUNE@02Nf9J00YlIEinJF:0KFN2LF^3MG25N7B7
O7R9P7f;Ph6>QhDJoooo00Z=RhZ>SXf?T92@TY:AU9FCUiRDVI^EW9fFWZ2GX:<2V:>V01BIYJVJZ:bK
ZZjL[;6M[kBN/KNO];ZO][fP^L2S_LBG/kb>ZK:BZk:E[;2G[;2HZjjJZjfKZZ^LZZZMZZX2WZZZ01FO
ZZVPZJNPYJBPXZ2OW9ZMUiFLTY2JSHZFQh>CP7^?NWB;Lf^7Jf>2I5YmG51mFe1mGE=nH5EoHUUoIEb0
Iel00X5ZH`0:PFeVPW1YPg=]Q7E`QGQdQW]gQgijR81mRH>1RXJ47?ooo`006_ooo`0:XI2:X8n8WXf7
W8b6VXZ4VHV3UhN2UHJ0U8EoTX=n0Y22O00ASX1kSGmiRgehRGafQgYdQWQbQ7M`PWE_P79[PG=]PWE_
Og9/OFmYO6iWO6aVO6]TO6YS009lJF8067aXHWeXHWeXHWiVHGeSGWePG7eMFGaJEW]HDgYGDWUECgQD
C7MAB7I?AGE<@GE8?793=G0m;Flj:W4o;gA4=GI9>gU>@G]CA`9nFDd02X5NDXASF8QXGX]^I8icJY9h
KiEmM9V2NYb7P:2<QA[oool02YF>S9F?SIB?SY>@Si:@T9:@TI6ATY2BThnBU8nCU@:>TiH04XfDUhbD
V8bDVH^EVXZEVhVEW8RFW8NFWHNGWXBDW82AV7j>UGj=TWj<TGn;Sgn:SH29Rh28RP:1QhX2PXN:01F4
QhZ3PhJ3P8:3Ngj2MgV1LWAoKg1mJf]kIfEhHUifGEQdF55bDTY^Bd5[@cQY@3=[A3Q]B3e_C49aDDMc
ED`00WIJDP0:N5mGNf=LOVQQPFeWQ79/QgIaRW]fSGmkT8B1ThV66_ooo`0:T8f<T8n>TI2@TI:BTI>C
TYFFTYJHTYRJTiZLTi^N0Y>MX00DU9jRU:2TU::VU:>XU:FZU:J/U:R_U:ZaUJbcSjN_R:6YR9nVR9jT
RYjRRifQS9bOSI^MSYZLSiZKT9ZK0Y6JV`0ETY^KTYNGTi>DTXj>THV9Sh>3SWmnRgYhR7EaQ6iZPFQR
OV9JNe]BMUA9Lda0L4PkLD/oLdi3M597MEI<MeYA009hGUD02WYRFWaVGgiZI81^JH9bKHAgLXMjMXUo
Nh^3P8f7QA[oool02Xf<Rhj>SXnATI6CU9:EUY>HVIFKWIJMX9NPXiRSYP:JYJT059^X[9b[[if]/Yj`
]Inc^J2e_:6h_j:k`ZBoaibh`I:`^I>_]YF^]9N_/iV^/YZ^/I^][ib/[If/[9j][0:P[J`05J6^[J6[
ZJ:WYZ6SXJ2MVinGUIfBT9Z<RIJ6PY=oNXihLXYbJXM[HX9TFWmMDWaICGeKCgeMDWiOEGiRFGmUG002
P6QP00Z0Jf>1KVN2LFZ3M6j4Mg:5NWJ7O7V8P7b9Ph2:QX@Loooo000Joooo00ZQT8VOSXRMSHNLRhFJ
RXBHR8:FQh6DQGnBQ7j@PW`2SX5k016=OgV;OGR9O7J7NWB5N7:3MW21M6ioLfb3MW1oLfenLF]lL6Yk
KVMjK6EiJV=hJ65hIUl00WQUGP0HN6EONFEONFEONVMQNVIPNVAMNF5JNEeHMeMBMU=>M55;LTm8LTe4
LDY0LDPlLD@hKd0bKS/[JcDTK3HTKc`/LD8cM4PjMde00WYCA`0:OUU=PEmDQFEJRFYPS71WT7I]U7]c
V85iW8IoWhb56_ooo`0:UHj<U8n=U92?Ti2?TY2@TI6BT96CT9:DSi>ESY>F0XfDU`0DS9BHS9FIRiFJ
RYJKRIJLR9JMQiNNQYNOQiRQP9:JOY2GOXjEOHfCOHbAOX^@OHV=OHR:OXN9OXJ9OhN90X26R@0EPXR:
PXF7PX:4PGeoP7UkOW9cOFe^NVQXMf=RMEmLLUUEL5E>Kdm8K4Y0JT<hIcd`Ic`_JD8fJdLkKD]1L517
009cEDd02WEJDWQPF7]UGWmZI89_JHEeKhUiMHanNXn3P9>8QA[oool02Y2=S92?SY6ATI6BTY:DUI:E
Ui:GVI>IVi>KWY>MX0:DWZ8059BPYIBRYiFTZIFUZiFW[IFY/9FZ/YF/]9>/]HVS[8VRZXVQZ8ZPYH^O
Y8bOXhbMX8fLWHfKW8jKVhnKV`:@Vi/05I:LW9>IVI>EUI:?Si6;RXn3PhenOHYhMXIbKh9/J7iUGg]P
F7UJDGECBG=<@Fm6>Fm5>71:?G9>@W=BAgAFC002MUYA00YhGUIjHe]lIf5nK6J1L6^3MG26NGF8OWZ;
PWn=Qh@Joooo00Z=S8^>Shj@TY:AU9BCUiRDVY^FW9jGWj:HXZFJYJP2VjR/01BLZjnM[[>O/KJP];VQ
][fR^L2S_<BS_lNP_/ND/kfE/kbF/[ZG/[NI/[NK/[JL/K>M[k6N[jnO[ZjO[jh2XJn^01FS/:jS[:^S
Z:JRXZ2RWYbPUiFOTXnKRhRGQH6BOWV=Mg6:LFV7Jf:3IE^0GU=mF4elEd]mFTmmGE9mGeEnHUT00WmU
G@0:OfQPP6]TPFmXPW9/Q7E`QGQdQW]hQgmlRH:0RXJ47?ooo`006_ooo`0:XI29Whj8WHf6Vh^5VHV3
UhN2UHJ0ThAoTH=mSh5k0XeoNP0DRgihRGafQgYeQGQcPWIaP7A^OW9/Ng1ZMFYTNFiWNViXNFeWN6aV
N6]TMVUQMFENM6=LM69KLf9KM6=L0WETG@0EMfQQN6YSN6YSN6QQMfALM5]DLUA>L4m8KT]4KDU0K4Hl
K4@hK48eK3h`JcTZJCDTJ34PJSDTK3/[Kd4cLdLj009fCT402WYDB7iKCh9QEXIWGHY]I8icJi=iLIMo
N9^5OYn;Q1[oool02YF>S9B?SY>@Si>@T9:ATI6ATY2BThnBUHjCUXfDU`:=U9P04XbEVX^EVhZFW8VF
WHRGWXNGWhFGX8BHXGV>V7b?V7b?Ugb>UGf>U7f=Tgf<TGb9SG^6RW^6R09lQXP2OXJ801F0QhV1R8Z0
QHJ0PX:0OWmmMGEjKFigIVIdH61aG5U^EU5]DT]/CDIZBCmX@SQV?C5T>2]U?2mW@CEZAS]/Bd400VmA
B00:LUI>MEaDNF5JO6MQP6eWQ79]QgQcRgeiSh=oTXR56_ooo`0:T8f<T8n?TI6ATI>CTYFFTYJHTiRJ
TiZMTibOU9jR0YBPY00DUJ:WUJBYUJJ/UJR^UZZ`UJ^cUJfeUJnhQjB]R:>/RJ>ZRJ:YRZ:WS::VSJ6U
SInQS9bNSI^LSY^LSYbK0XnJV`0ETY^JTiZJTYJETY:ATXn>ShJ5SGimRGMeQ6m]P6YVO6=MNEiFMeQ@
ME=9LTa1L4LjKD8dKTDhKdTmL4e2LU57009dETd02WIKDWQOF7YTGGeYHgm^JH9cKXEhM8MmNHZ1OXf6
Q1[oool02Xf<Rhn?Si2BTY:EUY>HVIFKWIJNX9RQY9VTZ9^WZ`:LZjl059j^/ina]Z6d^Z:g_Z>j`JBm
aJG0b:K3cINh`YJf_iNe_IRd_9Zd^Y^e^Yfe^Ijd]Yja/Yn`/:2`/:2a[`:R[jh05J>][:F/ZjBVYJBS
XJBQWj:IUj2BT9^;R9J3P99mNHefL8U`J8MZHXAUFh5OE7iJCW]EB7aGBgaJCWaMDWeOEP02OF9I00Yn
IUeoJF60K6J1L6Z3Lfj4Mg:6NWJ7OW^9PWn:QH<Loooo000Joooo00ZQT8VOSXRLS8JJRXBHR8>FQX6D
QGnAPgj?PWb=P7/2Rgii00R9O7N7NgF5NG>2Mg60M6mnLVekKfYkL6X2MVaW00IgK6MfJfIfK6IeJVAd
If5bI5`3KemI01=]HU]dJV=dJV=gK6IjLFYjKfQhJ65fJ61cHe]_Fe=ZCdQYB45XACeX@cUX@CIY?c=Y
?BmX>2UV=2<00V@^7003Ic@SJSX[KT4c009bB3/02WI?@g]FBgmMDXATFXQ[HHeaJ95hKiInMYZ5OIn;
Q1[oool02YF>S9B?SY>@Si:@T96ATY2AThnBU8nCUHjCUhfDV0:<UIT048^FVhZFW8VGWHRGWXNHWhJH
X8BHXH:GXGR>V7V?UgZ?Ug^>UGb?UGb>UGf=TW^:SP9iQHP06GV4R7J3QGb8RWb8RWn8RX:;S8:9RX63
Q822PGekNWUcLg=XIg1NGFeIEf]DCfY?BFU<A6Q8?fM3>6@m<F8g:V4f:F<k;VE0=FQ6?002Jda200Y_
DTUbF51fGUMjI5enJVB2L6^6MW6:O7R>PWjBR8@Joooo00Z@SHbAShnATI:ATiBBUINBUiVCVIbCVijD
WZ6DX:@2UJ:V01BEY:VFYZbFZ:jFZ[6F[;>F[[JF/;VB[[R5XZb7Xjb8Xj^9XZV;XjV=Y:V>Y:N>XJ><
W9f=Vib>Vib:V9P2SY^K01FAVIVCVYZDVIRDU9>DTY2ARXR>Ph67N7J2KVamIfEjHE]gFeAfEdmdDdUb
CD9`Ac]/@CA/@39]A3M^B3e_CD800W5BB00:LeM>MUaDN65JNfMPOVaVPG5/Q7IbQg]hRX5nSHJ46_oo
o`0:SHb;Si2?TI>CTYJGU9ZKUYbNUj2RVJ>VVjJZW:Z^0Yj]/P0DWk6fXKBjXkNnY;_2YKk6Y/7:Z<G>
X/;<TkG0U[JoV;JoVKJlVkNlW[RmX;VlXKNhX;>cXK:bXk:aWZb[0Z6/[00EXjZYYJVXYJRWYZFSYj:P
Y9^HXYFBVhb9UX9oTGahS7E^RFmWQVYQQFEKPV1EP5]?OEI9O5A7O5M:NeY>NeaB009lH5H02WeSFWiW
GgmZHh1^J89bK8=fLHEiMHMmNXR1OXZ5Pacoool001[oool02Z6?RIj>Qib<QYV:Q9N8PiF6PI:4Oi22
OHj1NhaoNP:9OGP038MkMXEiM8=gLX1eL7icKG]`JgU_JW5YIG=[IWA[IWA/IWAZI@9dJfD01W=YHg5U
GVePFF]PFG=/IG=]IP9dKfP05GE`JGI^IgQ`JGU^IWY/IGMWH7=PFFYDCFA8@F=2>f=0=f@n<fDm<FHk
;VHh:F@c8f8^7F4[6V4^7V@c96Pk;@02KD<f00YbBcigDTMlFTn1HEN6J5j;KfJ@MVfEOGFJQ7bNRX@J
oooo00ZESXbDShjCT8nBT96ATI:@TY>?TYF>TiJ=U9R<UIT2RiJK01B;UYb:Uij9V9n8V:26VJ65VJ:4
VZAgSi]gSYQhSYMiSiMjSYEkSiIlTIMmT9EkS8mhQhYePhIkRH]jQhT2O8Z;01EnRX^0RHZ2Rhb3QXJ3
Q8B2OginNGQdK6][GeiYEUEWDDiVC4MVBT=WAcmV@cQS?C9Q>2]O=2IO=RYP>RmS@3H00VM7?@0:Jdi5
KeA<M5]CN65JO6QRP6iYQGA_RG]fSH5mTXN46_ooo`0:T8f<TI2?TI:BTYBETYJHTiRJTiZMU9fPU9nS
UJ6V0YFTZ@0DUZJ[UZR^Uj^aUjfdUjnfUk2iV;>mQjJaQ::]QZ>/RJB/RJ>YS:F[SZN/T:NZSj>USYnO
RIRISI^LRiRH0XjJVP0ET9ZJTYVIUI^KUIFDUY>AUHj;TXV6R7ajOfm/NfERMemJMEUCM5I>M5=9LTi3
L4PlKD<eJch_JT0cJT@gK4Pm009^CT@02W1CBW=ID7INEgUTGGaZI7m_JX=eL8IjMhV0OHb6Pa[oool0
2Xf=S8n@T96DU9>GV9FKW9NNX9RQY9ZUZ9bY[9f//@:O/;D05:6c^J>g_JFk`ZJnaZS2bZW5cZ[9diRk
aiBf`9Jg`9Vh`9Zg_Ifi_j2k`:>l_j>i^Z>e]In][Z2/[IbWY`:PZZT05J>YZ:FYZ:N[ZZRTXZRRWjNN
VZJJUij@S9F3P8mjMX]dKXQ]IXIYHHEVG8AREX5MDGmGBWaCAG]DAgYFBWYICP02NUaC00YkH5MlI5an
J65oK6J1L6Z3M6n4N7B6O7V8PGj:QH<Loooo000Joooo00ZQShVNSHNKS8JIRXBFQh:DQH2APgj?PGb<
P7Z:OWT2R7ag01B6NWF4N7>1MW5oM6mkLF]hKFQhKVY]IV9`JFAaJVIbK6MbJfIbK6IbK6McK6IaJfAb
JV9]Hea`IEeaIUl2LFMO01EbJF5cJ5mdIemdI5]eHeYgHUQhHeYdG5AYD4QO@CYO?3=P>S1R>RmS>ReS
=bQR<R=P;AaO:AMM:QQN;1eR=2H00VTm<00:KTHjM4i3NEI;OeiDQ6ILRFeTSWA/U7adVH=kWXZ36_oo
o`0:UHj=U8n>Ti2@TY6ATI6CT9:DSY>FSIBGS9BIS9FJ0X^FW00DRYNMRIRORIVQR9ZRQYZSPiVRPiZU
L8ZFM8fGMXjGN8nHNHnFNY2GO9:IOI:GO92COHf?MH:4N8>6NHF60WZ5QP0EO8N8OXJ7P8J7Oh61P81o
PGakPW]iOG9`LFITIEIEHdi;HTY5I4Q1IDHnI4<iHShcH3P[GS<TG3<VFcDYGSX`009S@SP02VM9@6a@
B75HD7EOF7YUGgm/Ih=cKXQjMHf0O967Q1[oool02Y2>SI6@T96CTi:EUY:GVI>IW9>LWYBNXIBPY9FS
Z0:FYJ/059JX[YNZ/IR]]9V`]iVa^YNb^iJc_H2P[H>R[8JS[8RU[8ZTZhbV[8nY[Y6X[92UYi6RXXNE
UXZFUhbGV0:>UiL05I2IVY:IVIBIV9BCTIFASiF=RYF;R8n1OHAeLGQVHWAMF79GDG=DC7=BBG=?A71:
?Fi3=V/n;fTn<6Lo<VM3>002JTTo00Y]CdIaEDedFeAgHU]kJ65nKVR2Lfn5NGJ9Ogb<QH<Joooo00Z>
SHb@TI2BUIFDV9VFW9fGWj:IXjJKYjZMZjnO[[<2XK:h01BS][bU^/6W_/JY`lZ[a/n[b=6YbMBA]L:D
]/6G]l6J^<2L^;jO^/2R_L:U_L2T^[ZU]KFJZ:VMZJZOZZX2XJVY01FT[:^VZj^X[:ZXYZ>YY:6XWi^W
W9RQTXjHR8B>NgN:LVf7K6F6J626IUf5HeR3GU:0F4]nE4EkDdIhDdIgEDX00WQIC`0:NEeDNf5IO6IN
OVYSP6iYPW=^Q7McQWahR81mRXB27?ooo`006_ooo`0:X8n9WXf7Vh^5V8V3UHN1TXEoT89mSH1kRgij
R7eh0XIkMP09Q7UdPWMcP7IaOWA^NFmYLFMQLVYUL6UUKfUV009`JFD02G1ZIG1/Ig9^JG=_JWEcKGMf
Kg=aJW1[I6mYHP02KfIN01E_IEi`I5a`He]`GeIaG5A`FU5bG59bEdi_DdYTAcmK>S9M>2mN>2eP>2]Q
=BMO<R=N;AeM:AML:1ML:aYN;b400V@i:`0:JT8eL4/oMU=8O5]APV=IQf]RSG=ZTg]bV89kWXZ36_oo
o`0:UHj=U8n>Ti2@TI6BT9:CSi:ESY>FSIBHS9FJRiJK0XZGW@0DRIRORIVQRI^SRIbUQibVOiJPNY>N
LX^GM8fGMHjGMhjGN8nFNI6HO9BJOI>HOY>FOi:DNH^=NHR:NHN90WV5Q`0ENhJ8OHF7OHF5OGmoOGal
OGMfOWMeNg1]MfUWJUaIH4a:H4M4HDI0HdHnHd<iHChcGcT/GS<VFc4SFS<UFCDZ009O?C<02VA5?6U=
A6iDCG=LEGQSGGeZIH9aK8MhM8b0O967Pa[oool02Y2>SI6@T96CTi:EUY>HVY>JWIBMX9BOXiFRYYFT
Z@:FYjd059NY/9R//iV`]i^c^iff_iFa^Xb[]X2P[8>R[8JT[HRT[8ZTZhbW[I2Z[i6WZi2UYi2RXhZK
W8^IVXfIVP:>V9P05I2JVY>IVIBIV9>CTIB@SY:9Qi:9QHn1O8YiMGe[Ig9KEg5ED75CBg=CBG=?A75:
?Vi4=f`o<6Pl;FHm;V<m<P02IdDj00YZBd9^DTUbFE5eGeQiIEmmK6J1LVf4N7B8Og^<QH8Joooo00Z>
SHb@TI6BUIJDVIZFWInHXJ>JYJRLZJfN[K6P/KH2X[Fj01BT^KnV_LBY`/V/alnacMJ[b]>O`Lf@]<2D
]/6H^<6K^<2M^KnP^l2S_/:T^[jR][NQ/K:KZZ^OZZ^QZj/2Xj^[01FU[ZfX[JbY[J^YZ:FYY::WWIZW
W9RSU8jMS8NBP7Z8LF^6JVB6J5n7Iej7I5V5H5>2FTaoEDMkDT=hDD=dD4H00WIEB`0:MeYANEmFNf=L
OFQQOfeWPG5/PgIbQG]gQh1mRHB27?ooo`006_ooo`0:X8n9WHf7VX^5UhR3U8J1THAoSX5lRgmkRGei
QW]g0XAjM@0DPWQcP7MbOgIaOgE`OgEaMfmZL6]WL6]XKVYVKFUVKFUWKFYWKVaXKfiZKfeXKV]VKfiX
KfiWKVeVKVaU0fm/I00DL6YRL6UPL6MNKfAJKeiDKU]AKeM=KU98JDa2GclfFSL^G3L/GSL[GcDWGS4R
G2dMFbPHEb<ADb8AFR`M0V0d9`0:IchbKDLkM515NUU>P65GQVUPS75YTWUaUh5jWHV26_ooo`0:UHj=
U8n?TY2@TI6BT9:DSi>ESI>GS9BIRiFJRYJL0XVGWP08R9RPR9ZRRIbURYnXSJ:]PIVSLhjJM8fI0WB>
V00:MHjHMXnGN96INY>JNY2FN8b@NHb?N8b>N8Z<NHZ<0WZ:R`0ENhZ<OHV:OHR8OHF4OH1nNgUhNWId
NG1]MVUVL65MHe1=GTM3GdE0HTDnHT<jHChdGST]GC@WFBlQDB/MES4V009J>Bh02V11>6I9@F]ABW5I
DWIQFWaXHh5`JhIgLh]oNi66Pa[oool02Y2>SI6AT9:CU9:FUi>IVi>KWYBMXIBPY9FSZ9JUZ`:FZ:l0
59N[/YR^]YZb^Yfg_j:laYBa^h:S[h:R[XBS[HJT[HRT[8VT[8bW[HnY[XnUZXbOXXbNX8bMWXbLWHjK
W0:?W9`05I6MWI>LW9BJVIBGUI>ASi:;R928Phj1O8YiM89_JWANFFmDCg1CBg=CBW=@AG5;?fi5>6a0
<VTl;Elf:60j;P02Hd0e00YWB3i[CdI_ETidGEEhHeelJVB0LFb4Mg>8OW^<QH8Joooo00Z>SHb@TY6C
UYJEVY^GWZ2IXjFKYZZMZjnO[kBQ/kP2XkNm01BU^l:W`<NZaLf_bm>edM^Vam6C]l>C]L6F]l6I^L6L
^<2N^KnQ^l2T_L6T^KbP/[BP[k6P[ZjQ[JfS[:d2YJf]01FW[ZjY[ZfZ[:^ZZJJYY:6XWY^UW9JRU8jN
S8NFPWb9LVf5JFB6J628J5j8IEZ6HEB3Fdj1EdUoE4EdC3mbCD800W=BA`0:MEM=MeaCNF5IO6IOOV]U
P71[PWE`QGYfQgmlRHB27?ooo`006_ooo`0:X8n9WHf7VXZ5UXR3ThJ1T8AoSH5lRWijQgahQ7Yf0X9h
M00:P7IbOWEaOWE`P7QcQgiiQGafMW1/KfYWK6UVJfYV0V]YI`07JfaYKFiZKFeYJVMSJVMQJVQRJVUR
00A[J68056aWH6aVGVaSFf]PF6YME6UKD6UICVYGC6UCB6A:@5do=E/i;U`g:ede:5`b95/^7UXZ6UXY
650Q4EDX6@9M<R@02V@k;VY4>75=@WMFC7iOEHAXGXY`Ii5hL9N1NIf9PQ[oool02YF?SI>@Si:ATI6A
ThnBU8jCUXfDV8^EVXZFVhVFW@:8Uil048NIXHNJXhRLYX^QZY2U/8VOZ7VAW7B>VG>>V7>>UgB>V7F>
UgJAVGRCVWR@UgF9SP9eR8/06GJ8RgN8RgR9RgR9RgV9Rg^8RW^6Qg^3PgYoOWUjN7IfLgEaKG=[Ig1T
GVUIDf5<B5m7@F56?f54>V0o=Ehj;Udf:Edd9TdW6e0]8@02EcD[00YM?SASASiYCdM_EdmdGeQjIf60
KfV5MW:;OWZ@QX<Joooo00Z@SXfATI6BU9BCUiRCVYbDW9nDWj:EXJJEY:VFYjd2UZV`01BG[;BH[kRJ
/kbM^<6P^lJE/[b6YK24Y:j5Y:f6Y:b8Y:b9Y:b;Yjf>Z:j>YJZ:WJ2:W9j;Vif<W9f>Vi`2SibM01FA
WIfCW9bCVYVDUYFBTXnASHV=Qh:;P7^7NGB2L6YiI5ibF5=aE4acDdYcDDIbC41_AcU^@SA]@31J<B=L
=BT00V0m<P0:I4@jJDa3KE=;LUYCMV5KNVQSOVm[PgIbQgejRhB26_ooo`0:SXj=TI:BTiNGUY^MV:2R
VZBWW:R/WjfaXK6fX[Fk0ZBi`00DY[g5Z<;:Z/K?[/cE[/gHXL;>U;O3U[O2V;S2V[S0WKW0WkVoXK_0
Y;c0Y;VlX;6cXJn`XJj_Xjj_Y:j^0ZJ_[`0EZ;2`Zk2_Zjf[[:ZWZZFRZJ2LYI^EXY>>WH^5UX5kSWI_
Qf]UQfUQRFQORFIKR69EQEe?Q5U:PeI6KdLiKdXm009`CT<02W=DBWEID7QOEgYTGGeYHgm_JH9dKhAi
MHMnNhV4PAcoool001[oool02Z2?RIb<QiV:Q9F7PY:5P8n2OX^0NhQmNHEkMh9hM@9oMW8027edLG]c
KgYbKW]dKW]cKWQbKW5/JV]XI@9XIfD02FMXIVMYIfQZJ6U/JVU[J6MUHFERG6ESGFITG`03IfEO01EX
IV1YIUmXHeaXGeQWGEEVFU9TEdiTE4YTDDMRCD9PAcaM@CMK>c5K>2eK=BUK<BAJ;R1J:aaI:AQ=7a5B
9AP00UT^8@0:H3P[Id8fKT]0MEA:O5eCPVIMRFmVT7M_UX1iWHV26_ooo`0:UHn=Ti2?TY6ATI:CSi>E
SYBGS9BIRiFJRIJLR9NN0XJHX00:QIVQQIZSQI^VQYjXQ9bWP9RSNI:MLhjILHbGLHfF0W:>U`08M92H
MY6IMXnFLhV?LHB9LXF8LhJ:MHN:0WJ7RP0EMhV;NHR:NHF6NH62N7emMWUgLg=aL6eZKVMSJf1KIeQC
HTm:H4Y4H4M0HD@lH40fGS/`GSP[GC@VBRDICBTN009C<RL02UXk<F13>VI<A6aDCG9MEWQUGgi]J8Ae
LHYmNY25PQ[oool02Y2>SI6ATI:DUI>GVIBJWIBMX9FPY9FSZ9FUZiJX[`:FZk8059J]]YN`^IRc_IVf
`9Jd_i6_^HZX/hJT[XFS[HJSZhNT[8RT[8ZV[HfW[HfUZXZNXXVJW8ZIVh^KW8fKW@:?W9d05I6MWY>M
WI>JVI>EU9:ASi2<R8b6PHQnNHAfLGm^J7YUGgELEW=GCg=EC7ABAg9=@G18>fm4=Fm1<EL_8EPb9P02
GCT^00YR@CMVBCm[D4Q`F51dGeUiIf5mKVV2MG66OGV;Q84Joooo00Z>SXfATi>DUiRFW9jIXJ>KYZVN
ZZjP[k>R/kRT]kd2YKc301BW`<NXa<bZam6ZbmFWb=BR`/fL_<NJ^L>J^<6L^;nN^KnO^;nQ^/2T^l2T
^KbR/kJQ[k2R[ZnT[jnV/;02Z;2`01FZ/K6//K2][jf]ZZR/YZ>ZXIbUVYFPTXbKRXBFPGZ@N76;KfR9
Jf::JV2;J5b9HeJ6GU26FT^5EdM]ACM[ASX00Vi;@00:LE57LeM>MUeDNF9KNfQQOVeXPG=^Q7QdQWik
RH>17?ooo`006_ooo`0:X8n9W8b6V8Z4UHN2THB0SH9mRWmkQWahPWUfOgMc0WadL@0DNG9_Mg1]MFi[
LfeZLF]WKVMTJVARIV=RIF=RI6ARHfESHfITHfMVI6UWIFQVI6ERHV1LHEiIHV1KHf5L0VAQG00EI69M
IF=MIF5KI5eGI5YCI5Q@HUA=H599H4i6Gd]2GDHmFd0fFS`bFCP^FSHZFS8VFRlRFbdNG2/KBad>CR4B
009F:ad02Ude:6Do<fa9?W=BB7YKDX5TFhQ^IHmfKiIoN9b8PA[oool02YF?SI>@Si:ATI2BU8nCUXfD
V8^EVHZFVhRFWHJGW`:5V:0028>HXX:IY86JYGnJYWfGXWVBWGB>VG2;U`9_RYD02Vn;UG2<UW6>Ug:?
V7>=UG::T724RFn2QW64R7:5R@9dQHT05GF6RGN7RWN5QgN0PWEkO7AgMg5aL6i[JF]UHVQOFfEHDf5@
Bf1<AV19@V15?Em1=ell<Uli;F0g:DLS5dTU6P02D2hS00YF=beM@3MTBD5ZDT]aFeAgHeimK6N3M72:
OGV@QH8Joooo00ZASXjATY:BUIJCV9ZDVijEWZ:EXJJEY:VFYjfFZK02UZbd01BF[[NF/KZE/kfD/knB
/;^>ZkJ9Y[25Xjj4XJ^5XJZ6XZZ7Xj^9Y:b;YZb;Y:Z;X:B9VYf9V9Z;VI^=Vid2Si^L01F@W9fCWIfC
VYZCUYFAT8j?RhR:Q826OGR2MG1nKVQjIUmeGUIdFU5dEdedDdQbCT9aBCa`ACMb@c=E;B1D;R800UTf
:P0:GchcI4HlJDi5KUI>LeiGN6EOO6eXPGA`QWaiRhB16_ooo`0:Shj=TY>CU9RIUifOVZ:UWJNZWjb`
XK6eXkFkYK[00ZNna@0DZ<;:ZLK?ZLWCZ<[FYlOBXl;=Wkg7Vk[3VkS0WKNoW[RoX;VoX[ZoXk_0Y;Vm
Y;FhXZnaXjj_YJn_Yk6a0ZVa/@0EZk:a[[>a[[2^[ZbY[JJRZZ6LY9VDX96;VhV3UX5jTGUbSG9YS6mU
S6aQS6UMRFAGR5mAQe]<R5U8Jd@fJD<g009[B3d02Vi>A75DBgAJDWMPFGYVGge/IX1bKH=hM8ImNXV3
PAcoool001[oool02Yn?RIb<QYR9Q9B6PY24Ohb1OHQnNXAkMh1hMGaeLP9iLVl057E_K79/JVmZIfaW
I6YTHVIQGfAOGF5OGV1NGUmOGUmPH5iRHEmSHUmUHf1UHf1SH5iOFeeKEeiMF5mOFP9PH5/05F5PG69Q
G69OFV9MEf5IDf1FD5iBC5e?B5];AE]9@U]6?UU1>EPm=5Li;ePf:ePc9eT`8e/_85l_7ThP44TL3P02
DRLJ00YK<RIR?C5ZAcaaD4IhFU1oHeZ6K6B>MVjEOgNLR84Joooo00ZEShfCT92BTI:@TYB>TiJ=U9R;
UIZ9UYb7Uij5Uj02PiRQ01B1V:9oV:AmV:EjUZ=gTj1cSYY`RIA/R9A/QY9/Qi9/R9=/RYA]RiA^SIE_
S9A_RI1]Q8Y/P8E^PXI`QHP2LXF901EcQHUfQXYfQ8MePH9cNW]bMWI^Kfm[JFMWHf5VGU]TF5AQDTeP
CTQOBT=OASiO@SQN?C=O>biS>R]<9aY481D00T`Z7`0:Dc@ZFcheHTLoJ519KeUBMF9LO6]UPW=_RGah
ShF26_ooo`0:THn>TY:BTiJGU9VKUIbOUInSUZ>WUZF[UZR_UZ^b0YJ]]P0DUJniUK6lU;>oTK6mSjjj
RjRcQj>]Pj6[PinYQ9nXQJ2YQZ:YQj>ZRJB[RZ>YRZ2UR9^NR9NIRYVJS9^L0XjKW@0ET9bMTifMTiZJ
TiJET92>SX^8RH=oQ7]gP7=_O6eWNFIPMV1HMUaDMEQ?M5A9LTm3LDXmLDHhM4DeFC4SD2XM009F<RH0
2U`j<693>VM<@faDC75LEGITGW]/Ih1dKhEkN8Z3PA[oool02Xn>SY:DU9FIVYROX9^TYYjY[:6^/Z>c
^:Fh_ZNl``:X`LP05:W4cJ[8dZ[;eZS:eZO7dZ?1binka9bi`Yfg_ijg_Ynh_Z2i_j:j_j>j_jFi_JFf
^ZBb/jB^[jJ_/:Ra/@:Z/K405Jbb/Jnd/[2a[jn]ZZfVXZZQW:BHTin@RYZ8PYJ1NY9jLXmdJhmaIhi^
HhaYGXYUF8QODXILCHQJBVm7>FE0<`02J4Di00Y/Bd5`DTQcF4mfGeMiIEilJfEoLFb2Mg>5OGZ8Ph4L
oooo000Joooo00ZOSXRKS8JGRHBCQX6?Pgn;P7b6OGV2NWMnMWAiLg42MG1]01AaK6Y]JFMYIFAUHEmR
GUaNFeYMFeYLFeYKFeYJFe]JG5aJGEeJGUiJGemJH5mKH5iJGE]IFUIJFUIKFeL2G5aH01ENGEUOGEUO
G5MNFEAMEU5LE4iJDDYICDIGBD9FAT1F@ceF@3QE?CAE>C1E=R]F<bQG<BEK<29R<b=M;1]>81400TdR
5@0:FC4THC/`J4DjKdm5MUQ?OV9IQF]SSGE]U7igW8R16_ooo`0:UHn=Ti2@TY:BT9>ESYBGS9FIRYJK
R9NMQYNOQ9RQ0X6HXP08OYRSNiNTN9NUMI:PLXnLKHREJXJBJHFA0VR4T00:JHJ@JHNBJXRBJXVCJhVB
K8R@JhB:JX25Jh25KH:70Vn3Q`0ELHB8LhF8M8>6LWj0L7UjKWEeJfi^J6QVI65OHUaIHEMDH5=>Gdm9
GT]4GDHoG48iG3hdGS/_Hc/]F30RBB<F009691T02U4b:5Tl<f15?FI>AfeGDGAQFg]ZI85cKXQlN8n5
PA[oool02Y6?SY:CTi>FUiBJW9FMX9JQYIJTZINW[INZ/IN]]0:F[kP059Fa^iBb_Y:c`92_^hf/]hNS
[X>PZX:OZH:MYh>NYhBOYhFPZ8JQZ8NRZHRQZ8VPYHRKWhNGVXVHVX^JV`:>VY`05I2LWI:MWI>JVY:E
U8n?SHb9QhR2Oh=jMGibKGY/IWQVH7MRFWINEGAID7=EBW5?A6m:?Vm6>755=V<h:E@[7P02DB`P00YI
>2eP@CMUBD5ZDTY`FU=eHUajJfF0Lfn5NgR:Ph4Joooo00Z?ShjCUIFFVY^IX::MYZRPZjjR/;BU]K^W
^/2Y_lH2Z/?;01B[am6[bmF[cMVYb]FWam:Q_/RM^/:M^<2M][jN][jP]kjQ^KnR^KnT^[nU^KfV]kZU
/kFT[jnV/;2Y/K42Zk:a01F^/k:`];:a/Zn`[JV]YZ:ZX9^TV9>OT8VJQh2EPGVCNg:BMfjALfV?KfB=
JUj:IER7H5:4Fdb3F4UdBcaW@3<00VA0=00:JTPmKU16LUI=MEeEN6=LNfYSOg1[PWIbQGaiR8>07?oo
o`006_ooo`0:Whj8Vhb6UhV4TXJ1SX=nRGmlQGaiP7UfNgEcMW5_0W5]K006K6UXIfETHemOGUUIFeIG
EeEE1EEGE`09E5QHE5UIEEYJEEYJEE]JEUYIEEQFEUQEEeQE009HF5D05EYJEU]IEU]IE5YEDEQBCUM?
BeE=B5=9A596@594?E50>U8n=U8j<U4g;U8d:U8a9e@_8eH]8EX_8U`_8E/^7`02Eb`P00YI<BEO>RmV
@cU]CD=dEdelH5R4JV:<M6bCOWJKQh4Joooo00ZEShjCTI2BTY>@TiF>UIR<UYZ:Uib8Uij5V:22V:82
OiRS00MlV:AhUjEeU:=`SYe/R9MVPY1TPhl00VB2SP04IH:=IH>>IXB?IXB?0VN5S`05J8B=J8:9J7n6
JGn5Jh66009]PHH05Fn3Qg62Qg:1Q71lOfigNFYaLfQ/K6=UI65OGEmJF5iFDeiCCUe?BE]:A5]6?UY1
>ETm<eTh;U/g;5Tb9E<[7P02CBTN00YA<BMG>S5N@c]TCDE[ETmbGeUiJ6>0LVf8NgN?Q84Joooo00ZA
ShjBTi>DUiREVifFWj:GXZJGYZ^HZJnH[;>G[[L2U[6j01BE/kfC]<2A/l2>[[Z9Y[>2WZYoWJR0W:J0
W:F1W:F2WJJ3WZN4WjN5WjN6WjJ7WZ>6VYn6Ui^8V9Z:VI/2SIVK01F@W9bBW9fCVYVAU9>>SXb:QhF6
P7f0N7AlL6]iJfEgIV1gHe]fGeIdFU5bEDY`CdA]BSi[A3MY@CAT>R]K<2800U@^8@0:FCH[GSleI4Po
JE18KUUBM65KNFUTOg9^Q7YgRX>06_ooo`0:Shn>TiFEUi^LVj6SWZNZXZf`Y;>gYkRmZKg3Zl;90Zg7
c`0D[L_D[LoJ[M3KZl_FY/?>X;[3W;S1WKJoW[JnWkJmX;NnX[VoXkVoY;VnYKRmY[NjYK:eYK2aYk2`
Z[:b0Zbb/@0E[kFc/[Fc/k>`/JfY[ZJRZInKYIRBWhn8VHMoUX5iU7adU7U`TWE[Sg5USFaORVIIQV1B
PUU;OUE7MD`mJT0b009S?S402VU7>fe>A75EBgAKDgMRFgYXHWi_JX5eLHElNHR2P1coool001[oool0
2Yn>R9^<QYN9Q9:6PHj3OXUoO8ElNH1iMW]eLgIaK`9aKF`01VaYJ6MUI6=OGeiIFE]FEeMEE@EEEeL0
2EAHF5AIFEEJFUEJFUEKFUIJFEEHEUIHEEMHE@02F5QE01EJFUIKFEIKFEAJEE5HDTiGCd]ECDQCBDAB
AT1BA3eA@3YB?SIB>S9A=biB=2YB<BMD;b=F;B5J;b9L;b5K;Ql00UL/800:FC4UGcX_IT<iKDe3M5M=
O61HQ6YRS7A/TgifVhN16_ooo`0:UHn>Ti6@TY:CT9>ESYFHS9JJRYNLR9NNQIRPPYRR0WnHX`07O9RT
N9NUMIBSL8jMK8RGIX:@I8>?009TPXh016F2SFF3SVJ4SfJ4S`9WQHl01FR4SFR2RFQoQVUoQF^1QP02
KH6601E_PhMaPXMbPHA`O7m^MgUZLG=XK6aSIFAQGeeOFUQNEU=NDdiMCdUKBTAKASiJ@CUI?C=I>2iK
=baI<REC:ah00TdY7P0:DC4WEcXaGT<kI4e5JeI?LUmINFQSP79]R7]gShB16_ooo`0:THn>TY>CU9NH
UI^MUYnRUj:VUjJ[V:V_V:bcUjjg0YJa^P0DUK>mTkC0TK?0SZjjRJJcPYjZOifXP9bVP9bUPIbUPYfV
PijWQ9nWQInWQYnVQijSQYZOQYNKR9RJRYVK0XfIV`0ET9bLTYbMTiZITIBCSXj<RXN5QX1mP7QdO71[
NF]UMfIPMf=KMUmFM5YALUE:L4m4KDXnJd@gJD4dI3X[Fc0R009D;R402UTf:eho=FA8?fU@B6iIDWAQ
FgUYI7mbKXAjMhZ3P1[oool02Xn?SY>EUINKW9^QXijWZZ:]/:Bc]jNh_JVm`j_2b@:]all05:g;e:g?
fZg@fj_;eZK3cZ2j`ibh`Iff_ijf_Ynf_J2g_Z:i_j>i_jBi_ZFh_JJg^ZFb]JF`/JN`/:Zb/P://[40
5Jne/k:e/k>c/;6]ZJjVXZVOVjFHTYn?R9V7OiJ1NIAlM9AiL99eJhmaIHe/GhYVFHIPDX9IBgiEAgE<
?FY0<P02Hcha00YYAc]]CTAaED]dFe=gHU]jJ69nKfZ1MG65O7V8PX0Loooo000Joooo00ZOSXRKRhJF
R8BBQH6=PWj8Ogb3NgUnN7EiM79cL6h2KF]Z00MXIfIRHV=MGEiHF5UCDeAADE9@DU<0151CE09?De@2
CeAD00E@E5A@De=@E5=BEEADEeD00UEHEP0EEeUFF5QFF5MDEeA@EE1=DTe9DDY7D4Q3CT@oCD0kC3dg
CC/dCCPaCCD]CC8YCRlVCR`SD2XPDR/ODRPJDBDG009C:Ad02UL`95dh;F=1=f];@W9EC7YOEh9YHH]c
K9=mMY^7P1[oool02YF?SY>ATI:BU92DUXjEVHbFVhZGWXNHX8FIXX6IX`9nVJD02gZHYGFHYW6DXfb=
W6J3TV5nS5mnS61oS620S660S6:0S002HX6<00MSPHaSPH]SP8UTOXITOHAVOXAYP8H00V^1QP0EKH>7
L8:7L824KW]nJgEhIfmaIFY[HFASGUiLG5UGFeEBFe9>FTi9FDY4EdDnET0iEC/cE3H/Dc@YD2dQC2DI
009=:Qh02U0`9UDh;e]1>F9;@fUDCW1NF7QWHWmaK8MjMhj4PA[oool02Y6?Si>DU9FHVIJLWYNPXiRT
Z9VW[IV[/IV^]IRa^@:G/kd02iJe`9>g`i2d`8^/^HBQ[GnJYWbJYGfJYGjKY7nKY86LY@02PYfU00N3
WJF4W:>4Vj65V9f5UYZ7UiZ:VI/00XbJV`0ESibMTibMTiVITI>CSHf<R8J4Q7mlOgMcNg1[NF]UMfMP
Mf=LMEmGLeYAL5E;KTm4JdTmId8fI3lbGSHXEb`N009F<2<02UTf:Udm<f96?FM>AVeGD79PFWQXHgia
KHAjMXZ2P1[oool02Y2?SiBFUYRLWIbSYJ2Y[:B_/jNe^ZZk`:c0ajk6c@:`b]<05;3?f;3CgJoAg:_:
e:BnbIjg`I^e_Ybe_Yjf_Inf_J6h_Z:i_j>i_jBi_ZJh_:Ff^JFb]:F`/JRa/JZc/P:]/k805K2f];>e
/kBc/;:]ZJjVXZVNVZFGTIj>QiZ7OiN2NYInMIEkLI=gK91bIhe/H8UVFHEPDX1HBg]DAW=:>fXo<002
JD8d00YZAS]]CD9`DdYcFU5fHEUjIf5mKVV1MG24NgR8PX0Loooo000Joooo00ZOSXRJRhJFR8BAQH6<
PWj7Og^2NgQlMgEfLg5`KVh2JVUY00aSI6AKGemEFU]?E5E:CU19C4m9CDm:CU1:Ce5;Ce5;Ce1:Cdl2
BDi?00I9CDm9CTm:CDi;CTi=D51?De82DUED01EDEeIFEeEFEE=DDU1BCda@BdQ=B4E;A419@3a8?3Q8
>SA7=c58=Bi8<b]8<2M8;BA8:R599ae;9aa;8aM97Q400T`R5P0:DR`QFCD[H3lfJ4U0L5A;NEiFPFQP
RG9[TWefVhN06_ooo`0:UHn>Ti6ATY>DT9FGSiJJSIRMRYVOQiVQQ9ZSPIZU0WfJYP0DN9VWLYNVK9:Q
IHVHGWn>FWZ9FW^9Fg^9G7f:GGj:GWj:Ggj:GWj:Ggj9Ggb8Gg^6GgZ3H7V1Hg^2IWf30VUoQ@0EK8:7
KX:7Kgn3KGYnJWAgIVi`HFQYGF5QFeaKFEMFF5ABEe5=Ede9EDU4E4@nDSlhD3XbCc@[CS8XBbXOAR8F
00979AX02T`]8e8f;ETo=f19@VMBC6mLEgIVHGi`K8IjMXj4P1[oool02Y:@SiBDUIFIVYNMX9RRYIZV
ZYZY[i^]]9^`^9Zc_0:I]/0059Nh`i>ha8nc_hRY]GnLZGVGXgVGXWZHXWbIXgjJY7nKY82LY86LY86K
Xh:IXH6HWX:EVX:DV8FEV8RGVP:;VI/05HnLWI:LWI>IVI2CTXf<RhR5PX9mNWefLWY`JgQ[IGMWHGIS
G7AOEg5KDFiEBfa>A6Q8?FA1=F4m<E/d9UD[7@02E2`P00YG<bQK>c5PA3]UC4E[EDiaGUQgIf9mL6b3
NGJ9PX0Joooo00Z@T8nEUiNJWYnNYJJRZjjV/[FZ^;b]_/>`a<ZbbM42/loG01BddmfceMnadM^Zam:Q
^/FK];jJ];bL];bM][fO]kjQ^;jS^KnT^KjU^KfV]k^U]KRU/K>U/;2X/;6Z/[42[KBb01Fa][Be][Be
/jnc[JV_YZ6ZWYRTUY2OSXNKR86IQ7^HP7NFO7:DN6fALfN=KF69IeZ5Ge=oF4YjE4IcBC][@3400VU1
<`0:JTDiK4]0KU98LUQ@MEmHN6IPO6eXP7A`Q7]hR8:07?ooo`006_ooo`0:Whj9VX^6UXR4THF1S89o
QWilPG]hNgIeM79aKVe]0VMXJ@09Gf9TEEUJBU5C@T]??dM;@4M;@TU<A4Y=AD]>0096C4h02DI<CDA;
CD=:C498Bd=8BdA9BTE:BTQ=CD]@C`02CU=B01EAEUACEeECE59ADDm?C4Y<B4I9A496@3e4?3U2>3E2
=S92=2m2<Re2<BY2;RM2:b=39am291]38QQ37A946`l00THL400:CRPMEC8YGCddIDLoKU9:MeaEOfMP
R79ZTGaeVXN06_ooo`0:UI2>U9:BTiBETIJHSiNKSIVNRiZQR9^SQI^UPIbW0WbLZ@0DMi^ZL9BTIXbL
Fh:BDgR9DWJ6EGN6EgV7FGZ8FWb9Fgf9G7f9Fgb8FW^7FWV5FWN3FWJ0G7InGgR0HW^20VInQ00EJX67
KH:7KGj3JgUmIg=fHfa^GfIWFf1PF5YJEUIEEE9AE4m=Dda8DDQ3D4@nCShhC3PaBS8ZB2lWA2HL@b4F
00927a@02TPY7dlc:UHm=Ee7@6EABVeKEGEUH7e_JhEiMHj3P1[oool02Y:@SiBEUIJJViROXIZSYi^X
[9b//If`]Yfc^ibf_`:K^L@059Zlb9Fha8f__86S/7JGY7BCX7FDX7RFXGZGXWbIXgjKY82KY7nKXh2J
XGnGWgnEW7nCV82BUX>CUhJFV0::V9X05HjLWI:LWI>IV92CTXb;RXN3PH9lNGefLWY`JgM[IWIWHGAS
G7=OEg1JDFeEBfY>A6I7?F51=Edm<EPa9E</7P02D2LK00YD<2EH>BmN@CUSBT=YE4e_GEMeIV5lKf^2
N7F9PWlJoooo00ZAT92FV9RKWj2PYZRT[K2Y];R]^kn``/Ncb<jfc]D2^=?L01BjfN>if>6ddMZXa<jL
]/6H/K^I/[^J/kbM]KfP]kjR^KnT^[nU^[jV^KfU][ZU/kJT/;:T[k2W[jnZ/K02[[>b01Fb][Be][Bf
/jnd[JV_YZ6ZWYRUUY2PT8RMRX:KQGfIPGRGOG>ENFjAM6R>KV69IeZ4H5=nFD]iEDMbBC]/@c@00VHm
;`0:J4<fJTTnKE16L5M>M5iFMfENNfaWOg=_PgYgQh9o7?ooo`006_ooo`0:Whj9VXb6UXV4THJ2Rh9o
QWmlP7]iNGIeLg5aK6e]0VEXJ@09GF=VDeULADiB>dI<=3m6>498?4E:?dQ;@DU<0092BTd02D5:CCm9
Bci7BSa4Aca2ACe2A3m4AT=8BDQ=C@02Be5A01E?E5=@EEA@De9>Cdi<BTQ8AD=5@Cm1?3Xn>3Dm=38l
<Rhl<2`m;bXm;BLm:bDm:B8m9Ahl8ATl81Lk6A0l60h00T0I3P0:B2@KDBlVFCXbHTDmJe19M5]DOVIO
Qg5ZT7aeVXJ06_ooo`0:UI2?U9:BTiFFTYNJT9VMSYZPS9bSRIfUQIfXPIfZ0WfN[00:NIj_LIJVHXVJ
E7f>B763Bg62CgB4DWJ6EGV7Eg^80UUlR@08F7^8EgZ6EGJ2E7=oEG5lEg9kFWAlGgR00VAlP`0EJH26
Jh66K7j3JGQmIW9eH6]]G6AVF5mPEEUIDUADDE1?Cde;CdY7CDI2C48mBSdgB3LaAC8[@bhW?R@K?1lE
008m6a402T<V74/`:58j<eY5?V9?BF]IE7=TGga^JXAiMHf3P1[oool02Y:@T9FFUYRKW9ZPXibUZIjZ
[Yn^]:2b^J2f_Yni``:N_LP059k0cIZjaXb/^GbN[6f@Wfj?WG6AWWBDX7RFXG^IXgfJY7nKXgnKXWjI
XGfFWGbAVG^?UGf?U82@U8BCUP:9UiX05HjKW9:LWI>IV92BTXb;RHJ3P89lNGefLWY`JgM[IWEVHG9R
Fg5NEViID6]DBVQ>A6A8?Em1=U/l<U@a9Dl[7P02C2<G00Y@;B9E=RaK?cIQB45WDT]]FeIdIF1kKVZ2
N7F9PGlJoooo00ZATI2GVIVMX:6RZ:ZW/;:/]kZ`_/:daLZhc=:kd]T2_MSP01C0gnS0fn>dc]NU`<ZE
/KbC[[VF/;VI/[^L];bP]kjS^KnV^[nV^[jW^KfU][VT/[FR[[6S[JjU[JfY/:l2[[>a01Fc][Bf]kBg
];2e[JVaYZ6[WYRWUi2STHZPS8>MQgjKPWVHOW>FNFjBM6R>KV:9J5^4HE=oFTejETQaBC]Z@S@00V@i
:`0:IT0cJ4LlJdi4KUE<LUaEMV=MNV]VOW9^PgYfQh5o7?ooo`006_ooo`0:Whn9VXb7UXV5THJ2S8>0
QWmmP7]iNGIeLG5aJVa]0V9WJ@0DG6AXEUeRAe1E>4E;;Sa4<Sm5=d=8>TE:?TQ=?dU=?TQ;?DI9>D=6
=T55=3m4=Ci3=ci2>Sm2?TA5A4Y<0TU@D@0ECEADCeEECe=BCDm=BDU8ADA2@Chm?3Xh>CDc=c4_=bl]
=RdZ>2`X>BXV>2PS>2HP>2<M=b0I=adF<aH?=1<;008i5@`02T<Q6D`]9EHh<5m3?6U?Ag9JDgaUGXI`
JI1kM9V6P1[oool02YF@SiFCTiBFUi>HVi:JWi2LXXfNYHZOZ8JOZX:O[09nWjh02WZP/GFIZVB:VU5j
S45/P4E]OdYaPTidQ59hQeIjR09GNhP025EiQE9fPdmcP4m`OE1^NU9]N5I`NEafOP9RNh805FR0QV^1
QfanPfUhOFEbMEmZKE]SIEINGe9HFDmCDde?Cda;BT]8AT]5@DU0?4Ll=d@g<48b:cl]9SPS6cDK4P02
=QL=00Xn8QY6;BE>>35G@SaOCDMXF5=aHUijKFV4N7B=Ph0Joooo00ZCTI2FUiNIW9jLXZBNZ:^Q[K6R
/KNS][bS^L6R_LH2X/3;01BQ`lnO_<R=[;QiVjUURi]XRiY]SiaaTYifUJ5kVJ=mVZ=oVjAnVZ5lV9mi
U9agSiMgS9=iRi1lS922TI@2R9JI01F>VibBW9fCVIV@Ti:=RhV6Ph62O7UnMg=iL6afJfEdIV5aHEY_
GEI]F51ZDdYVCTARB3eN@SMJ?C9@<BE99QX00TLO4`0:C2TODS<YEcddGTHoI519JeYDLV=ONFeYPGMd
R85o6_ooo`0:TY6AV9ZJWZ:SY:Z/Z[:d/;Zm]L;6^LW>_M3F_mKM0/;Li00DaN7Za=cT]LgEX[g7SJ^h
Sj^fTjjhUk2iVkBlXKRnYKZoZ;c0ZK^oZ;ZmYKJiX[2dX:f_XJZ/XjZZZ:f]0Zfa/00E/kJc^;Nd^KB`
]ZjZ/jNQ[YnIZYVAYY>;XXf5WhQnW8=jV7icUGU^TWAXSVmRRVULQF9DP5a>NeM9L4/mISla009Q=RP0
2V<m<6I4>FU<@VaCBW1JDgARG7UZI7eaKH9iMXN1Oacoool001[oool02Yn?RI^<QiJ:QI67Phb4PHJ0
OX1lNWQgMW1aLFM[K09OIFP055UQI55JGd1<Dc=2BRTj@bhmAC=1B3Q4BS]8CD1<DD5=DD1<D3a9CCI4
BC10AC0n@S<n@SHm@CY0@d99B`98D5405DaEETmFEdmDE4a?CdQ9B4=2@D0n?C`i>3Lc<S<^;C8[:S4Y
9c8Y9S@X93@V8C<T7c8R73<O6C<M5c0H4RlC3002=18;00Xn7aM8:R=A=RmL@C]VCDI`F59jI5f4KfV?
NgBIQWlJoooo00ZFTHnFU9BEUiREVYfCW:6BWjF?X:R<XJ^8XJf2XJh2OJ6`01AiWZidV:UPQiU;MhXj
J7e0Jgi6Kh5;LX=@MhIFO8YIOXaJOhaHOHUBN8E<Lh19KW]<KGU>JgIAJgEJLg/2HGZ201EWP8M[PXQ/
OhEYNGiULgENJVeKI6IGGf1AF5U=DU9:CDi7BDQ7ATA7@d16?c]3>cI1=S0o<R`m;RLe91d_6A400S4D
2`0:>AlG@RXSBSD_Dd0jGD]6IUIAKf5MNFaXPgMdS89o6_ooo`0:Ti6AUiRHVijOWZBVXJZ]Y;2dY[Fj
Yk[0Ykg5Y/390ZC3cP0DXl;=X;g8S:ZgM9NVGXJGHhRHJHbJKXnLM9BPNiVSOibUPYjVPYbTOIRPMY>K
LhfEM8^BMHR>MhN<P8jA0XNEU`0ESY^MTifNU9ZJTYBCSXf:R8B1Q7ijP7QdNW5]MV]VLfEPKV1JKEaE
JeQ@JE=:IDi4H4PmGD8hFChcCS4VA2<I009171002TLV74h`9e@j<U]4?F9>B6UHDg5RGWQ/JH1gM8R1
Oa[oool02Y:BTIVKVj2TY:N/[Zfe]kBn`;W6b[k>d/;Ef/GKh@;7h>P05<SRjLWNiKK<e9ji`hNW]8^X
/hn[]IB^]iZb^Z6g_ZJk`:Zm`Jbl_jVi_:>d^9j]/Ij/[YjXZYnUYZJZZP:]/:l05KBe/kVg];^e/KV_
Z[JYX[2QVJfKTjVESJF?QZ69P9f4NYMmLiEiKY=dJ8m_HXYYG8ESEH5MCgaHBVm;?68l;P02GC8T00YP
>RiS@SMVBD1ZDDU^FE5cHEYgJ6=lLFb1NGF6PGhLoooo000Joooo00ZOShVKSHRGRhJCR8F=QH>8PX21
OGaiN7Q_LG9TJF/2Ff=W01AFGV9CG614D5Lc@d`V>D<[?DH`@DTeA4/iB4lnCE=4DUQ8E5U:EEY4DEDl
Be0gAd`hB4dlBDdnB4a3C4h2B55D01E<EUQ?EeU?EEI<Ce18BDU0?d0m?3`g=SHa;c0]:bX]:BP/9RD]
9B<`9B8a924a8Qh_81/^7AT/6QHX5A4X4Pd00RhA300:>AdG@bPRCC@^F40jHd]5KUMAN6=MPfmXSWYd
VHIo6_ooo`0:UY6@UiFEUiRJUYbOUYnSUJ:XTjB/SjF^RZB`Pj:`0WbQ/00DN9b/MYVXHHNIBGF9=VEj
?6Um@Vf0Ag62CWJ6E7^:Fh6?Gh:?HhB@GGn<DgR5CG9oCG5mDG1jDfihFWAl0V5jPP0EIh68K8>9KH66
JgYoIgEhGFU/FfEWEUmPCUMIBE1AAda=@dM7@dA3A44oA3lk@SXf?SHa?34/>2`V;R4K:AL@008[4PX0
2S@M5SdX8DHc;E0n>EU9A6=ED6ePG7Q[J89gLhb2Oa[oool02YBBTIRIVIfOXJ6VZ:B]/:Rc]j^i_Zbn
aJc2bZ[4c@:Ua<l05:?1bj:laX^Y]G2DY5V2U5n5UVF:V6^=Vg6BWWRHXX2MYXBOYhVQZ8>LXgVDWG>=
UG:<TgB9SgN7S7n=T0:7U9L05HjKWIBNWiJKViBEU9:@SHR3PHIoO89jMG]bKWAZIG5TGfaNFFYJE6UG
CfQCBVA=A618?Ue3>5Lm<TT^93hQ5`02?1T?00Y38aY9;BE@=c1G@S]OC4IWEU5_HEegJfQoMW>7PGhJ
oooo00ZCTY6KW9^RYJFZ[k2a^;Zh`LBoblk5dmO:fn3;h>H2bn?[01C:hNO:g>:dbM6I]L21X[26YK6<
Z;>B[;FH/;RN]K^U^KnX^[j^_KnY^KbP/KJKZZjIZ:^JY:JLXZ>UZ:L2[Jn]01Fd]K>j^;Fm][:k/J^j
[JFbXIVaWIF_VHnYTXVRRX2MQ7ZGOG>DNFfBM6R@L6:;JUb6I5J3Ge1lF4U/B3]N>B`00UT_8P0:G3P/
H3leHdLnIdm7K5M@LEmIMVMRNg1[PGQeQX1n7?ooo`006_ooo`0:X8n9W8f8V8b8U8Z6ShR5RXF3Ph1o
NgYjL79cH6EW0TmGG00DCUUNCUQN@TmG<D==8cQ3:3a6;T19<dA<=dM??4aC@U9IAeILCU]PDEeRCEYO
AUAH@E1E@4iB@Da@A4iA0TQBE@0EC5IID5QKDEQID5AECe9BB4U9@D94>CXk<34c;R`^:RPY9b<T:B<S
;2<Q<2@Q;b<O;B0L:a`H9aPD7a4>7`d9008W3PT02S<J5ChU84Ta;5@n>61:A6]FD7MRG89^J8ejM9R5
Oa[oool02YNAT9REUYRJViVNXIVRYYRUZiNX/9BZ/hnY]HFU/`9cVJX057:GZ72DY5n6UdIcR35RN3QW
Ncm[OTE`PD]dQ55hR5QoSUf2T6F6TfF5TEn0S5QiQ5=eP5=bO5IaNe]eO@9QNh805FR1R6f4RVn3R6in
PVejOFE_LF5ZKEYSIDiHFdUADdE<CSm5AT12@T4o?T<n>T4k=Shg<S/b;C@[9BLM61lB3@0290l800X^
6Q<g9Am1<2]<?3MFAd=QDdm[Ge]fJVN1MW>;PWlJoooo00ZETY6JVIZOXJ:SZ:ZX/;>/]k^`_/>ca<Zd
bM2ab]<2XKo;01BP_<NM]l:9Yk=/TZ9DOY5JPY=QQiIXS9U^T9aeU9mlVZB1WJJ8X:R5WZEoV:1hT9Qc
S9=dRHmiRHioSI42QiBG01F?VifEWYnHWIfGV9JFU92>QhB=Q828OWUkLfmeJfIaIF1YGEQXFE=WEDiX
DTUUCTAQBCmNA3UE?353:b8f7A@00SHF3@0:?R0HA2XSC3D^DcliG4Y4I5E@KEmKMFYWOWEbQh1n6_oo
o`0:U9>BW9bLY:NW[;6a]K^l_LG7aM3BcM[Mdn?Wen[_0/_Rj@0Db]kTa]SN//K>UK:mO9j/PZ6^RJJ`
SjZcUJjeVk6gX[JkYKRlZ[ZmY[JiX;2dVZV]UjFXV::TWZ>SYJNV0Zf^[@0E]KFc^kRe_[Nb_K:/_:jU
]Z:J]j6G]IfBZI>9XXZ0WXEkUWecTgQ]T7=WT6mRSFYLR6IGQV1AOEQ9JDHiF3HY009E;B402UTe:U`m
<V14>fA<AFUECViMEgAVHGY_Jh1gM8J0OQcoool001[oool02Z2@RYf?RYZ>RYJ<RI:;R8f8QXR5Q820
P7AfMfE[K@9@G64054ABFD=AF3];E2m2CB8hA2LlAba0BS54CSE5CcU:DSm@F4AFGTUJHDYJHTUIHDIG
GT=CFD5@ET9?E4A@E098DeL05DaGFe1IGE9JG59GF55EE51?CU1=C4i9B3ln?SXf=SHb<c0/;30Z:S0X
9c4V92lS8B`Q7RXM6R8E4a/?31P71@027`P500X/5Q8h8Qi5;b]A?3MMB4AYEE1eHEb1KFR<NGBHQGlJ
oooo00ZHTY6IUiNJW9fKX:>LYJVMZZnM[[FL/KZH/[j;ZkT2MI^[01AZTJ9VSIiGPI=3LHH_H7LfIGXl
JWe3Kh58LH==MHEDNhYJPHmNPi5OPY1LOheINhQEMX9DM7iGM7iKMWl2HWb401EXPHU]Q8]`Q8Y`P8A^
Ngi/M7E/LW9[KViHH65CEeQ>DU=5BDY4ATI3@T54@3a3?3Po>3<m<bha:B@R6aLH3PX00Q`9100:9aD@
<R4L?2dYB3TeDdE1GU5>JEiJMFYVP7IcRh9o6_ooo`0:UI>BVi^KXJ>TYZ^][;>f/Kbo]lC8_<cA`MCJ
^M3H0ZC0b`0DV[K2UK6lPZ6_J8nOD7^>Eh2AGXFDIX^IK8fJLI6LN9JPOI^TPIfUPI^TOINONI:JMHbD
MX^ANX^@P8jB0XREV00ESi^NUIjOV9jNV9VGUYB@Thb7U8V4ThIoP7MbNViYMVUTJemJJE]EJ5I?JE=:
Idm6Hd]1HDLkDcX`?bTQ;aTA008`4PT02SLM5ClW84La:dll=eQ8@f5CCVYNFWAYIWeeLXJ0OQ[oool0
2YBCTYfMWJJXZ:nc/kRn_l;9bl_EemKQi>7_l]o_l`;>h^L05<OIgl;CfJc2bY6^^WRJZGnNZhFS[HfY
/I>[/iN]/ija]j:e^JFf^J>c]j2_/i^Y[IRTYiZSY9nTY:JXY`:][jd05KFe/k^h];jg/[jb[;b]YKVU
W;VSVKZPUJRBRJ>;PIn6NiAlLY9gK91bIY5`HXm/GHaWF8]SDgaGB6I5>5<c:002D2XN00YD<RMG>S1L
@SUQBT9VDda/FeIbI61hKFYoMgB5P7hLoooo000Joooo00ZQTHbNT8bKT8bHShbESX^BSH^=RhZ9RHV5
R8UbN7/2H6a`01A?GVA6EUdkCEH_@dhR>4DV?4L[@4/aAe4fBeDhBeDjCEDnDEU1EEe2Ef11EEi0E5`o
DETnCeM2DEQ5DUL2B5AI01E<F5a@FEeBFUiBEeY@DeE>D51@CdiFDDmAC4]:A4=4?C`l=SHg<C4c;2/a
:BP`9R@]8R0[7a`Q5Q@I3PhE20L00QX50`0:9Q8?<alL@2dYCCXfFTM3IeA?Lf5LP6eXS7UcUhEo6_oo
o`0:V9>BVYRHW9jOWZ>VX:V]XZjdY;BkYK[2ZL;<U[>o0X>V]00DLINWIXfNDgjA@6n4;Emf<f=h>VQk
@Vn1B7>5C7F5D7N7E7b:Egn=F7n>EWb:E7V7DWF2Dg=oEgF0G7R10V9mQ@0EJ8:9KHB;L8B;L825KG]n
JgEgK7=cL79aIfUYGf5PFEUHCe1@BTY:AdE3AT8oAChj@SXf?cHa;bPT7aXG50h:008F1P402R0A3B`M
6SLZ9T<g<dm3@5]@C6MLFG=YIWmeLXZ1Oa[oool02YJDTibLW:>UYZV^[k2g^KO0`kk:c/KDfM3Qi[oC
f`:^am0059fh`i:^^G^MZfB<W4eiSEAmSe^2TVB9UV^=VW2@VgBBWGVFX7bIXWbHXGZDWGNAVGF=U7F:
T7^<TX6@U0:8UYT05I2KWIJMWiVNWYVIV9JCTI>=R9>:Q9B7P8UmMh9eKg]]Ig5SGFeNEfaIDF]FCFYA
B6M=@fA9?U0i;c/X82/I4@02:@h600Xa614i8ae2;RU;>SEEAD5NDDeXGEUbJ6ElM766OgdJoooo00ZE
U9>NWYjXZZZb]KFl`L76cLkAfM_NinW]n?[Pk_42dnCX01C6e]bkcMBS^lF;Z[IeV:IkVjR2X:Z:YJjA
Z;2F[;:K[[BP/KJR/kNR/KFO[K6LZJbJYJRKXZBPYJFVZJP2[Zn]01Ff]K:l]k>o]k:o/Zbm[JFiYYfi
XiRgWY>[U8ZUSH:OQW^EOG:DN6fDM6NCLF>BKEj@JUZ>IUEiEDMR@cI?<bL00T/V6`0:CRhTDSH]Echf
GDM0He1:JEUDL6=NMfaYOWIcQGmm7?ooo`006_ooo`0:XI:<Wi:=WI:>Vi:>VI:?UY:@U9:ATY:BT9BD
OH>60VYdN@0DFVM]CEeT?E5J;TEA8CY793]7:T1;;dI@=TaG?E=M@5IP@eUSAUeWBf5ZBV1ZB5mXAU]T
A5MOA5ELAEEK0TQEF`0EC5QMD5YODU]PDUQMCU9FBde@Bda=C4];BdQ8BTI6AD51?CTj>3<d=Bh_<RX[
<2HV;R<R:QlN7QHF5Pl@5@/:008D0`802Ql>32dL6S`[:4Xi=UQ6@fECCg9PG7m]J8]iLiN5Oa[oool0
2YVDTYbJVYjPXJ6VZ:B//:Nc^:Zj`:k1bKC;e:2kaP:<ZkP057VMZfV?We=oTSi_Q2aPMS1QMSQVNSm/
OTMbQ4iiRE=lReMnSEV1Sef3TEb1SeYoS5MkR5MgPeUhPeekQ09ROXL05FR1RVf4Rg65Rg62R6ejOfUc
MfQaLVM]KVAXJ61SHeYLFe9DDde>CDY8ATQ4@TI0?D@l>3lg<R`W91XI5a@@3@0240<000XI3@XU6AHb
9b@o=35<@CiICT]UFeQbJ6EnMG::PGhJoooo00ZGU9>NWIfUYjN//;6d^[bka<O4cm;=f]kHj>c7fMl2
]L[B01BR^lF@[KUhVjYPRIY<NHa@NhaHOhmPQI9XRiQ_T9adTiiiUImjUj5lV:5kUImiTiahSiMhS9=l
SiB2TiL2RINJ01F@VifFWIjIWYjKViZGTi:BS8VAR8>>Pgj9OGN4Mg5nKfUeIf1bHEY`G5A^F4m/E4Y/
D4EVBSm>>2le9Al[6Q<00R@;1@0::Q@><QlI?2/VASLbDD<oFdm;IU]HL6MTNg=aQGmm6_ooo`0:UYBC
X9nOZZ^[];Ng_l?3b]3@e]gNhn_]l__miO3c0]OTj00DamKL]/W@W[S2QjJbLiJTN9RTOibVQZ2YSJF]
TjV_V:^`WJfaW:fbWZfaW:Z^VjR[VZFWVj:TXJJVZ:^Z0Zna[P0E][Ba_;Jb_kNa`KB]_jjV^ZJM]j:H
/ibB[IF;Z8n4XXMlVh1dVG]_V7MYUg=UUW1PUVeLT6MFMeA5Fd0dCc<X009691T02TPZ8D`b:E8k<eQ4
?Em>B6IGDViQGGE[J7aeLXAoOAcoool001[oool02Z:BSJ6CSYnDT9jDTIfFTi^GUIZHUiVJVYZMWXZ?
T@9gOh<056EaMU=SJT5DGS57Db8lBB8jAbLnBRe3CS99E3U@FcmHHTENJ4QQK4YTKd]UL4YTKdMPJTEJ
Hd=FGTAFG096EU`05DYHGDmJGe=NHEMPHeILH4iAETQ:CTA5BDA4AT=1@d4n?c`i>SPd=CD_<3<[;38X
:C0U9BXO7alG618=3a082@023P0000XD1@DX6APh:BM8>3EFAT=TDe1aH5anKFR;NGBGQGlJoooo00ZJ
U9>MVi^QXZ>TZ:ZX[k>/]kb`_lFealnldMZ[`ld2U[:n01B1X[1/TZ9EP9<oKh@]H7L]GgDdHgLkJ7]2
KWm:M8EANhYGOheHPHmKPi9LPi5LPY1JOhaINhMJNhEMOHL2HGn801EWPHU/PhYaQH]eQX]dPHE]MgaV
L7APJFaOIFMMHF9IFe]CEEE?D4i<BTQ:ATA9@T18?c/o=S8[9b@F5aHA3`d00P/2000:30@27QDC;B@Q
>c8_BD0mETe:I5YHL6MUOGAbRX5n6_ooo`0:UiFDWijNYjRY[k:c]kbn`<O:bM?FdmoSg^c`cmoT0[_>
eP0DY[k8TJjjN9^YGhRIC7V<CGR9E7b;G86>HhJCJh^GLI6KMY>MMiFNNYJPNiFONiFMNY:JNi2GOY6G
Q9FI0XVHV`0ESiZLUIbMVIjMWIfLW9RFUXn<THR5RX5mQW]fPgIaOg1ZNFUSMVALLemFLEYAL5M=LEA9
IDTnC3L^<B@N:QXD008Q2`D02Qh;1bXI5CHW8d4d<4e1?EQ=BVAJEfmVI7YcL8EoOA[oool02YJEU:6P
X:^/[;Jh^<;5aLgBd][Oh>O^koKmo^[bm0;Ii>P05<OFg;C8cibf`8FT/7:FY7BEXG^HXh:LYHVPZ8nT
ZiFW[9RX[IRY[I^Y[Y^X[9bXZibVZInVZ:BYZJZ^[@:`/Jl05KJc/;^e/;je[l6d[L6`YkfXWkVSVK:L
TJjERZZ@QJJ:OZ64MiioLIajJiYfIYYcHi]`Gi1VEGABA5Po=50d:@02ARHK00Xn8a]5;BE<=c1C@C]K
BdISEE5[H5acJVMkM7:3OgdLoooo000Joooo00ZSThfRUI2QUY:QV9BPVINPViZPWYfPXJ2QY:FBV9X2
PHV=01A^NGmLJg98Ff@dBeLU?T`Q>TPU?4TY@D`_AE4dBeHiDE`mEV50FVE2G6Q3GFQ3G6Q2FVI2F692
EEe3EE`2AEEK01E8EE]<Eee@FUmEGF5JGf=KGF5GEe]<CU53A4Pn?T8l>chi=cXg=3Hf<C<f;c0d;2dd
:RXZ8R8N61X@3Q8;20/00Pl61`0:4PL89APH=RPWASPfEDI3He=@LF1LOVeXRWUdUhEo6_ooo`0:VYFC
WYbLXjBUYj^][;:f/;Zo]/?9_<cC`]KN//WC0Ynia00DRJNeLiNVFH>E@W65;f9i;5ic<F1d>6Eg?VYk
A6n0BWB4CgR8DW^;EGf=EWj=Egj=Egf;F7b:FW^7GGf80V5nR00EIH28JH68KX:8LhB8MhB7MWn2LgUk
J6mbGfIXFF1QEeYKDeIFD55@CTa:CDU7CDI3CD<o?SLc:RLU5QTI30h>008:1@@02PH101PA42PQ7cP`
;THn?5A<BV9JEfmWI7adLHV1OQ[oool02YREU:2OWjVZZ[6d]KZo`L?:c<gFfMSRiN?_lmCSj0;1d]T0
5:_1biB`_7VLZV69VTejSD]fR55hR5QmRen1SVJ6TVb:UG2>V7>@VgJBW7RCW7VCWG^CW7fCVh2CVHFF
V`:9V9/05HjIVi:JViJKVY^KVIjJUibDTIV>RXn5PHQmN8=fLH1`JW][I7QVGWEPEgAMDgEJD7EGC6=8
?T/f;S<V8BHI50027`d800XD1@8S5A4`8b0m<Bi9?S]EC4UQFEI]IF=iLW24OgdJoooo00ZFUIBQXJ2]
[Jfh^KW4a/K@dmCMhN7Zko3ho_o/loD2fnGY01C8embdaljK]Kn5Y;1cUZAbTYmhUImoVJ66W:><X:JA
XjRDYJVGYZ^IZ:bKZ:bMZJbOZJbSZjbV[:b//:h2/K:`01Fe/k2i]:jm/jg0/Z[2/:NoZZ6lYI^eWI>a
Uhb/THFYRgnTQWVQPG>NNfbMN6ROMFFPLf6=I5=cDD=L@CI=<bT00T8U6`0:<a/D?BLPAC8/CSdhEdQ3
H5=?JEiJLFUVNWAaPgil7?ooo`006_ooo`0:XiB>XiJAY9RDY9^GY9fJY:2NYJ>RYZJVZ:Z[VinP0X^A
U@0DMX66Hg5hCV1Z>DmL9d5?83U88CY79Se9:d5=;dEA<dYE=diI>U9M>eAP?EEQ?EIR?EEP?UAO?U9L
@59J0T9BFP0EA5=JAeAJBeEJCeMLE5UMEUYMF5ULEeMIDe9DC4]=AdA6@Sm1@3`n>cHh>38d=Rl`=Rh^
;BDW8QdO5aHI3PlB008>2Pd02Q492b<I6S@Y:DDh=eA7AF=DDG1QGGi]JHYjM9N5P1[oool02Y^EU:2M
WJFUYZZ][jne^;Fn`[[7c<7@elSJhKW=eP:W_lT058n]^GVKZUn7VDMdRC5TNb]MLbiMLSAQM3YUMd1Z
NdE^OTUbPTefQE1hR59jRE=kRUEkREIkREQkR5]lQ`9OOHL05F9nQfInQVYnQFioQ79oPg=nP7AkOG5f
Mfa_L6EXJ5mPH5YKFUMFE59@CU5<BU19ATm6@Clh=BdZ:1/M7@d@40021PH600X2000C3`hT7ahe;Re4
?CaCC4YQFEM_IfAlM769PGhJoooo00ZHUYFQX:2ZZj^c][Nm`L;7c<kAf=_LiNSWlOGHiNX2amOM01B_
aLfH/kinWjeUS9a?O8i:MHM>MHEENXQLOHYRPXeWQI1/RI=`S9IcSiUfT9YhTYajTi]mU9^0UI^4UY/2
RIRK01F<V9Z@V9VDV9NGV9JJUYBJU92JT8^FRXF@Pgf9NgF5M6eoKVMmJF1iI5YiH5IiGE9gFDeSB3m<
>30g:2<T6AD00QP;200:3P<0714>:R0M>2h/AS`jDdY8H5QEK6ESN79`Q7im6_ooo`0:UiFDXZ6Q[Zj]
^KZjaLO7d]GEgn;Rk?3`n_kokO?e0]kWjP0DbMSL]LS>WKJoQjFaMINTLY6NMY:MO9JNPiVPRIbRSYnT
TZ:WUZFYVJN[W:R/WZZ^XJ^^YJf^ZJn_[K6`0[:c/00E]K>_^;>]^k:[_[6X`:jU_jZQ_ZJL^J2E/iV=
[Y:6ZXaoYHMiY89cXGe]XWYZXgMVXG=QRf9BLe53GD4fBC0W008j8AT02R/G43DR73l^:DTj=E=6@EeA
CFILFG1XIGUcL89nO1coool001[oool02ZBDSjFGTZJJUZJMVZNPWZVTXZZWYZb[Zjf_[inSY0:AUiX0
3gj8SFUgOeAUKciDH2Y3DQliB1lgAB<jAbLnBR]1CBi5DC58E3A;ESE=FCM>FP02>4mK00<iCeXjCUPk
CUP00Se>E`0E@4iF@TmFAU1GBE9GCE=HD5AHDUAGDU=FDU5DD4iAC4Y<ATA6@Si0?SXk>cHg>C8c=Rl`
;bT[9b8U7a`O5QDH008A3Q802Q4;3B4H6C@Z:dDj>EE8Af=FDg5RGgi^JX]jMIN6P1[oool02Y^FU:6N
WZJVYjb_/K:h^[S1aKo:clGCf/cMi;g@f0:/`l`059Jb_WjO[VF;W4ahS3IWOBYLLb]KKc1NLCIRM3aV
Md5ZNTE]ODQ`P4]cPdefQDmhQe5hQe=iQeIjQeUjQ`9LNhH05EmkQ69kPfEkPVUkPFakOfiiOFmgNVid
MVa_L6U[JfAUI5iOGE]IEeMDDUE@CE=<B4i6@Sli=Rl/:R4P7a4C4`021@L800X0000>2``Q7Adc;Re3
?CaBBdYPFEM^IfAlM769PGhJoooo00ZIUYFRXJ2/[:be]kRo`lC9c]3DfmgOin[Zm?OKi^/2b]WO01Bd
b=2L]/23XZmZSimDOi19M8I;Lh=BMXEHNXMOOXYTPXeYQY1]RI=aS9IdSiQgTIYiTY]mTi^0UI^4UY/2
R9NK01F;UYV>UYNAUYFDUI>GTi6GTHjGSHVERHBBQ7j>OWR9N724LFV1K6=oJ5inHeUlGeAfF4aRB3m<
>34i:B@T6QH00Q@;2@0:2@405@`:9AdK=B`Z@c/iDDU7GUMEJfARMg5`Pgim6_ooo`0:UiFDXj:Q[Zj]
^[^jalS8dmGEh>?SkO7anoook_Ce0^3XjP0Dc=WM]lW?XKS0S:NcNYVVLI6MLi2JNY>LPIJMQiVOS9fR
TJ2UUJ>WVJJZW:V/Wj^^Xjf_YZn`Z[6a[[:a0[:d/@0E]K>^^;:/^[6Z_JnW_ZfT_ZZP_JFK^Z2E]IZ>
/YF8[Hj1ZHUjZ8AeYh5`Yge/YWYXWg9PRF1ALDm2G3ldABhV008c7aP02RDD3b`L5cPY9D@f<Tm3?eY?
C6AKF6iWI7QbL89nO1coool001[oool02ZFESjJHU:RLV:VPW:^TXJfXYZj/Zk6`/;>e]JFYZ`:GWJ40
58F?U75oQUU/MT=JIRm8Eb0kBQ`eA20gAB@jAbLmBBXoBba3Cbi5DC17DS58E399EC=:ESA:ESE:E3I:
E08hBU<05CY:Dce:DT1;Dd==DdI>E4U>E4]>Dda>Dd]=DDY:CTQ7BTA3AT0o@Cdk?C/h>SXe=cHa<c0/
;RTW:R8Q9A`K7`025QDJ00XF4aHS71hf;Rm7?CeFBdYUF5EbI65oKfb;NgJGQX0Joooo00ZLUYFRWijX
Z:R^/K:e^[bl`lO2cM7:emcAhNS1dm/2/LK@01BL]l:5YK=[TJ5BOY4kK84/GWDXF6h]FflcGg4hHW<m
IWI1JWY4KGe7Kgm:LX9<M8A>MHE@MhICMhEEN8D2F7V401EKN89NN85QN7mTMgiWMgeYMWYZLgMZLG=X
KFmVJFYSI6AOH5mLFeUIEUAGDe1ECT]<AT8n>SL`;R`R8R8D5QH00PL:300:0@<430X;81dM<Rh]@cdl
DTa:H5YHKVMUO7AbRH5n6_ooo`0:VIJEXj:Q[Jf]]kRi`LC5c=3Be]cNh^W[kOKigNS/0/gKh@0D^<cC
X[[4R:NcL9BSFX>DBgJ8BG61CgB2EWR4G7^7HWn9IX>>JhJAKhVCLXfGMHnINI6JO9>KOiBKPiFK0XJF
V@0ERIFGRiBESY>CTI:AU96?U8n;U8^7ThN2T8=mSWigRgUaR7A[Q6iUPVYPPFILOf5FLeI;GTLnBcPa
>2TT91XG008A30X02PL20@h81b4J6C8[:T4j>Dm9AeeFEFYTHWMaL8=nOA[oool02YNEU:>RXJn_[[^k
^lS8b=CFeN7ShnoalOcoonocm0;Qj>X05<oKg[_;dJFk`Y6[]GjLZ7>BWW6>V7RAVGnDVhFHWH^KX92O
Y9FSYYVVZIfY[:2/[jB^/:R`/Jbb/K2c/P:c];005KFb[[Ra[;Z`ZKb^Y[f/XkfYWkbTV[ZPU;NKSkBF
RK:APjn<OJf7Mjb3Lj^0KZUkJI]_GHAMCVi=@5Tm<d8]9@02;AdG00XO4PhS5Q8b9B8o=31;@CiGCT]R
FUM]IVAgLW21OG`Loooo000Joooo00ZUUHnVV9BXW9RYX9b[Y:6]Z:J^[:^a/;2c]KFUZJ/2UifQ01B5
SiAaOhIIK7I3FVH_B5LP>dXL=D@P=dDT>TLW?DTZ?d//@dl^AE4`Ae8aB5@bBEDcBUHdBUHeBU@fBU@2
>4YC01DjBU<mBU90Be=3CE=6CUA9CUA;CU=<CU=;CE5:BTi8AdY4@dI0?d4m>cdk>3Xj=CLf<C<`;2hY
9bXR8BDL6al00QHE6P0:5Q<F8a`N=Rh_AcdmET]:IEQELVAQOfm/Rg]fUhJ06_ooo`0:W9JEXYnNZ:RX
[[6b]KZl_<?7`/gAb]OLdN7X`M?K0[76d00DW;O2QJFcJi6QDWjA>fb1;5ie:5Q^;E]_<ema>69c?FIf
@FYjA6emAfmoBW:2C7B4CWF5D7N6DgN5EGR50UQiQ00EFgR2GWR1HGQoI7MnIgMmJGIjJW=gJW5cJ6e_
IVUZHfATGf1OG5]IFEIDEe=@EDi;C4I2?SXg<2h/8R8R51HF00872P`02P4310`:2b0M7C8^;D<m?59<
BV1JF6iWIGadLXV1OQ[oool02YVFUJ>RXJf][KNh^L74aLc@d]KLg^;YjngfnMgXk0;=fn405;S<dj:j
a8RW/g2DXeZ3U4]fR4UaPDmdPUIhQ5akQf9oRFJ3SV^6TFn9Tg:=UgF?VGVAVWbCVgnDVh>EV`:6UYT0
5HVEUh^DUHjCTi6BTIBASiB?RiB;Qi>7PY23OHinMh]iLHQdJhA^IH9ZH85VG7mQEW=FBei7?T/h<CPY
92@J5`024@`:00X70P4>20LQ6QTb:bY1>SU?BDMMEUEZI69gLG23OWdJoooo00ZGUIBSXZ6_[jjk^k_8
b<SDe]GQhn?_lO7looo_lo@2hNSZ01C?fmjkbm6U^l:AZkEnW:QcTYiaSYQhTIUoU9^5V9f;Vj2@WjBE
XjJIYZVMZJbP[:nT[[2X/;6//[6`/k82/kB`01Fe/Zjh/Jbj/:Vl[ZJm[:>mZInlY9ZjX9BgVhndUXVb
TH>_S7f]QgN/Pg>[P6jYNfVKKef4GDi^CD1I?C=2;BD00RdM5`0:7a8>8aHB<RDR?c@`Bd4nEdi;HUYG
KFITMg9`PGel7?ooo`006_ooo`0:YIF@YiZEZIjJ[::O[ZNT/:^Y/k2_]KFe^KZkZjj`0YbSYP0DS9JK
NHJ>HgAnCF9^>55O9d9B7CM77SI48CM593U69S]7:3e9:D1<:d5>;4=@;DA@;TAA;dEA<4EA<DE@0S=5
C`0E=DE?=dI?>TI??4M?@4Q?@dU@A4U?ATU>ATQ=ADM;A4A9@d96@Cm2@3`o?SXl?CPj>SDg=30c;R/_
:BL[92<W008O7b@02QlN8RTT9c/d=T]2@UU>CFMJF7=VHh1aKHalMiR7PA[oool02YfGUJ>PWjZYZK6b
];Rl_[o6bLK?e<kJgmKTjlKGgP:eb]<05::lahf[^7BHYe^4Ud=bQc9TNRQIKb]IKC5LKcEOLCYRLceV
MT5YNT=/ODI_P4QaPD]cPdedQ4meQ59fP`9DMX805EMeP5UdOUadOEmdNf9cNFAbMfE`M6E]LFE[KF=X
JF9TI61PH5eLFUaHEU]EDUM?C4e6@Slk>34_;B@T91LI6@022`l@00X520T=3@hR820c<2m3?ciBCDaQ
FUU^J6IlM7:9PGlJoooo00ZJUiFTXZ6^[Zfh^K[3aLK>dM?Ig^3Tjng`n?[Pj^h2d=gS01BmcmJX_lR@
[;QgVJMPR9QANXa8LH9=LX5DMH9JNHEPO8MUP8]YQ8m]R99aRiEdSYMgT9UkTYYnTiZ1U9X2Q9BH01F7
TiJ9TYB<TI6>T8n@SXbBS8VARHFAQH6@PWb>OWN<NG::MFf7L6N6K6:5J5eoHEI`E4YLASe9=c0f:B@R
6QL00Q0<300:1@<32`L77aXJ<2/Z@3XiCTU7G5MEJFASMW5`Pgim6_ooo`0:UiFDXj:Q[jn^_;bkb<W8
eMKEh^CSl?7aoOool??d0^;XjP0DdMcO_lkCZkk5UZjgPinZMiFPL8fHMXnHOY>JQ9JLRYZOT9jRUJ:V
VJJYWJZ]XJb_YJn`ZK6b[K>b/;Bb0[>d/00E]K:^^;6[^ZnX^jfU_J^R_JRN_:BI^YnD^Ib?]iN9]I:4
/hio/8Ui/8Ed[X5_Z7YWUF]JP5Y<JDXnDcX`?2TR008W6QD02QT?31`A3RdR7c/b;dTo?EE=BV1IEf]U
HgIaKh5mNacoool001[oool02ZJFT:VKUZ^PVjjUXK6ZYkB_[KNd/kZi^Kfo`;2d]P:RZ:`059:LXH2=
UF]lQEAYMCmGIBi8Eb4lBadfA1lf@b4gA28hA2@hABDjARHlBBLnBbLoC2PoC2U0C2]0CBa1C08]@D/0
5Bm0Bc50BSA1BcM2BcY3C3e5C3i5C415Bd54BT54BD52Ad51AD0o@clm@3ll?clk?C/g>SPe>3<a=C0^
<R`[;`02:2P]00XZ:Bdf<SE2?3i@AdQMDe9YGUaeJ6J1Lfn=OGRHQh8Joooo00ZMUiFTX:2[ZZZb];Fj
_/32b<_9d]KAg>7Iing:f^42^LgF01BX`<^D/;emWZeRRYa;N8`iJGh/GG<[FFd_FfdcGVlgH74jHg<m
IWI0JGY3K7e5KWm7L81:LX5<Lh9?Lh42D7=o01EBLWeELG]HLGYJL7UML7IPKgEQKG9QJfmQJF]QIVQQ
HfAPH61NGEaMFEMKEU=FCda;AD90>cTc<2lV9RDJ6a/00PlB4`0:2P`=5QDF9R@T=S<bAD50E4m=HUaJ
KfQWO7EcRH5o6_ooo`0:VYNEY::R[jj^^KZja<K7cm?DfmoQi^c^l_Wkhnc_0];Oi00D`M;I[L?<Uk6l
OIj[IhfLEgn@C7B5CG60DgB1FGR4GW^6Hgj9J8:<K8J@L8ZDLhfFMXnGNY6IOI:IP9>I0X:CU`0EQ96D
Qi2ARXn?S8j=SXb:ShZ7ShN4ShB0Sh5kSWegSGYbRgE]RG9XR6eSQFQMO5mDK598FT@lASD_<bLS81TG
008>30`02P<20`h<320L730/:clk>Ti9B5aGEVUTHgIaL8=nOA[oool02YREU:BRXK2_[Kbk^/W9b=KF
eN?Tho3al?koo_7dm0;Rj>X05=CMh<?@eK71b9Za^XRS[G^HXg>@VWJ>UgfBVHBFW8ZJWY2NXIFRYIZV
ZIjZ[:>][jN`/JZb/Zjc/k6d/P:d];005KFb[KN`Z[Z^Yk^]Y;bZX;fWWKbSV;^PU;ZLSkVHR[NDQKF?
OkB;N[>7MJj1Kj=fI8mVEWYGBF95>T`e;CDU7P028AHB00XA2@HJ4@lZ8Qli<Bi7?caCC4YOFEM[IF=f
LFn1OG/Loooo000Joooo00ZVUi6ZW9N]XIf`Yj>d[JZh/[2k^;No_Kg2`l>d^;X2Yjf`00^HXJJ7U9]d
PheMLWe6GfdbCUhU@E8N>4PM=D@N=D<O=D<00R0f@P038CM48SQ58SU7008S>TL06B@jAbHkAbPkAbPk
AbTlAb/lAbhmAc4oB3A0B3M1BCU1BC]1BCa2BCi2B3m2Acm0ASm0A40o@d4o@T0m@Cll?c`j?CTh>cDe
>C8b=P02;bld00X^;34l>Ca9@dEECDiQEeI/HEmhJfR3MG6>OWZIR88Joooo00ZMUiFUXJ2/Zj^d]KJl
_l74b/c=e=SEgn?MjNk>gN<2_]3H01B]a<jK]/:4Y;9/TJ9COi8nKX@aHWP/Ffl^FVhaGFleGg0hHG8k
Hg@mIWLoJGY2K7a4KGe6Kgm8Kgi:L7h2CFml01E>Kg]@KWUCKWMFKGIIKGAKK79MJg1NJFeOIfYOIFMO
HfAOH61NGUeNFUQLEU=DCT];AD<o>cTd<S0W9bLK7Ad00Q4D5@0:2P/=6a/K:RTY>CHfB4A3EU5?HeeL
L6YXOGIdRX9o6_ooo`0:VYNFYJ>R[jj^^[^jaLO7dM?DgN3QjNg_mO[liNka0]GQiP0DaMGK]<O?W[K0
QJBaKi>RG8>DDGV9Cg>2DgB1F7N3GWZ6HWf8Ih6;JhF>KhRBLXbEMHjFNI2HNi2GOY6G0X6@U@0EPXnB
Q8j@Qhb=RH^;RhV8SHR5SHF2SH9nSWmjSGefSGYbS7I]Rg9YRFiSQ6MMMeaBJ4m7E44j@S@^;bDR71LF
008;2`/02P000A4@424O7c4^;T0l?4i:BUaHEfUUI7IbL8=nOA[oool02YREU:BRX;2^[Kbk^/W8amKF
e>?Sh_7al?oooO7dm0;SjNX05=KNhLSCekG4bZ2e_8nW/7nKYGRCWGR?V7jBVHFFVh^JWY6NXYJRYI^V
ZJ2Z[:B^/:R`/Jbc/jnd/k:e/P:d/jl05KFa[;N_ZKV]Y[Z[XkbXWkbVW;bSV;^OTk^KS[ZHR[VDQKN@
P;J<Nk:6M:]nK9aaH8UQDg5AA5]1=T@`:BhP6`026Q4>00X;10<K4a8Z8R0h<Bm5?ceBC4YNFEMZIF=e
LFn1OG`Loooo000Joooo00ZWUi6[WIR_XincZJFg[jbk][C0_K_5a<?9bLZk_/02[[>f00bOYjb@Vj9l
RiAVNHA@IgDiEFDXAULN>DXK=4@K<d8L<d4L<T02738o00HM<SlM<d4M=44M=48N=D8O=T<28CE201DR
=T8U=d<X>D@[>TD_>dDb?DHe?dLg?dLi?dLk?dLl@4Hm@4Hm@4Dn?dA0@4E0?dA0?d<n?D8l>d0i>Clf
=cd00SHg?00:=cDjA413CdY;FU=CIEaKL6ESNVi[QGMcSh1kVHR36_ooo`0:WYNFYZ6P[Zb[][Jf_/32
al_=d=OJfN;Vh^gadn3W0/CDf`0D/lSAX[_6S:ZhMIRXGHJHAWF9=VQm;Eeb;EY^<5a^<ee`=Uma>65b
>V=d?6Ig?VQi@6Yk@V]l@fakAVek0TQ/N@0EBF]gC6YfCVYdDFYcEFUbEfU`FFU^FfM/G6EYGFAVGV9S
GV1PGEeMG5UHFEABDDe:B4A2?C/i<S4a9bLX6adN008B5QL02Pl@4B0P82l];Cdj>T]7AUQCDVEOGW5[
JGigM8Z2P1[oool02YZGUZFSX[2_[[^k^/K7am;De=kQh^__l?SloNS`lP;IhnL05<WGgKW;dZBka8jZ
]GRIYfB9VEMnSU5fQE=dPUQgPeejQF9mR6J0RVZ4SFj7T76:TgF<UGN>UWZ?UGb@U@9nSY<05H2<T8:;
SXB:RhJ9RHV7QXZ6Ph^4PHb1OHaoNHelMHeiLXafKHYbJHI/HWmTFW5HCf5<A4ln>3da;2/S8ALE5002
20T:00X10P<D4a@T8R<c<351?Si?C4]MFEQZIVEgLW63OgdJoooo00ZGUIBSXJ2`[Zfl^kW9b<KFeM?S
hn7al>oooogam?<2iNWZ01CHgn7;eMRialbW^L2F[;B6WjUoV:5kTY]oTYZ6Uib<VinBWj:HXjFMYjVQ
ZjfU[k2Z/K:]/k>`];:b];42];>_01Ff/:^g[ZRh[:FiZZ:kYijkYIZkXYNkWY:kVhjjUhVjU8FiT82f
RgZ`Q7:VNVVDJeb0G4iYBd1C>c8m:bDV6QH00Q8<2P0:2@<36QDC:R<R>38`AClnDTa;GUUGJVETMG5`
P7el7?ooo`006_ooo`0:YiNB[9jI/:BP]J^W^K:__[Vga<2obLS7cm3@`lK80[Fj_@0DYZjcUZ6XPi:J
KX2;F6ml@Ea/;TaM7ce>6SA56C92634o62lm62hl62hk5bhl5blm630n630o630n6C0n0QX`?P0E730n
7S908CA09CE1:CM2;3U4<3]5<ca6=Ci6>3i6>Sm6?416?D16?d57@D=8@T=8@d=8@d=7@D97@415?Sm4
008o@4D02TE4BDa9C5I@DV1HFFYPH7=YIgeaKXMiMI21O9Z9Q1[oool02YjHUZJRXJn/[;Ng]l31`/W<
c];HfmgTinO`m=WUj`;9fMl05;W<eJS0bYB`_GfN[FN=We1lT3i_Q31QMbeKL2mLKc5ML3ANL3IPLSQR
LcUTMC]VMceXNCmYNT1YND5YN093J7H05DAWM4IVLdUVLTaWLE1VKe=VKUEVK5QUJUYTJ5]SIUeQHeeP
H5aMG5YHEeICDDi;BTI3@Sdk>C<b<BPX:1dO7`025ALH00XK6a`W9RLd<S91?Si>BTUKEUEWHF1cK6]o
N7F:Ph0Joooo00ZJUiJUXj:`[jjk^k[7alOCe=COhN;/ko3jo_k/l_D2gNKY01C>f]nnc]F/`<VF[kZ2
X:a^T9iPQIAENXUDMHAHN8AMNhIROHQVP8YZPhe]QXmaRI5dRiAfSIEhSIAjSI<2O8b@01EmRXeoR8^1
QhV3QXN6QHB7Ph69PWn;Ogb;OWV<NgF=N76<MFf9LFR3JF1iH5MZE4aJB45:>cHh;R/V81lB4Q800P@6
200:2@X;61PI9bHV=C@d@d51DDi=GUYJJfMVMg=bPgmn6_ooo`0:UiFDXj6P[jf/^kZhb<O5eMCBh^7O
l>o]ooklloCd0^OZjP0Dfn3Qc]KI_l_?[Kg3W[6gSjF]QijWOiJNPIBKQiRMSYbPU:2SVJBWWZRZXjb]
Yjn_Zk6a[[Bb/KBb/kB`0[Bb[@0E]JnY]ZfV]j^S^:VP^ZJM^ZBI^j6E^ifA^i^=^iN9^i>4^I1o]8Yh
Zh1_WGATRVEFMEE9H4HkBSH^<bDP6a@A008810<02P`71a`G5RXU93Pc<TE0?e9=C5iJF6YVI7EbL81m
O1coool001[oool02ZRHTZfOV[6UXKN]ZKbd/L6l^LO4`/k<c=GFe/_>d0:l`/D05:je^YnY[hbJXgN9
U65gQ4aUMCMDIBE4EQXgBALa@QD_?a@]?A@/>a<[>Q8[>Q4Z>Q4[>Q8/?14[>a8[>`8C:c/05A@/>QL]
>aX_?Alb?b<c@2Lf@B/h@bhjA38lASDnAcU0B3a1BCm3BD54Bd=6C4A7C4E7CDM8CDI7CDA6Bd94B@02
?d1500Y;BDeDD5=LEeQUGUi^IFAgK6^0M769NgNBPWjJRX@Joooo00ZNV9JWXZ6_[:bh]kO1`/?;cLoE
fM_Oi^SZloKPjo02d=kT01C0d]Zaa/nM]l:7Y[AaUJELQIM8Mh/gJ7h_GW<^G70`GG4bGW0dGg8eH7<g
HW@gHgDiIGHkIgPkIWLlIGH2?FEd01DoHg51HW14Hfm7Hfi;Hfe>HfaAHfYDHfUGHfMIHVELHF=MH65L
G5aHEeMCDE1;BTU3@T4l>cXb<S8W:2TL7b000Q<E5P0:8B4R;B`/>SPgAT=2DTi=GUUGJF=RMFi/P7Uf
Rh>16_ooo`0:VYNEYJ:Q/:j]^kZjalO6dmCCgn7QkNo_noknlOKh0^;Zk00DdmkSaM?I/lG=WkFoRjJa
NYRVJXbKG82?EgV7FWV6GW^7HWj9IX2;JX>=KHJ?L8R@LXZBMHbDMhbCN8^A0WV9SP0ENXN:NhF8OHB6
P8B5PX:2Q85oQgmmR7ijRWagRgYdS7QaRgE]QfmVOFIMLUaDHU19DT@nA3Pd<R/Y81dL3@l@00800P@0
2Pl@4AdM7R/Z:cPg=dI4A5=@D5mLG6aXIgQdLhAoOQ[oool02YNETj>QWjn]Zk^i]lO5`mCBd>7OgNo]
jogln_Kem0;YjnX05=gRh];IflC>d;G1aZJe^iV//XnTZhJKXhFGWXZJWi2NXYJQY9bUZ:6YZZF/[JV_
[jba/K2d/[:d/KBc[`:d/J`05KB]Z;F[Y;JYXKNWWkVTVkVRUkZOTk^LT;^JS;^FQkZBPkN>OK26MJAj
JYA]GWmNDFY>@eLo=T4`:BTN6a<>3@020`0000X@3@`N6QT/:2Li=CA6@T5CCTeOFeUZIVEeLW61OG`L
oooo000Joooo00ZXV9:]WiZcYZ:h[ZZn][?4_[c;alGBd<oJf][CeML2a/_>016f_/>W/KRFXj^2TYe]
PHeJLGm6H70`CUlO?U4G=4HD;T0B:c`@:CX>:3T=9cP<9cP;9SP00P/W>@0H2RHh2bLh2bLh3RLh4BPh
52/j6Bhl7C4n8C=09SE2:cQ4;c]6<ci8>419?TA<@DI>A4U@B4]BBDaBBDaCBTeCBdeCBTeBBdaA0TQ8
C00:DU5DFeMJHeeOJf=TLfYYNg1^PgMdRgeiThAoVhZ56_ooo`0:WYRFYj:Q/:b/^KNg`/;2c<k?e][K
hNKYkOCginoc0]STjP0Ab=SO^<cEYkk8TZjjOIf/JXnPEh6C@g:6=FEj<5md<5ib<Eea<Uib<emb=61c
=F5d=F9d008gI7H063MRLcQQLCQQLCUPKcaOKCiOK49PK4IPJdYQJDiPJ55PIeAQIUMQIEYPHUaPH5YL
G5MGEU5AD4Y:BD92@CXj>S4b<RLY:QlR8P8I6QX02RLW9c@b<Slm?4]7AUIBD65LFVaVI7I`KX5jN8b4
PA[oool02YZGUJFRXK2^[K^j^LO6aM?Cd]oPh>c^k__moOGin@;Xk_005=WSi/_GgK_;dJRla9F]]hFQ
[7JEXVN9UeioSEelREmmRF=nRVN1RfZ3SFf5SVn7T768TGB;TWJ;TWF8SP9fQX/05GJ4R7R2QWV1Q7b1
PWn0P85nOHAmNhIkN8QkMXUiLhUfKhQcJh9[HgMRFV]HDEa<ATa0?3dd<B`X9QTJ6P`>40020PD700XC
51HQ8R<_;Rll>c]9AdMEDe9QGUi]JVUiMGB4P7lJoooo00ZGU9>RX9j^ZjZi]kK5`l;Bd<kOgM_]j^Sk
nOOgmO<2k>c[01CQi>CFfmc:dM>kaLV]^[jR/KJHZK2?XZR;W:>>WJ:CX:BHXjJNYjRSZZ^X[Jf[/:n^
/[2b];:d];6d/Jd2/jnZ01Fc[:JcZJ:dYinfYIbgXiVhX9FiWI:iVXjjV8ZiU8JgT82cRWZYP72JLfB8
IUQdEd]PAci<>C4f:B@N61D=2PX00P80000:4Pl?81dM;R/Z>cLgB4A3E51?GeaKJfMVMW=aPGil7?oo
o`006_ooo`0:ZIRC[Z2K]:NS^Jn[`;Nda/2mcLW7eM?Bgn3Pg]oQ0]3CeP0D`LO;/K_0XZjeSifVNXbH
J7f:E6el@Ee^;4YM7Se@53964B`o3RTl2bHi22@g1b<f1R<f1R@g12@g0b8e0P@R=00A1R@e2RHg3RPi
4bXj62hm7C4o8cE2:CQ4;ca8=41;>D==@4M@ATaDBTmFCE5HCe=IDEAJ009BEE/03U5DFU9EFeMGG5MG
G5aJGF9NH6USI71XJGM^KGidLXIiMheoNiB5PIb;QQ[oool02YnHUZNRX;2/ZkVg]/;2`/c=c]OIf^;V
j?3emnofn@;Qj^l03]7OiL7Bf[;6cijf`HVV/gNIZ6F;W5AnTD9`Q3QXO39RMc5OLc9OLc9NLP8aGg<0
139PLcARM3=RM35OL@8aGFh05C=LK3ILJcULJSeLJD9NJDINJ4YOIdiOIU=PIUIQIEQOHe]NH5YKG5IF
EU5@D4Y:BD=3@S/k>c8c<bLZ:b8T9@029BDU00X`;bhj>CQ5@T9@C4]JEUATGee^J6MhLW22NgV<Q88J
oooo00ZJUYFUXZ2_[Jbj^KS6aLCBdM7Ng]k[k>cjno_jo?d2k_;d01CPin[Ag>34dMJb`lZO];fAZK>3
WZUfTj1YR9ITQ91SPHeUP8aYPhe[Phe]QHi_QXmaQi1dRI5eRI1bQX`2LH>901EbPHIdOh=fOh9iOGml
OGinO7^1NgV3NWN6N7B7Mg:5Lff3KfQlIf1aGUMTE4iEB4A6?CXg<BlV92@D5aT83@l00P/>400:6A/L
9RLX<c<d@3loC4Y:F5EEHf1PKV]ZNWIeQH1o6_ooo`0:UiBBXYnM[JZY^;Jda<6od<g;g=[GjNOTmoCb
nOKd0^o^k00DiNKUfMcMcmCE`/W;];k1Z[JjXJndVZV^U:>XU:>WUj>WW:FWXZVZYZ^[ZZj][K2_/;:_
];Ba][B`/k2/0[:]Z00E/JVS/ZNP/ZFM]::J]J2G]YjC]Y^?]iR;]iF7]Y:3/Ham[8AeWgUZSfaNOEiB
JE15ED4i@C4/:R4N5A4A1@@4008610D02QDC4b@Q8C4^;Cdj>TY6AEEBDF5MG6aXIgIcLX5nOAcoool0
01[oool02ZVITjjPVkBXXkZ`[<6h]LS1_/o:bMOEe>7Qh>GWj0;JgMl05<[@e;_3b:^g_YZX/HJGXWJ9
UFAjR5A/O41KKBm=Gb90E1LeBA4^@PXX?0HT>0@R=P<R=P<S=`8S>04S=`808SH05@4R=@DT=PTW>@lZ
>a<]?QT`?b0d@bLiAbhnBcI3Cce8DdE=Ed]BFU1EGEAHGeMJHEULHU]MHe]NHeYMHUIHGP02GUiR00YT
HVEYIFM_JFYeKVelLW62MgF9O7V?PGfFQX:MS8HJoooo00ZOV9FWXZ2`[:^i][K2`L7<c<gGf=WRiNK^
l_Cenod2j_7d017JiN[:f=nkcMFY_lVD[k^5XZmdUZEVRiaEOY18M8LnKH4hIWXfI7LcHGD`Gg<`GW8a
Gg<00S9QM00H;eia;E]^;E]^;UYZ<EUY=5YY>E]X?EaX@EaVAUeVC5iVDEmVEF5UF61SFUiPF5]KEEIF
DE5@BTY:A4A4?3dm=3De:bd^8b@T0Rh^;@0:>3Hf@ClnBdQ7EE5@GUUHJ69QLF]YNWAbQ7ajSHF26_oo
o`0:VYJEY:6P[jb[^KNfaL?2d<o>g=cKjNWXm_Kfoooo0_Cgm`0=i^_]f>3SbmKJ^lW?Z;[2W;2hSZF_
QIjXNIBOLHfIK8VEK8JAKXJ@009^QXl01Fn5SW67SgB9T7B8Sg65S002KX6701E^OX=`O85bO81eNgeh
NgajNGUmN7N0MgF2MW>3MG21L6]mJVEdHeeZFUAMD4]?AD50>SPa;RdQ8R<C5QT62`d00Q<F600:824S
;2d^>3PiA4=3Cdi>FUQHIF=RL6e/NgMfQH606_ooo`0:UY>BXIjLZjVW][Bb`KnmcL[8fMKCiN;OlNk[
n_Od0_?`kP0Dj>OVgMkNe=OGb<g>^/;4/KZmZ;>gY:ncWZZ^W:R[W:RZXJVZYjb[Zjj][:n^[k2^/[6^
][>_][:^/jnZ0[2ZYP0E[jNQ[jBN/::K/Z2G/YjE/Y^@/iR</iF8/Y64/8eoZXIgXGa^Tg5TPfAHLEM<
GDPoBSTc=BXV81/I3Pd=0001008=30`02QXI6BPU9C@b<D0n?Da9B5MDDf9OGVeZJ7MdLh5oOAcoool0
01[oool02ZVITjnPVkFXXk^`[<:h]LW1_m3;bMSEe>7Pgn[[j`;UinT05=KJgLO>d[S2ajRd^iBT[HBE
X7B8U6AjR5A/NdANKSEAHbU6FAlmCaLeB10_@`/Z?`PX?@PY?PHY?`DX?`839cd05@<V>`@V?0PY?@d/
?a<`@QTdAB0gAbTmBc93D3]:ED=?FTaEGU9IHUQNIEeQIf1SJF=UJfEWKFIXKFAWK6=TJ002J6IZ00Y/
JF]`K6eeKfmjLW:0MWF5NWR;OgbAPgnGR8>MS8LJoooo00ZNUiFWXIn`ZjZi]KC2`;o<bl_Fe]OQhn?/
ko3ho?d2loSk01CSk>oEh>G6e=^ealnP^<:AZkN3X:eeUZAXRi]KPI9@NX]9LhE3KX0nJWdiIWTeHgLe
HWHfHgHdHWHbH7<2<5e`01D^Ff`_FFXbFVTgFfTkG6Q0GFM4G6I:GVI@H6IEHFEGH6=JGV1HFeaFEeMB
DU9<C4]6ADDo?clh>3P`<C4];2`00SLf=@0:@3hmBDI5DDe<FUEDHUeLJfETM6e/O7EcQGikSHJ36_oo
o`0:VYJDY:2O[Z^Z^;Je`l70c/g<fMWHiNGTl_;aooon0__lo00Dk?3agnGXd]_Na<oD//78YKJnVZjf
TJJ_R9jXOiNQNY>MN92IN8fFMXbDLhZBLXR@M8R?MXV@M8N?LXF<0Vn1R00EKGj3KG^0KgYnLgYlMGUj
MgQhNGIeO7EcOGAaOW5]NVaXMVMRKEmJHeIBEda9BD4o>cHe;2//7b4R4AHI3A4D008K7R002RLX:S8c
=3hm?TQ7B5=ADEeKFfQUI79_KWahMhJ2P1[oool02YJCTJ2MVjZWY[Bb/;nl^/[7aMGBcn3Mf^cXiOSd
l@;fl^l05>[Xin7PgmOHf<g@d;o5akJm_k2h^Z^d]ZN`/ZB][jF][ZR][Zb_[Jj`[Zj`[K2_[K:`[;Fa
[KB_Zk6/Z0:_Z:<05JfUWjbPVjfOV:nMUJjJTJjGSJfCR:f@Q:^<P:N6NYmnLIEdJ8IXGGILDVA?AU50
>Cda;BTS81PE5@L92@<31@024Q8B00XP7Ql/:RXh=SI4@D5?C4]IEeITHF1^JfYhMGB2OghLoooo000J
oooo00ZYVI>_X9^eZ:>k/:c2^;G9`Kk@blSIeM?Rh=o/k>/2k^o`01CQi>KCem_4bm2f_lJU/KVCXZ^3
U9mcQY=SN8IDJgY7GflmEFHcCEhYAUPQ?e8J>ThE=DXD=DTB=4T?<TP2331601D;;dD;;T@><4DC<dLH
=TTO>T`V?Tl_A5<hBUQ3DEe;Ef5CGFIKHFYQIVeVJW1ZKG9]KgE`LGMaLWM_LGI`L7@00W5_LP0:M71b
Mg9cNgAdOgMfQ7YhRGekSX5nThF1V8V4WXf76_ooo`0:WYNEYj6O[jZY^;Bc`Kjnb/W9e=CDgn3Pj^c/
moWi0__no`0@kO;eg^KZcm_P`LoF[l7:W[FnTJZePj2/MYFSJXbKH8BDFWj>DgV9C7F6AW21@Veo0SiY
N`0I?6Mi>FEg=V9d=V9d=5m`<ea]=Ea/>Ee[?EeZ@EiYAUiXBemXDF5WEV9VF61SFUmQFE]MEeQHDe=C
CTe=B4M6@d91?S`k=SHe>cTh0091?ch02TQ5A51<BeMCDUmJFFMQH6iYIgI`KWigMHIoO8j6Q1[oool0
2YVEU:>OWZfZZ;Nd/l6o_/_:bMKEe>;Qh>k]k?_jn0;oool05??dmNKYjmWOh/cEf;c8cJnm`jFe_9b^
]I>V[X^PZ8NKXhFHWh:EW7nBVW^?UWZ=U7R:TGV:TGN9SgB6S@9aPXP05FmoQ6ekPFmiOW5iO79gNWAg
MgEdM7McLWQaKgQ^JgAXIFiSGfEKEeaBCe19Ad<n?CDc<bPY:ahP8Q<H6QTL7`0292HX00X_<34i>CY3
@d==C4aGEEEQGUiZIfMdL71mNGR6PX4Joooo00ZETY6OW9ZXYZBb[jfl^KO6`l7Ac/_Lf=GWhn3bk^X2
mo?`00c^j^STh^3Jf]W@d]74b<Rl`L:g_;fc^KZ_]KJ//kB//K6_/K02/K6_00J`/:fb[jbb[ZZd[ZZb
[:R`ZZD2[ZFQ01F[XYbYWYRYViBZVI6YUXfYThVVSXBURX2QQGZLOg>BMV^7K69hH5MYE4aHAT15>3<`
:BHP71/B41441PL<30d00QTI6P0:9RDU<C0`?C/jAdE5DTm?G5UHIV=RKfe/NGIePX1n7?ooo`006_oo
o`0:ZIVC[j2K]JRS^k2[`[RdbL6md<[7f=CBhMkMjn[Y0_?dm00DkNo`g^7Td=GI`LW>/K_2XJjfTInY
PiBNM8JBIW^8FW1oCfIfAUi^?UMX=E1R<4aN:DII9D=F8d5D8D1D0QhnDP0E73eA7CeA7ciB8d1C9d=E
;DMH=4aK?E5OAEIRCeaWEf5[GfM_IF]cJfmfL7=hM7IkMgQmNW^0O7f1Ng^0NGQk009iMWT02W]fN7eg
N81iN8AkNXQmNhb0OI23P9F7PYZ:QIj>R1[oool02YjGU:JPWZjYYkNc/L2l^lW7a];AdMgLg>OXj??d
m0;mool05?OjnnO]l=WQiL[Ffk[9d:bnaYfc_9:Z]HFP[7ZHY76AWVV:V6>4TUeoSUIjRE=hQdabPTY`
P4M^OTE/O092J7P05CmVMSiTLd1SLD9SL4ERKTQSKDaSK59TJeETJUYTJ5]SIEaQHU]MGUUIFEEDE51?
CTY9B4M5A4=0?T8o?TE3@@02BTM600Y@C4]FDU5MF5MTGee[IFAbK6YiLg60NGN8P7j?Qh@Joooo00ZI
UI>RWYf[Z:Ne/[6o_;_9a/GCdM3Ng=_Yj>Kem?82ookm01CjnOW/k^kOhnGCfM_5c]6jaLV__<6X][^N
[[BGZ:nCXjZ@WjF<Vj69V9j4U9Z4TiUoSYEnSI=lRi5jR8h2MXB:01EcPHIaOH9aNgmcNWecN7YdMWMd
M7AfLW5eKfecJfU^IV=XH5eOEeEFCde:AD@m>c/_<34W:BXM7b8L828U9bT00Rd_<00:=SLh@411BDQ9
DU5AFeUII69QKFYYMW9aOW]iQh>16_ooo`0:UI:@WY^IYjBR/:f[^KJd`l2mcLW6em?@hMgJjnOS0_G`
k@0DlNcYi^?Qg=_Idm?BbL_:`lG5_L30^[fm]KVi/[Jf/kFd];Bb];:_];:^/Jn/];2[/JbX/JbW/:ZU
[jNR0Z^RW@0EZ9nIYIZEY9NAY9F>Xi69XHj5WHV0VhAkUWidT7M]QViUNVAKJeQAG4a6Bchj>30]9B8P
61LG2`/<2``=5QLG008R8B802Rd[;3Lf=T50?d]9BEECDUmLFfQUI75^KGYgMX>0Oacoool001[oool0
2ZVHTZnPV[FWX[^_Z/6g/lRo_<o8aMOBcn3Lf^WWiP;clo805?Gem^W[k=_Oh/gCekg5bjnj`::^]YFS
[8FEX7N8U6anRV5ePUQ]Ne1VMDMOKd=KJceFIcUCI3E@Hc=?H@8bCV02<4eO01<bCUlfD64jDV<oEVE5
FVQ=GV]DHViKIg5SK7E[LGUaMGafNGmlOH9oP8B1PXJ4QHV4Q8R1P8>0OH000X1lO@0:PG]lPgalQGel
R7imRh1nSh>0ThF2UhR4Vh^6Whj86_ooo`0:WYJDYInM[JRV][6__[ZialC3d<k=f]SHi>?Skno^0_[k
nP0DoOkol??dh^SZe=gQaM7F^<O=[;g4X[FmU:^dR:6/PIZUN9>OLHjIJhVEHh>@H82=Fg^9F7V7E7J4
DG>10Tm`OP0EC6ekBV]hBfYgCVYeD6UdDVUbEFU`FVU_G6Q]GVM[GfEWH6=TGUmPG5]KF5IEDe5?CT]:
BdM5BTI4C4Q6Cd]9009CCdd02UQCDUeHEf=NG6USHVmYIgE_KGaeLh9kNHV1Ohn7QA[oool02YRDTj6M
W:ZVYK>`[[bi^<G3`Lo=bmWGe^CRh>o]j`;jnOL05?klno;alNGWj=[MglgCeL;;c[W2a[>m`JVf^Z6_
]9jZ[iVUZYFQYI6NXX^IWX^GW8JCV8BAUH6=Tgj:S`9kQh`05GN3QgF0Q7AmPGEkOWEiNgAfN7=dM7Eb
LG9^KFmYJ6USHF=MFeYEDe1<BdA2@SPh>Bd_<2@V:28U9bPZ;2la<P02=SLi00Xn?d16ATM?CTiGEUIO
GEeWIFA_KFagM7>0O7^8Ph8Joooo00ZDTI2LVYRUXZ2]ZZRf/k6o_;W8a<;AcL_Ke]?Th=`2kn[V01Cb
kN[Xhn7OfmWGe=?>cLc7alK1`/70`;nk_;^h^KRi^;Fg]K:f/k2f/Zjc[j^d[jZaZjN`ZZF^YZ:/Xil2
Z9nJ01FTViJQUi6OThjOT8ZLS8FHR86DPg^BOWJ<Mg24KfQiIUm]G5EODD]?A40n=S@/:BLM71`@414>
3Q0G5aPP82400RXY:P0:=3<c?C`lAdE5D4i=FEMFHUmNJVQWLg1_NgQgPh5o7?ooo`006_ooo`0:ZIRB
[YnJ]:JQ^ZjY`;Faakfjc/K3eLo=g]WGinCR0_7ak`0Dn__jloCei^W[f]kQc=;F_/K;/;[0YJngV:B]
RYRROhnIMHF@K7f9IGJ3GG1mEV]hDFIeCF=bBV1`B5i_0TIMKP0EAEa]AUa]Aee]C61_D6=aEFIdFVYf
H6ehIG1jJW=lL7MoMgb2OH26PXB8QHF9QXJ:RHV=RXZ=R8N:QhB6QX:400:6P8402XJ0P8N0OhV0Ohb2
P8j3PI:5PYF7PiR9QIb<Qj2?RA[oool02YfFTjFNW:bVY;B_[Kbh]/C1_lg:bMKDdn3NgN[Yj0;fmO@0
5?ooooSinN_^kmoTi];Ig<C>dkS5bjnna:Be_9R/]92U[HNMYX2HXGZBW7>=Ufj9TfV5T6F1SF5mRUmj
Q`9LN8@05EUeP5QcOUUaO5]aNeeaNEi`N65`MVA_M6E^LFA[KVAXJVAVIV9RHV1NGE]HEeEBD55<BU1;
BE9=BeA@CUMBD@02FUID00YOFUQSGUaXHf5^J6IcKF]iLW1nMgF4OG^:PX2@R8DJoooo00ZHTi:PW9ZX
Y:>`[Jbi][G2_kk;b<ODd]3Ng=[Xi^D2lo;`01Cmno[fm??[jn_Ph^;Ef=[:cm71b<^l`lJd_L2/][VX
/KBQZZfMYjVIXZFDWZ:AVij=Ui^:U9N6T9B3S942P8V=01EkQHUiPXIhOh9hOH1gNWafN7UeMGIeLW9a
KVe[IfMUHF1NFeYEDe9;BTY0@44d=SLY;2dW:B/];c0b=3Dh>CX00Slo@00:ATI7CDe=E5=DG5YJHf5Q
JfQXLVm^NWIePGelR8B36_ooo`0:Ti6?ViRGXj2NZjRV/k2]^kRe`l2mc<S5e=3=gMWE0^KQgP0DknWV
jN?PhMcIfMKCdLo=b/S7a/G3a<;0`;nm_K^i_KVf^;Fa^;>_][6]]:jZ/ZfX/:ZU[ZNRZj>OYinK0ZBL
U`0EWiNBW9>>VHn:V8b6U8N1T89mSGihRWUbPg9[N6USKUmJHEE@DdU6A3dk=30_92<S5ADF4A8C6QXK
8B4R:RTZ008b<C802S/j>T=2@Ta:BUABDUeJFVERHVeZJGAbLGajN8B1P1coool001[oool02ZRHTZjN
VK>UX;V/Yknc[lFk]lc3`=?<bM_EdnCPgP;]jnX05?[inOkno_Cem^KYjmWMh<cBeL37c;Jna:^d^inY
/IFPZ8VFWh2>UgV7TG:1S6]lQVMhPfAePF1aOUe_O09LKW/045]/NUa]NUi^Nf=aOFEcOfYfPFmiPgAl
QGQoQWf2R8:5RhN9SX^;T8j>TY:@Ti:AT`:>S8l00hf:S8^7RH^5QP02RXB400Z;Ph><Ph:=Ph:?Q8:A
QH>DQhBGRHFJRhJMSHRPShTJoooo00ZMUI>TWI^[YJ:b[:^i]K?1_K_9a/CBclgKf=OThn42knk/01Cl
n_Woo_gfmOGYjn_Lh>;@e]W5c]6mal^c_lFY]kbQ/;JFYjj?XJR8W:>3UimmTYYhSYIeRY=`QY1/PX`2
JX2:01EWO8IVNhAVNH5YNH5YN7m[Mgi^Mga_MWY_M7I]LG9/KFi[JVYXIVETHF1QG5YKEUADCT]HDTmJ
E59LEeENFEL00V9LFP0:IF1NJF=RKFQVLVaZMg1^O7EcPGYhQWmlRhB1THV66_ooo`0:Ui>AWi^IYZ:Q
[ZZY][>a_[^ia/?2clc;f=GDhMoM0^_Yi`0Dm_?bnOKelNo^i^KUg=cMd]CEbLg>a<W:_/?4]kbn/[Nh
ZK2bYJ^]X:NYW:>UUijPU9^MT9NJS9>FQhnB0XB;S`0EP8N:OHB7NX23O7n1NG]nN7UkN7MhMWAdLFi^
JVQWHf5PG5YIDU5BB4U:?d11=3Hh:b`]<C8d=SLi?3`m@D920097AdP02Te=CEACDeYIFF5OGfQUIFi/
JgEbLGahMh9nOHV5Pa[oool02Y>@SYZGUJ6NW:RUXjn/Z[Nc/Kjk^<K2_lk9a]KAcP;Nf=D05>KPgNSR
g^?MfM_Fdm??c<g:alS5`lK3`<?0_L2l^Kji]KZe/KRc[[F`ZkB]ZK6ZYJjWXj^TWjNPW:>LV0:OV9@0
5IZCSiN?Ri::QY:7PXb2OHUnNXIjMH9dKgU/J6iSGf=IEEI?C4Q3@CXh=b`/;1hO81@D5A`L7B@S92/[
:c<b<P02>STj00Y2@D5:B4QBD4mIEeMQGUiXIVE_KFafM7=mNgZ5PX4Loooo000Joooo00ZXUi6]WIRb
Y9jhZZFm/Jg3^;C9`;c@b<GGdLkOf]P2j>GS01Cbl>omo?cooooemOKWj>[Jg=o?dmK6bljm`lRc^[nZ
/KNOYjnFWjN?VJ29Ti^3SiMnRY9iQHmePXabOhX2LGf800e_O8M_O8I`OHMfP8YlQHj0Qi23R927Ri6<
SY>?T9BATIFDTiNHUYT00iRGVP05UYBGTi2BTHf>T8Z;ShV900:?QhL02Xn6QI26QI66Q9:7Q9B8Q9J9
QIV:QY^<Qij>R:2?RA[oool02YbETZ>LVJVSXK2ZZ;Na[kji]lG1_lg9b=GBd=kKfP;WiN<05?7_kOci
mokln_CblNOWim[Mg]3Ee/S>d<78bkS0a;6j_JNb]Yn[/9RUZY>PYXfLXHRGWH>CVGn?UWZ;TP9gQhl0
5GB4Rg:1R75oQWAoQGJ0QGV0Q7YoPWYlOgUjNgMgMgAbLG1^KFiZJFUUHf=NGEmIEeiHEEmIEf5KFF=M
FfEPG@02J69P00Y[IF=_J6IbK6YfL6ikM79oN7J3O7Z8P7j=QH:ARHLJoooo00ZFTY6MVIRTX9n[Z:Jb
[jfj]kG1_[g9a/CAc/gJemD2h]oM01C[j>Kdl>kfl_3]j^SRhN3Gf=O?dM7:c<c5alRn`L6j_;bc]KJ/
/;6WZjbSYjRNXZ>JWYnFVYbAUYR<TI@2R8j@01F4RHb0QHQmPHAmOh5lOX1lOGikNGYgMGEbKfm[JFUR
HF5IFEUBDU97BDXm?d4e=cTf=SPk?3e0@455ADI:BTX00Tm>C`0:EEADFUUIH5iNIVASK6UYLVm^N7Ad
OWYiQ81oRXF46_ooo`0:TXn>V9JDWibJYJ:P[:VW/jn]^KJc`;bial?0c/W60]G?c00DfmGBhM_Hh]cI
g=KCeM3=c/W6bLG2a/:oa<2l`;^h_kVd^kF`]k6/]:jY/J^V[ZNSZjBOZ:6LXifIWiRE0Y^DT@0EUXn<
THZ7S8F2RH5mQGejQ7]hPGIcNVm/LFMTIUiLFUABCDU8@Cln=3@d9bPY7AhO7ahO9bHW;Rd^=C@d?3/k
0093@D402TU8B51?CUMEEEiLFfESHV]YJ79`KgQfMGmlNhF3PAcoool001[oool02ZRGTJfMV;:TW[RZ
YKfa[L>h]<W0_=38aMOAc]oJf0;XiN<05?;`koglo?ooooGem^OXj][LgloCe/K;c[g3b;>j_jZa]inW
[iJOYhnIX8VCVh>?Ugj:TWV5SgF2S79oRP9aOHP03FmlQfmlQW1mQgJ0RWb5SX27T8>8T8N;THb>Thn@
U96AUIBCUiRFV@03V9NJ00FFU9NCT9:ASHj@RX^?RHT00Xn7Q`0:ShJ5T8J5THJ4TXN4U8R4UXV5VHZ6
Vhb7WXj8X8n96_ooo`0:W9FBXibIZJ>Q/:ZX]k6__[VgaL6ocLW8eM;@g]_J0^OUh`0DlNo]o?Wgo_cj
m?;ainOWf]gNd=GFb<k@`LS;^<34/KZmYk:fWj^`V:FZTj2VSIbQR9NMPi>IOhnFNX^B0WN7S`0EM8B;
LX68LGn6M7n5MX25NH24NWn2NWaoNGYkMgMgM79aL6i]KVYYJFESHeiMGeUGGUQEGeUGHE]IHeeKIF1M
009XHV002V]UHfmXIW9/JWI`KW]dLWmhMX=lNXR0OXf5PY69Qa[oool02YJBTIfIV:BPWj^XY[:_[KZg
]L6n_LW6a=7>cM[Ge@;Rgmd05>_Xi_C`k_Kbl>gZj>;Qh=OHeloAdL[<c<G7b;k1`KZl_;>e]Zb`/JN[
[:>WZ9jRXiZNWiJJW96FV8bAU0:8SY005HB9S825R7f1Q7eoPGanP7amOW]iNWMeMG9_Kf]YJF9QHEUI
FE9BDTM9BSdo@CDg>CHf>3/l?D10@DE5ATY:BP02Cdi?00YEE5AJFEUPGUiVI6=/JFUbKfihM7AnNWV4
P7n:QH@Joooo00ZBShjHUYBOW9ZUXZ2/ZJNc[jfi][?0_;W7`l3>bLH2eLo<01CKeM;QfmSRg=WLe]?E
d<g>bLK9aL;6`[o4`;c0^kRo^KBk]K2g/Jbd[ZVaZjJ^Yj>[Y9nXXIbSWIVOV9D2ViBA01FFShbARXN<
QH:9PGf5OGZ4NgR1MW=jKfaaIfAVGUaJE59=BDQ1?chd=3@W:2TM7QlO7QlW9RL^;Bhe=3@l>c/00T=1
@@0:BDQ8D4m>EeEEGUaKIF=RJfUXLW1_N7IeOgakQH>17?ooo`006_ooo`0:Z9NA[9bG/J:M]ZRS^jjZ
`;Faa[bhc<?0dl_8f]CA0^;Mf`0Dj^OUlo7`oOclooknmOCdinOYfmcNd]GGc<oBaLS;_L33]KRlZk2e
Y:V_WJ>YV9jTTiZPSYJMRi:JR8nG0XF=U@0EQ8^DPXVBPhZAQH^BRHfDT9>HUYNKV9RLViZMW9ZMWI^M
WYbNX9jPXZ2RX9nRWYbNVYJHUi:DUHn@U8f=Th^;00:BRXT02Y:9Qi>8QYB8QYF9QYJ9QYR:QYZ;Qib=
R9n>RJ6@RQ[oool02YbDTJ:JV:NQWZfWYKB^[;Ze/l6l^/S3`/o;bMOCdP;Og=X05>STh_3]jo[fm?ch
m_7^kNCShmWJf]3Cdlc>clG8bKk2`kNk_Jfd]ZN^/J2X[9^TYiJPXi6KWhbGVhRCV0:4Si@03h6<TGj8
SGb5RGb4Qgj3Qh>6R8F6Qh>2Ph:0P7mlNgYfMGEaKg9]JfmYIfURH002If1M00AWHEiXHV1ZI65/IV<2
KVQV00YaJVQdKF]gL6ijM75nMgF2NgR6OWb:PX2>QX>BRXLJoooo00ZFTI2LV9JRWYfXYJ>_ZjZe/[2l
^KO3`;k:alGBc/d2fMKD01CPgM_Xi>;_k>[akN_Xi>?Mfm[Ddm;=cLc:bLW5aLC1`;jj^[Vc/k>^[jjX
ZJZTYJFPXZ:KWIjFVIZAU9H2S92B01F8S8j3QhUoPXAmP85lOX1oOWmnO7ahMWIcLG5/JVYRHF9HFEYA
DU99Bd`o@D8n?Sm2@T=5ADI:BDY>CDiBDE800UMFEP0:G5YJH5mOIV=SJfQXL6e]MG9aNWMfP7akQH60
RXJ56_ooo`0:THn=UiBBWIZHXinNZ:FS[Z^Y];2^^[Jd`;bia/6o0/c7a00DdLc9e]7=fmGBg=KBe]3<
clW6bLC0a<2l`kfj`;Zf_[Nb^[>_]JnZ/Z^W[ZNSZjBPZ::MY9jJWiVFViFB0YJAS@0ETHb9S8N4QX5n
PWejOgYiOgQfNg=aLf]YJfARHEaJE55@AdI6?3`l<C8c9BHW9BDU;2//<S4b>3Lh?SdmAD=3009;BDT0
2U5?CeMEEEeKFV=QH6UWIVm]K7EbLGYhMh1nO8J3PQcoool001[oool02ZNFT:^KUK2PVkBVXKV[Ykja
[L>g/lRn^/k5`]G=bP;KeM805>?Mfn[Vi?;_k_cjnOgkno?alNSWj=gMg]OGfM;BeLc=clG5b;no`[Zj
_[Be^:j_/ZRZ[Z>VZYjQYi^NX`:HVj405INJX9FHWI:EVI:DV9FFVYVHW9^JWIjLWj:OXJFQY:JSY:NT
YJRUYZVVZ:BRY:2MWYfHVIZDUIRATIN?SYJ=S002UHb:00ZERhVFRXRFRXNGRhNIRhNJS8NLSHRMSXRO
ShVQT8XJoooo00ZKTi6PVIJVWYb[Y::`ZZRf/:jl]kG2_K_9a<;@blT2em;@01CNf]SVhMo]jNOfl^og
l_3]jNKRgmkGe]KBdM7=cLg9b<S1`/:k^kbf]kN_/K>Z[:fTZ:VOXjFIWZ6EVYd2T9JI00n>TiN:Si:6
RXf4RHZ5R8Z8R8V7QXN6Q8B6PX64OgeoNWQkMG=fL6edKFU_IfD00ViWI004KVQUKfQVL6YWLV]Y0WA]
J`0:MVm]NG9`NgAbOWMePGYhQGekR81nRhB1ShN4TXZ86_ooo`0:UI6?VYJEX9bJYZ:PZjNV/Jf/]k>b
_KZh`l2nbLK40]3<b`03e]?AgMWGhmoM00;Zi^@03n;MfmWEdlo>c<_9b<S6a<G2`;jl^[Rf]K>b/Jj]
[:ZXYjFUY:2PX9ZKViFGV002T9:C01F=SY27RX^2Q8IoPH=nOh60OgmlNgagMWIcLG5/JV]RHV=JFU]A
DU=;C4e7AdQ:BDY<C4a@CdmCDU9GEEIJFET00UiMG@0:HV5PIfETJfUXKfe/M75`N7EdOGYiPWimQX:1
RhN56_ooo`0:THj<UY>AViRFX9fKYJ:PZZJT[j^Y];2^^KFc_[Zg0/>o_00Db<?0c<O4d<_7eLo<eLo;
clS4b<:n`[fi_kZf_KNc_;F`]k2//Z^W[jRTZjFQZ:6MYInJX9^GW9JCUi:?0Y:=R`0ESXZ8R8B3PWmm
OW]jNgQgO7MeMg5_KfYXJ6=QGEUID4i>A4A5>CXj<C8b;Bd]<c8b>3Lg?C`l@d92B4M7CDa<009CDE40
2UQFEUeLFf=QH6QVIFe[JW9`KgMeM7ajNH9oOXN4Pacoool001[oool02ZNFSjZJU:jOVK:SW[JXXkZ]
Z;nc[/Bh]<Vo^lk5`P;Dc<T05=[Cd>7KfNSShO3/j_Wgm_[gmo3^kNKTi=oMg][If]OFem;@d/_9blK4
a/?0`l2m_k^i^kFd][6`/Zj//0:ZZJ`05JRWZZJTZ:FSYJ:PXjFRY:VTYJbVYjjXZK2ZZ[:/[;:/[Jn[
[:n[[JbYZZNSXj>MWInIVIfEUI^CTYZ@SiV?S@02V8f;00ZHSHZHS8VIS8RJS8RKS8RLSHRMSXVOSXVP
ShZRT8XJoooo00ZJTY2OUiFTW9ZXXIn]YZBb[:Zg/Jnl]kG2_K_8`l42c/W701CDclgKe]?Qg=[Xhn7a
k>WajnSXhn3MfMOFd]7Bc/g?c<[9a/G1_kjm^[Zi]kJf/k>a[jn[ZZZVYJJQXJ82W9fN012IVY^EUYNC
TiB>SXn@SXnBSXjAS8b@RXV>QhF;Q867P7f0NGMlM75jLVigKfafKV/2MFi[00=fKfagL6ehLFh00WUb
L00:NgAbOGIdP7QfPW]hQGekQh1mRX:0SHF3T8R5Th^86_ooo`0:U92>VIFCWYZHXinMYjBR[:VW/Zj/
]k>a_;Rg`Kjl0/O3`@0Dc<S6d/k<em?AgMWFhmoMhmkKfmKDdLg;blS6alC2aL6o`;bj^KJd]K:a/Jj]
[Z^YZZNVY::QWYjMVYVI0YBDU@0ETI6BRhb>RHV:PH>5PX>3Ph62OgemNgQhMG=cKFa/IVEUFeaME5EE
De=BDe9CEEADEeIFFEQHG5]KGeeMHV1P009VI6<02VUWIfeZJW1^KGAaLGQeM7aiN81lNhB0OhR4PXb7
QQ[oool02Y2=S9BAT9VEU9fJV:6NW:JRX:ZVY:j[Z;>_[;Nc/0:k]k@05;nj]l>n^lK1_/[4`Lk8a<g6
`/O1_<2j][^e/KVb[[Na[;>/Z:jXXjZTXJNQWJFNVZ:LUifHU9RCT9>?S@:>RhT05H^8QXF2PX9oOWYi
NGYhMgQeM79^KV]XIf=PGeQGEdm>CT93A3Xj>STh>3`j>d0o?dA3@dU7Ade<C59@D5IEE002FeUI00YO
GUeTHV5XIVI]JfYaKfifM79jN7MoO7^3P7n7QH<Loooo000Joooo00ZVUHnYVI>]W9N`X9^cYIngZJBk
[ZVo/Zk3^;?8_KT2cL>o01CBbLKHclcNe]CTg]c[i^Cdl>oglo;akNgVh^7Nf][KemOIe]OHdmCDcm3@
bl_;aLK9a<C8`/;3_Kfm][L2]k:c01Fe[k2b[JjaZj^]Z:R_ZJVaZZZd[:^f[Zfg[jnh/;2h/K2b[Zn`
[:f/YZJXXJ6TWIbQVIROUYBMTi6LTHnKT8d00Y^?S003Vhj;Vhf:Vhf900:LSHT01If>RIj>RIn?RJ6@
RZ:@RP0Joooo00ZJTXnNUY>QVYNUWYbYXZ2^YjFbZjVf/:jk]K?0^[P2aKnm01C:aL;@b/SEd<gKeM?R
fmWYhmo[hmoTgM[Ie=7BcL[>bLO<alG8`l74_kg1^kVl][Fi];:f/Jnb[J^[YjD2YJ:R01FRWYjMVi^L
V9RFTi>GTi:GTI2GShjFSH^CRXR?QXB=Ph23NgR1NGEoMgAmMW9lM79lM75kM75lM79lMG=mMW@00Wmg
M@0:P7UfPWYhQ7ajQWilR81nRX:0S8B2ShN4THV6U8^96_ooo`0:U8n=Ui>AViNFX9^JY:2NZ:BR[:RV
/:b[]K6_^KFc0[jj^00D`[jlal?1blO5d<c9e=3>f]GBfMCAe<o<blO4aL6n`Kfj_[Zh^KJd]K:`/jn]
[jZYZjRUYjBSXj6OWY^J0YRFU`0EU9:BShn@SHb<QHJ7QHF5Ph:2P7inO7UiMWAdKfi^JfUYGUiNG5]K
GEaLGUeMGeiNHEmOHf5QIF=SJ6EUJVQW009]JVX02W1]KG=`KgIcLWUfMGaiN7mlNh9oOXJ2P8V5Phb8
QQ[oool02Xn<Ri>@SYJCTYZGUIjJVJ6NW:FQWjRUXjbXYZn[Z@:c[j`05;Jb[kVe/[bg];nj]l:l^<Bn
^/6k]kjg];Rb[[B^Z[6ZYZfWXjRSWjFOW:>MVZ6JUibHU9RDTYJBSi:>R`:<RXP05HR6Q8B2PX5oOgYi
NGUhMgEcLg1^KFYWIV5OGeQGF59ADDA4AD=2@TM6ADY8B4e;Be1?CeABDUQFEUaJFEmMG@02Hf5Q00YW
IFA[J6Q^K6]bL6mfLg9iMgImNgV1OWf4PX68QH@Loooo000Joooo00ZVU8jXUi6[VYB^WYR`XI^cYInf
Z:>j[:Nm/:c1]K02aKVe01C9_[[>a<3BbLKHclcMe]?Sg=[Yhn3_jNO]inKUg]gOf=OJeMCHd];FcloE
c/gCb/W?a/C;`/38_kg4^kP2`;Ne01Fj/[2h/:jg[jje[Zfe[Zbg[jfj/K2l/k6l];>j/[>k];Fe[jn_
Z:N[Xj:XWifUViVRV9JPUY>OU96NTXnMTHd00Yf@S00:WHn;WHn:WHj:WHj:WXj9Whn9Whn:X8n:XI2:
XY6:6_ooo`0:VI6>W9BAWiNEXY^HYYjLZJ:P[JJS/:VW]:f[^;6_0[be/`0D`;Zga;jlbL;0c/O4dlc9
em3=g=GAh=SDg]KBeLg9clO3bL;0al2ma;fj`k^h`;Nd^kB`]k2]]Jj[/:VV0ZbUX`0@YZ2NXYfLWiZI
WIRFViJDViBBVi>@VI2=Uhj;TXV6T8N4RH1mQWikQGaiPg]hPWYg0h5jM`0>PWYhPg]iQ7ajQ7ajQGek
QWilQh1mRH5oRh>0S8F2SXJ4T8R5TXZ7U8b96_ooo`0:Thj=UY6@VIFCW9RFX9^JXinMYZ:QZZJT[JVX
/Jf[0[B`[`0D^;Bb_;Nf_k^i`kjla/:ob/G2c<O4c/S6c<K3`kjk_[Re]kBb]K6`/jj]/Jf[[ZVWZZJT
Yj>RYJ6OX9bJ0Y^HV00<UY>CTY2ASXf=RXV:QhN7QHB4PX20OW]kNGMgLW1aKVa/IfEU0fQVIP06JFMW
JfQXK6YYKV][L6e]LVm^0WAaL00:MW=bNGEeNgQgOGYiP7akPgmnQH60R8B2RXJ5SHV76_ooo`0:SXb:
THj=U96@UiBBVYNEWIZHX9bKXinMYJ:PZ:BR0Z^WY@0D[JVW/:bY/Zj[]:n]][6^]k:^^;:^]k6^]Jn[
[jRUZZBOY:2MXYjKX9^HWiZGW9NCV9BAUY>@UI:?T8f;0Xf:R@0ER8J5QH>3P7moO7]kN7QhM7=cL6i]
JFMWHf9RFeYJEU=CCdi>DU5AEE=CEeEEFUQHG5]JGeeMHV1PIF=SJ6IU009[JFP02Vi/Jg5_KWAbLGMe
M7YhMgekNH1mO8>0OhJ3PXV6QAcoool001[oool02ZFCSJNESjVHTZ^KUJfMUjnPV[:SWKBVX;NYY;Z/
Y`:m/:/05<2c[l>g/lNk]l_0_<o5`M?:a]S?bmcCd>?KenGLfN?JemgDdMK=c=K<bmG;b];8a/o4`L_0
_/Vn_<Nk^@;5^KH05L:g]<2e/[bc/;^b[kZb/;Vb/;^c/K^c/[nh^;jg][N_[[:XYjfSXJZOWJNLVJFI
UZ>GU::ETJ2CT:2BSYnAS@02Wi2<00>NT8^NSh^OShX00Yn?RP05X8n:X92:XI2:XY2:Xi6;01[oool0
2YR@SI^BT9fETYnHUJ:JV:BMVZNPWJZSX:fUXjnXYP:b[:T05;J_[;Vb[kbe/l2i]/>l^LNo_<[2_lk5
`M?:aM78`lo5`<W0_<:j]l6h]L6g]Kjd/K^a[[N^ZkB/ZK6YYP:_YZ<04:^SX:RPWZBMVZ:KVInIUifG
U9bETYVASY^BSiR?S9:9QHj5PX^3P8Z1OXR0OHMoO@>7Og`03XMoOHR0OHR1OXR1OXV1OhZ2P8^3PHb4
PXj6Phn7Q928QY:9Qi>;R9F<RQ[oool02Y:=S9B@SYNBTIVETibGUYjJV:6MVj>OWJJRX:VTX`:[YjD0
5:jZZ;6/Z[>_[KJa[kRd/[^f/kfh]Kji]/6l^;fg]KZd/KFa[Zn[ZZfYYjfXYj^VY:RTXZJQWj>OWInK
VP:MVIP039REUIFBTY6>SXf<S8Z9RHN5QHB2PWilO7ikNgYgMgEbLG=`L09bL6l01g=`Kg=`L7AaLGEb
LWIcLgQeM7UfM@02NgQg00YmNGQnNgZ0OG^2OWf4P7n6PX68Q8::QXB<QhJ>RHPJoooo00Z>RhV@SH^B
ShfDTI2FTi:IUIBKUiJMVYROW9ZQWI/2XinM00FUXInWXj2XY::ZYJ>[YZ@00jbWY00<[JNSYj6NXijJ
X9bIW9RFVYJCVIFCV9BBUi>@UI6?TXn=Shb:0Xb9R00ER8J5QH>3PGmoOGalNWUiMWAdLW1_JVQWIfEU
Hf5PGeeMH5iNHEmOHf5PI6=RIVATJ6IVJVQXKF]ZKfe/LFm^009cLG002WEcLWQeM7YhMgajNGilNh5n
OH>0OhF2PHN5PhV7QAcoool001[oool02ZFCSJJDSZNFT:RGTJZITj^KUJfMUjnOVK2QVk:SWP:dYZ00
5;JXXkV[Y[^^ZKj`[<6d[l>g//Jj]/Vm^Lc1_<k3_]34_m;7`]36`Lg3_/g2_/c1_lc1_LVm^/>h]L6e
/`:o/k005Kfb[[fa[K^_[;R^Z[R]Z[V_[Knf/k^b[kN]Z[BYYk6UXZfQWZZNVZRKUjJIUJFGTj>ETJ:D
Sj:CSZ6BSJ6AS002X96<0j2@R`07X92:XI2:XI2:XI2:XY2:XY6:Xi6;01[oool02YR?SIVASY^BT9bD
TYjFTj2HUJ6JUj>LVJFNVjNPW@:YXYl02:^TXJfVXk2XYK:ZZ;B]Z[N_[;Va[K^c[`:m];002[jd/;nf
/K^b[[R`ZkR`[;R_[;R^Z[F[Z:nWY:bTXP:[XYl04:RPWJNNW:BLVJ6JUinHUIfETZ6IUIbDT9V@SIN>
RiB;R969QXn7Q8j6Phf5PXf4PP><Q8403Xb4PXf5PXf5PXf5PXj5Phj6Q8n7Q928QI28QY69Qi::Qi>;
R9B<RIF=RQ[oool02Y6=Ri>>S9B@SYJBT9RCTYVETi^GUIfHUijJVJ2LVP:RWY`05:BOWZJQWjNSXJVU
Xj^VY:bWYJfYYZjZYjnZYjjYYZfXYJjXYJRTXZJRWjJRX:FQWjJQWjBOWInKVIbIV0:JUYD039NDTiJB
TI:?Shn=S8f:RHN5Q8V6QHB1P89oOX5mOGikNWejN@=lNGP01WeiNGejNGikNWmkNX1lNh5mO0:2OWd0
2X=oOXB0OhF1P8N3PHR4PXV5Q8Z6QHb7QXf9Qhj:R1[oool02Xf:RHj;RY2=Ri6>SI>@SYBAT9JCTIND
TYREU9ZGU@:KV9H00ibIUifJV9nKV@02X9bJ0j6MVP0<X9bIWYZGWIREViNDUI:@U96>UI:?U92?U92>
U92=T8f;SX^:0Xb9R008R8J5QhB4Q8:1PGmoOWakMWEdMWAcLFm^0W1^K@9_KF`02G1]KG1^KG9_Kg=a
L7AbLGIcLWMeM7QfMGYhMP02NgUh00YmNWUnO7^0OGb1Ogj3P7n4PX26Ph:7QH>9QXF:QhHLoooo000J
oooo00ZTTXbUThbUU8fVU8jWUHnWUY2XUi6YV9:ZVI>[VY@2[9^F00^]WIN^WYR_WiZaXI^bXYfcY9ne
YZ2fYj:hZJ>iZZBiZjD00[Z[YP:iZjD01KV[Y[Z/Ykf_Z;b^Z;b^Z@02^jfY0[Z/Z0:i[:P04KR[Yk:U
XK2SWZnQWJfOVjbMVJZKUjRIUJNHTjJFTJFET:BDSj>CSZ>CSJ:BSJ:BS::AS009XY6;0j>ARa[oool0
2YN>S9R?SIR@SIVASYZBSi^CT9bDTIfETYjFTinGU0:PV9D02J6IUZ:JUj>KV:BLVJFMVZJNVjNOW:RP
WJVQW@03ZZ6M00RYX9bXWibXX9bXWibYX9b[XIfYX9bXWi`2YijK00nVWIVUW9VTViRSViRQV9FKTi2J
TXnITHjHShbFSX^ES8ZDRhRCRXRBRXNBRHL01Y69QP:BRHL2TXZ700RBRXRCRhRCRhRDRhVDS8VES8ZE
SHZFSHXJoooo00Z@S8ZASH^BSHbCSXfDShjDT8jETHnFTY2GTi6HU982VIBC00NJUIBKUYBKUiFLV9JM
VINNVINNVYP00inJV00:WYZGWYVGW9RFViNEW9NEViJEW9REWIRFVYJDVIFD0YNCTP0<UY:AUI6@U92?
TXn>T8b;RXN6RhN6RXJ5RHF4R8B3Qh>2QX>118J2P@05Qh>1Qh>2Qh>2R8B2R8B300:9QH<02XV5Q8Z6
Q8Z6QH^7QHb7QXb8Qhf9Qhj9R8j:R8n:RA[oool02Xb:R8f:RHj;RHj<RXn<Ri2=S96>S96>SI:?SY>@
SP:CT8l019BASiFAT9FBT9FBT@BFTi401IJBT9FASiBASY>@SY6>S003T8f;00BASH^@SH^=RXV<RHP2
RXR700Z9QXF8QHB6Q8>5Ph:2P7mmNgYoOGaoO7]nO7]nNgX2OG]j00UnNgYnO7]oO7]oOGb0OGb1OWf1
Ogj2Ogj3P7l00X>1P00:Q8:0QH:1QX>2QXB3QhF3R8F4RHJ5RHN5RXN6RhR77?ooo`00oooooi7oool0
0?oooonAoooo003oooooTOooo`00oooooi7oool004Koool30000FOooo`<0001Joooo0`0005[oool3
0000<Oooo`00BOooo`030000oooooooo05Woool00`000?ooooooo`1Joooo00<0003oooooool0F_oo
o`030000oooooooo02koool002Soool500000_ooo`800004oooo0P0000Coool400000_ooo`<00003
oooo0`0000?oool20000=Oooo`@00003oooo0P0000?oool400000oooo`@00002oooo0`0000?oool3
00000oooo`80000foooo100000;oool400000oooo`800004oooo100000;oool300000oooo`<00003
oooo0P0003Koool400001?ooo`<00002oooo0P0000Coool400000_ooo`<00003oooo0`0000?oool2
0000:oooo`00:_ooo`050000oooooooooooo000000;oool010000?ooooooo`0000;oool010000?oo
ooooo`0000;oool010000?ooooooo`0000Goool010000?ooooooo`0003[oool00`000?ooooooo`03
oooo00@0003oooooool00002oooo00<0003oooooool00oooo`040000oooooooo00000_ooo`030000
oooooooo00?oool010000?ooooooo`0003_oool00`000?ooooooo`03oooo00<0003oooooool00ooo
o`040000oooooooo00000_ooo`040000oooooooo00000_ooo`030000oooooooo00?oool010000?oo
ooooo`0003_oool00`000?ooooooo`06oooo00@0003oooooool00002oooo00@0003oooooool00002
oooo00@0003oooooool00005oooo00@0003oooooool0000`oooo000Zoooo00D0003oooooooooool0
00000_ooo`040000oooooooo00000_ooo`040000oooooooo00000_ooo`030000oooooooo00@00002
oooo00@0003oooooool0000koooo00<0003oooooool00_ooo`040000oooooooo00000oooo`030000
oooooooo00;oool010000?ooooooo`0000;oool400000_ooo`040000oooooooo0000??ooo`030000
oooooooo00?oool00`000?ooooooo`05oooo00@0003oooooool00002oooo00<0003oooooool01000
00;oool010000?ooooooo`0003coool00`000?ooooooo`02oooo1@000005oooo0000oooooooo0000
00;oool010000?ooooooo`0000;oool400000_ooo`040000oooooooo0000<?ooo`00:_ooo`030000
oooooooo00;oool200000oooo`040000oooooooo00000oooo`<00003oooo0P0000Coool40000>ooo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool00_ooo`<00003
oooo0P0000Coool40000??ooo`030000oooooooo00?oool00`000?ooooooo`02oooo0P0000Coool3
00000oooo`800004oooo100003coool01@000?ooooooooooo`000002oooo00@0003oooooooooool2
00001?ooo`<00003oooo0P0000Coool40000;oooo`00:_ooo`050000oooooooooooo000000;oool0
10000?ooooooo`0000;oool00`000?ooooooo`03oooo00<0003oooooool0A?ooo`040000oooooooo
00000_ooo`040000oooooooo00000_ooo`040000oooooooo00001Oooo`030000oooooooo04Goool0
10000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`05oooo00<0003ooooo
ool0AOooo`040000oooooooo00000oooo`030000oooo000000;oool010000?ooooooo`0000Goool0
0`000?ooooooo`0joooo000Yoooo0P0000Coool200001?ooo`800005oooo0P0004Ooool200001?oo
o`800004oooo0P0000Goool20000B?ooo`800004oooo0P0000Coool300001?ooo`800018oooo0P00
00Goool200000oooo`800005oooo0P0003coool00?oooonAoooo003oooooTOooo`00oooooi7oool0
0?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool0
0?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo000Joooo00MkNgajNg]jNW]jNW]j
NWYjNGYiNGX00WUiN@05NGQiNGQhNGQhNGQhN7Mh009hMgL3N7If0WQeM@09N7EdN7AdN7=cMg9`N7Ad
N7EeN7EfN7EeMgIf009gMGH2MWEe00=fM7EfMGEeM7D00WIeMP0@MWMhMWMiMgUjN7YkN7YlNG]mNGan
NWioNgn2O863OH>6OhJ:OH:5O822O7n1Ngj00g]nO`04NgeoNgenNgenNgan0g]lO@03NgalNg]loooo
01Woool019:3PY:3PI:3PI:2P0:APX03TH5o1920OP:@Ogd01HmoO8mnO8mnO8mnNhmmN`02Sgej00J?
O7V>O7R>NWN?O7V?OGZ?OG/4SWek0XilNP>=O7X01HelNhemO8inOHioOXj0O`02Sh6000Z@PX6@Ph:@
Q8BAQXJBQhNCRHZES8fCRHVCQhJBQXD4TXF400>BQH>BQ8>BQ8<00Y:4P`BBQ88Joooo00FaUhbaUXba
UX^aUX^`UH/00[2ERP03/9B:[iB9[iB900>_ThP00jjCR:jBQjjBQ`02[Y6600B]THF]T8F]T8F]T8@2
[Hn400>]Sh>]ShB]Sh@00Zf@Q003[I25[Hn4[Hn400>/Sh@2[8j40Zb?Q@05[I26[I66[I67[I:8[Y:8
00:^ThT01ZjDRZnES;2FSK2HSk6IT;2GSP:`UX`7/9J;00>`UXbaUXbaUX`00[6GS003/IN=oooooooo
01Soool2`ZJC00K1YY;1YI;1YI;1YI70YI70Y942`:B@0/2SS`:oXhl2_j:>0kjQS@03_Z6<_Z2<_Z2<
00:mX8`00kjPS;fPS;fPR`02_J2;00>nWh^mWh^mWh/00[fOR`06_In:_Ij;_In;_In;_In<_Z2<1;jP
S@06_Z6=_Z6>_Z6>_j:?_j>@_j>A1knST0;0Y902`:BA00C1YI71YI;1YI;1YY<2`ZJC7?ooo`006_oo
o`09NW]kNWYjNWUjNGUiNGQiNGQhN7MgN7IgMgIf00=gMGD057IdM7IcLgIcLWEbLWEaLGEaL7E`L7E`
KgA_KWA^KGA]K7A/JWA[J7E]K7E^KWE_KgA_KgA`L7=`L7=_K`9bKVl05G9^KW9^Kg5^Kg5_LG9`LW9b
M7=dMWAfN7EhNWIjO7MkOWQmP7V0Pg^3Qgf7Rgn;T86=TWn8S7f5R7f3QWb1Q002O82300EkP89kOh5k
OX1kOX1kOGl00W]mOP9kO7d00g]lO?ooooooo`0Hoooo00BBPh6BPX2APX2APGl2T81n00B?Ogf?OWb?
OW^>OG/2SWaj00n=O7V=NgR=NWR<NWN<NGJ<N7F;N7F;MgB;MW>;MW:;MG6;M6n;Lfj;MG6;MG800X]f
M003RWMdRWIdRGIc00>8MG<058QdLhQeM8QeMHQgMXUiN8UjNX]lO8]nOHaoOhf0P8j2Phn5QY28RI:;
S9B?TIFATiB<SI:9RY:8R967Q`:AQXH01966QI65Q965Q965Q0BBQ8<2TXB26_ooo`04/IJ</IF;/9F:
/9B90ZnCR004[Y:7[Y66[I66[I250Zb?Q004[8n3[8j2Zhf1Zhb10ZZ;O`08ZHYnZHYmZHUlZHQlZHQk
Z8MkZHMjZHQk0jV8O003Z8QmZ8QlZ8Mk00FWQW/04:N6O:N8OZR9OjR:P:V;PJV<PZZ=PjZ>Q:^?QZ^A
R:fCRZjFSJnITK2JTZnGSZjES0J^U8X2[iB:00J_UHZ`UH^`UX^`UX^aUXbaUh`Joooo00[2YY?1YI;1
Y970Y930Xi2oXhnoXXjnXXfnXHfnX8`2_J2;00ZmWhZlWXZlWXVkWHRkW8NjVhJjVhFjVXFiVXBiVH@2
^IV30[VIQ003^IR3^IR2^IR300:iV8<00kVGP[RGPKRGP@02^9J10[RFPP04^9R4^IR5^IV5^YV60kZJ
QP04^Y^7^ib9^if:_9j<0[bPS`04_9n<_9n;_9n;_9n;0kfPS009_Z2=_Z6=_Z:>_j:?_j>@`:B@`JFA
`JFB`ZJC01coool001[oool02WYjNgYiNWUhNGQhN7QgMgMfMWMeMGIdM7IcLgEbLP9eLW4047AaL7A`
Kg=_KW=^KG9]K79/Jg9[JG5ZJ75YIg5XIW5WI75VHW5TH79WI79XIg9ZJ@9aJVX06G1ZJVmYJFiYJViY
JVmYJViYJViZJfi/KFm]Kg1`LW1aM75dMW9fNGAiO7ElOgMoPWV3Qg^7Rgj;TH:AV8:@UX2;T7j8S7f6
RGb4Q`02O8>600QlPHAkPH=kP89kOh5kOh1kOX1kOGmkOGh2Ngam6_ooo`0:TX>1TH:0T85oT81nSgmm
SgilSWejSGaiSG]hS7Yg0X]iMP0ARgQeRWMdRWIcRGEaRGA`R7=_R79^Qg5]Qg1[QfmZQfiYQfaWQV]U
QfeXQfm[Qfm/Qg1]00:6L6d00hE_KHA_KXA_KP02QFm^01>4Kfn5LG66Lg>6MGF7MgN7NGV8NW^9OGf:
Oh2;PX>=QXN?RH^BSI2ETiNETYFCSY2BRhbARHZAR8P00Y67Q`03THJ6THJ5THF500:AQH@2THB30Y:4
P`03TXB2oooooooo01Soool02[6FS;2ERjnDRJnCR:jBQjfAQZf@QJb?Pj^=PZ^<P@:ZRgl04jV:OZV9
OJR8O:N7NjN6NZJ5N:F4MjF3MJB2M:B1LjB0LZAoLZAoLJAoLZB0LjB0M:B1M:B1MJB0M@04Xh1e01>S
OgFSP7JTPWRUPgZUQG^VQWbVQWfVQgfVR7jVRX2WS8:YSXFZTHR/U8b^V96^V92]UHb/ThZ/TXT01:bB
R009[I:8[I>8[Y>9[YB9[iB:[iF:/9F;/9J;/IJ<01[oool02/6VTl6UT/2TT;nSSknRS[jQSKfPS;fO
R[bNRK^MR0:kW8L02KZKQ[VJQ;VIPkRHP[NGPKJFP;JEO[FDOKFCO002]99k00>dTGZdTG^dTGX00[BA
NP:dTG/00kFANkBANkBAO002]95l0[F@O004]Y5m]Y=o]iB0]iB00[JCO`09]I=o]IB0]YF1]iJ3]iR4
^9V7^Yb:^Yf:^I^700:iVXH03KZKQkZLQkZLQk^LR;^MRKbNR[fORkfPS;jQSKnRSl2ST<6UTL6VTP0L
oooo000Joooo00YjNW]iNGUhMgQhMgMgMWIfM7AfLg=eLW5dLG1cKfl2Lfm^011bKFaaK6YaJVU`JFQ`
J6I_IfE_IV=^I69^Hf1^HUm^HEe^Ge]^GUU_HEi_Hf5_I6<2KVET01U]IFE/IFI/IFI/IFI]IFI/IVM[
IfQ/JFY]JVe]K6m^KW5^LWE`MGQbNGadO81fP8EiQHYkRHmoSiF2UIb1TIQoSY=nRi1mR8emQXX00Wb5
R00:O8>7Nh:5Nh64Nh23Nh22Ngn1Ngj0NgeoNgenNgam6_ooo`0:TX:1TH5oT81nSgmmSWekSGajS7]h
RgUgRgQeRWMd0XUfLP0@R7AaQg=_Qg5]QW1/QFiZQ6eYQ6aWPfYUPfUTPVQRPVIQPVEOPfAMPfMQPfQT
PfUU0X=ZI`0IPVYXPV]YPV]ZPV]ZPf]ZPfa[PVe/Pfi]Pfm_Q75aQ79cQ7EfQGQiQg]lR7j0RX:4S8J8
SXZ=THnBU9BHTi6ETXjATHb>T8Z;T8R:00:@QhP01927Qi26QY26QY25Q@:AQH@2THB300>BQ8>BQ8;o
ool06Oooo`0:/IJ;/9B:[i>8[Y:7[I25[8n4Zhj2ZXb1ZH]oZ8Ym0ZN8O00;YXIjYXEhYH=fY89eXh1c
XWmaXGe_XGa^X7Y/WgU[WgQY00:OMfP00j1hJZ1iJj1iK002X7Y]01NPNVjPNg2QO7:QO7:ROG:QOG>Q
OWBROWBROWFSOgJSP7NSPGRSPgVSQ7^TQWfURGnVRh:XSXFYTHV[U8b[Th^ZTXVZTHL01:Z@QP0:Zi26
Zi66[967[9:7[I:8[Y>9[YB9[iF:/9F;/IJ<6_ooo`0:`JJB`:FA_j>@_Z:>_J6<_In;_9j9^if8^Yb6
^IZ50[RIP`0:]iN1]YIo]IAn]9=l/i9j/i1i/Xmg/Hee/8ad[h]b0Zn:L@B_RW801;2:L[2:Lk2;M;6<
MP:cSGP04;>>N[>?N[B>N[B>NKB=NKB>N[B=N[B=NK>>NK>>N[:?N[>@Nk>AOKBBO[BCP;FDP@:eUH40
0kJEPKJFPKNGPP02]iR300ZhVHBiVXFjVhJkW8RlWXVmWh^nXHfoXXk0Y931YI8Loooo000Joooo00Yj
NWYiN7UhMgMgMWIfM7AeLg9dLG1cKfmbKVeaKF/2LF]Z01A`JFQ_J6I^IVA]IF9]Hf5/HUm[H5e[Ge][
GEUZG5M[FUI[FEA/F5=/G5Q/GU]/Gee[H5m[HF1ZHF5ZHV82JF9R01EYHF9YHV=XHfAYIFMZJ6YZJVa[
KG1/L7=^M7M`NGebO85ePHIhQXakS99oTYV2Uin0TiYoSiInS99mRXmlR8d00Wb6R`0:O8F9NhB7Nh>6
Nh64Nh23Ngn2Ngn0NgioNgenNgam6_ooo`0:TH:0T85nSgmmSWikSGaiS7YgRgQfRWMdRGEbR7A`0XMb
KP0DQW1/QFiZQ6eXPf]VPVUTPFMRP6IPOfANOf9LOV5JOUmIOUiGOeiFOf1JOf9MOf=OOfAQOfEROVES
OVIT0WiVI@0EOVMUOVMVOVUXOfYZP6a/P6i^PG1aPG=cPgIgQ7YkQWeoR863RXF8S8Z>T92DTYBITI6E
T8jAShb?ShZ<ShV:00:?R8T00hn7R8n6Qhn6QP02T8F500F@QHBAQ8BAQ8>BQ8>BQ8806_ooo`0:/9F;
[iB9[Y:7[I66[8n3ZXf1ZH]oZ8UmYhQkYXIi0ZF4M`0;Y89eXh1cXGiaX7e_Wg]/WWUZWGMXW7EVVg=S
Vg5QVW1P00:JKel01i]aHI]bHY]bI9]cII]dIiadJ9aeJP02W7I[01FMMfbMN6fMNFjNNW2ONg2ONg6O
OG:POWBPOWFPPGNQPgVRQG^SQgjTRX6WSXJXTHVXShNWSXFWSHBWSH>XSH<00ZR>P`0:ZHj4ZHn4ZXn5
Zi26[966[I:7[Y>8[iB9/9F;/IJ<6_ooo`0:`JFB`:B@_j>?_J6=_9n;^if9^Yb7^IZ5^9V3]iN10[FE
O`0D]9=m/i9j/Y1h/Hif/8ad[hYb[XU_[8M]ZhE[ZX=YZX9XZH9WZX9XZX=XZX=YZh=ZZh=[ZhA/[8E^
[HI_0Zf7L@03[XQc[XUd[hYe00:`RWD02[29M;2:M;69M;28Lk29M:n9M:n:M:n:MK2<Mk6>N@:aSgX0
1;:?N[:@N[>ANk>BO0:dTgh02[FEOkNFPKRHPkVJQKZKQk^MRKfORkjQSKnSSl6UTQcoool001[oool0
2WYiNWQhN7MfMWIdM7EcLWAaL7=_KW9]K75[JW1ZJ09_J6H04ViVI6eTHVaRH6]PGFYNFfULFFQKEfMI
EFMGDVMED6MDCfQCCVUCCFUGDVUIEVUJF6QLFVQLG09WGEd3IUeN01AVGUmVH65VHV=VI6IWIfUXJVeY
KG5[LgI]N7]`O85cPHIgQhejSYEoUIf1V:1oU9]nT9QmSYAmRi5lRXl2O8R=00YlQX]kQHUkQ8MkPhIk
PHAkP8=kOh5kOX1kOGmkO7dJoooo00ZAPX2@P7j>OWb=O7Z<NWN;N7F9MW>8M767LVn5L6`2Q6iZ01>3
K6R2JVF1J6=oIV5nI5imHUalGeUkGEMjFeAjFE9iF51jEdmkEdmlFUAlG5MlGUUkGe]kH5ekH5h00gYP
G`0ENV5PNV9QNfASNfEUNfMWO6YZO6a]OFm`OgAdPGMhPg]mQGn2QhB8RXZ>SY6FT9>ISi2DSXfASX^?
SXZ=SXV;00:>R8T01hj7R8j6Qhn6Qhn6QXn5QI25Q924Q002THB300>BQ8?oooooool06?ooo`0:/9F:
[i>8[I66[8n4ZXf1ZH]oZ8UmYXMjYHEhY89e0Z:0L`0DXGi`X7a^WWU[WGMYW7EVVW=SVG1PV6iNUf]K
UFUHUFMFUFIEUFMFUVUIUf]LUfaMUfeNUfePUfiQUfiR0YM_H`0CV71TV75VVG=XVGAYVGAZVWE[VWM/
VWQ]VgY_W7]`WGecWX1fWh=iXHImY8^3YHf5Y8^2Y8Z1Y8Z000:URX02YX^000ZWS86XS8:YSH>ZShB[
T8F/THJ]TXN^ThV_UHZ`UX/Joooo00[1YI:oXhnnXHfmWh^kWHVjVhJhVXBgV8:fUWndU7d2/i9j01Bb
T7R`SGF_Rg>^RG2/Qff[QF^YPVRXP6FVOV:UNenTNEfSN5bTNEfUNenUO66VO6:VOF>WOFFWOVJXOVL2
Z7mX00>YP6VZPVbZPfd00Z^3K@B[Pf`2Zh9[00ZZPffZQ6f[QFn/R7>]RGB]RG:^RG>^RW>_RgF`SGH2
/Hmh00ZcTG^dTWfeUGngUh:hVHBjVhJlWHVmX8boXXk0YI4Loooo000Joooo00YiNGYhMgMgMGEeLg=d
LG5cKfiaKFa`JfU_JFM^IfD2K6AR01A[HV1ZH5eYGU]XG5QWFUIVEe=UEE5TDdiSDD]RCTUSCDMTCDIW
D4UWDdiWEE9VEUAVEeIUF5QTF5QTFET2HeUJ01ERFEYRFU]RFeeRGEmSH6=SI6ITIf]VJfmXLGA[MWY^
O81aPHIfR8ijSiMnUZ1oUj1nU9amTIUmSiIlSI=lRi400Wb9SP0:NhN<NhJ:NhF9NhB7Nh:5Nh63Nh22
Ngn1NgioNgan6_ooo`0:TH60SgmmSWekS7]hRgQfRGIcR7A`QW9^QFm[PfeY0X9ZIP0AP6QSOfIQOV=N
O65KNeiHNEaFN5UCMeM@MUA=M55:M4m7MDi5Me59N5E?N5MBN5UDN5YF009gFeP00gIKFGIKFWIKFP02
MUaK01=fGEefGemgHV9gIFEhJ6QiJfakL71mM7EoN7Z2OGn5PhN8RHj<T9J=TIJ<SY><S92<Rhj<RHb<
R8/00Xb8RP04SHN9SHJ8SXJ7SXJ60Xn5Q@04T8B4THB4THB3TXB36_ooo`0:/9F:[Y:7[I25Zhj2ZH]o
Z8UmYXIjY8AgXh5dXGma0Z1lK`0DWWY/WGMYVgEVVG9SV6mOUVaLUFYITfMFTVABT61>SUe;SU]8T5i;
TV9BTfAETfIFTfIHTfMITfMJTfMK0i=XG00?TfQMTfUNTf]PU6aQU6iRUFmTUG5VUWAXUgIZV7Q/VWY_
W7idWX9hX8ImX8Mn00:QQW`00j66Nj:6O:>7O002Y8Qm00ZURGjVRh2WS86XSH:ZSXB[ShF/THJ]TXR_
U8Z`UX/Joooo00[0YI6oXXnmX8blWXVjW8NhVHBgUh6eUGndTgbbT7T2/8if01B_S7>]RG2/QffZQ6ZY
PVNWOfBUO62SNEfRMUVOLeFMKe6LKDjNKe6PLeNQMEZQMU^RMUbRMefRMejSMeh2XgQO00BSN62TN66T
N6:UNF82YGYR00nUNV>UNf>VNf:VNf:UNf:UNf>VOFFWOVNWP6VXPFZYPFZYPV^ZQ6b/QVj]R7000Zj:
L`0:/8ef/Xmi/i9l]IAn]iN1^IV4^i^7_9j:_Z6>`:BA7?ooo`006_ooo`0:NGUiN7IgMWAdMG9aLfm_
LVe/L6]ZKfQWKFITK6AQ0VYQG`0DJEmLJ5aIIUYFIEMCI5E@HU9=HE1:H4e7GdY4GDM1Fd@mI4Y2Idm9
IU1<IE5>I59@He=BHUACHEADH5AD0V1DE@0EGeAEGeEFGUMHGUUKGUaOGf1SHFEXHVU]IFmbJ7EiK7^0
L867M8R?N8nGOINPOIJOOIBLO9:IO92GO8jDNhbB009kRY002W^9SW^7S7^6RW^4R7^3QW^2QG^1Pg^0
PW]nP7]mOQ[oool02Y61OhmnO8elNH]iMhYgM8QdLHIbKXA_Jh=/J85ZI@9oIf8057iTGgaQG7YOFGUL
EWMIDgIFCgACC7=@BG5=AFm9@Fa5?79:@GI@B7IBBgECCWEDD7AEDGAEDW=EDg9ED`9bEE@05G5EE75E
EG5GEW5IFG5KG79OH7=SI7AWJ7I/KGUaLgafN7mkOX:1QHJ7S8Z>U8Z>ThZ<THZ;ShZ:SHZ9S8^8R`02
RhN:00Z<QhV<QXR=QXN>QXN>QHJ?QHF@QHF@QHBAQ8>BQ8<Joooo00Z`U8Z^TXN/Sh>ZS82XRGfVQgZT
Q7NSPGBQOW6ONfh2WGUZ01:KMVNJLfBHL62FKEfDJUVCIUFAHe:?H4j=G4V:F4F6DCf9E42>FdR?GDb?
Gdn?H56?H5:>H584SV1C012>Ge>=GeB=H5B=HEJ=HeR>IEZ?J5b?JUj@KF6BL6BDLfNFMFZHNFjJOG:L
P7JLPGH2WH5f00>NPWNOPgRPQ7T00Z65NP0:XhMlY8QmYHYoYh^1Z8f2ZXn4Zi66[I:8[YB9/9F;6_oo
o`0:`:BA_Z:>_In;^ib8^IZ5]iN2]IEo/i9k/Y1h/8ee0Zj:LP0?[8Q_ZXE[Z89XYgmTYGaQXgUMXGII
Wg=EWFmAVV];UFA3UFA4VV]<W6i@WFmC00>ML5D019e`EYi_EIi_EIi_E@>NKUD04Yi^EYi_Eii`F9ma
F9mbFImcFJ1cFZ1dFZ5dFj5fG:9gGJ=hGZ=iGjAjH:EkHZInI:R0IjV3JP:[QFd02Zf8LJn;M;6>N;>A
NkFEOkNHPkVKQ[bNR[jQSL2TT1coool001[oool02WUiNGQfMgIdM7EbLG=_Kg9]K71[JVmXIfeVI6aT
H@9ZHEl056UOG6QLFFIJEVEGDfAED69BCF5@BV1=Aem:A5e7@E]4?FA:@VM?BFI@C6EACVABD6=CDV9D
Df5DE61DE09PE5D05EmDEEmEEUiGF5iIFeiLGemPHf5UJ69YKFE_LVQeNFakP721QgB8SgR?UgfGX7fF
WgfDW7bBVGb@Ugb>U7^<TP02NhZ@00YkRHikQhakQXYkQ8QkPhIkPXEkPH=kP89kOX1kOGhJoooo00ZA
PGn?OWb=O7V;NGN:MgB8M766LVj4Kf^3K6R1JVD2OfMR01AnI5mlHEajGeUiG5IgFE=fETmdDdacD4Ua
CDE_BD5/ACabBT5fD4QfDT]eDdieE51dEE5dEE9cEE=bEE<2LUED01EaEEAaEEEaEeIaFEUaFeabGf1c
HfAdIfQfK6eiLG=lMWQoNgj2PHF6Qhb:SYB:SY>:S96:Rhn:RXf:RHb;R8/00X^7RP0:S8N9S8J8SHJ7
SXJ7SXF6ShF5T8F5T8F4THB3TXB36_ooo`0:/9B:[Y:7[8n3ZXb0Z8UmYXMjY8AgXh5dXGiaWg]^0Yei
JP0BVgIWVW=TV71PUVeMU6YITfIETF=BSf1>SEa9RUQ5QU4mREA0SU]8See<Sem?Sf1ASf1BSV1B18iP
D`0@SUmCSEmDSF1DSF5FSF=HSVEJSfQLSfYNT6eQTW1TU7=WUWEZV7U^VWebW81fW85f0Yf1MP03WX9g
Wh=hX8Ai00:QQGX02Z>7O:B8OJF:OjN;PJR=PZZ?Q:^AQZfBR:jDRK2ERa[oool02/2TTKjRS[fORk^L
R;VJQKNGP[FEOk>BNk:@N;2=M@:^RW803jb8KjZ5JjR2J:MoI:ElHJ=iGJ5fFImcEIe_DIY[BiET@iET
A9Y[C9a^D9e_D`03WG1E00BML5JNKeFNKeFNKeD3WViE01:NKUJNKeNNL5ROLEROLUVOLeVPLeZPM5ZQ
M5^QMUbRMefSN5jSNEnTNV2UNf:VOVBXP6NYPfX2ZhE]00Z]R76_RgBaSWRcTG^eUGngV8>iVhJlWXZn
XHg0Y90Loooo000Joooo00YiNGUgMWIfLg=dLG1bKVe`JfY_JFM]IVA[Hf5ZHEh2J5iK01AWFeQUF5ET
EU9RDdiQD4]OCDQNBTALAd5KA3eI@3UH?cMYCDEWCTMTCTUSCT]QCdaPCdiOD4mND51MD502G4mA01EK
Ce5KCe9JDU=JE5MKF5]LGV1MHVIOIf]RKG5VM7QYNGm^P8MbQhmfSYIkUZ1kUIikTiakTYYkT9QkSYIk
SI@00W^;T@0:NhZ?NhR=NhN;NhF9NhB7Nh:6Nh64Nh22Ngj0Ngen6_ooo`0:T85oSWikS7]hRWQeR7Eb
QW9_Q6m/PfaXPFUUOfIR0WeSGP0DNf1KNEeGMeYDMUM@M5A=LU59L4e5KdY2KDHmJT8iJD0fMTa3MDi6
M4i8Ldm9LDm;LE1<L51=Ke1>KU1?0Vi?C`0BKDm>K4i?K51@Je9CK5IGKEYKKUmPKf=TLVQZMFi`N7=e
O7UlOgj2PXB9QXZ@QhZ?QhZ>QhV>0XR8S00=RHN;RXN:RXN:RXN9RhJ8S8J7SHJ7SXF6SXF5ShF5T8F4
THB3TXB301[oool02ZnDRJfAQZ^=PZV:OjN7NjF4N:>1M:5nLImkKIehJP:JMFH049QaHYI^GiA[Fi=W
Ei5TDhmQCheMBX]IAXQE@HI@?8A=>H]E@HaHAHaIB8]JBH]JBP::FT/06HYJC8UJCHUIC8UIC8QGBhQF
BXMFBXMGC8MJCXQMDXUQEHUSEh]WFheZGXm]HI5`I9=bIiEeJIMhKIQiKIUjKiYlL9]mLIaoLif0M@02
Wh9g00ZPQ7VRQW^TR7fURWnWS86YSX>ZT8F/TXN^ThV`UH/Joooo00[0Y92nXHflWXVjVhJhV8>fUWnc
TgbaT7R_SGF]RW42ZhM^00jYQ6ZWPFJUOV>SNenQMe^OM5JML5:KKDjIJDVFI4>DHD2EHd>HJ4VIJD/2
VFY=00BIJTjIJDfIJDjIJDl2V6M>00ZHITbHI4^HHTZGHTVGI4^HITfHJ4jHJE2IJe6JK542VfeB00VL
KE:LKE6LKE6NKe>OLEJPM5VRMebTNV2VOF@00ZR1J00:ZXA/[8Q`[h]d/Hmh/i9l]YJ0^9V4^if8_J2<
`:>@7?ooo`006_ooo`0:NGQiMgEeMG9bLfm_LFe/KfYXKFMUJfARJV5NJ5iK0VIKE`0DI5QDHeA@HE5=
Gdi9GT]6G4Q2FTDnFD8kEchgE3XbHD@kJdi5ID]5HT]6H4Y7Gd]8GD]9G4a;Fda<FTa<0UU;C00EF4Y<
Ed]>ETi@Ee9DF5IIFE]NFV1TG6EYH6a`I79gJ7UnK7n6L8J>MHfENIBMNIBNNY>LNY:KNY6INXnGNXjE
009kS9<02W^;TG^9Sg^8SG^6Rg^5R7^3QW^2Q7^0PW]nP7]mOQ[oool02Y20OXimNhajMhUgM8MdL8E`
KH=]JH5ZIGmVHWaSGP9jH5X057QLEgIIDgAECg9BBg1?Afi;@fa7?f]4>fU0=fHl<G55>WY?A7A<@g5;
A6m:AFi:AVe:Afa;B6];BFY:B@9YBDT05FQ9BFM9BVM;C6M>CfQBDfUFF6YKG6aOHFmUIg9[KGE`LgUf
NWalP821QX>6S8>7S8B7S8F7S8J7RhN7RhN7RP02R8J:00Z9QXV:QXR;QXR<QXN=QHJ>QHJ?QHF@QHBA
Q8BBQ8<Joooo00Z_U8V]T8FZSH6XRGfVQWVSPWJQOg:OO6jLN6ZJMFH2V75R01BFKEjCJUZAIUF?HU6=
Gdf;FdR9EdB7Dcn5CcZ2BcF:Dcb@FTF;ET>9ED>8E4>7E4>6E4B5E4F5DdF4DdD2Q59501F3D4B2CdB2
D4B2DDJ2DdR2ET^3FDf5GE66H5B8I5R;Ie^>Jen?KF6AKf>BLFBCLFBEM6NFMVZGN6bINfnKOG400Yao
L`0:WX5fX8AhXXIkY8QmYXYoZ8b2ZXn4[966[Y>8/9F;6_ooo`0:`:B@_J6<^if9^IZ5]YN1]9Am/Y5i
/8ef[HYbZhM^0ZV4JP0@Yh1VY7eRXWUMX7IIWW9DVfm@VF];UfM6UF=2Tf0lV6I2VfY9UfI6UVE6UFA6
UF=50YASAP06U696U656Tf16Tf16Tei4TUe30Y9L@P0ATUa3TEe4TUm5Tf56Tf=8U6A9UVE:UfI:V6I:
V6E8Uf=5V6A6VVQ;W6a?WW1DX7AIXWQM00:TO6802ZN0IjV4Jjb8L:n<MK:@NKBDO[NGP[ZKQkfORknS
Sacoool001[oool02WUhN7IeMGAaLG9^KW1[JViXIVaUHfYQGfQNFfIKF09TEe@0569DD61AC5i=B5a:
A5Y6@EU3?EM0>EHl=58g;e`n=FM8?fE8@698@Um7@Ue7@ea7A5Y7AUU8AeQ8BEM7B@9FAdP05EA5B5A7
BU=:CEA?DUEDEeIJGEMOHUYTJEi[Kf9bMfMhOV]oQFj5S7>;TgF@VWRDWWVCWGVCW7VAVWZ@V7Z?UP02
NXfD00YkS99kRY1kRHikQhakQHYkQ8MkPXEkPH=kOh5kOGhJoooo00Z@P7j=O7Z;NGJ9MW:6LVn4KV^1
JfMoIf=mHemjH5/2N5aF01AfF59cEDiaDDY_CDI]BD5[ASeY@SUW?SAS>2e/?cAfBSmdBCmaB41^Ad1/
AT1ZAT5YAT9XATAWATEVADD2IDA401ET@T=TA4ESATQSBD]TCU1UDeEVF5UXGEm[HVE^JF]bKg9fM7Qi
NGelOH9nPHJ0QHZ1QHZ2QX^3QX^5QXZ6QXX00XN6RP0:R8J9RHJ9RXJ8RhJ7S8F7SHF6ShF5T8F4THB4
THB36_ooo`0:[i>9[924ZXb0YhQlY8EhXX5dWge_WGU[VWEWV75R0YE]GP0DTfUIT6EESV5@S5e;REU7
QeE2QE4mPddhOdH`QTdgSUM1ReA0R58oQU4nQ4lmPdhmPThmPDhnP4hoP4do0Wm;?`0EOdTnOTPmOTTn
OTY0OTa2OU15OU=8P5M;PU]?Q5mCQf=FRFIIRfQKSFULSFUKSf]MT6iPTW5TU7AWUWIZV7U]00:JO700
2YaoLij1MZ24NJ:6NjB9OZN;P:V>Pj^@QJfCR:nERQ[oool02/2ST;fPS;ZLQkRIPkFFP;>BNk2>Mjj;
Lj^7KZV4JP:VP6H05:AlHJ5iGImeF9aaDiY]CiQYBYEUAI=Q?i1K>9EQ?Y]YB9MVA9ES@Y=Q@I5O?i1N
?Y1M?XmM?hmL?hmK?`:?FSl03XiH?XiE?8eD>heD>heD?8eE?8eH?XeI?hiL@HmN@Y1O@i9P@i=P@Y=N
?`:BFcX01IEP@9MTAYUYBia^DIibE`02XGML00ZTNf:WP6NZQ6b]RG6`SGJcTG^fUX2iVXFlWXZoXhlL
oooo000Joooo00YhN7QfM7AdL71aKFe_JVQ]IVAZHf1XGeaVFeQTF5@2HUA@01AOD4aMCDQKBDAIAD1G
@S]E?SMD>S=B=bmG>C1S@cYR@c]PA3aNA3iL@ciJ@cmH@d1GA4=FA4AEA4ED@dD2DdA601EA@dIAAdY@
BdeAD5=AE5MCFEaDGV5HI6QLJfmPLGIVN7iYOXE]Q8aaRI9cSiQfTiegU9ihTiehTYaiTIYiT9P00WZ>
UP0:NXfDNh^BNhZ?NhR=NhJ;NhB8Nh>6Nh64Ngn1Ngeo6_ooo`0:T81nSGaiRWQeR7AaQG1]PVaYP6UT
OFEPNV5KN5eG0WEID`0DLeE>L55:KTa5JdQ0JD@lId0gIC`bHcP^J3/`LT@iL4@iKd@jKD<lJT8kJ44k
IT4lID4nI48oHd90HT100V91@@0EHD52H4E5GdM8H4a=H4m@HE9DHUEHI5]MJ65SK6MZL6e`Lg9fMgMk
NW^0O7n5OH:7Oh>9P8B:PHF:PhF:Q8F:00:5QXX02XN6RHR6RHV6R8^6R8b6Qhf5QXj5QXn5QI25Q964
Pa[oool02ZnCR:b?Q:V;OjJ7Nj>3MZ1nLIijKI]fJ9QbHiE^G`:CJUX0591UEHeQD8]MBhQHAXED@H=?
>h1;=Wm6<HA;=8YA>hQ@>XI?>XA>>X9<>H1:=gi8=ge8=ga8>7a8>G]7>@9kAcX017]8?7Y;?WY<?gY>
@P9iCd<03gY?AG]CB7eHBh1LCh=ODhEREXQUF8UVFHYWFH]VEhaWF8i/GY1_HY9bIYEfJ@02UgU]00ZI
O72LOg>NPWNQQGZSR7fVRX2XSH:ZT8F]TXR_UHXJoooo00ZoXhnlWh^jW8NgV8:dU7jaT7V^S7B/R72Y
QF^VPFL2Y7eR016QNEfNMERLLE>IKDjFJ4VDI4>AH3j?G3VDH3fGI4:EHT2CHCnAGcj?GCb=FSV<F3N;
EcL00XYF>00HRUDiRUDjRUDjRULlRUPmREPmRETmRELmR5@jR5<iQe@jR5LkRUTmReXmSE/nSU`nSe/l
SePhSUDbSeHdTUdlUF93UfM:VVa@0YebEP0:X7MMY7aSYh5XZXI^[X]d/I1j]IEo^9V4^ij9_j:?7?oo
o`006_ooo`0:N7MhMW=cLg1_L6a[KVQWJfARJF1NIeeJI5UEHUEA0UmAC@0DGDe8FdU4F4DoET4kE3df
DSTbD3D]CS4XG3`aGcleGd4hGD4iFd0kF3ljEShjE3lmE450Dd52DT52DT530U54A@0ECdI8CTU:Cdm@
Ce9DCU=ECeQKDEiQEVAXFV]_Gg5fI7QnJ7j5K8>;KXRALHfGM96KMiFPMiBOMi>MN9:LNI6J009jT9P0
2WZ>UG^=Tg^;TG^9SW^7S7^5RG^3Qg^1Q7]oPG]mOa[oool02XmoOHakNHYgM8McL8A_Jh5ZIWiVHW]R
GGQNF7IIE09cEDl0571ABVe<AF]8@6Q4>fDo=V<k<F4f;5da9VPj;Vdo<fa0=V]0=fU0>6Hn=f<l=V4l
>64m>f0n?Eln?Eln?P9N@D0045e4A5e8Aee=C5i@D5a?D5eBDeiFEf5KG6EQHfUVJ6i/Kg5aMGAfNWMj
OgUmPg^0QP9mPhT00gn4RH24RX:5RP02Q8F:00Z6QXV7QXV9QXV:QXR;QXN=QHN>QHJ?QHF@QHBAQ8<J
oooo00Z^ThR[SX>XRWjUQGVRPGBOO6nLN6ZILfFFKf2CJe/2T6IF01B=HE6:GD^7F4J4Dd21CS]oBSEl
ABmi?bUnA2b3BS>3BcF2BcJ0BSInB3AkAC9i@c9h@c=g@cAf@cAgA3H2MdHi00EgBcegCd9gE4IgETQf
DdH00WE@A00>Me96NEE9O5Q<Oea?PV1BQ69EQVAFQfAFR6AFRFEFRVMHS6]MSfiQTG9V0YAfJP0:UgU]
VWeaWH1eWh=hXXIkYHUnYhb1ZXn4[9:7[iB:6_ooo`0:_j>?_9n:^I^6]YN1/i9l/8ig[HYbZXI]Yh9X
Y7iS0Z5iGP0DWWEIVg5DVFa>UVQ9Tf=3T5lmSEXgRED`RUHaT5`hT5djSedjSE/jReTgREHdQU8bQE4b
QE4cQ54cQ58d0XED=`0EQUXmQUi2Qf55Qf96QEe1PeLlPe@hPe8gQ5<gQEDhQeHhR5LiRUPjRePhReHe
Re<aRe8`SEDdT5/kTf53UVM:00:IKE402YecF:5hGZEnIJR3Jjb9LK2>Mk>COKNHPk^MRKjRSQcoool0
01[oool02WQgMgEcLg9_KW1[JVeVIFYSHFMNG6EJEf9FDf1BCP9MCTT055Y9A5Q5@5E1>e<m=U0h<Dhd
;4`_9e8c:650=Eho=E`n=UXo>5Pm>5Dk=e4j=e0k>U4n?dln@4do@596A`9AB4T05E1<CDm>Cdi>D4a@
DT]BEDaIG4eLH5=RIUU[KemaMVAhOfQnQV^3Rff7T6n<UG6?VWBCWWFEX7JDWgNCWGVBV`02NY6I00Yj
T9MkSYEkS99kRY1kR8ekQXYkQ8MkPXEkP89kOGlJoooo00Z?Ogf<NgR9MW>6LFj2KFUoJ6AlI5miGeYf
FeEcEU02L59;01A]CDIZB45W@c]T?cIQ>S5O=B]L<2EQ<bM^?c9[?S=Y?C=W?SEU?3ER>S=O>3=M>3AM
>SQK>SUI>SYM@T82GTM601ENBdYNCTeNCTiKCTiID51JEEIJEUMNFE]RGf5WIFM/Jfm`LGEbMGYdN7ef
Nh5gOXAiP8MjPHQlPhUnPhZ0Q8X00X>5RP0:QHJ:QXJ:R8J9RHJ8RhJ8S8J7SXF6ShF5T8F4THB36_oo
o`0:[Y:7Zhj2YhUmY8AgXGmbWGY]VWIXUg5RU6aMT6MG0XeRDP0DRUi<QeU7Q5=1PDhkOTTeNT@_MchX
O44YPdTaPDPbOdPcOTPdO4LdNT@aMd4^M3h]Lch_LSh`L3haLdLi0WI?@@0>MeA6N5Q<N5M;MEA7LeI8
LUM:LEA7LU54ME96N5I9O5Y=OeeAPF5CPf9D0XARE005QF5BQV9CR6IHRfYMSViR00:ALfL02YEgJiQk
Ki]nLij2Mj65NZB8OJJ;PJV>Q:bAQjnDRQ[oool02[nRSk^NR[RJQ;FEOk6@NZj<M:^8KjR3JZEoIJ9k
H0:OMUX059abEIU]CiEXBI9S@hmO?HaJ=hQD<8]F<XiJ=XeJ=haI=h]I>8UH=hME=8EB<H9>;X1<;H1<
;Wi<;WmD=P:4GT405HISAhUXCXQVC8IQAH=RAH5QAGiJ?WeB=Wi?<h1A=8=B=XED=hMF>8QF=XQD<hMA
;hM=:XM>:hYD<hiK?95QA002UVQ;00ZJKU>NMEZRNf6VPFRZQVn^S7FbTWbfUh:jW8RnXXhLoooo000J
oooo00YhMgMeLW9bKVe_JFQ/IF=YHEmVG5YSF5EPDe1NCd/2Fd]601AHAT5E@C]B?CI?>35==2a;<2M8
:b9I>2eO?SAM?SAJ?3AH?CME>cIB>3A>=cA=>CQ<>ca@A4ABBDUFCTl2DDe>01E?CTm=CDi;C4e;DUA;
E5M;Ee];FEe@H6EHJViNLWMSN7mWOhIZPh][QXm/RYA_SIQaTYecUJ9eUJ5gU9miU9h00WZCW00:Ni6I
NhnGNhfDO8^AO8V>O8N;NhF8Nh:5Nh22Ngio6_ooo`0:SgmmRgYgR7EbQG1]PF]XOVMSNV9MMeeHM5QB
LE==0Vi>B00DJTU2Id@lI3lgHCXaGCD[Fc0VF2/PICLZJcdaJCdbIS/bIC`dHSXcGcPaFcHaFSHcEcLf
Fd0nGdQ6Hdi<0Um<B`0EGDi<G4e<FTa;FU5AFe=DFUAFFEAFFeUKH5mQIFEXJVY_KW5eL7AiLWMlLgUo
M7b2MWn6Mh6:NH:9O8>:OhB:00:1QH/02XB6RXJ6RXN6RXV6RHZ6R8b6Qhf6QXn5QI25Q964Pa[oool0
2ZjBQjZ=PJJ7O:>2MYmnLIaiJiQcIIE^Gi5YFXiTE0:;Gdh058MJB8AD@X5??7e9=GU4;gHo:G<j97Y1
:H17<7i7<Ge6<G]5<WU4<GM2<7@o;W4n;Vhl;G13=7I@@WUFB09gETT05GIGBWEFB7EFB7EJCGIJCWAI
CG9EBFmCAW5BAGEDB7UHC7aLCgiNDX1PDh1PDX5ODX5PDX9QE8=REHMVFH][G`02Sg1T00ZBMFVFNFfI
OG6LP7FPQ7VSQgbVRh2YSX>/THJ_U8XJoooo00ZnXXjkWHVgV8>dU7j`T7V]Rg>YQVfVPFRSO6:ON5`2
W7=G00RIKU6FJD^BI4F?Gcj;FSR8EC:5DBf6Dbl2RUPe00Z9F3J8EcF6ESF5ECB2DS60CbmlBb]lD364
H4>6I4P2QFE:01F5Idb5IDV5ITZ6J4b7Idf5I4V1GT9kESYiCc=lCS9nD3>1DCB3DcF4DcB5DS64Cbj4
CB^3C2^4CRj8E3B=Fcd00Y9SAP0:UVY?Vg5GX7QNY7iVZ8A][HYc/I1j]IJ1^Yb7_Z6=7?ooo`006_oo
o`0:MgIgM79aLFe/KVQWJfARIemMI5YGHEIBGU5=G4a80UU7@P0DET<mDchgCcTbC3</B2hVAb/SBBXP
GcdaGSdcFcddF3`dES`fDcXeCcLbBcLdC3XjC3hoET]:E4Y:DDY:0Tm:B`0ECDU9BTQ9B4Q:BDe@B4mB
BUAHC5QKDF1UEVM/GW5fHgUoIh26J8>;JHF>JXRBK8bGKY2LL9BQLiFPMYJQNIJP009kUIh02W^CVgbA
V7b?UWb=TWb:Sgb8S7b5RGb3QW^0Pg]nOa[oool02XmoO8]iMhMdLH=_K81ZIWaUH7UOFgEJEG9ECfi@
BP9[Bd@056Q6?VA0>64k<Ude:eT_9EL[8EPZ7fTj;FTl<6Lk<F@k<V8k<eli<U`f<5Tf<ETi=UTm>f57
AF17AEi7A@9LB4H05EY7AEQ6A5I6AEM:BUM;BeQ@DE]DEEiKGF1NHFASIfQYKVa`M6idN6meNg1gOW5j
PG=mQ7B0R7J0QgV2RWj5R`02PHJ;00Z3QX^5Qh^7QhZ9QhZ:QXV<QXR=QXN>QHJ@QHBAQ8<Joooo00Z]
TXNZS86VQg^RPWFNO6nJMVVFLF>CK5f?IUN<HE02R5]:01B5ETB1DCimBcMiA31e?RQb>B=c>B9l@R]m
ABilAC1jAC5iAC9f@c5d@C1a@S1a@c=bAcMfC3afCCedCCd2Ldho00mbCSiaCCe`CCi`CT1aCd5cDTAe
ETUfFDacEDYbDTMeEDUiFDekGE1lGU5mGU400WiND004Oei@P5m@Pf9EQfQL0Xa^HP0:T7=WU7M/V7]`
VgmdWX=hXXMlYHYoZ8f3Zi66[YB96_ooo`0:_Z:>^Yf8]YR3/i=m[higZhUaYhA[Y7mUX7YOWGEI0YY`
D`0DUV]=TfI7Sf50Re/iQe@aPdl[Q4l/QE8_QeHcQeLdQULfQELfQ5HfPUDeP5DeP5HfP5PhPEPiPUTk
PE/l0X5L?@0EPE`nPE/lP5/mP5XmPEXlPe`nQV13Q5i2OEHkN4`aNT/_ODhaOe0bPE4bPE0`PDd]PD/Y
P4TVP4XWPTd]R5Hh00:>Gd802Y=WBiQ^DieeFj9lHjN2JZ^9L[2?NKFEP;VKQ[jQSAcoool001[oool0
2WMfMWAaLG1/JfeWIVURH6IMFf=HEF1CD5e>BUU9A@9FA3l055<o>E0j=4`e;DP^9T4V7T@W7U<b9V90
=5dm<eTk<eHk=5@k=E4i=4dg<ddk>4m1@597AUM=C59;Bdm9B@9<B4T05DY5ATM5AdI5B4I9C4I=CdQD
EdYEFTiMHe=TJUa^M6AjP6N0QfN3RfN4SFN6TFV:UFb?VfjCWg:FXgJGY7^JX`02O9NQ00YlUIilTi]m
T9MmSYAlRi5lRHelQXYlPhIkPH=kOX0Joooo00Z>OWb:NGJ6Lg22KVYnJ6AkHeigGEQcF59`DTa/CDH2
JDQ001AU@SYR?CAN=biI<2IA9aaB9AYO<2A]?S5X?35U>S1R>C5O>C9M>39J=c5J>cMM@SmPBDISCDYN
BTMKAdD2FDI401EG@T5D@T5C@T9CADECAdMECTiGD55KEUUOG5mSHVEXJVi[L7A/LgQ/LgU]MGa^N7m`
O8=bOXIePHUiPhanQhd00X27S@0:PhN=QHN<QhN;R8N:RXN9RhJ8SHJ7SXF6T8F5THB36_ooo`0:[I66
ZHb0YHIjX81cW7Y]V7AVU6iPT6UJSF=CREi=0XEHA`0DPU=1OddjNdLcMT0[KSHOJc0IMS/SP4L`O4D`
ND<_Md<`MD<aM4<aLT<bLdLgMTm0NEM7NUQ8ME93LTho0W1<?00EKTPiKDLiK4LiK4LhKDPiKTdnL4m1
Le96MEE9LeA8M5A9MeQ<N5Y>NE]>NU]?NUa?Nee@O5e?OemAPV9EQVMJ00::K6002XmaII=fJYIjKiYn
Lif2Mj66NjB9OjR=PZ^@QZjDRA[oool02[jRS[ZLR;JGPK6BNjf<MJV7KZF1J:9lHYigG9YbEP:GKE00
59AXBY1SA8eN?HUG=H5=:Ga67h=?:XUG=8IF=8AE=8=D=89E=H5F=X5G>89K?HARAHQZCHIXBX9P@gmM
?`9nFC/00geF>7aE=gaE=P02O58c011mE3IoEcV1EcZ1Ec]kD3AgBRijC2mlCC1mCRmnCBemC2]mBRUn
B2IoBBN1CBb5Dc@2RU/n00Z@I4NFJe2KLeVPNV6UPFVZQg2_SWNdU7niVXJmXHdLoooo000Joooo00Yg
MWIcL71_JfY/IVAXH5iTFeQQEU=NDDeKC4MGAd82E48l01AA?3I>=c1;<RY5:b8o8aY<;B=O?C5O?cAK
?3=G>c=D>cEB>cE?>3A<>3A<?3U?@d5@ATE@B4Q>BDU<BDT2BdQ801E8AdM6AdM5B4U5C4e5D597E5M:
EU]=GF9BI6UIK79SNX1VPHMVPh]UPhaUQI1WRIAYSIU[T9e/TZ1gVZIlW:H00WfJY00:OINPOIFMOI:I
OHnFOHbBOHZ>O8N;O8B7O863Ngj06_ooo`0:SWilRWQeQG9_PFaYOFIRNF1LME]FLEE@KDm9JTY30VI4
?@0DHclgGcTaG3@ZEbdSDBHKFRhRJS`_JShaIC/`HSTaGcXbGCTcFcLbF3LbF3/gFd4nG4E3G4M5FTQ6
F4Q60UM7A@0EEDE4DdE3DTI5DTU8DTa<E4m?EU1BFEEHGE]NHV9UJFa_JW1dJW9gJW9hJWAkJgInKGZ2
KWb4KWb5Mh>;OXR?00:0R8h02X>9SXF8SHJ8S8R8RhZ7RX^7RHf6Qhj6QY25QI64Pa[oool02ZfAQZR;
OjB5NImnLY]hJiIbI99/GHiVEhYPD8IJBP:3ED<057m??Ga:=gU4<7Dn:G0h8WDl9Gi6;gi7<GY4<7M3
<7A3<G93<W52<W13<g16=W5;?7=?@G9A@g5B@W1A@P9^D44036e>?fa>?V]>?V]@@6]@@Fa?@Fi>@G1A
A7=DAWEGBWIHC7EHC09fFDd01gMJCWQJCWQKCWUJCWIGBWaMD8AWF@02RF]O00Z=L6FAMFZENFjIOG:L
PGNPQGZTRGjWSH:[T8J^U8TJoooo00ZnXHfiW8NeUX2`T7Z/RW>XQ6bSOfJONUnKM5VHKe82U6Y<01BA
IDJ>H42<G3^9EcB6DRn5DRj7EcB8FCN4ESF2E3F0E3IoECMnECMnEcYnF3]nFcj0H4AoHTEnHDAmH4<2
O5m201ElGT1kGCikG3ikGCikG3akF3UlESQnESQoESQoECQjD3=gBbmiC2mjC2ikC2ekBR]kB2QjAREg
@AiiAB>2DC400XMI>`0:SV55TfU>VG5GWWQOXgmWZHI_[Xef/i=n^9Z5_J2=7?ooo`006_ooo`0:MgEf
Lg1_KfYYJfASIemMHeUGGeAAG4i;F4U4ED@n0U8o>@0DCcXcCCD]BS0WAb/RBR/PEcH[H3lcFc`bF3/c
EC/dDS/eD3/eCCTeBcTeBc`iCT=1CDA4CDI5BdI6BDI60TM5AP0EAD=5@dA5@TI8@TU<@deAA59FB5ML
C5mSDVM/FG1fHGZ0IH67I8::Hh:;Hh>?I8NCIhbHJ8nMJI6PO9n/OYnZ009oWJL02WnIXgjFWgjCVgjA
Ugf=Tgf:Sgf7S7b4R7b1Q7]nP1[oool02XimNhUgMHAaKX1[Ig]UH7MNFW=IE6mBCF]=AVM7@09T@CT0
560l<edf;E/a:5T]8eh`8fTj;6do<VHk<68j<5li<E`i<U/i<ePh<eHi=5Lk=eU1?EQ2?eM4@EI4@UA4
@P9C@d805E52@Dm2@Di4@di6ATm9BU1<CU=ADeIHFUaOHF9WJVQ_LVYcMVQbMfMaN6QbNVUeOV]iPFak
Q6amQgZ8TGj:T@02PHZA00Z3RY25RHn6RHf8R8b:R8^;QhV=QhR>QXN@QHFAQ8@Joooo00Z]THJXRWnS
PgNNOG2IMVVEL6:@JU^<HeB7GDf3EdH2P54o01AmC3UjAS=h@Rig@2]mABj6CCF2BcAjAC1f@bmc@c5a
@c9`@c9^A3=]ACE]ASM^B3U]BCY]Bca/C3e[Bcd2JT/l00eYBCaWBC]WBS]VBSaWC3iWCCmYD49/EDI`
FTaeGe9gHEAfGU9dFTh00WAICP06MEY>MUY>MUY?Me]@OF5EPVII0XQ/H00:S71TT7AYU7U^V7ebW85f
WhEjXhUnYhb2ZY25[YB96_ooo`0:_J6=^9^6]9Eo[hmhZXUaYX=[XGeTWGMMVG5FUFa?0Y5VB@0CSV52
RedmRUXhReTgTV0mUfE2SEhkQ5LeP5DdOUDeOE@fO5@gNeHiNePkNePlNULjNEPjNEXmNE/n00=hFSd0
0gMI?7MH>gIH>P02MULi011fESQfEcQhFS]kG3inGT5mFcmiE3MgCS1hC2mhBbehBR]hBBUhAbMiAbMh
AbMnCRl2QELj00Z;Gd>AIdbGKeFLMUfROVJWQFj]S7FbTgfgVHFmX8`Loooo000Joooo00YfMGEbKfm^
JFQYHf9UGE]QEeEMDTiJC4QFAT9C@C/2D3`e01A==bm;<RY9;RE9:R1=;B9A<bQE>2iF>S5D>S=B>cE@
>SE>>cI<>CE:>CE:>cU:@3i;@d9:A4A8A4A6@d@2A4=401E2@T=0@T<o@dHoAdY0Bdm2D5E7EUa;GV=A
IVaFKWELMWeQOHARP8UQP8]QPXiRQY=URiQVSYaVT:1mXJj1XZh00X2OZ@0:P9bUOiRQOiFMOY:IOXnE
OH^AOHR<O8F8O8:4Ngj06_ooo`0:SGekR7IdPg1]OVUVNV=OMEaHL5IAK51:J4U3I4<l0V4n=P0DGSP`
Fc<ZFBlTFB`PG2lRGc<XHCL/H3P^GSP`FcTbFCTbEcTcESPcE3PdE3XfE3djE3lmDd4oDT4oDD0o0Tm0
?`0ECClnBcloBT10BT=3BdI7C4Y<D4mBE5IIFEePGVAWHVY^IW1dIW5gIG1hIG5jIgAmJGR1JGZ4JWb7
NhZCOhbD00:1S9802X>;THF;T8J:ShR9SHZ9S8^8RXf7RHj6Qi25QI65Q1[oool02Zb@QJN9OZ:2MYek
KiMeIi9^H8iWF8UPDHEJBX1C@P9mCC/057U7=GI2;gDo:GDm9GPo9gU2;7M3;WA1;G50;Vm1<6e2<Fa3
<f]2<fY3=6Y4=VU4=FQ4=FQ6=fM7>FI7>@9UASP03FA6>6=6>695=f96>697>V=9?FE<@6Q@@faEB6mI
C75KCg=LD79KD002LUQ>00IcF4idFTmdFTmdFU1mHUN2Ie`2QV]O00Z;KfB?M6VCN6fGO7:KP7JOQ7ZR
R7jVS8:ZT8F^ThTJoooo00ZmXHfhVXFcU7j^SGNYQg2TPFRONV6JM5ZFKU:BJ4/2SV=500f:GCj8FCR6
ESB7EC29ES:8F3J4ESEoDS9lDC9jDSAhDcIgE3QgE3T00WMF>P04ME<gM54dM5<fM5Dh0g=E>003LeHh
LUDhLE<e00=aDS@03g9C=G=D=WIE>7MG>GQF>7MC=gI?=7E<<7I:;GI9;7M8:WM7:7M69WM7:Ge><002
PeDh00Z9GD6?IDZEKE>KMEbQO6BVQ6f/RgFaTWbgVHBmX8`Loooo000Joooo00YfMGEaKVi]J6MXHV1T
FeUOEE9KCdaGBDED@ci@?SP2CCPb01A;<ba9;bI8:b58:Ai9:b5<;bI?=2aB>31A>S=?>SE=>SE;>SE:
>CE8>3E7>SM8?Ca8@T58@d=6@T=4@482@D5201Do@44m?d8l@D@lADTnBTm1CeA6EUa;GVE@IVeEKGEJ
M7aNNhAOOHMNOXUOPHeQQY9TRYMUSIaTSimnXZn2Y:l00X:Q[00:PIjXPIZSP9NOOi>JOi2FOXbBOHV=
OHJ9O8:5Ngn06_ooo`0:SGekR7IcPVm/OFQTN65MLeYEKU=>JDe7IDI0HD0i0Udj<P0DFS@/F2lUER/P
ERTMEbXOF2dSFC4XFcD/FSH_F3LaESLaE3LbDcHbDSHbDCPeDCXhDChkD3hmCchmCC`l0T/m?00EBC`l
Ac`lAcdoAT12B4A7BdQ<CdmBDeEIF5eQG6=WGfQ]HfecHfieHVifHg1iIGAmIgR1JGZ5J7^7NhZCOhbD
00:1SI@02X><ThF<THN;T8R:SXV9SH^8Rhb7RHj7Qhn6QY65Q1[oool02Zb@QJJ8OJ61MI]jKIIcII1[
GX]TEXIMCX5FAWe??`9iBCL057E3<78m:W0i96lf86lg8Flg8Vhj9Vhl:Vdm;6/n;VTo;fPo<6Lo<FI0
<VI1<fI2=6E2<fA1=6=2=691=09Q@C@03F12=5m2=Ei2=Ui2=Ui4>657>f=:?fI?A6UCB6aGBfiICVmJ
CfmHC`02KeM>00IaFDmcFU1dFe5dFe5lHEF0IEP2QFYN00Z:KfB>M6VBN6fFO76JP7JNQ7ZRR7jVS86Z
T8F^ThTJoooo00ZmX8bgVHFbTgf/S7FWQFjROfJLN5jGLENCJdn>I4L2RUi000f6FCV3E3>1CbeoCBYn
C2UlBbQjBbYhC2igCBmeCS5dCc=cD3AbDCD00W9B=`05LU8fL4lbKdhaKdlbKdlc009^Cc<05Fi@<fi@
=6e@=6e><Ve=<Vi><fm?=71B=W9C>7AD>7AC>7AA=W=><g=;<7=:;WE:;GI9;7M9:gQ8:GE59GU::P02
P5<e00Z7G3n=I4VCK5:IM5^ONf>UPfb[RWBaTGbfV8BlX8`Loooo000Joooo00YfM7EaKVe[IfIWH5mR
FUMMDe1ICDUEAT9A@3]=>SD2BSD^01A8<2Q6:b959ae69ae6:B19;RI==Be@=c1>>C==>SA;>CA9>3A8
>3A6=cA5>CI4>cY5?cm5@T93@D91?d42?d1101Dm?d4j?D4j@4@jA4PmBTloCeA5EUe:GVE?IVeDKGEH
LgaKNH9KNXELOHQNPHePQI9SRYMUSIaUSiikWjb4Y[800XBT[`0:Pj2ZPYbVPIRQP9FLOi6GOXfCOXZ>
OHJ:O8:5Ngn16_ooo`0:SGajQgEbPFeZNfISMUmKLEQCJe1;ITU4HT<lGC`e0UXf;P0DES0WE2XQDRHK
DRDJDBHLDb/RES0XF3<[ESD^E3D_DSD`DCD`Cc@`CSDaCCLcCCPeCCXiC3`lBc`kBC/k0TPk>`0EASXk
A3TkA3`nA3m1ATA7B4M;C4iBDEEJEEaQFV5XGFM^Gf]bGfacGfefHG1iI7AmIgR1JG^5JWb7NHRAP8jF
00:2SYH02XB>UHF=ThN<THR;ShV:SH^9S8b8RXj7R8n6QY65Q1[oool02Z^?Q:F8O9n0M9YhK9A`HhiY
FhQQDh=JBgiB@WU;>P9eA3<0574n:fdh96/b7FT`6VP`76Pb7fTf8fXh9VPi:FHj:V@k:f<k;68k;F8m
;V4n<64o<F0n<Eln<Elo<Uho<P9M@3<05E`o<e/o=5]0=5]1=Ua3>Ee5>f19?V9=@fIAB6UEC6aHCfaI
D6]GCVaFCVeGCg1ID79KDGEMDgMNDgaPE7mSE`02QFUN00Z9KfB=M6VAN6fEO7:IP7JMQ7ZQR7fUS86Y
ShF]ThTJoooo00ZlX8bfVHBaTWb[RgBUPfbOO6BJMEbDKUB?Id^:H4<2QEXl01B1DcAmCRekB2IhAB9f
A29dA2=dAREcAbQaB2Y`BBa^BRe^Bbm]C31]CS9]Cc=/CS9[C2mZBRiZBbmZCC43JTdb00=ZCC=ZCC9Y
CC800VY=<P0?JddcK4hdKU0gL58iLE<jLE4hL4dcL4/aLD/_LdX^MDX]N4/]Nd`]MdHVMTHW009nD3<0
2XEJ?XaSB99[DIQcFYijHjB2JjZ9Lk2ANkJHQ;bOS1coool001[oool02WEdM71]KFYVIFEOGF1HEE]A
CUI:AU93?dhm>4Xg<@97<BX054@[94<W7T8S6D8T6d<W7TP`:D`e;Tdg<D/i<dXi=4Ph=4Lg<dDf<d@f
=4<h=D8i>48m?D=1@T4o@Cln@08l?T005CXl?cLl?cHn@SQ2AcY9CSi>ED=FGDQNIDiVKU=/MEIbNeIe
OeMhPeYkQeaoS5n4TF>:UfN?WFbCXGZN[8>W/`02QjRc00Z5Xjf3WZR1VZ>0UYj0TYUoSYAnRXmmQhYl
PhIlOh4Joooo00Z<O7Z6M7:0K6UjI65dGEU^EE5XCTUSAT5N?cUI>342EC4Z01AB:b9?9Aa=8AI<8AM<
8aY@:b=C<2QC<R]B=2e@<bi?<bi=<Ri<<Ri;<Rm:=359=C=9>3M9>cY8>SY6>CT2A3Pi01E3>3U1=cU0
>3]0?412@DE6Ad]:CU9>E5YCFf5GHFQIIFeJIfmKJG9MK7EOKgQRLgeVMh5[O8MaPH]mRY>1SiP00XBA
V@0:QI2GQXjEQhfCR8b@RH^>RhV<S8R:SXN8ShJ6THF46_ooo`0:Zhn4YHMkWWmcV7MZTViQRfIIQEi@
P5I7NThoMDLf0W0o;P0@JcPUJ34NIB`GHRTEHBTFHRlLI3<RI3DTHSLVHCHWH3LXGSLXGCLYGCPZG3T/
G3X^0U/l;`9J>bl2FC/`00YH>c1G>c1F>c1F?C=G@3II@cYLAciOBd9RCTIUDT/3IeE=00QYEDeZETi]
F51aFe9fGeInI5Z4JEf2IU/2Q6UN00Z9L6J=M6ZAN6jDO7:HP7JMPgZQQgfURh6YShF]ThTJoooo00Zl
WhbfV8>`TG^YRG>SPVZMNV:GLeVAJe2;I4R6G3l2P5Dg01AlCRigAbIc@B1`?A]]?1Y]?ai^@R=]@bE[
A2IZA2MYABUXABYWARYWAbaWBBiWBRmVBBiUB2aUAb]UB2`2ITP]0VE9;P0CIDP]I4P^IDT_ITX`Id`b
J4`bJDddJdlgK4lgK4heK4`cKD/aKTT_L4T^LdX_N4daPE<dPe8cNd//009kCS402XAJ?hYRB91ZDIIb
FIaiHZ>1JZV9Ljn@NkFHPkbOS1coool001[oool02WEdM6m/K6UTI6=MG5iFE5Q>C5=7A4i0?4Xi=4Hc
;@93;BH0540W7chQ63dN5ChQ6D4Y8DLc;4Xf;dXh<DTh<TPh<dHf<T@e<D<e<T4e<d0f=40h=d4l?D4o
@3ln@3`l?`8j?3l05CLj?S@j?C<l@CE1AcQ7CCa>E41EGDMMITeVKe1[ME9_NE=bOEAePEMiQE]nRUj3
T6>9UfV?WFnDXWVO[HF[^002Rjfi00Z5YK23X:Z2VjB1Uin0TiYoSiEnRi1mQh]mPhIlOh4Joooo00Z<
NgV5Lg5nJfQhHembFeM[DTiUBdIO@ceJ>cEE=2d2D2`U01A=9Ae97QE76Q566a=88a]=;2E?;bQ?<B]>
<Ba<<Ba;<2a9;b]8;ba7;be6<Bi5<c56=cI6>CU5>3U3=SL2@CHh01Do=3Lm=3Hl=STm>Sho?dA3ADY6
Be5;DUU@FV5CGfIEHVYEHfaGIVmJJ79MK7MPLG]UMX5[O8MaPXakS9J6Uj400XZIXP0:QY:JQXnGQXjD
R8bBRH^?RhZ=S8V;SXN9ShJ6THF46_ooo`0:Zhn4Y8IkWGebUWEYSfaORFAFPU]=O5=4MTXkL48b0VXj
:@0CIC8PHBTFGB<?Fb0>FbDDGBdLGS4PGS<RGC<SG38SFc8SFC4SF38TEc8UEc<WEcHZEcP]EcT^EcT]
00=E=b`05E@f;58f;58g;E8i<5<l<eE0=eM3>eY8@Ei=AF1@B65@BF9@BF=ABFEABVMCC6]FCVmIDGAM
EG]SFX=[HX]eJ`02SGE/00Z:LVR<M6^@N6jCNg:HOgJLPgZPQgfTRh6YShF]ThTJoooo00ZlWh^eUh>^
T7ZXR76QP6RKN5nDL5J>J4f7H4B1F3/2Ne0b01=eB2Q`?ai[=aIW<a9V=AIV>QaU?QmV?b5U?b9T?b9S
?b9R?b=R?bAQ@2EQ@BMQ@bURAB]QAB]QA2X01F53:@0CH4<YH4@ZH4@[H4D/HDL^HTPaI4/cID/cITXb
IdTaIdL_J4H]JTH]KDL]L4P]MD/`Ne0dPUHjQea000:6G4402XEL@HURB8mYD9EaFI]hHJ60JZR8LZj@
NkFGPkbORacoool001[oool02WEdM6m/K6UTI6=MG5iFE5Q>C5=7A4i0?4Xi=4Hc;@93;BH0540W7chQ
63dN5ChQ6D4Y8DLc;4Xf;dXh<DTh<TPh<dHf<T@e<D<e<T4e<d0f=40h=d4l?D4o@3ln@3`l?`8j?3l0
5CLj?S@j?C<l@CE1AcQ7CCa>E41EGDMMITeVKe1[ME9_NE=bOEAePEMiQE]nRUj3T6>9UfV?WFnDXWVO
[HF[^002Rjfi00Z5YK23X:Z2VjB1Uin0TiYoSiEnRi1mQh]mPhIlOh4Joooo00Z<NgV5Lg5nJfQhHemb
FeM[DTiUBdIO@ceJ>cEE=2d2D2`U01A=9Ae97QE76Q566a=88a]=;2E?;bQ?<B]><Ba<<Ba;<2a9;b]8
;ba7;be6<Bi5<c56=cI6>CU5>3U3=SL2@CHh01Do=3Lm=3Hl=STm>Sho?dA3ADY6Be5;DUU@FV5CGfIE
HVYEHfaGIVmJJ79MK7MPLG]UMX5[O8MaPXakS9J6Uj400XZIXP0:QY:JQXnGQXjDR8bBRH^?RhZ=S8V;
SXN9ShJ6THF46_ooo`0:Zhn4Y8IkWGebUWEYSfaORFAFPU]=O5=4MTXkL48b0VXj:@0CIC8PHBTFGB<?
Fb0>FbDDGBdLGS4PGS<RGC<SG38SFc8SFC4SF38TEc8UEc<WEcHZEcP]EcT^EcT]00=E=b`05E@f;58f
;58g;E8i<5<l<eE0=eM3>eY8@Ei=AF1@B65@BF9@BF=ABFEABVMCC6]FCVmIDGAMEG]SFX=[HX]eJ`02
SGE/00Z:LVR<M6^@N6jCNg:HOgJLPgZPQgfTRh6YShF]ThTJoooo00ZlWh^eUh>^T7ZXR76QP6RKN5nD
L5J>J4f7H4B1F3/2Ne0b01=eB2Q`?ai[=aIW<a9V=AIV>QaU?QmV?b5U?b9T?b9S?b9R?b=R?bAQ@2EQ
@BMQ@bURAB]QAB]QA2X01F53:@0CH4<YH4@ZH4@[H4D/HDL^HTPaI4/cID/cITXbIdTaIdL_J4H]JTH]
KDL]L4P]MD/`Ne0dPUHjQea000:6G4402XEL@HURB8mYD9EaFI]hHJ60JZR8LZj@NkFGPkbORacoool0
01[oool02WAcLfi[JfQSHV5KFU]CDEE<BE14@D/m>DHe<D8^:@8n:24053/R6STL53PL53/R6d4^9TLe
;TXg<4Pg<TLg<TDf<T<e<D8d<40c<3lc<Che<chg=chk>chm?c`m?cXk?`8h>cl05CDi?C8i?C4k@C91
AcI7CC]>ED1EGTINId]UKTeYLdm/Mdm_NU5cOeEgQ5UlREf2T6:8UVR?WVjDXWRN[H6Y^002Q:Re00Z4
YK23X:^2W:J1V:20U9^0T9IoS95nR8amQ8IlOh4Joooo00Z;NgV4LW1mJVMfHEi_F5EXD4aRAd=L?cYF
=c5@;bT2BbLP01A781Q36A5160m271E69Qm;;BI=;bU<<2Y:;b]9;bY7;BU5;2U4;2U3;2Y2;Ba2<312
<cA3=CM1=SQ0=CL2?SDg01Dl<cHi<cHi=CTj>Chl?TA0A4Y4Be9:DeY=F61?G6A@GVMAH6UCHfeFIW5J
JWENKg]SMH1XNhM_P8]gRIB0Tih00X>CW@0:Q9:JQI2GQXjEQhfCRHb@RhZ>S8V<SXR9ShJ7THF46_oo
o`0:ZXj3XhEjW7aaU7=WSFYNQV5DOeQ:N4m1LDHgJcd]0VDd8`0DGb`JFR@AER0>EB4@EbLFFB/KFRhN
FBlPF2lPEbhPERdOE2`ODb`ODR`PDRhRDS0UDS8XDc@ZDSD[DSH/0U4f;00ED3D[CcD[CSD]CSL_CcXb
DCdfE48lF4M1FTY4Fd]5G4a5G4a6GTe7H4i8He1:Ie==JeI@Ke]DMEmGO6IMPVeT00:5KfH02XMaJ8Yd
JXigKY9kLYMoMY^3NYn7OJB;PJR?QJfCRA[oool02[^ORkBGPZf?NJJ6L9mnIiQfGI5]E8YUBX=L@GaC
=`9eBbd04fm28fTj6V@d564c560d5V4g6F4i760j7Ulk7elj7Udi7E`i7E/i7E/i7U/j85/l8U`m95`o
9Ua0:005GD8Y0ea1:@0@G48[GDD^GdL`H4PaH4H_H4D^HD@]HT</Hd<[ID<[J4<[JdD/KdL^M4X`N4hc
O58g0WmF>`0:PUY0Qf17SFQ?TfmHVGMQX7mYYhMb[Xmj]9N3^in;7?ooo`006_ooo`0:M7=cKFYZIV9Q
GeUHFE5?DTU6C44nAcTe@C4]?2XT0SPS700D=A`D<aP@<a/D>2@M@C0YB3L`B3LaAcLbACHa@c@`@C<_
?S8_?C4_?34`>c@c?3Hf?3Xk?3`n>c`n>3/n0SHj?P0E<cPl;cPm;S]0<D17=4M>>DiF?eINA5eVAf9/
BFIaBVUdC6ahCW1mDWF2EW^8Fh6?H8REIhjMKI>RMIf/OJJe00:1Yk@02X>U/H>Q[8:MYh:IXX6EW82A
Ugn=TWj8S7f4Qgb0PA[oool02X]kNH=aKgaXIWAOG6aFDfE=BEi4@5Lk=e4c;D/Z90958Q/053lI4C`E
33XF3SdM5T<W84T]9dT^:DP^:DL]:DD/:4<Z9d4Y9SlX9chX:3hZ:Sh];Sla<Slc=Chc=Sdc=P8k<cH0
5CTa=CHa=CHc>3Lh?SXnA3i4Bd9;DTI@F4QDGDYHHD]JHdaLIdmPJe9SKeIXM5Y^NEmdOfEjQFanRW>7
TgV>VP02OY2J00Z1TIZ3T9R5SiJ7SY>9S96:Rhn<RXb>R8Z?QhNAQHDJoooo00ZZSX>RQ7VJNg2CLVJ;
J5b3Ge9lEDQdBce]@S=V>2T2GRlN01AH9A=B7Pa>7@]=80mA9AED:AYE:aaE:aeD:aeB:QaA:1]?9aY=
9QY<9Q]<:1e<:R1=;B=>;bI><BM><RT2CC<Z01E<<RY;<RY;<ba;=Rm=>C9??CIA@CYC@ceDA3mEAT1F
AT5GAd9IBD=KBdENCDQQD4YUE4i[F55`G5EfHEYjIEd00WmXH00:Q6iUR79ZS7I^TG]bUWmfVX=jWhMn
Y8^1Z8n5[I>96_ooo`0:^in;]9J1[8ihYHE_WWaUUWAKSV]BQf97OePmMdlc0W15:00DJ3/LH3@CFc4A
F30AF34CFC<FFSDHFSDJFSHJFCDIF3@HES8GEC8FE38HE38IE3@KECHNESTPEc/RF3dT0UTn9P0EFClX
FClWFClWFClXFD0YFD4[FD8/FT8/FD4[FT0ZFSlYFSlXG3lXGSlXH40XHT4XID8YJ4@ZKDH]LDP^LdT^
009gCC<02WiF?HANAXYVCY5^EiQfH9mnJJJ7LJf?N[BGPk^ORacoool001[oool02W=bLfaYJFAPH5eG
EUI?CDm6A4Pm>d8e<S`]:CLU808b7AL052dE3RXD3B`I4cHU7T<b;4Ph<DLh<THg<T@e<44c;cha;S/`
;SX`;cT`<3Tc<cXf=c/j>c/l?SXl?cLk?`8d>Cd05C0g?2dg?2`j@2hoAS96CSM=ESaDGD1JI4=OJDES
KTIWLTUZMd]_O51dPEAjR5UoSUn6UFF<Vf^AWg>LZW^R/@02PJVg00Z2Y[>3Xjj3WjV2VZ>2UYj1TYR0
SI=oRHemQ8MlP88Joooo00Z:NWR2LFijIfAbGEYZE55RBTMJ@CeC=c=<;RU59B02?Q`F01@g4P/b3PP`
4@`g6aI19b96;BM7;BU6;BQ4:bM2:RHo:2Dm9bDk9RDi9RHj:BTk;2dl;c4l<C@l<SDk<SH2>C8e01Df
<3@d<3Dc<cPe=cdg?D<k@dXnB511CEI3D5Y4Dee6EV58FVE:GFU>HViBIg=FK7QLLGiRMh=WNXI^Q91f
RYD00Wf@V`0:P96KPY2IQHnGQhjDRHfBRXb?S8Z=SXV:ShN7THF56_ooo`0:ZHf3XHAiVGY_TG1TRFIJ
P5a?N595L4PjJ3h`H3@U0UPY6P06D1h=AaH5@Q@4A1T;Bb8CCbLH0U0X6P0<CbLJCRLIC2DHBR@GB28G
AR8GAR<IAbHMB2TPBB`SBRhUBRlW0TXa:@0EBC4YB38ZB38[B3@^BCLaBcXdCC`gCChjCSlkCT0kCd4m
DD<oDdE1ETQ4FD]7G4i9HE1<IE=>JEI?Ke]DMEmG009kIEd02X5/I8IaJH]fKY1jLYAnMYV3NYj7OZ>;
PZR?QJfCRA[oool02[^NR[>FPJ^=MjB4KYakI9AbFXaXCh=OAG]E>W=;;`9Z@B@01f0e5eH[2dhV1d/V
2Th[3e8^4e@`5@02EC4F00]D<AEC<1AA;aA?;A==;1==;AA>;aM?<QUA=1]B=amD>B800UDl9003EShV
EShWEShW00=E?BL03eDm:5@l9e<k9U8j95<j95@k9EHk9ELm9UTn9e`n9eln9f8o9fDo9VU19fe3:002
LdP]00YiDcZ0G4B7I4f>KEJFMEnMOVRTQW6/SWZcUX>kWh/Loooo000Joooo00YcLW9[J6QRGeiKEEEC
C4];@d54>SLm<Bhg:2Da81`2:aPC01@U3`TQ40/Y6QDg9b96=Rm9>C=8>C=6=c93=C4o<Rlk<2hh;bhg
;Rhf;blg<S8h=SHj>C/j?3hi?40g>cl2<cTn01D_=c`[=S`Z>D0/?dH_ADddC5DhDU`kEf8nG6M0H6a3
I716J7E9KG]=LX1AN8IGOHeLQ9=RRYUXSiiaVZUjX[400X:/^`0:PjRePjB`Pj2ZPibUPYNOPI>IP8jC
OhZ>OXF8O8226_ooo`0:RWYhPG1]N6ESL5]IIe5>GTM4ESdjCS<_ARTU?b0K0SLG4@05<0d7:@/7;18>
=A`H@BTT0095;BT03D@/:48[9clY9S`V9CTU93LT9CDT9CHV9cLY:cT];cX`<cXb=CTb=P02=c4e01Dd
;c@a;c@`<CPb=S`d>d8g@4TiADhkBE<mC5LoCe]0Dei3EV96FfM:Gfa>I75CJGIHKgaMM85RN8AZPHic
R9D00W^BW`0:OY:LPI6JQ92HQXnFR8jCRXb@S8^=SXV;ShN8THJ56_ooo`0:ZHf2X8=hV7U^SfmSQVAH
OEY=MDm2K4@gHcT/FblQ0U8T5P06BAX;@185?A<6@1P;AQlBBb@G0TdV6@05C2HIBR@HAb<GAB4G@b0F
00917aH01D4P64<T6dDX7dL[8dP^9P02B2lX01E7;bQ5;bU4<2Y5<Ra5=2i6=S57>3A7>CE7>SI8>SM9
?3Q;?SY=@Ce@A41DAdAHBTMKCDUOD4]SDdeYEe5`G5H00WQVG`0:OV]TPg1YRGE^SWYbTgifV89jWXMn
Xh^2Z8n5[I>96_ooo`0:^Yj:/YF1ZhagXX=]VWYSTW1HRFI=P5a2Me4gKTL/0VDm8@07G3<FD2P<B2<8
AB<9ARD<C2XACRdC009@;a@01Dl_54h]54/[4dTZ4TLY4@02ARL@00A8:Q9;;QI><Q]@=b02DSXS01EC
>bEC?2IB>bEB>bEA>RA?>BA?>2A==b9;=B1;=21<=1m==1m?=R5A>29D>B=F>RAI>bAK>b=M?2AP?2=V
?bL00Ve7;P0:ME0iOEY3Q6==S6aFU7AOW7eXXhEaZhij/iJ2^Yn;7?ooo`006_ooo`0:LW5bJFMWHEeM
F5=CCdY8Ad0n?cHd=bdZ<B@P:a/G0RDC3P0D80d87Q0=:AdH>B/UC3/cC3`fBCXdAcPd@SHb?C4_>2l]
=2`[<R`/<Rd^=C4b>3Hg>SXk>cdo>Si2=ce10S8j?`0E;CLm:CHl:3To:Si5;4A=<DYD<e1J=UAO>EUU
?EiZ?f9_A6QeAfajBg60CgN6E7b<FX:BGhRHI8fMKiNWNjBc00:3[[d02XBZ^8BV/XBR[8BMYX>IX8:D
VX6?U82:SWj5R7b0PQ[oool02XUiMh1_KGMTHVeJEfA?C5]4@E4i=TP_:d0U8CPK5`8a4Pd052X;1RL<
2BdE4SHO74D]:4H_:TD^:T@]:T4[:3`W9SPT8c<Q8C0P8BlP8S4T9SDY:cL/;cT`<cXc=cPc=`8f<SL0
5C8`=Bl_=Bha=ble>c0i@S<nAcA2C3E5D3M9E3Y=F3a@G41EHD=IITMNJd]RL4mWMEA/NeUbOeeePfIm
S769UP02NYBQ00YnTin1TYb4TIV6T9N9SYB;SI6<Rhj>RH^@R8RAQXDJoooo00ZYSH:PPWRGN6f=KF:4
HUMkEd]aC41W@3AN=BQE:Qd2C20B01A560]05P/n5P]06Pi78AE:91Q:9AQ;9QY:9AY78aQ381Do718k
6A0i6A0j6a<m7QI08AY29Ae5:R96;BL2ARlY01E5;bY3<2Y2<2Y2<B]2<Ri2<bm1=310=351=C92=cA3
>3I6>cU9?Sa<@Sm?A49CAdEFBdQJCDYMCd]RDTm[FUH00WAUH00:Nf]UPG1ZQgE^SGUbTWifV89jWHMn
XX^2Yhn6[9>96_ooo`0:^Yj:/YF0ZXagXH9/VGQRT6iGQVA<O5U0LdhdJD<Y0V0i7P0DF38HDRdDBBL>
A2@;A2D=B2T@BR/BC2dDCBhEC2dDBBXAABH=@B<:?R49?R8;@B@=@bH?ARTCBRlICSDO0U0i900EDC/V
DC`WD3`UCcXTCCPSBcHRB3@PAS8NAC0LAC0KAC0LAc4LBS<NCC@PCSHQDCLRDcPRECPREcLRFCLQGc`U
009XA2d02W5?>7UH@X5QC8YZEI9cGiYlJ::5LJZ=N[:FP[ZNRacoool001[oool02W5aLFQVIemLG5EA
DDa7AT<l>cXb<34X9RXN6b@F4P8O3PX051X;21L=2bDL6C`^:E4o=e0o>4`m=dPk=T<g<cdc<CP_;c<]
;Bl/;S0^<3Dc<cXi>C/k?C`o@Ce3ASQ0A08c?4405Bdh?BPf?2Hh?bLmABU1C2e8Dc1>FC9BGSIFHcUK
JCaPKT9WM4I[NTU`OdeeQE5kReN1TEb7Uf:<W72IZGjW]P02QK7100Z6[KZ6Z;B6Y:j5WjR5VZ:3UIb2
T9F0RhmoQXUmPH8Joooo00Z9NGMoKVaeHf5[F5IQC4YG@Cm==C=3:RLi7a`a5A82:P`801@U20DO20LW
4a8g8Qm8<B]8<Re6<2a4;ba1;2Xm:BPh9RHc92D_8RD^8RDa9RPe:bdg;S4i<CDk=SXi=SX2=C<i01Da
<CH^;cD/<3L/=3`/=d4_?4H`@4/a@ThcAE8eBEHgCEXlDf10EfE4G6Y7H6m;IGA@JgYEL7iJM8=VOhib
S9X00WZFY00:OYFQPIBNQ9:KQi6HRHnERhjBSHb?SXZ<T8R9THJ56_ooo`0:Z8f2Wh9gUWM/S6aQPV5F
N5E:KDTmHcdaF30TCRDH0THJ3@0D?a@8=a47=a<:?Q/@Ab<GBBDJBRHKBRLLBBLLAbHLA2@K@24I?1hG
>1`E>1dE?20H?R8K@BDNA2XTABlY0TDa:`0EA34[@S0[@C0[?c4/?S0]?S4^?S8`?C8`?34`?38`?S@b
@CPfAC/iB3hmBd50CDE3DDQ6ED]9FDi<HEECJUeJ009bIV802WU[IWm`JXIeKhaiLi5nMiN2Nif7OZ:;
PZN?QZbCRA[oool02[ZNR[:EP:V;MZ62K9QhHXi]EXARBWUF?Vi:<F@o909J=1T055<^4dXX3d8S340S
344U3THY4TP[54X]5T`_64``6T/_6DP]5T<Y53dU43/T3CdU3d4W4D<X4dP^64`f8@9?>RH02E0m:50m
:Dll:4dj9TXg8TPd84Hb7d@`7D4]6P02?bXH00Y1;1U5;a]8<Ae9<Qi;=1m==B5?=R5B=b=F>BEL?BT2
I4@_00Y]CCUfEd9oH4b7JEF@LUjHNfRQQ76YSGZbUX:jWX/Loooo000Joooo00YaL75WIFIMFUYCCdm8
A4@n>CPd;B`Z8R4Q61HK3`d260X701@G2`TF40hZ8Ae1<beGA3aC@S]??cY:?CU5>CI0=S@j<S8h<S8c
<34e<S@l>CU0?d13@T=4AdU2BD`j@dP2<ci301D/>3hW=SdT=clT>d@T?DTZAe<ZBUH[CE/_DV0eFVLj
H6e1IWA4JgU8Kgm;M8A@NX]EOi1IQ9EORia`VZYoZ[T00XRd``0:R:nlR:ZfR:F`Qj6ZQYbSQIJMPi6G
PHb@OhJ9OH636_ooo`0:R7QgOVe[M69PJEIDGTY8DchlB38`?2DS<ATF:@h<0R<81@0D80L67`/:;1TG
?2LSC3D`BSD`B3<_AC4_@Rl]?Rd]>bX[>R//=RT[=bX/>bl`?C@f?cLi@C`o@3i2>cXo0SDf?00E<C8h
;Blf:S0h:C8l:3<n:cY5:Sa8:Ce::d1><4ID=4aJ>U5O?UIT@EYYAEm^BFAdCFUiD6emEW:3Hh2?LXjM
009kVJL02WjFXh6EWhBDW8NBVHV@UX^?Thf=T8n;SI28RI66QQ[oool02ZR<PYj1MiEgK8][HH1PEGID
BFY7>ehi;U8[7dLN4P8o5@T053XB1cPD2S`J448O5DTV6dXX7DXX7TTX7dTX84PY8DPZ8dT/9DH[94@Y
8T@Z8d@/9TH_:DXe;TXf<4Ld;`95<bl05D<b;T4a;Cl`;Ch_;C/];3X^;CP^;3D/:c@[:cH^;CTa<Cde
=44h=dDl>dQ0?d]3@Te5ADm7Ae=;BeaDDfMOG@02L6MU00YgJfQnL6^4MFn;NG>AOWNGPg^LQgnRRh:W
ShJ/ThTJoooo00ZjWXZbUH2YRgNPPVbGN6:=KEJ2HDYfE3aZAReM>1l2E2lE01A>:a5<:a=7:A=39a52
9a55:QE7;AM9;QU:<1]<<am?=R9A>BEA>BA==B59<am6<am8=B9<>RI=>bM>>bP2CcdZ0Tln;006CS`Z
C3TWB3@RA30N@BhL?2XH0SPV500;>RPF?2TG?b/H@bhKAS0MB34OBC8PBS8PBc@QCcPUEch/009PA380
2VU=>G9F@WaOBhEXEHibGYMkJ:24LJV=N[6FP[ZNRacoool001[oool02W1`L6IUIE]IFE1>CTE2@CXe
=BhY:28L6aH?3P`30P8C20D051D=2aPC4RXS84@f<5]8@5M5?U92?D`o>dLl>D8i>3df=S/f=SPe=Chj
>TA0?dM5ADU8BDM:C459CCY5BP8c?T@05B`h?RHe?B<g?b<kAB@oBbU8EBE8ERA9FBiBH3EJJ3QNKD1U
M4AZNDQ`OdYdQDiiRe9nSeB2U5b:W72KZh:/^`02R[G400Z:/;j:[;R:Yk:9Xj^8WJF6V9j4TYR2SI60
QhYmPH<Joooo00Z8N7ImKF]bHEmWEE=LB4M@>cY3;R`f7ahX4A0J0@026`8101@L20LO3Ph/6aXn:RM?
>C===c=:=C96<c53<C10<30n;c0m;c4l;c52=CI6>SY8?Ci8@455@DA0?d@k>d42=SHm01D`<CP/;cLZ
<CTZ=3hZ=d8/?TXW?4TS>dXZ@E0_AeHaBUThD5llEFA1FVU3Gfm6HgA:IgQ;JW]ALH9QP91aSih00W^I
Y`0:OYNSPYJQQIFNR9>KRY:HS92DSXjASh^=T8V:THJ66_ooo`0:Z8b1WX5gU7I/RV]QOemEM5=8IdDj
FSH[Bb@J>A050S<:000D=106=QD<?1/C@b8IBRTNBbTPBRXQBRXRB2XRB2/TBBhXBS0ZCC<]DSTbE3/d
Dc/dDC/eCS/fBcTdB3Hb0TDd<009@c8_@C4_@38`@3<b@3Dd?SHf=c4b<B`^<b`^008f;c402SXb<chf
=d<k>dHo?dQ2@dY4ADY5ATe9BUMADF=LF`9]IV@02WEZIga_Jh=eL8YjM91nN9J3O9b7Oj:;PjN?QZbC
RQ[oool02[ZMR[:EPJV<Mj22KIMiHhe^Eh9QBWEC>fE2:E8/4P968@P054HV3TLZ4dHZ5D8Y5D4X54@[
5dH^6TP_74Ta7D/d8Dlj9e8m:eM2;ea7=5]8=EM4<EA3<551;dln;Dlm;09??R`05Dln;E0o;U0o;Tln
;Dhn;TXk:T<d9C//7CPX6CPX63LV5SPV5C`X5d0/6T@_7TDa84Da7dD`7dDa84Pc8U0j:002FT4_00YU
BSQ_E45iGT^3J5F<LEjFNfROQ76XSGZaUX>iWX/Loooo000Joooo00Y`L71TI6EIF5Q>C4a2?d0e<S8X
9BDJ5QH810@500024@X801@D40lI5QH^9bA9>S=PC4=JBD9EAD1>@3e9?Sa5?Ca0>SXm>CTl>CXn?3e2
@456ATM8BT]5BTe0BDdjADX2<Si501D[>3lU=clS>40S?4HU@D`XB5@XBELWBeXeEV@hG6XlHFm6JGM9
KWa:Lh=9MHI;N8Y>O8i>Oi9LRiebW:b6[;/00Xbga@0:SK?0SJjjSJZdS:F]RYnWR9ZPQYBIPhjBPHR;
OX636_ooo`0:QgQfO6e[LF1OIEACFDM6CCXh?b/Z<1/J70L65@000QT51@0D60P97@l@;QhL@bhZDcdg
D3XgC3PfAc@dA3<c@S<d?c8d?S8d?S<f@CHiA3XmASm2Ad95A496@415>ca30SDg?P0E<38j;34i:S8k
:SI0;3Y5;Sm;;T1<;45?=DQF=TaJ>DmN@5IT@UYYA5i^@f1aA6=dAVEgAFMjD763HX2@LhjM009kV:L0
2WnHYH>HXXJGX8VEWHbCVHfAUXn?TY2<SY69RY:7QQ[oool02ZR=PYj2N9AgKHU/HWmPEW=CBFI5>eLe
:d@N53LB208b3`L052d<1C0B2cXK4dDU6dd/8T`/8d`/9DX[94T[9DT]9dT`:dXc;d`f<Tlh=50l=e8n
>U0n>Thm>T/k>4Ph=@95=C<05D<c<D4c<T0d<d0f=D8h=d<j>T<j>D4i>D4i>T0i>T4i>d@l?DDn?dM1
@TI2@dM2A4M3ADE3ADY7BUI@DF5IF@02JV9Q00YcJFMkKfb2MG29NWF@OgVFQ7fLR82RS8BWT8N/ThXJ
oooo00ZjWX^bUX:ZSGVQQ72HNVF>L5Z3I4eeECiR@2MC<AP2ARL@01@m80/n90m1:1A3:aM3:aQ4;AY6
;ae8<1m8<B1:=B==>RU@?bmD@cAFACIGAcQFB3UDASMAA3A@@S9?@302Ccl_015?@31@@C9@@S=@@S9A
@S9A@C1A@2m??Be8>2Q5<bA4<R=3<B94<R95<b=5<R=4<B53<B400T4^7`0>AC8RBcDTEC`ZEC`ZH4Pf
K591MUe;PFMERg5OUG]XWXAaYhej/9J3^Ij;7?ooo`006_ooo`0:Kg1`I6ATF5MHC4];?chn<S0`928R
518B0P0120H60Q0=300D6QLE8QhM>BhZCclhI4m6GTa5F4U4DTE2C4=0ASln@Sdm?S/k?3Xl?Cdn@453
@dE7A4Q:A4]>?dU=>DA:0S4nA00E:SU09CQ08SM18S]6945=9dMD:4YH;51N>EUV?5m/@FAbBFajBFmn
Ag:3AgB6B7N:BGZ=BWfAGXbOMYj^RJjl00:@^/P02Y6f`Y6a_I2]]XnW/8fQZH^KXXREVXF?Th:8Rgj2
Q1[oool02XMhMga/Jg1PGVACDUQ6AD/h>3dZ:BdJ6A`821`92@8N30d0524B4bHH63LU8dPc;eI0>e<n
>Tll>T/j>DLi>D<f=clc=Cdb=C`c=cdf>D0j?T8m@D=0A492Acm0ASXl@`8d=ch05Blc>b/b>bTb?2Te
@2XiAB`nBbm1CSA7E3i?G3mCH45FHdIKJDEMK49OKd5PLD5RM45TMd9VNU5cQFB2TWB@WP02OI^Y00Z1
VZN5VZB8VJ:;Uin=UI^?TiN@T9>ASHnBRX^BQhHJoooo00ZXSH>NPgVDN6j:K6=oHEMcE4]WAciI>2m:
:1m28AP2?AhE01@h71@h71E18aY9:R5?;bI>;bM=<2Q=<R]<<bi9<2]7;bY7<2e7<c19=SA:>CM<>cU<
?3Y;?C]:?3]7>CP2ACHd00U2=3=1=3A0=CE0=CM0=cQ1>SY3?3e9@T9?AdH00Te5A@0:CDI6BTE6Ad=6
AD96AD=6A496@d=7BdU<EU9DHEYK0VUSHP0:LVUWNVm/PWEaRG]fT81jUhAnW8V1XXb4Yi27[9B:6_oo
o`0:^Z2</iN4ZhmkXXIbVWeXT7=NQVQCNUa6KU0iH4</0UDj900DBS8MABhIARhJARlLA2dKABlMAc8P
BCLVBcXZBSPXBSLWBc/[CCl`CT8eCd@gD4@gCd<fCT<fCd@fCd8c0Tm0<@0ACd4aD48cD48eD44dCd4c
Cd4bDD8cF4PhFTTiED@dDT0`Ccd^BSX[ASHXA3@VA3<U@C4S0090<2403T@c94Xf9e8k:e8k:ee6=FUA
@7ALBgmWEHYaGiAkJIj4LZN=Nk2FPkVNS1coool001[oool02Vm_L6=SI5IFEdY9BSdl?Bl^;b4P8A4@
4@000@L71`8@3`l051`J62/U8Sld;eA3?FEABF5@BE]=B5E:Ae17AD]5A4M3@d=2@dE3A4E5ADM8BDM:
BdM<CTE=D3i8CCM3B@8`?D@05BXj@RDh@R8h@b0jAR4oC2E6DbQ:F2e@GS=GICQMJciTLT=YND=/OD=_
PT=bQDAdR4=gRdMlTF2>X7bR/HV^_002Tkc:00ZE^LFF]L2E/;VCZ[:@Y:^=WJ>:Uib6T9B3RHaoPX@J
oooo00Z7N7IkK6Y`GeiTDe9GATE:>3Pl:RX]6a/M2`/N3@h28A4B01@W61P`81ln;2U<>3AH@SiE@CiA
@3i>?Si:?Ci8?Cm6?3m3?3m5?T57@DA9A4M8ADU8AT]5AT/o@DPi>d<2<cHn01D_<c`[<cdY<ShW=40W
=dDZ?4X]@4laAU@gC5XkDElnEVE1FVToFf`oG6lnGW4nH7<lHGDoIGYBM8MYQYIeTJ000WfLZ`0:PYbX
QibWRi^TSYZQT9NMTIBITY6ETXj@TX^;TXN76_ooo`0:Z8f3WX=iU7Q_RViTP69IM5M>JDY2G3heCc4X
B2XS0T<V7`0D@BDN@bHOAbXRC2lWD38ZCc4ZCS</CSD_CSLcCc/gCc`iCS`kDD0oE4E3EDM6E4M6DTM6
CdA4BclnAcXj0T@f=P0E@CDe@3Hf@3Hh?SDi?CDi?SLj@3XlA3doB493BTE7BdM9BTI9ATA8AD98@d57
@T56@416@D97BTY?FEIHHUeN009XHf<02W1XIgY`KH9fLhYlN961O9N6Oif:PZ:=QJRAR:fDRQ[oool0
2[^PS;>HQJb@OJB8M9b0K9=gHhY^FH5UD7QLAVY?>P9MAC0015@m:U0i9D/f8dLd8P94<B003TLd94Th
:Ddm;e13=U96>E=7?5I<@EYAAe]CBEUBB5M@AUA<@E57?4m4=`=>@C@054m3=U14>4m2=d`n=4/m<Tdo
<U11<e93=E=5=e53=Tdo<TPk;dDg;4<d:D4b9Sl`8ch_8cla94Df:DXi:`9>>R/02UU3=6I@@79LC7iW
EXUbHIAkJYj5LjN>O;2FQ;VOS1coool001[oool02Vi_L69RHeIEETU9BS/k?2h^;alO810@4@010PL8
2@8C4Q80520M72lX9T<g<UM6@6IBBVACC5i@C5Q=Be=;BDi9B4]8B4U9BDY:BTQ:BdQ;CDM;CTI<Cd5:
CC]5BcA0AP8_?4@05BTk@bDj@b<jAB4mB250CB=5DbE8Eb]?GS1EICAKJSQPL3aUMSeYNcm/Od1`Q41b
QcecRDQmTf>@XgfR/HJ/^`02TKW700ZK_LVL^LBJ];fH[KFDYjf@X:F<VIf8TIF4RXeoPh@Joooo00Z7
N7IkK6Y_GeiSDe9GATE:>CPl:b/^7AdP3PlR4Q829aLH01@]7Qhe9BA2<2i@>cQIA3mGA45C@d5?@D5<
@D9:@499@DA9A4M;ATU:AdY:B4a9B4e7Ade1A4Xl?THf>D42<CHn01D^=3d/=3h[=T4[>4DZ>dTY?D`Y
?Th]@e<bBETeCUdhDV8jEFHkF6XkFVdkGG0kGW<hGWA0IWaEMhYYQYIaSYd00WVHY`0:QIn[Rj2ZSinW
TIfTTYZPTiNKTi>FThnAThb<ThR76_ooo`0:Z8f3WhAjUGU`RfmVPFELMUYAJdm6H4<lECTaD3@]0Tda
:P0DBRlXBRhWC30YD3<[DC@/D3</Cc@^CSHaCSTeCc`iDD4oDdI5EDU8ETa<ETe>EDe>DTY;CDA4B3dn
A3Th0T4f=P0E@3Hf@3Hh@SXl@ce0@Se2?STo>cLl?CTm@Ce1@d14A455A496@d57@T57@D57@D58?Cm7
@D=:CDeBEeEHG5UK009RGUh02ViVIG]aKhAiMHanNY:3OYV7PIj;Q:>>QZRARJfDRa[oool02[^PSKBI
QZfBOjJ;Mij3L9MlJ8mdH8M]FH1VDgELB@9ZDSl05619=eM2<54l:d/h9dDc8d@b8THd9DPh:D/m<4i3
=e9:?eMAAeYEC5]HD5aJDU]IDUMECE==@dm7?4e3=`9<@S@05Da2=Dm4=e98?5E;@E=9@4e2>DPl<TPk
<DXm<T/n<d/n<TPl<4Hi;T@f:d<e:T8c:Cl`9Sh`9D4d:D8d:D@e:002Ac@V00YB?BiTCd1bGDenJ5R9
Lf:DOFbNQWBWSWf`UhFiWh`Loooo000Joooo00Y^Kg1RHV=EEEI8BDXj>c`];BlN7b4?4A800P@82P/2
51@D01@S7ahb:bQ7>SEHB45WDd]VEDmQDdmKD4iECTeAC4a=Bd]:BT]8BD]6BDY5BD]3B4Y0ATXlA4Th
@TLb?T@2;C]301DY>T<V>TDT?4LS?TXR@DlVAe@XBeT[D5l/E6<`F6TcGFlgHW@jIWTmK80nKh<kL8Dj
LXU;P9ETTZAiX;28[K`00YJlb@0:Z<OBY;o9XKS1WK6hV:Z`U::WSiZORY>FQH^=P8>56_ooo`0:QgQf
Nfa[Kf1OHeACEdM6BSXj?Bd]<1lO8Q4B9AHG0R/L700D<R8R?2XYB3@bDShkFTE1FDI4EDE4DD=4CD=4
Bd94BD96B4=7Ad=8AT=8AD=9@d98@457?3i5>3]2<cLo0S0d?@0E;C<m:c@o:cI2:cU6;3e;;d9@<4AC
<4IF;TQH<4YL<TiP=E9U=eIY>UY^>Uaa=eeb=Ume@fYoEWR<IHBELHnO009nWJ/02Y2Y]9:V[iBSZiFP
YiJMXYJIWIJEV9FATiB=SI>8R1[oool02ZR>Q9n4NiIkLXaaJ8=WGgUMEFiCBfA9@UXo>EHl=P9D>S@0
0e8g<E8g<5<g<002DcL`00mA=Rm?=S1>=S9=>3E=>cQ>?Se?@D5@@dA?ADE?ADI>A4E;@D=8?Sm5>CY2
=SH00Sld=@0E?S<e?cDg@3Pk@Sa0AD55B4A8Ad=8@d15?Sa1?C]1?Se3?ci5@3m6@D99@D=:?d99?D9:
A4Q?CDmEE5AIFUYN009WIFH02WE`KgifM8MlNHj1OIF6PIZ9Pj2=QZB@R:VBRZfERa[oool02[bQS[FK
R:nEPZR>Nj67M9Z1KY=jIhedHHI_G7eWE@9cGT`056YD@V5<>eQ4=4lm;DPf9dDc9DDd9TLg:DTk;T/o
<di5>U1:@59=AE=?Ae=@B59?Ae1<A4i8?da3>DY0=@=:?c<054a1=Tm5>U=9?eM>A5Y?AUM<@dm4>dPm
<dDi<4@i<4@h;d<h;T@h;d@h;T4f;40d:d0e:d4f;3ld:d4f;09;?C002UI5>6EBA79OD7mZFhYeIIEn
KYj7MZR?O[6GQKVOSAcoool001[oool02Vi_L65RHeAEETM8BCXk?2`^;ahP8@lB4`431@X<3@8D5AD0
52@P7c@]:TLk=eM8@VEBBfIFD69FDEeCD5M@Ce9>CTi<CDY:C4M9BdE7BD96BCm4Aca2ASQ0AC@nA2ll
@`8[>D805BPj@bDjAB@lB28nBb91CRA5DbI:F2]@GbmFIC=KJcEOL3UTMSYXNc][P3U]PSM_QCYcRTn3
UfFDYWZS/Xjb`002Wl7=00Z`cMJ/aLjW_LFR]KbM[K>GYJZBW:2<U9N6S8j0PhDJoooo00Z7N7MkK6]`
H5mTE5AHB4M;>c/o;Rlb8B8U5AHZ6QX2;QlO01@f9RHo;Re:=cEC?caIAD9HAdEEATIAADE>@dE;@TE8
@TE6@DE4@DE2@4E0?dDm?D<k>d8g>D0d=Sh`=3d2;38l01D[<SdY<clY=D8Y=dDZ>dT/?dd_A58cBEPf
CEdgD64gDf@jEVTjFFdjFg0fG70dGG<fH7M7KX=HO8iWR9UgUZD00XNS/@0:UjjiVJ^dVZR`VZB[VZ2U
VIbPV9NJUi:DUHf>U8V86_ooo`0:ZHj4X8ElUgacSW=[Q6YRNf1ILUM@J4i7GdDoGD<m0UY1>`0DF3hh
F3dgEc`fESXdDcPbD3H`CSDaCCHbC3LdC3PfBcXiBc/kBcdmBShoBCdoAc`mACXk@SLi@3@f?C8d0S``
<`0E>c4c>c8e?C@h?SPl@Ca0A414AdA8BDM;BTQ=B4M<ATE;ATI<ADM>@dI>?dA<?DA<?dI>AdeDD5AJ
F5aPHFAW009]KFh02W]fMH=kNH^0OI:5PIN9Q9f<QZ6?R:JARJZCRjjES1[oool02[bQSkJLRK2FQ:ZA
OZB;NIj5LiR0KY9kJHefI8I_GP9lIUH01G5MC6QDA5i;?5=1<dTh:P02@c<U00e4=BM6>2Y8>bm9?S=;
@CM<A3]<ASi<Aci;ACe:@c]8@CQ7?SE6?3800THk<@0EAS`aB3dcBd0eCT<iDDLmE4]1Ede3FDi5Ede3
DdPoCd@kCD8iBd4iAcde@cXa@CP`@ST`A3XbA3`cA3hdAd0g009?ACX02UU;?fMFBGAREH5^GhahJ9J1
LJ29NJVAP;6HQkZPSAcoool001[oool02Vi_L65RHeAEEdM8BSXk?B`^<1hP8Q0B50441PX=3P8E5QH0
52@Q83@]:dDj=eA6@F5ABVIFDFAGDeiEDUQBDE=@D4i=CTY:C4I8BT96B3m3ASa1A3Po@c@m@S0k@B`i
@08X=d005BHi@b@jAB<kAb4mBR50CR94DRE9F2Q>GReDI31IJSAOLCISMSIVNSIYOCE[P3A^Q3aeS5:6
VVVGZGjV]YBf``02Z<G?00ZgcmVebm>_`/VX^KnR/;FKYjbDWZ:>UIR7SHn1Q8DJoooo00Z7N7MlKF]`
HF1UEEEIBDU=?Ce0<34d92@W5aP[71`2<24R01@i:2U1<2m:>3IA?caGA49HAdIFB4MBATM>A4M:@dI7
@DI4@4A1?T<n?48l>T0i>3hf=Sdb=3/_<SX/<3X2:Bli01DX<3/W<ChV<d0V=D<W>4LY?4//@E4_AULc
C5`fD64hE6HhEVXgF6`eFFhcFg0cG78iHgU:LXIMP9=^SYioW:X00XnX]00:WK:lX;6iX:jeX:V_WZBY
W9nRViVLVIBEUhj?UHV86_ooo`0:ZHn5XHImV7ieSgE]QfeUOVAMME]DK59<HdU3H4M10Ui6@00DGD@o
Fd8lFSljEc`fDcTcD3HaCSDaC3DbBcHcBCHdB3LfAcLgASLgACLg@cHg@C@f?c<d?C0b>bha>Bd`0SL/
;`0E=bd`=bhc>30e>S<h?3Lk?cXo@Si4A498AdI<B4Q?B4U@ATQ@@dM?@DI>?TE=?DA=@DQABe9JEU]R
H6AYJV]_009dLg@02WmiNHQoOI26PiJ:QY^=R:2?RZBARjNCRj^DS:jFS1[oool02[fRSkNMRk:IQZfD
PZN?OJ::N9b5M9N1Ki9lJhYdH`:2KEd057QUEFeJBf9@@EI5=dXj;D<c9T4b9D8c9T<e:D@g:dDi;dHk
<DHl<THm=4Dn=D@m=4<k<d8i<44h;T4f;@91=R`05D8f;D<h;dDj<DPm<d]0=di3>U56?U=9@EE;@UE;
@e=:@Tm6?d]2>dLo=d@l=48j<T@l=4M0>4]3?4i7?e19@002ED]100YLCT=YFDehIeZ4LVB?NffHQ7BQ
Rg^ZTh:bVHRjX8hLoooo000Joooo00Y^Kg1QHV=DEUM7BDXj?3d/;c0N8B<@4aH21@P;3a425QLI01@T
8R4b;B]2>CI@AD1NCdYUEU1UFEEPEUAIDe=CDE5>CTm9BTa4AdY0A4Ll@D@h?T8e?44a>Sl]>3lY=Sh2
9SI001DT=d8R>D@Q>TLP?DXO@4hP@e8RB5PUCEhXDV<[EVP]Ffh_Gg<`HgP`IW/`JGlbKHA0NHmGRYi^
Vjb4Z[VJ^/H00[39d`0:_mCL`=?J]lS>[[g3Y[>hWZV^Uj2ST9NIRHf@PXB66_ooo`0:QgQgO6e/LF9Q
IEIFFTY:CSho@S8c=RHW:AXK;QlQ0S<U9P0D>R/[@C4aB3ThCclmEDA3F4M6ETU9DTM8CDA7BD96AD15
@Ci3?S]1>cTo=cHm=3@k<C8j;S0h:bhg9b`g0RD/>00E92dj8bll8c4o8c=28cI69CY:9cm@:dAE;DQJ
;daN<E1S<E=W<5EZ<5M];eU`<5ed?6MnD7N;HXFHM9>SQZ6_00:H[kX02ZJi`Z^j`ZRd^jJ^/j>X[:2Q
YIfKWY^EUiR?T9F:RA[oool02ZV?QJ68OYV0Mi5hL8U`J81WH7QOFFmGDFI>BFA=B@9SC4P0565:AEi7
@e]4?eLo>e<k=e0g<dde<T/e<TTd<TLd<TDc<d<c<d4b<Sla<Cd_<3/^;cT/;SLZ;CDY;3<W:`8b9b/0
5C8X;C<Y;c@/<CD_=CLb>3Tf?3/j@ChnAD11B453BT94CD15CCi5CSe5CS]5CS]6DD==Ee1HH5]QJFIZ
L79cM`02OGan00Z8Ph>ARHRGSH^KT8bOTXfSThfVU8fYUHf/UXf_UXdJoooo00ZmXi2iWhbdVhV_UhFZ
Th6USWfQRWZLQWJGPW:?O6d2QgEV00anK5icHUEUETUIBSi=?S=4=BU0<BA0<BE1<RI1<bQ1=2U1=B/2
@3H/00Do=B`n=B/m=2/l<bXk<BP00c/`9`08?34X?C8Y?c@/@SL_A3XbAcheBT0iC4<l0Te5?P04C4@n
BT<lAd4jA3lh0T8m=`05AD0jBdI0CdY4E4i7F59:009MEDd02VEJD71SEge_HhQhJi:0LY^7NJ>>Oj^E
Q;>KRK^QSacoool001[oool02Vi_L65RHeAFEdM9BSXl?B`_<1hQ8a0C5P8520/?4@8F5aT052@R8C8]
:d8i=U15@5i?BVEFD6EIEF1FE5UCDe=ADDi>CdU:C4A7BT14Aca1A3Pn@SDl@C4j?bdh?bTf?P8V=T00
5B@g@R8iA24jAb0mBQm0CR13DR98F2E=GRQBHb]FJ2eKKRmOLc1SN31VNc1YOc9]Q41iSeN:WVjK[8BZ
^IZjaP02/<WC00Zoe=c0dmZgb<j^_L>V/kRNZJjGX:>@UiV9SI22Q8HJoooo00Z7N7MlKFaaHV5UEUIJ
BTY>?Sm2<S<f9RLY6Q/^7b42<bDV01@j:b]1<C58>CQ??ceEA4=HAdIFBDUBAdQ=A4M9@TI5@4E1?T<n
>d4k>Clg=Sdd=3/a<SX^<3P[;SLW;3L29B`h01DT;CXS;c`S<ClS<d8S=THU>TXW?e0[A5D]B5X_C5ha
D6<aDfL`EFX`Efd_FG0`GG@lIgi@Mh]RQIQdTj>6XJl00YR_^P0:Y[W2Zk[2Z;BkYZjcXjR/X:6UWI^N
ViFGV8n@UHZ96_ooo`0:ZHn5XHQnVH1gTGQ`RG1XP6MPN5mIKeMAITi9I4e90V=<B00DHDY5GTM3Fd@o
EclkDc/gD3LcCCDbBcDbBC@bAc@bAC<c@c<c@C8b?c4a?Bl`>bh_>B`^=bX]=BT/<bL[0S8W:`0E<RP]
<bT_=2`a=Ble=c8h>CHl>cY1?Si5@458@D=:@TA=@4E=?TE>?DE>>dE>>dIA@deGD5QPFf5YIVY`LW=g
009mO7h02XR3Pi69R9N=Ri^@S9nBSJ>CSJJDSJVESJbFSJnFSA[oool02[fST;VOS;BKRJnGQJZCPJF>
OJ6:NYb6MYN2LXmlK@:7MFH037i/GW=REFEFBEU:?Tdn<d@e:D0a940a9D4b9T4c:44d:D4e:`90=R`0
1Cle;3he:cdd:c`c:S/a:003>c0W00Pl<BPm<RTo=2a2=bm4>S97?SE:@3U<@c`2CDDn00A<A3i:@ca7
@CY4?cP2@Sdg00E5@3Y;AT1?BTADCTMHDTX00UeEC@0:IEY@L6=GOFmSR7Q[TX1bVhMiXhioZiF4/i^9
^j6?7?ooo`006_ooo`0:KVm`HF=TEEIGB4U;>Sdn;C0b7b8T4ADG0`L:3A0C0QLI6P0D928S<Bd/@3Pf
CTA0G4i:HeE@IeYFH5QEFEADDe5ACDe?AdU<@TI9?T=6>Cm3=Ca1<CXo;CLm:CDm9S@m0R@e?`0E8SI1
83Q47cY77Sa:7Sm>7T=B84MH8daM9E1R9eAW:5U/:Uaa;65f;FAj;FQo=G27B7nDGXnRMJ2`S;2mY<3<
00:jd=P02/WKh/[KhKk=dkC1aZZf^Z:/[iVQYI:HVXZ>T8:5QQ[oool02XQiMge^KG9SHVIGEe]<C510
@D@e=CPY:R`M7S4S908f:2T053`^;T<d=4Xj>U10@5I6AEQ9B5Q:Be97BDe4B4Q1AT<n@cll@C/i?cLf
?C<c>S0`>2`^=RT/=BHZ=2<Y=08R:CH05B4Z>20/>al_?Qla@B0dAB4hBB@mCRI1DbQ5F2Y9GB]=HBa@
IBeCJBeFK2iHL3APMdE^Q5MmT6Z;WGfJZI6Z]P02Y;S200Zb`l^fa<^`^l6//kRWZjnTY:NPWInLUiRI
T96FRXTJoooo00ZZT8JRRH2KPGVCNW:;Lf^3JfAkHeecG5I[E51YDdl2Ie5>01AVD4aSCDUPBDELAD9H
@CiB?3U>=cE;=397<c55<C12;blo;Rhm;Bhj;2dh:R/f:2Xd9RTa92P_8bL^8RL2;B8W01D]8bT^9B/^
:2h_:S4a;SDd<STf=Cdh>D4j?4@k?dPl@4Xl@T/l@ddlA4hkAE10BUE;EEiGGfQSJG1`M7UnOh<00XZ9
R`0:UI6AW9JEWiJDXIJCY9NBYYNAZIN@ZiN?[IN>[iN>6_ooo`0:_ZBA^Z2>]Yf;/IZ8[IJ5ZI>3YHn0
XHamWHUkUH9d0XelKP0CQ7AWNVYNKUiCH597E4LmB3`b@C<Y?c0U?S0T?RlT?BlS?2lT>c0V>RlV>BlU
>2hU=bdT=R`S=B/R00<e:R802cH[8cL]9CT_9c/a:Shd;D4h<D<k=4Dm=TLo>DM0>TM0>`02AT0j00Q5
?cU4?cU6@Ca<B4=BCDQGDTeMF5=TGeP2JfAM00YaJV5kLFN5N6f>Og>FQGRNS7fVTH:]UhNdW8^kXXlL
oooo000Joooo00Y^Kg1RHfAEEeQ8BT`k?T0^<C<P92HB5QT42@`=4QD261/L01@S8b@_;2`l=cE<@d1I
CDQRE4mVFEEPF5IHEEABD55;C4i5BD]0ADPk@DDf?D4b>Sl^=cdZ=C/V<c/S<S`28C<n01DO=D0N=d@M
>DLM>dXL?dhM@U<NAULPBU`QCf4SDfHUEV/VFg0XGgDYHgX^JH0kM8]?Q9UVUJMoY[FG]l>_b=800/GG
gP0:enK[d^3Ta=7E^<C8[[RlY:faW:>VTiVKRhnAPhF66_ooo`0:R7UhOFm]LfASJ5UIGDi>DD=3ASLh
>R/];R0R<bHW0ST[;00D?S0a@cDfB3XkD451ETI5FDU8F4Y:DTQ:BdA8AT55@3e2?3U0=cHm<c<j;c0g
:bde:2Xc92Pb8RLa7bHb0QdV=00E72Pf72Xj72dm72m07C=47SM983]=8SmB949F9DIK9dYO:4iT:U5X
:UE/;UYb>VElC7B9Gh>FM9BTRJBaW[>n00:a`/X02/;@el3<d[O0aK6g^jb_/ZNWZJ:OXIjHVIZATIJ;
RQ[oool02ZZAQj>:PIb3NiElMHefKhI_J7iWHWIPFfiIEFeHE@9/Ee<056UEDVIACf9=BUi9AU]4@EHo
?E4j=dXe<dHb<D8_;Sl/;3/Z:SPX:CDV9c<T9S0R9BhP8b`N8RXN8RTM8P8X7R@05BPO9BPQ:2TS:b/V
;RdZ<Rl^=S4a>S<d?SDh@CHkACLmAcPoBSU1C3U3Cca7DdE@Fe5KIEmWKfidNWaoQ8Z;SP02V9JG00ZU
Xj>YY:>WWibWWIVYViNZViF[VY>]VI6^V92`V8hJoooo00ZoY9:kXY2gWhjdWHb`VXZ]UhRYU8FUTX>Q
Sh:JRG`2TX9f01::NfmoLFIbIEYUFDmICD=>@SM5=bdn<2Hl;R<j;B8i:b0g:Qlf:Ahd:Alc:1lb9ah`
9Qd_9A`2;b@L0RlU7@0E;bDN<BLP<bTR=B`U>2lY>c8]?CD`?cPb@3Xe@S`g@Sdh@chi@chj@SljAD4m
BdM3DDi:F5IAH5eHJ6AOL6aU009hLV`02X9lMHV2NXj3NIB7Ni^;Oj:@PZVEQZnIRKJNSKbRT1coool0
01[oool02Vi_L69TIEIHFDU;CC`o@Blb=B4U:1<H6`D;3PlC5P8I71d052<S92d[;3Xg=TU1?eA;AeiB
Cf5FE5iHEUMDE51@DDU<CT=7Bce3AcPo@c<k@2hg?2Xe>bHb>B<a>B0`>P8N<Sd05Add@1`fA1/iAa/k
Ba/oCa]2Daa5Eai:G1m>HB5BIR9FJb=JL2ENMBUTNc9]Q4=kT5R;WW6L[HV]^j6ob[W?f002cmkU00[O
k?3Cgn?7d]Jka/Va^[fW[[6MY:JDVI^<Si63QHHJoooo00Z8NWQnKfidIFAYFeYND51DADI8>S/l;Rl`
8bDe:2X2>bd_01@o<S=3=SM:?3e@@T=DATIFBDUEBD]@B4]:A4Q3?dDn>d4h=chc<c/_;cLZ;3@V:34S
9S0O92hM8bhJ8Rl26B@b01DI9SDH:CPH:c`I;T0J<T@K=DPM>D`N?E4P@EHRAEXSBElUCF@VDFP[Efhc
GgI2K89EO91[S9j0WJ^E[KVY_<H00[c;dP0:bmOMa<kC_<C8][Zn[k6dZZV[YJ6RX9VJVi:BUh^:6_oo
o`0:Zi67Y8^2WXEmUgmhT7UbRG9]PVaWNVAPLUeJLEaI0VmKF00DK5UFJEICIU=AHTm=G4Q7ET91D3`k
BCHf@c4a?bd]>bXZ=bLW=2<U<20R;AhP:Q`N:1XM9APL91LL8aLM0R<H7`0E8a/R8adU920X9R</:2L`
:R/d;2hh;S4l<3E0<SQ4=3a7=3m;=T5>>TIB@DeIC5QSFVA^JG5iN7j4QhZ>UIJI00:SXJ802ZjZZZjY
Z:jVXjfSWjfPVjjNV:jMUZnKTk2JTK6HSa[oool02[nUTkbSTKVQT;JPSk>NS[2LSJfJRjZGRJJDQin>
PP:GR7`04Hn0MHAgKGU]I6aQFEeDBe17?dHk<chb:SX]93LZ83DX7S<V6c4T6BlR62dQ5b/O5RXN5@02
:1dD01PX7ADY7QLY7QLZ81T[8Q/]9Ah_:28b:bHd;RTg<B`i=30k=c<m>CDo>cPo?CY0?ca4@Si9AdA?
CT]HEeAQH5aZJ6=bL6]jMg82PWih00Z9Pgf@RH6ERh:KSX>PTHFVU8N/V8VaW8bgWhnmXi4Loooo000J
oooo00Y_L75SI6EFF5Y:CDhm@D<`=3LS9bXE6Qh63A0A5AP26AdO01@S92H/;2dh=SE4?ci?B4IID4eK
De5JEEAEDe=>CU17BTe0ADTj@DDe?44_>3h[=3/V<STR<3PP;cTM;cX26c4l01DK<d0J=T<J>DPJ?4/I
?dlJ@U<KAEPLBU`MCF4NDFHOEF/QFW0UGgD[IWhgLXQ<PIISTZElY;BC]<:[aM35eml00]_Vj`0:iNoc
e^3TbM?F_/K:/kZmZ:nbWjBWUIZLS8nAPhF66_ooo`0:RGYiOg1_MFIVJeaLHE9BETQ8Bcdn@38d=2LY
>B`]0Sd`<P0D@C@fACTjBShoCd93DTI6E4Q:D4M:CDI9Ad=7@Ci4>SU0=C@l;c0h:R/d9RPa8B@^7B8/
6R0[61l]5Ql^0QDQ<00E52@d5BLg5BXk5Rdo5c5463A86SQ<73eA7T1E7dAJ84QO8TaT9U5Y;5Ua=fAk
BW>9GhBGMIBURZBcWkG0]LG>00;9e=/02]?Mh/WAeL76b[Vm`;>c]Zb[[:NRY:6JVibCTYN;RQ[oool0
2Z^BR:F<Q9n7OiV2NY=lMXagLHIaK7m[IgMTHGISH09dHEh0575NG6iLFVYHEfABDEi<BeI5ADdl?DHe
=T4_<3`[;3LV:3<R92lN82/J72PG6R@E624C5alB5adB61`B6@8L4a/05A`F7QhI8R0L9R4P:R<T;RHW
<RP/=b/`>bdc?bhf@c0jAc4nBcE2CcY8ETABGe9OJf9]MW9jPX67SY2DVJ2QY002[jf_00Zh];Be/:jc
ZjVbZ:BaY:2aXYbaWiRaWIFaVi:aVI0Joooo00[0YY>mYI>kY9>iXi>gXY:dXI:bX9:`Wi:]WI2UUXX2
WHn401BER7j<P7N0MFabJ61SFU=DC4E6?SPl<R/g:b<d:1la91X^8AL[7Q<Y6a0W6@hU60hS5PdQ5PdQ
5PhP5Q028ALA01DR6A<T71LW81XY8al/9b8_:RHc;RXe<Bhg=34i=S@k>CLl?3Xo?ce3@d9:BdYDEE=N
GeaYJ6IbLFikNGJ4PWh00Xj;Q`0:U8n:V96:W9>:X9B:YIJ;ZYV<[i^=/ij?^:6@_JBB7?ooo`006_oo
o`0:Kg1aHfEVEeYKBdi@?d95<SHi9BX]61dQ2A0C4QLJ0QXO8@0D8bHW:b`]=C@d@3dmBTE4DDa:E4i=
Ee9BDU9BBde?A4Q;?D=7=ci3<CY0:cHl9c<j8S0h7bhg72dh6Rdi0QT`?@0E6C=16CI46CU863]<63m@
6D9D6TIH6TYM74eR7E9V7EI[8EYa9V5h<F^2@WV>F8ZML9^/R:bjX;g8^LkGdn7V00;Yl_H02^O`lmSQ
i<_Ce[o7bKBk_JZ_/Z2TYiJJW8f@THB5QQ[oool02XUkNH1aL7IXIfeNGV=EEEU;C4m1@T@f>3T[;Cd`
<@90=3H054<g>DHj?4Tm?de2A4m5Adm6BDa4B4Y4B4A1Achl@SLf?S0a>B/]=BDX<B0T;Q`Q;1PO:aDM
:Q<L:a4L;08@7bl05A4R=14U=a8Y>a<[?a@_@aHcB1PgC1TlDA]0EQe4Fai8H25=IBMCK35NMT5/PUEm
TFb=Wh6N[YJ^^jfobLCAf002fN?W00[Ih^K=e=O4bLbl_/6e]KN_[:fXXjBSVi^MTi>HRhXJoooo00Z/
TXVVSXFQRH6KQ7fFP7V@NgJ:MW:4LFinJfUlJVP2N6QV01AeI6=aH5m/Fe]WEUIPD51GAdU<?Cm5=CLn
;c4i:B/c8bD^7R0Z6A`U5QPQ4QHN41@K3a@I3A@G31@F31D25PhH01DG4A`I5B0K6B@M72LO82`R9C4T
:CDW;SXY<Sl[=T<]>TLa?T`eA58nCE];FVMKJGA]Mh5nQHf=TYRNX:B_[k400[no_`0:`/2o_;Je^K6^
]jbX]JRS]:FO/j:K/inG/YbC/YZ@6_ooo`0:`:JD_jJE_JJE^jJF^ZFG^:FH]jJI]JJJ]:FJ[InE0ZBH
SP0DVhn7T8ImQ7YcMfiWJ65KF55<B44l?3@^=B/T<2HN;B4H:A`C9QT?8aD;81<97Q8971496a0:6Pl9
6@l:0QXA300E6a@@7ALD81/G8ahK9b8O:RHS;RXX<Bl/=38a=SHd>3Tg>c`k?d50ATQ8D5=BFeiMIfUX
LW=aO7ajQhJ3TY2=00:MW9T02Z6OVj6KU:>JTZJJTJZKT:fMT;6OT;JQTKZST[jUTacoool001[oool0
2VmaLVAVIeUKGDe@DT55AcDi?2P]<1/Q90dD618I708K82<052<V:2T/;C8c=C`k?4A2@dY7Adi;Be9?
Cdi?D4M;CD15BCU1AS<l@R`h?bLd?28a>Qh_>1X/=aP/=aL]>P8F<3d05ALc@QLfAAPiBALlC1M0DAQ3
EAU7FQY;GQ]>HaaCJ1iGKB=LLb]VOCYcR4f2UVFCYGfT/iBd`Jc5clKGg]kXk@02koOi00[Tk>kHgn;<
dmG0a/Ve^kfZ[k6PY:JFVY^=Si64QHHJoooo00Z:NgZ1LW5hJFU_HF1UF5QLCTmBADI8>cdn<C=0=3H2
@cLj01A5>Sa7?3i:?d9<@dE=ADQ<ADQ9@dQ7@dQ1?dDj>D4b<c`/;SPV:S@P9C0K8BdF7R/C72X?6RT=
6BT<6b/231d_01D=8C<>93L?:3/@:clB;d@D<dPE>4dG?58I@5LKAE`NBV8SCfP/FG4jIWe<MH]RQYUh
UjR=Z;JS^<>jb];?f]l00]kWj`0:f=oRcmGHal[<_l32]kJh/:f^ZZBUY9bLWYBCV8b;6_ooo`0:[I>:
Z8n6Xh^3WXN0VH=mU7mjSg]gRGMdQ7=aPW9a0Wi_KP0DNV]ZMFIVL65QJE]LHUAEF4Y=CT54ACPk?2ha
=BHY;b0T:A/N91HJ7a8G6`hD5`/B50TA4PP@40LA3`TB0Q0;5P0E4@hI4a8M5ADQ61XV6ah[7R<`8BPe
8bdj9S4o:SI5;Ca:<T5@>TYIAUITEFAaIW=nN8:;R92GVIjSZZb_^KVj00;4`/802/?0_l6k^Kfe/[^`
[;R[Y[NWXKFTWKBPVK>MU;:JTA[oool02/6WUL2WU[nXV;jXVKfYVkbZWKb[Wk^/XK^^Y;FYX@:[XIT0
5::HT9R>Qhb3OGefLFiXHeiHE4e8AChj=C</9RdS7BPN5b@I4B0E3AdA2AT>1aH<1AD;1A<:1A891A4:
1P8B30T05A@?2aHB3aXF4adJ624O7BDS8RTX9b`];30a<3@f=CPj>ce0@4=7B4aADEMKG6=WJ71bLg]m
OHJ7QY6ASiZJU`02X9nK00ZUXYfWXI^YX9R[X9J^X9FaXIBdXYBhXi>kY9>oYI@Loooo000Joooo00Y`
LG9UIfQJG5i?DUA4AdXh?3l/<C@O9BTA61`D6al26b4T01@R9bXX;2l_<SDh>S]0@D96ADI9B4U;Bda9
C4i3B4`l@TLe?T@^>D4X=ShR<S/N;cTJ;CPF:SHD:SLD;CX2530n01DF=4<F=dLG>TXG?DhG@E8HA5LH
B5/JC60KD6DME6XQFW0XHGPdKH=7O91LRiicW:b:[KZP_LRjc]ODhNKXl?800_Cin`0:iN_]f=kPc=7D
`<G7]KZlZZn`X:BVUiVKSHnAQ8F66_ooo`0:RWajPW=bNF][LF=SJ5]KH59CEdU;CD12@cHh@cPj0THk
?@0DAce0B3m2BT54C4=7CDI9C4I:BDA9A457?Si5=SM0;S4j9b`f82Hb6R8_5Ah/4A/Z3ATY2ALX1aLX
1aT[0PPL;`0E2R0c2b@h3BLl3R]042m54SA953Q>5SaC645I74IN8DeU:5E]=F5iAg26Fh2DL96SQZ6a
V[:n/L?=bMGKfn?W00;Uk>l02]_Phm7Ef<W:cL30`[Vf^;:][Z^TYJBLW9jDTiR<Ra[oool02ZfDRZV@
R:B=QJ2:Pib7PIN4Oi>1OHmnNhYjN8QiN0:4MWH057mbLWY]KWAWJFiQHVIJG5iAE5=7BdLk@3/`=C8V
:b/M8bDG7AhA61T=5AD:4Q4740h53P/33PT33`P54@8:1a@05@`;60l?714C8A@H9QLM:aXR<1hW=B4/
>b@b@BTgAblnCSM7Ed9CHU5QKf9`O7=oRHB=UYBKXZJZ[kRj_<K5aP02c<_:00[9aLC5_kg1^KJn/jnk
[ZViZZBgYInfXYZdWYFcVi4Joooo00[1Z9K1ZIS0ZY[0Zic0[Io0[Z;0/JG1/jW1]Jbl/ZX2]:^T01BY
XI^NUi:CS8N5OgYgLFeXHemGDe15@Che<Bh[924U6aHP5A0K40/F30LC2@D@1`<=1@4;1@4:1@891@<2
2`L601D=2PT@3PdD4Q4H5aLL71`P8B4U9RHY:b`]<C8b=SPi?3i1ADM:Ce5EFeeRIfU^LgAiOGj5R8VA
U9>MWifWYjD00ZZYYP0:[:VU[JRR[jJN/:FL/ZBI]:BH]jBG^ZFF_:FE_jJD7?ooo`006_ooo`0:L79c
IVQYG5iPDEAFATY<>d12<3Dh92X^61lS5QdQ0Q/R9P0D8BL[:Bh`;S8e=STk?T12@TA5ADI8ADQ:A4U<
?TA9>416<Ce4:CM08c@m7S0k6Rhi5R`h4RXg3bTg4Bdk0Q<a@00E5CE55SU95c]<5cm@649D6DII6TYN
6diS7U=X8EQ]:5me<FUo@WN;EXJIJiFVPZJeVKO2/<OAb]WOhN[]m?Wk00;enO/02^GZjmOLg/_@d[o4
a[Bi^ZZ^[j2SYIJIVXf?T8B5QQ[oool02X]lNh=eM7]]K7=UIF]NGV=FEe]>Ce=6B4/o@DPm@099?T40
54Y0@da3ATe4Adi6BDm8C4e7C4U6BdA2BCdnAS<g@2/`>b@Z=Q/T<QDO;PlL:`/I:@PG:@@E:04E:08H
:`8473005@LP=@TU>@/X?@`/@PlaAQ4eC1@jDALoEa]5GB1:HbMCJc9NMT=/PUIlT6Z<WX2M[IF]^Z^n
bL;?emOPiNW`l`02j_3c00[MhNCCeMO:b/c1`<6j][Nb[Jj[YJFUW9bOU9>IS8XJoooo00Z^U8^ZTXVV
ShNRS8JORXBKR8>HQX:EQ8:CQ8B@PX<2Rgin01B5NGZ1MGIkKg1dJFY]HFATFEaICeA=A4Y0=chc:C4X
7RHQ5QlJ41TC2Q@>1Q4:0`h70@d400d200d20Pl210DC01D72QP:3Qd=4R4@5bHD7B/H8S4L:3PQ;ShV
=DD]?4ddAEDoD61?GfiOKW]`OHV1S9JCVj>TZ[2f^Kg5alSDeMH00]KFeP0:c/_9bL?0aKbi`KJb_[2[
^j^U^JNP]j>K]InF/i^A6_ooo`0:`ZRF`ZZI`ZbL`ZjO`k2R`k:Va;J[a[Z`bKnhakjh0[fe[`0D/Z^V
Z::MWINBT8Z6PGaiLVi/HUmNDDm>?S`l;b/Z91hL7ADB5`l<4@T630D32@801`401@000P000@410P<3
0`0E1`L72P`=3Q0A4aDF61/L7B4Q8RHX:2d_;S<f=C/n?D=6B4iAE5]NHFMZKWAfNh22Qhb=TiNHWj>R
ZJb[/kNg00:g^KL02[Bb[[B^Z;B/Y;FZX;JXWKRWVkVWVK^WUkjWU/2WUAcoool001[oool02W5bLfMY
JUePHE=FF4U=Ccm3AS@j?BX`<alV:QLO8`8K8bL0528Y;2P^<Bdc=S@h?3`o@Sm3AD96BD56BD56BSa3
BCM0ARhl@b@f@1hb?AX_>QL^>Q</>@lZ>0h[>Q4_?P8D=4<05ADgAaLkBaPnCaQ2DaQ5Ea]9G1e>HQmB
Ib=GK2UNLc9XOCmdR561U6F@XG^P[i:a_JW1bl7BfMWSingbm?cno`02l??e00[Ri^SFf]_:cLnn`/>c
]kRY[:jOXZ>FV9V=SY24QHHJoooo00Z;OG^4MWEmKfifJ6Q^HF5WFUYPDeAIC4iBATQ;@482C49401A=
A4M>ATU>ATY?B4eABTi?BTm<BDm6ADa0@DTg>T@^<clS;3TH93<@7bl<6b/86BX45bX05BT05b/16Rl2
11hc01D68SP89S`::d0<;dD><TTA=dlF?EDJ@e/OBF8WDFTbG7A0JX1BN8eVR9]kV:V@ZKNV^/Flbm?B
g>7Tj^g`mOL00^S/kP0:g^3Re=GFb/[;`/31^[Jg/jf][:BTYIbKWiBCVHb:6_ooo`0:[YF;Zi>:Z969
Y8n8XHf7WXb7W8^7VXZ8V8^:UHZ90Y66QP0DS862QWamP7IhNW1cLfU/Jf5UHUUNEdiDBT99?3@m<2Tb
8a`V618M40/G2PDA1`8?0`4>000?004A0@@D0P875`0E10XJ1`lN2a@T3QTY4Ah^5R<e7B/l8c=4:SY<
<d=E?U1PC5i]G6ejKWb8P8^FTI^TXj^a]KZnaLS:dmCEfm_K00;He]D02];>c<g6`lRn^lBh/l2b[Kf]
YkZXXKRTW;JOUk>KTQ[oool02/:YUl>[V/>]WLB`XLFcYLJfZ/Rj[l^o]/k5_/k7`@;5_kX05;^e/;2[
YjFQWIRETX^8QGikN71]K61NGTm=CChl?2l];B4N7QLC4`h;2PP410D10@800@000@010`031@801@L0
5@872PH;3P/A50lF6A@K7QTQ9B4X;2P`=C0h?CY2AdE>DU9KGf1XK6ieNGb2QHV?TIJKWJ:WZ:jb/[Jj
^[Zm_@02_;fk00Zk^;Bi]:ji/:Vi[ZBi[:6jZYjlZI^mZ9VoZ9O0YiDLoooo000Joooo00YbLgAXJV]O
HF=FFE]<D593AdXi?T4_=CTU;30K8bL272@Y01@S:bhX<3<^=3Lc>C`k@48oA4M0ADToADTmADTk@dTe
@4L/?4@T=d8O=3lL<ShH<ChD;cdA;SdB<3lD=4<25cQ701DH>d`J@50K@e@KAELMBE`PCV4SE6LWF6`]
Gg<dIg]1LhI?Oi5SSIegW:^<ZkRS_<JkcMCBgN;Vk>ohnO_mo_l00^g_l00:gn;SdmKGal_<_<31/[Ff
Z:^/Wj6RUINHS8j?Q8B56_ooo`0:S7elQGMfOg5`N6YZLFATJeiNI5MIGU5CEda>D4E80U16B@0DDTQ;
DTY=Dd]>Dda@E4iBDdiCCdaBBDQ?@dA<?3i8<SQ39S0n72Ti5B@d420b2aha1a``11/`11db1R0e0PLT
>@0E2BLm2ba232m63S=:4SQ?5SeE6dAL8DYR:E9Y<eac@FUoDGN:I8JHNIFVSJJdXkO2^LSAcmWOhNO[
lOCgmOSj00;Xj^`02]gNh=?Ce<[8bL:n_kZe][>/[:bTXjFKVinCTYV<RQ[oool02ZnES:bDRjVBRjJA
RZB@RZ:?Rj2?Rij?SIf@SY^@T0:HSY0059B:Rhj5QXUoPX9iO7]cMWA[L6YRIf1HGUA=E4Q1BC/e?RdY
=24N:QTE8Q8?7@`;6PP860D860D96`D<7P863R005@LA8`TE9``I:`lN<1DT=Q/[?B4bA2TjC3=4ECi@
HDaNKUa]NfelRGn<Ui6LYJ>[/kJk`<S:c]KGfN7RhnCTh`02g=WH00[Ed<k?b<G:`;c6^KG2/jjn[ZRk
ZJ:iY9bfX9NdVi8Joooo00[3ZIO4[9_5[io6/Z?7]JS9^Jg;_K?>`[WAb<7DcLT2d<_701C6`Kfk]kBa
[JZUXYnGUI>:R8MlNgY^K6aOGEe?CTho?Sl`<34T8b@K61XB4A<<2`h820`62@d52Pl52a421@`B01D5
3Q@74AL;5A`?6b0F8BLM:2hT;cD]>3hh@dQ4CeAAG65PJVi_Mg]nQHR<TYFJWj:W[:jd^;Vn`/?5b/[6
bLT00/?3`@0:`;fi_[Rb_KB]_K6X_JnT_JfP_Z^M_jZJ`:VH`JRF7?ooo`006_ooo`0:LW=dJV]]HF=U
F5]MCe=EAd]>?T=6=C/n;38f8RX_0QhV:P0D92``:C4d;cHi=3/n?454?TA7?TA8?4A8>T=8>498<cm7
;3a59SU48SM383M373I26SI463E463M56SU80Q/mC@0E7T5A84EE8DQI8TaM9E1R:5AW;E]^<V5d>VUk
@g:4DWj>HHZJMIRWRJNdW[O1]LS?cMWNhNOZlOCfoooomoWi00;Xj^/02]_Ngm3BdlC7b;Zm_[2b]:NY
ZYfOX9BFUhb=SX>4QA[oool02XanOHIhMh1bLWY]K7AWIfiQHVULGF=GF5eBDeQ=C`9DBT`055I<CeI>
DEM?DeQAEEYCEeIBEe5>E4]:DDA5CSi0BSHkAR`e@R@`?ad/?1TZ>a<W>A0V>@dU>@dW>`hY?@8>;440
5A0_AA8cBA@gCALkDQ]0Eb16GBI=I2iEJcMNM4=YOU9fRF>4UGNCXh^S/J2d_kK5c/gFgN3VjNocmO_m
o_Cfm`02inSY00[Lg=gBdM79a/O1_Kfi];BbZj^[Xj:UViZOTi:IRhXJoooo00Z_UXb]UHb[U8bXThbV
ThfUTXjSThnRTi6QUI>RUiL2X9JG01BKTY>FSHjAR8Z<PhJ6OX5mMGUbJg1WH6IKEEa@BU95?dPi=Cl_
;3PV9C8O82hI6bXD5bLA5RLA5bP@62T23aX/01D@72lB7c8D8cHH:3/M;d4T=DP/?E0eAeQ0DV==GfmM
KW]]O8UoS9NAW:FS[;>f_<;9c=3If]gUi^O]k^kXj>P00]oKfP0:em7?dLW5c<6makZe`kB^_jnX_:VR
^JFL]j2G]9^B6_ooo`0:`jZHa:fLa[2Pak>UbKNZbk^_c/2edLFle<c4fM?>0]WDd00Dd<c8a/:o_;Re
/Zn]YZBRUiFDRHN6NWQhJVUYG5YKCTa=@T11=SDg;2d_8bDY71lS5QXO51TO4aTO41TP0PlJ8@0E3a/S
41dU4b0X62H^7R`d9C<k;S]3>4E<A55GDUiTH6]`KgUnOhN<SYFIW:>VZ[2c^Kk0aLW;cM;Dd]SIcm?C
00;9bLH02/G2_L>l]/6h/<2dZ[naY[n_X[n]Wl2[W<2YVL6XUQcoool001[oool02W=dMF]/KV=UIe]N
H5=FF4]?DD97BSY0@c8h?2Xa=@8R:bl052@]<B/c=c4h?3Dl@3Y1AC]3Aca4BCY3B3Y4BCQ3BC91BBdo
B2TnB2LlB2LmBB8kB28mBR0lBR4nC291C`8TAE@05BQ9F2]>GBeAHBiEIC9IJSIOL3eVMT9/OD]eQ5In
SFF:V7FFY8RT/9^c_K33b/OCfMkTing`lOgno_clo>o`l002h^CT00[Gf=W;cLk1`lBg^KZ^/;6UYZRL
WYnCUIJ;S8f3Q8DJoooo00Z=Ogf7NGR2M7=mKfmgJVYbIFE]H65XG5eSEeUODeD2FU1B01AJDE=KDUEL
E5MLEEULEUYHE5UDDEM>CEA9BU93AU0k@Ddb?4X/>DLX=TDU=4DO<D<M<D<K<4<J<D@J=4L273M;01DO
>dlR@5@TA5PVAed[CF8aDfPiFg11HgM;KH1GN8UWQIEiTj:<XZnO/Kbd`/[:dmWOi>O^lO?moooloOg_
ko000^CSi00:f]SHd<k>b<C4`;^k^;:b/JZYZj:QYIZIWY:AV8^:6_ooo`0:/9J=[YJ=[9F=ZYF>ZIF?
YiF@YYJBYYNDYYVGYY^K0ZJMWP0DY9bMWYJHVY6DU8b?SHJ9Q7f1NW=hL6U_IV1WG5MOD4eFADA??Ca8
=cI3<C8o:Rdk9RXi8RLg8BLg82Ti0R4[?00E8Rho9C939cE7:SY<<3mB=dMI@55QBEYZEFEdHW5oLWn<
PXjITifVY:fd][g2bLgAf]gNj>WZm?KfloCdj>KU00;OfmT02]SAc];9aLg1_LRk]LBd[/2_Z;fZX[ZU
W;NPUkBLTQ[oool02/>ZV<F]W<NaXLRdY/ZhZlfm/M32]m?8_]O>amcFd0;Pg=P05=_He]7>blO4`[bj
^;2_[J:QX9BCThN6QWUhN6a/KEmPHE9DETQ:CD12ACTk?c8e>R/`=BL]<RD/<B@/<`8S;C@05B<_=RDb
>RPe?R`i@S4oB3U7Cd9@EdeJH5QTJVE`MWAnPX:;T96IW9nVZJjd][c2`lW>d=CIfmcSiM_Qh]?Ee002
cLc900[9aL36_kS4^[;2]Zc2/jO1/:?1[Z31[9c1ZYW2Z9LLoooo000Joooo00YcM7I/KVmUIfUMH69F
FEa?DeE7C4m0ADPi?d8a>3`2:C4e01@V;S8]=CTb>Shf?T8i@THlA4PnAT/jA4XjAD/hA4/b@T/a@T`^
@T`/@Dd/@TdY@DdZ@dlYA54ZAU</BUL2<4iK01DdDV0gEV@iFVPlGVe1I797JWQ=L7mCMhELOheYRYMh
UJ68XZfJ/;R^_lG3cm?Hg^7ZkNkjno_mo?calO7VinL00]_Mg@0:dM;CalS9_Ko0];JfZjf^XZBUVYbL
TY>DRX^<PX>46_ooo`0:SWmnRGYiQ7IeOg5aNVe]MFQYLFAUKF1QJ5eNI5UK0V1EF00DGUAFH5MJHEUL
H5UMGeUMGEQMFUMME5=ICdmGBD]D@4IB>dA@=d5?<Sm>;ce=:c]<:Sa<:Ca=:3i?:D5B0Ra4EP0E<4QJ
<deO=E5S>EEX?U]^AF9dCFYkE762Gg^;K8JEO9>QSJ6]Wk2j/l37b=3EgN7Tk^oaoOknoooom??dj^WY
00;Pg]h02]KCe<k:b/K1`Kjh^;N`[k2XYjZPX:BIV9jBTIR;RA[oool02[2GSJjGSZfFSZbFSj^GTJZG
TZVIU:VJUjVLVZZOWP:[XZ805:ZQXjNOXJ:KWIbEUiB>THf7RhF0Q7]fO75/LfMRJEaIHUABG4e<ETI6
DT11CS/mBcPkBCDiB3<jBC@kB`8e?Td05CM1DCU5ECa9FD1>GTIDI4iLJeITLem]NfYhQ7N4ShNAW9NP
ZJN^][Vn`l_>dMcNgn[[k?Oin_Wjn^o^kNOShP02gmWG00[Hd<gBb<C=`Kc8^[G4]:k0[jRmZJ:jYIbg
X9NdW98Joooo00[4ZYS5[Yg7/J79]JK;^Jc>_[;A`kSEbL3Id<SNem42hmoK01CSh=gKfMOBd<k7a/Bj
^[R_[jjTXj>GUiN9RHUkNga_Kg1TIFMKGEmCEEQ;CU96BDe1ADXm@TPj@DLi@TP2>T=:01DjAD`lB4ln
Be=3D5Q9EUi@GFEIIVaSKgE]N7ijQ8V8TIFFWZ:TZjjb^;[1a/O>dmCHg]oRj^cSjngLgmoEe]@00]3>
bP0:c<O1bL6ia[bcaKR]`kBX`k6T`ZnP`ZbM`ZZJ`ZVG7?ooo`006_ooo`0:M7EfKFm`IfUZH6=UFEeO
DeMIC55CAT]>?dE8>3m20S8i?@0D:c@g;cTl=3e1>414?4A8?TM;?TM<?4I<>dI=>TM>=TI?=TMA=4MA
<dMB<dQB<TQD<TYE<daH=TmK>E=O0SaFHP0E@E]XA5m/BFAaC6UeDVmkF7F1GG^7Hh6=KHZENiFORJ2Z
VZfe[;_1_lW>d]SJi>KXmoKgno_jlO7aj>SXg]oO00;DeMH02/_<c<73`kVj^k2b/ZRYZZ2QXYRIVY6B
ThV:Rh:3Q1[oool02Xj0OXYkNXEgMh5cLge_KgU/K7EXJG5UIViRHfYOH@9XGEh056AJG6IMH6MNHFIO
HVEOHf=NHemLHEYHGUEEG51BFdU?FDI=FD9;Eci9ESa8ECU7ESQ7ESM8F3U;FS]>GP8nDF405D9FITEJ
JTUOKdiTM5A[NU]bPF9hQfV0SWB9Uh6EXI2Q[:6_^;BnaLO=d]SLgn[Zk?_knoooooKemNg[jnCQh@02
fmSH00[Bc/k:aLG3_Kfl]KFe[Jf_YZFYWijSV9NMTI2HRXTJoooo00Z`Uhf_Uhj^Uhn]V92/V9:/VIB/
ViJ/WIV]Wif^Xj42/:NV01B`ZZZ_ZJ^ZY:JUWj6OVIbHTYJ?RXj6PHImNGmdL7QZJ75THV]MG6IHEf5C
DUe>Ce];CEY8C5U8CEY9Ced2Be5O01E=E6=@F6IDGF]IHg5PJWQXLWi^NHEfPHf1RiJ=UZ2KXj^[/KNl
`<G=cm;Kg=kYjN[hnOWloOgclo;/jNSTgmd00]gFd`0:elk:dLK2c;njb;Vca;>]`:jW_JVQ^ZBL]j2G
]9^B6_ooo`0:a:ZHaZjMb;6Qb[FVc;Z/ckjbd/Bie/[0f]38gmSB0^GRg@0DjNWUi^GSgMcKdm?AbLS7
_Kfl/K6`YZFUVYVJSHj?PX>4N7UkL75cJFY/HV=UG5iQEe]ODeQLDUMLDUQN0U9IG`0EDe]REEiUFF9Y
GVQ_IFieK7IlLgf3NhB:QHjBSiRLW:>WZK2b^;foaL[;d=CFf]kPiNc^j>oah^KVg=gLe]GB00;Bc/T0
2/k7`L_1^LRm/lJh[/FeZLBbY<>_XL>]WL:[V/:YUacoool001[oool02WEfMfm`LFU[K6=UIeePHUMJ
GE5EF4]@DdE;CT16B@8j@DD053Hm@CDm@CM0A3]3Aci7Bd19CT9;D41:D3m:DCm<Dca;Dce=EC]=ESa>
Ec]?FCa@FceBGCmEGd9HHdILIP99GfX05DmUKe=YLeU_NEacOV=iPfQoR6f4SWB;U7nEWHfPYib//Zbh
_Kg5bLkBeMoPhO3^k_Whn?3`l>OWimkOgmKFeP02cLk>00[4aLJl_Kjd]KJ/[JjTYZJMWYnFUiR?T968
RHZ1PX<Joooo00Z?P7n;O7^7NGR3MGEoLW9lKfmiK6aeJFYcIfQ`IFH3KVAU01=^IFI]IFM/IFQ/IFQZ
I6QXHfQSH6IOGFAKFf=EFF9BEf5>EF1<E5m:Dem8E618EF59EV=;F6I=FfT00U1OK00EEF=aFFQeGfik
Hg>0JWZ6L82<MXJBOXjHRIRQV:>/Yk2g]kg3al_?f=WKjNOXn?GdookmmoGek^c/i^?Sg][J00;FdM40
2/k9bLO1`<2i^;Va/K>ZZZfSXjNMW::FUIf@SiR:R1[oool02[6GS[2HSjnHT:jITJjJTjjKUJjLUjjO
VjnQW[6UX`:cZZT05;Ra/[Ze][F`/ZnZ[:VTYZ:MX9bGVYB?U8f8SXF1QgajPGEcNfm]MFYYLFIUKV9S
K61RJf1QK5mQK61SKP9RIG005FEXM6Q/N6ibOG=hPgUoRX26T8N=UXnEWIVOYZJZ/;Bg_<;4b=3Ae=oN
gng[k?Whmogmo?KfmNo]jnSTh^;Kf002fm??00[EblO@a;o<_[S7^;73/Z_0[JJmZ:2jY9^gWiJdVi4J
oooo00[4ZYS6[Yg8/J7:]JK<^Zc?_[;Ba;SFbKoKd<SPf=42i^7L01C_k^_blo7Zj^WPh=oEe]G;bl_1
`L6h]kR][JjRXZ>HV9Z=SY25QXMnP81hNW]cMGM_LWA^LGA/Kg=[Kg<2Jg1e01E]LWM`MGYdNWmjP8Eo
QX^6SI:=TiNDVijNY:JX[K2d^;[0a<K;cm7Ff]_RiNKZkno[l?7Wjn_Qhn;LfmWGe<l00]?=a`0:clNo
c<6ibKfcakV]a[FYaK:Ta:nQ`jfM`j^J`ZVG7?ooo`006_ooo`0:MGIgL75cJfa^IFQYH6=UFeiPEUUL
DEEHC55CAde@0T=9C00D?dI9?4A7?4A8?dM;@DY>ADeAATmDATmEAE1EAE5H@e5IA5=KAEAMAEENAUMP
B5URBU]UBeeWCf5ZDfE^0UMXL@0EG6efHG=kIgV1K7j7LhB;MXN?NhfDQ9FLT9nTWJV^ZkFi^l74b/g?
fMWJj>KVlo;al?3`i^KVgMkNeMKFcLk>00;5a/H02[jn_kJg^:n`/:RYZJ6RXiZKW9BEUHf>ShN8RH62
PQ[oool02Xn1OhamO8QjNHEgMh9dM7mbLWa_KgU]KGM[K7EZJ`9dJFX057AYJgA[K7E[KGA/KW=[KW9[
KW1ZKVeXKFUWK6IVK69SJf1RJeiQJUaQJUYQJe]RK5]RKE]SKUeUL5mXL`9RK7L05FM`NfafP75kQWN2
SH29TXB=UXVBVi>KXinV[:^a][Vl`LS9c=OFenGRho;_kocjn_Whn>o]k>OShmoKf]OCdP02d<_:00[9
`l;2_;^l];Bf[Zf`YjJ[XJ2VViZQUIBLShjGRHPJoooo00ZaV8j`V8n`VI2_VI:_VYB_W9J_WYR`X9^a
XincYj@2]Z^Z01Bi/K6n^KW0^kfk][Rd[k6^ZJ^XXjJRWJ6LV9bFTYN?S9:9QXf3PHQoOHAlNX9jNH1g
MgifMGefMGifMWl2N7R101EkNhAoP8R3QHj:SIJCUIfHVZ6MWjJVZ:fb/[Nl_L38b<[Ee=GRh>7]jn_g
m_Knoooko?cbl>o[inGTg]_Ne]<00]W?bP0:dlS3cl6lb[^ea[J_`k6Y_jbT_:NO^J>J]inF]9^A6_oo
o`0:a:ZHaZjLb;6Qb[FVc;V[ckjad/>ge/Rnf/o6gmK?0^GOf@0Dk>WUm?GcmoShk^o_hn?SfMWHd=3?
b<S7`<30]kNh[Zj_YJFVWIfNUiNHTY:CSXn?RX^<QXR9QHJ8Q8F80XB6R@0EQHR;R8^>Ri2CTiNKVinS
X:BWYZR[[[2b]kZj`<;3b<_;dmGEgN3PiNSYk?3bl?OjkO?ei^SXh>3NfmWEem;<00;Cbl@02/o6_Lc1
]lZl/LRh[<NeZ<FbY<B_X<B]WL>[V/>YUacoool001[oool02WEfMg1aLf]/KVEXJF1SIE]NH5IIG55E
F4aADdM=D093BD`053m6BCa4Aca4B3m7Bd5:CTE=DDI?E4I?EDE@EDEAF4=AFDACFdEDGDEEGTIGH4QI
HTYKID]MIdmQJU=UKP9GJ7405Ea]MV5cNfMiPFanQg>4RgJ7Sg^=U8BEW92OY9fY[Z^e^K_1a<[=cmWI
f^SVi_?blO3`l>KVi]gNg]GFe/g>cP02aLK600Zn_[nf]kR_/;2XZJVQXZ>JVibDUIF=SXn7R8V1PX8J
oooo00Z?PGn<OGb8NWV5MgN2M7AoLW9lKfmiKFegJfaeJV/2M6UZ01AdJF]dJfaeJfedK6icJfibJfi`
JVi]J6eYIfaVIVaRHf]PHV]NHFYLHFYJHF]KHVaKHVeKHfiMIG1OJ7<2HVag01EWL7]/MX1aNhIgPXf0
RI:4SIJ9TY^CVj>OYZb[/KJi_<78bLcGe]OUh^?bknoln_[in?S_kNcWhn?Ofm[Gdm800]3;bP0:bL?2
`[bk_;Bd]Zj]/:NVZj6PYY^JXIFDW8n>UhV86_ooo`0:/IR>/9R?/9V@[iVB[iZD[ibF[ijH/:2K/J>O
/jNT0[J[ZP0D^K6a_[Vi`;^m^kJh]:na[ZV[Z:>VXYfQW9RLUY:GShbBRHJ=Ph68Ogf4O7Z2NWV0MgMn
MWEmMWEnMWIo0WQhP@0ENg^4Oh28PhF>RXfFTiFMV9ZQWInVYZR]/[:g_;g0b<S:eMCEh^3QkN_[moKf
o_oonocll_3_jnOUi=kKg]KC00;IclX02]?8`lo1_<Zk]LJf[l>aZKn/Y;bWWkVSV[NOU[BKTA[oool0
2/BZV<J^W<RaXLZeY/biZlnn/M;3]mK8_][?a]oFc`;UgmT05>cYiOCeloOhn>k_kn?ShmWIf=3@clS8
al30`;Ng^:j^[jFUYYfMWYNGV9:BThj?ShZ;S8J8RHF6R8B5R0:4QXT05HF8RhR;SX^@Ti>GVi^OXj2T
YjJXZjj`/[Nj^/32`lS;bm?EeMgPh>GXjNc`l_3gn^gcmNKXj>3Pg]_IeMOBc002dl_400[?a[g<`KO:
_;78^:c7]JS5/ZC4[j34[Ig3Zi[3ZILLoooo000Joooo00YfMgQaLgA]KW1XJVaSIVQOHVAJGV1FFUaB
EUU>DeH2BU1C01A7CE55Bdm3BTi3BTi6CE58D5E:DeQ<EEY<EU]=Eee<F5m=FV5?G6=?GFEBH6MCHFUD
Hf]GIViKJW5OKGD2I79i01EXMWe^Nh9ePHQjQXaoRXn2SY>8U9VCWZ:LYZVX[k>g^kk6b<WCdm?Pg]k]
jn[/k>_Shn?Kfm_CdmC<c<c4aLD00[fn_`0:]kNh/;6aZJZ[XjBUWIjOUiRITI:CRhb=QXN7P8626_oo
o`0:T860SGimRWakQgUhQ7MfPWAdOg9bOG5aNfm`NVi_0gU^K`0>NFm`Ng5bNg9dNg9dNG5dMg5dMW5e
M71eLfmdKfidKVidKFieJfeeJfif0V]^M`03K71iKW=kLGEn009dNH405GQmQGf1RH>8ShV=U8jAUi>G
W9ZNXjFW[:j`];Vj_LO6b=GBdn;Ng^kYjOWemOSemNk[jnKSh]kJf]OBd]3;bP02b/C300[4_Kbn][Fh
/:ncZZV^Y:>YWYfTVINPTi:KSXfGRHLJoooo00ZaV8jaV8n`VI2`VY:`ViB`W9JaWYRbXIbcXineYj@2
]j^Y01Bj/Jnn]kK3_[o4`<;0^[bi];Jc[[2^ZZf[YZVVXJFQW:2LV9fHU9VDT9JASI>>Ri6<RI2;R8n<
RHn<RY02SXbB01F@SYBCTINIUibNW:6TXJB[Z:^b/;>k^K_4`/?<b/_GeMGSh=o]jn[hm_Goooomo_kd
lo7]jNOVh=gPf=GKdLd00]G:a@0:dLBnc;jhb;RbaK>/`JnW_ZZR^jJN^J:I]YjE]9^A6_ooo`0:a:ZH
aZfLb;6Pb[BUc;RZckb_d/6eeLNkfLg3g]C;0^?Ke00DjNCOl>kZn?Whn__kl_;ainOVgMgLe]KEdM3@
b/W9`l;1_;^j];Bd[Zj^ZZRYYJBUXZ6QWijOWIfNW9bM0YbLWP0EWIfOWYnPXZ>TYjNX[Jb/]KFd_;bl
a<C3bl_:dM7AfM[IhN;QjN_[lOCemO_nl_Skjng]i>CRgmcIf]G@e/o800;BbL402/o4^lfo]LZk/<Rh
ZlNeYlJbXlF_X<B]W<>[VL>YUacoool001[oool02WMgN7=dMFi`LFY/KVIYJV9UIemRI5]OHEMKGUAI
F`9AEUT054mDEdeCET]AEDU@E4UAE4eEFE1HGE=KH5ALHEANHeAOIEIQIeYUJeaWKEeXKeiZLF1/Lf=^
MFMbN6]eN`9`NWl05GAmPWV2Qgn7S8>;ShR?TXRAUHnHViVQXj>Y[;2d][o0`Lg<c=[Gen?QhNGUi=gM
gMKFe/o@d<W9bL;2`kbl_@02][Jg00Z`/;6ZZZ^TYJFNWj2IVY^DUIF?Si2:RX^5QHJ0P84Joooo00V@
PH2=Ogj;OGb9NgZ6NGR4MgJ2MGF1M7AoLg<00gibLP0DOG9cOW=dOgAfP7IgP7MiPGQjPGUlP7UlOWQm
OGUmNgQmO7UnOGZ0OG^0OG^1O7^1O7^2OGf4Ogn5PH680XF5R`0ER8R>SHfATI2EUIBHVYVLVi^OXZ>V
[:b^][Fg`l32d/g=g]SHjnCSlng]m?3_jnSWi>3OgMSGe]3@d<W9bL?200;4_;`02[jf]KV`/;B[ZZnU
Y:^PWjJKVZ:FUIjBT9Z=RiJ8Qa[oool02[6HS[6HSk6IT;6JT[6KU;6MU[:NV;:QVkBSW[JWX`:hZjL0
5;^_[Kje/l:j^/K1`/O3a<Bo`;nj_;Ze]kNa];B_/k2//:jX[:bWZZZUZ:NRYJBOXj:MXJ6LX:2KWj6K
X0:SWJ805JFOXjNRYJVTYZfWZ;6/[;B_/;^f]l>o_lc8b=SCdn?Og^gYj?Ocl_klo?gmo?GclNkYinOQ
g^7IeMcBcMO;aP02d/Fo00[>_kW:^[?6]Jk3/JW0[:BmZ:2kYIbhXIRfWYBdVY0Joooo00[4ZYS6[I_7
/9o9/j?<]jS>^jgA_k;Da;SHb[oLd<H2hMO?01?Vg]S/in;bkncin_Wko?_dm??[jn[Sh^;MgMgIfMWD
e=C?c/g<bLW8aLG3`<2n^kZj]kNg];Bd/[800k>`/00E];6a]K:a]K:`]kBa^kVe_kbja<;0c<[7dm;@
gMcJiNGTk>g/loGdn?gnmO[lk_7`j>OUh]oKgMSBfM7;eL_300;Aa[d02/o2]lbm//Zj[LRfZLNdYLJa
X/F_WlB]W<>[VL>YUQcoool001[oool02WMhNGAeMW1bLfe_L6U/KFIYJV=VJ61SIEeQHeYNH@9HG5l0
0eIKGEAIG5=HF`02DEMK00mBFEeEG65IH6ELHfQMIFYMIV]PJ6iSJg5UKG=XL7EYLWQ[LgU^MW]bNGmf
OH400W^1Q@0EOXB7Q8R;QX^>SY6CSi>FTYNIVinPXjJX[[2a^[ZjaLC4d/o>g=WIfm_Ke]KFd=3@b/[:
a<C4_[jn^;Vi/k>d00:][Zh02ZRYZJ>TYIjOX9ZJViFFUY2ATXb=SHR8RH>4QGn0P1[oool02Y22P8j0
OhanOHYlNhQkNXMiN8EhMhAgMX=fMX9eM@:1MGH03h5fMX9gMh=hNHAjNhIlOHMoP8MoPHR0PhR1Q8R1
QHN1QXR3QhV4R8V4RH^6RP02RhN<00><R8f?RXnASI400YB@T`0EUi:EViJIWIRKXijOYJ2RZJBV/Zb]
^[FeaKjndLW8f]?Bi]gLk^SWkNSXin;Qgm[IfM?Bdlc<cLK5al2o`[Zi00:m]K@02[R_[kBZZK2VYJbQ
X:RLVjBHUj2DTif@SYV<RYJ8QQ[oool02[6HS[6HSk6IT;6JT[6KTk:MUK:NUk>PV[BSWKJVX@:hZJD0
3KZ]Z[fb[l6g]/Fm_L[5a/_7bLS2a<Bn`<6k_[nj_;jh^kbf^KZd]`02^;6d00Fg/;>e[[6d[:nd[:ne
[Jl00[J^[`0E]jj_^K6a^k:b_[Fd`KRgaKflcLG3eLg;gMKDin3Nk^WWm_7_oO[ino[im?7_kNOUi]oL
h=SDfm7<e/[5d/Fo00;>_kT02/Zj]<Nf[lBaZ/6]Y[jZX[bVW[ZSV[NPUkFMTk>JT1[oool02/BYUlF/
V/N_W/VbX/^eY/fiZ/nm[m;1]=G6^]W;`@;MdLP05>;Hd>OOf>gWh_?`k?[kn_cmoOGem>g]k>SWinGT
i>;QhMoMgM[GemOCdmKAdM??c]3;b/c8a/_6a<[5``;8`l405LS3`<W3`LW3`<[4`<g7`m;<b=WCcmoJ
e^KRgng[j?;akoKgm_[no_SloO3blNWYi^CPg=oIdm[BbmK=a=?7_P02d<>h00[>_k?;^jo:^:_8]JO7
/ZC6/:35[Yk4[9_3ZYW3ZIHLoooo000Joooo00YhNGYeMWMbLgE_LG9/KW1ZK6eWJV]UIfURIFMPI6H2
GV9T01AMHF=KH69JGf9IGV5IGf9IH6=NI6QPIVYRJ6eSJVmVKG9ZL7E^M7QaMg]aMgabNGefNh1jOX9k
Oh=nPXD2PXF701F5R8^9Rhb;SXnCU9BDUINIVi^PXJ:XZJZc/[:m^k_3`/;AcloAd=7;bl_7alO2`/:m
_Kfh^;Rc/kB^[jnZZZ/00ZFVYP0:XJ6RWIfNVIVJUIFFTI6BSHj>RHZ;QXJ7PX:3OWn06_ooo`09TH:1
Sh5oSGmnS7imRWakRG]jR7YiQgUiQWUh00>5N7P04HEiNHEjNXIkNhQmOHUoP8f3Q9:8RY68RY27RXn7
RY29SI><SiN?TYR@TiN?TiJ@TiZBU@02WIBF01RMU9NOUYROUYRQVIZTVi^UWIf[XZ:]Y:BcZZVi/K31
^KS;`/7EblWKd]7Vg]gUgmkNf=OId]7Cc<_>a/G9`L34^kZo][Fk/[02]Zf/00ZbZJN_Y:>[X9nXW9^T
VINQUIBNTI2KSXbHRXVEQhDJoooo00ZaV8jaV8naVI2aVY6bVi>bW9BcWYJcWiVdXI^fY9h2^:NR01Bj
ZjJl[j^o/k33^;K7_kk=alOBcLo@b/_:a<G6_l76_l;8`LC:`lC9`/?6_l34_;k6_Kk8_[k6^k_3^KP2
`kRg01G4^KO5^KO5^[O8_KW:_kc@a<7FblSMdm3Ug=W]i>7bjnShlo;flo;_j^SYhmoTfmONe=3Ic/WE
b<;A`kg=_[L00/Zi/P0:akF^a;6Z`JfV_jZR_:NN^ZBK^:6H]inE]IbB/iZ?6_ooo`0:`jVGaJ^JaZjM
b;2Pb[>Sc;JWc[Z[d;f`dl:ee/Jj0]W;`00DgM77h]O>imkGk>KPl^kZnoWhoooono[jlO3_jnWXj^OW
j^SXjnSWjNGTiN7PhMcKh]cJh]cIgmOCf];>0]O?b`0Eelo:e/k9e/k7e/k8f=3:gMG?hm_Ej>;Mk^WU
m>o/moGbn?[im_Shkno]j^OSi=oJgmSAfm;:elc3e<NmdL>h00;>_k<02/bk[lZhZlVfYlNcY<JaXLF_
WlB]W<B[V/>ZV<>XUQcoool001[oool02WQiNWIgN7AeMW9cM6maLVe_LF]]KfU/KFMZK6IYJP9TIfT0
0f=VJ69VJ65UI`02HFEX00mRIVYSJ6aVJfiXKG5/LGE_MGUcMg]eNGegNgihO7mkOh9mP8=nP89nP8>2
Q8H00XF6Q`0EQhV:RX^;Si2@Ti>DV9NGWIbLXj>SZj^[/[6a^[Vi`<71a/G5`;o0^k^l]kRh/kBd[k2`
[:b/Z:RYY:BUX:6Q00:MWIh02YVJViJGUi>CU92@THb=SXV:RhJ7R8>4QH61PWinOa[oool02I62PI21
P8j0OheoOXanOH]mO8YlNhUlNhUkN`03R7]k01B8O7^9O7b9OGf;Ogn<PH:?Q8FBR8VFS8fGSHnISi6J
TI>LTYBMU9JNU9JOUINQUiRRUiRQUYJPUIJSV9P2Y9VH01FUVYVWW9Z[X9n^Xj:bYjFg[J^n];;5_;_<
`/7Bb/WId]7LeM?EcLc@b<O;`l;6_[g2^KRn]KBj/Jnf[J^cZJL00ZnUY00:[:6PZIjMYY^IY9RFXIFC
WY:@W8n=VHb:UhV8UHJ56_ooo`0:/IR=/IR>/IV?/YZ@/YZB/Y^C/ifE/ijG]:2I]J:K0[NTWP0;^JNR
^j^V_JjZ`;>_a;Reb;jlcLG3d/_;dlc<d<W9clO700;?a/L01lo5a/o5aM35a<o3`Lbo_L^n^l^n^P02
b[fh01G9^kO9_;K<_k[>`KcAa;oFb/GLdLgSf=GXg]_/i>;ak>[ak>WYh]oTfmOOe=3Jc/WFbL?B`kg>
_kS;^[C8]Zl00/FcZ`0:`jnX`:bT_ZVQ_:NN^ZBK^J:I]inF]YfD]9^A/iV?6_ooo`0:`jVFa:ZHaZfK
ajnNb;6Qb[BTc;JWc[V[d;f_d/2c0]G5^00DfLVng<k4h=C:iM[Bj^7JknWSmO7]noWfnoWgmO;`l^g[
kn_Zkn[YkNSVkNOTkNGRj^7LimgGi=[DhmSA0^3Fc@0EgM;9g=78gM?;g]C<h=K?i=_DjN7Kk^SSl^gY
m?3^n?OfmOCbkN[Vin;Mh]_Dg]G=f/o6el[0e<JkdL6fc[ja00;<^jh02/^hZ/VeYlRcY<NaXLJ_WlF]
WLB/VlB[VL>YUl>XUAcoool001[oool02WUjNgMhNGIgN7AeMW9dMG5bM6maLVi`LFa^L6]]K`9ZKFh0
3FU/KVQ[KFQ[KFQ[KFQ[KVU/KfY^L6a`LVibMGEiNgQkOgUkOWanP002OX230Wn0P`03Oh63PX>5QHJ7
00:6QhP05H^;Rhf=SI6@T9BCTiRGUibLWJ2QXZZZZZj_[k>c/kBe];6a/Jj^[j^[[:RXZJFVYZ:SXinP
X9fMWIZJViNHV002U9FF00ZBTY>?T96=SHj:Rhb8RHV6QXN4Q8F1PX=oP81mOGhJoooo00JAPh6@PX2@
PH2?P7n>P7j=Ogh2S7im1H]nO@0?RginS7moSH60SX:2T8F5ThN7UXZ;VXn?XIJFXiRIXYJGXYNGY9VJ
YIRIY9RH00:SUiL06JBHV:JJVJNKVZNKVZZNW:bOWJjRX;6TX[BXY[N^[;bb/LBk^/[1`<g5a<g5`lRo
_/Bk^/6g][fc/[Z`[[J/Zk>YYk2VY:jSXJ^PWP02Z9fK00ZVVYVTV9JQUIBOTi6MT8nKSXfJS8ZHRXRF
R8JDQX@Joooo00ZaUhfaV8jbV8nbVI2bVY6bVi:bVi>cWIBdWYJeX9P2]Z6J00fgY9fiYZ2kZJ>m[JO0
/:c3]K77^[K;_kcAa/?GcL_Hc/cDbLOBa/@00]C7aP05d/C2d<6nc[nlc[nlcl2k00;?`;X2d<6k01?A
`[cBa;kDal;Gc<OKdLgQf=GWh=gZhn3Vg][Qe];Ld<_Hb/GDaKo@`K[=_KK:^K;7]Jk5/Z[3[jL00/6/
Y00:_jZQ_JNO^jFL^Z>J^:6H]inF]YfD]IbB]9Z@/iV>6_ooo`0:`jREa:VGaJ^IaZfKajnNb;6Pb[>R
bkFUcKRXckZ/0]6n/00Ddl6de/FhfLVmg<k3h=?9i=W@jMoGk^GNmNkXnOC_n_C_m>gXl>SSl>STl>OS
k^?NjmoIimcEim_Dim[B0^KId00EiMW?i=S>hmO>hmS?i=_BiMoGjN;LkNSSlo3]m?;^kn[Uj>7Khm[C
gmC;flo5f<ZoeLJjd/:fckjacK^^c;RZ00;:]ZL02/VdYLRbX/J`X<J_W/F]W<B/VlB[VL>ZV<>YU/:X
UAcoool001[oool02GYkNgQjNWMhNGIgN7EfMgAeMW=dMW9dMG5cM003L79c011_LG=_LG9^LG9^LG9^
LG=_LW=`LgEaM7IcMWQfNG]hNgekOGj1PX>1PhB0PH>1PX@2P8:401V2Q8F3QHF5QXN5QXN8RHV:RXZ=
SHf?ShnBTi>KVi^NWYjRXZ:QXZ:PXJ6PX:6OWinMWIjKVibIVIZGUiREUYJCU9BATY:?T96>SXl00Xb<
S@0:RX^;R8V:QhN8QHJ7Q8B5PX>3PH62Oh20OWioO7em6_ooo`06TXB2TH>1TH:1T8:0Sh60Sh5o1hj0
O`0CSX20SX60Sh:1T8>2THF4ThJ6UHV8V8b;Vhn>WY6AXIBCYIVGYIVHY9NFYIRGY9NHXYJFXiNFXiNE
00:TV9H05JNJV:RKVJZMVj^OWJjRX;J[Z[Z`[[fc/K^a[kV_[[R^[;J[Z[BYYk6VYJnTXZfQX:ZOWJRM
VjJJVJFHUj>FU@02XIFC00ZPTi6NTI2MShjKSXbJS8^HRhVGRHRFR8JEQXFDQH<Joooo0[6HSP08/YR>
/YR?/YV?/YV@/YZA/i^B/ibC]9fD0[BNUP0D]J2H]j6J^:>L^JJO^jRR_Z^U`:nY`k:]a[JabKZec;fh
cl6kd/BndL>mcl6ld<6mcl2mcKfjbk^gb[Ze0/^j]00Ebk^dc;becKbfcKffcl2ie/S3flo;g=7;fLc7
e/W3e<JodL6kc[fgbkZcbKJ_a[>[a;2X`ZjV`:^S_jVQ_JNN00:lYI`02[ZSV[VRVKRPUkNOU[JNU;FM
TkBKTKBJT;>ISk:HSQ[oool02/>XU/>YUlBZV<F[VLF/V/J]W<N_W/R`X<VbX/^dY0;<]ZL05<jiZM2k
[=:n/=C1]=K5^=W8_=c<`N3Aa^?FbnKIcnSLd^cQe^gRfN_Pe^[NeN[Ne^WMeNKIdN;Ec>3Cb@;Pd/L0
5N3Aa^3Ban3BamoAa^3CbNGKd^_Sfn[Rf^KLe>?Hcn3Cb]c>a=W:_]K5^M?2]M6o/Lnl[/fiZl^gZ<Ze
YLVcX`02b;6Q00[7/9o6[Yk5[Ic5[9_4Zi[4ZYS3ZYO3ZIK3Z9K2Z9DLoooo000Joooo00EjNgajNW]i
NW]iNGYhNGX00WMhN@=fMgP2MGIh1GEfM`0:MGIhMGMhMWQiMgUjN7YkNW]lNganOGioOWn0OWj00Wio
P003Oh21Ph>3Q8B400:5QHH01hN7QhR8R8V9RH^;Rhf=SY2@THf>SP02SXj?0Xf>SP0:SHf>S8b=Rh^<
RXZ;RHV:R8R9QhN8QXN7QHJ6Q8F50X>4Q@0:PX>4PX:3PH62P861Oh21OWn0OWioOGenO7enNgam6_oo
o`04TXB2TX>2TX>1TH>10Y62P@J@PX03T8:100ZAPh:AQ8:BQ8>CQHBDQXFER8NGRHRHRhVJS8^KSH`2
W8j=00FLShfLShjNTHnQU96RU9800Z>FT`06Y9NEYIRFYYVGZ9ZHZIfKZijL0ZNKV@0=YiZIYYZHYIVG
Y9RFXiJEXYFCXIBBX9:AWY6@WI2?W8n=W8j<Vhf;00:JS8/02YV;RYR:RIR:R9N9QiJ8QYF7QYF7QIB6
Q9B5Pi>4Pa[oool00k6GSK6HSK:HSP03/YR>0[:IS`0@/YZ@/iZA/i^A/i^A/i^B]9bC]IfD]YjF]Z2G
^:6I^J>K^ZFM_:NO_JRQ_jZR`:bT0l6]Y@05`ZjV`ZnWaK6YakB[akB/00;8]Jd05LRe[/Vf[/Vg[lZh
/L^j/lZh/LNd[LJcZlFbZ/B`Z<>^Y/6/Y<2ZX[jXX;fWW[bUW;^TVkZRVKVQV;RPUkNOUP02]ijE00Jf
WIBeWI>eW9:dVi6dVY2cVY02/iV?00>bV8jbV8goool06Oooo`0:`ZRE`jRE`jRF`jVFa:ZGa:ZHaJ^I
aJbJaZfKaZjL0/N_W@0<b;2ObK6Pb[:RbkBTc;JVc[RXckZZdKb]dkj_e<2aeL:cel>e0mO4]@05elFf
f<JhflVjg<Zlg<^m00CLbkh04mg<_mg=`Mg=`][9_MO5^=G4]]C2]=:o/M6m[lnk[<fhZLbfYl^dYLVc
XlRaXLN`WlN_W/J^WLF]W002aJbJ00[4Zi[4ZiW4ZYS3ZYO3ZIO3ZIK3Z9K3Z9G2Z9G2Yi@Loooo003o
ooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00@oooo`<0001Loooo0`0005[oool3
0000F_ooo`<0000aoooo0016oooo00<0003oooooool0G?ooo`030000oooooooo05[oool00`000?oo
ooooo`1Joooo00<0003oooooool0;_ooo`00:oooo`<00004oooo0P0000Coool400000_ooo`<00003
oooo0`0000?oool20000>?ooo`D000000oooo`0000000003000000?oool0000000000P0000?oool4
00000_ooo`<00003oooo0`0000?oool20000=_ooo`D00002oooo0P0000Coool200001?ooo`@00002
oooo0`0000?oool300000oooo`80000foooo1@0000;oool200001?ooo`800004oooo100000;oool3
00000oooo`<00003oooo0P0002_oool002goool01@000?ooooooooooo`000002oooo00@0003ooooo
ool00002oooo00@0003oooooool00005oooo00@0003oooooool0000ooooo00<0003oooooool00ooo
o`050000oooooooooooo000000Goool010000?ooooooo`0000;oool00`000?ooooooo`03oooo00@0
003oooooool0000moooo00D0003oooooooooool000000_ooo`040000oooooooo00000_ooo`040000
oooooooo00000_ooo`040000oooooooo00001Oooo`040000oooooooo0000?Oooo`050000oooooooo
oooo000000;oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`00
00Goool010000?ooooooo`00033oool002coool300000_ooo`040000oooooooo00000_ooo`040000
oooooooo00000_ooo`@00002oooo00@0003oooooool0000ooooo00<0003oooooool00oooo`030000
oooooooo00;oool00`000?ooooooo`02oooo00@0003oooooool00002oooo100000;oool010000?oo
ooooo`0003goool00`000?ooooooo`03oooo00<0003oooooool01?ooo`040000oooooooo00000_oo
o`030000oooooooo00@00002oooo00@0003oooooool0000moooo00<0003oooooool01?ooo`040000
oooooooo00000_ooo`040000oooooooo00000_ooo`030000oooooooo00@00002oooo00@0003ooooo
ool0000`oooo000[oooo00@0003oooooool00002oooo00@0003oooooool00003oooo0`0000?oool2
00001?ooo`@0000noooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`02
oooo0`0000?oool200001?ooo`@0000loooo00<0003oooooool01?ooo`040000oooooooooooo0P00
00Coool300000oooo`800004oooo100003coool00`000?ooooooo`02oooo0P0000Coool200001?oo
o`<00003oooo0P0000Coool40000;oooo`00:oooo`040000oooooooo00000_ooo`040000oooooooo
00001Oooo`030000oooooooo04Woool00`000?ooooooo`03oooo00D0003oooooooooool000000_oo
o`030000oooooooo00?oool00`000?ooooooo`17oooo00D0003oooooooooool000000_ooo`050000
oooooooooooo000000Ooool00`000?ooooooo`17oooo00<0003oooooool00_ooo`030000oooooooo
00;oool010000?ooooooo`0000Goool00`000?ooooooo`0joooo000/oooo0`0000?oool200001Ooo
o`80001:oooo0P0000Coool200001?ooo`800005oooo0P0004Soool200001?ooo`800004oooo0`00
00Coool20000B?ooo`800004oooo0`0000?oool200001Oooo`80000loooo003oooooTOooo`00oooo
oi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooo
oi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`006_oo
o`04G6idG6ieG6ieG6ie1Ee_M@04GFmfGVmfGVmfGVmf15i`MPAOL7L2Gg1f00IOL7EOKgAPL7IOLGMO
LGQOLGL5Gg9h00MOLGQOLWQNLWQOLWQNLGQOLWQNLWP00UmcN@04Gg=jGgAjGgAjGgAk0V1eO006HGIm
HWR0HGImH7ElH7AkGg=j0emcN@09GW9iGW9hGW5hGW5gGG1gGG1fGFmfG6meG6ie01[oool7JG5d2fYa
L`09JW5bJg5bJg5bJg1bJg1aJfm`Jfi]Jg1aJg5b009[LG<00f]bM6YaLfYaL`04JW5c01=YLG=ZLG=Y
LG=ZLWEZLgEZM7I[MGM[MGQ[MWU/MgY/N7]]NGa]NWi^O81`OhA^Ngm]NGe]N7a/MgX00VafNP06K7Ii
JgIiJgEhJgEhJgAgJWAg0VYcMP03JW9eJG9eoooo01Woool3KgAe0VmcM@E_Lg@6Kg9c0VmbLP9_LG82
Kg5a00M_L71_Kfm_KFa`L71`LG9`LW=_LG800VmbL`03Kg5cKg5bKg5b00=^LG82KW5c00A^LgA^LgE_
MGI`MWP2L7Mi00YaN7YaNWabNgicO7mdOX9fPXIdOX5cO7icNWebNG`3LWQk00EaN7YaMgUaMgUaMWQ`
MWP00W1eM`03L7EfL7Afoooo01Woool2LgIg00=cMGMcMGIcMGH00W=eMP03LgAeLWAeLWAe009bM7@3
LW=d00=bLg=bLW=bLW<00W9bLP0<LW5bLW5aLW1`LW1_LFi/LW1`LW5bLW9cLW5bLW9cLG9cLG9b0g5a
LP9`LG82L75c011`LgE`M7EaMGMbMWQcMgUcN7YcNG]dNWeeO7mfOX1gP8AjPhQgOh9fOH1fNgieNgd3
MGYl00EeNG]dNG]dN7YdN7YdN7T00WAgN@03M7MhM7Ihoooo01_oool001[oool01Ea^M5a^MEe_MEe_
MEe_MP03GW1f00YOL7MOLGMOLGMOLGMPLGMPLGQPLWQQLWQQLWUQLgT3HW=i00ISLgUSLgQSLWMSLGES
LgQSM7X2HgEk0f9eN`9RMW`00f=fO69fO69fO003HWIl00mQMgeRN7iRN7mSNH1SNX5SNh5SNh9TO8=T
OHAUOHEVOXIUOHATNh=SNX5SNH000V9gO`0:HWMnHGImH7ElH7AkGg=jGg9iGW9hGW5gGG1fG6me6_oo
o`9YLG@00fUbM6YaM6YaL`04JW5c00AZLG9[LG9[LG9[LG82Jg1b0V]`L@9/L742K71`00I]Kfm]Kfi]
KVe]K6Y]KVi]L702KG5b00=/LW=/LG9[LG800V]aL`0EK75bJg5bJW9cJg9cJg9dJgAfJgEgK7IiKGQk
KGUlKW]nKgb0Kgj2L824LH:7LhF;MHN=LX>8LH25L7j3L7f1009_Ngl02VikOVijOFeiO6ehNfagNVaf
NF]eN6]dMfYcMVYbMA[oool016mdMFmcMFmcMFmcM09_LW@2Kg9c16maLP04Kg5aKg1aKg1`Kg1`0fm_
K`0=Kfi^Kfi]Kfe]L6e[L6]YKfUWL6a[L6i^L6m_Kfm_Kg1`KVm`KVm_009]Kg005Fi_L6e_L6a_L6e`
LFe`LVebM6ecMFmfN71gNW5iO79kOG9mP7=oPWF2QWN5RGR8SW^:T7R5RWJ2QWF0Q7EoPP02M7f000Yd
O7mcNgicNWebNWabNG]aN7YaMgUaMWQ`MGM`MGHJoooo00YcMWMcMGIcMGIcM7EbM7EbM7AbLgAbLW=a
LW=aLG83LG5a00=aL71aKg1`Kfl00W1^KP09L6i]L6e]L6a/L6a[L6]YL6YXL6QULF]YLFa/009`KFd0
0g1^KVm^KVi]K@03KVa]01A]K6e]KFi]KFm]KW1^L79^LWA`M7IaMWQbN7]cNWadO7mdOh9gPXIiQHUk
RHmmRi5jQX]iPhMhP8AgOh82MWj100IfOH1fO7meNgieNWeeNWaeNG/2M7Qj00=dMgUdMgSoool06ooo
o`006_ooo`03G6idGFieGFme009NL7H01Em`MUmaMf1aMf1bN65bN002HG=i0V9cN@06Hg=jHgAjI7Aj
I7EkIGEkIGIl0VIfO006IgIkIgEjIgAhIgIlIgMmIgQn0VIhOP03IGUoIGQnIGQm009UN7d056AhOVAi
OV=iOV=iOV=iOf=jP6AlPVEnQ6IoQVN0QfR1R6R2RFR3RfV4S6V5SVV4S6V3RfR1RVN0R6InQP9UOHD0
2VElPfAkPV=iP69hOf5fOF1eO5mcNUibNEiaMee_MQ[oool00fUaM6UaLfYaL`03JW5c00=ZLG9[L79[
LG800f]`L@9/L742K71`0fe_K`08KVm_KVm^Kfm]Kfi/KfeZKf]XL6i/Kg1_0VmaL@03KW5bKG5bK75a
009/L7405Fe`LFaaLF]bLV]bLf]cMF]dMV]fN6eiNfikOW1mP75oPg:2QW>4RGB7S7J:T7N>UGN<TgJ9
SgF6S7B4RG>2Q`02LX2500YaOh=`OX9_O81_Ngm^NGe]N7]/MgY[MGQ[M7MZLgHJoooo00M_LgE_LgA_
LgA_LWA_LW=_LW9_LG800Vm`L@04Kg1`Kfm`Kfm`Kfm_0Vm^KP0=Kfe]Kfe/Kfe/Kfa[KfaZKf]ZL6YX
L6YWL6QUL6IRLFYWL6]ZL6e/009_KFd06Fi]KFe]K6a/KFa/KFe/KFa/KF]]KV]_L6a`LFabLfecMFif
NG1iO75lOg=nPWB1QGJ5RGR8SGZ<TWfAV7f@UW^<TGV8SWR6RWN4R002MX:600YfP8AeOh9dOX5dO7mc
NgibNWabNG]aMgYaMWQ`MGLJoooo00UcMGMcM7IbM7EbM7AbLg=aLW=aLG9aL75`L7000g1_K`0DL6i^
Kfe]Kfa/Kf][Kf]ZKfYYKVUXKVUWKVQVKVMUKfISKfAQKf=NKfISKfMVKfUXKVUYKVYZKFUYK6UY0V]X
J@0EK6QYJfQYJVUZJf]/K6e_K6maKG1cKW=fKgIiLGUlLWaoM7n3MX>7N8N<Nh^AOY6HOY2FO8^ANXR=
NHF9N8>7009hPHD02WN0PgMoPWInPGImOgElOWEkOGEjO7AiNgAhNWAgNAcoool001[oool02Ua^MEe_
MEi_MEi`MUm`Mf1aMf1aN65bN69bN69cN@9SLgX056=dNVAeNfEeNfIfO6IfOFMgOFQhOVUhOVUiOfYi
Of]iOV]iOF]hO6]jOf]kP6YkPFYlPVUlPVQkPFMjP09UNGh2IGQm01=TNGiTNX1TO85TOH=UOXAVP8IW
PXQYQ8]ZQHa[Qhi[R91/RY9]S9E_SiQ]S9E/RY=/R95[QXiZQ8`00VV2RP0:Ih28IWj6IGf4I7^2HgV0
HWMnHGElGg=jGW9hGG1f6_ooo`06JG5dJW5cJW1cJW5cJW5bJg1b0f]`L@04K6m`K71`K71`K6m`0Ve_
K`0AKVm_KVm^KVm^Kfm^Kfm]L6i]LFi/LFe[LFaYLF]VLVi[LVm^LG5`LG9aL75aKg5aKG5`009/L702
K6m_01=ZL71[LW=[M7E[MWM/N7Y]Nge_OX5aPHAcQ8MdQh]fRY1gSIAjTYUlUimkTiYiSiIhS9=gRY1f
Qhd00WF5RP0:M8>8Lh66LX24L7j2Kgb0KWYnKGQlK7MjJgEhJW=f6_ooo`0:Kg=eKg9dKg9cKg9cKg5b
Kg5aKg1`Kfm_KVm_KVi^0Vi^K@0DKVe]KVa/KVa[KV]ZKV]YKVYYKfYXKfUWKfQVL6QUL6MSL6IQL6AO
LFMTLFUWL6]YL6][Kfa[KVa[KF][0V]ZJP0EK6YZJfY[JV][Jfe^JfmaK79cK7AfKGMjKg]nLWn2M8:6
MXJ:N8Z?NXjDOI>JPIVROiFLOI6HO8jDNh^@NHR=009hQX/02WR4R7N3QWJ1Q7EoPWAmP7=lOg=jOG9i
Ng5gNG1eMa[oool02W=eMW=dMG9cM79cLg5bLW5aLG1`L71^Kfm^KVm]K09_K6`056i[JViZJFiYJ6eX
IfeWIFeVI6eUHfeTHVeSH6eRGfeQGFePFfiNFFiQGViSHFeUI6eVIFaVIF]VIVYVIP9YIFH05FYUIVYU
IfUWJ6UYJVY[KFY]Kf]_LVacMFifNW1jOW9nPWB2QgN7S7V;TWfAV86GX7nCVWf?UWb<TW^9SWZ7R`02
NHF900YhPhMhPXEgP8=gOh9fOH1fO7meNgeeNWadN7YdMgTLoooo000Joooo00EMKWEMKgENKgEOL7IP
LGL00V5bN003HW=iHg=jI7Aj009UMG/02VEfO6IfOFMgOFQhOVUiOfYjP6]jP6akPFelPVimPP9_OH80
16mlP6mmPfmnQFioQ@9]OhD06FaoQ6]nPfYmPVYmPVUlPFQkP6MkP6MlPVMnQ6MoQVN1R6R3RVV7SF^9
T6f:TVj=UFn@V72AVW:CWG>EX7:CWG6@VVn>Ufj<UFf9TP02K8N@00YZQHeYPh]XP8UVOXIUO8ASNX5R
MgmPMGaOLgUML7LJoooo00EYLGAZLG=ZL79ZLG9[L7800V]`L@03K71`K6m`K6m_00=]Kfl2KVm^0Vm^
K@9`KV`03G5^K79^Jg=^JW=]JWA]J7A[IWA^JgA`KW=aL7=bLG9bLG5bLG1aL@02Kg5`01E^L6m]Kfm/
L71/LW9/M7I]MWQ]NG]^O7m`PH=bQHQdR8agS95iT9IkU9]nVJ60WJInVJ5mUIekTYUjSiIiS9<00WN:
T00:MXN=MHF:M8>8LX65LGn3L7b0KWYnKGQkK7IiJWAg6_ooo`0:Kg=dKg9cKg5bKg5bKg1aKg1`KVm_
KVi^KVe]KVe/0Vi/J`0DKV]ZKV]YKVYXKVUWKVQVKVQUKVMTKfISKfIRL6EQL6EPLFAOLF9LLVERLFMU
LFUWL6YYKfYYKVYYKFYZ0VaYJ@9[JFT04fYZJV]/KF]_L6]aLfadMfehNVmmP7:1QGB5RGN:SgZ?UGfD
Vh2JXX>OZ86JXX2FWGjCVGf@UWb=TP02NXZ?00YiR8ehQXYgQ8QfPXEeP8=dOX5cO7ibNWaaN7Y`MWPJ
oooo00YcMGIbM7EbLW=aLW9aL75`Kfm_KVi_KFa^K6]^JVX2KFUX01=]J6M/IfE/IVA/I69[Hf5[HUm[
HEi[H5a[Ge][GEU[G5Q/G5I]FUA]GUY]H5e/HF1/HV5[Hf9ZHf<00fUSH`0EJ69SJ6=TIfAUJ6IXJ6U[
JF]^JFmaJW9eKGMjKgb0LX24MHF:N8Z@NXnGOYJNPY^TP9JOOY>JOHnFO8bBNhZ?009jR8d02WV6RWV4
R7R2QWN1Q7MoPWImP7IlOWEjOGEiNgAhNAcoool001[oool02Ue^MEi_MEm`MV1aMf5bN65bNF9cNF=d
NVAeNfEeO09VMW`056MgOFQhOVUiOfYjP6]kPFalPVimPfmnQ71oQG:1QW>2QgB2QgB1QWB2Qg>2R7:3
RG63RG23RG22R6n2R09^PXL05Ff1QVb0QF]oQF^0QV^2RF^4Rfb6SFb8T6f;Tfn?Ug2AVG:CW7BFWgFI
XWJJY7NKYWJIY7FGXG>DWW:BW76?V@02KhbF00Y]RI=/Qi1ZQ8eXPHYWOhMUO8ASNH5QMWiOM7YNLGLJ
oooo00AYLG=ZLG=ZL79[L782Jg1a00A/L71/Kg1]Kfm]Kfl2KVm^00=^KVi_KVe_KVd00W1^K00?LFe[
LVe[LVeZLfeZMFiYMViYMfiYN6eWMfm[Mg5^MW9_MG9aM79aLg=aLW9a009aLW405G1bLFmaL6mbLFic
M6mfMfmhNW1lOW1oPW:3QgF9SGN=TGZAUWfFW7nKXX:PZ8>QZh6NYh2KXgnGWgfDW7bAV002NXjE00Yi
S95gRHifQhadQ8QcPHEaOX=_O81^NGe/MgY[M7LJoooo00Y_LgA_LW=_LG9_L75_L71^Kfm^KVi^KFe^
K6]^JfX2KVYY01A^JFQ^JFM^J6I^IfE^IV=^IF9^I65^I61_Hem`HeiaHUebHUecHU]cIF1bIV=aJ6E`
J6M`JFQ_JFQ^JFT2KFUY01E/JFU[JFU[JVY[Jfa[KW1[LGA/MGQ]N7a`OX5cQ8QeRHeiSI=lTiYoVJ63
X:V5XZb3WZN2Vj>0UimoU9]nTIL00Wb>U00:NhbANXV>NHN;N8B8Mh:6MGn3M7f0Lg]nLWUkLGIh6_oo
o`0:LgEfLW=dLG9cLG5aL6m_Kfi^Kfa/KV]ZKFUYKFQW0VaWI@0DK6ETJfARJV9PJV5NJUmMJEiKJEeI
JE]GJEYEJEUDJUQBJeQBK5MAK5]FK5eJJeiLJUmNJV1OJF1PJ61P0fMPH@0DIV5QIV9SIVAUIVMYIfY/
J6iaJG5eJgMjKWb1LH66MHJ<N8fDO9>KP9^TPYfWP9VROiJNOY:JOHnFO8fC0W^:T00:NXR=NHJ;NHB9
N8:6Mh64Mgn2MWf0MG]nMGYlM7Qj7?ooo`006_ooo`0:GFmeGW1fGg1gH75hHG9hHW=iI7AjIGEkIWIl
IgMm0VQhOP0DJGUoJWZ0Jg^1KGb2KWf3Kgj4LH25LX67M8>8MXB:N8N<NXV?NXV>N8N<MhJ<MXJ<MHJ=
M8J<M8N<LhN<0g:6S00DLHJ<L8N<L8N=L8R?L8ZAL8bCLHjFLY6ILiBMMIRRMi^TN9fWNZ2[O:>^Nj:]
NZ2[NIfYMi^VMYRRM9BO0W:AV`0:LHjHKh^DKHR@JhB=JH69Igj6I7^3HWQoH7AkGW5h6_ooo`0:JG5c
JW5cJW1bJg1bJg1aK71`K6m`KFm_KFm^KVi^0Vi^K@9_KV`04G1]Jg5]Jg5]JW9]JW=]JGA]JGE]J7I]
J7U^JG]`JWabJgYaKGUbKWQbL7McLGIcLWEdLP03M7Ab01EcM7=bM7=bMGAaMWIaNGUbO7ecOh5dPXEe
QhYgS91jTYMmUYb0Vj:3XJV6Yk66Y[25Xjf3X:V2WJF0VJ5oUYd00WfCVP0:Ni2FNXbBN8Z?MXN<M8>8
LX25LGj2Kg]oKGQkJgEh6_ooo`0:Kg=dKg9cKg5bKg1`KVm_KVi^KVe/KVa[KV]ZKVYX0VeYI`0DKFQV
KFMTKFISKFERKFAPKF=OKF9NKV5MKV1KKf1JLF1JLf5JMFAMM6EPLfIRLVMTLFMVL6QWKfQWKVQX0VeX
J00>KFUYK6UYK6YZJfa]K6maK7=eKGMiKW]nL824LhJ:MhbANY6GOYROPYnW0XJV/005QJ:/Q9nXPYbT
PIRPP9FL009nTYP02Wf?UGb<TG^:SgV7RgR4R7J1QGEoPWAlOg9iO75gNA[oool02W=dMW9cM75aLW1`
L6m^KVm/K6i[JVeYJ6aWIVaVI09[I68056YRH6YQGVUOG6QMFVQLF6MJEVMHE6IGDVIED6IDCVMCCFYC
C6aFCfaIE6]JEfYKFFULFfQMG6MMGFMNG@9VGUh2IEiO01=TH65THV=UIFMUJF]VKG1XLGEZMgY]O85`
PhQdR8iiSiMlUin1WjV2WjV1VjEoV:5nUIenTYYmT9H00Wb=T`0:Nh^@NXR>NXN;NHB9N8:6Mh23Mgj1
MWaoMGYlM7Qj7?ooo`006_ooo`0:GFmeGW1fH75gHG9hHW=iHgAjIGEkIWIlIgMmJ7Qn0VYiO`0DJgZ0
K7^1KWf3Kgj4L7n5LX26Lh:8MH>:MhF;NHR>OHbBPY2EOXbBO8^@NXZ?NHZ?NHZ@N8^AMh^@Mh^A0gJ<
TP0DMXfBMHjDMHnEMY2FMY:HMYBKMYFMN9RQNI^TNYjWNj6/OJB_OjNcP:^hP:ZfOjNdOJBaO:6]NYjY
N9ZU0WJFX@0:M9>MLXnIKh^EKHRAJhB<J828IWb4HgV0HGElGW9h6_ooo`9ZLG<01V]`LV]`LFa`LFa_
L6e_Kfe_KP9^KVd2Kfi/0W1]J`0BLFeZLVaYLVaYLfaXM6aWMFaWMVaWN6aWNViWPWA]P7A^OG=^Ng=_
NW=`NGAaN7EbN7AbMgEc0WIeM00EMGIdMGMeMGUgMGYiMGalMH20MX>5MhN9NH^>Ni2EOIFKP9^QQ:6Y
QjJ`RZfhRJ^fR:VcQjF_QJ:[Q9nWPY^S00:0Uil02WjDVgb@UgZ=TgR9SgJ6RgB2Qg9oPg1lP6ehO6]e
N1[oool02VmcM6mbLVm`LFi_L6i^KVi]KFi/Jfi[JVeYJ6eXI`9]IfD056eVI6eUHVeTHFeRGfeQGFeP
G6eOFfeNFFeMF6iLEVmLEGQSG7QUGWEUH7AUHG9VHg5VIG1WIVmWIVmXI`9^J6P05FeXJ6aYJFa[Jfa]
KVa`LFedMViiNfmmP7:2QWF8SGR>U7bEW82LY8BS[8R[]XRY]8NV/8JS[8BPZH>MYH:IX@02P9JM00Yo
TiUnSiElS99kRHiiQXYgPhMfP8=dOH1cNWeaMgTJoooo00YcM7EbLW=aL75`Kfm_KFe^JfY]JFQ/IfI[
IFAZHf42JV5O01AYGeeXGU]WG5QWFUIVF5AUEU5UE4mTDTaTD4YSCTQSC4E/Dd]^Ee1/Ee9ZF5AYFEIX
FUQWFeUVFUYUFe/2I5]K01ETFeaSG5eSGUmSH69SHfITJ6YUK6mWLGAYMg]/OH9`PhUdRY5iTYYmVJ:2
XJb2X:Z1WJN0VjAoV:1nUIemTYX00Wf@UP0:O8fCNh^@NXR>NHJ;NHB8N865Mgn2MWf0MG]mM7Qj7?oo
o`006_ooo`0:GFmeGW1fH75gHG9hHW=iHgAjIGEkIWIlIgMmJ7Qn0VYiO`0DJgZ0K7^1KWf3Kgj4L7n5
LX26Lh:8MH>:MhF;NHR>OHbBPY2EOXbBO8^@NXZ?NHZ?NHZ@N8^AMh^@Mh^A0gJ<TP0DMXfBMHjDMHnE
MY2FMY:HMYBKMYFMN9RQNI^TNYjWNj6/OJB_OjNcP:^hP:ZfOjNdOJBaO:6]NYjYN9ZU0WJFX@0:M9>M
LXnIKh^EKHRAJhB<J828IWb4HgV0HGElGW9h6_ooo`9ZLG<01V]`LV]`LFa`LFa_L6e_Kfe_KP9^KVd2
Kfi/0W1]J`0BLFeZLVaYLVaYLfaXM6aWMFaWMVaWN6aWNViWPWA]P7A^OG=^Ng=_NW=`NGAaN7EbN7Ab
MgEc0WIeM00EMGIdMGMeMGUgMGYiMGalMH20MX>5MhN9NH^>Ni2EOIFKP9^QQ:6YQjJ`RZfhRJ^fR:Vc
QjF_QJ:[Q9nWPY^S00:0Uil02WjDVgb@UgZ=TgR9SgJ6RgB2Qg9oPg1lP6ehO6]eN1[oool02VmcM6mb
LVm`LFi_L6i^KVi]KFi/Jfi[JVeYJ6eXI`9]IfD056eVI6eUHVeTHFeRGfeQGFePG6eOFfeNFFeMF6iL
EVmLEGQSG7QUGWEUH7AUHG9VHg5VIG1WIVmWIVmXI`9^J6P05FeXJ6aYJFa[Jfa]KVa`LFedMViiNfmm
P7:2QWF8SGR>U7bEW82LY8BS[8R[]XRY]8NV/8JS[8BPZH>MYH:IX@02P9JM00YoTiUnSiElS99kRHii
QXYgPhMfP8=dOH1cNWeaMgTJoooo00YcM7EbLW=aL75`Kfm_KFe^JfY]JFQ/IfI[IFAZHf42JV5O01AY
GeeXGU]WG5QWFUIVF5AUEU5UE4mTDTaTD4YSCTQSC4E/Dd]^Ee1/Ee9ZF5AYFEIXFUQWFeUVFUYUFe/2
I5]K01ETFeaSG5eSGUmSH69SHfITJ6YUK6mWLGAYMg]/OH9`PhUdRY5iTYYmVJ:2XJb2X:Z1WJN0VjAo
V:1nUIemTYX00Wf@UP0:O8fCNh^@NXR>NHJ;NHB8N865Mgn2MWf0MG]mM7Qj7?ooo`006_ooo`0:GFme
Gg1fH75hHW=iHgAjI7EkIWIlIgMmJGQnJWUo0V]kP00>KGb2KWf3L7j4LH26Lh67M8>9MXB:MhJ<NHR>
NhZ@OHbAQI>GP8jDOXfC0Wf=T`04O8jDO8nENhnENhnD0WZ@U@0ENY6GNY>INYJKNiRMNiVONiVPO9ZR
O9bTOIjWOJ6ZOjB^P:RcPZbhQ;2mQ[G3QK;0PjnmPZbiP:RdOZB`O:2[009iW:L02WNHXWBCWG:?VFn;
U6f7SfZ2RfMnQVAjPV5fOEmbNA[oool02VYaLfYaLV]`LV]`LFa`L6e_Kfe_KVi^KVi^KFm]K09`KF/0
571]JW5/JG9/JG=/J7=[IgA[IgE[IWI[IGM[IGQZI7U[I8MgL85dKWmdKgecKgadL7]dLW]eLgYfLgUf
L`9hMWD05GQgMGQiMgMlNWQoOGV1PGV4Q7Z7R7^;SGf?TWnEVH6JWhBPYXRV[X^/]Xjd_hfa_8b_^HZ[
]HVW/HNT[HFPZ002PibT00Z1V9moU9]lT9IjS99hR8ieQHUcPHE`OH5^NGe[MGPJoooo00Y_LgA_LG9_
L71^Kfm^KVe^K6a^JfY]JFQ]J6I]IfD2KFES01A/I65/Hf1/HUi/H5a/Ge]/GUU/G5M/FeE/FUA/F59]
F55nIemiIEifI61dI61cIF9bIF=aIVE`IfE_IfH2KVMW01E]IfM]JFU/K6]]Kfm]LWA^MgQ_NgeaOh9d
QHUfRi1jTIMnV9n2X:R6Yk6;[k^:[KR9ZkF8Yk67Y:f5XJV4WJD00X:JX@0:PIJMOi>IOXnEO8bANXR=
NHF9Mh:5MGj1Lg]mLGMi6_ooo`0:LWAeLG9bL6m`Kfi^KVa[KFYYK6MVJfETJV=QJF5O0VQOG00DIeeJ
IUYGIUQDIEIBI5A?He9=He1:HTe7HD]4H4Q1H4LoLUM>KUI?JeIAJEIBJ5MDIeMEIUQGIEQGI5QH0V=H
F@0EHUQIHEUJHEaLHEmPHV=UHfQZI6a_IW5dJGMlK7j3L8B:M8bCNI>KOIZTPZ>^PZ6/PInYPIfVP9ZS
OiRPOYFM009nTYT02Wf@UWb=Tg^:T7Z8SGV5RWR3QgN0Q7InPGEkOWAiNacoool001[oool02Ue_MEm`
MV5aMf9cNFAeNfEfO6MgOFQhOVYiOfakP09]O8804VmmPg1oQ7:0QWB2QgF3RGN5RgR6S7Z8SW^:T7b:
TWf;TWn<Th6?UH6@UX2@UX2AUh2AV7nBV09oTiT2OYBI01EnUI]oUienVYmoWJ60WjB0XJJ1XZV1Xj^3
YJj3Z;64ZkB4[[V6/[j8]/B;_Lb:_<^8^<J6/l64[kb2Z[N0Y[800WfQ[@0:NYbWMiRRMI>MLXjHKhVB
JhF=J828IGb3HWMnGg9i6_ooo`03JW5cJW1bJg1a009/L7001Fe_Kfi^KVi^KFm]K71]J`02L6aZ01=a
K6UbK6QcJfMcJfMdJfIeJVEfJVAgJV=gJF=gJ65lKFJ2Lfb1Lfj0M6moM71nMG5mMG9mMWAlMg@00g]g
M@0ENWQfNWYhNWikNX5oNhF4O8V8OHb<OXnAPIBFPiVMQIjSQjBZRZZbS[6kTKW4TKS4T;G0S[6lS:fg
RZVbR:F]00:6X:T02XBLY86HWgnDVWb?UGV;T7N7S7B2Qg5nPVmjOVafNA[oool02VmbM6maLVi_L6i^
KVi]KFi[JfeZJFeXIfeWIFaUH`9/I64056aRGfaQGFaOFfaNFFaMF6]KEV]JE6]HDV]GD6YDCG=LE7]T
G7QSGGISGgASGg=THG9UHW5UI71VIFmVI@9^IVD03VeVIVeXJ6a/Jfe`L6ieMFmiNW1nOg:2QGJ8RgR>
TgbDVWnKXX>RZhRZ]0:</[h01H^_^XZ/]hVX/XNU[XJQZP02Q9fU00Z3VZ61UYeoTYQmSYAlRXmjQh]h
PhMfOh9dO7iaN7XJoooo00YbM7EaLG9`Kfm_KFe^JfY/J6M[IVAZHf9YHEmXGe`2IeaI01AVFUIUEe=T
EE5SDdiRD4]QCTQPBdEPBD9OASmL@S]XC4=aETe]E4eZDdmXDdmWE55UE59TEEASEEEREED2HEEE01EP
EEIOEUQOFU]OGEmPHfERJ6YSKFmULWEYN7a/OhA`QH]dS9AhU9amVjF2Xjn2Y:n2XZb1WjZ0WJJ0VZ=o
V:000WjEW00:OY:IOHnFO8bBNhZ?NXN;NHB8N865Mgn2MWanMGUk7?ooo`006_ooo`0:GVmeGg1gHG9h
Hg=iIGEkIWIlJ7QmJWUoJgZ0KGb10VmmP`0ALGn4LX26M8:7MX>9N8F;NHN=NhR?OHZ@OhfDOXbBOHZ@
P8fCPY2FPi6HPi>IPiBKPiFL00:3UYd068>GWH:GWH:GWH6IWX:LXH:OXh:RYX>UZHBW[8FX[HJZ/8N[
/hR^]hV`^XZc_XZg`hflbXo2dY35eHk0d8^kbXVfa8Ja_XB/^0:1Y[802WjQ[G^LYgNGXGBAVg6<UFf7
T6Z2RfImQF=hOemcNQ[oool02VYaLfY`LV]`LFa_L6e_Kfe_KVi^KFm]K71]Jg1/JP9aK6T04W9[J7=[
Ig=[IWAZIGEZI7IZHgMYHgQYHWQXHG][Hgm^Ih5aJX5bKH5cKX1dL81eLWmfM7mgM@9nN7D2OGQe01Ek
N7ElO7UlOgelQ85mR8InSH^0T8n2U9B4V9Z7WJ69XZN;Yjj=[KFA];jD_<NF_lbD^lNB]l:@/kf>[[R<
Z[<00XVU[@0:Qj2XQ9bSPINNOY:HNhfCN8V>MHB9LX24Kg]nK7Ii6_ooo`0:Kg9cKg1aKVm_KVe]KVa/
KFYYKFUWKFMUK6ESK6AQ0VaRG`0DJf5MJemKJeeIJeaGJeYEJeUCJeM@JeE>JU=<L5Q@MeiFMf1IMf5K
MF5MM69NLf=PLVARLFESL6ETKfET0ViUI00EKFATKFQXK6a[KG5aKWIfL7alLH21M8F7MhZ>Ni6EOYNM
PIfUQ:B]RJ^fS;>oSkO4S[C0S;6lRjfhRZVcR:F^00:7XJX02XFMYH>IX86EVgnAUWf=TW^8SGR5RGJ0
Q7AlOg9hNQ[oool02W9cM75aLG1^KVi/JfeZJFaWIVYTHVURGfQOG6MLF@9UFUH056AGDf=DD69BCF5?
BV1<AUm:@ei7@5e4?E]0>6=7?Ve?AVa@BFYABfQ@C6IACFEACVABD6=CDV9CDf5BD`9ODU<05EiADUiD
EUeHFEiLGUmRI61XJV9]KfEcMVUiOFb0QG67SGF=UGRDWGfKYH2R[H>V/X:T/8:R[H6PZX6MYX2JX`02
OiNO00YoU9anTIQmSYElRi5kR8ejQHUhPhIgOh=fO7meNG/Loooo000Joooo00YNKgIPLGMRLWQSM7YU
MG]WMgeYN7i[NX1]Nh5_OH<2LGj4015bP8IdPXMfPhUhQH]jQhelRHmnRi60S9=lRHn0S9:1SYB3SiF4
TIR5TiZ6UIb7Uij7VJ000XNJX@0HQiZPQYZPQYZPQIRNQIVOQI^RQYjUQZ:WR:R]RJbaRjjdSK2gSK:k
S[FoS[O3S[_7T;o=TLCDU<[KTlWKT<?CS[g<RkO5R;:o0XF/^00:PJJbOZ2[NYZUMYFOLhnHKhVBJhB<
Igj6HgV0H7=j6_ooo`0:JW5cJg1bJfm`K6m`KFm_KVi]Kfi/Kfe[L6aZLFaY0W9[J00DLf]WLfYVM6YU
MFUTMVUSMfURN6QQNFQPN6MNOfeUPFmXPG5ZPW9/PW=^PGA_PWIbPWMePGQfPGUfP7Qf0WmiMP0EOGMe
OGYhOGekOX:0OhJ4PHf<PY:AQINGR9bMRZ2SSJJZSjZaT;2gTkFoUKc7V<;?V<?@U[g9U;S4T[BnSjnh
00:<Z[802XZU[HNOYhBJXH2EVgf@UWZ:T7J6RW>1QG1lOfagNQ[oool02VmbLfm`LFi^KVi]KFe[JVeZ
J6eXIVaVI6aTHFaRG`9[HEd056]OFV]MF6YKEVYJE6YHDVYFCfYECFYCBfaCBWILDgIMEGINEgEOFWAP
Fg=PG7=RGg9SHW9THg5TI71TI09_I6@05FeSHfaVIVaZJVe`L6idMG1lO7:1PWF7RGV=T7fCUh6JX8BO
YhJU[XZ/]Xbc_Y2iaY2jahne`Xfa_Hb]^8^Y/`02RJF^00Z7XJV5W:B3V9j1TiUnSiAlRXmiQXYgPHEd
OH1bN7/Joooo00YbLgAaL75_KFe^Jf]/J6M[IFAYHf5XH5eWGEYUFUL2I5MC01ASE51RDDaPCTUOBdIN
BD9MASmL@c]L@3QO@CQ[C49ZC4=YCDEXCDQVCDQTCDUSCTaRD4iQD51PDE5PD542GU1A01ELCe5LDeAL
EeUMGEmMHF=OJ6YPKG1TM7MXNWi]PHIbR8ieSYIhU9elVZAoXJb2Yk:3Z;B2YK22XZf2X:Z1WJH00X2J
XP0:P9NOOiBKOY2GOHfCNhZ?NXN;NHB7N823MWeoMGUk7?ooo`006_ooo`0:GVmfH75gHW9iI7AjIWIl
J7QmJWUoK7^0KWb2L7j40W:0Q@0DM867MX>9N8F:NXN<OHV>Oh^APHfCQ8nERYFKQY6HQI6GQY:HQi>I
QiBKRIJNRYZQRibSRifTS9fTRibS0XZKXP0ER9NNQiFLQiFLQiNNR9^SRjB[SJ^aSk2gTKBkT[JoTkW3
Tk_7Tkg:Tl7?U<KEU/[KUlkOUL[KTlCDT;k<S;S500:9/Kh02XF[]h6T/7fNZGVHXWFBVg6<U6b6SVR0
QfAjPF1dNa[oool02VYaLf]`LFa_L6a_Kfe^KVi^KFm]K71]JW5/JG9[J09bJfL04W=ZIGAZI7EYHgIY
HWMXHGQXH7YXGg]WGXIaIh=`Ih=`J8=aJX9aJh9bK89cKX=fLXAiMHAiM`:3NGL2PGUg01EoN7InMgEo
NWUoOGeoPH22RXZ5TY68VIV;Win>XjJAZJjB[KBC/[VE]/2G_LNI`/jKamBJ`m2H_/ZE^LBC];h00Y2^
]`0:SJVaRZ>[QYjUPiRNOi:HNhfBN8N<M8:6L7b0KGMj6_ooo`0:Kg9cKg1`KVi^KVa/KFYYKFUWK6MU
K6ERK6=PJf5M0V]OF`0DJUeHJU]FJUUCJUMAJEE?JUA<JU9:JU17N5]BMeaCMUaEMUeFMEeHLeeILUiJ
LV1NLf=QLVASLFASLF=T0W1UI00EKFAUK6EUKFUZKFe^KG1aL7UjLX62MXR:Ni2BOiFIPibRQZ6YR:N_
RZbfSK>nSkS5T[g;TK[7T;K2Sk:mSJjh00:;ZK802XVT[HNPYhFKXX:FW82AUWf<TGZ7RgR2QWEnPG9i
Na[oool02W9cM71`L6m]KFeZJFaWIVYTHVUQGfMNFfIKEfAHE09SE500565AC61>BEi;AEe8@Ea5?U]2
>UXo=eTl<VQ7?FU9@6Q:@VM;@fE;AFA:AF9:AV5;BF5>CF1?Cem?Cem>D09MD5405EaBDeYCE5]IFU]L
GU]NH5eVJ5m]KfAdMfUlOff2QW:9SgJ?UgREWG^JY7jPZh6U/HBZ]h>X]8>U/H>R[H:PZ@02PYfV00Z1
VJ:0UYioTiUnSiElS95kR8eiQHUhPHAfOH1eNW`Loooo000Joooo00YNKgIPLGMSLgUUMG]WMgaYNGi[
NX1^O85`OH=bOh@2M86600QfPhQhQ8YjQXamR8ioRi21SI:4T9F4SiD2RI>H00J8TiR9U9V9TiV:UI^;
V9j=Vj<3T:2V01>BWJB;UIb;UIb8TiV5SYF5T9N7Uij9Uin<W:B@Y:bE/;NF]kjG^/:G_<JG_/VF`<bF
`]2GamJIbm`00Y_Ah`03V<_LULGDTKk<00:=]l@02XV`_8BY]82R[G^KYGNDWW:>Ufj7T6V1RFEjPV1d
Na[oool02VYaLf]`LFa_L6e_Kfi^KFm^K71]Jg1/JW5/J79[I`9cJVH047AYI7EYHgIXHWMXHGQWH7UW
Gg]WGWeXGXMaIhI`J8E`J8AaJX=`JX=aJX9bKHAeL@:6NWL06HIkMhUlNX=gMH=gMH1gMGedLgefMGil
NgmmOX:4QHJ<S8bGV8nQXY:VZ9B[/9F`]YJc^iNg`9Rlai_2cYg8eIk9eYc4dIZobYNi``02U;>m00Z@
[KJ=Yjn9XJR5Vj:1UI]mSiAiRHiePhMaOH5]Mg/Joooo00Y_LW=^L71^KVe^K6]]JVQ]J6I/IV=/I65[
HEi[Ge/2JUeI01AZFeIYFE=YEe5YEDiYDdaYDDUYCdI]DDMjGE=hG5=gG5AfGEIdG5IbFeIaFeQaGUac
Hf9bI6=aI6=eIfL2LFAT01E^IVI/IFE[IVM[Jfa[KFm^MGMaO7ihQhUmTI>2V9Z5WZB8Y:^9Z;2;[;J=
/[f?^<BC_/^C_lfB^lRA]l:@/[d00Xj]]`0:S:RaRJ>[QijUQ9ROPI>IOXjCNhV=N8B7MGj1LWUk6_oo
o`0:LW=dL6m`KVa/KFUXJfETJF=QJ5mMIUaII5UEHeEA0V5BC@0DH4i9GT]5G4Q1Fd@mFT4iFCheEcXa
GCdcK4XoJDU0IdU0ITU3I4Q3HDM2GdI3GTQ7Gda<GTe=G4e>HE=D0UiCD`0EG5EFFUIGFUMHFEYLF5eO
FfAWGFY]I7=fJGf0KX>7LhZAMY2HNIFNNYZTOInZOjB`PZVfPj^hPjReQ:FaQ:>]00:3WjT02X:LYH6H
X82EW7nAUgf=Tgb9SWZ6RWR2QGMnPGEjO1coool001[oool02Ui`MV5aN6=cNFIeNfQgO6YiOVekP6mm
PW5nQ7>0Q@9fPXL037R4RGZ6Rgb8SGn:Sh6<TXB?U8J@UHjFVXbDVH^DVH^CVH^EVP:;U9X01XbFW8jJ
XI:OYYBOYXbCVXbBV@:;T9L05HZ?UXVAV8N?UXJAVHFCVXRHWhbOYYF[/Y^g_Ybma9bob9_1c9[2cYW4
dIW7eY_<g9gAhYkDiIkAhI_<fiO4dP02T[c900Z=]<68[KR3YK1nWZQiUj5dT9U_RI9ZPXYUNh=QMG/J
oooo00YZLG=[L75/Kg1]Kfi^KVe_KFa`KFYaK6UbJfMcJVH2M6UT01AdJF=eJ65fIf1gIemiIUijIUek
IE^8L6B8LFN7LFR6L6R5LFZ4L6V3KVR2KfZ4Lg27N7F:O7V4MWB5N7H2PgEd01F1MGAoMWEmM7=lNGUl
Ng]mP861QXN;TiBDX:6FZJZH[[6I/kRI]KbH^<2I_<NL`/fNamBPbmVPbMFOaM2L_lT00YRh`P0:U;6j
T:^cRjB/QijUPiNMOi6FNX^@MXB9LWj2KGQk6_ooo`0:Kg9cKVm`KVe]KF]ZKFUWK6MUK6ERJf9OJf1L
JUiI0VYKEP0DJEUDJEMAJ5A>J59;J519J4m6Ida2N5U>NeeBNEaCMU]CMUaFLeYDLEQCKeQEL5aJLF1P
MVMVLVASM6MW0W5UI@0EKfEUKFIVJVATJVY[JFa^JW5dKGIiMh>5P92CQ9ZMR:2URZJ/RjVaRjbfSK6l
SkO3T[c:U<7@UKo<UK_8TkO200:A/K/02Xn/]HbV[hVQZ8JKXX>EVh2@UGb:SgV5R7IoPW=iO1[oool0
2W9bLg1_Kfi[JfaXIfYTHfQQGfMNFfEJEf=FDf9CCP9PCdX055i<AUa8@UY4?EU1>ELm=EHj<EDf;6M4
>6]9?fU8?fI7?fE8@V96@5m4?ea3@5a6AEa:BV1BDEmCDV=HF09OEEH05EaFEeYFEeQDEEMKGEMMH5QQ
IEUUJ65_LfYlOg25RGB;TGNBVGVFWWZIXg^MZGjR[X2X]H>/^XB[^8FY]HFV/@02QJ>/00Z4WjR3Vj>1
Uij0TiUnSiElRi1kQh]iPhIgOX5eNW`Loooo000Joooo00YNL7IQLWQTLgUVMG]YN7e[NWm^O85`OX=c
OhEePHH2Mh>801AiQHYkQhanRHj0Ri24SYB7TYN7TIFBVIf?UY^>UIV=TiR=U9V=TiV=TiR<TiV>U9^=
UIfBW:>?VZ:>VJ02SYRP01F=UYj<Uj2;V:2;VjB:W:F8WJN7W:F;Xj^F[kNP_/FP`lbOaLnMaM2LaM:L
b=NMcMbOd^>Pe^RReNNQdn:MbmT00YK2c`0:TKW5Rk6lQZVdP:6[NiVSMY:KLH^CJh>;IWb4HGEl6_oo
o`0:JW5bJg1aK6m_KFi^KVi/Kfe[LFaYLV]XLf]VLfYU0WAYH`0DMFQRMVMPMVINMfEMNFELO6IMO6EJ
SgEYRg9XRG5XQg1WQW1YQFmXPfeVPVeXPfm/PW9`RWekQgaiQWYi0XEjN@0EPgQgPGUhOgUhP7inOgn0
OX>4OHB6PXf?SYVKVZVZW;6dWKFjVkNnV[W1Vkc6WL7<WlODXLcKXlcIY<[FXLG?00:L_LL02YRf_i>_
]hjW[hZPYhFJX82CV7b<TGN5RW9oPfihNa[oool02VmaLVi_Kfi/K6eZJFeXIVaVHfaSHF]QGV]OFfYL
E`9YFU@056UGDFQECVMBBfI?B6I>AFQ=A6U<@WmODWaMDgULDgMJDgEKE7=IDg1FDFiGDfmJF6iMGGQZ
JGEYJ7=XI`9aJ6P05FmVIFeVIV]VIf]/KVY^L6YbMFYdMg1nPW^:SXNIWH^RYhfX[Xb[/hb]]Xb`^hne
`Y6lbIC1d9K1ciS0cIRla`02UKK000ZB/;V>Z[:;Y:^8WJB4Uij1TIMmS91jQXUfP8=cNW`Joooo00Ya
LW=_KVm]JVY[IfIYHf9XH5eVG5UTF5ERE51PDD`2GTe701ALBD=JACiH@CUF?3ED>C1D=biF=R]^BSe[
BCiXB3iUAcmSAd5PACmM@SeJ@SmKADEJBTYUEeIREUEPEED2GUIF01EKDeAIE5AGDeEGFEaFFeiGH6AH
HfMNKG5WMg]aQ8QeSI9hTiYiUimiVJ9jW:MlXJeoYkB1ZkZ4[;V7[;V8Z[D00XNV/00:QZ:[Q9jVPiVQ
PIFLOi6FOHbANhR<NH>7Mgn2MG]m7?ooo`006_ooo`0:Gg1fHG9hI7AjIgIlJWQnKGZ0Kgf2LWn4M865
Mh:70WV4R@09NhJ;OHR<OhV>PH^AQY2FSYRNSIFJSiJJT9JI00:?UYX02HnEVXnCV8fAUXb@UHZ<TXR9
T8b>UHnDVi2FW@02T9VQ01F@VZ6?Vj>?W:B?X:V>Xj^?YJj=Xjf=Z;6@[;FK^<2TaLfRam2Qam:OamBN
b]RPcMbQd^:Re^RSenRSe>FQd=h00Y_6e00:UKg:SkC0RJbgPjB^OIbVN9BMLXbEK8B=Igf4HGEl6_oo
o`0:JW5bJg1aK6m_KVi]Kfe/L6eZLFaYLV]WLfYUM6UT0WEXHP0DMVMPMVINMVALMV=JN6=IP6UOQFaQ
SGAXRg9XRW5XR75XQg1YQViWPf]UPVaWPFaYP6e[QWAbQWMeQWQf0XIjN00EQ7UgPWYhPWYjPX20PX>3
PXR9PHR:Q8nBR9JHUJ>VWk>eWkRkW[VoW;W1W;c6W/7<X<KCXLcIY<kLYLcJY/[E00:P`/`02Y^j`iJb
^i6[/XbSZXNLXX:EVWf>TgR7Rg=oPfihO1[oool02VmaLVi_Kfi/K6eZJFaWIFaUHV]RGf]PG6YMFFYK
EP9YF58056QFCfMCC6I?B6A<A699@6Y>AG=DBGmODgaMDgUKDWMKDgEKE7=HDVmED6iHE6mJF6mMG7ET
HgAVIG9VI@9aIfL05FmUIFaVIV]VIfa/KV]_LFefN6efNW1nPgF6RX:DV8fTZ8jZ[hj/]8b/]Xb`^hje
`I6kb9?0ciO3dYW2dIc2c@02V;[500ZE];fA[KJ=YZj:X:N6VZ22TiUnSI9kQh]gP8AcNWdJoooo00Ya
LW=_KVi]JVU[IVEYHV1WGUaUFUMSEU9QDTiOCTT2GDY501AKAT1I@S]F?CIC>31><RUD=BaP?S9_Bcm[
BCiWAciTAcmRAT1OA3mL@CeKAD5MBDQNCTeTEEAPEEANE5@2G5AD01EJDE9GDU=FDUAFEeYFFeeHHVEH
HfMLJg5RLgQ]OhEgSYAiUI]iUj1hV:5hVjIjWjamYK>0Z[R4[Kb7[[b;[kT00XVZ]00:R:F^QZ2YQ9bS
PYNNP9:HOXjCO8V=NXB8N7n2MW]m7?ooo`006_ooo`0:Gg1fHW9hIGAjJ7MlJgUnKW^0LGj3M824MX:6
NHB80W^5RP0DOHN<OhR=P8V>P8Z?P8Z>R92ESiBHSiBGTIFITYJITYJHTYFHTI>GT96ET9:GTIBIT96G
T96HTI:ITI>J0i2CV`0DSiFMSiJOSiRQT9^UT:6[TJB^T:RbTJfgU[>mX<39YLSAXlSCXLSDX<[HXLkM
Xm;RY=OWZ=c^[=g^YM?R0Yo;f00:V<7=T[S4RjnjQJJaOijXNIJOLhjFKHJ>J7j5HWIm6_ooo`0:JW5b
Jg1`KFm_KVi]Kfe[L6aZLVaXLf]VM6YUMFUS0WIXH@08MfMOMfEMMV=JMF1GLUeBOVILS75URg9V0X]a
I`0:RW5WRG1XQfiVQFaUQFmYQg=_QW=`Qg=aQgEcQWEc0XEeM00EQ7EcPWIePWMgPWYkPWn1Q8J7QHV;
QXnBRIJISijRW:nbXKRlX;ZoWK[1WKc5W/7;XLKBX/_HY]3N[]CRZLkI00:Ua]402YnnaiVf_YB^]HjV
[HVNYH>GW7j?U7V8S7B0Q6iiO1[oool02VmaLVi^Kfe/JfeYJ6aVI6aTHF]RGV]OFfYLEfUJE09YEe00
56QDCFMABFE=AF98@5e3>F]>A7eLD7eMDG]LDWUKDWMKDgIKDg=HDW1FDG1JEG=PGG=QGg=RHG=SHW5T
H`9`Hf<05FiRHVaSHf]UIV]XJVa^L6edMfmgO75nPgF6Rgf@UH^QYY2[/8n/]8b/]Hb_^Xjd`96jai>o
cIK3dZ39eio5d@02W;o:00ZH]l6D/;V@ZK6;XZZ7W::3UI]oSY=kR8agPHAcNWdJoooo00YaLW=_KFi/
JFUZIFAXHEmVG5YTFEERE51PD4]NC4L2G4Q201AJA3eH?cQE>S9@=2a:;RAI>2i/B3a/BSiYB3iVASiS
AcmQAT1NA3mK@SiKAT=OCD]OD4iODE5NDU9LDe82FU9B01EHDE5FDE9EDeAEEUUFFeiGHFAJHfUMJg5Q
LgQYOH=fSI9jUY]iUimgUj5gVZEiWZ]lY;5nZ;J0ZkZ;/l2=/[d00Xb]^00:RZRbR:>/QYjVPiVPPIBJ
OhnDOHZ?NXF9N823MW]m7?ooo`006_ooo`0:Gg1fHW9hIGEjJGMlK7UnKg^0LWj3MH65N8>7NhF90Wf7
R`0:OhV=PHZ>PHZ?OhN<N866NX>9RHnCT9FHTiJIU9FI0YBFV007U9>FTY6ETY:FUIRLUIRNUINMUIJM
00BDUid059>HWi>IXI>LY9BOYiFRZiJT[iJV/IFX/iJ/]i^e_j;0bZC6dJ?8e:;:ej?=fjCAhJGEiJGF
ijoNkZ[GiP:RcM/02Y_4dIFkahjb_HRY/h6PZW^GXGF?V6j7SfQnQV9fOA[oool02VY`LVa_L6e^KVi^
K71]Jg5/JG9[IgAZIGEYI7IYHP9gJ60047QVGWQUG7MSFGANEFmJCgIPEhI^Hh]aIXaaIhaaJ8]aIhYa
J8U^IXM/IHM_J8YfL@::Mg@06HUgM8QgM8MfM8MfM8IfM8AgMHAiN8AlO8F0PHJ5QhV9S8Z>TXbDV8nK
XIJV[9jc]j2h_Yji`9jkaIo0bZ75dJ;9eZ;;fK;Hi:oBgP02Z<[D00ZR`L^L^L6F/;R@Z;2;X:N5V9io
T9IjRHedPHE_NG`Joooo00Y_LG9^KVi]Jf]/J6M/IF=[Hf1[H5eZGUUZFeIYF582JEI?01AXDd]WD4MU
C4=RAciOA3UZCD=iFTmkFe5jFe9iFe=gFe=fFe=dF59aEe5aFUEeHUmeHf5dI69cHf9aI6<2L6=R01E^
HV9/Hf=/IFI[JFY]KG1^LWIbN7edOhAhQX]mSiF6Vj6=Yjb>Zk><[;F<[[V=/kn@^<JA_L^B_lnUc]bS
b]H00Yo2c@0:Vk_5U[>lTZbdSJF/RIjTQINLPI2DO8V=N8:5M7]m6_ooo`0:LG5bKVe]K6QXJFARIemM
IE]HHeMCH59>GTi9GDY40U]6?`0DFD8jEcdeECT`DC<ZDC8WGSdaJdPlJDPmIdLmIDLoHTHoH4I0GT@o
Fd<oFdI3Gdi<GU1?GU5@G55@Fe5A0UU@D00EEdm?E4m@E59DDeEHEEYMEUmSFVAZGFaaHWAjJGj4LHV@
N9BJN9JNMYNPMYVTMifZNZ:`NjJeO:ViT;S6T;G200:?/K`02Xb[]HZV[hNPZ8FKXX:FW82@UWf;T7^6
RWR1Q7IkOQcoool001[oool02Um`MV=cN6IeNfYhOFejOg1mPGAoQ7N2QWZ4R7f7RP:0RHd028:;SXB<
T8F=THB;THB<THN=THjCUIBGVP:GV9X02IRGVIRFV9NEUiJCUIJDUiRJWYZMXiZLXYVKX003V9ZP01FG
VInFVJ2GW:>GX:NHXZZIYJfKZ;6KZkFK[[RM/[fO^<>R_/RTa<jTam:Tb]JTc]^UdMnUe>>Ve^Nbh>j]
f^L00ZKAgP0:WlODV;g9TKBoRZ^ePj:/OIVRMY2IKhR@JGn6HWIm6_ooo`0:JW1bK6m`KFi^KVe/L6aZ
LF]XLf]VM6YUMVUSMfQQ0WUWG`0:NVINNVELNVAINF5GNf=HOfMLQVeRS75VSW=XSW9Y0XeaJ008RfmW
RFiVRG1YS7I`SW]fSGYgS7UeRWQe0XUhM@0ER7IdQWMeQWYiQWimQh:2RHJ8S8b>Si:ETIRLU9nTV:N/
WK2eWkFkWkRoW[_3Wko9XLC?XLODX/_I]M[V/]KQ00:/cMP02ZG4cYnlaIVc^i>[/XfRZHNJX86BUg^:
SWF2QFmjOA[oool02VmaLVi^KVe[JVaXIV]UHV]RGfYOFfYLEfYJE6UGD09YE4d056UBBFQ?AVM<@VI9
?fU;@6i@AWEGC7UKDGYLDWULE7QKDgMKDgEIDW9HDW9JEGEQGGIUHgEVI7ATHg9THP9`Hf805FiRHFaR
HVaUIVaZJfe^L6mcMg=iOWN1QW^9SX2AUhFJX8ZSZHbX/8bZ/h^]^8fb_Xnga92kbY2ncZS@gZO=f@02
X/KA00ZM_/RI]/2D[kN?Yjn;X:J6V9j2TIImRXiiPXIdNghJoooo00YaLG9^K6a[J6MYHf5VGUaTFEIQ
EE5OD4aMC4MKB482FT<l01AH?cQG>c=E>2iE=2YH=b]M?C9S@cQUASaUAciSAd1QAT1PAd1NACmKA3mK
AT=MC4UND4mMDE1KD51ICdl2Edm?01EECTiCCTmBD59BEEMCFEaEGV=JIFYOKG=TMG]YOXE_QhidT9Mf
U9eeUImdUj=fW:UiXJmiYKAjZ;RB^/RD^LD00Y6d_`0:SZjhS:RaRJ:[QYfTQ9NNPI:GOXbANhN;NH64
MWan7?ooo`006_ooo`0:Gg1fHg=iIgEkJWQmKW]oLWf2MH24NH>7OHJ9P8R<0X>;SP0DQXf@R8nBRY6D
S9:ESYBHTIRKUI^MVIbMVYbMVi^MW9ZLW9VKW9RIViJHVYNIViZMWInSWZ6VWInTW9jS0Y^NX`0EVifR
VYbRVYjTVj:XVjF/VjN_WJ^bWjffWk6iX;BmX[W2Y;o9YL?=Y/OAYLWEYLgIYM3MY=;QXmCT]>;a/Mk]
00:Ye>802Z;:ei[0c9>f`Hb]]hFT[GjKY7NAVW29T6V0Qf=gOQ[oool02VY`LVa_L6e^KVm]Jg1/JG9[
IgAZIWEYI7MYHWUXH09jIel027aWGGeVFgiUFX1UFH9XGHI]HX]aIXmdJ0:@MFX02Y1dJXmcJHiaJ8e`
IhabJXeeKhmkMY1mNHikMhejMP:;NWH05HYiMXQhMHQjN8QoOHZ4Ph^8R8j>Si6DUYBJWINPY9ZW[9j_
]9nc^Inf_Inj`Z2nb:33cJ36dYo8e[SLj;KJi@02[m7L00ZYb=:R_lRK][jE[KB>Y:^8W:62TiQlRhme
PXI_NWdJoooo00Y^LG5^KFe]JVU/IfE[I65ZHEeZGUUZFeIYF59YETl2JE=;01AYDDQYCTEZC49[C41]
CdAaE4UfFDmjG55kGUAjGUEiGEEhG5AfFe=dFE=dFeEdGe]fIF9fIfEdIVAbI682L6AS01E_Hf9/HV9/
IFE/JFY^Kg5`M7MeNgmiPXMmRXn1TIN5VJ2:XJV;YJj;Z;:;[;N=/Kf>]/>?^/R=_<bZd]n[dMd00ZK9
e@0:X<7<VkW3U[6jTJVaS:6XQiZPPi:GOX^?NH>6M7]n6_ooo`0:L75bKFa/JfMVJ69PIEeJHUQEH5=?
GTi:G4Y4FTDo0UQ1>P0DEcdeEST`ESH/EcDYF3P]G3dbH48hI4DlI4LoHTQ0HDM0GdI0GDE0G4@oFdI2
FdY7GE1>G55@FU1@F4i>0UI>CP0EE4e>DDa>DDmADE=FDUUMEEiSFfI[GfidI7IlJGj5KXJ=LXfFLi2J
Li>NLiJRMY^XMj2^N:BcMjJgU;_9U[c800:D]l802Y6a^hj[]8^U[HROYXFIX8:CVGn=TWb7RgV2QGIl
OQcoool001[oool02V1`MV=cNFMfNf]iOFmkP7=nPWN1QG^4R7n7RX>:S@:6SI0058Z@ThfCUI2EV9>H
ViFKWIVNX9^PXYjPXInQXJ2PXJ2OWj6MWZ2LWJ2JW9nJW9nLWj6PY::TZ:6RYj2PY@:OWj@05IjOXifN
XifPYIfRZ9jV[9nY[j6]/j:`]jBd^ZBf_JBi`JJnaZO2bjS6d:O9e:O<f:K?g:C@gj3@hK7OkkKSl@02
[MSU00ZTcMVM`/jE^<>>[kV7YJn0W:EiTi]aRI5ZP8QSMghJoooo00YZL79/Kfm]KVe_KF]aK6UbJfMd
JVEfJF=hJ65jJ5l2O6MN01AnIef0Ie^2IeZ5JEb8K5n<LFF?MV^CMf^CNFfCN6fCMfbCMF^BM6^ALVZ@
Lf^@MVnBNgFCOgZAOGV?NWL2SGYf01F<NWJ9NGF9NgR:OWf<QHB=RHVAT92DUYRHW9jIXJBKYj^N[K:O
/KNP]KbP^L6P_LNQ`/bPa=6LaMBcf>FkgnX00[?Eh00:[<_EY<7:WKS0UjnfT:J]RYfSPiBJOHb@MX>7
L7Ym6_ooo`0:KW1aKFe]K6UXJfITJV=PJV1LJEaHJEYDJEM@JEA=0VUBB@0DJU16JTi3Jda0KTi2L555
M5M<N5aBO5iDO61FNf1GNUmFNEeFN5aEMU]DMEaFMEmJMfAQMfQVMFIULfAS0W5THP0EKf=RK69RK6EU
K6UZKfmaLGAgMWb0NhB8Ohb@Pi:HQYVORInWRJ>[RZN`Rj^fSK2lS[G2S[W7Rk[:Y/kL[mGR00:YcMT0
2Z?5ciflaIRc_9>[/hjSZXVKXHBCV7n;T7Z4QgElOQ[oool02W1aLFe[JfYVIFMPGfAKFF5FDeiACEa<
AeY7@EQ3?09G?SL055Hk<UDg;EDd:ELe:EPh;E`n=614>f=6?F98@658@F17@Em6@5e5@5a5@5Y6@UY9
AE]=C5]AD5U@CeM>CP9ECTh05E==CU1;CDm>D51BEE9IGEENHe]WK61_MFEgOFUnQFf5SG2;U72>V76A
W7>FXGFJYgNP[GVS/WNU]I2haYZoc002Uk[600ZC];j?[KN<Yk29X:R6VZ63U9Z0SY=mR8ajPXEgO7hL
oooo000Joooo00YPLGMTLgUXMW]/NGi`O81dOh=iPXImQHR1RH^6S8h2RXnB01B>TiFBUYRFVY^JWZ2M
XJ>QY:FRY:FSY:FTY:FUY:BUXj>UXZ:UXJ6UX:2UWj2TWj6UXZBVYJVUYJVTY:P2Xj>W01FQXZJPXZJP
XjRQYZ^RZJjSZk6U[[FV/[VX][fY^KnY_<:Y_lNZ`/^Za/nZbMBYc=NXc]ZTcmfMc=bRdnBagnh00[;M
jP0:Y/kKW/C?Uk[5T;2jRJN`PIfVNYBLLXZBJh68HgMn6_ooo`0:JW1bK6m_KFe]KfaZLF]XLfYVMFUT
MfQRNFQPNfMN0WiWG@08PFMLQ6QKQfQJRVeOSG1STWMZUGU]UWY^0YMkK`0:UWU_UWQ]UGM]UGI/U7I]
TgM_U7]eUGmjU7mjTWeh0Y1lN00ESW]gS7YgRgaiSH5oShJ5THZ:U96AUiNIVijPWJ>VWZR[WjbaX;2f
XKBkX[W0Xkg6Xl7;XLC@W<CBYloM]]cY00:ifnH02Zk=ejK3c9nj`YVa^9:X[X^NY8BEVgj<TGN3Qg1j
OQ[oool02Vi`LFe/K6aYJ6]UHfYRGfUNFVUKEVQHDVQECVQBB`9YD4L056Y>A6]=@Fe<?fm@A79CB7QL
DGaOEGePEWeRF7aQF7]PF7YOEgUNEgQMEWMNEgIOFWMTH7QXIGIWIGAUI09aIF<05FmSHVeRHVaUIFeZ
Jg1`LW=fN7MmP7b5RX6=TXFCVHNIWhRMYHVQZX^V[hbZ]Hj`^i2e`I2iahjjbIc7eZ_Dh@02[]?O00ZV
am:O_/RJ][jE[KF?YJb:WJ>5U9YoS91jQ8MeO7hJoooo00Y`L75/JVYYIFAVGeeRFEMOE55MCd]JBTAH
ACmF@3T2EC`d01AD>2iD=2YD<RIF=BYH>2eN@CMRACeRAcmRBD5QBD5OB45NAT1MAT1KAD1JAT9IB4EJ
C4YKD51ICdmFCTh2E4e>01EAC4e?Bde>CE1?DUIBFEeEGfAKIfaPKgIUN7mZOXI/Q8e]R95^S9I`T9]b
UJ5eVZMhWjekY;=lYkJ;]<>H_l`00Y^ob`0:UKO2TJniSJVbRZ:ZQibSQ9FLP8nDOHV=NX>6Mgao7?oo
o`006_ooo`0:H75gI7=iJ7IkKGUnLGb1MX23NX>6OhJ9Q8Z<RHj@0XjBT`06TiJGV9ZKW:2PXJJVY:VX
Z:ZZ1JZXZ009ZjNWZjJVZZFUZZFUZZBUZJFVZZNYZJNZZ:NZ00:WYjX05JFUZJBVZJBVZjFZ[ZN]/JR`
]:Zb]jbf^jfi_jfk`ZjoaJg1bJg5cJk8dJg;eJg>f:_@g:WBgZG@gJ?@gZCAh002Z=?O00ZVc]ZPaM2I
_<JB/[b;Z;:3WjMkUIecRi=/PHUTN7hJoooo00YZL75/KVm]KFa_K6YaJVMcJFEeJ6=gJ65jIemmIed2
P6ML00N3Ie^7J5Z:Jeb?LF:CMfRIOFnKO7000Y]mL@04VWebVWaaVG]`VG]`0YQjL005Ug]bUgefUh1i
UX1jU7ii00:BOWT05I1lN8imN8enNhn3P968QYF>S9NCTibJVijPXZ2UYj6Y[:6//J:`]ZBe^jBi`JFn
aZK2c:K7dJC8djK=fZcDh@02/]KQ00Z^c]RXaLjQ_<BK/[ZDZK2=X:J6UiaoSI9gQ8Q`NghJoooo00Y^
L75]K6a[J6MZI69YH5eXGEUXFEAWEU1WDdaXDDP2JDi501AZC49/Bcm^C3maDDEfFDamHEF0HUMoHeUo
HeYnHeYmHUUlHEQkH5QjH5QiH5UhHEaiIF1iJ6AgIfEeIV@2LVIT01E_Hf=]Hf9/IFI^JfaaLG=eN7Yi
Oh9oQh^3SiB6U9Z8VIn8W:B9X:V;YJj=Z[F?/;^B]L6D^lRF_/^KaMBTcmd00Z_AgP0:Y/WDXL3:VkO0
UZngTJJ]RijTQYJKP8fANhF8MGao6_ooo`0:L71aK6YZJ6ASI5iLHEQEGE9?Fda8F4M2ET8lE3df0U8h
<00DDS@[DS0UDRlTE3@YFC`aGdDlHdLnHTU0HDU1H4U2GdQ1GDI0G4I0FdI1FTM2FDQ5FTe:FTm>F4m?
EDe=0U==CP0ED4Y<CDY<C4a?CU9FDEUMEV1TFVM]H71gIWR0JGj6Jh>;JhJ?KHZDL8jJLY>PMIVVNIn]
OJJdPJZhR[?2UKo=00:L`Lh02YJha9:a^hjZ]8^T[8RMY8FGWH6@UGj:SWZ3QWMmOacoool001[oool0
2V1aMfAcNFQfNfeiOW5lPGJ0PgZ3QWn6RHB:S8V>T0:>TY<01Y>FUiRJVibPX:6VYZBYZ:RZZPFZZ:P0
2J^WYj^VYZZUYJZUYJZTYJVUYZZWZJVWZZRWZP02YjNZ01FUYJVTYZVTYZ^UZZjW[K6X/;BZ/[N/][^]
^Kn]^l:^_lF]`LV]aLf^b=6]bmF]c]R[d=bYd]jUd=fSd=jTdN000ZSCg`0:Y/kJX<G@VKc6T[:lRjRb
PinWNiFMLh^CK869I7Qn6_ooo`0:JW1aK6i_KFe/KfaZLFYWLfUUMFQSMfQQNVMOOFMM0X1WG007PfMK
QfQJRV]LSg5RTgMXVGe_Vga`00:KOG4019YmLYYlLIUkL9UkL0:HNW001IMkLYMmMYN0NIJ0NYAnN@02
TWii01F@O7R>OGR=OW^?Ph2AR8JESXbGTi>LVY^NX::PYJNQZJbQ[;6R/;JT]K^T^L6U_/JV`/bVam6T
b=>VcMZ/e>400[;Fh@0:[/kHZ<G>XKc4Vk:jU:V`SJ2VQYNLOhfBMhB8L7]n6_ooo`0:KW1aKFa/JfQW
JVARJF1MJ5eIJ5UDIeI@Ie=<J5580VU>A@0DJTa2K4/oKT`oLE55MUU<OF5EP69GOf=IOf=JOV=JOF9I
O65HNf1HNV1HNF1IN65LNFEPNFQTMfMUMFIT0W9VI00EKf=SKF=RK6EVKV]/LG5cMGQjNGn2OhN;PhnD
QYBJR9VOR9bTRJ2YRjF^SJZeSk2kT[G1U;_8U[k;VlGDY<oM00:[dMh02ZK9e:70bY^g`9J_]i6V[H^N
Y8JFVh2=TG^5R7ElOa[oool02W1`LFaZJVQTHfANG65HEEeBCe]<B5Q7@UI2?5@m=P9B>300558d:e8`
9E8_95@d:ETl<Em5?6=7?V99@659@F19@Um8@Ee6@5a6@5]6@EY7@UU8AEY=BUY?CUQ?CeE=C@9CCDh0
5E1:C4e:C4a<CdiBEU5IGEIPI5YWKF1`MfIhP6UnQV^3Rf^6Sff:U72>VW:CX7FIYWVO[GfV]86Z^8Zc
`YFoc@02W<7>00ZF^<BB/K^>Z[B;Y:b8WJB5Uif1T9EnRXijPhIgOGlLoooo000Joooo00YPLGMTM7UY
Mg]]NWibOH5gP8=lQ8J1QhZ6Rhf<Si42TYBE00NGV9VMWIbRXZ6WYjJ/[:^^[Zf_[J`01:n/Z`:`[:/2
/:^[00F_Zj^_[:b_Zjb]ZZ^[Z:X00ZZWZ@0EZ:JYYjNYYjR[Z:^_ZZnb[K:f[[Fh[kNl/K_0/[o4/l;8
//C;//O>//[B//gF/M3I/M?L[mGO[MCP[MOU[][X00:/e^802ZS?fj;7dYbnb9Bd_HfZ/hFPZ7fFWWB<
Tfb2RFAhOa[oool02VY`LFa^KVe]Jfm[JG5ZIW=YI7EXHGQWGgYVGGiVG0:1IUX02hEWFXYWFHi[G9=b
HiUlKIj1Lj21Lin0LimoLiioLieoL`02WGic00NLOW>LOWBLOgJKPGVKPW^IPG^FOgT00YAnN@0ETWah
SgehSgmkTHB1U8Z7V92>VYFDWY^LXJ6SXjJXY:Z]Y:faYK6fY[FkZ;[1ZKo6Z/C<ZlWC[<_F[m;N/m[V
00:beN402Zo?fJ[7d:BnaYfd_9J[/HnQYhNHWH2>TgR5R75kOQ[oool02Vi`L6a[JfYWIVUSHFQOG6MK
EfIHDVIDCVIABVM>AP9XC4802fU:?fa8?6m;?gACAW]NDX1UFH=UFX9UFX5TFh1TFgiSFP02OF9J00Ml
HUYkHeakI5ijIf9jJFEhJ6EeIV@00W=UI00EL6=RK6=RK6IVKVa/LW9cMgUkNh23P8R<Q8nDQYBJR9RO
R9bSRZ2XS:F^SjZdTK2kU;K2V;g9Vl3=XLWGZ=?Q00:Ycm`02ZK9eJ;2c9fi`YRa^I:X[hfOYHNGW86>
TW^5RGEmOa[oool02Vm`L6]YJFMSHV=LFUmFDe]@C5Q:AEE4?e<o>54i<P9?=B`054l`9dl/8U0^8e@e
:e]1=V58?VA:@F=:@F59@V19@Ui7@Ee6@5a6@5]6@EU7@eY9AUY=BeY?CUM>CUE<C@9BC4d05Dm9Bda:
C4]<CdeBEU5IGEIQIEYXKV5aN6EhP6QmQFV1RVZ4SVb8Tfn=V7:CWgJIYWZO[GnW]8B[^Hbea9G0c`02
U[g;00ZE^LBB/[f?[;F<YJj9WZJ5V9j2TIInRXmkQ8MgOGlLoooo000Joooo00YPLGMUM7UYMg]^NWic
OH5hP8AmQ8N3R8Z9S8j?TI42UIJF00bLVi^TX:2ZYJB`ZjZe/Jnf/k2f/[2e/Jne/:jd/:jd/:ne/;02
][6`00Jf/[2f/K2e/[6d/K6b[jn`[:d2[JZ[01F[Z:VYZ:ZYZZb[[Jn]/;>_];Nb]kZd^knf_l>g`lNg
aL^hb<jgb]6gc=BgcmRgd]^geMjff>:df>>dg>RfhNh00[?Mj@0:[M?NY/[DWl39UkJoSj^dQZ6YOYNO
MXfDKH:9I7Qo6_ooo`0:JW1aK6i^KFa[KfYXL6UULVMRMFIPN6INNfELOVEJ0X9UF@0DQfIHSFQITfeN
VWIWXH1aYHEfYHAfY8AfXh9eXX5eXH5eX85eXH5eX85fX8=gX8AiX8ElWhInW8AmVH9l0YJ0NP0ETgeh
TGehT81lTXF1UH^8VI6?WYNFXYjNY:>TYZRYYj^]Z:jbZ;:fZ[JkZk_1[L37[lG=/<_D/LgG]=GP^MgY
00:hf^D02[?Bg:g9dZK0b9nf_IR]/i2SZ8VIWX6?TgV5RG5kOa[oool02Ve_L6][JVYVIFQRGfMMFVEI
EFEFD6ABBfA?AfE<@`9VBCl056Q7?6a7>g1<@7MFBX1SEXIXG8IXGHEWGH=VG85UFh1TFgmSFgiSFgiT
G7eVGWiWHGeZIGe[IgYZIgMXI@9dIV@05G1SHVeSHVaVIVm/KG9cM7MjOGf2QH:9SHF?U8NDVXRHWXVL
Xh^PZ8jT[Y6Z]9>a^iNg`Y^nbYk2cZC;fJ[DhP02Zm?O00ZXc=NTa<jO^lBJ/kZDZ[6>XJN8V9f2Si=l
QXUfOGlJoooo00Y_Kg1ZJ6QUHF1QFUUME55ICDYEAd=B@Ca?>cE==Rh2C30X01A;;29<:R1>;RAE>2eN
ACYTBd5UBd=SBd=RBD9PB45NAd5LAT1KAT5JAT9IB4AJBTMJCTaJCdmGCdiECDh2DT]=01E>BD]:BD]:
C51<DUI@FEiEHFMKJFmPLGQTMgiVNhAWOhQYPhe[Qi9^S9QbTYifV:EjX:b0YkF5ZkV<]/BD_lh00YJn
c00:UK[6TkBoTJfgSJN_RZ2WQiVOPi:GOh^?NhB7Mgeo7?ooo`006_ooo`0:H75fIGAiJGMkKWYnLgf0
NH63OXB7Q8V:Rhf>TI:B0YRGUP09X9fKZZJU]Jj/_KB``;Rd_kRd_KJc^kFb^[Ba00:i/k402KVc/[^d
/[be/kfg];bg];^f]KZe]KNb/[B_/002/Jb]01F^ZJ^/Z:Z/Zjf^[[2`/kFc]kVf^kfi_l:k`lJmalZm
bLfmbm2mcM:mc]FmdMRme=blf>2mfnBlgNNlh^fki?000[WSk`0:/MORZ/gFX/;;V[S0TJfeR:>ZP9RO
MhfEKX>:IGQo6_ooo`0:JVmaJfe]K6]ZKVUWL6QTLVIQM6ENMfALNVAJOV=H0X=SEP0DR6AESf]KVG=S
Y7e][8Mf[HUiZXQiZ8IhYXEgYH=fY89fXh9fY8=gYHAhYHIjYHQlYHUoXhV1X8MoWHAm0YV1N`0EUGih
TWehTX5lU8J2V8b9W9>AX9VHY9nOYjFUZJVZZZf^Zk2b[;>g[[Nl[k_1/L77/lO>]LgE]m3H^mWS_=kY
00:mh>/02[OFh;3<eJW2bZ:h_iZ^]I:TZXZJWh:@U7Z6RW5lOa[oool02Ve_L6]ZJVUUI6MPGVELF6AG
Df=CCV9?BF9<A6=9@09TAS/056E3=fY7>g9@@giLChUXFh]/GhY[GhMYGXEXGH=VG85TFgmTFh1TG7mU
GX1XH81ZHh1/Igm]JGa/J7UYI`9eIfD05G5SHVeSHVaVIfm/KG=dMGQlOWf3QX:9SHF?U8RDVHVHWX^L
XhbPZ8nU[Y:Z]9Fa^iVh`YjnbZ;2cZO>fZcCh@02[mST00Z[cmZWa]2Q_/JL]KbFZk:@XZR:VIj3T9Am
QhYfOH0Joooo00Y^KfmYIfMTH5mOFEMKDTmFBdMBA41??CQ<=c59<BX2Ab`S01A59Qa69ai;;REG>c5S
BCiWCTAVCDAUC4=RBT9OB45MAT1KAD1JAD5IAT9JBDEJC4UKCdeKD4mHD51ECTl2DDa=01E=BD]:BD]9
C51;DUI@FEiEHFMJJFmOKgMRMGeTNX9VOXMXPXaZQY5^RiMaTIifV:EkWjb1Y[B6Z[R=]/BC_</00YW2
d00:Ukc9UKK1TZniSjRaRj6YR9ZQQ9>HP8b@O8F8N7f07?ooo`006_ooo`0:H75fIG=iJGIkKWUmM7f0
NH23OhB6QXV:S8j>Ti:B0YZGUP09XYbI[:JS^[6]a;Vcbl2iakfg`kZe`;Nd_[Jc00:m]K802Kje//2f
]<6h]L>k^<>m^/:m^l2k^Kbg][Nb/P02]:j^01F`Zjb_ZZ^_[:fa/;6c]KNg^[bj_/2n`lG1al[2blg3
cM73cm?2d=G2d]S2e=[2e]g2f^73g^K3gnS4i^o3io400[oVl@0:]m_T[]3IY/G=WK[2U:nfRjB[PIVP
N8jEKh>:IGUo6_ooo`0:JVm`Jfe]K6YYKFQUKfIRLFEOLf=LMV9JNV9GOV9E0X9QD`0:QV5@SVUIWGIU
Zh9a]hil]8im/8]k[HUiZXIhZ8Ag0ZJ3MP08YhAgZ8EiZXUmZhb0ZXj3Z8f4YH^3X8Mo0Y^3O00EUWmi
U7iiTh5lUXN2VHf:WiBBXi^IYj2OZZJV[J^[[Zn`/;:d/;Fh/[Vm/kg2]L;8]lS>^/gD_=7H`M_T`n3Z
00;2i>h02[cIhkC?ejg5c:Fj`If`]YBVZhbKX8>AUG^6RW9lOa[oool02Ve_KfYYJFMTHfEOG6=JEV5E
DF1ABem=AUm9@F16?09Q@SL0564o<VE5>G=CAX=QDi9_H95`HXi^HH][GhMYGXAVG89UFh1TG81TGH5V
GX9YHX=^IXA`JX9`Jgm_Jg]/J@9fJ6D05G5THfeSHVaVIfm]KG=dMWUlOgf3QX:9SHF?U8RDVHZIWXfM
Y8jQZI6V[iB[]INa^i^g`Z2nbJC3cJ_>f[3Dh@02/mcX00Z_d]fZbM>T`<VN]kjH[KBBY:V;VYn4TIEm
QhYfOX0Joooo00Y^KVmXIVIRGeiMEeEHCdeCB4E?@Ce;>SE7<be4;BH2@RLO01@o81Lo91a;<BQJ?cEZ
CT=/DDIYCdIVCDASBd=OB45LAT1IAD1IAD5HAT9JBDIKCDYMDDiLDU5JDU9FCe02DDa>01E<BD]9B4]8
Bdm:DUI>FEiDHFMHJ6mLKWEOLgaRN85TOHIWPHaYQY5]RiMaTIefUjAkWZb0YK:5ZKN>]/BE_L/00Y_6
e00:VKo<UkS3U;6kTJZcSJ>ZRIbRQIBIPHfAO8F9N7j07?ooo`006_ooo`0:H71fIG=hJGIjKWUmLgao
NH22OhB6QXV:SXj>UI>B0YfHUP0DXi^GZJ:M^:nZakZddL>kcL2jb;bgaKZe`KNb`;Jb`KNd`[Vfa[bi
bKjjbl2kb/6lb<6maL2m`K^j^kFc0[J_[P0E/Z^[/:ZZ/:b]/[2b][Jg^[^m_/72`lG7a/[<b<k@b=3B
bM;Eam?Ga]GIamOLamWOamcRb=oVb>;Yc>W`bncd00;6j_<02[cNi[?BfZW7cj2l`iJ`^8fU[8>JXGV?
UVn4RfIiOa[oool02VY_L6Y/K6]YJ6aWI6eUH6mSGG9QFWEPEgUPEGePD`:1H5402XEOCXYVEI]eIJj5
LkjCOkZBP;F>OK6;Njf7N:V5M`:XQ7L02:Z6NZf9O;2<Ok2?PZnAQJfBQjV?QZ>9P@:MQ7d05IMoNIAn
N9>1O9J7PYZ=RZ2ETZBLVZVQX:fWY[2/[;:`/;>d]KBg^KBj_[Jo`kS3b;_8ckg=e<3BfLOLi<[Tk@02
bNSb00[1gNFid]ZaaljX_L>P/[RGYjb>WJ65TYIkQh]bO7lJoooo00Y/KVmYJ6QVHf5SGE]QEeANDTiM
CTQLBD=LASiM@ST2GCld01AN?31P@cMbDdN6I5JJM6BGM6FBL6>>KF69JUj4IUb2IEb0I5^1IEj3If26
Jf>8L6R8Lfb6M6n3LfmmKV/2MfUV01EaI6=]Hf9/IVI_K6ebM7IiO7imPhJ1R8b6Si>9U9Z;VIj>WZF@
XZVBYjnE[;FI/K^M]l:Q_LRU`/f_c]ZffND00[SPk00:/mKP[LcFZ<;;XKW0VjnfU:F[SIbPQY:FOXR;
Mgj06_ooo`0:KFi^IfEUHEeLFeECEDe;CdE2BSdiASHa@RlY@2TR0SdS6`0D>QhE>b<KBS8ZGD8hLUA7
L5A9K557J4m6I4]3GTM1FTE0Ed<oETA0EdE2FTU6GDm;Ge9@GUECG5EEEe9B0U9>C`0EC4U<AdQ;AT]?
BE5EC5QNDF1VEFI^FFadGG9jH7N1Hgb5Ih6<JXJAKH^GLI2MMIJSNYf[Oj>aQ:RfSkC2VL3>00:NbML0
2Yc2ciVkaYJc_I>/]HnU[8^MXhJEVh:>TWf6RGQnP1coool001[oool02V1`MVAcN6UeNVihO7=kOWUo
PGn3QHN8RHn>SYRDT`:PVYL05:JNVjjUX;nc[<bm]MK5_=72^/bn]lNk]LBg/[nc[[jb[[nc[l>f//Vk
]/no^/o1_Lc1_LW2_/Fo_;ff]0:g[jh05K>ZZK2YZ;2[Zk>`/;Nf]kbm_[o1`/?6alS<cLcAd/gDeLkF
f<gFfL_Gfl_Ig/cKh<gMhlcPi/cRj<oWkM3/l`02bngd00[1h>RgeMb^bM2S_/BI/[V?Yjf5Vj9kT9I`
Q8]VNH0Joooo00YYKW1YJf]ZJ6MZIF9/Hei]H5Y`GeMcGUAgGU9mGU42PUi?01B6HE6;IeJON6JdR7G5
Uh:oU86iT7jdSGb_R7VYPgFVPG>UP7>WPWJ]QgZcS7nfTHBcTXJaU8V^U8ZUS8@2WXEm01FHOgRDOGNC
P7ZFQX6JS8ZQUI:TViVXX9n^YjJb[Jfe/[6h][Nh^K^h_;ni`<Bla<VnbLo0cM?2dMS:fn;@i^h00/k[
m00:a^3X_MGL]L[@[;o5X[BiVJV^T9jRQY>GO8R;Lgf06_ooo`0:K6i^J6MWI65PHE]IGUEBFdm;FDY5
F4DoF48jFClf0U/l<@0DG3dbGd8gLeE8RfQIXGUXW7MWUW=UTG1SRf]OQ6ILP6=JOF5IOF=KPVMORFaT
S79ZRgA]RWMaR7QcOg5^0WQZJ00ELFARK69QJfEUKF]/LG9eMg]nNh65OhN;QHjBRIBIS9ZOTInUTZ>Z
U:N_UZbeV[6kWkO2X[g7Y/7</LkI^mcV00:nhnl02[SIhk7?f:_5cJBk`Yfa]iJW[8jMXHNCUWn8RgMn
P1[oool02Ve]KVITI5mKFeQCDE9:B4]1?dHi=D4a;CdZ9CXT7P8h7aL053LM5SHQ6TTc:f56?7QHBgAG
C71DBV]AB6E=AEi8@EU4?eE2?U=3@5I6@ea;Af5BCV5CDF5GEF1JFEUEE@9BCe005D]:C4I8BdA:CTI@
EDUFGDmNIU9TK5IZLUY`NEifOf9kQFR2S6Z6TFb;Ug2@WGFFXgZLZWjR/8>W]I2d`ig3d@02X/gK00ZO
aM6L_LRI][nE[[JAYZj<WZF8Uib3SY=nQXYiOX4Loooo000Joooo00YPL7ITLWMXM7U/MgYbNWagOGmn
PX>6QhN@SXfKUY@2Y9bH01BYXIf/Xink[jS<_;?Ia[cD`[W?_[K:^kC6]k31/Zbk[JNgZjJeZZFk[Z[3
]:o8^;?7]k;3][;1]k>l/k42]jj[01FcZJN`Z:J`ZZVc/:ng][Jo`;o2`l?8bLW>d<oBe=GBe]OCfM[B
f]c?f]g>fmk>gN7@gnCAh^KCiNWGj^kGkO800]7^l`0:a^;X_=OM//_AYko5W;BjTJR^QibRO92GLHF;
IWV06_ooo`0:JFi_J6YZJ6MUJF=PJF1LJUeGK5]CL5YAME]?O5e?0X=NC`0DQf=CRFIGWWQV]XYfbIZ5
`iJ2_I9o^8im/HUiZhAeY7i`X7e`W7]_XX1c[8Mj/Xf0/Xj2[Xn5[967YH^30Yj5O@0EV7igTgafTWii
U8F0V8Z7XYJCY9ZHZJ2O/JRV]Zn^^;>b_;Rh_;^l^kk0^l34_LG9`LW>`lkCam?IdMkTe^S_00;DkOD0
2/_RjL;Gg[W<dZo1aZJf^ibZ[i:OXhNDUgf8S7=mP1[oool02V]]KVMVIV9PGUiIEe]BCeM<B5A6@E=1
>U<m=EDk<P9J>c0055`n=5e3>GAFBXm[FjImJj1jJIYeIiAbI8i]HHMWGGmRFG]PF7INEgaSG8I[HXab
JXecK8]fL8QhLh1bK`9hJfP05G5THV]QH6UTI6]ZJfe_LWMlOWV0Pgf5RXB=TH^EVXjKX9>QYYFUZiJX
/9N/]I^b^ing`J:lajS2cKKAfl7Nj002`nK`00Zlg>Ffd]Z_b<nX_LBP/kVHZJj@WZ:8U9N0RHahOX4J
oooo00Y/KFiTHfAMFUYED4m>AdE7?S]0=34j;2Pe91ld7aT2=1`D01@e7QPe8ae;=RiVBSmnGDmiFTic
Eda]DdYWCdMQBTAJAT1GAD5A@T1FAT=OCTUTEE5VEeAUFeUSGEaJEeP2DU1B01E;BTa5AdY2BDe4CUA5
DUY=GVI>HVY@IW1FKGIMMGmRNhEXPXa[QY9]RiM_SiedUJ=iVjUlX:n3YkJC]lBQa]<00ZK@g@0:XlOC
Wl3:W;S1V;2hTjR_SZ2VRIRMQ8nDOXN:NGn17?ooo`006_ooo`0:Gg1fHg9gIg=gJgEiL7MjMGYlO7n0
Q8F5Shf<WiZH0[2XX`0D/JJQ/JNQ_K2Xc[bbg<Nlel>idKnfc;^cb;R``k>/_JfV^:VS/JBO[Z:M/ZFP
^J^W_ZnZ_k6]_[>_^k6^0[N]ZP0E/jVV[jNT[ZNV[j^Z/:f]]kJf_[fka/G4clk<dM?AeMOFf=cKe]cL
dmcNcm_Nd=cPd]oSe>?Wf>O[h>kah?;f00;HlOH02/cUj/7JgkK>dj_1aine^iBY[hRMXgfAUg:5RfMj
P1[oool02VQ^KfMZJFMUI6IQGVIMFFMJE6QGCf]EC71FBWYJC0:<IUD058eXEhm[Fj1iJ;V<MljMQlNH
Q<2DPKZ?O[B;Njj7MjN0LJ9mKiYiK9YjKZ1oLjN6Njb:Ojb=PjV>Q:B:PP:NQ7d05IMnMi9kMI1lMi61
OI:5PYZ@SYjETZFLV[6WY;J^[;Zc/L2j^Knm_Kk0`Kc1aKk4bL78cLC=d/_Df]SRin3]lP02fo3g00[A
iNc8f^2ncmBc`lRY^;bN[;2DX:B9UIQnRHadOH0Joooo00YZKFiUIVEPGUeLEeEGCdaCB4A?@Ca<>cE;
=Rm>=B`2GT0d01AO@cQRB3efF4bCKEf[PFjUOFbNN6VGLfJAKf>:Jf23IE]nHUUgGeMjHEZ0Ien7KfN<
Lfb;MW26MW60LVh2N6]X01E`I69ZHF1WHV9XIfUYJfmaN7]bNgmgPHJ4S92:U9V>VYnFXZNGYZbHZ[6G
[KJJ/K^N]/2Q^lJZ`ljle=g9h^/00/WYlP0:`MoW^mGL/l[A[<36XkFkVjZ_TZ2TRYFHPHZ=N7n16_oo
o`0:Jfa]Hf=SFeQHDdi>BTA3@SXh>Rl]<RDR;1`H:1D@0S@M5P0D=B4K>BLQCCTaJTe2Pf5COEiAMUU?
L5E<JU5:I4i8GDU4FTM3EDE2FDU6Gdm;IEIBJ5YGIeeKHEaLFUQI0U9ADP0EBTY<A4M:@DQ=@TeC@e5J
BEeUB5iXBV9]EVafGGEoHGZ4JH:<K8NBKhbHKi2MLYFSMiVXNIn^PZNfU[W6YlWF00:Zd]h02ZK:eJ?2
cInka9^c^YJZ/I6RZ8^IWXF@U7n8RgUoPAcoool001[oool02Um_MF9`MFEaMFUcMVedMg9gNGMjNgmo
Oh^9R9ZDTP:_Xih05;^]Y[b^YlBdZm2m/]g7^mS3^=>o]Ljk/LZj/<Je[L2_Yk^YXKJUW[FUWKJVW[VX
XKb/Y[j_ZKf`Zk^_Z`:g[:P05K>XY:nVXZfUXjfXYjjZZjn`/Jnb/k6f]l31`LG9bLW=c<oCdloEeLoG
f<kIfm3Lg]?NhMGRiMgZk>C`lnOhnP02h?Oj00[CjNg7gN6jd=B^`lRR]k^FZZn:WZ=nTYMcQX]WNX0J
oooo00YWKFiVJ6QUHf9TGeaSFUIREE1RDDYSCTEWCD5dE4H2RVAD01BEKUfILV6XOVblSWW@WhS9VXG3
UH:lT7jgSWbbRWZ[Q7FUOW2QO6jPOFnSP7:VQ7NZRGf[Rh6XRh6TRH02WH=k01FGOWJBNgB?NgF?Og^A
Q86CRhZCSHfDTI6WWij/Z:Na[Jbj][Fk^KVl_Kjk_l>l`lO0alc2c=7>e]_Mi>SWlOD00^?fn`0:f>[_
cMkS`m;F]lK:[;ZnXJjaUZ6URYFIOhV<M7f06_ooo`0:JVa]I6ATGUaKFEABDda9CT=0B3/g@c<^?R/U
ARlW0U/o=00DIDTmJTi3OEi@Ug1P[hAaZ7m^XGY[VGAVTg9USViSQfUOPVAKOV9JOVAKPVQPQVeURW=[
RGA^QGA_Og5]0WMZI`0EL6AQJV5PIf5QIfIXJF]_K7=hJgIkK7V0OhR=QI6FRIJKU:2UUZBZUjV`UZbe
V;2iW;BnW[S4[<G?`=KNd>K^00;?kOH02/SRj/3HgkS>e;33b:Ng_9j//IFQYH^FVH::SGUoPA[oool0
2V]/KF9RHUUGEe1<C4M1@3df=3@Z:2TN6ah@3B0@308a7AP053PV83d/9U<m=FiAAHMUEX1QE7YLDW9F
CVaDC6QBC65>B5e:AUY9AUa<B5m@C6AFDVMKF6ELFf1KFeUGF09BD5805DY:C4A7Bd58CD5=Dd=BFTIJ
HdILITEOJUM]MUadOV1iQ6^3SFf8Tfn=VFj?WG2CXW>HYgBL[8>X]iVjajc<e`02[mGQ00Z[cMRXaLnS
_LJN]KfI[;>CY:V=Vin7TYF0R8]jOh4Loooo000Joooo00YNKW=QKg=TKg=WL7=ZLGA]LWAbM7EfMWIj
MgJ=Qh@2Wi>?01B`XI^iZJ;4/ZW@_;7Mak[I`kSD_kC>^:k9]:[7]:[5/Z[1[ZJnZZ:mZ9nnZZ6oZj?0
[ZK1/:Rm[ZNj[JP2]j^V01FcYj>_YZ:]YJ6]Z:F_[:Za[jn_/;6Y[[2^/kBe^kbk`/?3bLW8c/k<dmC>
e]O?fM_BgMoDh>?NjN_VlO7ZmoP00^Gjo00:fNg`c>3S_m;F//G9YKRlV:^`S9jSOi:GLhJ<J7Z06_oo
o`0:Ifa]IFMWHf5PHEaIGeIBGE5;Fd]4FTDmESdcJDa00WaIB`0DSVQHVG9Q[85^_i1kdZ29c9b7aIN4
_I1n]haj/hYj[hQhZh=eZ81bYh1aZH=eZhIh[HYm[8b0Z8YoXhMn0Yf2NP0EUgefTW]dSg]dSgmjTXB1
U8Z8Thb<Shf>V9JFX9jOYZJW/:n_]KFe^;Zl^Kg0^/75_LG9`<W>d=OKh>GXjo7e00;YnOh02]o^l]?R
iLSEfKc8c;2l_jB_/iRSYXbFVH2:SGEnP1[oool02VU[K6=SHeaJFEIAD4m8ATPo?44e<CT[9RlN6D0/
909A>2l05697?6eAAXARE9]cHk:6LZ^2L:AmKI]fJIAbIHm_I8]]HXIYGh=VGH=WGXE[HXQ^IXYbJhYe
KhAcKGi_J`9gJFH05FmTHVURH6IQHFIVIfU/KVabMfaeNf]hOgJ2R7f:T8BBV8jLXY:QZ9>V[YBY/YF^
]iRb_9^f`Jo6d<CGgmCVkP02e_7i00[>ink6g>:mdMJdaLZZ^[jQ[[:GXZJ=UiZ3RhiiP88Joooo00YZ
JfaQHF5GEEE=BTY3?Shi<S4^9R@Q61HB1`DO4@h2;1/G01@i:B=4<R]LA3YdEDV:IeV4I5MmGeEeFU5^
EdmYDdeTDD]OCTUMC4QMCTYPDTiSEU=UFUMTGE]OFUYIEUL2DE1B01E9BTe3B4a0B4e0CE=2DUY6FF96
G6M8HFaDJgEJLWePNHAZPXe[Qi9[RiQ/SYa]TZ5_UJEaVJZ6Z[RM_<V`c=P00[CIi00:/M7K[LWBZ<79
X[RoW:neUZJ[SibQR9>FPHV<NX227?ooo`006_ooo`0:GVecH6ebHVeaI6eaIVe`JFe_Jfe^KFe]Kf][
PWai0YF;QP0DYIRB/Z:K`ZjUdKZ^g/FhflBheKndd;V_bK>X`ZbR_jVO_:JL^J:H]9jE]InE]j2G^JBK
^jRP^jZS^ZZT0[NZY00E/jNR[jFP[JBO[JNR/JfY];:_];>b/kBd];Ng]KVi^[jn`/K5alc;b]7@cMGD
cmWIdMcMeN3QhNWYjO3_j_Ce00;[o?d02^3alm;SiL?DekG6bJNi_9Z//8fOXh2BUgB6S6QjP1[oool0
2VI[KF=UIF5OGUiIEe]CCeQ<AeE5?e4n=T/d:em4>@9cE4L058IRE9I`H:b0KL6@Nm>ORLnNRLNIQL2C
PKR=Nk66MZb3M:R1LZInL:9lKZ=nL:F0LjR4MjR8O:J7O::4N`:MPGP05IMnMI9kM8ijM8imMi:5P9J<
R9N>SIRBTI^GUinLW:FSY:f[[;:a/[Fg^KNk_KVo`[_3al38cM?HfnGVj>__lP02koco00[Vl_GJi^W=
f=_0bljc_/6V/KBJY:N=UiZ1RXeeOX4Joooo00YXJfaQHV9JF5QCCdi;AD=4>cPk<2db9B4W5a<h9R02
BSD]01AMA3Y_DTJ7I5FOMVFcQW>_Q7>WP72ONVfGM6N@Kf>;K666JV25J5j3Iej4JV26K6>7L6R7Lfb3
L6]mK6P2MVQU01E_I69YHV5VHF5TI6EXK6e]LgI^MgaaO85fPXQkR8j1T9J:V9n=WZF?Xj^AYk2CZkFC
[kZI]L2aam3:f^3DiN`00]_dnP0:eN_acN3V`mCI^LS=[[c0Y;2dVJBWSiRKQ8b>NX226_ooo`0:JF]/
Gf1PEEADBdQ8@3`l=Bl_:B8Q71@B3@@26Pl<0RPK5`0D>2TSBCH_HDLmN5U=S6UKQfMKP6=INEmFLUYB
K5I@IeA?HU9>He9=HE9>HeEAI5MDIEYHI5eKGUUIEeAE0U1>D@0EBD]>@dU=@4Q>?T]B@55IAEURB5eW
C6=]DVYdEg1kGGR3I7n;IXB@IhRFJ8bJJHnOJI:SKiRYR:^jY;o;/<cG00:ifnH02[OEg[?=eZg4c:Nk
`Z2a]iVX[I6NXXZDUh>:SG^0PQcoool001[oool02Ue]LUi/LF1[Kf5[KV9YK6AXJVEWJ6IUIFERHGE`
KP:8P7`059Z>RJbLUKj[XLjh[=g3]]g5^=S1]M:l/LffZlJ_Y<2WWKZQUkNNTkFKT;BJSkFKT;ROUKZU
W;bYXK^YX`:iZJ<05KFWX[2UX:bQWZROW:VSWk6^ZKNe/K^j][^k^Kbn_;k1`<?6aLO;b/[@clcDdlgG
e/oJf]GPh>3Xingbl>ogmP02lOoo00[[n_[Gi^O7e]RgalZY^KbK[:n>Wj>1TYMdQX]XNX0Joooo00YU
JfaRI6ANGEaKEeEGD4aCB4=?@3Y:>313;RED?382JDe101AnGDnCKEfZOfc0T7_BWhSBX8[;W8S4UhBm
TH2eRgZ^Q7FXP7:WOW2TO6fSO6jSOFnUP7>VQ7RUQ7ZRPWP2WX1g01FHOWJCO7F>NWB:NGB;OWZBR8>I
Sh^OUY>PVYRRWYfVY:B/ZZZ`[k6c]KNe^K^f_Kng`<C0bLgDf=_Yj>W^l?800_Cmo`0:lo_mhN[/d]_N
a<g@][o2ZK:eVjFWSiRJPX^=MGj16_ooo`0:J6Y[H65QF5MFD4e<B4=1?cPe=R`Y;20L8A<?<20K0T@a
:@0DFD4gKU55QfAFX7MV/hIc/XMfZh=dXgiaW7U/U7AXSViTRFaRR6YQQFUOQ6YPQ6YRQFeUQ6mXPFiX
NfYV0WIWI00EL6ESJV=RIV5RHV9SHfMYJG1cKWMjMGj2NHB9O8V>P8nEQYJLRI^SS:2YSZF^SjRbSZ^f
V[K1/lSAc]_QeNG[00;Nm?X02^7dn=GVj/WHg;k;ck:n`ZNb]I^UZ92IVhF<SgZ0PQ[oool02VUZJeiO
GeACDdU7Acdj>S8];BDP7aPA40T20AD=2`8V6aL053PY8d/g<6=9?gYKCheYFh]ZGXAWG7eSFWIOEg1K
E6YHDfMGDVMFDVAFDFAGDf=GE6=IEV1IEe]FEUEADP9?CU005DU<CdA:Cd5:D3i;DSi?F49GH4ILITeS
KU5ZMEE_NUUePEikR660SV>5U6F9VFF<W6B?X6nIZX^]^jO0bjo;eP02^MWT00[1g>Bjd]Zcb<n/_/BT
];VLZZjDWj><UIR4RhelP88Loooo000Joooo00YLK79MJVmNJFeNIf]OIVQOI6EOHF9OGUmNFeY]IfD2
OWIb01BAQX2SU8fgY9_;]:SJ`K?NaKOJ`kKF_[?@^Zk;]:W6[Z?2ZIjoYIZmXiNlXYNlXiNmYIVmYifm
ZZ:lZZ<2^ZZT01FgZZBcZ::_YJ2ZXYjUX9bTXYjXZ:Bc/Jjl^kO1`Kg3a<76b<G8blW9c/c9d<o;dm;;
eMGEgMgQinG_lNgdmo@00_3in00:kOSgf^OWbMOH^LO9Z[VlW:b_SYnSPI:GMHJ;J7Z06_ooo`0:IFY/
HF=SG5]JF5ABDde9CdE0BC`f@c</?BTQCCH/0V16>`0DMUQ:S6QIYWaZ_Hijd9f6dj6<cYn;aiZ8`IF4
^i1o]H]k/8Mg[HAdZX9bZH5bZ85bZ89dYh=eYHAhXX9g0Yj1M`0EVWmgUWigTGegS7]gR7]hRH1mS8J4
Ui2=X9VGYYnNZ:FT[:VY[jj_/K>e/[Jh/[Vl/[c0`LS<eMSJjNKVlo7a00;en_/02_WnonO^kmONh<O?
dKW1`j^c]IfUZ92HVh>;SWInPA[oool02VMZJemPH5IEEDi;BTE0?S`e<c8Y9RLM6Q`@32/L5`8n;BH0
55@n=6]?@hISEIifIK:5L[B9Mjj7MjN2M:1nLIUiKI=eJXmaIha_I8U]HhM/HhI/HXA/Hh9/I7m/IWYY
I09fIf@05G5VI6eUI6UTIFATIV5UJ6=[KVIaMG1jOWN2Qgb9SWn?UHBDVhNIXHZOZ8^R[8ZU[hZX/ibg
`KC9dLcIg]WVj`02h?;g00[[n_gLj^k?g=o2c]6f`LBZ/kJNYZVBVYb6SHmkP88Joooo00YYJV]NGUmB
DU97ATHk>CT_;2/R7QhE40l70@0C30X291XF01@g:2=;>35TBT1jFdn<JE^=KF27JV20IUiiHeacGeU^
G5M[FUIXFEAVEe=TEe=REU=PEU=LE5=IDe=CCe42CTe?01E:C4m6Be52C58oCEDmCeQ0EEi3FVA:HVa>
J7=CKWYFM81KNHINOXaQQ9=RQiMPRYYOS9ibVjb<[[bS_/Vbc=H00[gJi00:c>C[`]SO^/gC/L;7Z;Nl
Wjb`UZ6USYJIQH^>O8637?ooo`006_ooo`0:G6]aG6U^FfM[FfAXFf9UFemQFUaMFEUIEeEDI61O0WA^
JP0DRGiiW8j7/InEa[2Sf;j`glJgg/FhfL:fe;jbd;Z^c;FZb;6VaJfRa:^O`ZZN`ZVM`ZZO`J^P`JfS
_jfU0[f]Y@0E^jbU^:^U]:ZU/:RSZjJRZJFRYjJSZ:RV[:f[/kBb^;^i_L2n_l?1a<W7alg;bM3?bM7A
d][HgN;Pj>WVlO3]00;amO802^kfm=cViL_Fe[[7b:^h^Yb[[XnNXX6BUWF5RfQjOa[oool02VAZJemR
HUYJFEEBD51:AdY1?DDh<ch_:3LU7THb:@9H@3H0571BAXITEJ1hI[R;M/jKQ=BRS=6RSL^NRlFJR;nE
Q;ZAPKJ=OK:9NZn7Mjf5MZb4MJZ4MZV4MZN4MjB3N0:PPWP05If1N9V1NIF1NY60Nhf0O8b1Oh^4PXj9
R9>@SiZGUj2OWjFTYJRYZjf_/Jjc]Jnf^K2i_/37b];EenCRh_;_k`02nOWi00[mooo/l?7Kh>7:dM:k
`/>//kFNYZR@V9^3RhifOX4Joooo00YWJFYNGemEE5A<BDQ2?Sdh<c4^9b@S6QLH3PXW6QD2>2PR01A@
>S9WC461H5:JLf>`Pg6eRWRaRWZZQGNSPWFMOG:HNVnCMVb?LfV<L6J9KfF7KF>5K6B2JfAoJVAkJF@2
MVMT01EcIfE_IfI[IfQXIfUUJF]UJfmUKgAYMGY_O89fQ8YjRi:0TIR2UYn6VjF6WjV6XZf8Y[:L]l2c
alo8emcKi^X00^Odm`0:lOcohnkaeMoRam7C^L?5[;FgWjNZTiZLQhf?Nh626_ooo`0:J6Y[GEiNDE5B
ATE5>SPh;BXZ81dM4`l?1@404P`:0R4H5@0D=RLSBSLaHTU0N5Y>RVQKSFiQRFeRPfUQO6IOMV=MLF1K
KEeHJEYFIUQDHeMCHEEAGUAAFU9AEU1@DTi?0Te<C`0EBTa@AdaBA4eD@DiG?e5J@5EN@EUSAUmZC6Ib
DFeiEG>0FWR6Fgf<GX:BGHFEG8RIGXbNM9f]S:jlX[k9]/oH00;5g^H02]CXkl[Mhl3Ae[K5bZbi_Z:^
/YVSYXnGVXJ<Sgf1Pacoool001[oool02U][L5YXKEUUJEURIEQOHEIKGEEHFE=DE59@D61LF`9^J6D0
3h5gLYJ8P:^JT<6[WmFl[N36]n38^]c5^=S1]MBn/]6j[/jgZl^dZLZbY/RaY@02ak2T00?6/:G5/JO4
/JL00/:aZ00E_k6Y_K2Y^JnX]ZfX/ZbW[j^W[J^X[JbY[Jj[[k6^/kFc^K^i_L6o`LG4a<W8a/g<bM3?
d=KDf=gJh>?PjN[W00;^lNd02^kdl]kWi/_Ee;[5aZZg^9bY[8jMX86AUGB5RVQiOa[oool02VAYJeiQ
HEUIF5=@CTe7ADLn>T0e<3X/9C<R6d8_9`9C?3<056U=@H5PDIYdHk>7LlVHP]FSS=BTT<nQS/VMRl>I
R;jEQKZBP[N?OkB<O;:9N[27N:j7N:b6N:V5N:J5N0:SQ7T05J24Nif4O9Z4OIJ4OY>4P966PY28QI6;
RI>@SiJDU9^JVj6PXZBVZ:R[[JZ_/Zbc]k6i_L36bM3CeMkOh>k/k002n_Sg00[ooooam??Nh^;<dM:l
`/>]];FOYZRAV9^3RhifOX4Joooo00YVJFYMGUmCDe=:B4M0?3/f<Bl[928P61DE2`PT6A@2=BHP01A;
=bmSBCmlGE2EL62[P6nfRgVdS7b]RGZWQGRPPGFKOG:FNFnBMVb>LfV;L6N8KVF6KFB2K6AoJVAkJF@2
MfQT01EdJFIaJFQ^JFY[JVaXK6iXKW5XLWIZMW]]Nh5aPHMfQhmkSYInTib0Uj61W:J3X:^9Yk>M]l2c
alk6e]_KiNT00^_dmP0:m_koj_?ef^;Tb]?E_<C6[[JhXJRZU9^MR8j?O8626_ooo`0:J6Y[G5eNDE5B
ADA5>3Lg;2XZ7a`L4Ph>10004@/:0QlG5@0D<bHRB3H`GTLoLeQ<QFIISViRS6mUQFaSOVURN6IPLf9M
KUmJJUaHIUUEHeICH5AAG59@FE1?EDi>DDe>0Te;CP0EBTaAAdeCADiE@U1H@E9K@EEO@UYTAEmZBVEa
CFYgDW5nEWJ5Eg^:F7j?F8:CFHFGH8fOMYn^S[2mXl3;^]7I00;<h>L02][[l=?Sj<OFf[_9cK2l`:F`
/i^TYi6HVhN=Sgf1Pacoool001[oool02UYZL5UWJeMSIeIOHeAKGU9GFE5CE4i?Cda:BUYFE09XHUh0
57Y`Jhj0NJJCRKbUVM2gZ=o4]N?:^mo8^]_5^=S2]]G0]=>l/=6j[/nh[LjgZlffZ/beZL^eZLZeZlVe
Z`;7]J`05LFe[<:e[Knd[;bb[;VaZkJaZkBa[;>a[;Bb[[Fe/KNh]K^l^Ko0_/;4`/C7aLG:b<W>c<oC
dMKHeMgNf^?Th002jN[U00[Yk>WLhn79dM2h`/:Y];FJYjZ=Vij0T9=dQ8UXNGlJoooo00YSJFYMH65G
EeMACTe:AD=3?3Pm<Rhe:2<^7QLn;2@2CST_01ASB3ejFTbDKUj]PFk4TgkCXH[GYi7BY93<X8k7WHc2
VHVnUHFkTX:hT82eSGfcRg^aRWZ_R7V/R7ZZQgX2YhIk01FTQgfQQgjNQh2KR86HR8:FRHFES8RESXbG
TY2IUYFLVi^PWj2SY:JVZJ^X[:nZ/KBc^Kg1aLS?dM?MgMg[jNT00_Sel`0:o_ckloGdgn;RcM7B_<;3
[K>eWjFWTIRJPh^=MWj16_ooo`0:IVUZG5eNDU9BB4M6?S/j<bl]:B<Q7AHD4PT68QLC0S8T7P0DAc</
GDDkMeQ<Sf]LYGa[]8Ug]Xin/8]mZHMkXhAhWH1fVGaaU7U^T7I/SG9XRW1VQViUPfaTP6]TO6YT0WUY
IP0EMVYXM6]ZLFa/KVe^Jfi`Jg1dJgAhK7QmKgb2LH68M8J>Mh^DNi6JOIFOOYVSP9jYS:VdXKS1]<O>
amKKfnGX00;^loD02_Smo_7gn=kUi/gDeKk5a[2f^::YZYFKWHR>Sgb1PQ[oool02VQZJeaMGU1@DDA4
A3Lg=b/Y:QhL710>3P<0010<2`8N5aD0530T8D@d;UY4?FiDBX5SEha]HHiaIhM^IX1[I7YWHWATGfmP
FfYLFFIIEV9FDemCD5]ACeM?CU==CTm<C@9<Bdl05DY=DDM>DdE?ET=AFD9CG49FH4=KIDEOJdQTL4]Y
MTe^O51cPU9hR5=lS5AoTEJ4UVB@XW^R/I6b_jK2c;gBfP02d^;X00[PkO7LjNg=f]g0blnd_/6X/KBM
YJRBVI^8SHmnPX<Loooo000Joooo00YJJW1IIf]GHfMFGf=DFeiBEeUADeA>Cdm<BTYJEU@2J69N01Aj
L6^>P7VVThVlYIW@]jSOa;GSb[_Ob;[KaKSH`[KE`;CC_;3A^Zk?^:g>]j_=]Z[<]JW;]JW:]J_9]J/2
akF/01G5]Jc2]Jfo]:bl/Zbi/J^f/J^d/Jbc/Jbd/Zje]K6g^;Fk_;Vo`;k2a<;4alG5b/S9c/c?dm7F
f=GMg][Si>000^WZi@0:jNcYg>?QbM7@^<;2ZKBeVZNZSI^NP92CM8B9J7Uo6_ooo`0:HfUZGF1QEeMG
DDi=BTE3@c`h?C8^=BPS;QhG?R`T0Thi;`0DHdPmNUY<U6iN[H5^a9=ndj6:ejNAdZB@c:2>aif<`YV9
_YF5^i:2^920]Hem/h]k/HYj[hQi[8QjZXMj0ZN6N`0EY8MmXHMnWXN0VhR1V8R2UXV5UHb8UHj<Ui:@
VIJEW9^KX9nPXjBVYZV[Z:b_Z[6d/kVm`LG8cm7CgMgMjnWY00;hmO<02_klno?em=oRh/gAd[c2`jfc
]InUYi6HVX>;SGInPA[oool02VIYJUaMGU9BDTQ7AShk>S<_;BTS8AdF51891R8G4`8b91h054Lc;5e5
>gMHC8m[G:ElJkB9MkJ>O[2;OJV7Nj>4N9f0MYUlLIAiKY1fK8ebJ8Y`IXI^IH=/I81[I7aZI09iJFH0
5GIZJ7A[JW5/K6i]KV]^L6]`M6]dN6ahOFmlPW61R7B6SWN;U7^AVWfEWgjIXh2NZHbY]:6h`KC7c/OF
fm_Uj002k_?e00[hoOkamoSNiNK=e=FnaLJ`][RRZJZEVif8SXmlPH8Joooo00YXJV]LGEi@D554A4@g
=cL[:BXN71`@3Ph3000@30/27QLE01@`9254=2iJA3e^E4Z1HeN<KF6>LFN7KVJ0JfAjIf9dI5m_H5]Z
G5UVFEIREU=ODe1KDDmGCdiCCDi?C4d2C4]?01E:CE57CU=5CeI3DEU2Dea2EV13FfE5Gf]8I71;JGI=
KWa@Lh9BN8QCO8aDOi5FQ9ITT:9kX[6A/[nV`/bmd]X00];Rj00:h>gag>W]cM[M`<_?];k1Z;6dWJFX
TYVKR8f?OX:37?ooo`006_ooo`0:FVY_F6EZEV5UDeePDEQKCeAFC4m@BTY:ATE4E55?0V=LF@0DLfUT
QWUaW8^1/YfAajjPf;f]h/RhhLVkg/RjflJifLBhel:fe[nce;jadkb_d[^_dK^^d;Z^ckZ^c[Z_0/bj
/00Eb[Z`b;V`aKV``kR`_kN`_;J_^kJ`^KJa^KNb^[Rd^k^f_;fi_/2m_l?0`LG3`/O5aL[8blo<dMC@
e]SDfmcH00;Ph=/02^3QgMKKf<C;bKBm_JJa/YRUYhbIW7n>TW>3R6MhOQ[oool02V9XJUaOH5EFETi=
BdM3@D0i=ST`:c4U82TK53TX8@9:=B`055e3>79DAh]WF:AkJ;b=N<fKQMNVT=BVT/jST<ZPS/FMS<:I
RKjFQKbCP[V@OkN>O[B<O;:;Nk2:Njf9O0:[RGd05JR:OjJ;PJ>;PZ2;Q9f<QY^=R9Z?RiZBSYZDTYbG
UYfKVinOWj:SYJ>WZJBZ[JR`/k:i_L34alk@d]_KfnSViP02m?3_00[jmoKbl_7Mgmo<cm2l`<6]/[>N
YJJAUiV3RhefOX0Joooo00YUJ6YKGEiADE97ATDl>STa;R`V8AlK518?1`DO5A42;b8L01A2<2UG@3M_
DdN8IUROMfN^QG>gSWfbSGj[RWfUQWZOPgRJOgBFNg2BMff>M6Z;LFR8KfJ4KFF1K6EnJfD2Nf]W01Eh
K6UfKF]cKViaKg1_LG=]LgI^MWY^NWi_OH=aPHQcQXeeRY9hSiQiTiejUj:0WZV?ZkFS^L:fb<o9e]_M
iNP00^ocl`0:n_clm?Shh>GUcmCE_lG6/KJhXjRZUY^LRHj?O8626_ooo`0:J6Y[G5eND51A@d=4=cHg
:RTZ7A/L3`h>0P003``;0QdG5@0D;R<P@34/E44jJE58O61ER6YOSg9WRG1WPFaUNfUSMFEPKf5MJUeI
IUUFHUEBGU=@FU1?ETi=DTa=Cd]=0Ta;C`0EBTeAAdiDAE1GA59J@UAM@UMQ@e]VAF1[AV=`B6QfBVek
C760CgJ6CgZ;DGj@EhFHJYBUOjFcU[G1[<G?`mKM00;HiNX02^K`ln?^lM;Mh<C=d;K0`ZZb]InVZ9BJ
W8V>T7j2Q1coool001[oool02UUYKeITJEAOI55JGTiEF4]@DTQ;C4E6AT90?dm;B@9MEe<056eSGWmb
JYB3NZ^FR/2XV]6gZ=k3]>;9^n39_=k8^mg7^m_7^][5^MW3]]S1]=S0/mO0/mJo/mBo/]>n/`;B_[@0
5M2o]<jo]L^n]<Rm]<Fl/l:j/l6j/knj];jk]Kjk][jm^;jn^[o0_<32_l33`<34`/C8aLO:alc>b/oA
cM?Dd002emOB00[Ee];9cLZm`l6_^;NR[:fFXJ>:UiUnS91bPXMWN7dJoooo00YRJ6YKGemDEEE=BdY5
@Clm=c@f;BT^8ahV618e9Ah2AS8Y01AG?cA[Cd:2HE:MMF>dQg?6UX7CXXcDYY;@Y9;<XI38Whk5W8c2
VHVoUXFlTh:jTH2hSgneSGjcS7f`S7h2[hb001F]SH:ZSXBWSXFUShJRShVOT8ZNTXfNU92NUYBNVINN
W9^OWinQXZ>RYZRTZJbY/;>d^[foa<K<cm3IfM[Ui>@00_3]k00:mO?bjN[YfM_KbLc=^[joZk2bWJ>U
T9NHPhZ<MWj06_ooo`0:IFQZFeeMD55AATE5>cTh<2`[920N6A<A3@H471<@0RdP6`0D?RdVDS`cJ4i3
PV5DV79SZ81_/h]j/Xio[8]nYXMkXHAiW85fUgecTgU_SgE[S79YRG1XQFiVPVeVOfaV0We/J00ENfi[
N6m^MG1`Lg5bLG=eL7EhL7QkL7]oL7j4LH:8LXF=M8ZBMXfGMi:LNYNRPj2[TjfgYK_3^L[@c=SLgnKX
00;alo<02_cmo?7clmoShloCe<34aK6f]j>XZIJKW8V>Sgb1PQ[oool02VMZJe]MGTm@DT=4ACHf=bTY
:Q`K70l>3`400@h;2`8M5aD052/R7c`_:Thn=fE>AGMLDXAWG8a_IHUaJ89]IW]YHgEUHFmQGVYMFVEI
EV5EDeaBD5Q?CUE=CE5<C4i;C@9;Bdl05DY=DTQ?EDEAF4ABFd=EGd9HHT=LIdAOJdESL4IWMDQ[NTY`
P4]dQDahRU5nT5b9Vg2IZHFX]YfjaK?:d/[Jh@02g^W]00[^m_WUk_3EgN36c]6h`<>//kFPYZRDVYb9
SY1nPX@Loooo000Joooo00YIJ6iEHfQBGV9?F5a;DUE7CDm4AdQ0@T8m?3a;AdD2F59?00]WGUUhJfB;
O7:RSH:iX9;=/J7J_ZgQakORb[_Qb[cPb[`00]o9_@03g/RkgLNjgLJh00;LaKP06M_5^=W4^=O4^=O4
^=K3^=C3^=72^<k0]l^o]lRn]/Jn]/Bn]/>m]/6m]l2m^<2o^L2o^ko0_;k0_Ko2_/33`<?5`/K7a<[:
a/g=b@02d=3;00[Adlk3a/>f_;ZZ/[6NZ:VCWZ27U9MlRXiaPHEVMgdJoooo00YRJ6YJGUmCE5A;BTU3
@3hk=C<b:bLZ81`R5Q4a8Q`2@BlW01AB>c5TBCekFdfCKUf/P6g1TG_>WHOCY93AYI7>XY3:X8o7WXg4
W8_2VHS0UXFmTh>kTX:iT82gT86eSh42/Y2301FaT8B_THJ/THRYTXVVTX^TThfRU8nQUY:PV9FPVYRP
W9^PWinQXJ:QYJNSZJb[/KBd^[c0a<K;cLoHf=STh^800^k[jP0:mOCbi>CTeMKFa/W9]k^lZJj`W::S
SiFGPXV;MGf06_ooo`0:IFQYFUaMD55AADA5>SPh;R`[8QlN5Q8@2PD36Q4>0RXN6@0D>RXTBcP`HDTo
NU]>T6aMXga[[XIf/8am[8]nYhQlXHEiWH9gV7idU7YaT7M]SG=ZRW5YQVmWQ6mXPFiX0Wi_JP0EOG1]
Ng5_N7=bMWAdM7IgLWMjLWYmLWf1LH25LX:9LXF=LhVBM8fFMY6LNiRRR:>]Uk2hZkk5_L_Ad=[MhnSY
00;dm?@02_ooo^k_kmkPh<kAdKo3`k6e]J>WZ9JJVhV=Sgb1PQ[oool02VMZJe]MGdmADT=4ACHg>2TY
:a`L7@h>3`000Ph;2`8L5QD052TQ7SL/:4Xk=Em:@g1HCh1TFXM/HXM`Ih5]IWYYI7AUHFiQGFUMFVAI
EUmEDe]ACeM?CU=<C51;C4e:C@9;C5005DY>DdQ@ETIBFDEDG4=GH4=IHd=LIdAPK4ATLDEWMDI[NTQ_
OdUcQ4eiReB1Tf>>WgJN[8j^^jBnbK_?e]7Oi002iNka00[dnocTk>gEgMo7c]2j`<:]/kFQYZREVYb:
SY1nPX<Loooo000Joooo00YHJ6iDHVM@G61<EUY8D5=4BD/o@T@j>c`f=SE4@Cl2DDa900aPF5=_I5f3
M6^IQW^_V8[6ZY[G^JSQa[GTbk_Tc;gSc;kScKl2hlg000KRcL3Rc;kRbkkRbkgQb[gPbK`2g/Zm01GM
bKgJb;cGa[_DaK[@a;[=`[W:`;S8`;S6`;S4`;S3_kW2_kW2_k[1`;^o_kZo`;^o`;c1`[g3a;o6a/39
b<800/W8``0:b<[5^knl/;FdYJb/VZ>TSiZLQI6DNXR<L7n4IWMl6_ooo`0:HFQYFEiODE=DBDU9@Clm
>3@b;bPU9QdI7A8>;1lH0S/[900DC3L^GD@iLeE7RVMGXWUW^HYfbIN2dZ:=dZFAcj>Ac::?bJ2>aij=
aIb;`iV8`IN6_iF4_IB3_9>4^I:40[NCQP0E]YB8/iF9/IF;[YF<ZYJ=Z9J?YYJAY9RCXiZFXY^IXIfL
XInOXZ:RXjJWYZ^][[:e]k^m`/C6cLk>f=SGi>;Q00;]jNP02_3_k]oOgm3Bd/;5aKBh^JN/[IZPXHjD
UX68RgEmOa[oool02VEXJEYLGDm@DDA4ACTh>2d[:b4N7A@@3`L30QL?3@8V71P053HX8THd;E]4>g5E
BXMVF9]fIZR1LJj9NZb;OJN8O::5NYf2MiUoMIEkLY5hKhieK8YcJXQaJHE`JX=_JP:1LF`05GmcKged
LG]eM7UfMWIhNGEiO7AkOW=nPW>0QW:3RW:6SG>9TWF=UWVCWH2KYHjW/9jc^k31al;>dmCLg^SZj`02
moKe00[noOc[k>_KgMc<cljn`L6`/kBRYZNEVIZ8SHilP88Joooo00YXJV]LGUm?DE93A4Hf=cTY:R`L
71h>3a00008>2``26QHE01@W81hd:RM6>3=HASmYDd]iH5J0Iej4KFB0KFEiJ6=cI61]H5eWG5YRF5IN
E59JD4mECTeBC4a?Bde=Bdh2Bda@01E9CeA8DEM7DeY6EEe4F654FVE4GFQ4HFe4I755J7I5JgY6Kgm9
M8E?NheIQII[U:=oXk6F];n/a<g2e=[IiNT00^gcm@0:m_cliN[/eMcMalg?^/31[K>dXJJXUIZKRXj?
Oh:37?ooo`006_ooo`0:F6Q]Df5VCe]OBUAHATe@@DI8>cm0=SLh<2l_?3Tg0TY5@P0DFE5<JEiGO6eU
TGmdYi23_Z>CdK>Rh<:aiL^ji/fmilk0im32im73im74j=73j=32ilo1ilo0ilo1i/o10^G?`@0Ehlo1
hLfog/^of/Zne/RmdlJkclBjc<>ib/6ial6iaL2i`kni`[ni`;jh_[bg_Kbg_;bg_;bh_[fh_knj`L2k
00;0_kX02[Zk][>f/jV_[InWYYFOWhbFV8:>TGR6RVmnPfEfNa[oool02V5WJEUMGU1CDdQ8B3ln?CHc
<BdW928K61P?2bHJ508f9R0054Hc:ULo=F]?@X9QDYQbH:n3Kl6@NlnNR=:TSm2ST<jRSl^QSlVOSLNM
S<JKR/BIR<:GQ/2FQKnFQ[jFQ`:lUhT05K^HRkVIS;JISK>HSZnIT:bITJZITjNJUJFKUjBLVJ:NW::O
Wj>RXjFWZ:V/[[6d]KVl_L;4a/c=c]OGen;Ph002j^SW00[Ti>?HfMS;cLfn`L6a]KJTZJZHWYn<TiB0
QhYeO7lJoooo00YUJ6UJG5e?D554A4Dh>3P/:b/P7QdC40l50@4C3@X28QTF01@a9B11<BYC?cIYD4Em
Ge>AKf6ONV^ZQGJ[RW^WQg^RQ7VMPWNIOgFEO7:BNG2>MVj;M6^9LVZ7LV^5LV`2Pg=_01F2MG:0MgAn
N7IlNGQiNW]hO7ifOH1dP8=dPHIcQ8YbQhicRY9fSYMlUYn6WjREZk>U]kjea<W7dMCIgn3]kNd00__i
m`0:m_GdinOVf=WIb/_;_;jn[[6bXJFUU9RIR8b=O8216_ooo`0:J6Y[G5iOD59CA4E7=cPj:R/]7AhP
3a0B004330/;0QPE5@0D91lN<BTV@3@`DT8lHDi8L5YBN65HP6UQOV]TN6MRLF=OJemLIU]HHEMEG5=B
F51@E4i>DD]=CT]=C4]?0T]=DP0EBU1FBE9IB5ALAeIOAEURAE]VA5iZA69^A6AbA6QfA6akAVn0BgF7
E7n@HX^KMIZYRZZfWkW4]LWAc=[Oi>_^00;gno`02_?hn>?XjMGJflO<cKZo`:fb/j6UYiFIVhZ=Sgn2
Pacoool001[oool02UMWKE9PIDiJGTQBET=;CSi3ASPk?C4c<bXY:C@a;`93?CX0555:AF1FD7=UG8Qf
Jij8Nk>JR/R[V]ZkZNG8]^S>_N[@`>_B`^_Ca>cDaNgDaNkEaNkDaNgC`nkDa>gDa0;/e<@05N_CaNSB
a>G@`^3=`=c<_mS9_]C7_=75^lg3^L[1^<Jo]l>n]/2l][jk];bi/k^h/kZh/[Rg/[Vh/[^i];fk]P02
`;nj00Zd][:[[jbSZ:NJXJ6AVY^8TiAoRhifQ8Q]OH5UMG/Joooo00YQIfUHGEi@De=7B4Pn?C`d<S0Z
9R@P6ALE30TO50l2;b4K01@o;BE>>C1RB3ehFD^>JUZSNVRgR7C8Uh7@XHcAXho?XXk=XHo;X8g:Whc8
WH_8W8[6VXW4V8O4VHS3VXT2`YZ;01G0W8jnWHnkW92hW96dW9:aW9>^W9F[W9JXW9RVWIZSWYbRWijS
Xj>WZ:R/[Znd]KJl_Kk3a<G=cLgHemKSh=l00^cZj@0:g]kMd]?CaLO8^Kbm[K6bXJJXUYbMRY6COhJ9
M7an6_ooo`0:IFQZFUeNCe5BA4E5>3Pi;2//81hN4Q0@10413PT70QdE4`0D;24L>R`VC3XbH4Y0M5U>
QFMIUG=TXgm`Z8IhYHIiXHAhWH5fVGmdUGabTWU`SgM_SGE]RW=[R7=/QgA^0XIfL@0EQGQeQ7YgPW]i
Og]jOGemNgj0N822Mh65MH>8M8F;LhN>M8ZBN92IPYVRSJ>[WJnf[K_1^lO;cMCFgn;Sl_3_00;ooO/0
2_3_k^;RhMCEe<O8b;Vk^jb_[j2SXi>GV8N;S7^0PA[oool02VQZK5aNH51BE4A6B3Pj?2/];ahP8Q0B
50831@T:2`8F51D0528M7BdV93/a;dXn>EU:A6ICCG1KE7UTG7YXHGEUH6mQGFUNFf=JEeiFEEYCDUI@
D5=>CTm;CDe;CT]<D09;CU<05D]BEdYDFdUFGTQHH4IKI4IMJ4EPK4ASKdAULdAYN4E]O4QaPTmiRU^5
UF^BXH2Q[YFa_:S0bKk?e]KQi>calP02o?oo00[_l_?QiNKCemS6b/^i_Kj//K:PY:JEVIZ:SHinPX<L
oooo000Joooo00YGIfeBH6E<FEe7DEE1BD`k@D<d>3X];c0U9BD/:RP2>C@a0159@CaHCTMYG5AmKF:B
OW:USX2iWho?/J3P`JkXbkW[dKo]e<?_e/GaelKbf<Ocf<OdfLL00_CHaP0HmMW7m=S7m=S7lMS7k]O7
jmC5i]73h/k1g/bofLZme<Nkd<Bic<6gaknf`K^c_[Va^kJ_]kB]][>]][>/]K:/];:/]K:]];>^0[Ng
/`0:[Jj[Y:RUW::PU9bKS9FFQ8nAO8R;M8:6K7^0I7Ej6_ooo`0:HFMYF5eNCe=CATQ8?Cdm<c4`:BDT
7QTF4P/8610<0RLK5@0A=bLPAc<ZF44gKE55PV9CUG1OZ7i/_8eibYZ5cj2;cj6=cZ:>cJ6=c:2=bin<
bYj;bYf;00;8VhT06<RMS<NNS/NNS/JOT<>PT/6PTkfOTkVOU;FNU[6OUjjOV:^NVJRNVZFOWJ>OWjFS
XjRXZJj^[kFe][fm_/G5aLk=cMSFeN3Mg@;ViND02]SHf<_=cL32`kBh^JV][ijSYI>IVhV?TGj5Qg=k
OQ[oool02VEXJUYMGTmADTA5ASPi>R`/;B0O7a<A4@@20PX61P8G4@l052HL6C@X8T@d;UM3>fYBB7YN
DhUZGIQfJ:60LZ:3MZ22MYb1MIQnM9ElLY9jLI1hKhigKX]dKHUdKHYgL@:9NG@05HUkMhMmNHInNh=n
OH1oOgj1PW^2Q7V4QgN4RGJ6S7J9T7N<U7fDW8RMYIBW[Z>c^K>o`l;;c]?GfNKUiO?ak`02oO[h00[/
jnWNgMc@dM33a<Bf^;RZ[:fNXJ6BUIJ6RX]kOh0Joooo00YXJfaMGf5AE5E6B4Tj?3d];c4P8R@B5AL4
1PP82P`24a<D01@N6a/Y92<e;Ra4>SIBAD5MCTUWETm`GEMdHeaaHUe/Ge]WG5UQF5MLEEAGDU9DCe1A
CDm=Bde;Bdi;CU82C51E01E<DeU<EUe;F619FV=8G6I7GfY6HVe6IG55IgE6JgU8Kgm<MHEFOhmUS9]g
VJN;Z;BO^<6ca/k9e]_Qin[bmOD00_goo`0:kO3`gn;RdMCEa<S8]k^lZjn`X:>TU9RIRHb>OX637?oo
o`006_ooo`0:EVM/DEmTBeQLAU1D?dQ;>Cm2<SHh:R`]81lO8B0N0Rl/:@0D?SPdCT@oGE5:L69IQG=W
Uh9eZi:3_Z:AdkFRhL:_jlfik]?0lMK3m=W6mm_8n=c9nMc9nM_8nm_8o=g:0__Mb`0AnM_:mMW8lMO6
k=G5im72h/k0g<Zme/Nkd<>gbknda[bb_kR_^K>[]K2Y/ZjW/:bV[Z^U00:]ZZ@03Zj[YJfZY:RXXjRX
Xj>UXYfQWiJLVhnGUXRATX6;SGV6R7:0Q6]jOV=dNA[oool02V1WJEQMGdmCE4I8BCdm?C<b<BPV9AdI
5`l:21091P8N5A003RhP6Sh]9Ddi<659?WIIC8QVEiYdHj^1K[f?NlNGPlfMR<jPS<fPS<fQS@;>X8`0
1<fOS<^MRlbMRljPSP;>XY405LbSTlVSU<JSUL:SU[fQU[VQUkFPV;6PVJbOVJVNVZNPW:BQWjFTXjVY
ZJj_[kFe][bl_LC4a<g<c=SEe=gKfP02f][J00[?d=75a/Nj_Kf_/kBUZJ^KX::AUiR7SHmmQ8IcNgdJ
oooo00YUJFYJGEm@DU=5ATLi>S/];RhQ8B4D4a<510@50`824@d;01@O61D^8alk;RU=?3EPBd9^ETal
HEJ9K5nFMfVKNfnLOW:JOg>FO7:DO7:BNW6@NG2>N6n;MVj:MVn=NG<2SWaf01F=OWV;P7b9P7f6PX23
PX61PhAnQ8IlQHQiQh]hR8ejS99lT9N3V9n>XJRKZk6Z]k^i`/G8c]3Ifm_[j>Kgl_000_Cak`0:i^CS
fMSGc<c;_l30/kFeYjZZW9nOTIBEQHV:NWn06_ooo`0:J6]]GF1RDUEFAdU;>ci0;c8d8bDX5QPK20/=
1PT;0Q0A4`0D6QTJ9R<R<2/Z?CHdBd4nEDU5GU1;IEIAJeaGJeaHJ5aHHeYHGEIEFEADEE5BDTm@Cde@
Bd]>BD]?C4mC0TeBE`0ECUILCEQOCEYRBeeUBUmXBF5/BFA`B6MdB6YhBFelCW>2Dg^:H8JEL9>QPZ6]
UZnjZ[k6_/kCeMkQj^k^n__k00;inoX02^[/k=_Ng/kAd/;5aKFi^ZZ][YjRXi>GV8V<SGj1PQcoool0
01[oool02UIVK55OI4]GG4E?Dci7BSLn@C0e=RPZ:ahN7aXH5`8U8R0053D_:d@l=eA8@FEGCWUXGHUf
JY^5Mj^CPknTT]2bX=foZnS:]^kA_OGG`oWKao_MbOcMbOcLb?gLaokLb0;ogLT05OkMb_[KbOKHa_3E
a>cB`NK?`=o;_=S6^=71]<Vl/<:g[;ZbZ;B]YJnZXZ^WX:RUWZJSWJBRW:BQW:FRWJVWX@02XJ6M00ZK
WIZFVYR@UYF:TI:3SHimR8YfPhI`OX9YNGeRLgTJoooo00YPIfYHGEm?DeA6BDTm?Shc<c8X9bHM6QTA
3@/:10825@h;014U6QDe9b14<RYF@3I[D4AjGE2;JEZIM6>ZPFngRgS1TWk7VHG9VhS<WX[?X8c?XHg>
X8`00/fNR`0Hd:6>dZBAdZBAdJFEcZJFbjFFaZBG`Z>G_Z>I^J:I/j6I[Z2IZYjJYinLYJ6OYjBTZZVY
[Zj_]KFe^k^k`l;2bl[:e=;Ag=_K0]7AdP0:alW9_/31];NhZZj_XJJWUifNSYBFQH^=Nh>5LWYm6_oo
o`0:IFUZFeiOD5=DATQ9>S`m;c0a8b<T5QHG2@T900000P/8200=6A@B9alL=2TUA3H`EdDmHdm7LEY@
NV5GQV]PSW9VTgIZTgU^TGU_00:ANG001I1jLHihL8]fKh]gL8ijL`02TGih01FAPGb?Pgj=Pgn:Q8:7
Q8>5QXJ2QhQoR8YmRHalRXmnSiB2UIZ;W::EYJ^R[kB`^[joaLO>dM;NgMc/jNKim?800^cYi`0:gmkL
dm;AalO6^kbl/;6aYJNWVYbMSi:CQ8R9NWio6_ooo`0:JFa]GV5SE5IHBD]=?T12<SDg9RT/6QdP3Q4D
1@P;0P`?4@0D5aPI8R4Q:bPX=c8aACdkCTE2Eda8Fe1<HEEAHeMDHeMEGUIEF5=DE55BDe1AD4mACDiA
BDa@BDeAC51E0TmEF@0ED5QND5]QCeeTCEmXCF5ZCFA_C6McC6YgCFikCg:0EGV8GX>AK8jKO9^WSZRc
X[O0]LK<b]GIgnCVlO;booon00;blo<02^GVi]OJf/_=c[o1`[>f]jR[[9fPXI:EUhR;S7j0PQcoool0
01[oool02UIVK51OI4YGG4A?Dce7BSHn@2ld=RLZ:ahO81DD508J61H052TU8SPa;DLm>5M;A6]KDW]Z
Gh]gJi^5Mj^CQ;^QTLZ^W=JiY^32/>S:]no@_?CE`?OG`_OF`OWF`?[G`0;lf<805OcIa?_I`oOF`_;C
`>c?_NK;^]o8^=K2]<fl[lBeZ[b`YK>ZXJfVWJNQVZ:NV9nLUYbJU9ZHTYVGTY^HTibKU`02UiVE00ZC
UYB?Ti::T925SHeoRHYjQHMdP8=^O81XMgaRLgPJoooo00YQJ6YHGV1?E5E6BT/m?d0c=3@Y:BPN71`C
40l70`8230L401@L4a0Z7aXi:bA:>31OAce^E4QlGe::JE^GM6BTOVf_QGBfS7ZlTGo1UH;6VHK:W8S:
WHW9W8W;WHW=Wh`2cj:?01GAY9?@YYG=YIK8Y9K4XiNoXYRkXiVeXIV_WiVZWYZXWibUXInWY:>YZ:R]
[Jfc/kBi^[[0`<37alO?c/kBdm<00/S9bP0:_l72][Vj[[:cYJZ[WJ:SU9ZKRi:CPhZ<NX64LWUl6_oo
o`0:IFU[FemPDEAEAdU:?3ho<C8c9RHW6QXK3@d>00010P@30`0D4`l>81XG;B@Q>c0[CChgFTU1IE59
KUU@Mf5GP6QNQFaRQfmVQg9YRG=[S7E]SGM_RgM`RGI_RgQ`SGYc0Y1nM`0ETX5lTXAoT8F1S8F3RXJ5
R8N7QXV:PhZ<PX^>PHjBQI>GRIRMTZ2UW:V]Z;>f][k0a<W:dmCCh=kMk^WVl^k[00;ThMl02]SGeLg<
bl72`KNh]jb^[Z:TY9NJVhf@TH>7R7UmOa[oool02VU/KUmRI5EHFD]=Cd13ACDh>RX]<1lR9A<G6PL;
3P893A0051DG61hO82PW9c8_;d0j>4U2@4m7AEA;BEQ?CE]BD5YBDEMBDE=@DU5?DE5?DTm@DTe?DdY>
DT]@E4iCE`9@Ee`05E9JH5=OI59PIe1RJU5UKU5XLU9/Me9_NeAcOeQiQF21SVZ;UgVGXXVS[I^`^Jjo
a/;>d]KLgnOZj_Sfm_clnP02kNg]00[OhN3CeMG7bLVk_[j`/kBVZ:VKWYnAU9F7RX]mP84Loooo000J
oooo00YFIVa@GfA:Eea4Ce<mAdXf?T4_=3LV:R`M7b0C4a@24A0?01@N6aT/:2@k=2m9@3UJCTI/GEAl
Jf2<NFbLQgV[U8FhX932ZYW</Z7F^JON`:gUaK7Zb[G[b[K]bkK`cKL2llni01Gdd;[ddK_ack[/c;SW
bKKPaK?I`K3@^jc7]JNl[Z:dZ9j/XYVTWYFNVI:IUHnETXfBT8Z?SXR>SHR@SXV?Sh/00Xj@S@0:Rhn=
R8f<Q8^;P8R9NhF7MX:4LGj1K7YnIgIkHG9h6_ooo`0:HFQZF5iPD5EFAd]<?T51=CHf:b/[81lO5A<C
20H60P@1000@4Pd:8ATE<2@O?S0YD3heHDY1KUE:O5mCRFYLUG=TWg][YH5a[8If/hYi^Hmn_I:00/6F
Q00I`iR6aYZ8bIf;bIf;bj2?c:>BbZ>CaZ:D`Z:E_Z6F^J6G]:2G[YjHZIfIYinLYJ2NYZBRZ:NW[:b/
/K:b]kRi_;fn`L?4bLW:a<K700:n`<402[Nj^jnc]:R/[J2UYYRNWi6FV8V?TH68RWV0Pg5iNa[oool0
2VIZJeaPHE9EEdQ;C3i0@C@e=RTZ:adN7a4B4`@51`80000050`;2QTF52HP7C<Z9d<g<U12?5Y:@f=A
BVaIDGAOEgQTG7YWH7eZHh1]IHA`JHEbJhMeKXIeKXQfL8]iLP:>OGL05I20Ni:4OY26PHj6Phf8QH^8
R8Z;RhR<SHN>T8NAU8^GVY6LX9ZTZ:>]/:nf^;c1`/[<c=OFe>7OgNcWiNKSh002fmWG00[@clk6a/Fl
_;bb/k>XZZZNXJ6EV9R;Shn2QXMiOGhJoooo00YZKFiPHfEGFE]=D593ATPi?3h^<C@S9bXH71l=4AD2
20`?00`A5ALK7AlU9BH_;Bhk=cM3?Se8@d9<ATE@BTUCC4]CCTi@CTl2CTi@00I?Ce9=D5==DEE;DEE=
DeM?EEX2DEYN01EDGF=FHFMFI6]EIViFJG9FK7IILG]JMGmNNXESP8a]RIAhTif7WjRFZk>W^Knjalc?
e]WOhnC]knkknOSclo800^KVi@0:fM[Jc/o?`/C5^;Zj[K2`XjJWVIbMT9:CQXV:OGn17?ooo`006_oo
o`0:EVI/D5mTBUMLA4mD?DM;=Si2;cDh9b/]7R4R51DF0P`;2`0D4Q0?8AhK;bXV?SHaCT@mGU59KV1F
O6]QRgU]VHAgYHn0/9V9^J6A`JRGbZnMck>Qe[VVf[bYg;j[g[n[0^71[@0Ehl:^h/:^h<6]g;n/f;bZ
d[RWbk>T`ZjP^ZVM/:>HZ9jDX9R@VYB<U929Shb7RhV4R8N2QHAoPh9nQ8AoQXN400:6RHH02XB9Qh:8
Qgn6Qg^4QGN2Q7=oPVmlOfYhOFEeNV5aMa[oool02V5XJeUOHE5FF4Q<CSm3A3Hh>Bd^;R8S8aPG5``;
2`82000050P511PB3bHN6SDY94Df;e=1>F9<@feEBWYODhEWFhi^HIIeIiakKJ:0LJV5MZb7N;>=OKF?
OkRAPKZCP`:mUhL05L2IRL6KS;nLS[fLSkZMTKNLT[>LTjfKU:ZKUJFKUjBLVZ>NWJBRXJJVYZZ[Zjn`
/KFf]kRj^kbo`Kg0`KZl_P02]KRi00Z_/kBY[JjRYjRKX::DVY^=TiF6S8ioQXQgOh5`N7/Joooo00YV
JVaMHF9DEeQ:CDi0@d@f>CX/;RlQ8b@F5aT:2`d2004201@51PHC4A4P71X/9R@j<Bi5>SI@@ciGBDAQ
DD]XEe1/G5E_H5YcI5ifIf5kJfEkK6J0LFZ1LVb3M6j5Mg42RG]e01F<OWV>PWf>Q82<QH:<QhF;RHR;
Rh^9SHj:T9:<U9JAVIbGWj:PZ:ZY/;:e^[_2a<C@clkHe]GRh=gSgmgJf=H00];@c`0:bLS7_knn][Nf
[Jj^Y:JVVifNTYFFRHf>PHB6N7an6_ooo`0:JVe_HFAVF5]MCe9DATU;?3m2<SHi:2`_7R8U51PL0PX?
4P0D3Q<F6A`N8b@V;2`]=S@e?3Xj@SloAD92BTI6CDU9C4Y;Bd]=Bde@BdeACU1CBdmDCU=GCU=HCeEJ
D5QM0UAMHP0EEf1VFVEZFfQ^FfYaG6ifGW5jHWIoI7^4JH6;KhRBNI6JQI^TU:N^Xk>i]<75aloBf]gO
inSXm?Ccm??bjNSX00;Mg]d02];DdlS9bKjo`;Bf]ZZ/[J2SY9NJVhjATXF8RGaoP1coool001[oool0
2UIWKE1OIDYHGDA@ECi8C3M0@c0g>RP]<1lS9AHH6@8<30d050X:2AHD4b@P7C8/:48j=515?eeABFYL
DgYZGhQgJi>1MIj:OJNBQ:nIR[RPT;bTU<:YV<J/VlZ_W<b`WP;=/Il2ck:P01?=/J39[ik5[Ic0ZIZj
YINbXIB[WI6TV8jLThZDSXJ>RX>9QX23PWf0Og]nOGUkNWIkNgMnOgaoPWl00Wn3PP0:OXB3O8>3NX:3
Mh62M7n1L7aoK7YmJ7MkI7AiH75g6_ooo`0:HFU[FV1RDUMIBDi@@DE6>3/l;c4b9BLW6a`L410A0PD4
1@0D0P403``;7ALE:b8N>RhYAcPbDd8kGDY2JeA;MeiCOVEJQfaPSW5VU7IZW7a_WgmbY8AfYhIhZhUk
[Xan0[2?P@0E/i:4]IB7]9F8/IF:[iJ;[IJ=ZYJ?YIJ@XiNBXIRDX9ZHWibKXJ2OXjBTYjVZ[:j`/KBe
];Rj]KVk/kNi/;Bf00://;802ZN/[J:WZ9bQXiJLWI2FV8Z@TX>:S7f4QWInP71hNQ[oool02VM[K5iR
HeEIFTa?DD=6AcXl?S0b=2HX:A/M7a0B50851PP0504310d>3QXH5bDR838/:Sdd<DHm>Da2?UI9AEi@
Bf5ED6IJEFYNFViQGGAVHGAXHgU/Ig]^JWibK85eL0:4N7<05HQlN8YoNh^2OXZ4PHZ6Q8^9Qhb;RhZ=
SXfATY2FUiJLWYbRY:FZ[:nc];^m_LO7a];@cm_IemgJf=OEdm3>c@02bLS600[1`;ni^KR`/K6XZJVP
XZ:HVY^@TY>8RhaoPhAgO7dJoooo00Y[KVmSIFMJGEmBEEM9C4i0@dHg>cd^<S@T:B`K7b<241DI01@=
4QDG71hP92HX:b`a<S<h>3Tn?Cho?d14@dA7ATM6AdY8BTe9C4m9CE5<D5A;D5E>E5Q?EEYAFEeCG602
Ef1U01EKI6UNJ6iPK75PKgESLgYWMgi[O8A]PHUcR8mkT9N6VJ2BXjZP[[B`^ko1bL_Ce]SRhn?_knka
lNoXj>OOgmh00]GFe@0:blc<`/?3^;Zj[k6bYZRYWJ2QUINHS8n@Q8N8O7j07?ooo`006_ooo`0:EVM]
DF1UBeUNAE5F?dY>>495<CTl:S0b8BHX61/M0Ph>400D1@@530/:6AHD9B4N<bdY@CTdCdDoFU18Ie]B
MFMMP71VRWY_Th9fVXUlXXn2ZIB7[YV:/Yb=]In?]j6@0[VRT@0E^Z>B^J>B^::B/in@[ib>ZYV;YIF9
Wi:7VXn5UHb3ShR0R8=mPWmiOG]gNWYfNGUeMWIbMGEbMgQeN7]iNGek009iOgh02WUoOgQoP7IoP7=m
Og5lOVejOFYhO6MfNV=cN5m`MQ[oool02V9YK5YQHe=IFd]@DT=7BC/n@38e=RT[;1lQ8QDF5`892P/0
500000L61Q@A420K6BdV8c/a;4Lj=511>e]:@fMCBfmJDWQRFGmWGXE]HhabJ95fK9IjKiYnLYj2MJ25
N0:SQg/05JJ:OjN<PJJ>PjB>Q::>QZ6?Qij?RI^@RiZASY^DTI^GUI^IVIfMWInQXZBWZ:Z][jjc]Jnd
]Zfb]:^_/JR][P02YJV[00ZPYJNLXJ>GW9jAUiV<TYB6SHn1R8YkPXAeOGm_MgXJoooo00YWK6eOHfEG
Fea?DU=6BDXm@44d=cP[;BlQ8bDG6AX230d?01@210D92``D51@O7AdZ9bDe<2hn=cA3?3U;@SmCBDIG
CT]NEE9RF5IVGEY[HEe^I65bJ6AeJfQiKf]lLfh2OgIb01F4NWJ6OGV7P7f7PWn8QH>9QhJ:RXV:SHf>
TI:DV9RJWYnQY:FZ[:fd]KFo_kk;bLSFdm;He]CBd<o=bl[7a/D00/30_`0:^KVh/[:bZjb[XjFUW9jN
U9NGSI2AQHV:OX:3Mg]l6_ooo`0:K6i`I6MXG5mQE5MIC4mBA4M:?3m2<cLj:blb8RHZ0QTN8@0D41HI
5Q`O7R<V9RT/;S0b=CLh>CXl>cdo?d12@TA6@TI9AdY>Ada@BDiBBe5ECE9GCeEJDEQME5aPF61T0U]S
J00EH6Q]HfaaIW1eIg=iJgQnKgf2LX67MHJ=O8fDQiJLTJ2UWZZ_[;Ji^l;4blo@fmcLj^[Yk^g/iNGT
g]kMeMKE00;=c/d02/C5aKbm_K>e]J^][J:UYIZMWI:EUX^=SX>5Qg]nOacoool001[oool02UMWKE5Q
ITaJGdICF41<D3Y4B3<l?b`c=R@Z;1/O8@8B51D050D61P410@/:2ATF52HR7c<]:Slh<dU1>eA;A61F
CVYOEgIYH7maJ8IhKXenLiB3NIR7O9^:OYn>PJ:@P`:STH@04:BCQJ>BQJ6AQ9b>PYZ<P9F9OY26O8^3
NXN0NH9mMgejM7QfLGAdKg5aKFe_K6e^K09aLg000g9eLgAhMWAjN@02MG]k00YdO7acO7ebO7e`Nge^
NWa[N7]XMWYUM7URLWMOL7HJoooo00YRJVaKHVADFUe=DeA6BT`n@T@f>C/]<38T9bPK71h2414C01@3
1@H00@892PXF51@S7ad_:BHj<Bi2>3A<@3YFB4=NCdUYF55`GUMgHealJ622KFF7LFV:MFb?NFnCOG<2
UGme01FHPgVIQ7^IQWjFQWjFQh2DR86AR8>@RHF@RhVBSXfCTY6DUIFGVIZKWYnNXjFTZJ^[/KBW[K2U
ZjfSZ:ZQYZP00YfSY@0:VYnQUYbMTYNISI>ER8nAPhZ<OXF7NH23M7]nKWIi6_ooo`0:J6a^H6AVFEeN
DEEFBDa>@DA6>C`m<3<d9bX[7R0R0Q@F600D2@`=1PT:3Q0A6ATJ8b<R;B/Z=S8a>cHe@C`kB4=1CDQ7
ETm=FUABGeQFHeaJJ65OJfARKfQULfaYN71]0W]dL00EOgQePW]hQGmlPh1nQXB1QhJ4QhR7RH^;SY6A
UINHW9jOXjFV[Jj]]kJe`;nnblW7e=?Bc/g;bLS6`l?2_[fm00:h^;L02[:b/Z^/[:FVYYjPX9NJVY6C
U8Z=SX>7R7f1PWIjO1[oool02Va_LFEXJUiQHeMJG51CEDQ<CT54AcTm@34f>BT^<@8Q9bX051TO8QLM
8A`R9R@Y;2``<c8e>3Lj?3Tl?c`o@Sm3AT56BTE:CTM<DDY?E4]BETiEFU5HG5AKH5QOHeaSI`9PIf/0
5FE/L6Q`M6eeNFehOG=mPWJ1QGV5RWf;T8JCUi6LX9bVZZV`/kNl_/G7b=?Cdn7Pgn_[j^?Sh]_LfmCD
e<c=c@02aLK500Zm_[je]kN][k2VZ:RNXJ6GVIZ@TY>9Rhb2Q8EjOGhLoooo000Joooo00YGJ6iBHVM=
Ff57EEY2CU8lAd/f?d<_=cXX;S4P9BL25aXL01@=3a020`<0000:2PTH5aDU8b0`;2Ti=352?3M<AD1E
CTQPF51YH5Q`IUmfK6AlL6R1MFf6NW2:OG>=P7D2SX9g00f@PgR@PgV?PWR9OgF3NW5oN6mlMfmhM6ic
LFa`Kf]^KVY[K6QWJFH00fMXI@05JF]XK6m]KW9aKgEdL7If009`N7P02W1iNVmiNViiNfehNf]gNfUf
NVIeNFAcN65aMem`MQ[oool02V=ZKEaSIUILGTmEEdQ>D456B3Xn@38f=bX];b4T9@8H6Q`050h@4P<6
20431@/=3QPH62DR8BlZ:CLa;chg=4Lo>di5@UQ=BF1DCfMJEFaOFG9SGWMXHWa/IX1`JHEdK@:8N700
5H]kM8enMhj0NH^0NXUoNXIoNhF0OHF3P8J5Q8R8R8^=SXnATY6EUYJJW9bQXZ2VZ:6WZZ2VZ9jTYYbR
Y9ZOXP02UifO00ZDVYb@UiV=TiF9Si64Rhf0QhUlPhEgOh5bNWe^MWPJoooo00YYKFiRIVMKGf1DEeU=
D595B4Xn@D8f>C/^<C8U:2X27B0R01@D5aT;3a493@lB5ALM7QlX9bP`;Rhe<c<j>3M1?Si5@d=<BTUC
CdiHE5=LF5MQGEaUHF1YIF=^JFMcKV/2Mg5_01EkMW=oNWN2OW^2P7j3PGn3PX64QXF8RXZ=T92DUYJM
WYjVYZJ][Jfh][G2`;k:b<K9bLO4`l:o_kjj^[Ve]KD00[2a/00:ZZ^[YJJVWj6QVI^LTiJFSI2AQh^;
PHF6Ngn0MGYk6_ooo`0:KG1aIfU[H6=UFUeODeIHC51BATU<?d=6>3`o<CHi0RX`<`0D92X]7R@W7B<V
8bT/:Rlb<CHi=SXm>Ce0>cm3?dA7@4I;A4Y?B4iCBe5FCUAIDEQLE5]PEeiSG69VH6MZ0VA[KP0EJG1c
KWEhLgYmMWj2NX:5NhB7OXV<QI2CSYRKVJ6SYJ^]/[Jg_/31bl_;f=OFh^7Ph>7Pf=WHdM;Ab/_;`lC4
00:l_[h02[Jg]jn`/JRZZZ6SY9ZLWIBFUhf?T8N9RX23Q7YlOQcoool001[oool02UMXKU9RIdeKHDME
FT9>DSa7BcHo@blg>RP^<B0U9`8G6Q`050d?40830`0000X:2APG5BDS830/:CTd<D8l=da5@5E>B61H
D6UPF71VGgI/I7a`J85eKHIjL8YmLhf0M@:>PWL03I23N923NHn2N8UoMH=jLGmhKgagKgQdKW=aK71_
Jfi^JV]/J6MYIP03IfQU00EYJfQ/Kfe^LW5_MGA`MWH00W1hN00:L7UjKgUjKWUkKGQkJgMkJGIjIWEi
I7=hHG5gGg1f6_ooo`0:HfY]G6=VEUaNCeEGB4i@@DI8>Si0<SHg:Rd_8B@U0QPJ700D3Q0B0`H80@<5
2`d>61PH9B8Q;bXY=c4_?SLdAclkCTE2F4e9H5A?IeYEK5mILV=NMfQRO6aVP71YQGA]0XQhL00ERg]d
SGigSX1iRh1jRGmjQWmkQH1mQH>0QXF4R8R8Rhf>Si6BTIFFUYZLW:6RX:JXXJNZX:JXWZBVW::TVYnR
00:GWIl02YBJW92GVHfCUHV?THB;SH27RGb3QGMoPG9jOFifN1[oool02VU]KV9VIe]OH5AGFDe@DTE8
BSi1@SHi>bha<RDX:P8M828051@G6@/?4@T=3a8E5adN7bPW:30^;SDc<cXh=d4n?TE3@da:BE=?CUQD
DeaHEf5MG6EQH6UUHfiYIg=^J`9gLFl05G]fLgmjMh9nNh:0OX>1Oh>2PHB6QHR:RXf@T9BFUYfNWZJV
YZf][KRf]L;0_/[8a/W9alC3`[no_[Zj^KFe]@02/;6`00ZZZj^UYZJOXJ6IVibCUYJ=T967Rh^1QHIk
Oh1eNW/Joooo00Y]L75WJF]PHfEJGEmCEUQ<D596BD`o@dHh?3la=ST2:S0c01@T:RdN92LM8bHS:B`Z
;c8a=STf>Sdi?D0k?d<oA4M0AT]4BTm8CU=;DEI>E5UAF5aDFf1GGV=LHVIPIfX2I6]^01EYL7=^MGQc
NWefOX9jPXEkQ8MnRHb5T9>>V9^IXJ>UZjfb][Nn`<7;bl_HemKRhN3PhN3HfMSAd]7:bl_3a<@00[bn
_P0:][Ng[k2aZ:ZZXJ>TVYbMU9JGSHn@QhV:P8>4NWan7?ooo`006_ooo`0:EfQ^Df=XCUeRBEMLA55E
?dY>>D=7<c`o;3@g9B/^0QdR900D5APJ30h?0P<300412P/;61PF92<Q;BXX<c0]>SLd@SllBTM3E4m:
FeI@HUaFIf5KK6EOLFURM6eUMg1X0WYbJP0ENgA[OGI]O7E^NWA]MW9[KfaWJFQTIfMSI6ERHfERHVAR
HF=QGf5OGEmMGf1MHF=QIFUWJ6e[JW1_Jg9bK7Ad009]MGH02VefN6agNF]gNFYfNFUfNFMeNFEdN6=b
Mf1aMUi_MA[oool02V=[KUeUIeQNHE9HFT]ADdE:C3i3ACLl?C0d=RP/;@8P8bD051LK7@lB50D92`<7
2@hA4Q/L72HU9Bl/;3<a<3Xg=T4m?4Q4@U9;BEQACUmGDfAKF6UOG6iTH7=XI7M/I`9kL6/03gicKX5g
LX=jMX=kN85lN7aiMgYiN7amO7eoOh23Q8F9RXZ>T8fBU92FV9JMW`02V9nR00BHWZ6GWInEVijCVI`2
TINI00Z>UIN;TYB8Si65Rhj1R8YmQ8MiPH=eOGmaNGa]MGPJoooo00YYKVmSIfUMHF9GFUa@E5E:CDm3
ATPl?d4e>3X]<C829RT[01@O8R@G6ad@4aD>4Q@G6a`R92D[;2db<S<e=SHj>S/n?d55ADI<C4aAD55G
EUEKFUYOGEeTHV5YIVE^JfT2Lfm]01EgLg5lN7J0OG^2Ogj3PGn0PH21Ph>7RHV<SXjCUIFMWYfWYZF^
[Jff];?0_[g1`L2m_Kbj^[Ve][Fa/[6][Zd00ZRYZ@0:XjFUWj2PVIbLU9NGSi:BRXf>QHR9Oh>4NWio
MGUj6_ooo`0:KW1bJ6]]HVEWG61QEeYLDEAFBdmAADU;?d=6>Ci00S<h>`0D;S<f:Bhb92X]8bT]:Blc
<3Hi=S/o>cm3?495?dE9@DQ=ADa@BU1ECEAHDEQLE5]OEeeRFf5UH6IYI6Y]0VU^LP0EKW=fLgQkNGj1
OH:5P8F6P8N9Q8b>S9BFU9^MWZ>UZjj_^;Vi`l?3c/g<f]WHf][JdmCCcLk=alS7`L;2^[bl00:d][H0
2Zj`/:RZZZ:TYIbNWiJHVI2BThZ=SXF7R7n1PgUlOAcoool001[oool02UQYKeATJTmOI4]IGTIDF45>
DSa8C3M1AC4j?BXb=@8T:Rd051`R91DI6`d@4@<51P8410`>3QLH5b8R8BPX9Rd]:S<b<3Xj=d10?DE5
@D]:Ae5@CEMEDEaIEF5NF6AQG09WI5h05FQUGfYWHVeZIVe[IfYYIFIWHfAUHV5SH5ePGUYNFeULFeQK
FUMJFEIIEe]MFemRHF9WIVE[JVM^KVQ`LFUbL`02JW=e00YZM7IYMGMYMGQXM7QVM7QULgQSLWMRLGMP
L7INKgDJoooo00YTK6iOIVUIHF=DFee?EEM9Ce53B4Xm@T@f>cd_=3H2:2d_01@Q9BLI7R0B5QP93A08
3@lB5QTM824X:BT];Rhb<S8f=cLn?Ce4A4=9B4Q@CTaEDe9KEeIPG5YVHEiZIF82KfUV00maK6QeL6ei
MG9kMWEjMgEgMgIhNGQiNg]iOGikP8:0QHN4RXb9Si:;TYJ@V9X00Y6HV`04TINJT9NISiFHSIBF0X^B
U00:RI2BQXf?Q8^=PHR:OXF7NX:4Mgn1M7]nL7QkKGEg6_ooo`0:JVi`IFUZGf=UFEeOE5QICU9CB4a=
@TE7?3m1=STk0Rlc=003:B`^8RHX720R008E6A/03adR92HZ;30a<c@f=cLi>cXm?d53ADM9BTa=CU5B
DeEGF5YJFemOGfETI6YXI`02Kfe/01EbLFmhMGAmNgV0OWb1P7ioP823Q8>8RHV<SXjCUIBMWIbUYJB^
[Jbd/k:h^;Ne][Fc/k>_/;2/[JfXZZVUYZH00Z6RXP0:WIjOV9ZKU9JGT9:CRhj?QhZ;PXF6OH62NGen
M7Qj6_ooo`0:KW5cJFa^I6MYGf9TFUeOEEUKD5AFBdmAATY<@DE80Sa0@`0D=c`o<cPk;c@h:S0c:S0d
<3Lk=ce1?D96@4E9@TQ<@dY?B4mCCEAHD5MKE5YNEeiRFV1UGfAXHfU/J6e`0VebM00ELGEgMg]lOH22
PHB5Q8N8PhR:R8j@T9FGUibNXZJV[k6a^k^ja/G5c/g=d];Bc<g=alS8`/?3_;fm]kRh/[>c00:/[Zh0
2ZNYZJ:SY9bNWiNIVY:DUHf?T8R:Rh>5QWf0PGQkO1coool001[oool02UQYL5EUJe5PITeLHDUGG4EB
Ed1<DC]7BcI0A34j?@8[<cH052D/;ahT9QLL7PlC5@H82@D820lA4QTK6b0R8BDV9BPY:2d_;C@f=3Tk
>C`o?3m2@4A6A4Y;BDi?CE5CC`9EEU<05EMHEEUKEeYLFUeOG5YMFeIKFU=IF55GETmEEDeCDdeCDU1D
De1DDU=FEEQLG5aRHV1VIV9ZJVA/KFE_L6I`LP02Ig9d00YWLWEWLgIVLgMULgMTLgMSLWMRLGIPLGIO
L7EMKgDJoooo00YUKFmPJ6YKHfEGGV1BFE]=DeE8CU13B4Xm@T@g?3h2<CHh01@[<38T:B`N8bDG71h>
4aH>51LG71lR9RPY;Bh]<C8`<cDf>CXn@452ADE6B4U9C4a>D51DEEEIFUUNGUd2Hf9Q011VIFAZJFQ/
K6]aLG1_LG1]LG5^Lg=_MGIaN7YdNgihOh9oQXR3Rhj5SI68T9>9TI@2RY6D00>9T9>8Si:7SY400XJ=
S`0:Q8^=PXV;OhN9OHB7NX:4N7n2MGeoLWYlKgMjK7Ag6_ooo`0:JfmaIVY/HFEWG61RF5]MDeIHCE5C
B4a>@dM8?T530SPl?P0D<cLi;C4c:2`^8RHY720R724T92T[;S8d=3Li>3/m>Si0?d=5ATU;BTe>CU5B
DEAFEEQIFeeNHF5RIFIV0V][JP0EKVi]M7=aMWIeOWajOGalO7imP8:2Q8N7RXb<TY>CVIZJY:>RZjZZ
[:b][:f/ZZ^[Z:VYYZNWXjBTX::RWInO00:IVi`02YJHV9:EUHnATX^>SXN:Rh>6Qgn3Q7]oP7MkOG=h
NA[oool02VmbLf]^KfIZJf9UIeiQHeUMGeEIFe5DEda@DdQ<C`94B4/05415B3a1A3Tn@CDk?S4g>c8i
?CPn@cm5BDA:CTI=DDQ>DdaCEe5GG5EKGUQNHUYQIEeSJ69WJfM/Kfa`LP9aM7H05GAgNGYmOGf0PHF6
QXF7R8N:RhfATIBGV9bOX:NXZ;2a/Kfl^lG5aLK7al?5a;o0`;^l_;Jh^;:c/jf_[jVZZ`02Y:JV00ZP
XJ:KWIjGVIVBU9F>T969Rhf5QhR0PhAlOh1hNW`Loooo000Joooo00YIJW1FIVaBHfQ?GfA<FV18EU]4
DEI0CE4lAd`g@TH2<Sa001@]=STW<3<Q:B/K8B<D6A/;3a0830d>4Q8I7AhQ9BDT:2PV:BPW;2/[<2l_
=3@d>STf>c/g?Cdl@T92BDP2B4e<01E:D4m=DU5>E5ABEeM@EUI>EEE;DeA9DE98D517Cdm7CTm=DE1?
De9CFEUGGUiKHV=NIVMPJF]RK6iSKW1TKg800VA`L`03I75dI79eI79f009SLWH01F9aMV5aMV1`MUi_
MEe_M@0Joooo00YUKG1QJFaNIFQJHF=FGEmAF5Y=E5I9Ce54BT`oADL2>T1201@e>Sd_=CLZ;c8T:R`M
92HF720D720K8RDV:bh]<SDa=SPc>3Xg?3hk@48nA4I3BDY6Bde9CU1=DUADF5X2FUeM01EMHF5RI6AS
IfMYK6aXK6eXKVmXL75YLWA/MGM`NG]bO7mlQ8MnQXZ0R8^2RHf3Rhf3Rhj4Rhj3Rhf3RXb2RH/00X28
RP0:OhJ9OHF7Nh>5NH63Mgn1MGeoLg]mL7QkKWIiJgAf6_ooo`0:Jg1bJ6a^I6QYGfAUFemQEe]MDeMI
Ce=DBTi@ATY<0T55A`0D?D53>3`n=3Pj;c<f:bla9BX]9R/^:c0c=3Pk>Si1?T95@DE7ATU;BTe?C51B
D5EFE5MJF5]LG5iPHFAU0VMYJ00EJfe]L71_LW=cNWUhNWYjO7emOh61PhJ6RH^;T96AU9JFXJ6QXjBT
XZ>SXJ:RX:6QWZ2PW9jNVYbLUiZJUINH00:BUID02XnBTXb?T8V<SHJ9RX>6Qh23Q7f0PGUmOgIjO7=g
NA[oool02W1cM6a_LFU/KFEXJV5UIUiQHeYNH5MJG5=GFE1DEP9<D5<054U=D4I:CD=8Bd15B3e3Ac]1
ACi4B458BdM=DD]AEDiEFE9HG5MLH5YPHeaRIEiUJ6=WJfM[KFU]L6eaM09cMGL05GMiNg]mOGj0P8F6
QXJ7R8Z<S8nATYFHVIjPX:NXYjf^[[^k^[bm_KRi^[Fg]k:d]:n`/:^][JNYZJ>UYZ2RXP02W9jN00ZH
VY^DUiNATiB=Si29S8f6R8V2Q8InPH9kOGigNW/Loooo000Joooo00YIJg5GJ6iDIF]AHFM?GVA<FV19
Eea5DeQ2Ce<nBTl2>TI:01@f@DDa>cl]=STW<3<R:B`L8bDF71l@5QPB61TJ8B8P9bPU:R/W;BdY<30Z
<C8/=CH`>C/d?Clg@48kA4L2?dQ:01E5CDm7Ce58D55:DE9:DE=8D595CTm3C4i3Bda5CDa4BdY:D51@
EeQDG5eGH69JI6IMIfUOJFaPJfiQKG1RKW800V9_L`0:HW1dHW1eHW5eHW5eHG5fH71fH71eGg1eGVme
GFie6_ooo`0:IViaHf]^H6QZGFAWFF5SEUeODUULCeIHBe9DAdi@0T=:C00D?dE8>d53=Sdo<CPk;3<f
:2lb8bX^7bL[8BT]:S8f<3Pl=Sdo>3m2>d95?4A7?dQ;A4]?B4mBBU5DCeII0U=JG00@FEmQGF9SH6EV
HVMYI6U[I6]]I6a_IVmbJ75dKGIiKgQkMWn2NH64NX>6O8B7OHF80gj5R00>OHF7O8B6Nh>5Nh>5NX:4
NH63N7n2MWj0M7aoLgYmLGUkKgMjKGEhJg=f6_ooo`0:K75bJFi_IVY/HfMYGfAUG61RFEeNEEUKDUIG
CU9D0T]?D00DAd]=@dQ9@4A6?453>Ce0=CXm<cPk<CLi<cTl?454@DM:B4]=BTi?C55BCU9DDEIHEEUK
F5aMFUiPGf=U0VAWI`0<JFa/KFm^LG9bMGIeN7QhNW]kOGmoPHB4QXR8SHn>TI>CV9ZJ0iNIV@06UYRH
U9NGTiFFTIBDSi:BSI2A0X^>S`0:RHb=QXZ:Q8N8PXF6Oh>4O821NWioMg]mMGUjLWIh6_ooo`0:LG=e
KW5bJfi_J6]]IFQZHVEWGf=TG61RFUeOEe]M0UAHFP0DDUIHCe=FCE5DBe1BBDiAB4eAAdeAB4iABU1D
D5MJEE]PFemRGF5TGfAWH6EXHfQ/If]^JFa_JVe`Kg9d0W9eMP0EMgUjNWalOh20PhB4QhN7Rhb<Si6B
UYRHW9fMY:FUZJb//;6a[Jj^ZZb/Z:ZZYJNWXjBUX::RWInOVYbLUiVJ00:DUYL02Y6CU8j@TH^=SXR:
RhF7R8:4QWn2PgaoP7UlOGIiNQcoool001[oool02UY/LUQZL5IWKEATJU9RJ51OIDeLHT]IGdQFFdEC
F092Ce@053m<D3a8C3Q4B3@o@c0j?R`e>BL`=2</;a`T:1XS9Q`U:28[;RTb<bTc=2Xd=Bdg>C0k?S@o
@CI1@cQ4AP8jATT05Ce8Bcm:CD=<CdA=D4E=CdI=CdA<CTA<CD17Ad58BDQ@DDeGF59LGUEPHUQSIUYV
JEaXJeeZKUm/Kem]LF1^LP02H6mc00=QKgAQL7APL7D00V1`M@05Gg1eGfmeGVmeGFmeG6id01[oool0
2VM_LVA]Kf9ZKF1WJUeUIe]RIEQOHUELGe9JG51GF@9=DeH054U@DdI=D4=:C3m6BCa3ASQ0@cDm@34j
?R`e>Rhg?30j?cHo@ce5B3i7BSi8BT5;CTA>DDQAE4]CETiFF@9@FE`045ALGeMOHE]RIEeTIV1VJ69X
Jf=ZKFI^LFA]L6M`LfefNW5jOGAlOgEnPGMoPWR0PP=hP8<03WR0PWMoPWMnPGMnPGInP7EmOgAlOW=k
OG5iO71hNfmgNFefN6adMfYcMA[oool02VebLf]_LFQ]KVIZK6=XJF5UIeiRI5aPHUUMGeIKG09DF5X0
555EEdiCEDa@DTU>D4M;CDA9C497BT56BCi3Ad98BTE;CTY>DE1DEE9FF59GF5AIFeMKGEUNH5aPHV1T
I@9RIVL036MZJVY]KFiaLG9cLgEfMWQjNW]mOH63Ph64Q8F8R8Z=SXb?S`:=Si001hb?T8b?Sh^>SXZ=
SHV<S8N:RhJ9RP02Q8N800Z2QXN1Q8EoPXAmPH9kOh1iOGigNgeeNG]cN7UaMWLJoooo00YaM7I_LWA]
L79[KVmYK6eVJV]TJ6URIFMPHfENHV@2G61R00EJGV1HG5mGFeeEFUaDFE/00e=HF`0<DUQLF5iQG65U
Gf=VHfMYIFU/IVY/If]]J6a_JVi`KG1bL7=e0W=fM`0EMgUjNWalOX20PX>3QHJ6RH^;SHn@UINHV9ZJ
W9jOX::RWj6QWZ2PW9jOVibMVI^KUiVIUINGTYBET9:CSY2A00:<SXl02XZ<SHN:RhF7R8>5QX63Q7j1
PWaoP7YmOWQjO7IhNQcoool001[oool02UY/LUU[LEQYKeMXKUEVK5ATJU9RJ51PITmNI4eLH@9;FEl0
54UGG4IDFDAAET5?Dci;D3a8CCU5BCI2AS<n@c4l@Blk@2dh?Bli?S8l@C8m@C<n@3<n@SI2ACa7BSi:
C090C4l05D9=DD9>DTA@DdMAEDMBEDI@DT19C4A=D4QBED]FF4iJGE9NHEEQIEMTJ5UVJUYXK5aZKUe[
L5e/LEi]LUi^L`02Gfic0em_M007GfmeGVmeGVmeGVmeGFmeGFieG6id01[oool02VM`LVI^LFA]Kf=[
KF5YK5mWJUiUJ5aSIUYQI5QOHP9FGF0025AKGU9IG4mGFTeEEd]BEDQ@DdI>DTA<D092Bdl02T5;Cd19
CTA=DDM?E4M?DdM@DdMAEDYDEe1HFe=KG@9DGF0045MOHUQQHe]SIUiUJ61WJV9ZKEiVJV=[KfI_LVQa
M6]dMfifNG1hNg5iO79jOG9kO@=cNgh03W=kOG9jOG9jOG9jOG5jO75iNg1hNfmgNVmgNFifN6eeN6ad
Mf]cMVYbMA[oool02VibM6aaLf]_LFU]KfM/KFIZK6AXJV9WJ65UIUmSI@9MHF<055]PHEUNH5QLGUIJ
G5AIFe=HFU9FFE5EF51EF55FFE9GFU5GFUMKGEUMH5UMGeYNH5UNH5]PHV1TIV=VI`9UJFX036Q[K6U]
KVe`L71bLg9eMWQjNgIiNW]nOgf0PGj2PX64QH:5QP>3QXL01X:6QX:5QX64QH24QGn3Q7j2P`9mPH80
2Wb0PG]oP7YnOgQlOWMkOGIjNgEiNW=hNG9fN75eMa[oool02W9eMW5dMFmbM6iaLVa_LF]^KfU/KVQ[
KFMZJfEXJP9TIfT00f=VJ69UIf1TIP02Gf=U0eiRI@0<Gf=VHFEXHVMZI6Q[JVe_JfiaJVe`Jfm`Jfma
JfmbKg9dLGAe0W=fM`08MgUjN7]kNgenOX20PH>4RHZ;RH^<SY2A0XnATP:@TY<02HnBTXnATXf@T8b>
Sh^=SXV<SHR:RhN9RXF7R@02Q8J700Z2QHJ1PhAoPX=nP85lOh1kOGmiO7ehNWafNGYeN7TLoooo000J
oooo00YKKG=JK7=JJg9IJg5HJW1HJFmGJ6iFIfeEIVaDIF/2DfAY00]BHVQAHFM@H6E>GVA=GF9<Ff1:
FEm9F5e7EUa6EE]6E5X00TEDF@96E5X01DIDFDECF49@Ed=AEd=AEP02A59F0TECE`96DeL04DMDF4eJ
GTmLHE1NHU9PI5=RIUETJ5MVJUQWK5UYKUYZKe][L5a/LEa/LUe]LUe]Lee^L`09GFid0ea^M1[oool0
2VQaLfM`LVM_LVI^LFE]L6A/Kf=[KV9ZKF5YK61XJ`9OIfX02EiVJEeUJ5aTIe]SIUYRIEUQI5QPHeMO
HUINHP03EEiR00QFGf=GH6=GGf=GH6=FGf=DGV9FGf=GH6<2F65T00mIHVIJHfIKI6MLI6MNIfYTK6mU
KG1VKW5WL7=YLGAZLgE[M7M/MGM]MGQ]MWP01VifN@9]MWP2KGEh00Q]MGM/M7M/M7M[M7I[LgIZLgEZ
LWEYLWDJoooo00Y_LgE^LWA]LW=/LG9[L75[Kg5ZKW1YKFmXK6iWJfd2IV]/00MUJV]TJF]TJ6YSIfUR
IVQQIVQQIFL00f1UI`0:HFEXHFIXHfMYI6QZHfQZI6UZHfMZHVMYIFU[IVY[0VQ/K@0<JFe^JVi_Jfm`
KG1aKg=dMGQiM7QiMGUjMWYkMg]lN7amNGan17UmOP05N7anN7amN7amMg]mMg]l009fNW`02WIjNgEi
NgEiNWAhNW=hNG=gN79fN75fMg5eMg1eMQ[oool02W=eMg9eMW5dMW5cMG1cM6mbLfiaLfiaLVe`LFa_
L@9/Kg0016]^L6Y^KfY]KfY]KPAYK6h01FU]KfY^L6]^LFa_LFiaL`03Kg9d00A^LWA_LWAbMGIcMWL2
MGMh00YfNGYgNW]iNgajO7emOh22Q8F0PX>0PhB1PhB1Q8D2PXB500V1Q8F1PhB0PhB0PX=oPX=nPH9n
P85mP85lOh000WanO`0:NgeoNWenNGamNG]lN7YlMgYkMWUjMWQjMGQiM7Mh7?ooo`00oooooi7oool0
0?oooonAoooo003oooooTOooo`00oooooi7oool0043oool30000G?ooo`<0001Joooo0`0005[oool3
0000=?ooo`00@oooo`030000oooooooo05coool00`000?ooooooo`1Joooo00<0003oooooool0F_oo
o`030000oooooooo037oool002ooool200001?ooo`@00002oooo0`0000?oool300000oooo`80000n
oooo100000;oool400000oooo`@00002oooo0`0000?oool300000oooo`80000noooo0`0000;oool2
00001?ooo`@00002oooo0`0000?oool300000oooo`80000loooo0`0000Coool200001?ooo`@00002
oooo0`0000?oool300000oooo`80000^oooo000^oooo00@0003oooooool00002oooo00@0003ooooo
ool00002oooo00<0003oooooool00oooo`040000oooooooo0000@oooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00@0003oooooool00002oooo00<0003oooooool00oooo`040000oooooooo
0000A?ooo`040000oooooooo00000_ooo`040000oooooooo00000_ooo`040000oooooooo00001Ooo
o`040000oooooooo0000@Oooo`040000oooooooo00000_ooo`040000oooooooo00000_ooo`040000
oooooooo00000_ooo`030000oooooooo00?oool010000?ooooooo`0003?oool002koool010000?oo
ooooo`0000;oool010000?ooooooo`0000;oool400000_ooo`040000oooooooo0000A?ooo`030000
oooooooo00?oool00`000?ooooooo`02oooo00@0003oooooool00002oooo100000;oool010000?oo
ooooo`00047oool500001?ooo`040000oooooooo00000_ooo`030000oooooooo00@00002oooo00@0
003oooooool00011oooo00@0003oooooool00002oooo00@0003oooooool00002oooo00@0003ooooo
ool00002oooo100000;oool010000?ooooooo`0003?oool002koool010000?ooooooo`0000?oool3
00000oooo`800004oooo100004Coool00`000?ooooooo`03oooo00<0003oooooool00_ooo`<00003
oooo0P0000Coool40000@?ooo`040000oooooooo00000oooo`800004oooo0`0000?oool200001?oo
o`@00010oooo0`0000Coool200001?ooo`<00003oooo0P0000Coool40000<_ooo`00;_ooo`040000
oooooooo00001Oooo`030000oooooooo04goool010000?ooooooo`0000;oool010000?ooooooo`00
00Goool00`000?ooooooo`1<oooo00<0003oool000000oooo`030000oooooooo00Goool00`000?oo
ooooo`1<oooo00<0003oooooool00_ooo`040000oooooooo00001Oooo`030000oooooooo03goool0
02ooool200001Oooo`80001@oooo0P0000Coool200001Oooo`80001?oooo0P0000?oool300001?oo
o`80001>oooo0`0000?oool200001Oooo`80000ooooo003oooooTOooo`00oooooi7oool00?oooonA
oooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonA
oooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00oooooi7oool00?oooonA
oooo003oooooTOooo`00oooooi7oool00?oooonAoooo003oooooTOooo`00LOooo`<0002Uoooo0`00
07Coool007Coool00`000?ooooooo`2Uoooo00<0003oooooool0LOooo`00IOooo`<00004oooo0`00
00?oool300000oooo`800003oooo1@000004oooo0000000000001?ooo`80000:oooo0`000003oooo
0000000000;oool200000_ooo`<00002oooo100000?oool300000_ooo`D000001?ooo`0000000000
00Coool300000oooo`@00008oooo0`0000;oool300000oooo`<00004oooo10000004oooo00000000
00001?ooo`<00003oooo0P0000Coool300002Oooo`<000002?ooo`0000000?ooo`000?ooo`000?oo
o`D00002oooo0`0000?oool300000_ooo`<0001Xoooo001Voooo00<0003oooooool01?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`08oooo00D0003oooooooooool000000_ooo`030000
oooooooo00koool01@000?ooooooooooo`000002oooo00@0003oooooool00006oooo00<0003ooooo
ool00_ooo`030000oooooooo00?oool400001Oooo`040000oooooooo00001Oooo`040000oooooooo
00002_ooo`030000oooooooo00;oool00`000?ooooooo`03oooo00<0003oooooool00_ooo`040000
oooooooo00001Oooo`030000oooooooo00;oool00`000?ooooooo`02oooo0P0000?oool00`000?oo
ooooo`0;oooo00X0003oooooooooool0003oool0003oool0003oool400000_ooo`040000oooooooo
00000_ooo`030000oooooooo00Koool00`000?ooooooo`1Uoooo001Voooo00<0003oooooool01?oo
o`050000oooooooooooo000000;oool00`000?ooooooo`08oooo00D0003oooooooooool000000_oo
o`030000oooooooo00koool01@000?ooooooooooo`000002oooo00@0003oooooool00006oooo00<0
003oooooool00_ooo`@00005oooo00<0003oooooool00`0000?oool400000_ooo`040000oooooooo
00002_ooo`030000oooooooo00;oool00`000?ooooooo`03oooo00<0003oooooool00_ooo`040000
oooooooo00000_ooo`<00005oooo00D0003oooooooooool000000_ooo`030000oooooooo00@0000:
oooo00T0003oooooooooool0003oool0003oool000001?ooo`040000oooooooo00000_ooo`030000
oooooooo00@00002oooo0`0006Soool006Koool200001?ooo`800004oooo100000Woool010000?oo
ooooooooo`<0000Aoooo00<0003oooooool0100000Coool300000_ooo`@00003oooo0P0000Coool3
00000_ooo`@00003oooo0P0000Coool300002Oooo`800004oooo00<0003oooooool00oooo`040000
oooooooooooo0P000003oooo0000000000;oool400000oooo`800002oooo0P0000;oool200000_oo
o`80000:oooo0P0000;oool3000000?oool0003oool00_ooo`<00003oooo100000;oool200000ooo
o`@0001Woooo001Voooo00@0003oooooool0000Eoooo00<0003oooooool00_ooo`030000oooooooo
013oool00`000?ooooooo`0^oooo00<0003oooooool03Oooo`030000oooooooo00?oool00`000?oo
ooooo`2_oooo001Uoooo1@0000?oool00`000?ooooooo`0>oooo0P0000Coool300003oooo`<0000^
oooo0P0000[oool010000?ooooooooooo`800004oooo0P0001;oool00`000?ooooooo`0Eoooo00<0
003oooooool0Q?ooo`00oooooi7oool00?oooonAoooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.195393, -0.100021, 0.0110045, \
0.0110045}, {{17.75, 102.25}, {389.875, 305.375}} -> {-24.7497, -10.231, \
0.945827, 0.945827}, {{110.688, 195.25}, {389.875, 305.375}} -> {-112.682, \
-10.231, 0.945827, 0.945827}, {{203.688, 288.25}, {389.875, 305.375}} -> \
{-200.644, -10.231, 0.945827, 0.945827}, {{296.688, 381.188}, {389.875, \
305.375}} -> {-288.577, -10.231, 0.945827, 0.945827}, {{17.75, 102.25}, \
{296.875, 212.375}} -> {-24.7497, -98.193, 0.945827, 0.945827}, {{110.688, \
195.25}, {296.875, 212.375}} -> {-112.682, -98.193, 0.945827, 0.945827}, \
{{203.688, 288.25}, {296.875, 212.375}} -> {-200.644, -98.193, 0.945827, \
0.945827}, {{296.688, 381.188}, {296.875, 212.375}} -> {-288.577, -98.193, \
0.945827, 0.945827}, {{17.75, 102.25}, {203.938, 119.375}} -> {-24.7005, \
-185.936, 0.945006, 0.945006}, {{110.688, 195.25}, {203.938, 119.375}} -> \
{-112.557, -185.936, 0.945006, 0.945006}, {{203.688, 288.25}, {203.938, \
119.375}} -> {-200.442, -185.936, 0.945006, 0.945006}, {{296.688, 381.188}, \
{203.938, 119.375}} -> {-288.298, -185.936, 0.945006, 0.945006}, {{17.75, \
102.25}, {110.938, 26.375}} -> {-24.7005, -273.821, 0.945006, 0.945006}, \
{{110.688, 195.25}, {110.938, 26.375}} -> {-112.557, -273.821, 0.945006, \
0.945006}, {{203.688, 288.25}, {110.938, 26.375}} -> {-200.442, -273.821, \
0.945006, 0.945006}, {{296.688, 381.188}, {110.938, 26.375}} -> {-288.298, \
-273.821, 0.945006, 0.945006}}]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "Thus, we have succeeded in expanding the three-dimensional color image by \
means of the wavelet transform.\n\tAfter setting a mouse cursor on a \
following image, twice clicking the left side button of mouse animates the \
facial changes depending on the lighting angles. This is only effective on \
the ",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" notebook.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["Do[Show[GraphicsArray[{incIllusionG[[i]]}]],{i,angle}];", "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
69.000 12.813 moveto
(deg) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
5C6E745C6E755C6E755C6E755D6F755D6F755D6F755D6F755D6F755D6F765E6F765E6F76
5E70765E70765E70765E70765F70775F70775F70775F70775F70765F70765F70755F6F74
6070765F71775F71785F71775F72785F72785F72785F72785F71785F72785E72785F7278
5E71785F72785E72785F73795F73795F737A5F747A5F747A5F747B60757C60757C61767D
62788061767D60757C60747B5F737A5F73795F73795E72795E72785E71785E71775D7077
5D70765D6F765C6F755C6E75
5C6E745C6E755D6F755D6F755D6F765E70765E70765E70765F70775F71775F7177607177
607178607278617278617279617379627379627379627379637379637378637277637175
63737863747A63757B63757B62757B62757B62757B62767C63767C62767C62767C62767C
62767C62767C61777D62787E62787F637980637A81637B81637B82647C83647D84657D85
667E86657D84647B83637A8163798062777F62777E61767D60757C60747B5F737A5F7279
5E72785E71775D70765C6F75
5C6E745D6E755D6F755E70765E70765F70765F7177607177607278617278617379627379
62737963737A63747A64747A64757B65757B65767C66767C66767C67767B67757A677478
67767C67777D67787E66787E66787E65797F65787E65787D65787D64787E64797E63797E
63797E63797F637A80647C82657E84667F8667808768818868828968838B69848C69858E
69848C69838B68818A678088667E86657D85657C83647B8263798062787F61767D60757C
5F737A5E72795E71775D6F76
5C6E755D6F755E6F755E70765F707760717760717861727862727862737963737A63747A
64757B65757B66767C66767D67777D68787E69787E69797F6A797F6B797E6B797D6B787C
6B7A7F6B7B806A7B816A7C82697C82687B81677A8065797E65787D65787D64797E647A80
647C81647D83657E8466808667828869848B6A858C6B878E6B88906C8A926D8C956F8F98
6D8C956C8A936C88916B868E6A848C69828A678088667E86657D84647B8263798062777E
61757C5F737A5E72785D7076
5D6E755D6F755E6F755F707660717761727861727862737963737A64747A65757B65767C
66767D67777D68787E69797F6A7A806B7A806C7B816D7C826E7D826F7D826F7D826F7C80
6F7D836F7E856E7F856D7F856D7F856C7F846B7E836A7D82697C81687B80677B80677C82
677E84677F8667818868838A69878D6B89906D8A926E8D956F909870919A72939D7395A0
72939D71909A6F8E976E8C956D89926C87906A858D69838B688089667E86657C84637A81
62777F60757C5F73795D7077
5D6E755E6F755F707660717761727861727962737963747A64757B65757C66767C67777D
68787E69797F6A7A806B7B816C7C826E7D836F7E84707F85728186738287748287748186
7482877382887283897183897083897082886F82886E82876D81866C80856B7F856B8086
6B82896B848B6C868D6C88906D8B936F8F9770919972939C74969F7599A2769AA4779BA6
7699A47597A173949E72929C718F996F8C966D89936C87906A848D68818A677F87657C84
63798161767E5F747A5E7177
5D6F755E70765F707760717861727862737964747A65757B66767C67777D68787E69797F
6A7A806B7B816D7C826E7D836F7E8471808572818774838876848A78878C7A898F7A898E
78878C77868C76868C75868D74868C74878C73878C72868C72868C71868C70878C70878D
70888F708A91708C93718E9672919973949D7598A2779BA4789DA77AA0AB7CA3AE7BA2AD
7AA0AB799DA9779BA67698A274949F72919B718E986F8B946D88906B848D698189677E86
647B8362787F60747B5E7178
5D6F755E707660717761727862737963747A65757B66767C67777D68787E6A797F6B7A80
6C7B816E7D836F7E84707F8572808673828875838A77858B79888E7D8C928290957E8C92
7C8B907A8A8F798A8F798A90788B91778B90778B91768C92768C92768D92758E94758F95
76909676929876949B76959D7898A1799BA47A9EA77BA1AC7DA4AF7FA7B380ABB880AAB6
7FA7B47DA4B17CA1AD7A9EA9789AA57696A174939D728F996F8B956D88916B848C688088
667C8463798061757C5E7278
5D6F755F707660717862737963747A64757B66767C67777D69787E6A797F6B7B806D7C82
6E7D83707E8471808673818774838976848A77868C79888E7B8A907D8C91859397808E94
7E8D937D8D937D8D937C8E947C8F957B8F957B8F947A90957A91977A93997A969B7B989D
7B999F7B99A07C9AA27C9CA47D9EA77DA1AA7FA4AE80A8B382ACB884B0BD86B5C385B2C0
83AFBD82ACB980A8B47EA4B07CA0AB799CA77798A274939D728F996F8B946D878F6A828B
677E86647A8261767D5F7279
5D6F755F707661717762737964757B65767C67777D68787E6A797F6C7B806D7C826F7D83
707F8472808674828775838977858B78868C7A888E7B8A907C8A927D8B927F8C93818F95
8190968090968091978091987F92987F93997F93997E94997E959B7F979D7E9A9F7F9DA1
809FA480A1A681A2A981A3AB83A5AE83A8B184ABB484AEB986B2BE88B6C48BBDCC8ABCCB
88B8C686B3C184AFBC82AAB780A6B27DA1AD7A9CA77798A275939D728E986F89926B858D
688088657C8362777E5F7279
5E6F755F707761727863737965757B66767C68787D6A797F6B7A806D7C816F7D83717F84
72808674828776838978858B79878D7B888F7D8A907F8D947E8C927D8A90808D93829096
83919883939983949B83959C83969D83969D83979D82979D81999E829CA1829FA382A2A6
83A5A984A7AC85A8AD86AAB087ABB388AEB789B0BA8AB3BE8AB7C38DBCCA8FC2D290C5D5
8EC0D08BBBCA89B6C486B1BE84ACB881A6B27EA1AD7B9CA77797A174919B718C956D8790
6A828B667D8563787F5F737A
5E6F7660717762727863747A65757B67777D69787E6B7A806D7B816F7D83717E84728086
74828776838978858B7A878D7C898F7E8B91808C937C898F808C92818E94838F95849198
85939A86959C87979E8799A0879AA1879AA1879AA0869AA085989E85999F859BA2869EA5
86A2A788A8AD89ACB18BAEB48DB0B78DB2BB8EB5BF8EB7C38EBBC790BFCD91C4D494CADB
93C9DB90C3D38EBDCC8BB7C588B2BF85ACB881A6B27EA0AB7A9AA576959F738F986F8992
6B848C677E8663798060737A
5E6F7660717762727964747A66767C68787D6A797F6C7B806E7C82707E84728085748187
76838978858A7A878C7D898E7F8B91818D93848F958A959B869198859197869298879399
87949B89969E8A9AA18B9CA38B9DA48C9DA48B9CA38A9BA288979E87959C87959C87979E
889BA38BA4AB8DABB18FB0B791B4BB92B6BF93B9C393BBC793BDCA93C1CF94C6D596CADB
97CEDF95CADB93C4D490BECC8CB8C589B1BE85ABB781A4B07D9EA97998A275929B718C94
6C868E688087647A8160747B
5E6F7660717763737965757B67777C69797E6B7A806E7C81707D83727F84748186768388
78848A7A868C7D888E7F8B90818D92849095848F95899398899398889398899499899399
8A959B8B989E8D9BA390A0A690A0A690A0A6929DA48B959C889399858E9585909787979E
89979F8C9CA490A4AC95B0B796B7BE97BAC297BCC697BEC996C0CC96C2D097C7D699CBDC
9BD1E39BD1E398CBDC95C5D491BECC8DB7C489B0BC84A9B480A2AD7B9BA577949E728E97
6E8790698189657A8260747B
5E707661717863737966757B68777C6A797E6D7B806F7D82717E84738085768287788489
7A868B7C888D7F8A8F818C92848F948690958E969A8C94998B94998B93998B959A8B949A
8B949A8C969C8E9AA1929FA6949FA68C939A8C92998B90978A8F96899198878F96869199
85939A88989F8C9FA695ABB29BB7BE9CBDC49CBFC89BC1CC9AC2CE99C4D199C7D69BCCDC
9DD1E29ED4E59ED1E19BCCDB97C4D292BCC98DB4C188ADB883A5B07E9EA87997A1749099
6F89926A828A657B8361757B
5E707661727864737966757B69787D6B7A7F6E7C81707E83737F8575818677838879858A
7B878C7E898E808B90848E9487929787919592999D8F969B8E95998D93988D94998D9399
8D93988C93998E949B8D959D929CA38F9AA28E99A08E98A08D969E8C97A08B98A08B9BA4
8A9CA5889DA7879CA58BA3AB96AFB7A0BEC5A0C3CC9FC5CF9DC5D09CC5D29CC8D79DCDDC
9FD2E3A0D6E8A2D5E7A1D3E29DCBD996C2CF91B9C58BB1BC86A9B480A1AB7B99A376929B
718B936B838B667C8461757C
5F707661727864747A67767C6A787E6D7A806F7D82727F847481857782877984897B868B
7D888C7F898E818B918690968E989E8D959A8F969A9096998F969A8F969A8F959A8F9398
8D91968C90958A8C928889908C8E958F949B90969D9099A1909AA18F9BA38F9CA48FA0A9
8EA3AB8FA5AE8DA3AD8DA8B190ACB59BB8C0A4C5CDA2C7D0A1C7D29FC7D49ECAD8A0CDDC
A1D2E2A2D6E8A3D7E8A3D4E5A1D0DE9BC6D495BDCA8FB4C089ACB783A4AE7D9CA678949D
728C956C848D677D8461757C
5F707662727865747A68777C6B797E6E7B80717E837480847682867984887B858A7D878C
7F888D80898E808A8F808A8E8890958F94988F9497919599929699929698929598919397
90919590929791949990919790919891929991939A90939B90939B8F959D8F969F8F98A1
909BA590A1AB91A4AE90A8B291ADB796B3BDA0C0C9A5C8D1A3C8D3A1C8D4A0CAD8A1CEDD
A3D2E2A4D7E7A8DCEEACDDEEA5D3E29FCBD898C1CD92B8C48BAFBA85A6B17F9EA879969F
738E966D868E687E8562767D
5F707662727865757A69777C6C797E6F7B80727E837581857883877B85897D878B7F898D
818A8E818A8F7F878C7881867A8389898F93909598939699949599949698949698949396
92919592929695989C95989E95979D95969D94979D94979D94979D93989F9399A1939CA4
949FA795A2AB96A4AF96A6B195A8B396ACB79BB5BFA2C0CAA4C6D1A3C8D4A2CAD7A3CDDB
A4D1E1A5D5E5A5D6E7AFDEEEAAD7E6A2CDDB9BC4D195BBC78EB2BD88A9B381A0AA7B97A1
758F986E878F687E8662767D
5F707663737866757B6A787D6D7A7F707D81747F847782867A84887D878A80898D828B8E
848C90858D91848B91848C91878D918E939594979A97989A97989A989799989698979597
969395969497989A9E9A9DA39A9CA2999BA0989AA0989AA097999F9699A0979CA397A0A7
98A2AA99A5AD9BA8B19BABB59BAEB89DB2BD9FB8C3A2BEC8A4C4CEA4C7D2A4CAD6A4CEDB
A5D1DFA5D4E3A6D6E7B2E0EEADDAE7A6D1DE9FC7D498BDC991B4BF8AABB583A2AC7D99A2
7690996F8890697F8662767D
5F707663737967757B6A787D6E7B7F727D827580847983877D868980888C838B8E868D90
888F928A91948C92958E949891989B959B9D999C9D9A9C9D9B9B9D9C9A9C9C999B9C9899
9B96989A97999B9A9D9D9FA39EA1A69D9FA49C9EA39B9EA39B9DA29A9CA29A9EA49BA2A8
9BA5AC9BA7AF9DABB29FADB69FB1B9A0B4BDA2B9C2A4BFC9A5C3CDA6C7D1A5C9D5A5CDD9
A5D0DDA4D2E1A3D4E4B4E2F1B1DEEDA9D4E2A2CAD79AC0CC93B6C18CADB785A4AD7E9BA4
77919A70899069808763777E
60707663737967767B6B797D6F7B80737E827781857B84887F878A838A8D868D908A9093
8D939590959893989B959B9D999EA09BA0A29EA0A19FA1A1A0A0A1A09F9FA19D9EA09C9D
A09A9C9F9A9C9F9C9FA1A0A4A2A4A8A1A2A7A0A0A59F9FA49E9FA39D9EA39DA0A59DA2A8
9EA6AC9FA9AFA1ADB3A2B0B7A4B4BAA4B6BDA4B9C1A6BEC6A7C2CBA8C6D0A7C9D4A7CCD8
A6CFDCA4D0DFA0D0E1B1DFEFB6E3F1ADD8E5A4CDD99DC2CE95B8C38EAFB987A5AF809CA5
79939B7189916A808863777E
60717764737968767B6C797E707C80747F837982867D858881898B868C8E8A8F928E9395
929698969A9B9A9EA09DA1A3A1A4A5A2A4A5A3A4A5A4A4A5A5A4A4A5A3A3A5A2A2A5A1A1
A5A0A0A59FA0A49FA1A5A2A4A6A5A9A5A5A9A4A4A8A3A3A7A1A2A6A0A2A6A0A3A8A1A6AB
A2A9AEA3ABB1A5AEB5A6B2B9A8B6BDA9B9BFA9BCC2A9BFC7AAC2CBAAC6CFAAC9D4A9CCD7
A8CEDAA4CFDD9DCCDCA2D3E4B1DFEEB2DDEAA6CEDB9EC4CF97BAC590B0BA89A7B0819DA6
7A949C728A926B818863777E
60717764737968767B6D797E717C817680837A83867F8689848A8C898E908E9293939697
989A9B9CA0A0A1A6A6A4A9A8A8AAAAAAA8A8AAA8A8AAA8A8AAA8A8AAA8A8ABA7A7ABA6A6
AAA5A5AAA5A5AAA4A5A9A5A6AAA7A9A9A7AAA8A7AAA7A7AAA5A5A9A4A6A9A4A6ABA5AAAE
A7ADB1A8B0B4AAB2B7ACB6BBADB9BFADBBC2AEBFC5ADC1C9ADC5CDAEC8D1ADCBD5ADCED8
ABD0DCA9D2DEA5D0DDA3D0DEA4D1E0A8D3DFA6CEDAA0C5D099BCC692B2BC8BA8B2839FA7
7B959D738B936C818964787E
60717764747969777B6D7A7E727D817780837C848681878A868B8D8C8F91929495979899
9D9D9CA2A2A1A7A7A6ACACABAEAEADAFADACAFACABAFACABAFACABAFACABB0ACABB0ACAB
B0ABABB0ABABAFABABAFACACAFABACADAAABABA8AAAAA7A9A8A6A9A7A7A9A7A8ABA8ABAF
AAAFB2ADB2B6AEB5B8AFB7BCB1BBC0B2BFC4B3C2C8B2C4CBB2C7CEB2CAD2B2CDD6B1D0D9
B1D3DCAFD5DFADD4E0ADD7E5AEDAE8ACD6E2A8CFDBA2C7D29CBEC894B4BD8DAAB385A0A8
7D969E748C936C828964787F
60717765747969777B6E7A7E737D817880847D848783888A898C8E8F91919596969C9B9B
A4A0A0AAA5A4B0ABAAB5B1AFB6B3B0B6B2B0B5B1AFB5B0AEB4B0AEB4B0AFB5B0B0B6B1B0
B6B1B0B6B2B0B6B1B0B5B2B1B4B1B1B2AFAFB0ACADADAAABABA8A9A9A8AAA9AAACABADAF
ADB0B3AFB4B7B2B7BAB4BBBFB6BFC3B7C3C7B7C5CBB8C8CEB7CAD1B7CCD4B7CFD8B7D2DB
B7D5DEB6D8E2B4D8E3B4DCE8B6E1EEB3DDE9ADD3DEA6CAD49FC0C997B6BF8FABB486A1A9
7E979F768D946D828964787F
60717665747969777B6E7A7E737D807981837E848784898A8B8D8E919292989796A09D9B
AAA6A5B5AEACBDB4B0C0B8B4BFB8B4BDB6B3BBB5B2BAB4B1B9B3B1B9B3B1B9B3B2BBB4B2
BCB5B3BDB7B4BCB7B4BBB6B5BAB5B5B7B2B2B4AFB0B1ACADAEA9ABACA8AAACABADAEAEB0
B0B3B5B3B7B9B6BBBDB9BFC2BBC3C6BDC7CABDC9CDBDCBD0BDCDD2BDCED5BDD1D8BDD4DC
BCD8E0BDDBE4BCDDE7BCE2EDBBE4F0B9E3EFB1D7E2AACDD6A2C2CB9AB8C091ADB588A3AA
80989F778D956E838A65787F
60717665737969767B6E797D747D807980837F848686898A8C8E8E9392929A9796A29C99
ACA6A3BAB1ADC4B9B3CBC0B9C7BDB7C3BAB5C0B7B4BEB6B3BDB5B2BDB5B2BEB5B2C0B6B4
C1B8B5C3BBB8C3BDBAC2BDBBC0BBB9BCB7B6B7B2B2B4AEAEB0ABACAFAAABAFACADB1B0B1
B3B5B7B7BABCBABEC0BEC3C5C1C7CAC2CBCDC3CDD1C3CFD3C2D0D5C2D2D8C2D4DAC2D6DD
C2DAE1C3DEE6C3DFE8C4E6EFC3E7F1BFE6F1B7DBE4AED0D9A6C5CD9DBAC294AFB68BA4AB
8199A0788E956F838A65797F
60707665737869767A6E797D737C7F7980827F848686898A8E8E8E9593929D9896A39B97
A9A29DB8AFAAC7BAB4D1C3BBCDC0BAC8BCB7C5BAB5C1B7B2C0B6B2C1B7B4C2B9B6C6BCB9
C9BEBACBC0BBCAC1BCC8C1BDC5C0BDC1BBBABBB5B3B6AFAEB2ABABB0AAAAB0ACADB2B0B2
B6B6B7BABBBDBEC1C2C3C5C7C6CACCC8CED0C8D0D2C9D2D5C7D3D7C6D5D9C7D7DCC7D9DF
C7DCE2C8DFE6C8E2E9CCE9F0CBECF4C6EAF3BCDEE6B3D2DAA9C7CFA0BCC396B0B88DA5AC
839AA1798F966F848B66797F
60707664737869757A6E787C737B7E797F817F83858788898F8E8E989493A09A97A69E9B
AEA5A0BFB3ACCCBDB5D6C5BCD1C2BACCBEB7C7BBB5C4B7B2BFB3AEBEB2AEBFB3AFC3B6B2
C9BBB6CFBFBACFC1BDCCC1BDC9C2BEC5BFBCBDB6B4B7AFAEB3AAA9B0A9A8B0ABABB3B0B0
B7B6B7BCBDBEBFC1C2C3C6C7C8CCCDCCD1D2CDD4D5CED6D8CDD6D9CBD7DBCBD9DECCDBE0
CDDDE3CCE0E6CCE2E8CFE7EDD0ECF3CBEDF4C1E0E8B7D5DCAEC9D0A3BEC499B2B98FA7AD
859BA27B909670848B667980
6070766472776874796C777A727A7C777D7F7E8283868787908E8D9B9694A49C98A9A19D
ACA39FBBAFA8CCBCB3D9C6BCD4C2B9CFBEB6CABBB4C6B7B0C1B2ACBBADA7B7ABA6B5AAA5
BBAEAAC3B4AFC8B8B3C7B7B2C3B6B2C1B7B3BCB3B1B7AEABB3A9A7B0A8A6B0AAA9B3B0AF
B7B6B6BFC0BFC2C3C3C8C9C9CED0CFD2D4D5D2D6D7D3D9DAD2DADCCFDADDCEDBDECEDDE1
D0DFE4D1E2E6D3E5E9D7EAEED7EDF2D1EEF3C6E2E8BCD7DDB2CBD1A7BFC59CB4BA91A8AE
879CA27C909771858B667980
5F70766372776773776B757970777A757A7C7C7F808485858F8D8C9F9A98B0A8A3B1A6A1
B1A7A1BDB0A8CEBCB2DCC7BCD7C3B9D1BFB6CCBBB3C8B8B0C3B3ACBDADA6B8A9A3B1A49F
AEA29DB2A5A0B9ABA7BEAFAABFB1ADBEB3AFBBB1AEB7ADAAB3A9A6AFA7A4AEA7A6AFABAA
B0ADADB7B6B6BEBDBBC6C5C4CFCECCD1D3D1D5D7D6D8DCDBD6DCDCD3DCDECFDBDED0DCE0
D2DFE3D4E3E7D8E7EBE0EEF1E0F2F6D8F1F6CCE5EAC1DADFB6CED3ABC1C79FB5BB94A9AF
889DA37D919772858B677A80
5F6F756270756571756973766D7477727779777A7B7F7F7F8B89889A9492AFA39EBBADA6
BCAEA7C4B4ABD0BDB2DDC7BBD8C3B8D3BFB5CEBBB1CABAB0C6B5ADC0AFA7BBA9A1B6A59E
B5A59DB6A69EB9A8A1BCACA6BEAFA9BDB0ABBBAFABB7ACA8B3A8A4AFA6A2ADA5A3ADA8A7
AEAAABAFB0B1AFB2B3B1B6B7C0C1C1C5C9C9C9CDCCCFD3D3CFD5D5CFD7D8CED9DBD0DCDE
D3DEE1D5E2E5DDEAECE4F0F3E7F8FAE0F7FAD3E9EDC7DDE1BAD0D4AEC3C8A2B7BB96AAAF
8A9EA37E929773868B677A80
5E6E73616F73646F736770736A71746D72747274757676767A77768D87849F938FB0A19B
B9A9A2C4B2A9D0BCB1DDC7BAD9C3B8D4BFB4CEB8AEC9B4AAC7B4AAC5B2AAC1AEA6BEAAA2
BDA89FBEAAA1BFABA3C0AEA6C1B0A8BDAEA7BAADA8B7ABA6B3A7A3AFA6A2ADA5A1ADA8A5
AFACAAB1AFAFAFB0B1A9AEB0AEB3B4B5BBBCBBC2C3C3C9C9C8CECECCD3D4CED6D7CFD9DB
D2DDDFD4E0E3DEE9EBE6F1F1EAF7F8E5FAFCD9EDF0CCE0E3BFD2D6B2C5C9A5B8BC98ABB0
8C9EA37F929773868C687A80
5E6D73606D72626D71646D71666D70696D6F6B6D6E6D6D6D6F6B6B827C79958B86A59892
B2A29BC2AEA5D1BAAEDEC5B8DBC4B8D5BFB4D0B9AFC9B3A8C2ACA2BFA99FBCA69CB9A298
B49E95B59F95B7A097B9A49BBBA8A0BBAAA3BAAAA4B7AAA4B3A7A2AFA5A0ADA49FADA7A2
B1ADA9B4B2AFB4B3B2B3B4B4B4B7B7B5B9B9BABEBEC2C6C5C7CCCBCAD1D0CDD5D4CFD9D9
D1DCDDD5E0E1E1E9E9E9F0EFEAF4F5EBFCFDE0F1F3D2E3E5C3D4D7B5C6C9A7B9BC9AACB0
8D9FA380929774868C687A80
5D6D725E6C71606B6F616B6E62696C64686A65676866656565626175706E88807C9A8E89
AC9C95BEABA1CEB8ACDDC3B6DDC5B8D8C1B5D2BCB1CDB6ABC6AFA4C0A79DBAA197B79E93
B59B90B49A8FB59B90B89F95BAA59CBCA9A1BBA9A3B9A9A3B5A7A2B0A5A0ACA19EA89F9C
A9A39FB1AEA9B7B5B1BBBAB6BBBBB9BCBEBCBEC1C0C3C6C5C7CBCACAD0CFCCD4D3CDD7D6
CFDADAD5E0E0E0E8E7EDF2F0EFF7F6F1FFFFEBFAFAD7E6E7C7D6D8B7C7CAA9B9BC9BACAF
8E9FA381929774868B687A80
5C6C725D6A6F5E696D5E676B5F66685F64655F61625F5E5F5E5B5A6D67657E7672918680
A3948DB7A49BCBB4A8DAC1B3DEC5B7DAC3B6D6BEB3D0BAAECBB4A9C6AEA3C2A99EBFA59A
BDA397BCA297BCA397BDA599BDA79DBDAAA2BCAAA3BAAAA4B7AAA4B3A8A2AFA5A0AAA29E
A5A09CA4A29EA8A8A4B3B1AEBCBBB7C1C1BDC3C4C1C6C8C5C8CBC9C9CECCC9D0CFCBD3D2
CBD5D5D5DDDDE1E7E5EFF1EDF4F7F4F0F9F8EDF8F7DAE7E7C9D7D8B9C7C9AAB9BC9CACAF
8E9FA381929775868B687A80
5C6B715C696E5B676B5B64685B62655B5F615A5C5D59595957555464605F746E6A897E79
9C8E87B19F95C6B0A3D8BEB0DFC6B7DEC5B8D9C2B6D4BEB2D0BAAECCB5AAC8B1A6C5ADA2
C4AB9FC2AA9EC2A99DC2AA9FC1ABA0C1ADA3BFADA5BDADA5BBACA5B8ABA5B4AAA5B0A8A3
ABA6A2A9A5A2A7A6A3A8A8A6ACADABB3B4B2B8BBB9BDC0BEBFC3C1C4C9C7C7CDCBC9D0CF
C9D1D1D2DAD8DDE2E0E8E9E6F1F0EDF1F5F2EEF6F4DCE6E5CBD6D6BAC7C8ABB8BA9CABAE
8F9EA281929675858B687A7F
5B6B705A686D596569596265585F61565B5D555859535454525050605C5B6E6865817772
968880AB9A90C1AB9FD5BCADE0C6B7E0C8BADCC5B8D8C1B5D4BEB2D1BAAECEB7ABCBB4A9
CAB2A6C8B1A5C7B0A4C7B0A4C6B0A5C5B1A7C4B1A7C2B1A8BFB1A9BDB0A9B9AFA8B6ADA8
B2ACA7AFABA7ADABA8ADACA9ADAEABAFB1AEB3B5B3B9BBB9BDC1BFC1C5C4C4C9C8C6CDCC
C9D0CFD0D6D4D8DDDAE0E3E0E9EAE7EEF1EDEEF4F2DEE7E6CBD5D4BAC5C6AAB7B89CA9AC
8E9DA081919574858A68797F
5A6A7059676B576367565F63545B5E5257595153544E4F4F4C4A4A5A565468625E7A706B
8E8079A69389BCA599D0B7A8DFC4B5E3CABBDFC8BADBC5B8D8C2B6D5C0B4D3BCB0D1BAAE
CFB8ADCEB7ABCDB6AACCB5A9CBB5A9CAB5ABC9B5ABC7B5ACC5B5ACC2B5ADBFB4ACBCB2AC
B9B1ABB6B1ABB4B1ACB3B1ACB4B2AEB5B5B1B7B8B5BBBCB9BFC0BEC2C4C2C4C7C5C5CAC8
C9CECCCFD3D1D6D8D5DDDEDAE3E4E0E9EAE5E9ECE9DCE3E1C9D1D0B8C2C2A9B4B59AA7AA
8D9B9E80909374848968797F
5A6A6F58656A566165535D6051585B4F54564C4F504A4A4A46454454514F635C59736964
8679719C8B81B29D91C7AEA0D8BDADE2C8B8E1C9BBDEC8BADBC6B9D9C4B8D7C2B6D6BFB3
D4BEB1D3BCAFD2BBAFD1BBAED0BAAECFBAAECEBAAFCCBAB0CABAB0C8B9B0C5B9B0C3B8B0
BFB7B0BCB6AFBBB6B0B9B6B1B9B7B2BAB8B4BBBBB6BCBDB9BEC0BDBFC3C0C1C5C3C2C7C5
C5CAC8CBCFCCD1D4D0D6D8D4DBDCD8E0E0DBE0E1DDD6DBD8C4CBC9B4BDBDA6B1B298A5A7
8C999C7F8E9273838867787E
59696F566469545F64515A5E4E55584B5052484B4C45464642403F4F4B495D57536D635E
7F726A94837AAB968AC0A89AD1B7A8DEC3B4E2C9BBE0C9BCDEC8BBDDC7BBDBC7BADAC5B9
D9C3B6D8C1B4D8C0B3D7C0B3D6BFB3D4BFB2D3BEB3D2BEB4D0BFB4CEBFB5CBBEB4C8BDB4
C5BCB3C2BAB3C1BAB3BFBAB4BEBBB5BEBBB6BEBDB8BEBEBABFC0BCC0C2BFC0C3C0C0C4C2
C4C8C5C7CAC7CCCECACFD1CDD3D4D0D7D7D2D5D6D2C9CDCABDC3C1AFB8B7A2ACAD96A1A3
8A97997E8C9072828767787D
59686E556368525E624F585C4B5255474D4F4447484042423D3C3C4B474558524F675E59
786B648B7C72A28D82B9A092CDB1A1DABEADE1C7B7E2CABBE1CABCE0CABCDFC9BDDFC9BD
DEC8BBDDC7BADDC6B8DCC5B8DCC5B8DBC5B8D9C4B8D7C4B8D6C3B8D4C3B8D1C2B8CEC0B7
CBBFB7C8BEB6C6BEB6C4BEB6C3BDB6C1BDB7C0BDB8C0BFB9C0BFBBBFC0BCBEC0BDBFC2BE
C0C3C0C3C5C2C6C7C4CACAC6CDCDC9D0D0CBD1D3CEC3C6C3B6BCBAAAB2B19EA8A9939EA0
8794977C8A8E71818566777D
58686E546267505C604C565A48505344494B3F42443A3B3C36363544413F514C49605853
6F645D83746B99867BAF988AC6AA9AD7B9A8E1C6B5E4CBBBE4CCBDE3CCBEE3CDBFE3CDC0
E3CDC0E2CDC0E2CCBEE2CBBEE2CBBDE1CABDE0C9BCDECABDDDC9BDDAC8BCD7C6BBD4C5BA
D0C4BACDC2B9CAC0B8C8C0B8C6C0B8C4C0B8C3BFB9C2BFB9C2BFBAC1C0BBBFBFBABFC0BB
BFC0BCC1C2BDC3C4BFC6C6C0C9C8C2C9C8C3C8CAC5BBBFBCB0B5B4A5ACAC9AA3A48F9A9C
8591947A888C707F8466777C
58686D5361664F5B5F4A5458464D504146483B3F40363738302F2F3C39374A454259514C
695E577C6D65917F74A79083BEA393D1B3A2E0C2B1E5CBBAE6CDBDE7CEC0E7D0C2E7D1C3
E7D1C4E8D1C3E8D0C2E7CFC1E7CFC0E7CFC1E6CFC1E5CFC1E3CFC1E1CDBFDECBBFDACABE
D6C8BDD3C6BBCFC4BACCC3B9CAC1B9C7C1B9C5C0B9C3BFB9C2BFB9C0BEB8BEBCB7BDBCB7
BCBCB7BCBCB8BEBDB8BFBFBAC1C0BBC0BFBABABBB6B3B6B3A9AFAD9FA7A6959F9F8C9698
828E9178868A6F7E8365767B
57676D5260654E5A5E485256434B4E3E4346383B3D3133332A292934312F433D3A514A45
60565073655C88766B9E887BB39A8AC8AB9ADABBA9E5C8B6E8CEBDEAD0C0EBD2C2EBD3C4
ECD4C5EDD4C5EED5C5EED4C5EDD3C3EED4C4EDD4C4ECD4C4EBD3C5E8D2C4E5D0C2E0CDC0
DCCCBFD8C9BED4C7BCD1C5BBCDC3B9CAC1B8C6BFB7C3BEB6C0BCB6BEBBB4BCB9B3BBB8B3
BAB8B2B8B7B2B9B8B2BBB9B4BDBBB6C0BFBAB4B6B2ABAFACA3A8A79AA1A1919A9B889394
7F8B8E7684886D7D8165757B
57676D5260654C595D47515541494C3B414334383A2D2F302525252C2A2839343149413C
584E47695C547D6D62927E72A58E80B99F8FCFB1A0E0C1AEE8CBB9EBD1BFEDD4C3EFD6C5
F1D7C6F2D8C7F3D8C7F4D9C7F4D8C6F4D8C6F5D9C7F4D8C7F1D8C7EED7C7EBD4C5E6D1C3
E2CEC1DECCBFD9CABDD4C7BBD0C4B9CCC1B7C7BFB6C1BBB3BEB9B1BBB6AFB7B4ADB6B3AD
B6B3ACB5B2ACB4B2ACB5B2ADB4B3AEB7B7B3ADAEABA4A8A59CA2A0949C9B8C9596848F91
7C888B7482866C7B8064757A
56676C515F644B585C4650543F484B393F423236382A2C2D201F1F21201E2F2C293E3834
4E443F5D514A706259857367978275AB9283BEA291D3B5A2E1C2AFEBCDB9EED3C0F1D6C3
F4D9C6F7DBC8F8DCC9F9DCC9F9DBC8FBDBC8FCDDCAFBDDCBF9DBCAF5D9C8F1D7C6ECD5C5
E7D1C2E2CEC0DCCABDD6C7BBD0C3B7CBBFB4C6BCB2BFB8AFB9B3ABB5B0A9B2AEA7B0ACA6
AEABA5ADAAA4ADAAA4AEABA5ADAAA4A8A8A3A3A5A29DA19F969C9B8F9796889192818B8D
7986887280846B7A7E637479
56666C515F644B575C454F533E474A373E41303536282A2B1E1E1F1A1817252220352F2B
443C3754484165574E79685D89766A9B8577AB9383BFA492D0B2A0DDBFABE8CAB6EED1BD
F5D7C3F9DBC7FBDDC9FCDDC9FCDCC8FDDCC7FEDCC8FFDDC9FEDDCAFADBC9F6D8C6F0D5C4
ECD2C1E6CFC0DFCBBCD8C6B8D1C1B4C9BCB0C2B7ACBAB2A8B4ADA5AFAAA2ABA7A0A8A59E
A6A39DA4A29CA4A19CA5A29DA9A7A1A1A19D9B9D9A969A989096958A9192838D8E7D888A
768386707E8269797D627379
56666C505F644A575C444F533D474A363E402F3436272A2B1E1F201514141A1816292522
38312D473D38574B446B5B527B6A5F8B776B9B8577AB9384BBA191CAAE9CD6B9A6E0C2B0
E8CAB7EFD0BCF4D5C0F7D7C2F7D6C1F9D6C0FAD7C0FCD8C2FCD9C4FBD9C3F7D6C2F2D3C0
ECCFBDE6CBBADFC8B8D6C2B4CDBCAFC4B5AABCB0A5B3AAA1ADA69DA7A19AA29E989F9C96
9C9A949A98929997929B98939C9B979799959396948F93928A9090858D8D7F898A7A8587
7480836E7C8068777C627378
56666C505F644A575C444F533D474A363E412F3437262A2C1D1F2013131411100F1E1B19
2C28243B342F4940395A4E466C5D547C6B608C796C9C8779AB9485B8A090C2AA99CCB2A1
D6B9A7DEC0ADE5C5B1EACAB5EBCAB6EDCBB6F0CDB7F3CFB9F4D0BAF4D1BBF1CFBAECCCB8
E7C9B6E0C5B3D9C1B0D0BBACC7B5A7BCAEA2B4A89EACA299A49E959E999299958F95928D
92908A8F8E888E8D88908E898F8F8B8E908D8B8F8D888D8C848B8B8088897B8587768284
717E816C7A7E67767B617278
56666C505F644A575C444F543D474B363E422F3538272B2D1E21221415160C0B0B12100F
211E1B2F2A263E36314E443D5E51496E60567C6B618B796D998477A58F80B09989B9A191
C1A897CAAF9DCFB3A1D6B9A6DABCA9DCBEABDEBFABE1C1ADE3C2AEE2C2AEE0C1ADDCBFAC
D8BCAAD2B8A7CBB3A4C2AEA0BAA99DB0A398A89E94A098909A948C9490898F8C878B8984
88878285847F83827E84847F8687848689868489878288877F86877B8485778284737F82
6F7C7F6A787D65757A617177
56676D505F654A585D4450553E484C37404330373A282D301F23251618190C0C0D0A0A09
16141324201D322C28423A3450453F5D51496A5C537A6A5F88776B9381759E8A7DA79284
AF998AB8A090BCA494C2A998C6AC9BCAAF9CCCB09ECDB19FCFB2A0CFB2A0CDB1A0C9AF9E
C5AD9CC0A99ABAA597B2A194AB9D91A4988E9C938A948E868E8A8389868083827D807F7B
7E7D797B7A767B7B777E7F7C7F827F7F83827E84837C83837A8283778182747F81707C7F
6C7A7D68777B647479607177
56676D5160654B595E4551563F4A4E38424531393C2A3032212628181B1D0E0E10050405
0C0B0A19161425211E332D294139344F453F5A5048675B5275675D8070668A7A6F938276
9A897CA28F82A99487AE998AB29C8DB59F8FB7A190B9A291BAA392B9A392B8A292B39F90
AF9C8EAA998BA595899F92879A8F85958C838F888088837D827F797D7B777A7A76797975
767672757572777875787B79797D7B797F7E797F7F787F80767F80737D7F717C7E6D7A7D
6A787C67767A6373785F7076
57676D5161664C5A5F465358404C503A4448333C3F2C3336242A2C1B1F21121415050606
0101010B0A0919161426221F332D2A3F383349413B544B4460564E6A5F577669607F7168
86786E8D7E7394837998877C9B8A7E9F8E81A29083A39184A49385A39285A191849C8E82
9A8C8095897E90867C8B837A878079827D777D7A7478767174746F71716D6D6F6C6D6E6C
717370717370727573747876747A79757B7B747C7C737C7D727C7D707B7D6E7A7C6B787B
68767A6574796272775F7076
57686E5262674D5B6147555A424E523C474B363F432F373A282E31202527171A1C0D0F10
0203030000000A0A09181715252320302C29393431423C374C4540554E48605850696058
70665F766C647C706881756D867A708A7D738D80758E82779083789083798F8278897F75
837A717F786F7C776F78746E73716C706F6B6E6E6A6B6C68676966676865676865676865
696B686C6F6D6E72716F757470767670787870797A6F797A6E797B6D787B6B777B69767A
6675796473786171775F7076
57686E5363684E5D6249575C4451553F4A4E394347333C3F2C3437252B2E1D222415181A
0C0E0F0203030001010A0B0B1818162423212D2A2833302D3A3734423F3C4A4743544F4A
5B5650625C5667615B6C655F716962746D657770687A726A7B746B7D766D7C756E7A746D
76726B6F6C676968646767636465626365626264626163615F615F5D5F5D5F605D616361
656967686D6B6A706F6B72726C74746D75766D76786C77796B77796A7679697679677579
6574786372776071765E6F75
58696F54646A4F5F644B595E465458414E523C484C374145313A3D2A3235242A2D1C2224
15191B0D10110305060204040C0E0E1718172222212828262D2D2A3332303A3A3740403D
4545414B4A4751504D5755515C5955615E5864615C67645E68655F6A67626D6A666D6B67
6A69656667636465626163605D605E5A5E5B595C5B585B5A575A595659575B5D5B5F6261
626766656B6A676E6E6870716972736A73756A7476697577697578687478667478657378
6372776271776070765E6F75
58697055656B5160664D5C6149575C455257404C513B474B364044313A3D2B3336252C2F
1E2426171C1E0F13150608090508080F1112191B1B2022212526252829282D2F2D343634
393B393C3F3C3F42404446444A4B494E4F4D51534F555653575855595B575A5C5A5D5F5C
5A5D5B565B5A5359585157564F55554D53534D5352505453505452535655585C5C5C6262
606666626A6A646C6D656F70667072677274677275677376667377657377647377637277
6271766071765F70755D6F75
596A7056666C5263684F5F644C5A6048565B445156404D513C474C374246323C402D3639
27303321292B1B212314191B0B0F10080C0D0E1212191D1E212525242828262928272C2B
2B302F2F3434343A39363B3B373D3D3C4242424948484D4C4A504F4D52514E5454525757
5056564E55554B5354495152485050474F4F474E4F4D51504F5352535959575E5E5B6263
5E666760696B626C6E636E70646F72647073647174647275647276637276637276627176
6171766070765E6F755D6F75
596B7157686E54656B5161674F5E644C5A6049575C455358424F533E4A4F3A464A364145
313B3F2D363927303322292C1C2325161C1F1016181218191A2122202728252A2B272D2D
2930302A31322C353630393B343D3F3740423B44473F484A454D4F474F514850514A5152
4A5153485052454E4F434C4E434B4C454D4C444B4A4A5050505758545C5D5760625A6466
5D67695F696C606B6E616D70626E72626F73627074627075627175627175617176607076
6070755F70755E6F755D6E75
5A6C72586A7056676D54646A526268505F654D5C624B595F48565B455358424F543F4C50
3C484C384448343F43303A3E2C3539273034232C2F1C24281A23261C2528222B2E293233
2933342A34352D3739303B3E343F413641433844463A46493D484B3F4A4D434C4F444D50
454D4F464D4F444C4E444C4D4047474148494850514D5758525C5E5560625863665A6669
5C686B5D6A6E5F6C6F5F6D71606E72606F73616F746170746070756070756070755F7075
5F6F755E6F755D6F755C6E74
5A6C72596B7158696F57686E55666C54646A5262685060664F5E644D5C614B595F49575C
465459445156414F533E4B503C484D394549364246333E43313C412F3B402D383D2F393E
323C41323D41333E40333E423642453C474A3E4A4C404C4F424D51424E52445053475155
47525546505240494C444D504852554B56584E5A5D525E6155616557646859666A5A686C
5C6A6E5D6B705D6C715E6D725E6E735F6E735F6F745F6F745F6F745F6F755E6F755E6F75
5E6F755D6F755D6E755C6E74
5B6D735A6C735A6B72596B71586A7058696F57686E56676D55666C54656B536469526268
5161675060654E5E644D5D624C5B604A595F49585D47565C46555B46545A455459455459
46545A46545A465459455358425057435157435156445256455357455357465357465357
4754584D5A5E4F5C61505E6252606453626655646857666A58676C59696E5A6A6F5B6B70
5C6C715C6C725D6D725D6D735D6E735D6E745D6E745D6E745D6E745D6E745D6E745D6E74
5D6E745C6E745C6E745C6E74
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?ooo`ALKW@<G6ie4ee_M@AMKgH7GVmf45i`MPmOL7L8Gg1f15m`
M@AOKg@4H71f0emaM`AOLGP4Gg5g3embN0AOLGP4Gg9h15ibN0AOLWP4GW5h15mbN0=NLWP8Gg=i15mc
NPQOM7X3GgAk261eO0AQMWd4HWR0165fO@APMG`3H7Ak15mcNPQOLgT4GW9i15ibN0=NLGP4GW5g15e`
M`AML7H4GFmf15a_M@ALKWDEoooo000Doooo15a^M0aLKWDCGFme15e_MPMNKgH@GW1f3em`M`QOL7H4
Gg1e15m_M0APL7H3Gg5g15maN0AOLGL?Gg9h15maN0AOLWP4GW9h15mbN0ANLGP4Gg9h0eibN0QOLgT4
Gg=j25mdNP=OM7/8H7El165fO@ARN804HGIm161eO0=PM7/4Gg=j25mcN@ANLWT4GW9h0eiaN0ANLGL4
GG1g15e`MPAMKgH4G6me15a^MAGoool001Coool4G6id35a^MA=MKgD4GFmf1ei_MQ1NL7H?Gg1g25m`
MPAOL7D4Gfmd161`MP=OLGL4Gg5h15maM`mOLWP4Gg5h15mbN0ANLWP4Gg9h15iaN0AOLWP3GW9h25mc
N@AOLgX8GgAj0emdN`QPMG`4HGIm169hP0AQMWd4H7El0f1dN`AOLgX8Gg=i15ibN@ANLWP3GW5h15ia
M`AML7L4GG1f15e_MPALKgD4G6ie5Oooo`005?ooo`ALKW@4G6ie25e_M@AMKgH;GW1f15m`M`QOLGL3
H75g161aN0APLWP4HG9h165bN@AQLgT;HW=i16=cN@ASLgP4Hg9g16=aM@ASLgP3HgAj26=eN`aRMG/3
HWIl16=fO1ARMW`3HGMm169hOPARN7l4HgV016=jP@ASNh43Hg^216AlP`ATOH@4IGf516InQPAUOH@4
I7^30f=jP@ASNH04HWMo169gOPAQMWd4H7El0f1dN`AOLgX4Gg9i15ibN0ANLGL4GG1f15a_MAGoool0
01Coool4G6id15a^M@QMKgD4GFmf2ei`MPAOL7L8Gg5g0f1aM`APLGP4H79h165bN0AQLWT4HG=i2f9c
N@ASLgT4Hg=h16=bM`ASLGD4Hg=h0f=dNPQSMG/<HWEk0f9fO0ASMW`DHWIl0f5gO@ARN7h4HWQo16=i
P0ASNX44Hg^10f=kPPATO8<4I7f416EmQ@AVOXH4IGf416AkP`=SNX44HgV0169gO`ARMgh4HGIm161e
O0=PM7/4Gg=j15mbN@ANLWP4GW5g15e`MPALKgDEoooo000Doooo15a^M0ALKWD8GFme15e_MP]NL7H4
Gg1g25maM`=PLGL4H75h161bN0AQLWP4HG9i165cN@]RLgT4Hg=i16=cN0ASLWL4Hg5e16=cN0=SM7X8
HgEk369eN`=RMW`4HgIl569fO0=QMgd4HWQn169hO`ASNH04HgZ116=kP@=SNh84I7b316AmQ0AUOHD4
IWj616EmQ0ATNh<3HgZ116=iP0ARMgl4HWMn165fO@APMG`3H7Ak15mcNPAOLWT4GW9h15iaM`AML7H4
G6me5Oooo`005?ooo`ALKW@4G6ie25e_M@AMKgH;GW1f15m`M`QOLGL3H75g161aN0APLWP4HG9h165b
N@AQLgT;HW=i16=cN@ASLgP4Hg9g16=aM@ASLgP3HgAj26=eN`aRMG/3HWIl16=fO1ARMW`3HGMm169h
OPARN7l4HgV016=jP@ASNh43Hg^216AlP`ATOH@4IGf516InQPAUOH@4I7^30f=jP@ASNH04HWMo169g
OPAQMWd4H7El0f1dN`AOLgX4Gg9i15ibN0ANLGL4GG1f15a_MAGoool001Coool4G6id15e^M@AMKgD8
GW1f0em`MPAOLGL4H75g161bN0AQLWP4HG=i1f9cN@ASLgX4HgAj16AdNPATMG/4IGEk0fEfO0QVMW`4
IgIk16MeNPAWM7P4IgIl0fMgO@AWN7h8IWQn16EiO`AUN7h7IGQm16AhOPATNGh8HgUn16=iO`=SNX04
I7b216EnQ0AVOhH4Ih2716R1R0=XPXT4J8>;16V4S0AYQHh4JHB<16V3R`AXPHX3Ih2816InQPAUOHD4
IGb316AkPPASNH03HWQo165fO@APMG`4Gg=j15ibN@ANLGL4GFmf5Oooo`005?ooo`ALKW@4GFie15e_
M@QNL7H3Gg1f15maM`APLGL4H79h165bN0AQLgT7HW=i16=cNPASM7X4I7Aj16AeN`AUMG/3IGIl26If
O0AWMW/4IgEj16MdN0AWMW`3IgMm16MhOPQVN7h4IGUo16EhOPMUN7d4I7Qn16AiOPQSNGh4HgUo0f=j
P0ATO884IGj416IoQPAWP8L4J8680fR2R@AXPh/4JHB<16V5SPAYQ8`4JH>;16R1RP=WP8P4IWj616Em
Q@AUO8<4I7^216=iP0=RN7l4HGIm161eO0AOLgX4GW9i15iaM`AMKgHEoooo000Doooo15a^M0AMKWD4
GFme25i`MP=OL7H4Gg5g161aM`APLWP4HG9h165cN@MRLgT4Hg=j16=dNPATM7X4I7Ek16EeN`=UMW`8
IWIl16MfN`AWMGX4IgAh16MfO0=WMgd4IgQn26IhOPAUNGl4IGQn1fEhO@ATN7h4I7Un26=iOPASNGl3
HgZ016AlPPAUOX@4IWn616N0Q`AXPHP3J8:916R3R`AYQ8`4JHF>16V4S0AYPh/4J86:0fN0R0AVOXH4
IGf516ElP`ATNh84HgV00f9hO`AQMWd4H7El15mcNPANLWT4GW5g15e_MQGoool001Coool4G6id15e^
M@AMKgD8GW1f0em`MPAOLGL4H75g161bN0AQLWP4HG=i1f9cN@ASLgX4HgAj16AdNPATMG/4IGEk0fEf
O0QVMW`4IgIk16MeNPAWM7P4IgIl0fMgO@AWN7h8IWQn16EiO`AUN7h7IGQm16AhOPATNGh8HgUn16=i
O`=SNX04I7b216EnQ0AVOhH4Ih2716R1R0=XPXT4J8>;16V4S0AYQHh4JHB<16V3R`AXPHX3Ih2816In
QPAUOHD4IGb316AkPPASNH03HWQo165fO@APMG`4Gg=j15ibN@ANLGL4GFmf5Oooo`005?ooo`ALKWD4
GFme15i_M@ANL7H4Gg1g0f1aM`APLGP4HG9h169bN0ARLgT4Hg=j0f=dNPATMG/4IGEk16IfO0AVMWd4
IgMm16QhOP=YN7h4JGUo16YiO`A[NGh4JgUm16]hO0A[NWl3Jg^016YkP@AZO884JGb216QkP@AWNX03
IGUn26EhO@ATNGh4I7Z016AlP@ATOH<3IGj416J0QPAWPXP4JHB;16Z5S0A[Qhh3JhR@16b:TPA]S9D4
KhnH16f<U@A/RY<4K8RA0f^6SPAZQ8`4JH::16N0R0AVOXH4IGf40fAkPPASNH04HWMn165eO0AOLgX4
GW9h15e`MQGoool001Coool4G6ie15e_M@ANKgD4GW1f15m`M`=PLGL4H75h165bN0ARLWP4HW=i16=c
NP=SM7X4I7Ek16EeN`AVMW`4IWIm16MgO@AXN7h3JGQn16UiO`AZNGl4JgUn16]iO@A[N7`4JgYo0f]k
P0AZNh44JWb216UlPPAXNh44IgZ00fEiOPQUN7d4I7Un16AjP0ATO844I7f30fEnQ0AVP8H4Ih:816V4
R`AZQH`4JhN>0f^8T0A/RY84KHbE16n?V0A]S9D4K8ZC16b8T@=[QXh4JXB<16V2RPAWP8P4IWj616Em
Q0=TNh84HgV0169gOPAQMG`4Gg=j15ibN0AML7HEoooo000Doooo15a^M@AMKgD4GVme15i`MPAOL7L3
H75g161aN0AQLWP4HW9h169cN@ASLgX3HgAj16AeN`AUMG/4IWIl16IfO@AWMgd4J7Qn0fUhOPAYNGl4
JWUo16]iOPA[NGd4JgQl16]jO`=[Nh04JW^116YlPPAYO884J7^116MjP0=UNGh8IGQm16AiOPATNX04
I7b116AmP`=UOX@4IX2616N2R0AYQ8/4JXF<16^7SP=[R904K8ZB16f<U@A_SiP4KHbE16b:T`A/R943
JhJ>16Z4S0AYPXX4Ih2816InQPAUOH@3I7^216=iP0ARMgh4HGEl15mcNPANLWP4GG1f5Oooo`005?oo
o`ALKWD4GFme15i_M@ANL7H4Gg1g0f1aM`APLGP4HG9h169bN0ARLgT4Hg=j0f=dNPATMG/4IGEk16If
O0AVMWd4IgMm16QhOP=YN7h4JGUo16YiO`A[NGh4JgUm16]hO0A[NWl3Jg^016YkP@AZO884JGb216Qk
P@AWNX03IGUn26EhO@ATNGh4I7Z016AlP@ATOH<3IGj416J0QPAWPXP4JHB;16Z5S0A[Qhh3JhR@16b:
TPA]S9D4KhnH16f<U@A/RY<4K8RA0f^6SPAZQ8`4JH::16N0R0AVOXH4IGf40fAkPPASNH04HWMn165e
O0AOLgX4GW9h15e`MQGoool001Coool4GFie15e_M@ANKgD4Gg1f161aM`MQLWP4HW=i16=cNPATM7X4
IGEk0fEfO0AVMWd4IgMm16QhOPAYNGl4JWZ016]jP0=/Nh44KGb216imPPQ_OH84Kgb016mmP`=_OXD4
KWn526eoQ@A/Oh@4Jgj30fYmPPAYO844J7^016MkP0AWO884Igj416MoQP=WPHP4J8>:16V7S@A[RI04
KHZB16j=U@=_T9P4L96J17:CW@AcUJ04LY>M176@VPA_SYL3KXbE16f9TPA/Qi04JXF=16V3R`AXP8T3
IWj616ElQ0ASNX44HWMo161eO0AOLgT4GG1g5Oooo`005?ooo`AMKWD4GFme15i_M@AOL7H4H75g1f5b
N0ARLgT4Hg=j16AdNPAUMG/3IGIl16IfO@AWMgd4J7Qn16UiO`AZNX04JgZ00fakP@A]O884KWf226mm
PPA_O804Kgf30fmnQ@A^OhD8KGn516aoQ0A[OX<3JWf216UlP@AXNh04Ig^016MlPPAWOX@4Ign60fN1
R0AXPhX4JHN=16^9T0A]RY84KXfE0fn@V0A`TIX4LY>M17>EX0AbTid4LI2J16n>U`=^S9D4KHVB16b7
T0AZQHd4JH>;16R0R@=VOXH4IGb416=jP@ARMgl4H7El15mcN@AML7LEoooo000Doooo15e^M@AMKgD4
GVme15m`MPAPLGL7HG9h169cN@ASLgX4I7Aj16EeN`=UMW`4IWIm16MgO@AXN7h4JGUo16YjP0A[NX03
K7^116elPPA^OH88Kgf216mlP0A_OH<3Kgj516ioQ@Q]OhD4K7n416]nP`=ZOH84JGb116QkP0AWNh04
Igb216MnQ0AWOhH3Ih6816R3RPAYQhd4JhV@16f:TPA^SID3Ki2H172AVPAbTid4LiFP17:CW@AaT9X4
KhjG0fj<U@A]RI84K8N@16Z5S@AYPh/4J8290fInQPAUO8@4HgZ1169gO`APMG`4Gg=i15e`MaGoool0
01Coool4GFie15e_M@ANKgD4Gg1f161aM`MQLWP4HW=i16=cNPATM7X4IGEk0fEfO0AVMWd4IgMm16Qh
OPAYNGl4JWZ016]jP0=/Nh44KGb216imPPQ_OH84Kgb016mmP`=_OXD4KWn526eoQ@A/Oh@4Jgj30fYm
PPAYO844J7^016MkP0AWO884Igj416MoQP=WPHP4J8>:16V7S@A[RI04KHZB16j=U@=_T9P4L96J17:C
W@AcUJ04LY>M176@VPA_SYL3KXbE16f9TPA/Qi04JXF=16V3R`AXP8T3IWj616ElQ0ASNX44HWMo161e
O0AOLgT4GG1g5Oooo`005?ooo`AMKWD4GVme15m`MPAPLGL4HG9h0f5bN@ARLgT4HgAj16AeN`AUMG`4
IWIl0fMgO@AXN7h4JGUo16YjP0A[Nh44K7b216imP`=_OX@4L7n517:1QPAcPXL4M8:717B1QPAdPXL3
Lh:817:3R@AaPhT4L8>91722R0A_PXP3KX:716f1QPA/P8D4Jgn516^0QPA[PXT4JhB;0fb6S@A/R904
KH^C16n?U`A`TIT4LY>L0gBFW`AeVJ84MYZT17NKYPAfVJ@4MINQ17>DWP=bTY`4LHnI16n<UPA]RI<4
K8N@16Z4S@=XPHX4Ign716ElQ0ASNH44HGIn15mdNPANLGLEoooo000Doooo15e^M@ANKgD4Gg1f161a
M`AQLWP3HG9i169cN@ASM7X4I7Ek16EeO0AVMW`3IgMm16QhOPAYNGl4JWZ016]kP@A/O884KWf30fmn
Q0A`OhD4LX6617>2Q`AdPXL4M86617B2Q`=cPXP4LX>91763R@A`PhT4L8:816n2R0=^PXL4KH6616b0
Q@A[OhD4Jh2616^2R@A[Q8/3K8J=16b8T0A]Ri<4KhnG172AV@AbTi`3M9JO17FIXPAfVZ@4Mi^V17JI
Y0AeUj44LiBN0g:BW0AaSiT4KhbF16f9T`A/Qi04JXB=0fR1RPAWOhL4IGb416=iP@AQMWh4GgAj15ia
MaGoool001Coool4GFie15i_M@AOL7H4H75g165bN0=QLWT4HW=i16=dNPATMG/4IGEl16IfO0=WMgd4
J7Qn16UiO`AZNX04Jg^116alPPA^OH<3Kgj4171oQ@AbPHH4Lh:717B2Q`AdPHH4M8:70g>2R0AbPhT4
LH>91723R@A`PXP4Kh:80fj2Q`A]PHH4K82516]oQ@A[P8H4Jh:916^4R`=/QXd4K8R@16f;T`A_SiL4
L96I17:CW0=dUYl4MIVR17JJY0AgVjH4MYVT17FGX@AcU9h3LY:L176?V@A_S9H4KHVC16b7T0AZQ8d3
J86:16MoQ`AUO8@4HgV1165fOPAOM7X4GW5g5Oooo`005?ooo`AMKgD4GW1f15m`M`APLGP4HG9h0f9c
N@ATM7X4IGEk16IfO0AWMgd4J7Qn0fUiO`AZNX04Jg^116elPPA^OH<4Kgj41760Q@=bPHL4M8>817J4
RPAhQh`4NXV?17Z9SPAhQh`3MhJ<17J6S0AeQXd4M8J<17B7S0AcQh`7LXJ<1766S0A`Qh`4L8N=1728
S`A`RY43L8bC176>UPAbTIT4LiBM17FHXPAgVj@3N9fW17ZPZ`AlXjh4Nj:]17ZPZ`AiWJT4Mi^V0gJH
XPAdU9l4LY6K176>V0A_Ri@4KHR@0f^4S@AYPHT4Igj616AkP`ARN7l4H7Ak15iaN1Goool001Coool4
GFme15i`MPAOL7L4H75h165bN0=RLgT4I7Aj16EeN`AVMW`4IgMm16QhOP=YNGl4JWZ016]kP@A]O884
KWf316mnQ0AaP8D3LX6717B3R0AfQ8X4N8N<17Z9S`AjRHh4N8N<0gN6S0AfQX`4MHJ=17B6S0AdQh`4
LhN<1g:6S0AaQX`4L8N<1727S@A`R8l4L8ZA0g2<T`AaSYH4LY6I17>DW@AeV:84Mi^T0gRMY`AjX:/4
O:>^17^R[@AjX:/4NIfY17NKYP=fV:84M9BO17:AV`AaSYP4Kh^D16f8T0=[Q8d4JH6916MnQPATNh<4
HWQo161dN`ANLGPEoooo000Doooo15e_M@ANL7H4Gg1g161aN0AQLWP3HW=i16AdNPAUMG/4IWIl16Mg
O@AXN7h3JGUo16YjP0A[Nh44KGb216imP`A_OX@4LH250g:1Q`AdPhP4MXB:17R7S0AjRHl4NXV>17R7
S0=gQX`4MXJ<17F6S@AdQX`4M8N<17>7S0MbQX`4LHJ<1727S0A`Qhd4L8R?172:T@=`S9<4LHjF17:A
V@AcU9d4MIRR17NKY0=hWJL4NZ2[17bS[PAkXZd4NZ2[17VMZ@AgVjH3MYRR17BDW`AbTI/4LHjH16n;
U0A]R903JhB=16V1R@AWOXH4I7^3169hO`APM7/4GW5h5Oooo`005?ooo`AMKgD4GW1f15m`M`APLGP4
HG9h0f9cN@ATM7X4IGEk16IfO0AWMgd4J7Qn0fUiO`AZNX04Jg^116elPPA^OH<4Kgj41760Q@=bPHL4
M8>817J4RPAhQh`4NXV?17Z9SPAhQh`3MhJ<17J6S0AeQXd4M8J<17B7S0AcQh`7LXJ<1766S0A`Qh`4
L8N=1728S`A`RY43L8bC176>UPAbTIT4LiBM17FHXPAgVj@3N9fW17ZPZ`AlXjh4Nj:]17ZPZ`AiWJT4
Mi^V0gJHXPAdU9l4LY6K176>V0A_Ri@4KHR@0f^4S@AYPHT4Igj616AkP`ARN7l4H7Ak15iaN1Goool0
01Coool4GFme15i`MPAPLGL4HG9h169cN@=SM7X4IGEk16IfO0AWMgd4J7Qn16YiO`=[NX04K7^116im
P`A_OX@4L7n517:0QPAcPXP3MH>:17N5R`AiR8h4OHbB18:@U@AnS984O8^@0gZ:S`AiRXl4NHZ@17R;
T@AgRi04Mh^A1gJ<TPAfSI84MHjD17F?U@AfT9H4MY:H0gJDV`AfUId4N9RQ17VKY0AjWZL4Nj6/0gfT
[`AoYk<4P:^h182Z]PAoYk@4OJBa17bQ[@=jWZT4N9ZU17JFX@AdTid4LXnI16n;U@=]R944JhB<16R0
R0AVO8@4HgV0165eO0ANLWPEoooo000Doooo15e_M@ANL7H4H75g165bN0ARLgT3HgAj16EeN`AVMW`4
IgMm16QhOPAZNGl3JgZ016akP@A^OH<4Kgj4171oQ@AbP8H4Lh:80gF3RPAgQH/4NHR>17f<TPB2T9D4
OXbB17b;T0=jRXl4NHZ?17V:T0AhRi44Mh^@17N;T@MfS984MXfB17F>U0AeSiD4MY2F17JBV0=fU9/4
MYFM17RHX@AiVj@4NYjW17^Q[0=mY:l4OjNc182[^0B0Z[H4OjNd17fT/@AlXJd3NYjY17RJY@AfUZ44
M9>M17:?V@A_RiD3KHRA16^4S0AXP8P4IWb416=iP0AQMG`4GW9h5Oooo`005?ooo`AMKgD4GW1f161a
M`AQLWP4HW=i0f=dNPAUMG/4IWIl16MgO@AXN7h4JWUo0f]jP0A/Nh44KWf316mnQ0A`OhD4LX2617>2
R0=ePhX4MhF;17V8SPAmS984PY2E17j<TPAlRi03NXZ?17V:S`AiRY04N8^A17N;T0AgRi47MXbB17J=
TPAeSY@4MHnE17J@UPAfTYP3MYBK17JEW@AhV:44NI^T17ZNY`AkXJ`3OJB_17nW/`B0ZkP4P:Zf17nW
]0AmY;44O:6]0gZNZ@AhVZD4MYJQ17BCW@AbSiT4Kh^E0ff8T@A[Q8`4J82816IlQ0ASNH04HGEl15ib
N1Goool001Coool4GFme15i`MPAPLGL4HG9h169cN@=SM7X4IGEk16IfO0AWMgd4J7Qn16YiO`=[NX04
K7^116imP`A_OX@4L7n517:0QPAcPXP3MH>:17N5R`AiR8h4OHbB18:@U@AnS984O8^@0gZ:S`AiRXl4
NHZ@17R;T@AgRi04Mh^A1gJ<TPAfSI84MHjD17F?U@AfT9H4MY:H0gJDV`AfUId4N9RQ17VKY0AjWZL4
Nj6/0gfT[`AoYk<4P:^h182Z]PAoYk@4OJBa17bQ[@=jWZT4N9ZU17JFX@AdTid4LXnI16n;U@=]R944
JhB<16R0R0AVO8@4HgV0165eO0ANLWPEoooo000Doooo15e_M@AOL7H4H75h169cN@ASM7X3I7Ek16If
O0AWMgd4JGQn16YiO`A[Nh03KGb216imP`A`OX@4LH2617>1Q`AdPhT4MXB:0gN6S0AiR8h4NhZ@17f<
T@B5TiL4P8jD17j=T`MmSI<4O8jD17b?U@AkSiD4NhnD0gZ@U@AjTIL4NY>I17ZFV`AkV9d4NiVO17^I
X0=lVZ84O9bT17fNY`AmXJX4OjB^182X/`>2[;P4Q;2m18Je``B5//04Pjnm18:/^@B0Z;@3OZB`17bP
Z`AiW:L4MiRR17BCW@AbSiT3Kh^D16f7S`AZPX/4Igj616AjPPAQMWd4Gg9i5Oooo`005?ooo`AMKgD4
Gg1f161aN0ARLgT4HgAj0fAeN`AVMW`4IgMm16UhOPAZNGl4Jg^00felPPA^OH<4L7j41760QPAcPHL4
M8>917J4RP=gQX`4NHR>17^:T0AmS944QI>G182>U0AnSI<7OHfC17b>U0AlSiD4NhnE17^?U0=jT9D4
NY6G17ZCV@AjUY/4NiRM17^IW`AkVJ03O9ZR17bLY0AmWZL4OJ6Z17nT[PB0Z;<3PZbh18B`_@B6]L<4
QK;018>__@B2[;T4P:Rd0gjT/0AlX:/4NIbW17NHXPAdTid4LXnI0fn;U0A]Qhl4JX:;16MnQPATNX84
HGIm15mbNAGoool001Coool4GFme15m`MPAPLGP4HW=i16=dNP=TMG/4IWIl16MgO@AYN7h4JWUo16]k
P0=]O884KWf3171nQ0AaP8H4Lh6717B3R@AfQ8X3MhJ<17V8SPAkRY04OHbA18FCU`B0SY@4OXfC1gf=
T`AlSY@4O8nE17^?U@AkSi@3NY2E17ZAU`AjTiT4NYJK17^HW@AkVIl4NiVP0gbJXPAlW:@4OIjW17fQ
ZPAoY:h4P:Rc0h:/^0B4/;d4Q[G318Fb`0B3[kd4PZbi182X]0=nY;04O:2[17VLY`AgV:84M9>M17:?
V@=_Ri@4KHN?16Z2R`AWOXH4I7Z2165fO@AOLWTEoooo000Doooo15e_M@AOL7H4H75h169cN@ASM7X3
I7Ek16IfO0AWMgd4JGQn16YiO`A[Nh03KGb216imP`A`OX@4LH2617>1Q`AdPhT4MXB:0gN6S0AiR8h4
NhZ@17f<T@B5TiL4P8jD17j=T`MmSI<4O8jD17b?U@AkSiD4NhnD0gZ@U@AjTIL4NY>I17ZFV`AkV9d4
NiVO17^IX0=lVZ84O9bT17fNY`AmXJX4OjB^182X/`>2[;P4Q;2m18Je``B5//04Pjnm18:/^@B0Z;@3
OZB`17bPZ`AiW:L4MiRR17BCW@AbSiT3Kh^D16f7S`AZPX/4Igj616AjPPAQMWd4Gg9i5Oooo`005?oo
o`AMKgD4Gg1f165aM`ARLgT4I7Ek0fEfO0AWMgd4J7Qn16YiO`A/Nh04KGb20fmmP`A`Oh@4LX2617B2
Q`AePhT4MhF;17R6S0=jR8h4NhZ@17b:TPAmRi84OhbC186?U@B1T9H3P92F182AU`B0TIP4Oi:H27nC
V@=nU9T4OYFK17nGW@AnVYl4OifQ182OY0B0XJH3PJ:Y186SZ`B3YJh4PjRa18B[]0B4[[T3Q[:n18Rf
a0B;_L`4R[c;18RhaPB6/l44Q:nl0h:Z]`B0Y[84OJ6]17ZLY`AgV:84MI>M0g:>V0A_RI84JhF=16R0
R0AUO8<4HWMn15mbNAGoool001Coool4GFme15m`MPAQLGL4HW=i16AeN`=UMW`4IgMm16QhOPAZNGl4
K7^016elPP=_OH<4L7n417:0QPAdPXL4MH>917N5R`AhQX`3NXR>17^:T0AlRY84OH^B17n<T`B1SiD4
PI2F0h2@UPB0TIL4P96H17nBV0QoTiT3OYBI17jEV`AoUid4OYZO17nMX@B0Wj@4P:6V0h6RZ@B1Xj/4
PjF^18>X/@B4Zk@4Q:ji0hJb_PB8]/@4Rkg<18Zlb`B8^<H4Q[?118B__0>2Z[L4P:Jb17fQ[@AjW:L4
MiRR17FCW@=bSYP4KhVB16^5S@AXP8P4IGb3169gOPAOLWTEoooo000Doooo15e_M@AOL7H4HG5g169c
N@ATMG/3IGIl16MgO@AXN7h4JWUo16akP0A]O883Kgf3171oQ0AbP8H4M8:717F3R@AgQH/4N8J<0gZ8
SPAkRY04O8ZB17f;TPAoS9<4PHnE186@UP>0T9H4P96G182AV0AoTYP8Oi>I0gjDV@AnUI/4OiNM17jJ
W`AoWJ44P9nT182QYP>1XZT4PJ>[18>U[PB3Z;44Q:^d18B^^@>6/[h4R;K418^mc0B:_</4R;S618Jc
`@B4[k`3PZZg182V/PAmXJd4NYbW17NHXPAeTid3LXjH16n9TPA[QHd4J82816ElP`ARMgh4Gg9i5Ooo
o`005?ooo`AMKgD4Gg1f165aM`ARLgT4I7Ek0fEfO0AWMgd4J7Qn16YiO`A/Nh04KGb20fmmP`A`Oh@4
LX2617B2Q`AePhT4MhF;17R6S0=jR8h4NhZ@17b:TPAmRi84OhbC186?U@B1T9H3P92F182AU`B0TIP4
Oi:H27nCV@=nU9T4OYFK17nGW@AnVYl4OifQ182OY0B0XJH3PJ:Y186SZ`B3YJh4PjRa18B[]0B4[[T3
Q[:n18Rfa0B;_L`4R[c;18RhaPB6/l44Q:nl0h:Z]`B0Y[84OJ6]17ZLY`AgV:84MI>M0g:>V0A_RI84
JhF=16R0R0AUO8<4HWMn15mbNAGoool001Coool4GVme15m`M`AQLWP4Hg=i16EeN`=VMW`4J7Qm16Yi
O`A[NX04KGb116mmP`=aOh@4LX2617B2Q`AfPhT4N8F;17V7S@AkR8l3OHZ@17n=U0AnS984OHZ@182=
T`B2T9H4Pi6H0h>CV@B3U9/4PiFL28>FW@B3Uid3PYNM186IWPB2W:44PYnS18:RYPB3YJT4Q:N/0hFX
[@B6Z[04Qj^c18R^]`B9/;X4R[>n0hZg``B=_<X4Sl;B1935e@B>`=04Rk_:18Vfa0>6/Kh4Q:bh186V
/PAnXJd4NibW17NGX@=dTI/4LHbE16f7T0AZPX/4IWf516=hO`AOLgXEoooo000Doooo15i_M@AOL7L4
HG9h16=cN@AUMG/3IWIl16QhO@AZNGl4JgZ016elP@A_OH<3LGn417:0QPAdPXL4MX>917R5R`AiQhd4
NhR?0gf:T0AoSI@4OXbB17f:T0B0SI<4PY2F18>AV0>3TiT4PiBK18>EW0R3UYd4PiNM0h:GW@B1VIh4
PYbQ18:OX`B2XZH4PjFY18BW[0>5Z:d4QZZ`18N[/`B8[[L4RK2j18Zc_P>:]l<4SKc:18o2dPB@aMD4
S/3@18^kbPB9]/@3Q[6n18B/^0B1Y[84OZ6]17^LY`AgUj43M96K176<U@A]Qi04JX:;16ImQ@ASN7l4
Gg=j5Oooo`005?ooo`ANKgD4Gg1g165bN0ASLgT4IGEk0fIfO0AXN7d4JWUo16]jP0A]O844Kgf30g5o
Q0AbP8H4M8:717J3R@AhQH/4NHN=17^8S`=mRY04OhfD17j<TPAmRY04P8fC18:@UPB3TIP3Pi>I18>D
V`B3UI`8PiJM18>GW@>2Uid4PIVN18:LX@B2Wj<4PZ:V18>UZ@B4Yj`3QJR]18JZ/0B7Zk<4R:jg18V`
^PB:/kh3R[O318flbPB?`]84T<GE18k0d0B;^lX4RKK40hJa_PB4[;P4PJJb17jQ[@AkW:L4MiNQ0gBA
V`AaS9D4KHN@16Z2R`AVOHD4HgQo15mcNQGoool001Coool4GVme15m`M`AQLWP4Hg=i16EeN`=VMW`4
J7Qm16YiO`A[NX04KGb116mmP`=aOh@4LX2617B2Q`AfPhT4N8F;17V7S@AkR8l3OHZ@17n=U0AnS984
OHZ@182=T`B2T9H4Pi6H0h>CV@B3U9/4PiFL28>FW@B3Uid3PYNM186IWPB2W:44PYnS18:RYPB3YJT4
Q:N/0hFX[@B6Z[04Qj^c18R^]`B9/;X4R[>n0hZg``B=_<X4Sl;B1935e@B>`=04Rk_:18Vfa0>6/Kh4
Q:bh186V/PAnXJd4NibW17NGX@=dTI/4LHbE16f7T0AZPX/4IWf516=hO`AOLgXEoooo000Doooo15i_
MPAPLGL4HW9h16=dNPAUMG/3IgMm16UhOPA[NX04KG^116mmP`AaOX@3LX2617B2Q`AfPhT4N8F;17Z7
S@AlRHl4OX^A0h2<T`AlRHl4P8bB186>U0B3SiD4Q96H18FCVP>6UI`4QiNN18NIX0R7VZ44QiZP0hJJ
X0B5V9h4QIVO18FKXPB6WZD4QZ:W18RX[@>9[;44Rjjd18f`]`B=/[/4S[Fo18jg``>>^lL4T;o=1974
e0BDb]/4TlWK1933d`B>_L`3RkO518Rb_`B5[;P4PJJb17jPZ`AjVZD3MYFO17>?V0A_RI84JhB<16Mn
QPASNH04H7=j5Oooo`005?ooo`ANKgH4H75g169bN0ASM7X4IGEk0fMgO@AYN7h4JgZ016ekP@A_OH<4
LGj40g:0QPAdPXL4MX>917R5R`AjQhd4O8V?17j;T@>0S9<4O8V?182<TPB1SY@4PhnE18BAV0B5TiX3
QYFL18NGWPB7VJ08QiZQ18NJX0>6VZ04QIRN18FIW`B5Vj84QYjU18JRY`B8Z:d3RJba18^^]0B=/;L4
SK:k18je_`B>]l<3S[_7192oc@BAa=@4U<[K19?9f`B@`m<4S[g<0h^ga@B8/[l4QJbh186V/PAnX:/4
NYZU0gJEW`AcSiP4KhVB16^4S0AWOXH4HgV0161cNQGoool001Coool4GVmf161aM`ARLWP4HgAj16Ee
N`=WMgd4JGQn16]jP0A]Nh44Kgf3175nQ0=bP8H4M8:717J3R@AhQH/4NXN=17b9S`AnRi43P8bC17b9
S`B0S984PHjD18>?U@B4TIP4QI>J0hJEW0B7Uih4QiVP28NJX@B7VZ03QYZP18FHWPB5VIl4QI^R18JN
Y@B6XZL4R:R]0hV//@B;[[@4SK2g18fb^`B>]Kl4S[O30hjka`B@_ld4TLCD19C:f`BCbM/4T<?C18jm
c0>;]lD4R;:o18F/^0B1Y[84OZ2[17ZJY@=fUIl4LhnH16n9TPA[Q8`4Igj616=iP0APLgXEoooo000D
oooo15i_MPAPLGL4HW9i16AdNPAVMW`3J7Qm16YiO`A/Nh04KWb2171nQ0AbP8D3M86717J3R@AhQHX4
NXN<17f9SPAoRi44PHfC0hB?U@B:UI/4QY6H18FAU`B6TYP4Qi>I18NDV`>9UYh4RYZQ18^LX`B;WJ@4
S9fT18^LX`>:Vj84R9NN28NEW0B7Uih4R9^S18^TZ`>=Zk44Sk2g196d^`BB][l4TkW319>ka`>C_LX4
Tl7?19C6e@BFb]/4UlkO19G:f`BCa=@3T;k<18bha@B9/Kh4QJ^g186T/0AmWZT3NIRR17FBV`AaS9@4
K8J>16R0Q`ATNX44H7Ak5Oooo`005?ooo`ANKgH4H75g169bN@ATM7X4IWIl0fQhO@AZNGl4K7^016il
PPA`OX@4LX250gB1Q`AfPhT4N8F:17Z7S0AmRHh4Oh^A186=T`>4SiD4RYFK18JAV0B5TIL4QY:H18NC
V@B7U9/3RIJN18ZJX@B;W:<4RifT18bMY0B;W:<3RY^R18RGWPR7UI`4QiNN18RKX`B;Y:/3SJ^a18n`
]`BA];/4T[Jo19>i``BC^lL3Tkg:19?1c`BDa]D4U/[K19O>g`BEb]/4TlCD0i2nc0B<^<D4RK6n18F[
]`B1Y;04OIjY0gVHXPAeTY/4LHbD16b6SPAXP8L4I7Z1161dNaGoool001Coool4GVmf161aM`ARLWT4
I7Aj16IfO0=XN7d4JWUo16akP0A^O884L7j417:0Q@=dPHL4MX>917R5RPAjQh`4OHV>17n;T@B1SI<3
Q8nE18ZEV`B6TIP4QI6G18JBV0B7TiT4QiBK0hVFWPB:VZ44RibS18^MY0B<WJ@4RibS0hZKXPB8Uih8
QiFL18NGWPB8Vj<4RjB[0hf[/@B?/;L4TKBk19:f_`BC^L<4Tk_70i>mbPBC`Ll4U<KE19K:f`BGc]l4
UL[K19?4e0>@_/`4S;S518Va_PB5ZkL4PJB`17fNZ@=iV:84MI:K176<U0A/QXh4J82716AjP@APM7/E
oooo000Doooo15i_MPAPLGL4HW9i16AdNPAVMW`3J7Qm16YiO`A/Nh04KWb2171nQ0AbP8D3M86717J3
R@AhQHX4NXN<17f9SPAoRi44PHfC0hB?U@B:UI/4QY6H18FAU`B6TYP4Qi>I18NDV`>9UYh4RYZQ18^L
X`B;WJ@4S9fT18^LX`>:Vj84R9NN28NEW0B7Uih4R9^S18^TZ`>=Zk44Sk2g196d^`BB][l4TkW319>k
a`>C_LX4Tl7?19C6e@BFb]/4UlkO19G:f`BCa=@3T;k<18bha@B9/Kh4QJ^g186T/0AmWZT3NIRR17FB
V`AaS9@4K8J>16R0Q`ATNX44H7Ak5Oooo`005?ooo`ANKgH4H75g16=cN@AUMG/4IgMl0fUiOPA[NX04
KWb1171mP`AbOh@4M8660gJ3R0AhQ8X4NXJ<17f8SPAoRi04PHfB18B@U@>4SiD8RI>H18RCV0B9U9T4
RI>I18ZEV`>;V9h4SI^S392PYPBBWJ@3RiFL18RCV@B5SYD4QI2G18NGWPB9Uil4S9bT0i2T[0BE/;L4
U[Nn19Nj`PBG_<H4Ukk90iK0c0BF`]04UlOF19W;g0RKdN<4V<_L0iG5e0BA_/`4SKO418V`_0B4ZK@4
P::]0g^KY@AgU9h4LXjG16j7T0AYPHT4IGZ2161dNaGoool001Coool4GVmf161aM`ASLgT4IGEk16Mg
O0=YNGh4JgZ016ilP@A`OH<4LWn417B1QP=fPhP4N8B:17Z6S0AmR8h4Oh^@186=TPB4T9D3Q8nE28VC
V0B8TiP4RIBI18VCV@B:UI/3RiRN18fKX`b@X:H4TYfT0h^EW0B8TiT4QHjE18F@U`B7Uih4RINO18bL
Y0>@Y:`4UK2g19Jg_PBG^/84Ukc619Nnb@>F`<`4U/;@19O7ePBIbm`8Vm7S19S;g0>EaM@4TKk<18fg
a0B9/;`4Q:Vd182R[@=kVjD4MiBN17:>U`A^Qi04JH6916EjPPAPM7/Eoooo000Doooo15i_MPAPLGL4
Hg=i16EeN`AWMg`3JGUn16]jP0A^O844L7f3179oQ0AdPHH3MX>817R4RPAjQX`4OHR>17n;T0B1SI84
Q92E0hB?U@R9TiP4R9>H18VDV@B9TiT4RYFK0h^HWPB=Vj<<T:2V19:MY0>;UI`4R9>I18F>U@B5T9L4
QiNN18VGW`B<W:@3T:B/19F`]`BF]kh4Uk[219NlaPBG_/T3U/3<19K2d0BGamH4VL_L29_Ah`BHbm`3
ULGD196nc0B=]l@4RK2l18BY]0B0XZd3Ni^U17NDWPAbSYL4KXN@16V1R@AUNX84H7Ak5Oooo`005?oo
o`ANKgH4H75g16=cN@AUMG/4IgMl0fUiOPA[NX04KWb1171mP`AbOh@4M8660gJ3R0AhQ8X4NXJ<17f8
SPAoRi04PHfB18B@U@>4SiD8RI>H18RCV0B9U9T4RI>I18ZEV`>;V9h4SI^S392PYPBBWJ@3RiFL18RC
V@B5SYD4QI2G18NGWPB9Uil4S9bT0i2T[0BE/;L4U[Nn19Nj`PBG_<H4Ukk90iK0c0BF`]04UlOF19W;
g0RKdN<4V<_L0iG5e0BA_/`4SKO418V`_0B4ZK@4P::]0g^KY@AgU9h4LXjG16j7T0AYPHT4IGZ2161d
NaGoool001Coool4GW1f165aN0ASLgT4IWEk16QgO0=ZNGh4KG^016mmPPAaOX@4Lh2517J2Q`=hQ8T4
NXJ;17b8S@AoRXl4PHbB18B?U0B6T9D3SYJJ18bDV@B;U9T4Ri>I18^EVPR;U9X3S9JL18jJX@BBWjH4
U9nV18bCVPB<TYT3Ri2G18Z?UPB9TIP4QhnF18JAV@B5TiX4R9RO0hbOYPBEZk84VkNn19bma0BL_lP4
Vl7<0i[2cPBIa=44VLOF19_<g0BMdN84W]CU19kAh@>Kc=/4UlCB19:lb@B=]<44R:fh18>U/0=nWZP4
NINQ17B@V@A_RI84JX::16EkP`AQMG/Eoooo000Doooo15i`MPAQLGP4Hg=i16IeN`AXMg`3JWUn16ek
P0A_OH84LGj417>0Q@AfPXL3N8B917Z6R`AlR8d4OhZ?186<TPB4Si@4QY2E0hjFVPB<U9T4RiBI18^C
V@B;UIX8RiBJ0hbFW0B>VZ44TYnV19BOYPB<TiX4S9:I0h^@U`B:SiH4RI6H18N?UPB6TIT4QI>J18RH
W`><WjH4UJ^b19^g_PBL_L@4W;o819_1c0>J`/h4VLCA19W7ePBKc=`4WM7R19kDi@BNdN43VlcK19O4
dPBB_<T4SKC118R]^0B3YK03OYjX17VGX@AdT9T4KhVB16Z2RPAUNh<4HGEk5Oooo`005?ooo`ANL7H4
HG5h16=cN@AVMG/4J7Ml0fYiOPA]Nh04Kgf2175nQ0AcP8D4MX:70gR4R@AjQX/4O8R=17n:S`B1S984
Q8nD18J@U@>>UYX4S9BI18^DV@B;TiT4RiFJ28^DVP><UY`4SYZQ19:OYPBDWjH4S9>J18bBV@>;T9L4
RXnF18VAV0B7SiH4QY6I18FCVPB8V9l3S9nV19F[/PBK]kh4W;g419bob0BK`L`3V/;>19W4d@BIamH4
VlcL19gAhPBNe>D4W]7Q0i_<f`BGa=84T[c918fd`@B8[KP4PjF`0gjNZ0AiUj44M92I16n9TPAZPXX4
IG^3165eNaGoool001Coool4GW1f165aN0ASLgT4IWEk16QgO0=ZNGh4KG^016mmPPAaOX@4Lh2517J2
Q`=hQ8T4NXJ;17b8S@AoRXl4PHbB18B?U0B6T9D3SYJJ18bDV@B;U9T4Ri>I18^EVPR;U9X3S9JL18jJ
X@BBWjH4U9nV18bCVPB<TYT3Ri2G18Z?UPB9TIP4QhnF18JAV@B5TiX4R9RO0hbOYPBEZk84VkNn19bm
a0BL_lP4Vl7<0i[2cPBIa=44VLOF19_<g0BMdN84W]CU19kAh@>Kc=/4UlCB19:lb@B=]<44R:fh18>U
/0=nWZP4NINQ17B@V@A_RI84JX::16EkP`AQMG/Eoooo000Doooo15i`MPAQLWP4I7=i16IeN`AYN7d3
JgYo16ilP@A`OX<4Lgn517F1QPAgPhP3NHF:17^7S0AnRHh4P8^@18B>U0B7TYL4Qi6E0i:IW@B?UY/4
SYFI18fCV0B=U9T4SI>I18fCV0><TiT4SYBK18fEW@BBW:<4SiZR18jIX0>>V:04SIJN18bGX0B;V:04
Ri^T18ZLY@B8WJL3QibU18^SZ`BF[kL4X;k51:33c0BOaLl3WLG@19c5dPBLb=L4WLgL19oBh`BPe^P4
X]GW0j7ChPBMbmT4U/;?196ia@B;/K`4QZVd0h2QZ`AkVJ<4MY:K176;T`A[Ph/4IWb4165eO1Goool0
01Coool4GW1f165bN0ATLgT4IWEk16UhO@=[NWl4KWb1171nP`AcOhD4MH6617N3R0=iQHX4NhN<17j9
SPB0Ri04Q8jD18NBU`B7TID3TYVM18nFV`B>UIT4SI>H18fDV@B=TiT4SI>H0hbCV@B>U9/4SIFM19:L
X`B?VZ84SYVP0hjHX0B=UYh4S9NP18^HX0B;Vj@4RYbU18RMY`>7W:D4Rj>[19J_]`BP_/D4X<?<19o5
c`>MaM04W<GB19c8e`BMcM`4Wm;S1:3Fj0BReNL3XM?R19g;f@BF`/l4TKW518^a_0B6ZK@3P:6[17^I
X`AfTY/4LH^C16^3R`AVO8@4HGEl5Oooo`005?ooo`ANL7H4HG9h16AcN@AVMG/4JGQm0f]jO`A^O844
L7j317=oQ@AePHH4Mh>80gV5RPAkQh`4OXV>182;T0B4SY@4Qi:G18NAU@>BVId4SiJK18jEV@B=TiP4
SIBI18fCV@B=TiP3S9>I18jDV`B=UId4TYbS18nJXPB>VJ03SYRP18fFWPB<Uj04RiRP18^KY0B:W:D4
R9fW0hNLY@B;Xj/4UZng1:2na@BP`l`4WlG?0ig5d0BLaM84W<SG19g=g0BOd^<4X=KX1:;Ei`>Qdn84
WL_I19K2c`BA^LD4Rk6l18JY]0>0XJ/4NiVS17JBV`AaRi<4Jh>;16IlQ0AQMG`Eoooo000Doooo15i`
MPAQLWP4I7=i16IeN`AYN7d3JgYo16ilP@A`OX<4Lgn517F1QPAgPhP3NHF:17^7S0AnRHh4P8^@18B>
U0B7TYL4Qi6E0i:IW@B?UY/4SYFI18fCV0B=U9T4SI>I18fCV0><TiT4SYBK18fEW@BBW:<4SiZR18jI
X0>>V:04SIJN18bGX0B;V:04Ri^T18ZLY@B8WJL3QibU18^SZ`BF[kL4X;k51:33c0BOaLl3WLG@19c5
dPBLb=L4WLgL19oBh`BPe^P4X]GW0j7ChPBMbmT4U/;?196ia@B;/K`4QZVd0h2QZ`AkVJ<4MY:K176;
T`A[Ph/4IWb4165eO1Goool001Coool4Gg1f165bN0ATM7X4IgIl16YhOP=]NX04Kgf2179oQ0AdPHD4
Mh:717V4R@=kQX/4OHR<17n9SPB1Ri44QY2F18jHWPB=UIX3SiJJ192FV@R?UYX4SiFJ18nCV0B=TIH3
S92E18Z<TPB8RI04S8jE18nDV`B@UYd3T9VQ192JX@B?Vj<4SibT18nPZ@B>Xj/4SjF^0hfS[@B=Z;44
T:be19^h`0BTaLd4X/O@0j77dPBOam@4W/[H1:3=g0BQd^84X]KX1:?Gj0>Se>D4XM3N19_6e0BE_LX4
SkC018V/]`>3Y:h4OIbV17RDW@AbS9D4K8B=16MmQ0AQMG`Eoooo000Doooo15m`MPAQLWP4I7Aj16Mf
O0AZN7h3KGZ016mmPPAbOh@4M86517N2Q`AiQ8T3NhJ;17f8S0AoRHh4PH^A18J@UPB>V9h4SIFJ0hnF
VPB@UYT8SiJJ18nEVPB?TiP4SI6F0hb@U@B:S984R8V@18b>U@B?U9/4T9JM0i2IX@B@VZ44Si^S18nL
Y0B?X:T4SZ>[18nU[P>=Xjd4SJRa192/]@BK^<04Y<G=1:;7d0>Qam84WlOD19k:f0BPcM`4XM;R1:;F
j0BSenP3XmCU1:7@gPBKa]@4UKg:18nd`0B9[;L3PjB^17fLYPAhU9d4LXbE16b4S@AWOH@4HGEl5Ooo
o`005?ooo`AOL7H4HG9h16AdNPAWMW`4JWQn0fejP0A_OH84LWn417B1Q@AgPXL4NHB90g^6R`AmR8`4
OhV>186;T@B6T9H4SYRN18fEVP>?UYX4T9JI28nFVPB?UIX4Si>H18fAUP><T9D4RXbB18R9T0B<SYD4
SiBK192FW@>@VJ44T9ZQ18nKX`B?W:@4Sj2Y18jSZ`B?YJh3SJ>]18fX/@B@[;D4VkS01:C5c@BRam03
XLOB19o7e0BNb]P4X<gL1:7BhPBRe^P4XmOX0j?Di@BQd=h4VlKD19FmbPB?]<04RJbg0h>T[PAmW:H4
N9BM17:<U@A/Q8d4Igf4165eO1Goool001Coool4Gg1f169bN0AUM7X4J7Ml16]iOP=^Nh04LGj317B0
Q0AfPXH4NHB817^5RP=mQh`4OhR=1829SPB0RXl4P8Z>18R@U@B?U9P3SiBG196EV@BBUYT4TYJH19:E
V0BATiL4T96E0i2BU`BAU9T4T96G192AV0BATYT4TI>J1i2CV`B?UId4SiJO18nHX@B@VjD4T:6[0i6T
[PB@Z;84TJfg19Jc_@BP`<T4YLSA0j?8d`BQb=@4X<[H1:7>g@BSd^84Y=OW1:SLkP>/gNh4YM?R19o;
f0BH`Ld4T[S418^_^P>5Y[44OijX17VFW`AcSYH4KHJ>16QnQ@ARMWdEoooo000Doooo15m`MPARLWP4
IGAj16QgO0A[NGh3KW^0175nP`AdP8@4MX:617V4R0AkQHX3OHN<17n8S@B0RHh4P8Z?182:SPB8T9D4
SiBH0hnDU`BAUIT4TYJI19:FV0BBUIP4TI>G192AU@>@TYL4TIBI192AU`B@TIP4TI:I196CVPN@Ti/4
SiFM18nFW`B?V:44T9^U192QZ`>AY:h4T:Rb196]]`BF/kd4X<391:G8d@>Sb=<4XLSD1:3:f0BQc]d4
Xm;R1:CGi`BXg>h3[=g^1:GChPBObmP4V<7=19:ha0B;[kX3QJJa17nNZ0AiUYl4LhjF16f6SPAXOXD4
HWIm5Oooo`005?ooo`AOL7H4HW9h16EdNPAXMg`4JgUn0fikP0AaOX<4M82417J2QPAiQ8P4NhF:0gf7
S0AoR8d4P8V>182:S`B0RXh4R92E18nDV0>?U9L4TIFI19:FV@BBUYP4TYFH196CU`B@TID3T9:G196D
V@B@TIL4T96H196BV@BATiX7T9>K18nEW@B?UYl4SiRQ192KY@B@XJ/3TJB^192X/PBA[KL4U[>m1:30
b@BUb=43XlSC1:78e0BPb]P4XLkM1:?BhPBTenL4Z=c^0jcMkPBUdn84Wl_H19S1c@BB^<@4Rjnj0hFV
/@AoWZP4NIJO17>>UPA]QXh4J7j5169fOAGoool001Coool4Gg1f169bN0AUM7X4J7Ml16]iOP=^Nh04
LGj317B0Q0AfPXH4NHB817^5RP=mQh`4OhR=1829SPB0RXl4P8Z>18R@U@B?U9P3SiBG196EV@BBUYT4
TYJH19:EV0BATiL4T96E0i2BU`BAU9T4T96G192AV0BATYT4TI>J1i2CV`B?UId4SiJO18nHX@B@VjD4
T:6[0i6T[PB@Z;84TJfg19Jc_@BP`<T4YLSA0j?8d`BQb=@4X<[H1:7>g@BSd^84Y=OW1:SLkP>/gNh4
YM?R19o;f0BH`Ld4T[S418^_^P>5Y[44OijX17VFW`AcSYH4KHJ>16QnQ@ARMWdEoooo000Doooo15m`
MPARLWP4IGEj16UgO0A/NGh3Kg^0179nP`AePHD4N8>717^5R@AmQh/3OhV=186:SPB1RXl4OhN<17R1
QPAjPhT4RHnC0i2EV0BCUYT4U9FI29BFV0BDTiH4TY6E0i:BUPBEV9`4UIRN19FGW@BEUYd;U9NM19>H
W`BCVJ44TibT19BOY`BEXZ/3UZB_19JV/@BEZ;<4UZbg19^e_`BR`<X3Y<KA1:?8e0BRb]L4XlgK1:CA
h@BUeND4YMKW0joNkPBZenH4X/gK19_4d@BE^lL4S[:m0hRY/`B1X:X4NiNQ17F?V0A^Qhl4J7j6169f
OAGoool001Coool4Gg1f169bN0AUMGX4JGMl16aiOP=_Nh04LWj317F1Q@AhPhL4NhF917f7R`=oRHd4
PHZ>186:S`AoQh`4N86617Z3R@B9Si<3T9FH19>FV@BDUIT8U9JH19BCUPBBTID3TY:F19FHW0BEV9h4
UINM19FFW@^DUid4TiRO19>IX@BCW:@4U9nW19FRZ`>FY:l4UZJa19FX/`BF[;L4VkFo1:;0bP>Ta]44
XlSD1:;:e`BScM/4Y=7Q1:GEi@BUe^L3[mk^1:[GiPBRcM/4VlCA19Fka`B>/[d3R:Vc186PZPAkUj44
MHnH16j7S`AXOXH4HWIm5Oooo`005?ooo`AOL7H4HW9h16EeNPAYMg`4K7Un0fmkP0AbOX<4MH6517R3
Q`AkQHT4OHN;0gn9S@B1RXh4PHZ?17n7S0AhPHH4NX>918V?T`>@UIP4TiJI19BEV@RDUYP4U9>F19:A
U@>BTYH4UIRL19FHWPBEUid4UIJM2iBGW@BCV9l4TiVQ19>LY0BDWjL4UJ:[0iJT[`BFY[44UJRc19J/
]`BK]Kl4X/3:0jC6d@BSb=@4X/[G1:?=f`BTdN44YMGU1:GFi`>_g^h4Z]OV1:;=f`BKa=44UK_718jb
_@>8ZK<4PJ2Z17^GX@AeSiP4KXN?16QnQPARMWdEoooo000Doooo15m`MPARLWP4IGEj16UgO0A/NGh3
Kg^0179nP`AePHD4N8>717^5R@AmQh/3OhV=186:SPB1RXl4OhN<17R1QPAjPhT4RHnC0i2EV0BCUYT4
U9FI29BFV0BDTiH4TY6E0i:BUPBEV9`4UIRN19FGW@BEUYd;U9NM19>HW`BCVJ44TibT19BOY`BEXZ/3
UZB_19JV/@BEZ;<4UZbg19^e_`BR`<X3Y<KA1:?8e0BRb]L4XlgK1:CAh@BUeND4YMKW0joNkPBZenH4
X/gK19_4d@BE^lL4S[:m0hRY/`B1X:X4NiNQ17F?V0A^Qhl4J7j6169fOAGoool001Coool4Gg1f16=c
N0AVMG/4JWQm16ejO`=`OH44M7n417N2QPAjQ8P4OHN:1829S@>2Rhh4Q8b@18F=T@B4Ri44Q8bA18N=
T@B>TiD3U9NJ29NHVPBHUiT4V9JH19NEU`BFTiD3UYBG19RJWPBJWJ<4VYbR19VKX0NHVZ04UiVO19JI
X0BGW:<4Uj2W19RRZPBIYJd3VjRa19^[]@BK[[P4WK:m19nh``BR_/P3Y<C>1:C7dPBTb]H4Y<kK1:GA
g`BUe><4Y]KW0k;PkPB]f^L4Y]7N19o7e0BH_LT4TKBo0hZ[]@B3XZ`4OIVR17J@V@A_R904JGn6169f
OAGoool001Coool4Gg1f16=cN0AVMG/4JWQm16ejO`=`OH44M7n417N2QPAjQ8P4OHN:1829S@>2Rhh4
Q8b@18F=T@B4Ri44Q8bA18N=T@B>TiD3U9NJ29NHVPBHUiT4V9JH19NEU`BFTiD3UYBG19RJWPBJWJ<4
VYbR19VKX0NHVZ04UiVO19JIX0BGW:<4Uj2W19RRZPBIYJd3VjRa19^[]@BK[[P4WK:m19nh``BR_/P3
Y<C>1:C7dPBTb]H4Y<kK1:GAg`BUe><4Y]KW0k;PkPB]f^L4Y]7N19o7e0BH_LT4TKBo0hZ[]@B3XZ`4
OIVR17J@V@A_R904JGn6169fOAGoool001Coool4Gg1f16=cN0AVMG/4JWQm16ejO`=`OH44M7n417N2
QPAjQ8P4OHN:1829S@>2Rhh4Q8b@18F=T@B4Ri44Q8bA18N=T@B>TiD3U9NJ29NHVPBHUiT4V9JH19NE
U`BFTiD3UYBG19RJWPBJWJ<4VYbR19VKX0NHVZ04UiVO19JIX0BGW:<4Uj2W19RRZPBIYJd3VjRa19^[
]@BK[[P4WK:m19nh``BR_/P3Y<C>1:C7dPBTb]H4Y<kK1:GAg`BUe><4Y]KW0k;PkPB]f^L4Y]7N19o7
e0BH_LT4TKBo0hZ[]@B3XZ`4OIVR17J@V@A_R904JGn6169fOAGoool001Coool4Gg1f16=cN0AVMG/4
JWQm16ejO`=`OH44M7n417N2QPAjQ8P4OHN:1829S@>2Rhh4Q8b@18F=T@B4Ri44Q8bA18N=T@B>TiD3
U9NJ29NHVPBHUiT4V9JH19NEU`BFTiD3UYBG19RJWPBJWJ<4VYbR19VKX0NHVZ04UiVO19JIX0BGW:<4
Uj2W19RRZPBIYJd3VjRa19^[]@BK[[P4WK:m19nh``BR_/P3Y<C>1:C7dPBTb]H4Y<kK1:GAg`BUe><4
Y]KW0k;PkPB]f^L4Y]7N19o7e0BH_LT4TKBo0hZ[]@B3XZ`4OIVR17J@V@A_R904JGn6169fOAGoool0
01Coool4Gg1f16=cN@AWMG/4JWQm16ikO`=bOH84MH2417V3Q`AmQXT4P8R<18>;SP>6SI04R8nB18ZA
U0B<TYD4SYBH196HV`BEVid3VIbM19ZLW@BKVid4W9ZL19bIV`BLV9T4ViJH0iZGV@BKVYd4WInS19jQ
YPBMWj@4W9jS0i^NX`BKWJ84VYbR19ZNY0BKXZP4VjF/19^W[`>MZk84Wjff19na^@BP];d4X[W21:Bo
b@>U`ld4Y/OA1:G9e@BUcMT4YM3M1:CBh@BSe>@3]>;a1;7Nk@BYe>84X/[G19[0c0BC]/43S:fg18FT
[@AnVj@4Mi6J1729T0AYP8L4HgMn5Oooo`005?ooo`AOL7H4Hg=i16MeN`AZN7d4KW]o0g9mPPAeP8@4
NH>717f6R@B0R8`4Ph^>0hJ=T0B8Si84RY6D18bBU@B>U9P4TIRK19FKW@>IW9d4VYbM19^KW@BLVY`4
W9VK19bHV@BKUYP3VYNI19^JW@BMWj<4WZ6V19fOY0BLWZ<3VijS19^MXPBJW:84VYjT19^RZ0BKYJ`4
VjN_0if[/PBO[KH4Wk6i1:2d_@BR^L84Y;o90jG3c@BVam44YLWE1:G=f@BUd=d4Y=;Q1:?Di0>dh_44
/Mk]1:WDhPBRb]L4V/3<19>f`@><[KL4QJB]17jKY0AgTIX4L8V@16V0Q`ASMghEoooo000Doooo15m`
MPASLgT4IgEk16YhO@A^Ngl3LWf217F0Q0AiPhL4OHJ91828S0B3Rhh3QXf@18R?TPB:TI@4S9:E18jD
V0BAV9/4UI^M0iVLW@BJW9d4Vi^M19bJW0BLVI/4W9RI19^FV0>JUiT4ViZM19fOX`BNXJH4WInT19bN
X`>KWZ<4VifR19ZLXPBJWZ@4Vj:X19^U[0BKYjl3WJ^b19n]]PBO/KT4X;Bm1::i`PBT_lT3YL?=1:K7
d@BUbMD4YLgI1:G@g@BTd^44XmCT0kCRl@Bag^d4ZMCR1:;:e`BJ`<`4TkK10hb]]`B5Y:d4OY^T17NA
VPA`RI04JH2716=gOQGoool001Coool4Gg1f16=cN@AWMG/4JWQm16ikO`=bOH84MH2417V3Q`AmQXT4
P8R<18>;SP>6SI04R8nB18ZAU0B<TYD4SYBH196HV`BEVid3VIbM19ZLW@BKVid4W9ZL19bIV`BLV9T4
ViJH0iZGV@BKVYd4WInS19jQYPBMWj@4W9jS0i^NX`BKWJ84VYbR19ZNY0BKXZP4VjF/19^W[`>MZk84
Wjff19na^@BP];d4X[W21:Bob@>U`ld4Y/OA1:G9e@BUcMT4YM3M1:CBh@BSe>@3]>;a1;7Nk@BYe>84
X/[G19[0c0BC]/43S:fg18FT[@AnVj@4Mi6J1729T0AYP8L4HgMn5Oooo`005?ooo`APL7H4Hg=i16Mf
N`A[NGd4Kg^00g=nPPAgPHD4NhB817n7RPB3RXd4QXf@0hZ@T`B=TiD4T9FH19>HV`BEVid4VIjP19^P
XP>NX:44Wj6Q1:2PX@BPWil4XIfN1:2LW@BPVY`3WiZL19nLW`BQX:@4XZBX1:6RY`BPX:D3WinT19jO
X`BMWZ<4WJ2U19fRZ0BNYZ`4WjV_0j6]/`BR/;L4Y;Bj1:Bf_@BT^L44Y[k60jO2b`BXa]04YlWD1:O<
f0BVcm`4Y=3O1:3@h@>agnl4]^?a1:gHi@BTcMT4WL;>19Fh``>>[kT4QjF_182LY@AiTi/4LHVA16Z0
R0ASMghEoooo000Doooo161`MPASLgT4IgIk16]iO@A_Nh03Lgj217N1Q@AkQ8P4OhN:18>:S@B6SI03
RY2C18fCU@B@UIP4TiRK19FKW@BIWZ04Vj2R0ijPX@BOXJ44X:2Q1:2OW`BQWIh4X9bM1:2JW0>OVY`4
WibO1:6PY0BRY:P4XJ:W1:2PY@>OWj@4WYnS19fNX`BMX:D4WJ:X19jV[0BOZJl3XJfc1::`]`BT];X4
Y;Jm1:Bi`@BV_/H3Yl;;1:S6d0BWbM@4YlcH1:K?g0BTd=l4X=3Q0k7Ok`Bfho44[MSU1:C=f@BM`/h4
UKS30hj_^@B7YJl4P9bU17VCV`AaRI44JX2816=gOQGoool001Coool4H71f16=cN@AWMW/4JgUm16mk
P0=cOX84Mh6517^4R0AoQhX4PhZ=18J=T0>:T9<4SI>E192EV0BCV9/4UI^M19VNX0BKX:83WZ2Q19nQ
X@BPX:44X9nO1:6MWPBPW9d4X9ZL0inJW0BOW9l4XJ2T1::TZ0BQXZL4X:2U0inOY0BNWj<4WIjS19fP
Y@BMXZP4WZJ/19nY[`>Q[K<4X[2g1:Bd^PBT][d4Y;W11:JnaP>W`//4Z<K@1:O9e0BWc=P4Y/oL1:C@
g`BPd>43/Mo_1;KSl@B]f>D4Y<gI19g2cPBE^<<3SZni18NU[`B0W:D4NI>K1769T@AZP8P4HgMn5Ooo
o`005?ooo`APL7H4Hg=i16MfN`A[NGd4Kg^00g=nPPAgPHD4NhB817n7RPB3RXd4QXf@0hZ@T`B=TiD4
T9FH19>HV`BEVid4VIjP19^PXP>NX:44Wj6Q1:2PX@BPWil4XIfN1:2LW@BPVY`3WiZL19nLW`BQX:@4
XZBX1:6RY`BPX:D3WinT19jOX`BMWZ<4WJ2U19fRZ0BNYZ`4WjV_0j6]/`BR/;L4Y;Bj1:Bf_@BT^L44
Y[k60jO2b`BXa]04YlWD1:O<f0BVcm`4Y=3O1:3@h@>agnl4]^?a1:gHi@BTcMT4WL;>19Fh``>>[kT4
QjF_182LY@AiTi/4LHVA16Z0R0ASMghEoooo000Doooo161aM`ATLgT4J7Ik16aiOPA`O803M7n317V2
QPAmQHP4PHV;18J<SPB:Si83SY>E19:FV0BFVY/4VYjP19fQX`BQY:D4XZBU0j>TY@BTY:D4YJBT1:FS
X`BUXZ84YJ6Q1:FPX0>UWj04Y9nQ1:FRY0BVYJT4YJFY1:BTZ0>SXjL4XJ:V1:2RYPBPXjP4XJJ[1::Y
[PBSZk43YJje1:Jb^@BX][d4ZKVo1:Vl`PBY_lL3Z/;;1:[6c`BZbM@4ZLcG1:S>fPBTcmd4WLcL0j;C
i0Bagnh4/]gZ1:K>f`BNa<l4Uk[50i2`^PB9Yk04PIfV17ZDW0AbRY84Jh6816=gOQGoool001Coool4
H75g16AcN@AXMW/4K7Un171lP0=dOh<4NH:617f5R0B1RH/4QXb>18Z?TP>>TiD4TYJH19JJV`BJWZ04
WJ6S1:6TY@BRY:D3XjBU1:BTY@BUY:@4YJ>S1:FRXPBUXJ44YJ2P0jFOX0BTWj44YJ:T1:JUZ@BUYJT4
Y:BX0j>SY`BQXZH4X::V1:2SZ0BQYZ/4XZV^1:>[/@>U[[D4Y[:i1:Rf_@BY^Kl4ZKc21:Voa`>Z`//4
Z/K?1:[9e0BYc=L4Z<kJ1:C?g@BMc=`3X]?T1;7OkPBbgNX4Y/kK19k4c`BG^/D3T;2j18VW/0B1WJH4
NYBL17::TPA[PHP4HgMn5Oooo`005?ooo`APLGL4I7=i16QfN`A/NGh4L7b00gAoP`AiPXH4OHF81869
R`B6S8h4RXnB0hjCU@BBUYP4UYZK19ZNX0BMXJ<4XJBU1::TY@>SY:D4Y:BU1:FTY0BUXj<4YJ:R1:FQ
X@BUX:03YInP1:BOX@BUXZ@4YZFY1:FUZ@BTY:P3Xj>W1:6RYPBPXZH4X:>X1:6VZ`BRZJh4Xj^a0jF^
]@BV/[T4Z;Jm1:Vi_`BY_<84ZKo70j[2b`BZa/l4Z/WD1:W<e`BXc]X4Y<oM19g<g0>Rdn@4/Mo^1;;M
jPBVc]/4W/C?19Nja@>@/;X4RJN`186MYPAjU9`4LXZB16^1R0ASMghEoooo000Doooo161aM`ATLgT4
J7Ik16eiOPAaO843MX2317Z3QPAoQXT4Q8Z<18V>T0B>TY<3TiJG19RJV`BLX:04XJJV1:BYZ0BXZZXC
ZZRX1:^WY`B[YZH7ZZFU1:ZTY@BYYJH4ZZNY1:VWZPBXYjX3YjNZ1:FUZ@BTYZT4Y:J[1:FZ[PBW[K44
Z;2d0jZb]`B/][/4[KVo1:fk`PB^_lD4[L790jg5c@B^b=44[L_E1:g>f0B[d=`4ZM;N1:G@g@>Sd=h4
Y=7P1:SCg`BVc]X4X<G@19VlaP>B/[`4RjRb18>OY`AkUId4Lh^C16b1R@ATN7hEoooo000Doooo161a
M`ATLgT4J7Ik16eiOPAaO843MX2317Z3QPAoQXT4Q8Z<18V>T0B>TY<3TiJG19RJV`BLX:04XJJV1:BY
Z0BXZZXCZZRX1:^WY`B[YZH7ZZFU1:ZTY@BYYJH4ZZNY1:VWZPBXYjX3YjNZ1:FUZ@BTYZT4Y:J[1:FZ
[PBW[K44Z;2d0jZb]`B/][/4[KVo1:fk`PB^_lD4[L790jg5c@B^b=44[L_E1:g>f0B[d=`4ZM;N1:G@
g@>Sd=h4Y=7P1:SCg`BVc]X4X<G@19VlaP>B/[`4RjRb18>OY`AkUId4Lh^C16b1R@ATN7hEoooo000D
oooo161aM`ATLgT4J7Ik16eiOPAaO843MX2317Z3QPAoQXT4Q8Z<18V>T0B>TY<3TiJG19RJV`BLX:04
XJJV1:BYZ0BXZZXCZZRX1:^WY`B[YZH7ZZFU1:ZTY@BYYJH4ZZNY1:VWZPBXYjX3YjNZ1:FUZ@BTYZT4
Y:J[1:FZ[PBW[K44Z;2d0jZb]`B/][/4[KVo1:fk`PB^_lD4[L790jg5c@B^b=44[L_E1:g>f0B[d=`4
ZM;N1:G@g@>Sd=h4Y=7P1:SCg`BVc]X4X<G@19VlaP>B/[`4RjRb18>OY`AkUId4Lh^C16b1R@ATN7hE
oooo000Doooo161aM`ATLgT4J7Ik16eiOPAaO843MX2317Z3QPAoQXT4Q8Z<18V>T0B>TY<3TiJG19RJ
V`BLX:04XJJV1:BYZ0BXZZXCZZRX1:^WY`B[YZH7ZZFU1:ZTY@BYYJH4ZZNY1:VWZPBXYjX3YjNZ1:FU
Z@BTYZT4Y:J[1:FZ[PBW[K44Z;2d0jZb]`B/][/4[KVo1:fk`PB^_lD4[L790jg5c@B^b=44[L_E1:g>
f0B[d=`4ZM;N1:G@g@>Sd=h4Y=7P1:SCg`BVc]X4X<G@19VlaP>B/[`4RjRb18>OY`AkUId4Lh^C16b1
R@ATN7hEoooo000Doooo161aM`ATM7T4JGMk16ejOPAbOH43Mh2317b4QPB1QhX4QX^=18b?T@BBU9D3
UiRI19fMW0BRXZ44YjNV1:b/Z`B^[Zd4[jf/3jn/Z`R`[:/7/:^[1:n[Z`B_[:`4[j^/1:fZZ`B[Z:X3
ZZNY1:RVZ@BWYjT4YjR[1:R[[`BZ[k84[K:f0jje^0B_]k`4/K_01;:oa0Bc`/P4//C;0k;7cPBbb]84
//gF1;7@f@Badm`4[mGO1:gDh0>]enD4[][X1:cFhPBXcm/4X/OB19bnb0>D];d4SJZc18FPZ0AmUYh4
M8bC16b2R@ATN7lEoooo000Doooo161aM`ATM7T4JGMk16ejOPAbOH43Mh2317b4QPB1QhX4QX^=18b?
T@BBU9D3UiRI19fMW0BRXZ44YjNV1:b/Z`B^[Zd4[jf/3jn/Z`R`[:/7/:^[1:n[Z`B_[:`4[j^/1:fZ
Z`B[Z:X3ZZNY1:RVZ@BWYjT4YjR[1:R[[`BZ[k84[K:f0jje^0B_]k`4/K_01;:oa0Bc`/P4//C;0k;7
cPBbb]84//gF1;7@f@Badm`4[mGO1:gDh0>]enD4[][X1:cFhPBXcm/4X/OB19bnb0>D];d4SJZc18FP
Z0AmUYh4M8bC16b2R@ATN7lEoooo000Doooo161aM`ATM7T4JGMk16ejOPAbOH43Mh2317b4QPB1QhX4
QX^=18b?T@BBU9D3UiRI19fMW0BRXZ44YjNV1:b/Z`B^[Zd4[jf/3jn/Z`R`[:/7/:^[1:n[Z`B_[:`4
[j^/1:fZZ`B[Z:X3ZZNY1:RVZ@BWYjT4YjR[1:R[[`BZ[k84[K:f0jje^0B_]k`4/K_01;:oa0Bc`/P4
//C;0k;7cPBbb]84//gF1;7@f@Badm`4[mGO1:gDh0>]enD4[][X1:cFhPBXcm/4X/OB19bnb0>D];d4
SJZc18FPZ0AmUYh4M8bC16b2R@ATN7lEoooo000Doooo161aM`ATM7T4JGMk16ejOPAbOH43Mh2317b4
QPB1QhX4QX^=18b?T@BBU9D3UiRI19fMW0BRXZ44YjNV1:b/Z`B^[Zd4[jf/3jn/Z`R`[:/7/:^[1:n[
Z`B_[:`4[j^/1:fZZ`B[Z:X3ZZNY1:RVZ@BWYjT4YjR[1:R[[`BZ[k84[K:f0jje^0B_]k`4/K_01;:o
a0Bc`/P4//C;0k;7cPBbb]84//gF1;7@f@Badm`4[mGO1:gDh0>]enD4[][X1:cFhPBXcm/4X/OB19bn
b0>D];d4SJZc18FPZ0AmUYh4M8bC16b2R@ATN7lEoooo000Doooo161aM`AUM7T4JGMk16ijOPAcOH43
N82417f4Q`B3R8X4RHb>18nAT@BEUYH3W9^K1:BPX0BZYJ@4/:^Z1;Fa[`Bf/k04][:`0kFa[`Be/:h4
];2^1;B`[`Be/;08][6`0kJb/0Bf/K04]K:a1;Ba/@Bb[jl4/:b]0jfZZ`B[Z:T4ZJRZ1:VZ[0B[[Jl4
[K2c1:nd]`>b]kX4];^o1;Jo``Bg`lL4]lG;1;S8cP>gb]44]lcD1;O?f0Bgd]/4]mGN1;KHhPBdf><3
]=cX1;KQkPBcgNT4[M?N1:K:e0BO`<T3UkJo18n[]0B6XJT4OYNO17J=U0A]PXT4I7Qo5Oooo`005?oo
o`APLGL4IGAi16UgN`A^NWh4Lgf10gR0Q0AmQ8L4PhR:18V<SPB?TI44UIJF0ibKV`BTX:04ZZFT1;2[
ZPBe/Jl4][>`1;Jb/0>e/Jl4]K2^1;B`[PBd/:l4]K2`2;Ja/0>f/[04][6`1;Fb/@Bd/K44/Zn_1;2/
[@>]ZZ/4ZjRY1:VXZPBYZZ`4Zjf_1:f`/`B_];L3/[Nj1;Bk_`Bf_l<4]l?71;O5b`Bhb<h3]l[A1;O<
e0BgcmP4]m;K1;OEgPBff>84]=SS0kCLj0BfhNh4/mgY1:gCgPBVb]@4Wl390iNf_`B?Zk@4QZ6Y17jG
W`AfSI@4KH:916AhOaGoool001Coool4H75g16EdN@AYMg/4KWYn17=mP@=hP8@4OHB718>8RPB9S8h4
Si6A19FFUP>LVi/4Y:2P1:ZUY0B`ZjX4]K6_1;Jc/0Bf/[03]K6_1;F`[PBd/:h4];2_1;F`/0Rf/K03
][:`1;Ja/0Be/[44];6a1;:_[`B`[:d3[JZ[1:^XZ@BYZ:X4ZJZ/1:^][`B]/;<4[kBg0k:g^PBd^kl4
][o31;O3a`BgaL/4^<S>0kO:d@Bgc=@4]loH1;OBf`BgeMh4]]SR1;CHh`>dg>P4]^7^1;?Mj@B]dmh4
Y/[D19o0b@>G][l4Sj^d18JQZ@AnUil4MXfD16f2R@ATN7lEoooo000Doooo161aM`AUM7T4JGMk16ij
OPAcOH43N82417f4Q`B3R8X4RHb>18nAT@BEUYH3W9^K1:BPX0BZYJ@4/:^Z1;Fa[`Bf/k04][:`0kFa
[`Be/:h4];2^1;B`[`Be/;08][6`0kJb/0Bf/K04]K:a1;Ba/@Bb[jl4/:b]0jfZZ`B[Z:T4ZJRZ1:VZ
[0B[[Jl4[K2c1:nd]`>b]kX4];^o1;Jo``Bg`lL4]lG;1;S8cP>gb]44]lcD1;O?f0Bgd]/4]mGN1;KH
hPBdf><3]=cX1;KQkPBcgNT4[M?N1:K:e0BO`<T3UkJo18n[]0B6XJT4OYNO17J=U0A]PXT4I7Qo5Ooo
o`005?ooo`APLGH4IGAi16UgN`A^NWh4Lgf00gV1P`AnQ8L4Q8V:18^=SPBATY84V9NF0j2MV`BZYZD4
]Jj/1;fd/0C0^;@4_kRd1;ff/`>k]K84^[Ba2;Vc/@Bi/k84^kBb1;be/`>m]k@4_;Nd1;^f]@Bj]KD4
]k:b1;B_/0>a[:d4[ZV[1:bXZPB/Zjd4[Zj`1;2c]@Bc]kT3][^m1;Vo`PBk`lH4_LO:1;g9c@Bmbm03
_LgB1;g>e@BmdMP4_MCL1;cHh0Bmfn@4_=gW0kcRk@Bki?04^N?_1;7GhPBZcMH4X/;;0iZh`0BA[KD4
R:>Z182HW`AgSID4KX>:16EhOaGoool001Coool4H75f16EdN@AYMg/4KWYn17=mP0=iPH<4OXB718B9
RPB;SHh4TI:B19RGUP>PWI/4ZZJU1;F^[0Bm];04`;Rd1;nh]0Bm][<3^kFb1;Zd/@Ri/k44^K>b1;^d
/PBl]K<3_KNd1;bg]0Bk][D4^[Fe1;Nb/PBd[k03/Jb]1:jYZ`B/Z:X4[:^]1:j^/0B`/kD4/kNi0kJk
_@Bi_l84^l?61;g7bPBmbLd4_L_@0kg=dPBmc]D4_M7H1;gDg0Blf>04_M_T1;cMi`>lh^d4^nC`1;WS
k`Baen84Z/gF1:;2b`>J^<04TJfe18RSZPB0V9l4MhfE16j3RPAUN7lEoooo000Doooo161aMPAUM7T4
JGMk16ijOPAcOH03NH6317j4Q`B4RHX4Rhf>196BTPBHUiH3X9fK1:ZVY@Be[Z`4_KB`1<2h]0Bo^;@4
_KJc0k^e/PBj];48^K>a1;Vc/PBk];84_;Fc0kfg]0Bl]k@4^kJe1;Ze]@Bg/[84]:n`0k6/[@B^ZJ/4
[:RZ1:b[[@B^[[04/;>e1;>g^@>f^kd4^Ko21;_3aPBmalX4_LW=1;g;d0>mcM84_LkE1;gAf0Bme=`4
_=SP1;gKi0BlgNL3_>;]1;_Tl0Bihnl4/MOR1:[=ePBR`//3V[S0196]]@B8XjX4P9RO17N=U@A^PhX4
IGQo5Oooo`005?ooo`APLGH4IGAi16UgN`A^NWh4Lgf00gV1P`AnQ8L4Q8V:18^=SPBATY84V9NF0j2M
V`BZYZD4]Jj/1;fd/0C0^;@4_kRd1;ff/`>k]K84^[Ba2;Vc/@Bi/k84^kBb1;be/`>m]k@4_;Nd1;^f
]@Bj]KD4]k:b1;B_/0>a[:d4[ZV[1:bXZPB/Zjd4[Zj`1;2c]@Bc]kT3][^m1;Vo`PBk`lH4_LO:1;g9
c@Bmbm03_LgB1;g>e@BmdMP4_MCL1;cHh0Bmfn@4_=gW0kcRk@Bki?04^N?_1;7GhPBZcMH4X/;;0iZh
`0BA[KD4R:>Z182HW`AgSID4KX>:16EhOaGoool001Coool4H75f16EcN@AYMW/4KWUm17AmP0=iP8<4
OhB618J9RPB<SXh4Ti:B19ZGUP>RW9T4[:JS1;Za[@C4^K<4bl2i1<Nm]`C3^[D3`;Nd1;jf/`Rm]K84
_[Fb1<2f]0C1^;D3`k^h1<>m^PC2_K/4`;^i1;bg]PBg/[83]:j^1;2[[0B_ZZ/4[jb]1;6`/@Bc]KL4
]kZl0kZn`0Bn`lD4`LO:1<;;c@C3cM44`loC0l;@e@C2d]P4`]CJ1<;Fg@C2f^44`mkV1<?Oj0?4i^l4
`nOa1;oVl@Bgfn@4[]3I1:K5c@>M^/84U:nf18^TZ`B1VJ04N8jE16n3RPAUNGlEoooo000Doooo161a
MPAULgT4JGIk16iiO@AdOH03NH2317n4QPB6RHX4S8j>19>BTPBJUiH3XYbI1:bVX`Bj/Jd4a;Vc1<_0
^@C7_KL4`kZe0l2g]0Bn][<8_KFb1;je/PC0][@4`KRe0l>k^0C3_KX4`[fk1<2k^@Bl]kH4]k:b0kB^
[PB`Zj`4[jZ[1:n/[@Ba/;44/kFg1;Nj_0>j_/04_/?51<77bPC2bld4`lgA1<??d`?2d=D4`];H1<;D
fPC2e]d4`][Q1<?NiPC3gnP3a>K_1<?Wl@Boi_44]m_T1:k@f@BVaLd3WK[219B_]PB;Y:/4PIVP17R>
U@A_PhX4IGUo5Oooo`005?ooo`APLGH4IG=i16UfN`A^NGd4M7f00gV0P`AoQ8H4QXV:18b>SPBCTY84
VYNF0j:LV@B/YZ<4^[6]1<Bi/`C;`;T4akfg1<>j]@?0]k@4_[Jc2;fe/PBn]K84`;Jd1<6h]@?3^kP4
`kfj1<:m^`C0^kT4_;Nf1;Nb/P>d[Zh4/:^/1:nZZ`B_[:d4/K2a1;>e]`Bg^[`3^[k01;k3a@C1alX4
`/_=1<?=d@C3cm<3`]3E1<;Bf0C2e=X4`]KM1<;Jh@C3g^H4`moX0lCVk`C3io44_nKa1;OKi0B^d=T4
Y/G=0ifj`PBD[kH4RjB[186IX0AhSYD4Kh>:16EiOaGoool001Coool4H71f16EcN0AYMWX4KWUm17=l
O`=iP884OhB618J9RPB>SXh4UI>B19fHUP>SViL4ZJ:M1;R_ZPC7^[@4dL>k1<g0^PC8_;L3aKZe1<6g
/PC0][84`KNd1<:i]PC6_;T4bKjj0l_0^`C:`K`4b<6m1<G0_@C1^kX4^kFc0kJ_[PBbZj/4/:ZZ1;2/
[@Bb/;84][Jg1;Zk_@>n`L84`lG71<K:c0C8c]04b=3B1<WBe@?7dmL4a]GI1<OGg0C7fMl4amcR1<SO
iPC8h^T3c>W`1<_/m0C6j_<4_=kV1;?BfPBYall3X;c319J`^0B=YJ`4PiZQ17V?UPA_Q8/4IWUo5Ooo
o`005?ooo`APL7H4IG=h16UfNPA^NGd4Lgao0gV0PPAoQ8H4QXV:18j>SPBETi84WIRF0j>KU`BYXYd4
^:nZ1<Nj]0CA`k/4cL2j1<Rl]`?5^[D4`KNb1<2f/PC1]k@4`[Vf1<Jl^@C9_[X3bl2k1<[1_0C8`Kd4
aL2m1<6k^PBk]K<3]Zn^1;:[Z`B`ZZX4/:b]1;:`/PBf][L4^[^m0kk1`PC3aLL4a/[<1<S>d0C8d=84
bM;E0lOCe`C6eMT4amOL1<OIg`C7g>84b=oV1<SRj@?<jO04bncd1<KZl`Blg^H4/m;J1:W7c`>P_<<4
U[2h18fU[0B3VZ44NHnF16n4R`AVNGlEoooo000Doooo161`MPAULgP4JGIj16iiO@AcO7l3NH2217n4
QPB6RHX4SXj>19FCTPBMV9H3Xi^G1:VRW@Bh[jX4akZd1=73^`C=`;X4b;bg0lFj]@C1]k84`;Jb1<6g
]0C2^KH4a[bi1<Vn^P?;`;/4b/6l1<S1_@C5`;d4`K^j1;^e/`>f[jh4/Z^[1;2ZZPB`[:d4/[2b1;Jf
]`Bj^kd3_/721<?5a`C6b/`4b<k@1<S@dPC9d]D3am?G1<KEf@C7em`4amWO1<OLhPC8gnH4b>;Y0lcY
l0C;k?@4a^[c1;cNiPBcd]X4ZLO?0j2l``BF/;P4SJF/18>JX@AiSiH4KhB;16IiOaGoool001Coool4
H71f16EcN0AYMWX4KWUm17=lO`=iP884OhB618J9RPB>SXh4UI>B19fHUP>SViL4ZJ:M1;R_ZPC7^[@4
dL>k1<g0^PC8_;L3aKZe1<6g/PC0][84`KNd1<:i]PC6_;T4bKjj0l_0^`C:`K`4b<6m1<G0_@C1^kX4
^kFc0kJ_[PBbZj/4/:ZZ1;2/[@Bb/;84][Jg1;Zk_@>n`L84`lG71<K:c0C8c]04b=3B1<WBe@?7dmL4
a]GI1<OGg0C7fMl4amcR1<SOiPC8h^T3c>W`1<_/m0C6j_<4_=kV1;?BfPBYall3X;c319J`^0B=YJ`4
PiZQ17V?UPA_Q8/4IWUo5Oooo`005?ooo`APL7H4I7=h16UeNPA^N7`4Lg]n0gUoP@AoPhD4QhR918n>
SPBHU9<4X9ZG0jJNV`B^YJ04_k>/1<bm]@CFaK`4dL:j1<bn]`?7^kD4a;Nb1;nc[PBn/Zh4_k>_1<>f
/PC9^kH3cknj1<o1_@C<`Kd4bL:n1<Fo_0Bm][@3]jn^1;>ZZ@B`ZJP4/:^[1;>`/0Bg][L4_;fn0ko1
`PC3a/L4b<c=1<cAdPC=e=D4c]KH0lgFf@C;em/4bmWN1<cKh0C=gN<4c>3V1<cRj0??ind4d>cc1<_]
m0C1h>P4]mGL1:k9d0>S_/@4VK:i18nW[@B5Vj84Ni2F1724R`AVNH0Eoooo000Doooo161`MPATLgP4
JGEj16ihO0AcNgh3NGn117n3Q@B7R8T4Shj>19RDT`BPVYL3YYjK1:jUX0Bo/j`4c;fe1=K5_0CA`[X4
c;jg0lNk]@C4]k84_k>^1;jb[PBo/jl4`kJb1<Vk]P??_kX4cl6m1<c1_@C9`[h4aKnl1;ff]0>g[jh4
/jZY1;2YZ0B`Zj/4/k2`1;Nf]`Bl_Kh3_l721<?6a`C8c<d4c=7B1<gDe@C>e]P3cMKI1<_Gf`C;fMh4
c=_P1<gMh`C<h>H4c>;X0loWk@C@k?<4bngd1<7Pj0BgeM`4[/W@0j>na0BI/[T4SjN]18FKXPAkT9H4
L8B;16IiP1Goool001Coool4H71f16AcN0AYMGX4KWQl17=kOP=iOh44Oh>518N8R@B?SXh4V9BC1:2J
U`>VWY/4[ZFP1;nc[0C<_KD4e/Fl1=72^PC<_[L3ak^e1<Bg/PBo/jh4_[:^1;nc[`C3][84bK^f0lno
^PC?`Kd4c<6m1<W2_PC5_k`4_KJd0kN_[PBcZZT4/:VX1;2[Z`Bc/;04]kJg1;bm_P>o`L84`lK71<S<
c@C<dM84cMCE1<kFf0?=e]T4bmOK1<_IgPC<fn04cMgS1<cPiPC<h^P3cnO]1=3/l`C;kO@4`N3X1;OE
g0B^bM03Xkk419Vb^@B?Yjd4QI^R17^@UPA`Q8/4IWV05Oooo`005?ooo`APL7H4I7=h16UeNPA^N7`4
Lg]n0gUoP@AoPhD4QhR918n>SPBHU9<4X9ZG0jJNV`B^YJ04_k>/1<bm]@CFaK`4dL:j1<bn]`?7^kD4
a;Nb1;nc[PBn/Zh4_k>_1<>f/PC9^kH3cknj1<o1_@C<`Kd4bL:n1<Fo_0Bm][@3]jn^1;>ZZ@B`ZJP4
/:^[1;>`/0Bg][L4_;fn0ko1`PC3a/L4b<c=1<cAdPC=e=D4c]KH0lgFf@C;em/4bmWN1<cKh0C=gN<4
c>3V1<cRj0??ind4d>cc1<_]m0C1h>P4]mGL1:k9d0>S_/@4VK:i18nW[@B5Vj84Ni2F1724R`AVNH0E
oooo000Doooo161`MPATLWL4J7Ai16agNPAbNW`3Mgeo17j2P`B6QhL4T8j=19^FU0BTW9P3ZJ6M1:bS
W`Bk[jP4c;bc1=W6_0CD`[T4ckjf0lZk]0C6]k04`K:/1;^]Y`BgZjH4]JZU1;^^ZP?3]:l4b;Rc1<Ng
/PC3][84`KNc1;bc/@>g[Z/4/jVW1;2XYPB`ZZT4/k2_1;Nf]PBo`;l3`/?31<S9b@C>d<l4d]CE1=;F
e`CCfMX3d][L1<oJg@C>fmh4c]gQ1=3Oi0CAh^H4dnGY0mOZkPCGkO84dNkc1<KRj0Blemd4//_A0jNo
a@BL];X4TJR^18NLXPAlT9L4LHF;16IiP1Goool001Coool4H71f16AbM`AXM7T4K7Mj179jO0=gOGl4
OX:318J7Q`B@SXd4ViJD1:BLV0>YXId4[:>O1;^_Z0C<_;<4fLJl1=C2^@C?_[H3b[^d1<Jg/0C1/Z`4
^jfW1;N[YPBeZZD4^jjZ0l>d[`C8^;<4akNb1<>f/PC1]k<4_;>a0kN^Z`BcZJL4/:RV1;2ZZ@Bc/:l4
]kJf1;o0_`?2`l<4b<W91<k@c`CBe=D4d]KG1=?IfP?Bf]`4cm[M1<kKgPC>gN44d=oT1=7RiPCCiNT3
en[^1=O]lPCAk_<4a^;X1;cGg@Bbbm43Yko519bd^PBAZ:h4QibR17b@U`AaQH/4IWV05Oooo`005?oo
o`APL7H4I79g16QdN@A/MgX4LWYl0gMmO`AnPX<4QXN7192>S@BKUY@4Y9bH0jVQW@B/Xil4^jnX1<bl
/`CIa[`4e<:i1<nn]P?:^k@4a[N`1<6b[0Bk[JL4]j^V1;FZY@Bk[ZX3`kB_1<Rh/`C7]k84`kJb1<6g
/`Bl/k43]jj[1;>YY`B`Z:H4/:ZY1;>`[`Bg][H4_l2o0l;3``C8bLT4c]3?1=;De@CBe]L4dmWJ0m;J
g0C?f]d4c]_N1<kMh@C@gn@4dN;V1=?Uj@?Gj^h4engb1=7^l`C6h^P4_=OM1;;;d@>W_lD4W;Bj196X
[PB7W:84O92G1765R`AVNH0Eoooo000Doooo161`MPATLWL4J7Ai16agNPAbNW`3Mgeo17j2P`B6QhL4
T8j=19^FU0BTW9P3ZJ6M1:bSW`Bk[jP4c;bc1=W6_0CD`[T4ckjf0lZk]0C6]k04`K:/1;^]Y`BgZjH4
]JZU1;^^ZP?3]:l4b;Rc1<Ng/PC3][84`KNc1;bc/@>g[Z/4/jVW1;2XYPB`ZZT4/k2_1;Nf]PBo`;l3
`/?31<S9b@C>d<l4d]CE1=;Fe`CCfMX3d][L1<oJg@C>fmh4c]gQ1=3Oi0CAh^H4dnGY0mOZkPCGkO84
dNkc1<KRj0Blemd4//_A0jNoa@BL];X4TJR^18NLXPAlT9L4LHF;16IiP1Goool001Coool4Gg1f16=b
M`AWLgL4JgEi171gNP=eNW`4O7n018B5Q@B?SH`4WiZH1;2XX`>aYZ44/JNQ1;f`Z0C>_;84g<Nl1=O3
^@CA_kH3c;^c1<Rh/0C3/j`4_JfV1;RYX`BaY9l4[Z:M0k:UX0BiZjL4_ZnZ1;na[@Bn/jl4^k6^0kN]
ZPBcZJH4[jNT1:jWYPB_ZjX4/:f]1;Nf]P>n_K/4a/G41<o>c0CAdm44eMOF1=SLf`?Fg=`4dmcN1<oK
gPC@g>04d]oS1=CSi`CHin/3h>ka1>3bmPCHlOH4c>GZ1<7Jg`Bfc]<3Zl7719ne^`BDZJl4R9fS17fA
U`AbQH/4IgZ05Oooo`005?ooo`AOL7H4Hg9g16McM`A[MGT4L7Mj0gEjO0AlOh04Q8F518n=S0BOVYP4
/:RS0k6VX@BaYj44_K2X1<jl/PCLak`4el>i1=6o]P?<^k<4b;R`1<>c[0Bm[JH4^:VS1;6TW`B^XYd3
/ZFP1;V[Y`Bn[jX4_k6]1;jc[`Bk/Jh3]jfZ1;>YYPB_Yj@4[ZNV1:n[ZPB`[Jd4]kJf0kjm^`C6aL@4
clk<1=7Cd@CEemH4f=cK0mKLg0CCg=h4cm_N1=3Lh0CBgn<4e>?W1=SWj`?Pk_44h?;f1=SamPC<iNX4
`M[O1;K>d`>[`LL4WkFk19BY[`B8WJ<4OI6G17:5R`AWNX0Eoooo000Doooo15m`MPASLWL4Ig=g16]e
N@A`MgX3MGYl17aoP0B4QHD4Shf<19nJV0B`Z:<3/JJQ1;6WX@Bm/:P4c[bb1=c7_0CG`kT4dKnf0lbk
/`C8^;04`k>/1;f]YPBhZJ<4/JBO1:jRW@>bYJ04^J^W1;j_ZPBo/Jd4_[>_1;^a[P>g[JX4/jVV1:nW
Y0B^YjH4[j^Z1;2][@Bg][H3_[fk1<K5a0C?c/`4dM?A1=GGePCHg=/3e]cL1=?LgPC?fmh4d=cP1=;O
h`CDhnL4f>O[0n3^l@CPl_H4f?7f1<cUjPC1f]l4]/kC0j_1a`BO]K/4U:V_18RMX`AmTIL4LXF;16Mj
P1Goool001Coool4Gg1f16=bM`AWLgL4JgEi171gNP=eNW`4O7n018B5Q@B?SH`4WiZH1;2XX`>aYZ44
/JNQ1;f`Z0C>_;84g<Nl1=O3^@CA_kH3c;^c1<Rh/0C3/j`4_JfV1;RYX`BaY9l4[Z:M0k:UX0BiZjL4
_ZnZ1;na[@Bn/jl4^k6^0kN]ZPBcZJH4[jNT1:jWYPB_ZjX4/:f]1;Nf]P>n_K/4a/G41<o>c0CAdm44
eMOF1=SLf`?Fg=`4dmcN1<oKgPC@g>04d]oS1=CSi`CHin/3h>ka1>3bmPCHlOH4c>GZ1<7Jg`Bfc]<3
Zl7719ne^`BDZJl4R9fS17fAU`AbQH/4IgZ05Oooo`005?ooo`AOKgD4HW1e16EaM@AYLgH4KGAg0g9g
N@AgNW/4Ogmo18^9R0BJU984[j>N0k^]YPBl[ZL4a;B[1=2m/PCMak/4f<>h1=>o]@?>^k44b[Z`1<Je
[@C0[jL4^jVQ1;JUWPBeYId3]ZJN1;VXX@Bl[:H4_ZnY1;f`Z`Bk[j/3]jbX1;>XY0B_YZ84[JFS1:fX
Y`B^ZZ/4[k2a0jnb/`Ba][L4`<711<G9b@C9cL`4cm?C0loEe@C?emP4c]WK1=3LgPCCg^44eN;U1=gZ
k0?Tl?<4ioSj1>3gnPCCjNd4amgQ1;[@e0>^`lP4X[Nk19JZ[`B:WZ<4OY:G17>6R`AWNX0Eoooo000D
oooo15m_M@ARL7D4IG5e16UcMPA]M7L3LWMi17MjN`AoOgl4RhV819ZDTPB_Xih3^jfV1;b^Y`C4]:/4
d;fb1=g7^`CH`kP4dkne0ljk/@C:^[04a[F]1<2_Y`BkZJ44]ZFN1;FUW@>fYYh4^JRQ1;b/YPBn[jT4
_K2[1;^_Z`>g[:P4/jRT1:nVXPB]YJ<4[JRW1:jZZ`B_/;43[k:c1;6f]`C0`L44aLW91<W=c0C?dm<3
cmGE1<oGf0C>fM/4d=cN1=?Nh@CEh^D4gN[/0nC`l`CWn?X4h?Oj1=?Yk@C7gN44^]3D0jk3b0BR]k/4
UZZ_18ZNX`AnTYL4LhJ;16MjP1Goool001Coool4Gfme169`M@AULGD4JG=f16edM`=bMgT4MgYk17mo
O`B;RHP4VYBB1:nSWP>k[JH4_:jW1<BdZ`C@_K84gLNk1=S3^0CC_kD3c[^a1<Zj/0C6]Jd4`:nW1;^Y
X@BfYIh4]JFM0kJVWPBiZ:44_:bV1;j_Z@Bm/:/4^jn[0kN/Z0BcZ:@4[jJR1:fUX`B]Z:L4[ZZ[1:n`
/@>_/[<4/KJg1<31`@C5bLT4bLg<1<oCd`??eMD4cmOH1<kIf`C@g=h4dmkQ1=GRi@CMj^`3i?3c1>Oh
nPCPmoX4dnW]1<OMh@Bjd=@3[/?81::g^`BFZZl4RYjS17jBU`AcQX/4IgZ05Oooo`005?ooo`AOKgD4
HW1e16EaM@AYLgH4KGAg0g9gN@AgNW/4Ogmo18^9R0BJU984[j>N0k^]YPBl[ZL4a;B[1=2m/PCMak/4
f<>h1=>o]@?>^k44b[Z`1<Je[@C0[jL4^jVQ1;JUWPBeYId3]ZJN1;VXX@Bl[:H4_ZnY1;f`Z`Bk[j/3
]jbX1;>XY0B_YZ84[JFS1:fXY`B^ZZ/4[k2a0jnb/`Ba][L4`<711<G9b@C9cL`4cm?C0loEe@C?emP4
c]WK1=3LgPCCg^44eN;U1=gZk0?Tl?<4ioSj1>3gnPCCjNd4amgQ1;[@e0>^`lP4X[Nk19JZ[`B:WZ<4
OY:G17>6R`AWNX0Eoooo000Doooo15i^L`AQKg<4I6mc16M`L`AZLG@3KG9d179dM@AfMWH4NWMf18f7
Q0BOThl3/:6K1;VYXPC4/ZT4d;ba1=g7^PCI`kP4e;nd0ljh[PC9]:X4akBZ1<FbZPC1[ZH4_ZZR1;fX
W`>nZZ44_j^S1<2^YPC1/:P4_JjW1;Z]Z0>gZjH4/jNS1:nVXPB]YJ44[JRU1:n/ZPBa[jl3[k2a1:V^
/0B^/k@4]K^l1;_2``C3bLT3b<k>1<cCe0C>e]L4cmWK1=;Mg`CDh><4g^W[0nKal@CZmoP4iO[l1=W]
l0C<h><4_m;F0k;5b@BU^;`4V:^`18bNX`AoTYL4LhJ<16QjP1Goool001Coool4GVic165_L`ATKg<4
Ig1c16YaM0=]LW@4LWAe17IfMPAjMgH4SHN419nCS`>`XI/4^JVR1<BbZ@C@_;44gLNj1=W3^0CD_k@3
c[R^1<VdZPC7]:X4aK:Z1<6^YPBnZZ84_JRO0kjZX@BoZj<4`:jV1<6`Z0Bm[ZL4^ZfX0kN[YPBcYj<4
[jJR1:fUX@B]Z:D4[jbZ1;6_[`>_/;44ZJj`1:jc]0Be^k`4^l;31<?9b@?8c/h4c=?D1<kFe`C?fM/4
d]gO1=CPh`CNjN/3i_7a1>[gn0CUn_`4fNg`1<cPh`Bod]H3//G91:Fh_0BHZk04S9jS17nBU`AcQX`4
J7Z05Oooo`005?ooo`ANKW<4HFmc16A_L`AWL7<4JW5d0febM0AbM7D4MWIf17YgMPB=Qh@4Wi>?0k2Q
V`BiZJ84a;:Y1=2l/@CMakX4fL>h1=Bo]0?>^:h4bKBZ1<NdZPC5/ZX4`JjV1;jZXPBmZ9l3_ZZQ1;n[
X`C0[ZH4`K2X1;f^Y`Bj[JP3]j^V1;>WX`B_YZ84[JFQ1:fXY@B_[:X4/Jn_0jn`/@BY[[04[[>d1;Fk
_0Bk`/<4`lW90lS>cPC<dm@4c]KG1<oIf`CBgMl4e>3S1=kYj`?VlO44j_Oh1>Gjo0CIkO04c>3S1;oB
eP>baLT4YKRl19R[/0B<WZ<4Oi:G17>6S0AXNX0Eoooo000Doooo15i]L`APKG84HVea16A]L@AVKG03
JFe_16]]KPA]KFd4Kf][189lN@BERhH3YIRB1;:RV`C2[ZD4dKZ^1=k5^0CKa;P4eKnd0m2i[`C9/jP4
`ZbR1;nYW`BlYY`4^J:H1;BNU@>eWiD4]j2G1;VTV`BkZ:04^jZS1;ZZY0>gZZ@4/jNR1:nUX0B]Y9l4
[JNR1;6]Z@Bd/Zl3];>b1;>d]0Bd]kL4]KVi1;Zn_PC2a/D3alc;1<[Ad0C=eM@4cmWI1=7Lg@CEh>44
hNWY0nW`k`CZm?D4jocm1>3al`CBhnD4`mCG0kG6b@BW^K`4VZb`18fOX`B0TYL4M8J<16QjP1Goool0
01Coool4GVec161]LPARKG44I6ea16I]L0=YKFl4Jfe^16e]K@A_Jf/4PWai19F;QP>UV984/Z:K1<:^
Y@CA^Zh4g/Fh1=_4^0CE_k@3d;V_1<VcZ0C2[:84_jVO1;bVW0BiXYP4]9jE0kFOU@BgX9L4^JBK1;^X
X0BkZZ<4^ZZT0kNZY0BcYj84[jFP1:fTW`B]Yj84/JfY1;Bb[`>d/k84/kBd1;Bg]`Be^KT4^[jn1<;6
a@?7c</4b]7@1<gEe0C?fMT4dMcM1=GPh@CQjNT3jO3_1>[dm@C[o?d4h?7c1=;Si@C3e=L3]LK91:Ni
_0BJ[;04SInS182BU`AdQX`4J7Z05Oooo`005?ooo`ANKG<4H6eb169]L@ATKG44IVe`0fU]K`A[KFh4
KFe]16m[J`B2O7T4UH^60jFHTPBbXY/4`ZjU1=6j[PCNaKP4flBh1=Fo]0?@^Jl4bK>X1<:/XPBoZIl4
_:JL1;VRV0BdWYD3]InE1;NPU`BiY9/4^jRP1;^ZX`BjZZ@3]jZT1;>WXPB_YJ04[JBO1:fWXPBa[JT4
];:_0kBc/PBc];@4];Ng1;Fi^@Bj_[h4`/K50lO<b`C:dM04cMGD1<oIf@CAg=d4eN3Q1>7Yj@?Yl>l4
j_Ce1>_lo@CPlO<4d^?U1<?De`>ea/T4YkVl19Z//0B=Wj<4P9:G17B6S0AXNX0Eoooo000Doooo15i]
L`APKG84HVea16A]L@AVKG03JFe_16]]KPA]KFd4Kf][189lN@BERhH3YIRB1;:RV`C2[ZD4dKZ^1=k5
^0CKa;P4eKnd0m2i[`C9/jP4`ZbR1;nYW`BlYY`4^J:H1;BNU@>eWiD4]j2G1;VTV`BkZ:04^jZS1;ZZ
Y0>gZZ@4/jNR1:nUX0B]Y9l4[JNR1;6]Z@Bd/Zl3];>b1;>d]0Bd]kL4]KVi1;Zn_PC2a/D3alc;1<[A
d0C=eM@4cmWI1=7Lg@CEh>44hNWY0nW`k`CZm?D4jocm1>3al`CBhnD4`mCG0kG6b@BW^K`4VZb`18fO
X`B0TYL4M8J<16QjP1Goool001Coool4GFeb15i/L@APJfl4HF]^169YK0=TJ6X4IFMX16IUI@AUHV44
MG1^18R0O0>JSXT4[9bE1;j[X@C>^:`4gL>f1=g5^0CH`KD3d[ba1<ffZ`C6[j@4`:NM1;ZQU`BgWY<4
]I^@0kBJS`BeVi04^9nE1;ZUW0BlZJ44^jVS0kVYX`BeYj84/:FP1:bQWPBXWi`4ZJ>O1;6^Z@>g]K44
^kZf1;^k^@Bl_[`4_/701<?6a@?7blX4b]3?1<cDd`C=emH4cm[J1=GPh0CPj>L3kO;`1>ogmPCaool4
jo[j1=OVi`C7e]P3]lO:1:Vi_0BK[:l4SYnS186BU`AdQX/4J7Z05Oooo`005?ooo`AMKG84GVaa161[
K`AQJfh4HVU/0fAXJPAUIfP4IVEU16ERH@AeL6h4R81l0iZ>R@B/W9D4_Z^Q1<jh[0CM`kH4gLFh1=S1
]@?B_;44cKJ[1<J_Y0C0Yid4^Z6G1;NNT`BeVi03]9Z?1;FKT0BhWiD4^ZFL1;bYX@BkZJ<3^JVS1;FW
XPB`YJ04[:6N1:ROW0BYXil4/JjY0kNe/@Bk^[H4^k^i1;bn_0Bn`L04`lK50lO;bPC:d<l4c=CC1<gG
ePC?f]X4eN3P1>3Xi`?]l_04koOf1?7oo`C[n_X4enKW1<OFf0>galX4ZKVl19^/[`B>Wj<4PI:G17B6
R`AXNX0Eoooo000Doooo15e]LPANK744H6]_165[KPARJF`3I6QZ16EWJ0AVIFD4IF9Q17E`KPB8P7`3
VXj91:bLU@BnZj44c[R/1=g3]PCMaKP4f<6e0m:l/@C=]Z/4aZnT1<2WW@BjXIL4]ijC1;FKT0>dVXl4
]I^@1;ROU@BjYI`4_:VQ1;^YX`>iZJ<4]JNR1;2UX0B/XIh4Z9nL1:VSW`Ba[ZT3]kFa1;^j]PBk^kT4
_;jl1;k1`0C3a/D3al_:1<[@c`C<e=<4cMOF1<oJfPCEh>04h>SW0ngbl0C_moH4lOoo1>_jnPCGi^L4
amKH0kO7bPBY^K`4Vjb_18jOX`B1TYL4M8J;16QjP1Goool001Coool4GFeb15i/L@APJfl4HF]^169Y
K0=TJ6X4IFMX16IUI@AUHV44MG1^18R0O0>JSXT4[9bE1;j[X@C>^:`4gL>f1=g5^0CH`KD3d[ba1<ff
Z`C6[j@4`:NM1;ZQU`BgWY<4]I^@0kBJS`BeVi04^9nE1;ZUW0BlZJ44^jVS0kVYX`BeYj84/:FP1:bQ
WPBXWi`4ZJ>O1;6^Z@>g]K44^kZf1;^k^@Bl_[`4_/701<?6a@?7blX4b]3?1<cDd`C=emH4cm[J1=GP
h0CPj>L3kO;`1>ogmPCaool4jo[j1=OVi`C7e]P3]lO:1:Vi_0BK[:l4SYnS186BU`AdQX/4J7Z05Ooo
o`005?ooo`ALK784GFY_15iYK@ANIf/4GfIX0emTI@AOHF84GeiO15iKFPA]IfD4OWIb0i66P0BSU8d4
]jBK1<^dZ0CJ`K<4g/Fg1=[3]P?F_[<4d;Z^1<^dZ@C6[Z<4`ZVN1;nUVPBmXiL3_::G1;bSU`BmYIT4
_JNM1;fZXPBlZZ<3^ZZT1;NZY0BcZ:84[jFP1:ZRWPBUX9`4Y::N0jRXY0Bc/Jh4_;^g1<71_@C3a<44
a/S50lS;b@C9c/`4bM3?1<_CdPC;eMD4eMgM1>7Wi@?_lNd4m?Od1?3in0C]n?L4f^OW1<WGf0>ialT4
Z[Vl19b/[`B>Wj<4PI:G17F6R`AXNX0Eoooo000Doooo15a/LPAMJVl4GVU]15iWJ`AOIVP3GfAU15mQ
HPAOGUl4GU]J16eWI@AnMW83THJ01:>DS@BgY9/4bkBX1=[1/`CNaKL4f/>f0mJn/`C@^Zh4bkBY1<J^
X`C2ZIh4_jFJ1;fSU`>lXYL4_:>G1;fUV@BmYid4_JZR1;bZX`>jZZ@4]jZT1;>XXPB_YJ04ZZ:N1:FP
W0BTXYh3Z:RT1;>a[PBl^kL4`L6m1<?4`@C6b<D3b<_91<W>c0C9d<l4bm?B1<_Ee@CEgMd4hNOU0noa
k@Cdmo@4l?Wh1>ghm`CJinL4bMOH0kW7b@BZ^K`4W:b_18jOX`B1TYL4MHJ;16QjP1Goool001Coool4
G6ab15eZK`ANJFd4GVM[15mVJ0=OI6D4Gf5R15mNG`ANFeX4KFMU17ifLP>AQX04XiB=1;NTV`C;]:P4
f/6c1=k5]`CJ`kH3e[jc1=2j[PC;]:T4aZjS1<:YWPBoYIX4_J>G0kbRU`BlXiL4_JFI1;fWW@BmZZ84
_:ZS0kZZY0BgZZ@4/jRR1:nUX0BZXYh4YJ2L1:BRWP>XZ:@4/k6^1;bk]`C1`Kd4`lC11<K8a@?8blT4
bLk<1<W@c`C;dm84bmGE1=GMg@CQinD3ko7]1?Cgm0C`nOP4kOSg1=[Wi`C9emP3^LO91:Zi_0BL[:l4
SYnS186BU`AeQX/4J7Z05Oooo`005?ooo`ALK784GFY_15iYK@ANIf/4GfIX0emTI@AOHF84GeiO15iK
FPA]IfD4OWIb0i66P0BSU8d4]jBK1<^dZ0CJ`K<4g/Fg1=[3]P?F_[<4d;Z^1<^dZ@C6[Z<4`ZVN1;nU
VPBmXiL3_::G1;bSU`BmYIT4_JNM1;fZXPBlZZ<3^ZZT1;NZY0BcZ:84[jFP1:ZRWPBUX9`4Y::N0jRX
Y0Bc/Jh4_;^g1<71_@C3a<44a/S50lS;b@C9c/`4bM3?1<_CdPC;eMD4eMgM1>7Wi@?_lNd4m?Od1?3i
n0C]n?L4f^OW1<WGf0>ialT4Z[Vl19b/[`B>Wj<4PI:G17F6R`AXNX0Eoooo000Doooo15a[L@ALJFh4
FfM[15]TJ0AKHVD3FemQ15YLG@AIFET4EeED16APG`AdKVX3RGii19b>Q`BaWiD4a[2S1=Rn/0COa[L4
g/Fh0mW2]PCD_[84d;Z^1<beZPC8/JH4aJfR1<B[W`?2ZYh4`ZVM1<:ZW`C1Zj04`JfS1;n]Y@>m[JD4
^jbU1;R[Y@BdZZD4/:RS1:^VXPBYYJ83YjJS1:RXYPB/[J/4/kBb1;Rk^@Bm`;h3_l?11<C9a`C7cL/4
bM3?1<WAd@CBf]P4gN;P0nSYiPCal>d4lOGb1>kfm0CLi^D4bmKF0k[7b0B[^;X4W:^^18nNXPB1TYH4
MHF;16QjOaGoool001Coool4G6]a15aYKPAKIf/4FfAX15]RI@=KGf44FUaM15UIF@AGEE@4I61O17A^
JP>9OWT4W8j71;6OU@C6/:<4f;j`1=o6]`CNaKP3fL:f1=Bn/PC@^Zh4c;FZ1<RaYPC5[J84a:^O0l:Z
WPC2ZId4`ZZO1<6[X0C1[J<4_jfU0kf]Y@Bk[:D4^:^U1;BZY@B`Z:<4ZjJR1:VUXP>WYZ<4Z:RV1:b]
Z`Bc];84^;^i1;g0_P>o`l44a<W71<O=b`C9d<l4bM7A1=;Jf0CMh^03j>WV1?7`k@CamO84k_Kd1=cV
i@C;e]H3^/O81:^h^PBLZjh4SijR186BUPAeQH/4J7Yo5Oooo`005?ooo`ALJg44G6U^15]WJ`AKI6P4
Ff9U0e]OH@AJG5d4FEUI15MEE0ATH5l4M6iZ0hUnN@BLSXL4/InE1<J`X`CH_[04glJg1=k5^0?I`[H4
e;jb1=2j[PC<]JX4b;6V1<F]XPC4Zil3`ZZN1<:YW@C2ZYl4`J^P1<6]X`Bo[JD3_JfU1;^/Y@BhZjD4
]:ZU1;2XX`B[YZ84ZJFR0jNVX`BXZ:H4[:f[1;>d/PBh^kT4_L2n0ko3`@C4bLL4alg;1<W@c`C9dM44
d][H1=gRh0?XjNH4lO3]1?7elPC^m_@4g>KU1<_FeP>jalP4ZkRj19b[[PB?WZ84PI:F17F5R`AXNWlE
oooo000Doooo15a[L@ALJFh4FfM[15]TJ0AKHVD3FemQ15YLG@AIFET4EeED16APG`AdKVX3RGii19b>
Q`BaWiD4a[2S1=Rn/0COa[L4g/Fh0mW2]PCD_[84d;Z^1<beZPC8/JH4aJfR1<B[W`?2ZYh4`ZVM1<:Z
W`C1Zj04`JfS1;n]Y@>m[JD4^jbU1;R[Y@BdZZD4/:RS1:^VXPBYYJ83YjJS1:RXYPB/[J/4/kBb1;Rk
^@Bm`;h3_l?11<C9a`C7cL/4bM3?1<WAd@CBf]P4gN;P0nSYiPCal>d4lOGb1>kfm0CLi^D4bmKF0k[7
b0B[^;X4W:^^18nNXPB1TYH4MHF;16QjOaGoool001Coool4Ff]`15YXK@AIIFT4FF9U15QOH@=FFed4
EEQI15=DE0ABD504H5aK16iXI@>1Mg84UXR01:^JT0C1Zil4eKb]1>36]`CPb;X3g<Fh1=S1]@CD_[84
dKZ^1<jgZ`C;]:T4b[:V0lRaY@S7/:@4a[2U1<FaY`C4/JL3`[6X1;naZ@Bm/:T4^JnX1;J]Z0Bb[:L4
[j^W0jf[Z0B][:T4[Jj[1:na[PBc]K<4^K^i0kg1_`C1aL@4a<W81<K=c0C9d<l4d=KD1=SMfP?Phn04
jN[W1>kak@C^m?84g^OV1<_Ee0>jaLH4Z[Nh19bY[0B>WJ04PI6E17B5RPAXNGlEoooo000Doooo15][
L0AJJ6d4FFEY15URI@AHGf43EU]M15EHF@ACE5@4DU1@161LF`A^J6D3PGMb19J8P0B[VY04`J^O1=Fl
[@CPa[L4h<Rj0mc5^0CH`KD4e;jb1=6j[PC>]j/4bkBY1<ZbYP?8/JD8ak2T1<J`Y@C5/JL4a;6W0l:a
Z0Bo/JT4_K2Y1;V_Z0Bf[JP4/ZbW1:n[Y`>]ZjP4[JbY1:f^Z`B_/Jh4/kFc1;Vk^@>m`Kl4`LG41<C9
b0C6cL`4bM3?1=3Fe0CHgMX3h>?P1>WZi`C^lNd4k_Cb1=kWiPC;eM@3^/G61:Zg^0BLZJ`4SYfP186A
U@AdQHX4J7Uo5Oooo`005?ooo`AKJg04FVQ]15UUJ@AIHVD4F5mQ0eIKG@AEF5T4DeAD159@D0APG5/4
KVQU0h5gLPBFR804ZiZ@1<6[W`CE_:d4h<Jg1>38^P?LaKP4f<6e1=Bn/PCA^Zh4c[N[1<^dZ@C:/ZH3
b;6U2<N`Y0C6/:D4aK6W1<BaY`?2/JP4_k6Y1;f`Z@Bi[jP4]ZfX1;:/Y`B_ZjL3[J^X1:f/Z@B][Z/4
[k6^1;>e/`Bi^kT3_L6o1<75a0C4bLP4a/g<1<W@c`C@e]@4f=gJ0n3Sh0CYj^L4k_7]1>kdlPCNinH4
bmGD0k[5aPBZ]kP4W:V/18jMX0B1TID4M8F:16QiOaGoool001Coool4FVY`15UWJ`AGHfL4EUmS15AK
GP=BEeT4DE=D14i?C`A<BTX4FUID16QRGP=jL6/4SX1i1:JCR@BlYIT4d;NX1=o4]@CSb[/3glRj1=_5
^0CH`[H4eL2d1=>l/0CA^Zh4ckR]0ljgZ`C=]ZX4c;FY1<^eZ@C:]J/4bKF[0lNe[0C5]J`4`[F]1;nd
[0Bl/Z`4^K6[1;JaZ`>d/J`4/k6/1;Bb[PBe]K44]kRe1;^l^@>o`;h4`/C21<C7a@C5b/P4bLk<1<oC
d@CFf=D3gMkJ1>?Th0CYj^D4jNcY1=cSh@C9dM03^<;21:Vd]@BJYjX4SI^N182@T`AdQ8T4J7Uo5Ooo
o`005?ooo`AJJW04FFM[15MSI`AFGf<4E5]N0e9GF@AADe@4CTm?14a:BPAJEU@4J69N0gY`J`B>P7T4
YY>91;bUV@C@]jP4glBe1>?:^`?Ob;X4flFh1=S2]PCE`;@4dkb`1=6j[PC?^:d3c[N[1<ffZPC<]JT4
bkFY1<ZeZ`C9]J/3akF/1<Fe[0C2]Jd4_kB/1;bb[0Bi/J/4][6[0kBa[0Bc/J`4];:^1;Fe/@Bg^;D4
^kbi0ko0_PC2a<84a<O51<G:b0C9c/`4cm?A1=KHe@?Mg]X4hnCP1>WZi@CYk>T4g>?Q1<WAd0>h`/84
ZKBe19ZWZPB=Vih4P92C17B4R@AXNGlEoooo000Doooo15YZL0AIIf/4Ef=W15IOH`ADFeh3DUMI155C
E0A>Cdl4C4Y:15YFE0AXHUh3NW1[18j0N@BVThT4_:FI1=2gZ0COa;D4hlZk0mo8^PCKaKP4f<:f1=G0
]0CC_;04dKZ^1<nh[@?>]j/4cKJZ1<beZ@C;]JT4b[F[1<VeZ`?7]J`4aKF/1<:e[@Bo]:`4_;:/1;Va
Z`Bf/J/3];6/1;>a[0Bd/Zh4]KFa1;Nh]@Bk_;T3_l2n1<;4`PC4alD4aL[81<W>c0C?dm44e]SE0mgN
fPCSi>04jN[U1>W/j@CLhn44bM7@0kS2`PBY];D4VZNZ18fKWPB0T9<4M8B916QiOaGoool001Coool4
FVY`15UWJ`AGHfL4EUmS15AKGP=BEeT4DE=D14i?C`A<BTX4FUID16QRGP=jL6/4SX1i1:JCR@BlYIT4
d;NX1=o4]@CSb[/3glRj1=_5^0CH`[H4eL2d1=>l/0CA^Zh4ckR]0ljgZ`C=]ZX4c;FY1<^eZ@C:]J/4
bKF[0lNe[0C5]J`4`[F]1;nd[0Bl/Z`4^K6[1;JaZ`>d/J`4/k6/1;Bb[PBe]K44]kRe1;^l^@>o`;h4
`/C21<C7a@C5b/P4bLk<1<oCd@CFf=D3gMkJ1>?Th0CYj^D4jNcY1=cSh@C9dM03^<;21:Vd]@BJYjX4
SI^N182@T`AdQ8T4J7Uo5Oooo`005?ooo`AJJVl4F6EZ15IQI@ACGF04DEQK0dmDEPA<Ce04BTY:14I5
A0ADDDl4HeaI0g=YI0B6NG44W8^11;:MT@C7[Z04f;f]1>;8^0?QbK/4g/Rj1=_6^@CIa;P4el:f1=Jo
/`CD_[43dkb_1=:k[`CA^jh4d;Z^1<nj[PC>^Zl3c;Z`1<Zj/0C8^K04aKV`1<>h/0Bo]k04_;J_0k^f
/0Bi][44^KNb1;Zh]0Bk^kH4_;fi0kk0_@Bo`l04`LG31<;7a@C5b/P4blo<1=7Dd0?Ff=@4fmcH1>3P
f`CPhMd4e]_H1<C;b@>d_Kd4Y[6b19RUY`B<VI`4OhjB17>3R0AWN7hEoooo000Doooo15YZK`AHIFX4
EV5U15=MH0AAF5/3CeAF14a?D0A:BTX4ATE415AAC`ASG5T3LfUT18IiL@BLRh44/YfA1<N^X0CH_Jd4
h/Rh0n79^`CNb;X4flJi1=W4^0CG`[H4e[nc1=Bn/@?C_:l4d[^_1=6k[PC@^Zh4ckZ^1<jj[`?<^[04
b[Z`1<Ri/0C5^K04`kR`1;ng/0Bl]Zl3^kJ`1;Vf/@Bi]k84^[Rd1;^k]PBl_KT3_/2m1;o3`0C1aL<4
`/O51<G:b0C;cl`4dMC@0mKHe0CKg=P4h>3K1>3Qg@CFfmP4a<_90kBm_@BV/K84V:FW18bIW0AoSY84
Lh>816MhOQGoool001Coool4FVY_15QUJPAFHFD4DeeP155HF`=?E5H4C4m@14Y:BPA6AD@4E55?16=L
F@=cJF@4QWUa19b;P@BbWI44ajjP1=Rm[@CRb;P3hLVk1=k8^PCKa[T4fLBh1=O2]PCF_k<4e;ja0m>l
[`CB^jl4dK^^1=2j[PC?^Zh4c[Z_0lbj/0C:^[04b;V`1<Fi/0C3^;04_kN`1;bf[`>k][04^KJa1;Vg
/PBj^;@4^k^f1;bm^@>n`;d4_l?01<75``C2alD4aL[81<_?c0CAe=03e]SD1=_Lf0CPh=/4h>7M1=KK
f0C4blT3];fm1:Ja/PBHYJL4S9VL17n>TPAcPhP4IgQn5Oooo`005?ooo`AJJVl4F6EZ15IQI@ACGF04
DEQK0dmDEPA<Ce04BTY:14I5A0ADDDl4HeaI0g=YI0B6NG44W8^11;:MT@C7[Z04f;f]1>;8^0?QbK/4
g/Rj1=_6^@CIa;P4el:f1=Jo/`CD_[43dkb_1=:k[`CA^jh4d;Z^1<nj[PC>^Zl3c;Z`1<Zj/0C8^K04
aKV`1<>h/0Bo]k04_;J_0k^f/0Bi][44^KNb1;Zh]0Bk^kH4_;fi0kk0_@Bo`l04`LG31<;7a@C5b/P4
blo<1=7Dd0?Ff=@4fmcH1>3Pf`CPhMd4e]_H1<C;b@>d_Kd4Y[6b19RUY`B<VI`4OhjB17>3R0AWN7hE
oooo000Doooo15UYK`AFI6T4E5mT155JGPA>EEP3Be1B14Q;C0A5ATH4@T0o14m;B@AMEe<3KF=N17mb
JPBDPgX4ZiJ:1<2XVPCA]jP4g/>d0n;9^`CPbK`4g/Rk1=g7^`CKakX4f/Fi1=W3]P?H`K@4f<2c1=O0
/`CF_k<4e;nb1=>n/`?B_[@4d;nd1<jo]@C;_[@4b;fd1<Fl/`C2^[<3`KZc1;nj]0Bn^kD4_[^f1;jm
^0Bn_[X3_l2l1<32_`C0`l04`<C21<C8a@C7b/L4c<k:0loAc@CCe=04emOB1=GFdPC9cLX4_L?10jnh
]`BR[:d4UZ6S18ZGV@AnS904LX:716MhOAGoool001Coool4FFU_15ITJ@ADGf@4DEYN14iEF0=;D584
B4]<14E6APA2@3l4Cd]915eGD`=]Heh4Og9Z19B3NPB[UXX4`:RJ1=6gZ0CN`k@3h/Vk1>39_0CNb;/4
gLNk1=_7^PCJaKT4fL>f0mS1]0CH`;<4el2c1=Jo/`CD_k84dkjc0m:n]0C@_k@4c[ne1<^n]0C8_K@4
aKbc1<:j/`?1^[<4_kZd1;jk]@Bn^kH4_[fh1;jn^P>o`;`4`<:o1<33`0C0a<84a<S51<O:a`C<c/X3
cm7=1=?Dd0CGem84eMKB1<W=bPBm`l43[kRg1::/[@BFXJ<4RYNI17j<T0AbPXL4IgQm5Oooo`005?oo
o`AIJFl4EVAY15AOI0AAFUh4CUEH0d]@DPA8Bd`4ADI61490?`A?BdT4GEMC0feSGPAoLVX4U8=j1:^F
RPC0Z9X4dKNX1=k3]0?RbK/4h<Vl1=k8^`CMak/4flNj1=[5^@CI`kH3f<6d1=S0/`CG`;<4e[nc1=Bo
/PCC_[<3d[jd1=2o]0C>_kD4bkjd1<Rm]0C5_;<4`[Zc0l6j/`Bo^[@4_[^e1;jk]PBn_KP4_[jj0ko0
_0C0`[l4`<?01<34`PC4b<D4al[71<c>bP??dLd4dmC@1=OGdPCEe]84bLg:1;g3`@>_^;L4XZb]19JQ
X`B:UiT4OXb@17:2Q`AWN7dEoooo000Doooo15UYK`AFI6T4E5mT155JGPA>EEP3Be1B14Q;C0A5ATH4
@T0o14m;B@AMEe<3KF=N17mbJPBDPgX4ZiJ:1<2XVPCA]jP4g/>d0n;9^`CPbK`4g/Rk1=g7^`CKakX4
f/Fi1=W3]P?H`K@4f<2c1=O0/`CF_k<4e;nb1=>n/`?B_[@4d;nd1<jo]@C;_[@4b;fd1<Fl/`C2^[<3
`KZc1;nj]0Bn^kD4_[^f1;jm^0Bn_[X3_l2l1<32_`C0`l04`<C21<C8a@C7b/L4c<k:0loAc@CCe=04
emOB1=GFdPC9cLX4_L?10jnh]`BR[:d4UZ6S18ZGV@AnS904LX:716MhOAGoool001Coool4FFQ^15ES
J0ABGV84CeQL14]BE@=7CDl4A4M81412@P@m?3`4BdM515QBC`=WGUT4N6]T18]lLPBRSH84^J2B1<fa
X@CJ_Zd3hLNg1>;:^`CQb[`4h<Zl2=o9_@CNb;/3gLNj1=g6^0SLaKP4flFh1=W4^0?Ga;P4e/>h1=C3
^0CA`[P4c/2g1<^o]`C8_[H3a[jf1<Bn]PC3_KH4`Kfg1<2m^0C0_kT3`;nk1;o0_0Bn`;d4_l:n1<33
`0C3aL84a/O40l[:aPC=cLT4d=3;1=7CcPC3a/<4][bj0jZb/@BNZ:T4TijP18NDU`AlRXh4LH6516Ig
OAGoool001Coool4FFQ^15ESJ0ABGV84CeQL14]BE@=7CDl4A4M81412@P@m?3`4BdM515QBC`=WGUT4
N6]T18]lLPBRSH84^J2B1<faX@CJ_Zd3hLNg1>;:^`CQb[`4h<Zl2=o9_@CNb;/3gLNj1=g6^0SLaKP4
flFh1=W4^0?Ga;P4e/>h1=C3^0CA`[P4c/2g1<^o]`C8_[H3a[jf1<Bn]PC3_KH4`Kfg1<2m^0C0_kT3
`;nk1;o0_0Bn`;d4_l:n1<33`0C3aL84a/O40l[:aPC=cLT4d=3;1=7CcPC3a/<4][bj0jZb/@BNZ:T4
TijP18NDU`AlRXh4LH6516IgOAGoool001Coool4FFQ^15ESJ0ABGV84CeQL14]BE@=7CDl4A4M81412
@P@m?3`4BdM515QBC`=WGUT4N6]T18]lLPBRSH84^J2B1<faX@CJ_Zd3hLNg1>;:^`CQb[`4h<Zl2=o9
_@CNb;/3gLNj1=g6^0SLaKP4flFh1=W4^0?Ga;P4e/>h1=C3^0CA`[P4c/2g1<^o]`C8_[H3a[jf1<Bn
]PC3_KH4`Kfg1<2m^0C0_kT3`;nk1;o0_0Bn`;d4_l:n1<33`0C3aL84a/O40l[:aPC=cLT4d=3;1=7C
cPC3a/<4][bj0jZb/@BNZ:T4TijP18NDU`AlRXh4LH6516IgOAGoool001Coool4FFQ^15ESJ0ABGV84
CeQL14]BE@=7CDl4A4M81412@P@m?3`4BdM515QBC`=WGUT4N6]T18]lLPBRSH84^J2B1<faX@CJ_Zd3
hLNg1>;:^`CQb[`4h<Zl2=o9_@CNb;/3gLNj1=g6^0SLaKP4flFh1=W4^0?Ga;P4e/>h1=C3^0CA`[P4
c/2g1<^o]`C8_[H3a[jf1<Bn]PC3_KH4`Kfg1<2m^0C0_kT3`;nk1;o0_0Bn`;d4_l:n1<33`0C3aL84
a/O40l[:aPC=cLT4d=3;1=7CcPC3a/<4][bj0jZb/@BNZ:T4TijP18NDU`AlRXh4LH6516IgOAGoool0
01Coool4F6Q^15ARI`A@G604C5IJ14Q@D`=4BD/4?d9413Xk?0@f=SD4A44o155<B@=PF5<4KfAM18=d
J`BIQW/4[iR:1<JZVPCG^JP3hLJe1>C;^`CTc;d4hlbn1>?=_`SScL03h/g01>;<_PCRbkh4h/^m1>7:
_@CPbK`3g/Zm1=g9_@CJb;`4elJk1=C5^PC@a;X4cL:i0l[0^0C8`;P4a/2h1<C0^0C3_kT4`[ni0l:o
^PC1`;/4_knj1;o0^`Bo`;`4`L:m1<?4_`?6a/04bLS21<W8``C8b/D4^knl1;2e]0>U[:`4VZ>T18nJ
W0B5TI@4NXR<171oQ0AVMg`Eoooo000Doooo15QXKPADHVL4D5aP14aFFPA8D5<3A4U;13m2A0@j>c`4
=SHe14A1?`AAC4T3H5QC16mTG@B3M6/4VHIk1:nHRPC6ZYX4ekVX0n76]@CTbk/4i<bm1>?<_PCScKl8
hlg00n;=`0CRc;h4h/^n1>;;_@CQb[d4h<Vl0mk:_@CMbKd4f/Rl1=O6^`CDaKX4d<Bj1<g2^@?:`;P4
b<2h1<K0^0C4`;P4`kni1<:o^@?2_kX4`L2k1;no^PBo`;/4_l2l1<72_@C3a;l3a/K01<W8`PC9b<<4
b<[51;^o_0B`]K@3YJb/19ZSY0B?VY`4QI6D17Z8S0A`Oh@4IWMl5Oooo`005?ooo`AHJ6h4E69W151L
H0A<EUX4B51C0dA9B`@o@T@4>S/l13Hf=@A4@Cl4DDa90f1HD`A_I5d4PgA[19V6N`B_V8X4aZZJ1=Ni
Z0?Qa[D4i<^k1>C<_@CSc;h4hlfo2>?=`0?RcL04h/bn1>;;_PCRbkd4hLZm1>39_0?Nb[d4gLVm1=[8
_0CGa[/4e<Fj1=34^PC=`[T3b/2h1<S0^0C6`;P4a<2h1<>o^@C2_kT3`[nj1<70^`Bo_kX4_l2k1;o0
_0C1`[d4`lBo0lK6`0C9b<84bLS31<S:a@Bk_k`4/;Fd0jF/[0BJXj@4SiZL18FAU0AjR8`4L7n416Ig
O1Goool001Coool4F6Q]15=QIPA?Fel4BUAH14I=D0=1ATP4>cm013Hg>0@`;bl4?3Tg14Y5@P=IDD`4
JEiG17a]I@BAOg@4Yi231;jST`CA/j83h<:a1>G;^PCVcKd4ilk01>O@`PCWdL<4im740nSA``CXd<84
ilo11>O?`0CWcl44i/o10nG?`@CScl44hLfo1=k;_`CJb[h4e/Rm1=?6^`??a;X4c<>i1<[1^@C7`KT4
aL2i1<>o^@?2_kT4`;jh1;jl]`Bm_;L4_;bg1;bl^0Bn_KP3_knj1<70^`C0_kX4^[^f1;>f/`BY[jd3
WjNV19FOW`B<UYP4PXjA17R6RPA_OX<4IGIk5Oooo`005?ooo`AHJ6d4Df5V14mKG`A:E5P4ATe@0d56
B0@k?d04=SLh130_;`@l>CL4BTE20eUAC0AYGUL4O6eU195oM0BWT8<4_Z>C1=6cXP?P`[44iL^j1>K=
_@CWc/04im321>OA``CWdL@3j=731>S@`PCWcl44ilo01>O?`@CVcl43iLo11>??`@CQcKl4g/^o1=[:
_PCFb;d4dlJk0lo4^PC<`kT4b/6i1<O1^@C5`;T4`kni0l:o^@C0_[P4_[bg1;fl]`Bl_;L4_;bh1;jm
^0>o_kX4`L2k1<2o^PBj^kH4/kJc1:V_[@>OYjH4UInO18bFV0B2SY44N8J:16mnP`AUMW/Eoooo000D
oooo15QXK@ACHFH4Ce]O14YDF0A6CE03@DI813/o@0@f=cP4<2l_13`i=`A:AD83FE5<16UNE`AlKFD4
TGmd1:N@P`BnXi<4dK>R0n32/@CUbkX4i/fm1>O>`0CWd<84im731>OAa0?XdL<4j=321>O?`@CWcl04
ilo11>K?`@?Ucl44hlo11>7=_`CNbkl4f/Zn1=K8_@CCa[/3clBj1<c3^@C:`KT4al6i1<G0^@C3_kT3
`[ni1<2n^0Bn_;L4_Kbg1;bl]`Bl_;P4_[fh0kno^PC1`;/4`;nj1;Zk]PBc][<4ZJn]0inWYPBEWil4
S9JH18:>T@AhQXX4Kgj316EfNaGoool001Coool4F6Q]15=QIPA?Fel4BUAH14I=D0=1ATP4>cm013Hg
>0@`;bl4?3Tg14Y5@P=IDD`4JEiG17a]I@BAOg@4Yi231;jST`CA/j83h<:a1>G;^PCVcKd4ilk01>O@
`PCWdL<4im740nSA``CXd<84ilo11>O?`0CWcl44i/o10nG?`@CScl44hLfo1=k;_`CJb[h4e/Rm1=?6
^`??a;X4c<>i1<[1^@C7`KT4aL2i1<>o^@?2_kT4`;jh1;jl]`Bm_;L4_;bg1;bl^0Bn_KP3_knj1<70
^`C0_kX4^[^f1;>f/`BY[jd3WjNV19FOW`B<UYP4PXjA17R6RPA_OX<4IGIk5Oooo`005?ooo`AGIfd4
DV1U14iJGPA8DUH4@d]>0ci3AP@h>cd4<C<c12XY:@@d<Bl4@cdj0e5:A@APEU04LfEL18QfJ`BNR7/4
/iZ:1<R[VP?J^jT4iLRf1>S>_@CZd<04jm;21>_Ca0C/e<D3kMC51>kEa@C^e<D4kM?31>kDa0C]e<@3
k=C41>_Ca@CXd/@4iM321>3=`0CLc;l4f<Vn0mC7_0CAaK/4cL>i1<[1^0C6_kL4`kjf0l2l]PBn^k@4
_;Vc1;^h/`Bj^;84^;Nb1;Vh/P>k^K@4_K^f1<2o^PBd][84Zjn/1:>XY`>JXJ44TIZK18RCU0AoRhh4
MXB816emP@AUMG/Eoooo000Doooo15MWK@ABH6D4CUYN14QBEPA3Bdh3?T=613Pk?@@a<c<4:RTY13@a
;`A3?CX3DDY5161FD0AcIE`4R7I[19j8N`BcVXX4b:^J0mZkZ@CUb;H4j<jm1>[@`0C[d/84jm?41>cD
a@?]e<D4k]G51>kDa@C]dl<4k]C41>gDa0?/e<@4jm?51>SBa0CUd<84h<g01=c<_`CHbKh3e<Nl1=75
^`C=`kT4b/6h1<Jo]`C3_[H3`;bf1;jk]0Bl^K<4^kRc1;Zh/PBh]k84^KRb0k^i]0Bm^kH4`;nj1;Bf
/PB[[j`4XjRW0iZQX@BAVY/4R9>D17n;SPAfQ8P4KGf116EeNaGoool001Coool4EfM]159PI@A>FUh4
B59F14=;CP<n@dH4>3/m134c<`@Z:BT4=34_14<m>P=ABTD4H5I@17=UG0B8MV/4WXQk1;>JRPC8ZiX3
f[^Y1>G8]PCXc[d4j]301>_B`PC[dl@4k=C50ngDa@C^eLD4k]C51>gC``C^e<@4kMC40ncDa0C[dlD4
j=;41>G@`PCPcL04g<bo1=S9_P?Dak`4dLFk1<g3^@C:`KP4a[ng1<>n]P?0_;H4_[^d1;bi/`Bk^;<4
^[Rb1;Rg/PBi^;83^kVd1;fk]PC0_kX4];Jb1:^_[0BSZ:L3VZ6Q196JV`B8Ti@4Oh^>17J4R0A]OH44
IGEk5Oooo`005?ooo`AGIfd4DV1U14iJGPA8DUH4@d]>0ci3AP@h>cd4<C<c12XY:@@d<Bl4@cdj0e5:
A@APEU04LfEL18QfJ`BNR7/4/iZ:1<R[VP?J^jT4iLRf1>S>_@CZd<04jm;21>_Ca0C/e<D3kMC51>kE
a@C^e<D4kM?31>kDa0C]e<@3k=C41>_Ca@CXd/@4iM321>3=`0CLc;l4f<Vn0mC7_0CAaK/4cL>i1<[1
^0C6_kL4`kjf0l2l]PBn^k@4_;Vc1;^h/`Bj^;84^;Nb1;Vh/P>k^K@4_K^f1<2o^PBd][84Zjn/1:>X
Y`>JXJ44TIZK18RCU0AoRhh4MXB816emP@AUMG/Eoooo000Doooo15MWK@ABH6D4C5UM14MAE@A1BD`3
>d5313@h>P@];c049BDU12`Z:0@i=343BD4l15Q>A`AYG5@4OFeR199nLPBUSX04^In?0lnaX0CP`Jh4
j<^i1>_A_`C]e<<4kmK51?7GaP?bf<L4lmS71?CIa`Sdf<H4mMW70oCHa`Caf<L4k]O71>_Da@CVdL<4
h/k11=k<_`?Ib[d4e<Nk1=34^@C<`KL4aknf1<6k/`>n^K44^kJ_1;Nd[@Bf/jd4][>/1;Fb[0Bd/Z`3
]K:]1;Bc[PBg]k<4[Jj[1:BXY@BLXZ03U9bK18bEUPB4Si44O8R;17B2QPA/Nh04I7Ej5Oooo`005?oo
o`AGIfd4DV1U14aIG@A7DED4@DU<0c]1@`@d>3X4;Bl`12DU9@@/:RP4>C@a0dU1?0AHCTL4JEaD17e]
HPBBOW84YHj01;VOS`??/J04h<6^1>S;^@C[dKl4kMC31>oFa@CaelH3l]S71??Ha`CdfLL8m=S61?GI
a`?df<L4lMS71>kGa`C[e<D4i]731>;>`@CNc;l3fLZm1=C7^`C@a;T4c<6g1<No]PC1^k<3_[Va1;^f
[`Bg]:d4][>]1;Jc[0Be/Z`4];:/0kFb[@Bd/jh4]kNc1:f^Z`BTZ:D4W::P0iBLV`B<UIH4Q8nA17b8
R`AdPXH4K7^016AeNQGoool001Coool4EfM]159PI@A<FEd4Ae5E1459C0<k@D<4=3Pj12d_<0@U9BD4
;2XX13Td<@=9@C`4F4i716ULE0AmKF84TWib1:F>P0BiWhl3ck6P1>31[PCXbkT4jm6o1>gD``C_e/D4
lMO60o;Ha`Ccf<L4m=W72?CHaPCefLL3m=S71?7Ha`C^elL4jmC51>KA``CRc/44g/bo0mW:_@CDak/4
d<Bi1<c1]`C7_kH4`K^c0kji/@Bk]Zl4]kB]1;Jc[@Bf/j`4]K:/1;Bb[0>e/Zd4];>^1;Ng/`B][Z/4
Y:RU19bRX0>DW9/4S9FF18B?T@AlR8/4M8:616akP0ATMGXEoooo000Doooo15MWK@ABH6D4C5UM14MA
E@A1BD`3>d5313@h>P@];c049BDU12`Z:0@i=343BD4l15Q>A`AYG5@4OFeR199nLPBUSX04^In?0lna
X0CP`Jh4j<^i1>_A_`C]e<<4kmK51?7GaP?bf<L4lmS71?CIa`Sdf<H4mMW70oCHa`Caf<L4k]O71>_D
a@CVdL<4h/k11=k<_`?Ib[d4e<Nk1=34^@C<`KL4aknf1<6k/`>n^K44^kJ_1;Nd[@Bf/jd4][>/1;Fb
[0Bd/Z`3]K:]1;Bc[PBg]k<4[Jj[1:BXY@BLXZ03U9bK18bEUPB4Si44O8R;17B2QPA/Nh04I7Ej5Ooo
o`005?ooo`AFIf`4DEmT14]HG0A6D5@4?dQ;0cTo@P@b=SP4:R`]120O7`@Q81h4;b`Y0chh=0A>A3l4
GE5:171RF@B5LfL4Uh9e1:^BP`>nXY44dkFR1>72[`C[cKT4k]?01?7F``CdfLH3mm_81?SLb@Cig<T4
nM_81?_Kb0ClgLX3nmg;1?WKbPCefLP4lMO61>cEa@CWdL84h/k00mc:_@CFak/4d<>g1<^o]0C6_;84
_kR_0kVcZ`Be/:T4/ZjW1;2/YPB^ZjD8[JZT0jj[Y@B]ZZ@4Z:RS1:>UXPBMXIl4UYbK0hnGUPB8TI84
PH^=17V6R0AbP8@4JgYn16=dNAGoool001Coool4EVM/155OI0A;F5`4AU1D13m8B`<i?d84<SHh12X/
;@@P7al48B0N12l/:@<n>3@4CT@o15eABPA`HUT4QG=W19N2M@B[TX<3_Z:A1=>eXPCQ`Zl4jlfi1>kC
`0Cae/<4m=W60oOKb0Chg<T4nMc91?WKb0CkflP4o=g:0o_Mb`CiflX4mMW81?7GaPC/eLD4im721>;>
`0?Lb[d4e/Nk1=33]`C;_k@4a[bb1;nh[`>i/j/4]K2Y1;:^Y`B`[:H4[Z^U2:fZY0>^ZjD4[JZT1:RX
X`BSYJ84WJ6O19JLV`>?UiH4R96B186;S@AiQXP4LX2416]jOPASM7TEoooo000Doooo15IWK0AAGf@4
BeQL14I@E0@oB4/3>Cm2138f>0@Z;2d481lO124P7P@_;2T3?SPd14i4?`AMDDX4L69I18EcI`BGPWD4
Zi:30kjRT@CC]J84hL:_1>_=^@C^dl04lMK31?CIaP?gflP4n=c91?WLb@CiflP4nm_81?cMbP?kgL/4
nM_:1?GIb0CaelH4k=G51>OA`PCRc/03g<Zm1=K7^`C@`kL4bknd1<Jl/PBo^:l3^K>[1;F`Z@Bb[ZL4
/:bV1:j[Y@R]ZZ@3[Z^U1:fZY0BXZ:<4XjFR19fQW`BFW9/3SiNF18RATPB1Rhd4NHJ817:0Q0A[NWh4
HgAi5Oooo`005?ooo`AFIf`4DEmT14]HG0A6D5@4?dQ;0cTo@P@b=SP4:R`]120O7`@Q81h4;b`Y0chh
=0A>A3l4GE5:171RF@B5LfL4Uh9e1:^BP`>nXY44dkFR1>72[`C[cKT4k]?01?7F``CdfLH3mm_81?SL
b@Cig<T4nM_81?_Kb0ClgLX3nmg;1?WKbPCefLP4lMO61>cEa@CWdL84h/k00mc:_@CFak/4d<>g1<^o
]0C6_;84_kR_0kVcZ`Be/:T4/ZjW1;2/YPB^ZjD8[JZT0jj[Y@B]ZZ@4Z:RS1:>UXPBMXIl4UYbK0hnG
UPB8TI84PH^=17V6R0AbP8@4JgYn16=dNAGoool001Coool4EVI/155OI0A;Ee`4ADmC13i7BP<g?T44
<3Df12PZ:`@N7Ql46QPG12DR80<e;b/4A3`g15A8@@AUEdh4NFQM18UfJPBKQGL3Zi>31;nTTPC@/Z04
gKn[1>S:]PC^dKd4mMO30oWKa`CkgLT4o=g91?cLb0Cmg<L4o]c80ooMb@CngLX4n]_91?KHaPC`eL@4
k=;11>K?`0?Obk`4f<Jh1=71]0C9_;04`[N/1;ZbZ0>d[JD4[jZR1:^WX0BXYIh4YZ>M1:BRW0BTXI`3
YJ:M1:VWX@BQXId4VifJ19JJV0B@UYD3RY6B18>=SPAmR8X4MX>6171nPPAYNGd4HW=i5Oooo`005?oo
o`AFIV`4DEmT14]GG0A5Ce<4?TM:0cLn@@@`=CH4:2X[11hN7`@J61L49B8P0cD_:`A4?3L4E4Q116EG
CPAiJ5d4RGIZ19^5M`>[Th<4_jBB1=2bX0CM_j/4j<Zf1>kA_@Ceel<3nM_71?_Mb@ClgLT4o=c81?gL
a`Cng<P3omg91?kMbPCjflT4m]S61?3Ea0C/d/44i/o00mo;_0CHa[P4dL6d1<Vl/0C2]j`4^[:X0kB]
Y@B_ZZ84ZjNP1:RUWPBVXid4Y::L1:BQW0>UXYd4ZJNQ1:6QW@BKWIX4UYZH192FU@>:TI84Phf>17f8
RPAfPhH4L7j216UiO@ARLgTEoooo000Doooo15IVK0AAGf@4BeML14E?D`@nAdX3=ci1130e=P@X:R/4
7QhO11XH5`@U8R03=Bl[14@l=`ADB444IEM>17UXG@B9MVX4VhEg0j^CP`BoY984d;:P1=foZ`CXb[H4
k]6m1?GG``?iflL4nmg91?cMb@Clg<P4oMc71?kLb0?ogLT4o]g:1?[Kb@Cff<H4l=G41>cB`@CVcl03
gl^l1=S6^0CA`K@4bKb`1<:g[0Bj/ZP3]:fU1:nZXPB[Yj04Z:FN1:JSW@BTXY`4Y:6L0jFRW@BYYj44
XJ6M19^MVPBFVYP4T9JE0hZATPB3SHh4OHR:17J3QPA`OX84JGUm169cNAGoool001Coool4EVI/155O
I0A;Ee`4ADmC13i7BP<g?T44<3Df12PZ:`@N7Ql46QPG12DR80<e;b/4A3`g15A8@@AUEdh4NFQM18Uf
JPBKQGL3Zi>31;nTTPC@/Z04gKn[1>S:]PC^dKd4mMO30oWKa`CkgLT4o=g91?cLb0Cmg<L4o]c80ooM
b@CngLX4n]_91?KHaPC`eL@4k=;11>K?`0?Obk`4f<Jh1=71]0C9_;04`[N/1;ZbZ0>d[JD4[jZR1:^W
X0BXYIh4YZ>M1:BRW0BTXI`3YJ:M1:VWX@BQXId4VifJ19JJV0B@UYD3RY6B18>=SPAmR8X4MX>6171n
PPAYNGd4HW=i5Oooo`005?ooo`AFIV`4D5mT14YGG0A4Ce<4?DM:0cHn@0@_=3H49bX[11hO80@E51@4
6QPF0bTU8P@h<Bd4Acdh15M;A0A[Fe84NfYO18]gJ`>KQGL4Zi>41;^QT@C:[Y`4e[VV1>32/0CXb[L3
km2l1?CE`0Cgel84mmK11?WF`0Cjel03o=S21?cIa0CkfL<4mmK21?;C`0C/ckd4i/^j0mo8^0CF`[@4
cKb_1<BeZPBl/:D4/jZQ0jfVW@BWXIX4XYjH19nLUPBLVY@4VYRB19VGTP>KV9<4W9^G19NIU@BCUY@4
Si>B18Z@T0>5SHd4OhV:17Z5Q`AdP8<4KWb016QgO0ARLgPEoooo000Doooo15IVK0A@Gf@4BUML14A?
D`@mAdX3=Si012ld=P@W:R/47QlP11DD50@J61H3:BDR13Pa;@A7?CP4Ed]416]KDPAkJUl4RgM[0i^5
M`B[Th@4^j6A1<Z^W0CF^JH4h<:`1>S:]`?_d;`4m=G01?OG`PCge/44nMK01?[G`0?lf<84o=W41?_I
``Cge/84l]?01>c?_@CVbkX3glRh1=K2]0C=_:l4a;FZ1;b`Y@BcZZ43[JJM1:NQVPBRWYP4WibF19bJ
U0BJV984VINB0i^HT`BLViL4UiVE19>FU0B?Ti84RY2@0hF=S@AoRHX4NXF717B0P`A^O804J7Ml169c
N1Goool001Coool4EVI/151OI0A:Ee`4A4mC13e7BP<f?T04;c@f12LZ:`@N7b045A@D11XH5P<Y9B84
>34]14Lm>0AGBd@4Je]B17]ZG`B;Mf/3VhEg1:^CQ0BkXI44bZjL1=JiYPCP`[04j<Zg0no@_0CdeL04
mmO21?OF`@Cie/04n]O00ocH`PClfL@4nmW31?OF`PCbdl04k<nm1>K;^P?Ob;P4e/:d1<fl[`C4]JX4
_;2U1;>ZX@>]YYd4Yj6J1::NV0BOW9H4W9ZD19ZHTPBIUi83ViRC19bKU`BGVID4TiJD18nCTPB:T903
QHf=17n9RPAjQHL4M82316ilP0AXMg`4HW=h5Oooo`005?ooo`AFIV`4D5mT14YGG0A4Ce<4?DM:0cHn
@@@_=3L49RX/11dO80@C4a@44A0?0ahK6@@/:2@4>c@_14U0>@AJCTH4K5eD17a[H0><NF`4W8Mi1:^D
Q@BhX904`ZZI1<bbX@CF^JL3g/2]1>G5/@CZb[D4jlZf1>g;]PC`cKL3llni1?C@^PCddK/4lLnj1>c<
^0CWbKH4h<Fc0mW1/0C@^j`4akFW1;b^XPBdZ9h4[::I0jBNU@BNVI84VIF?19FBS@BBT8X4Shj818j=
R0>@SXT4Shn;18j@S@B;Shd4R8f<18B;R`>0R8T4NhF717J2Q0AaOX44K7Yn16MfN`AQLWPEoooo000D
oooo15IVK0A@Gf@4BUML14A?D`@mAdX3=Si112ld=`@V:R`47AlP11<C50@A40l37Q/I12`X90@k=2l4
BD0i15Y>APA/GE@4O6]P0haiK0BLQgT4ZiB51;RPT0C2ZYT4c;:Q1=JiY`?N`:d4iLFa1>[:]@C[b[H4
kL^f1?3=]`?cckT4m=2j1?CA^`CackX4k<bh1>O9]PCPaK<3fL6`1=2k[0C7]JL4_:jR1;BXWPB/XYT3
Y9jE19jITPBIUHl4UI:=19:@RPB?SXP4SXf80i2>R@B?Sh/4SY2=18^?S@B8SH`4Q8^;0h28R@AkQHL4
MX:4175nP@A/NWh4IgIk165bN1Goool001Coool4EVI/151OI0A:Ee`4A4mC13e7BP<f?T44;c@g12HZ
;0@M7b044a<D114@3`<N6aT4;2PT13/d;`A9@3T4FTi616aME0AlJf03S7U/19b7N@B[U8D4^:2@1<:Z
V@C</Z44e[VW0mk0[@CUaK44j/Ze1>_:]PC]bkH4l<fg0o??^@Cdd;X4m=6k1?7?^PC/c;P4ilVf1>35
/`?I`K04d;^/1<NeY`Bl[Z84]:RN1:bRV@>TWYD4WYVB19VES`BETXd4TY2:18n>R0B>SHP3T8j918n?
R`B>T8d4Rhn=18R=S0B4Rh/3P8R917^5Q`AfPX@4LGj116ajOPAWMW/4HG9h5Oooo`005?ooo`AFIV`4
D5mT14YGG0A4Ce<4?DM:0cHn@@@_=3L49RX/11dO80@C4a@44A0?0ahK6@@/:2@4>c@_14U0>@AJCTH4
K5eD17a[H0><NF`4W8Mi1:^DQ@BhX904`ZZI1<bbX@CF^JL3g/2]1>G5/@CZb[D4jlZf1>g;]PC`cKL3
llni1?C@^PCddK/4lLnj1>c<^0CWbKH4h<Fc0mW1/0C@^j`4akFW1;b^XPBdZ9h4[::I0jBNU@BNVI84
VIF?19FBS@BBT8X4Shj818j=R0>@SXT4Shn;18j@S@B;Shd4R8f<18B;R`>0R8T4NhF717J2Q0AaOX44
K7Yn16MfN`AQLWPEoooo000Doooo15IVK0A@Gf@4BUML14A?E0@mAd/3=Si212le>0@W:bd47R4R11@E
5P@<2`/34Q0?124N6`@_:RH4?SHa14i4?@ANDDT4KV1F0ga[H@B;NFd4VHAg1:F?P0B`VHT4^J6A1<6X
U`?:[id4ck>Q1=JiYPCJ_:T4g;j[1=joZ`?Q`Jd4hl:^1>;2[PCP`Jd4g;n/1=RlZPCB^:L3bk>T1<:^
X0BjZId4/:>H1:RNU0BPV903VYB<19B@R@B?S8L4RhV418R7PPB5Q7l4Ph9n0hB4O`B6Qh@4QXV618B9
Q`B2R8L4OhJ70g^4Q@AgPX@4Lgn216mlO`AZN7d4IGEj165aMaGoool001Coool4EVI/151OI0A:Ee`4
A4mD13e7B`<f?T84;cDh12L[;@@N8B8451DF10`;2`<B40l48AhK12lZ9P@n=S44CT@m15iAB@A^H5H3
O6]Q18]iK@BIQ7L4YHn01;2IR@BiXI44`JRG0lZ_W@C?/j44e[VV1=ZlZ@CL_Z/4g[n[0n71[@CS`Zh4
h/:^1>31[@CL_j`4f;bZ1=:hY`?;/j@4`ZjP1;ZYW@B`XiP4Z9jD1:2HT0>JU8`4U92918n<Q`B;RH@4
R8N218F4O`B3PWh3Q8Ao18J7Q0B6RHH4Q8V718:8Q`AoQXL3NhB517N2Q0AcOh84Kgao16YhO@AUMGX4
HG5g5Oooo`005?ooo`AFIV`4D5mT14YGG0A4Ce@4?DM;0cHn@P@_=CP49b/]11hQ8P@D5AH430/;0a8@
3`@Q7Q/4;bXV13hf<@A>A3d4GU5916iPEP=lJf44RgU]19V4M`BUSh04/9V91;VQT@C1Z9L3bZnM1<nc
X@CF^JH4f[bY1=bnZ`CN_j/3hL6]1>?2[PCR`Zh4h<6]1=bo[0CH_:X4d[RW0l^cY0C2[Z04^ZVM1;2S
V0BXWY@4X9R@0iZDS0BDT8T4Shb718^9Q0B8Qh84QHAo18>2OP>4Q7l4QXN418J9QPB4RHL4PXR717n6
Q`=kQ8D4Mh:417=oPPA_O7l4JWQm16EeNPAQLGLEoooo000Doooo15IVK0A@Gf@4BUML14A?E0@mAd/3
=Si212le>0@W:bd47R4R11@E5P@<2`/34Q0?124N6`@_:RH4?SHa14i4?@ANDDT4KV1F0ga[H@B;NFd4
VHAg1:F?P0B`VHT4^J6A1<6XU`?:[id4ck>Q1=JiYPCJ_:T4g;j[1=joZ`?Q`Jd4hl:^1>;2[PCP`Jd4
g;n/1=RlZPCB^:L3bk>T1<:^X0BjZId4/:>H1:RNU0BPV903VYB<19B@R@B?S8L4RhV418R7PPB5Q7l4
Ph9n0hB4O`B6Qh@4QXV618B9Q`B2R8L4OhJ70g^4Q@AgPX@4Lgn216mlO`AZN7d4IGEj165aMaGoool0
01Coool4EVM]151OI@A:F5d4A51E13i8C0<g@4<4<3Lj12P]<0@O8bD45QPI10`<3@<:2PT45Q@C12@P
7@@b;2P4@SXd1515?`AMDDT3JUaC17YZG`B8Mf/4Th5e19j:O@BWTX@4[iV:0kRPT0BlY9@4`ZVH1<J/
V`C:[i`4c;2N0lfaW`S?/Z04cK6P1<V_WPC5[I`4`:VJ0kZUU`BbXI@4ZifA1:BHSPBLThX4U8j60hj:
P`B9QX04Ph9m181oN`AnOGT4NgYf17]kM`=nOg`4Oh9o17n3PPAnQ8<4O8>317Z2P`=gPH84M7n1171l
O`A/NWd4J7Mk16AdN@APLGLEoooo000Doooo15IWK@A@GfD4BUQM14A@E@@nB4`3=d13130g>P@X;C04
7b<U11HH6@@<30d32PX911HD4`@T81d4<R`X148j=0A@ACl4GE590fYLD`AjJUl4R7M[19>1M@BNRWd4
Yi:41:nIRP>hX904_:BD1<:YV0C6[9/4bZnL1<b`WP?=/Il8ck:P1<faX0C9[ih4aJfL1<2YVP>jYIL4
/Z6D1:^MT@BTV8h4W9>:19B>QP>>RX<4RHJ018>2O@B0Og/4OWei17]jMPAkNgL3OWml17n2O`AoPh84
OXB317b3P`AjPX<3Mh6217AoP@A`O7l4K7Ym16QgN`ATM7T4H75g5Oooo`005?ooo`AFIfd4D5mU14YH
G@A4D5D4?TQ<0cM0@`@`=cX4:2d`11lS9@@F61T430`=0`X:2@@F51<4920M138/:0A2>S@4D4Do15eA
B@=ZG5<4NVYO18QgJ`BCPGD4WXYm1:NBQ0B_VHX3^:2@1;bTU0C2ZIP4aZbK1<Z_W0C</9h3cK6O2<nb
X0C=/J04bJnN1<F]W0C0ZIX3^ZFG1;:QU0B[WI44Y9R>19bCRPBDSXH3SXZ318V6P0B3PWd4P7mk17im
N@AkNWH4Ng]g0gioO0AoPWl4Oh>217j4P`AlPh<4NX:30gN1PPAdOh44L7ao16ajO@AXMg/4I7Ai161a
MaGoool001Coool4EVM]151OI@A:F5d4A51E13i8C0<g@4<4<3Lj12P]<0@O8bD45QPI10`<3@<:2PT4
5Q@C12@P7@@b;2P4@SXd1515?`AMDDT3JUaC17YZG`B8Mf/4Th5e19j:O@BWTX@4[iV:0kRPT0BlY9@4
`ZVH1<J/V`C:[i`4c;2N0lfaW`S?/Z04cK6P1<V_WPC5[I`4`:VJ0kZUU`BbXI@4ZifA1:BHSPBLThX4
U8j60hj:P`B9QX04Ph9m181oN`AnOGT4NgYf17]kM`=nOg`4Oh9o17n3PPAnQ8<4O8>317Z2P`=gPH84
M7n1171lO`A/NWd4J7Mk16AdN@APLGLEoooo000Doooo15IWK@AAH6D4BeUN14EAEP@oBTh3>495134i
?0@Z<3848BHX11PK7@@>3Q031@@510`;2P@I5Q@49B4N13<]:@A1>C@4CdDo0eY@B0AWFe84MFMM181`
IPB:NVl4Th9f19Z9O0>RSh84ZIB71:jIRPBbW8d4]In?1;NQT0>iXY44^Z>B1;VSTPBhXY84/in@1:nL
SPBZVH/3YIF919nBQ`BJShD4UHb318n8P0B8Pgd3PWmi17ekM`AjNWH4NGUe17IfLPAeMG84MgQe0gQk
N@AiOG/4NGmn17UoO`AhOh04MWn00g=mO`AaO7h4KGYm16YhO0AWMWX4Hg=h15m`MQGoool001Coool4
EVM]155PI@A;FEh4AE5F13m:CP<h@TD4<CTl12X`<P@Q9RP461/M10h>40<510D430/:11TF50@U8Ah4
<bdY144i=0A?ACl3FU1816MKDPAeIed4P71V18YjK`BCPWH4VXUl0j:?PPBYU8L4[YV:1;:LS@BeWhl4
]j6@0kVRT@BjXi84^J>B1;RRTPBcWi04[ib>1:ZIR`>UUHT4Wi:719Z?Q@BES8<4ShR018R3O@>2OgT4
OG]g17YjMPAiNGD4MWIb17EeLPAgN7D3N7]i17UmN`AiOgh4NGmo17QoP0AfOh03Lgeo175lOPA]NWd4
JWQl16MfNPASLgP4Gg1f5Oooo`005?ooo`AFIfd4DF1U14]IGPA5DEH4?dY>0cQ2A@@a>C`4:S0b124V
:0@H6ad43Ph@0`D41@@<2`X46AHD12DQ7P@c;BT4@CTd14m5?`=JD4P4Ie]B17EWG@B0L6H4RWY_19>2
MPBJRG`3XXn21:VDQ`B^VHX4/Yb=1;FOS`BgXI03^J:A1;ZSTPBiXi84^::B1;>OT0B_W8h4ZYV;0jFE
R@BOTXL4VXn519F<P`B?R804R8=m0h9oN@AmNgL4NWYf17UiM@AfMW84MGEb17MhM@=hNgT4NGek17Uo
OPAiOgl4N7n017IoP0=cOGl4LGan16ejO@AZN7`4IgIj16=cN0AOL7HEoooo000Doooo15IWK@AAH6D4
BeUN14EAEP@oBTh3>495134i?0@Z<3848BHX11PK7@@>3Q031@@510`;2P@I5Q@49B4N13<]:@A1>C@4
CdDo0eY@B0AWFe84MFMM181`IPB:NVl4Th9f19Z9O0>RSh84ZIB71:jIRPBbW8d4]In?1;NQT0>iXY44
^Z>B1;VSTPBhXY84/in@1:nLSPBZVH/3YIF919nBQ`BJShD4UHb318n8P0B8Pgd3PWmi17ekM`AjNWH4
NGUe17IfLPAeMG84MgQe0gQkN@AiOG/4NGmn17UoO`AhOh04MWn00g=mO`AaO7h4KGYm16YhO0AWMWX4
Hg=h15m`MQGoool001Coool4EfM]155QIPA<FUl4AU=H141<D0<jA4P4<c`o12`c=P@T:R`46alQ118D
5@<51PH40@4110/:2@@I5Q@49R8O13<]:P@o>3<3BD4k15A;A0APETh4JUmG17IYH0AoLFP4QWQ^0hen
L`BDPgT4V8Ml19^:OPBOSX44XY230j>AQ0BTThD4Xi:51:6AQ0BLSX84VXb019F9OP>@QW`4Rh=j18N0
N@B2OGL4OGYd17QfL@=dM6l4LG5]16e_K0A]KV`8LG=`179eL`=dN7H4M7Yi17EkN`AdO7`4Lgam179l
O@=`Ngd4KWYl16]hN`AXMWX4IGAi169bM`AOL7HEoooo000Doooo15MWK@AAHFH4C5YO14ICF0A0C503
>TA813<l?`@/<cH492X/11/O8@@B51D31@H610410@@;2PT46AHD12HR7`@c;BX4?cPc0dU1>`ADBd@4
H5I>16YOE`AfJF04Og5X18IhKP>=OW<4U8=i19R7O0BKRWh4Whj11::@P`>STH@4Y9>51:>BQ@BQTH@4
W8j219Z<P0BERGh3T8Il18^3NPB7P7T4PWeg17ejM0AhMW43M7A_175aK@A]Kf`4KFi/275cL0AbMG<3
M7Qf17AjN@AeNg/4M7al17=lO@AbO7d3L7]m16ijO0A[N7/4J7Ij16EdN@ARLWL4Gg1f5Oooo`005?oo
o`AGIfd4DF5V14aJG`A6DeP4@4a@0cY4B0@c?3l4;3<f12@Z;0@K7b444Q@E0`D61P@10@442`X911TF
50@V8Ql4<bdZ13lh<`=9@C/4E4]4161FCPAZGeL4MVUP17maJ0B6N6h3SGic19B3N@BHQg`4VhYn19n>
P@BRT8<3Xi641:BCQ@BSTXD4XI6419b>PPBJS804UHUn0i26O0B;PgX4Qh1i189mM`AmNW@4N7Ia0gAd
K`AaLFd4KFm/16e^K0QaLg04LWEc0gAhMPAdNWT4MG]k17AlO0AcO7d4LWam0g1kO@A^NW`4JgQk16Qf
NPAUM7T4HW9g15m`MQGoool001Coool4EfQ^159RI`A=Ff44AeEJ149>DP<lAd/4=Sm312lg>P@X;S44
82DW11LJ70<=3a040P<3100000@:2PT461LE12DS80@`;2T3>C@a148l=`A<AD04EDi8161HD0AYH5P4
L6IO0gI/I0AlL6P4PGE]18IjL0B:OG<4SH1e0hj2M`B@PgP4T8=i18n2N0B9OgD4PgYa17mhK`=lMfl4
N7A^17=aK0A`Kf/4KViZ16]/J0=WJFH<IfQU16U[J0A/Kfd4KW9a0fmeM0A`MWH4L7Qh171iNPA_NGX4
KWUk0fehN`A[Mg/4JGIj16IeN@ATLgP4HG5g15m`MQGoool001Coool4EfQ^159RI`A=Ff44AeEJ149>
DP<lAd/4=Sm312lg>P@X;S4482DW11LJ70<=3a040P<3100000@:2PT461LE12DS80@`;2T3>C@a148l
=`A<AD04EDi8161HD0AYH5P4L6IO0gI/I0AlL6P4PGE]18IjL0B:OG<4SH1e0hj2M`B@PgP4T8=i18n2
N0B9OgD4PgYa17mhK`=lMfl4N7A^17=aK0A`Kf/4KViZ16]/J0=WJFH<IfQU16U[J0A/Kfd4KW9a0fme
M0A`MWH4L7Qh171iNPA_NGX4KWUk0fehN`A[Mg/4JGIj16IeN@ATLgP4HG5g15m`MQGoool001Coool4
EfQ^159RI`A=Ff44AeEJ149>DP<lAd/4=Sm312lg>P@X;S4482DW11LJ70<=3a040P<3100000@:2PT4
61LE12DS80@`;2T3>C@a148l=`A<AD04EDi8161HD0AYH5P4L6IO0gI/I0AlL6P4PGE]18IjL0B:OG<4
SH1e0hj2M`B@PgP4T8=i18n2N0B9OgD4PgYa17mhK`=lMfl4N7A^17=aK0A`Kf/4KViZ16]/J0=WJFH<
IfQU16U[J0A/Kfd4KW9a0fmeM0A`MWH4L7Qh171iNPA_NGX4KWUk0fehN`A[Mg/4JGIj16IeN@ATLgP4
HG5g15m`MQGoool001Coool4EfQ^159RI`A=Ff44AeEJ149>DP<lAd/4=Sm312lg>P@X;S4482DW11LJ
70<=3a040P<3100000@:2PT461LE12DS80@`;2T3>C@a148l=`A<AD04EDi8161HD0AYH5P4L6IO0gI/
I0AlL6P4PGE]18IjL0B:OG<4SH1e0hj2M`B@PgP4T8=i18n2N0B9OgD4PgYa17mhK`=lMfl4N7A^17=a
K0A`Kf/4KViZ16]/J0=WJFH<IfQU16U[J0A/Kfd4KW9a0fmeM0A`MWH4L7Qh171iNPA_NGX4KWUk0feh
N`A[Mg/4JGIj16IeN@ATLgP4HG5g15m`MQGoool001Coool4EfQ^15=SJ0A>GF84BEML14AAE@<oBTh4
>D=713<l?`@/=3L49B/^11dR90<E61X430h?10830`@00@442P/;11PH5P@T8b43;BXX13<`;@@j=c@4
@Sll14Y7@`ADCdX4FeI@0f9LEPAWHE/4K6EO175YHPAdKFD4Mg1X0gYbJPAkM6/4OGI]17aeKPAjM6d4
MW9[16m/I`=YJ6@4IfMS16AUHPASIF84HVAR165SH@=OHEl4GEmM15mPG@AQHf44IFUW16Q]J`AZL6l3
Jg9b16adM0A]MGH4KGIh16agN@A[MgT3JWIi16UfN@AWMGT4IGAh16=bM`APLGH4GVme5Oooo`005?oo
o`AGJ6h4Df=X14iMHPA9Ee`4A55E0cm:CP@i@dL4<c`o12`d=`@U:bh47B8T0aDH6P@<3Pl40P<31001
0@@:2`/461PF12@S8@<]:RP4<c0]13Xg=0A2?c`4BTM315A?BPAKEU03HUaF16MQF`A/IEl4LFUR17A]
I@AgL6P3NW9Z17]dJ`AmMVd4O7E^17YdK@AfLV/4KfaW0fUXI0AWIf<4I6ER16=UHPARI684HF=Q0emQ
G`AMGed4Gf1M165SH@AUJFL4J6e[16Y`K`=[LW84K7Ad16eeMPA]MWP4K7Mi16]gN@=ZMWT4JGIi16Me
N@AUM7P4Hg9g161aMPANKgDEoooo000Doooo15MXKPACHfP4CUeR14UGG0A4DED3?dY>13U3A`@c?3l4
;3@g12D[;P@M8R@35APJ10`>3`@20`<4004110X;2`@H61H492<Q0bdZ:0@c<2d4>SLd148o?0A:Ad<4
E4m:15]FD0=RG5H4If5K16aUG`AaJF84M6eU17M`J0=jLVX4NgA[17efK@AlMFh4NWA]17IbJ`A_K6L3
JFQT16MWH`ATIF84HfER169THPAQHf43Gf5O15eOG@AOH5d4HF=Q16EYI`AXKF/4JW1_0f]bLPA/M7@4
KGEf16efN0A/MgT4JgMi0fYfN@AYMWT4IgEi16EdN0ASLWL4H75f15i_MAGoool001Coool4EfQ^15=S
J0A>GF84BEML14AAE@<oBTh4>D=713<l?`@/=3L49B/^11dR90<E61X430h?10830`@00@442P/;11PH
5P@T8b43;BXX13<`;@@j=c@4@Sll14Y7@`ADCdX4FeI@0f9LEPAWHE/4K6EO175YHPAdKFD4Mg1X0gYb
JPAkM6/4OGI]17aeKPAjM6d4MW9[16m/I`=YJ6@4IfMS16AUHPASIF84HVAR165SH@=OHEl4GEmM15mP
G@AQHf44IFUW16Q]J`AZL6l3Jg9b16adM0A]MGH4KGIh16agN@A[MgT3JWIi16UfN@AWMGT4IGAh16=b
M`APLGH4GVme5Oooo`005?ooo`AHJFl4E6AZ14mOI0A;FEh4AUAH0d5>DP@lB4`4=d55134j?@@Z<SD4
92X]0a`R90@E6A/43A0A10<51P@210@430h>11LH5`<R8R44:2PV12d]:P@c<S04>SXg1410?@A5AD43
BdY7155@C@AGEE44G5UE165NF0ATHE`3IfAN16QUG`AZIf84KFYV16e[I`AZJFD4IVMS0fAUHPAQHf04
GF1N15YNF`AIG5/4F5]J0eMJF@AFFEL4FeeK15mRH@ARIfH4IF]Z16M^KP=XL744JG9c16YcM@AZM7H4
JGEg16UeN0=XM7P4IWAh16EcN0ASLWL4HW5g161`MPANKgDEoooo000Doooo15QYK`ADI6X4CemT14]I
GPA6E5P3@DiB13a8C0@g@DD4<CXm12Xb=@@T:Rd3728T11DI6`@=41440`D6108410@<3Ph45aPG0b8R
8@@X:2H4;BdZ13<b<0@j>SL4@40m14E5@@=;BTL4DE1=15MED@ALFED4HEiH16AQG0=WI5h4J6EO16YW
HPA]JVH4KF]W16YYI@AVIf<3I6ER165SH0AMH5h4FUiK15ULF`AHFeX3EeYI15IIE`AKGE/4Gf9Q169W
IPAUJfX4Ifi^0fQ`L@AYLW<4JW=e16YdMPAYMGL4JGEh0fQdN0AVM7P4IG=h16=bM`ARLGL4H71f15i_
MAGoool001Coool4F6U_15ATJPA?Gf@4BeUN14IDF0=1CU84?4Q<13M1A@@a>Sd4:S8e12@Z;@<L8R@4
5ATK10d@4@@31@H40P@410`>3P@G61L38R8Q12PX9P@];BX4<c8`13Xj=`A0@3d4ADE10d]:A`AAD4d4
EeEA15aIE@AQGUP4I65L0fMTGPAXIEl4JVMR16eZIPA]JfL4JVUU16IWH`=TIF84HF=P15ePGPAJGU/4
FEaK15QKFP=GFUT4EUUG15]MF`AOHV44HVMV16E[JPAWKVh3J71a16UbL`AZLgD4JWAf16UeM`AYMGP3
J7Ah16IdN0AULgP4Hg9g169aM`APL7H4GVme5Oooo`005?ooo`AHJFl4E6AZ14mOI0A;FEh4AUAH0d5>
DP@lB4`4=d55134j?@@Z<SD492X]0a`R90@E6A/43A0A10<51P@210@430h>11LH5`<R8R44:2PV12d]
:P@c<S04>SXg1410?@A5AD43BdY7155@C@AGEE44G5UE165NF0ATHE`3IfAN16QUG`AZIf84KFYV16e[
I`AZJFD4IVMS0fAUHPAQHf04GF1N15YNF`AIG5/4F5]J0eMJF@AFFEL4FeeK15mRH@ARIfH4IF]Z16M^
KP=XL744JG9c16YcM@AZM7H4JGEg16UeN0=XM7P4IWAh16EcN0ASLWL4HW5g161`MPANKgDEoooo000D
oooo15QYL0AEIF/4DF1V14eLH@A9Ee`3AE9G141<D@@kAd/4=T14134j?@@[<cH39B`_11hT9P@G71h4
3a<E10H82@@520P43a4B0aTK6`@P8R449BHU12PY:0@];bd4=3Hd13Tk>@<l?c`4?d9014A6A0A:BdT4
CTm=155CC`=EEU<4EeQE15UKE`AJG5X4GEmL15YMF`AFFeX3DeUH155GEPA?EED4CE=C14eCDPA@E5<3
D5AB15=FE@AHG5`4G69R161VIPARJVX4I6a]0fE_L0AVL784Ig9d16MbM@AWLgH4IW=g0fEcM`ATLgL4
Hg9g169aMPAPLGH4Gg1e15e_MAGoool001Coool4F6U`15EUJ`AAH6H4CEaQ14UGG0=5DUL4@4aA13]7
B`@f@4@4<CXm12/c=P<U;2l47R@V11LL7P@?4aD41PP910D820@?4A836A/K120R8@@U9RD4:2TX12d_
;@@d=S@4>C/i0c`o?0@o@T04A4I414Y;B@A>Cdd4DE=?0eEFD`AGF5D4FE]G15YLFPAMGe`4FUeK15IK
FP=CFEP4DEMF14mEE@A=De<4CE=B151DD`=@E584DeIE15QLG0ALHV84H6IV169ZJPATK6d3IFm`16I`
LPAWLW@4Ig9e16McMPAVLgL3IG=g16AcM`ASLWL4HW5f161aMPAOL7D4GFme5Oooo`005?ooo`AHJG04
EFE[155PIPA=G644BEML0dEBE`A0C544>dM;13I0A0@a>Sd4:c<f0bD/;`@N92H45a`N10lC5@@620T4
1@P810lA4P<I6a/4828Q12DV9@@X:BP4;Bl]13@f=0@i>cT3?3ll13m2@0A4AT@4BT]914i?C@AADdl3
EEIC15MHE@AIFeL4FUaJ15eOG0AJGE/4EU]J0e=IF0AAEeH4CeEE14eCD`A=De84D5AC0e1DDPACEUD4
F5aL15aRHPAPIVH4HVYZ16A/K@=UKg04IW1b16MbM0AWLWD4Ig=f16IcM`=ULgL4I7=g16=bM`ARLGH4
H75f15m`M@AMKgDEoooo000Doooo15QYL0AEIF/4DF1V14eLH@A9Ee`3AE9G141<D@@kAd/4=T14134j
?@@[<cH39B`_11hT9P@G71h43a<E10H82@@520P43a4B0aTK6`@P8R449BHU12PY:0@];bd4=3Hd13Tk
>@<l?c`4?d9014A6A0A:BdT4CTm=155CC`=EEU<4EeQE15UKE`AJG5X4GEmL15YMF`AFFeX3DeUH155G
EPA?EED4CE=C14eCDPA@E5<3D5AB15=FE@AHG5`4G69R161VIPARJVX4I6a]0fE_L0AVL784Ig9d16Mb
M@AWLgH4IW=g0fEcM`ATLgL4Hg9g169aMPAPLGH4Gg1e15e_MAGoool001Coool4FFY`15IVK0ABHfP4
CemT14aJH0=8EU/4A55F141=D@@lAd`4=d96138l@0<]=ST49c0c124Y:`@K8B<451TK10/?40@830d3
3Q8B11TM7P@Q9BD492PX12HY:0@W;2/4:c0_0bld=0@d>ST4=S/k13Lm?@@l@T84@TU80dQ=C0A:D4l4
CE9A14iDE0ABEeL4D5IF14iEE@=;De@4BE5B14Q@D0A7Cdl4Adi?14eAD0=?De84DeUI15MNGPAKHV<4
GVIW161YJ`ARK6h3Hfi`16A_LPATL7<4I75d16AbM@ATLWH7Hg9f169aMPAQLGH4H71f15i_M@AMKgDE
oooo000Doooo15UZL0AFIV`4DV=X14mOI0A<FV03B5IK14AAEPA0CE44?4M<13M2AP@b?403;CHi12L`
<`@Q:B/46b4S11@I6`@;3a0420`=0`hB4P@I7Ah48BDU12@X:0@V:BP49b`[12/`;`<_=3@4=3Xi13Hk
>`@g?Cd4?4921499B0=8CD`4BU1?14eBD@A>E5@4DUMG151FEPA>EED3Be=D14UADPA8D504Adm?14M>
C`A=DE03Ce=B15=IF@AGGUh4Ff9S15iVI`APJF/4HVa^0f=^L0ATKg84I71c16AaM0ATLWD4I79f1f=b
MPARLGH4HG5f161`MPANKgD4GFme5Oooo`005?ooo`AIJW04EVI/159SJ0A?Gf@4C5YP0dQFF`A4DEH4
@4eA13a7C0@g@TH4<Sa00bdf>@@W<3<48BT[11/Q8`@D6A/42`l@10P<3@<>4Q846AdN124U9@@T:2P4
9RTX12L/:`@[<2l3;c@d13@j>@@f>c/4=cdm13a2@PA2BDP3B4e<14Y@C`A=DU44CUAD159GE`A@EUH4
CUEE0d]CE0A9DE84B51@14M?C`A7CTl4CE5@0dmCDPACFET4EeiN15]RH`ANIVL4H6U[169/KP=SKW04
I6mb16A`L`ATLG@4I79e16AbMPMSLWH4HW5f165aMPAPL7H4GVme15e_MAGoool001Coool4FFY`15IV
K0ABHfP4CemT14aJH0=8EU/4A55F141=D@@lAd`4=d96138l@0<]=ST49c0c124Y:`@K8B<451TK10/?
40@830d33Q8B11TM7P@Q9BD492PX12HY:0@W;2/4:c0_0bld=0@d>ST4=S/k13Lm?@@l@T84@TU80dQ=
C0A:D4l4CE9A14iDE0ABEeL4D5IF14iEE@=;De@4BE5B14Q@D0A7Cdl4Adi?14eAD0=?De84DeUI15MN
GPAKHV<4GVIW161YJ`ARK6h3Hfi`16A_LPATL7<4I75d16AbM@ATLWH7Hg9f169aMPAQLGH4H71f15i_
M@AMKgDEoooo000Doooo15U[L@AGJ6h4E6E[155QI`A?GV@3C5YP14UGG0A5DeP4@TmC13i:C`@jATX3
=T55134k?`@]=ST49c0c128Y;0@L8bD45Q`O0a0F60@B61T46R4R120W:0@U:R/49bd]12T`<0<Z<C84
;3Df130i>`@d?Cl4=d1213]4A`<oB4X4ADe?14M?D@A8D544BU5B14YAD`A8D583ADi?14=<CPA3Bd`4
ADe<14A;BPA:D503D5MH15ALG@AGH684FVAV15eWJ@AOJF`4H6]^0f5]L0ARKW84HVmc169`M0ARL7D7
HW5e165aMPAPL7H4H71e15m`M@ANKgD4GFie5Oooo`005?ooo`AIJg44EfQ^15AUJ`AAHFL4CeiT0daJ
H0A9Ee`4AE=H149?D`@nBTl4>TI:0cI1A@@a>cl4;CHi12L`<`@R:B`472<U11HL7`<@5QP44QPI11XQ
8P@P9bP49BX[12L];@@Y<303:S4b12`e=P@`>C/4=3do13M0@P@kA4L3?dQ:14E=C`A7Ce44B51A14YA
DPA:DE<4B51B0dE>C`A3C4h4@d]<14E=C0A4BdX4BU1@0e1GF0ADG5d4Ef1R15YTIPAMIfT4GfU/161[
KP=QKG04HVib169_L`ARL7@4HW1e1f9aM@AQLGH4H71f161`M@AOL7D4GVme15e^MAGoool001Coool4
FF]a15MXKPADIF/4DF5W14mNI0=<FV04BEML14ECF0A2Ce<4?TY?13Y6BP<f@DD4<C/o12df>@@W<3<4
8RT/11`S9@@F71l341HH118H6@@J8B8482LX12DZ:`@W;Bd4:C0`0bXa<P@/=CH4<3Tk13@m?`@g@484
>dA70cm8BPA5CDl4AdmA14Q@D@A:DE84BU5C14Q@DP=5CTl4@da>14=;C0A5CD`4A4]:14Y@D0=@EeP4
E5aM15MPHPAJI6H4GFMY15mYK0APJfh3HFe`169^LPARKg<4HW1d169`M@MRLGD4HG5f161`MPAPL7D4
Gg1e15i_M@AMKWDEoooo000Doooo15Y/LPAHJW04EVM]15ATJPABHVP3D5mU14eLHPA;FEl4B5IK14EC
F0A2Ce@3?da@13a8C0@hA4P4=3m3130j?P@/=CT49c0d0b</;`@L92P46R<V11`U:0@R:bh4:C8c12Tc
=0<Z=3D4;CLi130k?P@d?d44=T5313Q4AP<jATT4?DQ;13m:C@A3C4l4A4e@14E=C`A6CDl3A4a>14A<
C@A0AdL4@DQ914Q@D@A=EeP3DUaN15EPHPAHHfH4FVIY15aXJ`AMJVh4Gfa_0em]L@APKW84H6mc165_
M0AQL7@;H71e15m`M@AOKgD4GVme15e_M@ALKW@Eoooo000Doooo15Y/LPAHJW04EVM]15ATJPABHVP3
D5mU14eLHPA;FEl4B5IK14ECF0A2Ce@3?da@13a8C0@hA4P4=3m3130j?P@/=CT49c0d0b</;`@L92P4
6R<V11`U:0@R:bh4:C8c12Tc=0<Z=3D4;CLi130k?P@d?d44=T5313Q4AP<jATT4?DQ;13m:C@A3C4l4
A4e@14E=C`A6CDl3A4a>14A<C@A0AdL4@DQ914Q@D@A=EeP3DUaN15EPHPAHHfH4FVIY15aXJ`AMJVh4
Gfa_0em]L@APKW84H6mc165_M0AQL7@;H71e15m`M@AOKgD4GVme15e_M@ALKW@Eoooo000Doooo15Y/
LPAHJW04EVM]15ATJPABHVP3D5mU14eLHPA;FEl4B5IK14ECF0A2Ce@3?da@13a8C0@hA4P4=3m3130j
?P@/=CT49c0d0b</;`@L92P46R<V11`U:0@R:bh4:C8c12Tc=0<Z=3D4;CLi130k?P@d?d44=T5313Q4
AP<jATT4?DQ;13m:C@A3C4l4A4e@14E=C`A6CDl3A4a>14A<C@A0AdL4@DQ914Q@D@A=EeP3DUaN15EP
HPAHHfH4FVIY15aXJ`AMJVh4Gfa_0em]L@APKW84H6mc165_M0AQL7@;H71e15m`M@AOKgD4GVme15e_
M@ALKW@Eoooo000Doooo15Y/LPAHJW04EVM]15ATJPABHVP3D5mU14eLHPA;FEl4B5IK14ECF0A2Ce@3
?da@13a8C0@hA4P4=3m3130j?P@/=CT49c0d0b</;`@L92P46R<V11`U:0@R:bh4:C8c12Tc=0<Z=3D4
;CLi130k?P@d?d44=T5313Q4AP<jATT4?DQ;13m:C@A3C4l4A4e@14E=C`A6CDl3A4a>14A<C@A0AdL4
@DQ914Q@D@A=EeP3DUaN15EPHPAHHfH4FVIY15aXJ`AMJVh4Gfa_0em]L@APKW84H6mc165_M0AQL7@;
H71e15m`M@AOKgD4GVme15e_M@ALKW@Eoooo000Doooo15Y/LPAIJg44F6U_15MXKPAEIV`3E6AZ159R
J0A@H6H4CeiT14eLH@A;FEl3BEML14IDF@A4DEH4@DmC13i;D0@lB4d4>DE90cI2AP@c?T<4<Ca112lk
@0@]>3d4;cTn138l@@<b?D44<ci013<n@P@f@TD4?4M:13i:C0=0C4l4@TeA149>DPA4D5<4Ae5E14MB
E@A6D583@4U<14A=D0A8DUD4BeIH14iJG@ABGV43EF5U15MTJ0AIIVX4FVQ/15aZKPAMJg04GFaa0ei]
LPANKW<4Gfic35m_M0=OKgD<GVme15e_M@AMKWD4G6id5Oooo`005?ooo`AJK784FF]a15QYK`AGJ6h4
EFI/0eATJPABHVP4D61V14mNI0A=G644BeUO0dUGG0A6E5T4A55F145?D`@nBe04?4Q=13U5B@<f@TH4
<ci3134l@@@_>d04;CPm12li?P@b?443<Se113<n@0@c?T84=T9513a7BP@nBT`3@4a?149=D@A2CU84
A51C14MAE@A7DUD4AU1B0d19C0A4CE04B59E14]FF0A>FUd4DUiQ0eEQI@AGI6P4FFIZ15YXK0ALJVh4
GF]`15e/L@=NKG84GVic15m^L`aOKg@3Gfme35i_M@AMKgD4GFie15a^M1Goool001Coool4FVab15U[
L@AHJFl4EfQ^15EVK0=DI6X4DV9X151PIPA?GV@4CEaQ14]IG`=9Ee`4AUAI14AAEPA1Ce<4?T]@13a8
C@@iADT3=T9613<n@`@a?444;c]012dh?@@_>Ch4<Sa10c8m@@@c?T04<ci213I2A@@lAdX4?TY<0d1<
C`A2CE44@TiB14A@D`A7DED4Ae9E14I@DP=0BD`4A4e@14QBE@A;EUP4CUYM159NH@=EHFD4EfAX15UV
JPAJJ6`4G6Y^15e[L0AMK743GVeb15i^L`AOKW<<Gfmd0em_M@aNKgD4GFme15e^M@ALKW@Eoooo000D
oooo15Y/LPAIJg44F6U_15MXKPAEIV`3E6AZ159RJ0A@H6H4CeiT14eLH@A;FEl3BEML14IDF@A4DEH4
@DmC13i;D0@lB4d4>DE90cI2AP@c?T<4<Ca112lk@0@]>3d4;cTn138l@@<b?D44<ci013<n@P@f@TD4
?4M:13i:C0=0C4l4@TeA149>DPA4D5<4Ae5E14MBE@A6D583@4U<14A=D0A8DUD4BeIH14iJG@ABGV43
EF5U15MTJ0AIIVX4FVQ/15aZKPAMJg04GFaa0ei]LPANKW<4Gfic35m_M0=OKgD<GVme15e_M@AMKWD4
G6id5Oooo`005?ooo`AKKG<4FVac15Y[LPAIJg44F6Y`0eQYK`AGJ6h4EVM]15EVK0ADIF/4DfAY0e9R
J0AAHFL4D61U14iNI0A=GF84C5]P14YIG`=9F5d4AeIL14IEF`A6E5X8AEAI1dIDFPA6E5T4AE=H149@
E`A3DEL4@e5F0dABEPQ5DeL8AU=G14MDF0A=FUh3CeaQ151NHPABH6@4Df9V15ETJ0AGIVX3F6M/15UY
KPAJJVl4Ff]`15a/L@ALK784GFeb0ee]L`AMKW<OGFid35a^M1Goool001Coool4Ffec15Y/L`AJJg84
FF]a15QZL0=HJFl4EfQ^15IWK@AEIV`4E6E[15=TJ@=BHVP4DF5W151PI@A>GV@4CEeR14aKH0A:FEl3
BEQM14MFG0A6EE/4AUAJ24EDF@M6E5X4AUAI14ECF0A2D5L4@e5G14=AEP=4DUH8AE=G24ICE`A7E5P4
CEYN0dmLH@A@GV84DV1T15=RIPAEI6P4EfIZ0eQWK0AIJFh4FVY_15][L0ALK744G6ab15e]LP=MKG<4
GFic7ee^M0aLKW@Eoooo000Doooo15]]L`AJK7<4FV]b15U[L@AHJW03F6U_15MXKPAFIfd4EFI/15AU
J`ACI6T3DV9X155QI`A@H6D4CUiT14eMHPA<Ff04BUUO0dUHG@A7EU`4AUEK14IDFPQ5E5T7AUAJ14ID
F@A5DeP4@U1G14=AE`A3DEH3A59F24ECE`Q6DeL4AeAH14eJGP=?G644D5iR159PI0ACHVH4EFAX15MV
JP=HIf`4FFU^15YZK`AKJg04G6aa15a/LPAMKG83GFec15e^LamMKW@<G6id5Oooo`005?ooo`AKKG<4
FVac15Y[LPAIJg44F6Y`0eQYK`AGJ6h4EVM]15EVK0ADIF/4DfAY0e9RJ0AAHFL4D61U14iNI0A=GF84
C5]P14YIG`=9F5d4AeIL14IEF`A6E5X8AEAI1dIDFPA6E5T4AE=H149@E`A3DEL4@e5F0dABEPQ5DeL8
AU=G14MDF0A=FUh3CeaQ151NHPABH6@4Df9V15ETJ0AGIVX3F6M/15UYKPAJJVl4Ff]`15a/L@ALK784
GFeb0ee]L`AMKW<OGFid35a^M1Goool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool009?oool30000R_ooo`00U_ooo`030000oooooooo08Ooool0
08;oool200001?ooo`@00002oooo0`0000?oool300000oooo`800024oooo0021oooo00@0003ooooo
ool00002oooo00@0003oooooool00002oooo00<0003oooooool00oooo`040000oooooooo0000ROoo
o`00POooo`040000oooooooo00000_ooo`040000oooooooo00000_ooo`@00002oooo00@0003ooooo
ool00029oooo0021oooo00@0003oooooool00003oooo0`0000?oool200001?ooo`@00028oooo0021
oooo00@0003oooooool00005oooo00<0003oooooool0Toooo`00P_ooo`800005oooo0P0009Goool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(22) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
6971746971746971746971746971746971746971746A71736A71736A71736A71736A7173
6A71736A71736A71736A71736A71736A71726B71726B71726B70726B70716B6F706B6E6D
6B70716B71726B71736B71736B72746A71736A71736A71736A71736A71736971736A7173
6971736A72756A73756A74766B75776B75786B76796C777A6C787B6D797C6D7A7E6E7C80
707F846E7B7F6D797D6D787C6C777A6C767A6C76796B76796B75786B75786B74776A7477
6A73766A73766A7275697275
6971746971746972746A71746A71736A71736A71736A71736A71736A71726B71726B7172
6B70726B70726B70716B70716C70716C70716C70706C70706D6F6F6D6F6E6D6E6D6D6C6A
6D6E6E6D70706D71726D71726C72736C71726B71726B71736C71726B71726A72736B7273
6B72746B74766B75776C76796D787B6D797C6E7B7E6F7C806F7E8270808471828773858B
75878D728388718085707E83707D816F7B7F6E7B7E6E7A7D6D797C6D787B6C777A6C7679
6B75786B74776A73766A7275
6971746971736A71736A71736A71736A71736A71726B70726B71726B70716B70716C7071
6C70716C70706C70706D6F6F6D6F6F6D6F6F6E6F6F6E6F6E6F6F6D6F6E6C6F6D6A6F6B68
706E6C6F706F6F71716F71716E71726D71726C71716C70716D70716C71716B72726B7273
6B73756B74766B76786D797B6E7B7E707D80717F8372828673848974878C768A90778E95
778C9376898F75868C748489738287728085717F83707E826F7C806F7B7F6E797D6D787B
6C777A6B75786B74776A7376
6971746A71736A70736A71736A71726B70726B70716B70716B70716C6F706C70706C6F70
6D6F6F6D6F6F6E6F6F6E6F6E6E6F6E6F6F6E6F6F6D706E6D716E6C716D6B716C69716B66
726E6B726F6E7171707172717071716F71716D71706C70706C6F6F6C6F6F6A70706B7273
6B74756B76776C787A6D7B7D6F7E8171818473848774878B768A90778D947A92997C979F
7B939A798F96788C93778A9076878D75858A748388738186728084707E826F7C806E7A7E
6D787C6C777A6B75786A7376
6971746A71736A70726A71726B70726B70716B70716C70706C6F706C6F6F6D6F6F6D6F6F
6E6F6E6E6F6E6F6E6D6F6E6D706E6C706E6C716E6C726E6B736E6A736D6A746D68746B66
746E6B74706E7371707372717272717172717071716F71706E706F6D6F6F6C70706C7272
6C74766D76786D797B6E7C7F70818372858874888C778C917990967B949B7E99A1809DA6
7E99A17D959D7B92997A8F96798C93778A9076878D75858A748388728185717F83707C80
6E7A7E6D787B6C76796A7477
6971736A71736A70726B70726B70716B70716C70706C6F706D6F6F6D6F6F6E6F6E6E6E6E
6F6E6D6F6E6D706E6C706E6C716D6B726D6B726D6A736D6A756E69766E69776E69786D67
776F6B77716E76726F7572717472717373717272717172717072716F71706F72716E7374
6F76776F787A707C7E707F8272838775898D778D917A91967D969C7F9BA282A0A883A1AB
819EA7809BA37F979F7D949C7C91987A8E95798C9177898E76878C748488738185717E83
6F7C806E797D6C777A6B7477
6971736A71736A70726B70726B70716C70706C6F706D6F6F6D6F6E6E6E6E6E6E6D6F6E6C
6F6E6C706D6B716D6B716D6A726D6A736D69746D69756D68766D68796E697B706A7C726B
7A716D79726E787270777371767372757472747472747472737473727473727574717676
717979727C7D737F8174828575878A778C907A92977D969C809BA283A1A986A7B186A6B0
85A3AD83A0A9829DA58099A17F969D7D939A7B90967A8C92788A8F76878C748388728085
717E826F7B7F6D787B6B7578
6A71736A71736B70726B70716C70716C6F706D6F6F6D6F6E6E6E6D6E6E6D6F6E6C706D6B
706D6B716D6A726C69726C69736C68746C67756C67766C67786C677A6E6782746D80746E
7D736E7B736F7A7370797471787572787472777573767574757674757775757977757A79
757C7C758080768385778789798B8E7B90957D959B809BA184A1A987A6B08AADB889ABB6
88A9B387A5AF85A2AB849FA7829BA380979F7E949B7C90977A8D9378898F76868B748287
727F83707C806D787C6B7578
6A71736A71726B70726B70716C70706D6F6F6D6F6E6E6E6E6E6E6D6F6D6C706D6B706D6A
716C69726C69736C68736B67746B67756B66766B65776B65786A64796B6487777081746E
7F746F7D736F7C74707B74727B75737A7673797673787675787775787977777C7A787F7D
7981817984847A87887B8B8D7D8F927F9599819A9F84A0A688A6AE8BACB68EB4BF8DB1BC
8CAFB98AABB589A7B187A4AD85A0A8839CA481989F7F949B7C90967A8C9278888E758589
738185707D816E797D6B7578
6A71736A70726B70716C70706C70706D6F6F6E6E6E6E6E6D6F6D6C706D6B706C6A716C69
726C68736B67736B67746B66756A65766A64776A637769637768617C6D6682736C81736E
80746F7F74707E75717D75727D76747C77747B77757B77757A78767A7A787A7E7B7A817F
7B85847C89887D8C8C7E8F9181949683999D859EA387A4AA8AAAB28EB1BB91B9C491B8C4
90B5C08EB1BC8CADB78AA9B288A5AD86A0A9849CA481989F7F949A7C8F95798B9077878C
748287717E826F7A7E6C7679
6A71736A70726B70716C6F706D6F6F6D6F6E6E6E6D6F6D6C706D6B706C6A716C69726B68
736B67736B66746A65756A64766A637769637869627868617B6B637F6E6781716A81726D
81736E8074708075727F76747F77757E78757E78757D78757B78757C7C797C7F7D7C8481
7D88867E8D8B80908F82949484989A879DA189A2A78BA7AE8DADB591B4BE94BCC796BFCC
94BBC792B7C290B3BD8EAEB88CAAB389A5AD87A0A8849CA381979E7E92987B8D9378898E
7584897280846F7B7E6C7679
6A71736B70726B6F706C6F706D6F6F6E6E6D6F6E6C6F6D6B706C6A716C69726B68736B67
736A66746A6575696476696377696278686179686078675E7F6D65816F6881716A82726C
82736E81746F8276728277758178768179768078767F79767D77757D7A787D7D7B7E8280
7F8684818D8C829291859797889C9D8AA0A38DA6AA8FAAB190B0B793B5BF95BCC798C2CF
98C3D096BDC994B8C492B4BE8FAFB88CAAB28AA5AD879FA7849AA180959B7D90967A8A90
76868A738185707C7F6C777A
6A71736B70716C6F706C6F6F6D6E6E6E6E6D6F6D6C706D6A716C69726B68726B67736A65
746A647569637669627768617868607A685F7B675E86716783706783706883716A82716B
82726C82736E8376728479758479778379778379778179777F78767E77757F7A797F7D7D
7F8180828A8A8592918899998B9F9F8EA3A691A9AE92ADB493B2B995B6C097BDC799C2CE
9BC7D49AC3D098BECA95B9C493B4BE90AEB78DA9B18AA3AB869EA583989E7F92987B8D92
78878C748286707C806D777A
6A71736B70716C6F706D6F6F6E6E6D6F6E6C706D6B706C6A716C68726B67736A66746964
75696376686277686178676079675F7B675E7D685E87716786706885706884716A83706A
83716A82726D847571867A77867A77867B77897C7A8377758077757D74737D76757E7C7B
7F7D7E828485868C8C8C97988FA1A292A6A894ABB095B0B696B3BB97B7C098BCC79BC2CE
9DC8D59EC9D69CC4D19ABFCA97B9C394B3BD90ADB68DA7AF89A1A8859BA281959B7D8F94
79898E758387717D816D777B
6A71736B70716C6F706D6F6E6E6E6D6F6D6C706D6A716C69726B67736A66746964746963
75686176676077675F79665E7A665D7B655B88706488716787716886706885716A847069
836E68826F6A8473708778758A7C798476748578768375748175747F76757D74737C7979
7C7B7B7D80818186878B939494A0A196A9AA98AEB199B3B899B5BC98B8C099BCC79CC2CD
9EC7D4A0CBD9A0C9D59FC5D09CBFC998B8C294B1BA90ABB38BA4AC879EA583979D7F9196
7A8B90768489727E826D787B
6A71726B70716C6F6F6D6E6E6E6E6C6F6D6B716C69726B68736B66736A65746963756862
76676076665E77655D79655C7C665D7C655A8F75698B7268897168877067867069856F68
836D66826D68836F6C8272708A7D7B877C79867A79857A798378778179787F7978807E7E
7F7F807E83847D8486828D8F8E999B9AA9AA9CB1B49DB5BA9BB7BE9AB9C19BBCC69DC1CC
9FC7D4A1CCDBA3CCD9A4CAD6A1C5CF9CBDC798B6BF93AFB78EA7AF8AA0A7859AA0809398
7C8C9177858A727F836E787B
6A71726B70716C6F6F6E6E6D6F6D6C706D6A716C69726B67736A65746964756862766760
76665E76645C76635A78635980695F856C618D74688B72688A7168887168877069866E67
836B65826C67816C69806D6B867472867775867876867A78847977827A78827A7A828080
82838382888981888A848F9288969895A3A69FB3B59FB8BB9EB9BF9CB9C19CBCC69EC1CC
A0C6D3A1CCD9A4CEDCA5CCDAA6CAD5A0C2CC9BBAC396B2BB91ABB28CA3AA879CA282959A
7D8E9378878B737F836E787C
6A71726B70706D6F6F6E6E6D6F6D6B706C6A726C68736B66746A6575696376686177675F
77655D76635A756057725D527E665C8C71658B72668B71678B71678A7167897068876E66
856C65856F6987736F867370877371877573867573857574847573827675827777827A7B
827F8184868785898B868F928996998F9EA29CAFB2A1B8BCA0BABF9DBAC19DBCC59EC1CB
A1C6D2A2CBD8A6D0DEAED4E2A9CED9A5C6D19FBEC799B6BE94AEB58EA6AD899EA583979C
7E8F9479888C7480846E797C
6A70726C6F706D6E6E6E6E6C706D6B716C69726B67746A6575696476696277686078665E
78655C776359745E556F5A4F766057866E638B71668C71678C71688B71678A7168896E66
876C65876F688A76718A77748A7774897774887774877674867674847775847978847C7C
85808186858789898C8A8E928C94988F9BA196A6AC9EB3B7A0B8BE9EB9C09EBBC59FC0CA
A1C5D1A2C9D6A2CBD9B2D8E4AFD2DEA8CAD4A2C1CB9CB9C196B0B890A8B08BA0A785989E
7F90967A898D7481856F797C
6A70726C6F706D6E6E6E6D6C706C6A716B68736B66746A6576696377686179675F7A665E
7A655C7A64597961577B63587F675C866D628C71668E73688E72698D71688D71688B6F67
896E668970698C76708E7B768D7A778C79758A7875897875887674867775867A79867E7D
8782828986888C8C8E8F929591989C949FA498A7AC9DB0B59FB5BB9FB8BF9EBBC39FBFC9
A1C4CFA1C7D4A2CBD9B5DAE6B2D6E1ACCDD8A5C4CE9FBCC599B3BB93ABB28DA2A9879AA0
8192977B8A8E7582856F7A7D
6A70726C6F706D6E6E6F6D6B706C69726B67746A667569647769627968607A675F7C675D
7D665B7E655A80655982685D866D628B71668F746890756A90756A90746A8F73698E7168
8D70678C726A8D756F8F7B76907D798E7B778D7A768B7A768A7976887875887A78887F7D
8A84838B88888E8E8F919496949A9D97A0A49AA7AC9EAFB49FB3B99FB6BD9FBAC2A0BEC8
A0C3CDA0C6D29FC8D6B8DCE8B6DAE5AFD1DCA9C8D2A2BFC89BB6BE95ADB48EA4AB889CA1
8293987C8B8F7582866F7A7D
6A70726C6F6F6D6E6D6F6D6B716C69726B67746A657669637868617A685F7C675E7E675D
80675B82675A85695C886C5F8C71658F766B93776B93796D93786D93776C93756B92746B
91726A90736B90766F927B75937F7A917D798F7A778D7A768C7A76897975897B788A7E7D
8C85848D8989919090949698989C9E99A1A49BA7AB9EADB29FB1B7A0B5BCA0B9C1A0BDC7
A1C2CCA0C4D19CC5D4B3D8E5BBDFEAB3D5E0ACCBD5A4C1CA9DB8C097AFB690A6AD8A9DA3
83949A7D8C90768387707A7D
6A70726C6F6F6D6D6D6F6C6A716B68736A667569647768627968607B675E7E675D81675C
84685B87685A8A6D5F8D706392776A95796D967A6E977B6F977B6F96796F96786D95776D
95766C94766D93776F947B75957F7A947F7A927D78907C788E7B778C7A778B7C798D817F
8F8685918A8A9491919797999B9EA09DA3A69EA8AB9FACB1A0B0B6A1B4BBA2B9C0A3BDC6
A3C1CBA1C4D09CC4D2A7CFDDB6DCE9B9DBE6AECDD7A6C3CC9FBAC299B1B892A8AE8B9EA4
84959B7E8C91778387707A7E
6A70716C6E6F6D6D6C6F6C6A716A677369657568637768617A675F7D675D80675C83675B
87685A8A6B5C8F7162937768997D6F9B7C709B7D719B7D719A7D729A7C71997B70997B70
987A70987A70977B72977D7697807996807A947E79927E79907C788E7D788D7E7B8F8380
918886958E8C9793939C9A9B9EA0A2A0A5A7A1A9ACA1ACB1A2B0B6A4B5BBA4B9C1A5BEC6
A6C2CCA6C7D1A4C8D3A6CDDAACD4E1B2D6E1AECED8A8C5CEA1BCC49BB2BA94A9B08DA0A6
86979C7F8D92778488707B7E
6A70716C6E6E6D6D6B6F6B69716A6673696475686178675F7A665D7E665C81665A85675A
8A67598E6B5C937263997C6D9E8173A081739F80739F7F739E7F739D7F739D7E739D7E73
9C7E739C7E749C7F769B81799B827B99817B967F79947E79927C788F7D788F7F7B918481
948A8798908E9A95949E9B9CA1A1A3A3A6A8A4AAADA4ADB1A5B1B6A6B5BBA8BAC1A9BFC6
AAC4CCABC9D3ACCBD6AFD2DEB3DAE6B2D5E1AFCFD9AAC7D0A4BEC69DB4BC96ABB18FA1A7
87989D808E93788588717B7E
6A70716C6E6E6D6C6B6F6A6870696572676275666078665E7B655C7E655A826559876658
8D6859936D5E9A7667A18071A58576A58476A48476A38275A28175A18175A08175A18175
A08176A08377A08479A0857C9F867E9C847D99827C96807A937D78917D7890807C928581
958B8899918F9E9796A29E9EA4A3A4A6A8A9A7ABADA8AEB2A8B2B6AAB6BBABBBC1ADC0C7
AFC5CDB0CBD4B1CDD7B4D5E0B9DDE9B8DAE5B3D2DCADC9D2A6C0C89FB6BD98ADB390A3A8
89999E818F93798589717B7F
6A6F716B6D6D6C6B6A6E696770686472666174655E77645C7A645A7E6358836356886455
8F6B5B997363A47D6DAC8776AD8979AA8879A88678A68577A58376A48276A38276A48377
A58478A5867AA5887CA5897FA38981A0877F9D847D99817B957E78927D7892817C948682
988C899C9391A09998A49F9FA7A5A5A9A9AAAAADAEABB0B2ACB3B7AEB7BCAFBBC1B1C1C7
B3C7CEB5CDD5B7D0D8BBD9E3BCDEE9BDE0EBB7D6E0B0CCD5A9C2CAA2B8BF9AAEB592A4AA
8A9A9F8290947A868A717C7F
6A6F706B6D6D6C6A696D68656F666271655F73635C76625A7A62577E6255826153866150
8E69599D7665AB8271B78E7CB48E7DB08B7BAD8979AA8678A88477A68376A68376A78477
A88579AA897DAB8C80AA8E83A88D84A58B83A0877F9B837C967F79947E7993817C968782
998D8A9F9492A39B99A7A09FAAA6A6ADABABAEAFB0B0B2B4B0B5B8B2B9BDB3BDC2B5C2C8
B7C8CEBACDD4BCD1D8C1DBE4C3E0EAC2E4EEBCD9E3B4CFD7ADC5CCA5BAC19DB0B694A6AB
8C9BA08391957B868A727C7F
6A6F706A6C6C6B69686C67646D65606F635D72615A7560577960557D6053816051855F4E
8A66559B7565AE8573BE937FBA9280B58E7DB18B7BAD8778A98577A88477A88477AA867A
AD897CB08C7FB08F82AF9185AD9287A98F86A389819D847D977F79947E7893817C968782
9A8D8AA09592A49C9AA9A1A0ADA7A6B0ACACB2B0B0B3B4B5B4B7B9B4BABEB6BFC3B8C3C8
BBC8CFBDCDD4C0D2D9C7DCE4CAE4EDC9E8F2C1DDE5B9D2DAB1C7CEA8BDC3A0B2B897A7AC
8E9DA18592967B878B727C7F
696E70696B6B6A68676A65626C635E6D605A705F57735E54775E527D5E51825E4F866151
8B67569F7866B48875C59782BF9481B9907EB48D7CAF8879A98375A68173A58073A78276
AD877AB38C7FB69184B39286B19489AE948AA58C849E857D987F78947D7793807A968681
9A8C8AA19592A49B99A8A09FAEA7A6B2ADADB5B2B1B8B6B7B8B9BBB8BCBFB9C0C4BCC4C9
BEC9CFC0CDD3C2D1D8CADBE2D0E6EECEEBF4C6E0E8BDD5DCB5CAD0ACBFC5A2B4B999A9AE
909EA28693977C888B737D80
696E6F686A6A68676569636069605C6A5D576C5B53705A51755B4F7C5D4F835E4F876353
8966579E7866B68A76C99A85C39682BD927FB88E7DB18979AB8475A47E70A07D709C7B6F
A28073AC877AB28D80B28E82AE8F85AC9187A58B839E857D987E77937C76927E79948580
988A87A29693A49A98A9A09FB1A8A6B6AFAEB8B3B2BCB8B8BCBBBCBBBEC0BBC0C4BDC5C9
C1C9CEC3CED3C7D3D9D1DEE4D6E8EFD4EDF5CBE2E9C2D7DEB9CCD2AFC1C6A6B6BB9CAAAF
929FA38794977D888C737D80
686E6F676A6967656466615E665D59675A5468574F6B554C70564A7A5A4C8C66558D6857
8F6B5BA07968B98C77CE9D87C79884C09481BA8F7EB48B7BAE8777A78071A27D6F9A796C
9A7A6EA07F73A7867BAC8A7FAC8D83A98E84A48A829E847D977E77927B75907C7791817D
9285829A908E9E9592A59C9AB1A7A4B6AEACBAB3B1C0BAB9BFBDBDBEC0C1BCC1C5BEC4C9
C1C8CDC4CDD2CBD4DAD8E2E7E0EDF2DBF0F7D1E5ECC8DAE0BECFD4B3C3C8A9B8BC9EACB0
94A0A48995987E898C747D80
676D6E666868656362645F5C635A5662555062514A634E45674D417454468A6454956E5D
997261A87E6CBC8E79D09F88C99A85C39582BC907EB78E7CB28A7AAB8475A57E70A17C6E
A07D6FA38072A68477AA897DAB8B81A88B81A489809D837B977E76927B748F7B758F7F7B
918481938B8A938D8D949191A79F9EACA8A7B1ADACBAB6B5BBB9B9BCBDBEBBBFC3BCC3C7
C0C7CCC2CCD1CED6DBDDE4E8E7F1F5E3F6FBD8EAEFCDDEE3C3D2D6B7C6CAACBABEA1AEB1
96A1A58A95997F898C747D80
676C6D656767636160615C595F56525D514B5B4B445A453D563D33694C407C594B8E6858
997261AC816EBF907BD2A089CC9C87C59784BD907EB78C7AB38A7AAF8878AB8375A88072
A78071A98375AB8678AD8A7DAC8C80A88A7FA3877E9D827A977D76927B748F7B748F7F7A
928481948A88938C8C8F8D8E989696A09E9FA6A6A7B0AFAFB5B5B5B8BABCB9BDC0BAC1C5
BDC5C9C0C9CED0D7DBE0E5E8EBF1F5E9F9FEDFEEF2D3E2E5C8D5D9BCC8CCB0BCBFA4AFB3
98A3A68C9699808A8D757E80
666B6D636565615F5E5E59575B534F584C4755453F513E364B342B5F4439735447866254
967060AC806DC1907BD39F89CF9E89C79985C09381B88D7BB18676AC8374A88172A67E70
A27C6EA37E70A58073A88477A8887CA6877CA2847B9D8178977E75927B748E7A748E7D77
928580968C88978E8D9892919B97979F9C9CA5A3A4ADABACB2B1B2B5B7B9B7BBBDB9BFC2
BBC3C7C0C8CDD3D8DBE5E6E8EBEFF2EFFCFFE6F2F5DAE6E9CDD8DBC0CBCEB3BEC1A6B1B4
9AA4A78D979A818A8D757E81
656B6C6264645E5D5C5B575557504C5348434F403A4A3830432E25543C32694D417E5D4F
936D5DAA7F6CC0907BD29F88D2A08ACB9C88C49784BD9180B58B7AAE8475A88072A77E70
A47C6DA37C6EA37D6FA58073A68478A5847AA282789E8077987E76937C758E7A748A7974
8B7E7A928883998F8B9F9693A09A98A29E9DA6A4A4ACAAAAB0AFB1B3B5B7B5B9BBB6BDBF
B7C0C4C0C9CDD4D8DBE9E8E9EEF0F2F4FDFFF3FBFDE1EAECD2DBDEC4CDD0B6BFC2A9B2B5
9BA5A78F989A828B8D757E81
656A6C6163635C5B5A585452534D494F4540493C3643332C3D29214D362C60463B76584A
8C6859A67C6ABD8E7AD09D86D3A18CCE9F8BC79A88C19584BB907FB58B7BB08777AD8474
AA8272A98172A88172A88274A78375A58478A282779E81779A7F77967E77917D778C7B77
887B7889807D8C868497908DA09997A69F9EA8A5A4ACA9A9AFAEAFB1B3B5B2B6B8B2B9BC
B2BCC0C1C8CCD5D8DAE9E6E6F3F1F1F5FAFBF9FEFFE7EEEFD7DEE0C7CFD1B9C1C3ABB3B5
9DA5A890989B838B8E767E81
646A6B5F62625A5A59555250504A474A413D4538333E2F2837251E463229584036705246
866455A07866B88B76CE9B84D4A28CD1A28DCB9E8BC59A88BF9584BA9181B68D7DB2897A
AF8777AD8576AC8475AA8476A98476A78477A48378A082789D817899817995817A91807B
8D807C8C817F8B84828E898893908F9A9797A09F9FA5A4A5A8A9ABADAFB1AEB3B5AFB6B9
B0B9BEC0C7CAD2D5D7E4E2E2F2EFEFF9F9F9FDFFFFECF0F1DBE0E1CAD1D2BBC2C3ACB3B5
9EA6A890989B838B8E767E81
64696B5E616159595853504E4D4745473E3A4035303A2C2533221B422F27533C33694D41
8160519A7463B38773C99882D5A38CD4A490CFA18EC99D8BC39988BE9585BA9282B78F7F
B48C7CB2897AB08778AE8778AC8678A98578A68578A38479A0847B9D847C9A847D96847E
938480918682908885918B8993908F9694949B9A9BA1A0A2A4A6A8A8ABADAAAFB2ACB3B7
B1B9BDC0C6C9D0D3D5DEDFE0EEECECFAF8F7FFFFFFF1F4F3DEE2E2CCD1D2BCC2C3ADB4B5
9FA6A891989B838B8E767E81
63696A5D6061575757514E4D4A4543433C383D322E3528232E1E173E2C244E392F63483D
7A5A4C946E5EAD816EC4937ED3A18AD7A791D2A490CCA08EC79D8CC29989BE9585BB9282
B89080B58D7DB38B7BB18A7AAF8879AC887AAA877AA7867BA4877DA1877E9E87809B8881
988882968985958C88958E8C9792909996959C9B9BA09FA0A3A4A6A6A9ABA8ACAFAAB1B4
B3B9BDC1C5C8CFD1D3DDDDDDEBE9E9F8F5F3FEFCFBF3F5F4DFE2E2CDD1D2BCC2C3ADB3B5
9FA5A791989A838B8D767E81
62686A5C5F605556564E4D4B47434140393639302B312520291B143928214A352C5D4338
7254478B6758A47B68BC8D78CD9B85D7A690D4A692CEA390CAA08EC59D8CC29989BE9685
BC9382B9907FB78E7EB48C7CB28B7BB08A7BAD897CAB897DA88A7FA68B81A38B82A08B84
9D8C869B8D889A8F8B9A928E9A94929C97969D9B9B9F9F9FA2A3A5A3A7A9A4AAADA8B0B3
B2B9BDC0C4C7CED0D2DBDBDBE8E6E6F4F0EFFAF7F6F2F2F1DDDFDFCCCFD0BCC0C1ADB2B3
9EA5A6919799838B8D767E80
62686A5B5F5F5455554D4B4A45413F3D3734362D292E231E26181235251E463229573F34
6B4F428261529D7563B48773C69681D3A28CD4A692D0A492CCA190C89F8EC59C8CC29989
BF9685BC9382BA9180B88F7FB58D7EB38C7DB08C7EAF8C80AD8D82AA8E84A78E85A58F86
A28F899F908A9E928D9E94909E96949E99979E9C9B9F9F9FA1A2A3A2A6A8A4A9ACA9B0B3
B4BABDBFC4C6CCCFD0D9D9DAE5E4E4F0EDECF5F3F2E9EAE9D9DBDBC9CCCDBABEBFABB0B2
9DA3A5909798838A8C767E80
62686A5A5E5F5354544B4A4943403E3B3533322B272A201C22161131221C412F27523B31
64493D7B5B4D936E5DAC806DC1917BCE9D87D3A490D1A591CEA290CAA08FC79E8DC49C8B
C29988C09685BD9383BB9282B99080B79081B58F81B29083B19084AF9186AC9188A99289
A6928BA4938DA2948FA19692A09895A09A98A09C9BA09F9FA1A1A2A1A5A7A3A9ACABB1B4
B4BABCC0C4C6CBCDCFD8D8D8E4E2E2EEEBEAF5F4F2E4E4E4D5D6D6C6C9C9B7BBBCA9AEB0
9CA2A38F959782898B757D80
616869595E5F515354494949413F3D3834322F2825261D191D120E2C1F183B2B244C372E
5D44397355478A6757A27967B98A76C99782D2A28DD2A591CFA391CCA28FC9A08EC79E8D
C59C8BC39988C19786BF9584BD9483BC9384B99284B79386B69488B39589B1958BAE958C
AA968DA8968FA69691A49893A39A96A29B99A19D9CA19F9FA2A2A2A3A6A7A6ABADAEB2B5
B7BBBDC2C4C6CDCECED8D8D7E4E2E1EDE9E8F0EFEEDFDFDFD0D2D2C2C5C5B4B8B9A7ACAD
9AA0A18E949681888B757D7F
616769595D5E5053534848483F3E3D3633312D2724221B18180F0B261A1436262046332A
573F356B4F42826152987260AF836FC1907BCF9E88D2A48FD0A390CEA28FCBA18FC99F8D
C79D8CC69B8AC49988C29786C09685BF9686BE9687BC9789BB988BB9998CB6998DB3988E
AF9990AC9991AA9993A79A95A59B97A49C99A29E9CA29F9FA3A2A3A5A7A8A9ACAEB1B4B5
B9BCBDC2C4C6CCCDCED7D7D7E2E0E0EAE8E7E4E4E3D8D9D8CBCDCDBEC1C1B1B5B6A4A9AA
989E9F8C939480878A757C7F
616769585D5E5053534748483E3D3C3432302A2624201917150C091F140F2F211B3F2D25
4E393062483D78594B8E6A5AA37A68B78874C89781D0A18CD1A38FCFA28ECDA18FCBA08D
CA9F8CC89D8BC89C8AC69A89C49887C49988C39A89C29A8BC09C8EBE9D8FBB9C90B89C91
B49C92B19C93AE9C95AB9C96A89C98A69D9AA39E9CA29F9EA3A3A3A7A8A8ACAEAFB4B5B6
BCBDBEC3C4C5CDCDCDD8D7D6E3E0DFECEAE9DEDEDDD2D3D3C5C7C8B9BCBDADB1B2A1A6A8
969C9D8A91937F8689747C7E
616769585D5E4F53534648483D3D3D3331302925241E1916120B0818100C271B15372720
47332A5841376D514582625395705FA87E6CBC8D79CA9A85CFA08BCFA18DCEA28ECDA18D
CCA08DCB9F8CCA9E8BCA9D8BC89B89C89B89C89D8CC79E8EC69F90C3A092C1A093BD9F93
B99F94B59E96B19F97AE9F98AB9E99A89E9AA59F9DA39F9FA5A3A3A8A8A9AEAEAFB5B5B6
BDBDBEC5C5C5CECDCDD8D6D5E0DDDDE6E5E5D8D8D8CBCDCDC0C2C3B4B8B9A9ADAF9EA3A5
93999B898F917E8587737B7E
606769585D5F4F53544648493D3D3D3332312826251D19170F0A081009061E15102E201A
3E2D254D393061493E76594C8866579A7463AB816EBD8F7BC79783CD9D88CEA08CCDA08C
CDA18DCEA08CCEA08CCD9F8CCB9D8BCC9D8BCEA08ECEA291CCA393C9A394C6A395C2A396
BDA196B9A197B5A098B1A099AC9F99A99E9AA7A09CA4A19FA5A4A3A9A9A9AEAFAFB5B5B6
BCBCBDC4C4C4CDCCCCD8D5D4DDDBDADADADACFD0D1C5C6C7BABDBDAFB3B4A5A9AB9BA0A2
919798878D8F7D8486737B7D
60676A585D5F4F53544649493D3E3E3333322827261D1A19110D0B0A0402150E0B251A15
35272044322A5640366B50447A5D508B695A997463AA816FB78B78C1927EC79985C99B88
CC9E8ACFA08CCFA18DCEA08CCD9E8BCD9E8BD0A18ED2A491D1A595CEA696CBA596C6A497
C2A397BEA399B9A299B3A199AEA099AA9E9AA79F9CA5A19FA7A4A4AAA9A9AEAEAFB5B5B5
BBBBBBC3C2C2CBCACAD4D2D1DCDBDBD1D1D2C7C9C9BEC0C1B4B7B8AAAEAFA1A6A7979D9E
8E9496858B8D7B8385727A7D
61686A585E604F5455464A4B3D3F403334342929281E1C1C13100F0703020C07041C1310
2A1F1A392B244A38305F473D6E54487C5F528A695B977464A47E6DAF8574B68C7ABC917F
C19582C69986CA9C88CA9D89C99C89CB9D89CD9F8CCFA28FD1A493D0A695CDA596C8A496
C4A397BFA298BBA399B5A199AF9F99AA9E9AA89F9CA5A19FA7A4A3A9A8A8ADADADB3B3B4
B9BABAC0C0C0C7C7C7CFCECED2D3D3C8C9CABFC1C2B6B9BAAEB2B3A5AAAB9DA2A3949A9B
8B9293838A8C7A818472797C
61686A585E60505556474B4C3E41413536362B2B2B201F1F151313080606040100120D0A
21191530241F3E3029503E35614A416E554A7C5F53896A5C9573649F7B6BA58171AC8676
B38A79B98F7EBD9280C19684C19684C39886C69A88C99D8BCBA08FCCA392CAA393C6A294
C2A295BEA196B9A197B4A097AE9E98A99D99A79F9CA5A09EA6A4A2A8A7A7ACACACB1B2B2
B7B8B9BCBDBEC1C3C4C9C9CAC4C6C7BEC0C1B7BABBAFB3B4A8ACADA0A5A6989E9F919698
898F9181888A79808371797B
61686B595F61515658484C4E3F43443638392D2E2E2223231817170C0B0B020000080504
18120F261E1A35292445362F534139624C436D554A7A5F5385675B8E6E619675679C7B6D
A28071A98576AC8778B38D7DB58F7FB89181BA9383BD9787C09989C19B8CBF9C8EBD9C8F
BA9D91B79C92B39C93AD9B94AA9B95A59B97A49C9AA39E9DA4A2A1A6A6A6AAABABAFB0B1
B5B6B7B8BABBBCBFC1BDC0C1BABCBEB5B8B9AFB3B4A9ADAEA2A7A89BA0A2949A9B8D9395
868C8E7F8688777F8170787B
61696B5A6062525759494E50414546383B3C2F31322527271B1C1C101011050405020100
0F0C0B1D17152B221E3A2E2947383253423B5D4A426B544B775E537E655A876C608E7166
94766A9C7C6F9F7F72A48476A78678AB897BAE8C7EB08F81B39284B59487B49588B1958A
AF968BAD968DAA968FA59690A39792A19894A09A989F9C9BA1A09FA3A4A4A7A9AAACAEB0
B1B4B5B4B8BAB5B9BBB3B7B9B0B4B6ACB0B2A7ACADA2A7A89CA1A3969C9D9096988A9092
838A8C7D8486767E8070787A
62696C5A616353595B4B50524347493B3E40323536292B2C1F2122151617090A0B000000
070606141110201B192D26233B312C473A3450413B5B4A4367534B6F5A527862597F675E
856D638C726891766C967A6F9A7E729E8275A08578A3877BA68A7FA78C81A68E83A48E84
A28E86A18F879E8F899B908B9A918E9B94919B97959B99999D9D9D9FA1A2A4A7A8AAADAF
AEB3B5AFB4B6ADB2B4ABAFB1A8ADAEA5A9ABA0A5A79CA1A3979C9E9197998C9294868D8F
81888A7B8284757D7F6F777A
626A6C5B6264545A5D4D5354464A4C3E424436393B2D30322427281B1C1E101113030506
000102090A0A161414231F1D2F29263A312E4238344C403A5648435E4F49695851705E57
77635C7C6860826D658771698A756C8F796F937D73957F7598837999847B99867E96867E
968780948881918883908985908B89928E8D93929194959597999A9B9E9F9EA3A5A4A9AB
ABB1B4A7ADB0A5ABADA3A8AAA1A6A89DA3A59A9FA1969C9D9297998D9395888F91838A8C
7E8587798083747B7E6E7679
636A6D5C6366565C5E4F5557484E504146483A3E403236372A2D2F212425181A1C0E1012
0306080103050B0D0E1818182522212F2A2937312F3E3734473F3B4E4542584D4960544F
675A556C5F5972635E7768627C6C6680706985746D8878708B7B748D7E778E80798B807A
897F7A867F7B85807D8583808685848888888B8D8E8F9192919596969A9C9CA1A2A0A6A8
A1A7AAA0A6A89EA4A69CA2A49A9FA2979D9F949A9C9097998D9395898F91848B8D808789
7C8385777F81727A7D6E7678
636B6E5D6567585E6152585A4B5153454A4C3E4345373C3D303436282C2D202325171B1D
0F121405090B0307090E11121B1C1C2625252F2C2C3331303A3736413D3C484442524B49
58514E5F5753645B58695F5C6E6460736864776C677B706B7E736E817772837A76837B78
817C787C79777A79787C7D7C7D7F7F80838485898A8A8E908D9294909698969D9F989FA2
989FA2989EA1979D9F959B9E93999C9197998E95978B9294888F91858B8E81888A7D8487
798183757D7F71797C6D7578
646C6E5F6669596163545B5D4F5557494F5143484A3D4244363B3D2F3436282D2F212527
191E20121618090D10080D0F1216191D20212829292D2E2E3232323637373E3D3D444443
494848504E4C5553525B5756605C5A66615E6A65626F6966716C6875706D7975727B7675
7A7775777776787978797B7B797D7E7B8082808587848A8C898F928B929690989A91989B
91989B91979A9097998F95988D94968B9294899092868D8F848B8D81888A7E85877A8284
777F81747B7E70787B6D7577
656D6F60686A5B6365575E6052595B4D5355484E5043484A3D4244373C3E3136382B3032
24292C1E2325171C1E0E13160E1417171C1F222628292D2E2D313230333536393A3E4041
424545464849494C4C4E5050545555595A595E5E5D6362616665646A69686C6C6B717170
6F71706D71716E73736F757671787A747B7E787F827F8688838B8E858D91889093899194
8A91948A9194899093888F92878E91868D8F848B8D82898B7F87897D84877A8284787F82
757D7F727A7C6F777A6C7477
656D7061696C5E65685A6163565D5F51585A4D5456494F51444A4C3F45473A4042353A3D
2F35372A2F32242A2C1D2426161C20141C201B2225262B2E2D323531363833383A373C3E
3B40423E444643494A464B4D494E504D525454585A5A5D5D5D6161626464636767696C6C
686C6D686E6F6870716972746C757770797B727C7F7C84877E868A80888B82898D838B8D
838B8E848B8E838B8D838A8C82898B80888A7F86897D85877B8385798183777F81757D7F
737B7D70787B6E76796B7476
666E71636B6E60686A5D6467596163565D5F52595C4F56584B5254474E50434A4C3F4548
3B4143363D3F31383B2C3336282F32232A2E1F272B21292D2A323630383C363D3F383F42
3B42453C44473F484B444B4F484F524A51544F5659535A5C595F615D6263606566626769
64696B646B6D646C6F666F726871746D76796F787B767F827981847A83867C84877D8588
7E85887E85887E85887D85877C84867B83857A8284798183787F82767E80747C7F737A7D
71797B6F777A6D75786B7376
676F72646D6F626A6D60676A5D65675B6265585F62555C5F525A5C5057594D5356495053
464D50434A4C3F46493C4346384043353D40313A3E2C353A2E373C303A3F363F433D4548
3E474A3E484A414B4E444E514851544B53564E565950595C545C5F575F615B62655D6466
60666862686B636A6D666E71646D706770736D767A717A7D747C7F757E81777F82788082
788083788083788083788082777F82777E81767E80757D7F747C7E737B7D71797C70787B
6F77796D76786C74776A7375
677072666E71646D6F636B6D61696C5F676A5E65685C63665A6164585F62565D60545B5E
52595C4F575A4D55574B5255485053464E52444C50424B4F424B4F414B4F40494E444D51
474F54474F534750534751554A545750585B535B5D545D60575F625861635B63665E6568
60676A626A6D5E666A636B6F666F726871746B74776E767970787B71797C727A7D727B7D
737B7E737B7E737B7E737B7D727A7D727A7D717A7C71797B70787B6F777A6F77796E7678
6D75786C74776B73766A7275
687173677072676F72666E71656D70646C6F636B6E626A6D61696C60686B5F676A5E6669
5D65685C64675B63665A6265596164586063575F62565E62555E62555E62555E62565F63
576063575F63576063565F63545E62565F635760635861645962665A63665B64675C6467
5E676A646C6F656D70666E716770736971746A73756B74776C75776D75786D76786E7679
6E76796E76796E76796E76796E76796D76786D75786D75786D75776C74776C74776B7476
6B73766A73756A7275697275
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?oooa]YLG@WJW5c16YaLPM[LG84Jg1b16]`L@A[Kg04Jfi]16]`
L@=[LG88Jg5c16]bM1=ZLG<4JG5c16YaL`AYLG<4JW9e0fYcM@AZM7H4JgEg16]eN0A[MWT4K7Mj0fah
N`A]NG`4KGYn16ilP0A`Oh@4KW]o16eiO@=]N7`4K7Mj16afNPA/MWT4JgIi1f]eN0A[M7L4JWAg26Yc
MPAZLWD4JG9e5Oooo`005?oooa]YLG@WJW5c16YaLPM[LG84Jg1b16]`L@A[Kg04Jfi]16]`L@=[LG88
Jg5c16]bM1=ZLG<4JG5c16YaL`AYLG<4JW9e0fYcM@AZM7H4JgEg16]eN0A[MWT4K7Mj0fahN`A]NG`4
KGYn16ilP0A`Oh@4KW]o16eiO@=]N7`4K7Mj16afNPA/MWT4JgIi1f]eN0A[M7L4JWAg26YcMPAZLWD4
JG9e5Oooo`005?oooa]YLG@WJW5c16YaLPM[LG84Jg1b16]`L@A[Kg04Jfi]16]`L@=[LG88Jg5c16]b
M1=ZLG<4JG5c16YaL`AYLG<4JW9e0fYcM@AZM7H4JgEg16]eN0A[MWT4K7Mj0fahN`A]NG`4KGYn16il
P0A`Oh@4KW]o16eiO@=]N7`4K7Mj16afNPA/MWT4JgIi1f]eN0A[M7L4JWAg26YcMPAZLWD4JG9e5Ooo
o`005?ooo`QYLG@4JG9d16YaM1=ZLG<4JW5b1f]aLPQ[L788Jg1a26a`L@M/L704KFm_16e_KPA]KVd4
KFaZ16e^KP=]L708KG5b16abL`A/LG84Jg5b0f]aL`A/LG84Jg5b16YbL`A[LW<4Jg9d16]dMP=[MGL4
K7Ii16ehN`A]NG`4KW]n16mlP0=_OX84L8241762Q`AcQH/4MHN=17:3R0AaP8D3L7j3171mP@A_Ngl4
KW]n16ijO@A]NG`3KGQk16agNPA/MWT4JgEh16]dM`AZLgH4JW9e5Oooo`005?ooo`QYLG@4JG9d16Ya
M1=ZLG<4JW5b1f]aLPQ[L788Jg1a26a`L@M/L704KFm_16e_KPA]KVd4KFaZ16e^KP=]L708KG5b16ab
L`A/LG84Jg5b0f]aL`A/LG84Jg5b16YbL`A[LW<4Jg9d16]dMP=[MGL4K7Ii16ehN`A]NG`4KW]n16ml
P0=_OX84L8241762Q`AcQH/4MHN=17:3R0AaP8D3L7j3171mP@A_Ngl4KW]n16ijO@A]NG`3KGQk16ag
NPA/MWT4JgEh16]dM`AZLgH4JW9e5Oooo`005?ooo`QYLG@4JG9d16YaM1=ZLG<4JW5b1f]aLPQ[L788
Jg1a26a`L@M/L704KFm_16e_KPA]KVd4KFaZ16e^KP=]L708KG5b16abL`A/LG84Jg5b0f]aL`A/LG84
Jg5b16YbL`A[LW<4Jg9d16]dMP=[MGL4K7Ii16ehN`A]NG`4KW]n16mlP0=_OX84L8241762Q`AcQH/4
MHN=17:3R0AaP8D3L7j3171mP@A_Ngl4KW]n16ijO@A]NG`3KGQk16agNPA/MWT4JgEh16]dM`AZLgH4
JW9e5Oooo`005?ooo`QYLG@4JG9d16YaM1=ZLG<4JW5b1f]aLPQ[L788Jg1a26a`L@M/L704KFm_16e_
KPA]KVd4KFaZ16e^KP=]L708KG5b16abL`A/LG84Jg5b0f]aL`A/LG84Jg5b16YbL`A[LW<4Jg9d16]d
MP=[MGL4K7Ii16ehN`A]NG`4KW]n16mlP0=_OX84L8241762Q`AcQH/4MHN=17:3R0AaP8D3L7j3171m
P@A_Ngl4KW]n16ijO@A]NG`3KGQk16agNPA/MWT4JgEh16]dM`AZLgH4JW9e5Oooo`005?ooo`AYLG@4
JG5c3fYaL`AZLG84Jg1b16]aLPQ[L747K71a26a`L0a]Kfl3KVm_16i_KPA_Kfd4Kfi/16m]JPA_JfP4
L6i/0fm`K`Q_LG44KW5b16eaLPA/LG43K71a16e`L@A/LG44Jg9b16]bL`A[LgD4JgAf0f]fN0A]NG/4
KW]n171mP0AaOh<4LX:60g>4R@AdQh`4MXZ@17N>U@AgS9<4MXV?17F6S0=dQ8T4Lh:717:0Q@AaOh<4
L7j216mlP0=_Ngl4KWUm16ehN`A/MgX4JgEh16]dM`AZLgHEoooo000Doooo16UaM0AYLG<?JW5c16Ya
LPA[L784Jg5b26]`L@M/L748K71`36e_K`=^Kfl4KVm^16m_K@A_KV`4KfeZ16m[J0A`KV`3Kg1_26ma
L@A^LG84KG5b16aaL@=/L744KG1a16aaL@A[LW84Jg9c16]cM@A[M7H3JgIh16eiN`A^Ngh4L7f0175o
P`AbPXH3LhB917B7S0AfRY04MhjE17N<T`AfRHl4MHJ<0gB4R@AcPXL4LX25175oP`A`OX84Kgb00fmk
O`A^NGd4KGQk16agNPA[MGP4JgAg16YcMQGoool001Coool4JG5d16UaL`mZLG<4JW5b16]`LPA[LG88
Jg1a1fa`L@Q/L70<KFm_0fi_K`A^Kfh4Kfm]16m^K0A_KFX4Kf]X171^K0=_L6l8Kg5a16iaLPA]LG84
K75a0fa`L@A]L744K75a16]bLPA[LW<4Jg=e16]dMP=[MWP4KGUk16ikOPA`OH04LGn317:2QP=cQ8T4
M8N<17J:T0AgSYD4MhbC17J9S`AeQX`3M8B917>2Q`AbP8D4LGn3171nPPA_O803Kg]o16iiO@A]N7/4
K7Mj16]eN0A[M7L4JW=f5Oooo`005?ooo`AYLG@4JG5c3fYaL`AZLG84Jg1b16]aLPQ[L747K71a26a`
L0a]Kfl3KVm_16i_KPA_Kfd4Kfi/16m]JPA_JfP4L6i/0fm`K`Q_LG44KW5b16eaLPA/LG43K71a16e`
L@A/LG44Jg9b16]bL`A[LgD4JgAf0f]fN0A]NG/4KW]n171mP0AaOh<4LX:60g>4R@AdQh`4MXZ@17N>
U@AgS9<4MXV?17F6S0=dQ8T4Lh:717:0Q@AaOh<4L7j216mlP0=_Ngl4KWUm16ehN`A/MgX4JgEh16]d
M`AZLgHEoooo000Doooo16UaM0AZLG<4JW1c16YaL`AZLG83Jg1b36]`L@A/Kg04K71`0fa_L0Q]Kfl4
KVm_26i_KPA_Kfh3Kfm]171^K@AaKV`4LFe[175/J@AaJfH4LVi[0g9_KPAaLG04LG9a171aL@A_LG44
KG5`0fa`L0Q/Kfl4JW1`16]bL`A[M7D4JgIg0fahNPA]Ngd4Kgj11761Q0AcQ8L4M8N;0gJ:T0AgSI@4
NY:I17bGW`AkTiX4NHnF17R<T`=gRY04MXN=17F5RPAdPhP4Lh6617:0Q0=`OX84Kgb016ijOPA]N7`4
K7Mj16]eN0AZLgHEoooo000Doooo16UaM0AZLG<4JW1c16YaL`AZLG83Jg1b36]`L@A/Kg04K71`0fa_
L0Q]Kfl4KVm_26i_KPA_Kfh3Kfm]171^K@AaKV`4LFe[175/J@AaJfH4LVi[0g9_KPAaLG04LG9a171a
L@A_LG44KG5`0fa`L0Q/Kfl4JW1`16]bL`A[M7D4JgIg0fahNPA]Ngd4Kgj11761Q0AcQ8L4M8N;0gJ:
T0AgSI@4NY:I17bGW`AkTiX4NHnF17R<T`=gRY04MXN=17F5RPAdPhP4Lh6617:0Q0=`OX84Kgb016ij
OPA]N7`4K7Mj16]eN0AZLgHEoooo000Doooo16UaM0AZLG<4JW1c16YaL`AZLG83Jg1b36]`L@A/Kg04
K71`0fa_L0Q]Kfl4KVm_26i_KPA_Kfh3Kfm]171^K@AaKV`4LFe[175/J@AaJfH4LVi[0g9_KPAaLG04
LG9a171aL@A_LG44KG5`0fa`L0Q/Kfl4JW1`16]bL`A[M7D4JgIg0fahNPA]Ngd4Kgj11761Q0AcQ8L4
M8N;0gJ:T0AgSI@4NY:I17bGW`AkTiX4NHnF17R<T`=gRY04MXN=17F5RPAdPhP4Lh6617:0Q0=`OX84
Kgb016ijOPA]N7`4K7Mj16]eN0AZLgHEoooo000Doooo16UaM0AZLG<4JW1c16YaL`AZLG83Jg1b36]`
L@A/Kg04K71`0fa_L0Q]Kfl4KVm_26i_KPA_Kfh3Kfm]171^K@AaKV`4LFe[175/J@AaJfH4LVi[0g9_
KPAaLG04LG9a171aL@A_LG44KG5`0fa`L0Q/Kfl4JW1`16]bL`A[M7D4JgIg0fahNPA]Ngd4Kgj11761
Q0AcQ8L4M8N;0gJ:T0AgSI@4NY:I17bGW`AkTiX4NHnF17R<T`=gRY04MXN=17F5RPAdPhP4Lh6617:0
Q0=`OX84Kgb016ijOPA]N7`4K7Mj16]eN0AZLgHEoooo000Doooo16UaM0AZLG<4JW1b16YaLPA[L787
Jg1a16a`L0A/Kg04K6m_1fe_K`Q^Kfh8Kfi]271^K0=aKV`4LVi[17=^JPAcKFX4M6eX17A[IPAdKV/3
M71^17=aL0AcLW44LW9a175bL@A`LG43Kg5`16i`K`A]Kfl4K71`16abLPA/M7H4KGIh0feiN`A^O7l4
L86317:5R0AdR8`4MhbA0gV@UPAkU9/4OYVQ182MYPAnVJ44OIFM17^BV@=jSiH4NHbC17N:T0AfQhd4
MHF:17B3R0=bPHD4LGn3171lP0A^NWh4KGQk16afN@AZM7LEoooo000Doooo16UaM0AZLG<4JW1b16Ya
LPA[L787Jg1a16a`L0A/Kg04K6m_1fe_K`Q^Kfh8Kfi]271^K0=aKV`4LVi[17=^JPAcKFX4M6eX17A[
IPAdKV/3M71^17=aL0AcLW44LW9a175bL@A`LG43Kg5`16i`K`A]Kfl4K71`16abLPA/M7H4KGIh0fei
N`A^O7l4L86317:5R0AdR8`4MhbA0gV@UPAkU9/4OYVQ182MYPAnVJ44OIFM17^BV@=jSiH4NHbC17N:
T0AfQhd4MHF:17B3R0=bPHD4LGn3171lP0A^NWh4KGQk16afN@AZM7LEoooo000Doooo16UaM0AZLG<4
JW1b16YaLPA[L787Jg1a16a`L0A/Kg04K6m_1fe_K`Q^Kfh8Kfi]271^K0=aKV`4LVi[17=^JPAcKFX4
M6eX17A[IPAdKV/3M71^17=aL0AcLW44LW9a175bL@A`LG43Kg5`16i`K`A]Kfl4K71`16abLPA/M7H4
KGIh0feiN`A^O7l4L86317:5R0AdR8`4MhbA0gV@UPAkU9/4OYVQ182MYPAnVJ44OIFM17^BV@=jSiH4
NHbC17N:T0AfQhd4MHF:17B3R0=bPHD4LGn3171lP0A^NWh4KGQk16afN@AZM7LEoooo000Doooo16Ua
M0AZLG<4JW1b16YaLPA[L787Jg1a16a`L0A/Kg04K6m_1fe_K`Q^Kfh8Kfi]271^K0=aKV`4LVi[17=^
JPAcKFX4M6eX17A[IPAdKV/3M71^17=aL0AcLW44LW9a175bL@A`LG43Kg5`16i`K`A]Kfl4K71`16ab
LPA/M7H4KGIh0feiN`A^O7l4L86317:5R0AdR8`4MhbA0gV@UPAkU9/4OYVQ182MYPAnVJ44OIFM17^B
V@=jSiH4NHbC17N:T0AfQhd4MHF:17B3R0=bPHD4LGn3171lP0A^NWh4KGQk16afN@AZM7LEoooo000D
oooo16UaL`AZLG<4JW1b16]`LPM[L744K71`16a_L0Q]Kfl4KVm^0fi^KPQ_KVd8L6i/175]J`AbKF/3
LVeZ17=]JPAeKVT4MViY17M^J@AhKFL4Mfm[0gMaKPAfLVl4MG9a17AbL@AcLg44LW9a0g5bL@A`LW44
Kg5`16mbL@A^Lg@4KgIg16mhNP=`O7h4L7n217:3Q`AeRHd4MhfA17ZAUP=mUY`4Oi^R18:PZ0B3XJ/4
PIjW182KX`AoUil3OIBL17bAV0AjSYD4NHbA17N9SPAfQh`3M8B817>1Q@AaOX<4Kgb016iiO@A/MgX4
JgAg5Oooo`005?ooo`AYLG<4JW5c16Y`LPA[L787Jg1a16a`L0A/Kg08KFm_16i_KP=^KVh8Kfi]271^
K0AaKF/4LVe[0g9]JPAcKFX4MFiY17I^J@AgKVT4N6eW17M_J`=gLFh4MW9_17EbL@AdLW44Lg=a179b
L@=aLW44L79a16maL0A_LW44KW=d16mfM`A_N7X3L7an171oPPAbPhL4MHV=17N=T@AjTIH3OIJL17nK
XPB2X:P4Pj6[186NY`B0Vj<4OiNO0gfDW0AlTIP4NXjE17V<T@AgRHh4MXN<0gB4R0AcPHD4LGj316ml
P0A^NGd4K7Mj16]dMaGoool001Coool4JG5c16YaL`AZL784Jg1b1f]`L@A/L704K6m`26e_K`A^Kfh3
KVi^26m^K@Q`KV`4LFe[179]J`=bKFX4LfeZ17E^J@AfKVT4MfiY17Q]I`AgKf/3Mg5^17IbK`AeLW44
M79a17=cL@AbLW43LG9a171bL@A_LG04Kg9a16icM0A_MWL4KgQj0g1lOPA`Oh84LX>717F9S@AgSI44
NY6F0gfFW0AoVj84PZ2X18>QZ`B1WZL4P9^S17nGW`=mU9`4O96H17Z>U@AiS944MhV>17J7S0=dQ8P4
Lh65175nP`A_O804KWUm16agNPA[M7LEoooo000Doooo16UaL`AZLG<4JW1b16]`LPA[L743K71`16a_
L0A]Kfl4KFm^16i^KPA^KVd7Kfi/171]J`AaKF/4LFeZ179]JPAcKFT3M6eY17E]J0AfKFP4NFiY17]`
JPAlLV/4NW5]0gUbKPAhLW04Mg=a17IcLPAeM787M7Ab17=dL`AbM7<4LWEd175fMPAaNGT4LWam0g=o
P@AdPXD4MHN:17N<T0AjTYL4OIJL0h2KXPB3XJT4QZNa18JV/0B5Xjd4Pj2Y18:MY@>0VJ44OiJM17fC
VPAkT9H4NXbB17R:S`=fQh`4M8>817:0Q@AaOX84Kg]o16ehN`A[MGPEoooo000Doooo16UaL`AZLG<4
JW1b16]`LPA[L743K71`16a_L0A]Kfl4KFm^16i^KPA^KVd7Kfi/171]J`AaKF/4LFeZ179]JPAcKFT3
M6eY17E]J0AfKFP4NFiY17]`JPAlLV/4NW5]0gUbKPAhLW04Mg=a17IcLPAeM787M7Ab17=dL`AbM7<4
LWEd175fMPAaNGT4LWam0g=oP@AdPXD4MHN:17N<T0AjTYL4OIJL0h2KXPB3XJT4QZNa18JV/0B5Xjd4
Pj2Y18:MY@>0VJ44OiJM17fCVPAkT9H4NXbB17R:S`=fQh`4M8>817:0Q@AaOX84Kg]o16ehN`A[MGPE
oooo000Doooo16UaL`AZLG<4JW1b16]`LPA[L743K71`16a_L0A]Kfl4KFm^16i^KPA^KVd7Kfi/171]
J`AaKF/4LFeZ179]JPAcKFT3M6eY17E]J0AfKFP4NFiY17]`JPAlLV/4NW5]0gUbKPAhLW04Mg=a17Ic
LPAeM787M7Ab17=dL`AbM7<4LWEd175fMPAaNGT4LWam0g=oP@AdPXD4MHN:17N<T0AjTYL4OIJL0h2K
XPB3XJT4QZNa18JV/0B5Xjd4Pj2Y18:MY@>0VJ44OiJM17fCVPAkT9H4NXbB17R:S`=fQh`4M8>817:0
Q@AaOX84Kg]o16ehN`A[MGPEoooo000Doooo16UaL`AZLG<4JW1b16]`LPA[L743K71`16a_L0A]Kfl4
KFm^16i^KPA^KVd7Kfi/171]J`AaKF/4LFeZ179]JPAcKFT3M6eY17E]J0AfKFP4NFiY17]`JPAlLV/4
NW5]0gUbKPAhLW04Mg=a17IcLPAeM787M7Ab17=dL`AbM7<4LWEd175fMPAaNGT4LWam0g=oP@AdPXD4
MHN:17N<T0AjTYL4OIJL0h2KXPB3XJT4QZNa18JV/0B5Xjd4Pj2Y18:MY@>0VJ44OiJM17fCVPAkT9H4
NXbB17R:S`=fQh`4M8>817:0Q@AaOX84Kg]o16ehN`A[MGPEoooo000Doooo26YaL`A[L784Jg1a16a`
L@=/Kg04KFm_16e_KPQ^KVd4Kfi/1g1]J`AaKFX8LVaY17=/J0AdK6L3MFaW17I/I`AhK6L4NViW189d
K@B0M6h4OG=^0g]cK`AjLg04NGAa17QeLPAhM784MgEc0gIeM0AeMW@4MGMe17EiM`AeNWT4MGal17F0
P0=fPhD4MhN917V;SPAkT9D4OIFK182KX@>4XJT4QjJ`18Z]^0B9ZkH4R:Vc18NU[`B5XZ/3Q9nW18:K
X`B0Uil4OYBK17b@U`AjSI<3N8V?17J6R`AdPXL4LWn3171lP0A]N7`4JgEh5Oooo`005?ooo`QZLG<4
Jg1b16]`L@A/L743K6m`16e_K`A]Kfh8KVi]16m^K0M`KF/4LFeZ279/J@AcK6P4M6aW0gE/I`AfK6L4
N6aW17Y^I`B2M6d4P7A^17ecKP=kLfl4NW=`17UdL@AhMG84N7Ab17MeL`=fMG@4MGId17EgM@AeNGL4
MGYi17ElO0AeP803MX>517N7R@AiRhh4Ni2E17fEV`B0Vj43Q:6Y18NV/0B:[KP4RJ^f18RY/`B7YJl4
QJ:[0hBOY`B2Vj<4P9NO17jDV`AlT9L4NXfC0gR9S`AfQX/4M8:7179oP`A`O804KGQl16]eN1Goool0
01Coool8JW5c16]`LPA[L744K71a0fa_L0A]Kfl4KFm^26i^K@A_KV`7L6e[175]JPQbK6T4LfaX17A/
I`=eK6L4MVaW17Q/I`AjKVL4PWA]181dKPAmLfh3Ng=_17YcL0AiM744N7Eb17QdLPAgMG<3MWEd17Ef
M0AeMgD4MGUg17EjN@AeO7`4MH200gJ3Q@AgQhT4NH^>17^@U@AmUI/4P9^Q0hBQZ@B7Y[04RZfh18V[
]PB8ZK<4QjF_18FRZ`>4WjL4PY^S182GW`AnU9/4O92G17Z=T`=hRHl4MXJ;17B2Q`AbOh<4L7b016eh
O0A[MGPEoooo000Doooo26YaL`A[L784Jg1a16a`L@=/Kg04KFm_16e_KPQ^KVd4Kfi/1g1]J`AaKFX8
LVaY17=/J0AdK6L3MFaW17I/I`AhK6L4NViW189dK@B0M6h4OG=^0g]cK`AjLg04NGAa17QeLPAhM784
MgEc0gIeM0AeMW@4MGMe17EiM`AeNWT4MGal17F0P0=fPhD4MhN917V;SPAkT9D4OIFK182KX@>4XJT4
QjJ`18Z]^0B9ZkH4R:Vc18NU[`B5XZ/3Q9nW18:KX`B0Uil4OYBK17b@U`AjSI<3N8V?17J6R`AdPXL4
LWn3171lP0A]N7`4JgEh5Oooo`005?ooo`AZLG<4JW5b16]`LPA[L744K71`0fe_K`A]Kfh4KVi^16i^
K@A_KF`4L6e[0g1]JPAaK6T4LVaY17=/J0AcJfL4M6]W17E[IP=fJfD4Mf]U17QZI0AiJf@4QgM`185d
KPAoM6l3OG=_17adL0AkM784NgEc17YfL`AiMW<3N7Ie17QgM@AhNGL4Mgaj17QoO@AiPH44NHB40gZ7
R0AkRhd4OHnB17nEV@B1VYl4Q:2V0hRV[PB;[;H4S[Bo18fa_0B<[kT4RZ^e18VW/@>7Y:d4QJ2X18>L
Y0B1V9l4OiBK17b@UP=jS984N8R>17F5R@AcPHD4L7f116iiO@A[MGPEoooo000Doooo16YaL`AZLG84
Jg1b16]`L@A/L703KFm_16e_KPA^KVh4KVi]16m]K0A`KF/3L6eZ175/J@AbK6T4LfaX17=[I`AdJfL4
MF]V0gI[I@AgJfD4N6YT17U[I0B7Mg04PGA^17mdK`=mLfl4O7A`17]dLPAkMG<4NWIc17UfL`=hMWD4
N7Me17QiM`AgO7X4N7mm17V1P@AiQ8@3NXN817^;S@AmSi84OiFI186JW`B4X:H3R:J^18^/]PB>];l4
SK6l18b_^@B:ZkD4RJNa0hNT[@B5X:P4PibT186HW`AoU9/4O92F0gZ<TPAhR8h4MHF917>1Q@A`OH44
KWUm16]eN1Goool001Coool4JW5c16YaLPA[L784Jg1a16a`L0=]Kfl4KFm^16i^KPA^KVd4Kfe/171]
J`=`KFX4LFaY179/J@AcK6P4Lf]W17A[I`AeJfH3MV]U17M[I@AhJV@4NF]T18MgL0B1M6h4OgA_0gec
K`AlM704NgAb17]eL`AjMW<4NGIc0gQfM@AhMgD4N7Ug17MlNPAhOgd4NH6117V4Q0=jQhP4Nh^=17f?
TPAoUIT4PIZO18BPYP>8YZh4Rjbf18jd_`B=/K`4S:ni18Z[]@B9Yk43QjB]18FPZ0B3W:@4PIRO17nD
V`AlT9H3NXbB17R8SPAeQHT4Lh65171mP@A^NGd4JgEh5Oooo`005?ooo`AZLG<4JW5b16]`LPA[L744
K71`0fe_K`A]Kfh4KVi^16i^K@A_KF`4L6e[0g1]JPAaK6T4LVaY17=/J0AcJfL4M6]W17E[IP=fJfD4
Mf]U17QZI0AiJf@4QgM`185dKPAoM6l3OG=_17adL0AkM784NgEc17YfL`AiMW<3N7Ie17QgM@AhNGL4
Mgaj17QoO@AiPH44NHB40gZ7R0AkRhd4OHnB17nEV@B1VYl4Q:2V0hRV[PB;[;H4S[Bo18fa_0B<[kT4
RZ^e18VW/@>7Y:d4QJ2X18>LY0B1V9l4OiBK17b@UP=jS984N8R>17F5R@AcPHD4L7f116iiO@A[MGPE
oooo000Doooo16YaL`AZL784Jg1a26a`L0=]Kfl4KVi^16i^K@A_KF`4L6e[171/JP=aK6T4LVaX27=[
I`AdJfH4MFYU17IZI0=gJV<4MfUS17MXH@AlKFH4PW=/185cKPB0M6l3OgA`17ieL@AmMG84OGId17ag
M0MkMgD4NWQf17YjN0AjOW/4NX5o17^5Q0AlRHP3OHb<17j?T@B1U9H4PiVM18FNX`B7Y:X3RZZb18ja
^`BA^L@4TKS4192e`0B>/K`4S:fg0hZY/PB8YJd4QZ2Y18BLY0B1V9l4OiBJ0gb?U@AiRi04MhN<17B2
Q`AaOX84KgYn16afNAGoool001Coool4JW5c16Y`LPA[L748K71`0fe_K`A^KVh4KVi]16m]K0A`KF/4
L6aZ0g5/J@AbK6P8Lf]W17A[IPAeJVD4MVYT0gMZH`AgJF<4MfQQ17a]IPB2Lf`4PG=^181dK`=oM704
OWEa17eeLPAmMW@4O7Md1g]gM@AjN7H4NWYh17YnN`AjPGl4NhF417b9R0=mS8`4OXnA186DUPB3VId4
QIjS18NTZP>:Z[84S[6k196ia0BA^<@4T;G018ja_0B<[KL3RZVb18RU[@B6X:T4Q9bT186HW`AoU9X3
O8nE17V;T0AgQh`4M8:7175nPPA_NWh4K7Ii5Oooo`005?ooo`AZLG<4JW1b16]`L@Q/L703KFm_16i^
KPA^KVd4Kfe/171]J`A`K6X3LFaY179/J0QcJfL4M6]V17EZI@AfJV@3MfYS17MYH`AgJ644O6eV189c
K0B1Lfh4P7A_0gmdL0AnMG44OGEb17efM0AlMg@7NgMe17YhMPAjNWP4NWik17Z1O`AkQH@4O8V80gf<
S0AnSi44PIBF18>IW@B5WZ<4QjBZ0hZZ/PB>/K/4TKW4196ha0B@]L04S[6l18b]]`>:ZK84R:F]18JP
Z@B4W:@4PIRO17nDVP=lSiD4NH^@17N7S0AdPXL4LGj216mjOPA/MWTEoooo000Doooo16YaL`AZL784
Jg1a26a`L0=]Kfl4KVi^16i^K@A_KF`4L6e[171/JP=aK6T4LVaX27=[I`AdJfH4MFYU17IZI0=gJV<4
MfUS17MXH@AlKFH4PW=/185cKPB0M6l3OgA`17ieL@AmMG84OGId17agM0MkMgD4NWQf17YjN0AjOW/4
NX5o17^5Q0AlRHP3OHb<17j?T@B1U9H4PiVM18FNX`B7Y:X3RZZb18ja^`BA^L@4TKS4192e`0B>/K`4
S:fg0hZY/PB8YJd4QZ2Y18BLY0B1V9l4OiBJ0gb?U@AiRi04MhN<17B2Q`AaOX84KgYn16afNAGoool0
01Coool4JW5c16Y`LPA[L744K6m`16e_K`=]Kfh4KVi]16m]K0A`KF/4L6aZ175/J@=bJfP4Lf]W17=[
IPAdJVD4MFYT17IZH`AgJF<3N6UR17QXH@AkJf<4OfiW185aJPB1LVd4PG=^0h1dL0B0MG84OgId17mg
M@QnN7D3OGQe17]hM@AlO7T4O7mm17b4P@AmR8H4OXf;0h2@S`B2U9@4Q9RJ18NMX@B9XZL4RjN^0hf]
]@BA];h4U;c719Joc0BD^lL4T[O2192c_@>>[[P4S:Zc18VU[@B7X:P4Q9bS186GWP=nTYP4NhfC17R9
SPAeQ8T4LX2416mkOPA/MWTEoooo000Doooo16YaL`AZL784Jg1a16a_L0A]Kfl3KFm^16i^K@A_KF`4
L6e[171/JPAaK6T3LV]X17=[I`AcJfH4M6YU17EZI0AfJV<4MfUS0gQYHPAhJ644Nf]S17m^I`B1LFX4
PG9]185cKP>0M704P7Eb17mfM0AoMgD8OWQe0gehM@AkN7D4O7ai17aoO@AlQ844OHR617j=R`>0T8l4
PYBD18BHVPB7WJ44RJ:W18^W[P>=[KD4TKBn19Bla`BF_l`4U;_719:g`PB@/kd3SZjh18bZ/`B9YJd4
Qj2X18BLX`B1Uih3OY:H17^=T`AhRHh4MHB917:0Q0A_Ngh4K7Ii5Oooo`005?ooo`AZLG<4JW1b16]`
L@A/Kg04KFm_0fe_KPA^KVd4Kfe/171]J`A`K6X4LFaY0g9[J0AcJfL4Lf]V17AZI@AeJV@4MVYS17MY
H`=hJF84N6QQ17][H`AoKVL4PG5Z185bK@B1Lfh3P7A`181eLPAoMW@4OgMe27ihM@=mN7D4NgQe17al
N@AlOgd4O8B117f8QPAnSH/3P92?18:DU0B4V9X4QifQ18VRY`B;Yjh3SJfe196d_PBD_<L4U[o<19Bk
a`BB]l84T;>m0hj^^0B<Z[<4RJF]18NPZ0B4W:<4PINN0gjBV0AkSI<4N8V>17F4R@AbP8@4Kg]n16af
NAGoool001Coool4JW5c16Y`LPA[L744K6m`16e_K`=]Kfh4KVi]16m]K0A`KF/4L6aZ175/J@=bJfP4
Lf]W17=[IPAdJVD4MFYT17IZH`AgJF<3N6UR17QXH@AkJf<4OfiW185aJPB1LVd4PG=^0h1dL0B0MG84
OgId17mgM@QnN7D3OGQe17]hM@AlO7T4O7mm17b4P@AmR8H4OXf;0h2@S`B2U9@4Q9RJ18NMX@B9XZL4
RjN^0hf]]@BA];h4U;c719Joc0BD^lL4T[O2192c_@>>[[P4S:Zc18VU[@B7X:P4Q9bS186GWP=nTYP4
NhfC17R9SPAeQ8T4LX2416mkOPA/MWTEoooo000Doooo16YaL`A[L784Jfm`16a_L0A]Kfl3KVi]16m^
K0A_KF/4L6aZ175/J@AbJfP3Lf]W17=ZIPAdJVD4MFUT17IYH`AgJF84N6QQ0gUXH0AhIeh4OfeU185_
J0B1LFX4PW9/189cKP>1M6l4PWIb189gM@B1N7H4PGUf181hMP=oNGH4OGMe17ejN0AmOG/4OX:017n6
Q0B1SH`3PY:A18FGU`B8W9d4RZ2S18fVZPB?Z[43T;2g19>e_`BE_<L4V<;?19S3d0BF_LT4U;S40i:d
_PB?[kP4S:Zb18ZU[@B7WjL4Q9ZQ0h2EV`AmT9H4NXZ@17J6RPAcPHD4L7ao16agNQGoool001Coool4
JW5c16]`LPA[Kg04K6m`16e_K`=^KVd4Kfi/16m]J`A`K6X4LFaY179[J0=cJfL4LfYV17AZI@AeJF@4
MVUS17MYHPAhJ643NFQP17QWGPAoKFD4PFmX185aJPB2LV`4PW=^0h5dK`B2MW84PWMe185hMPB1NGH4
P7Qf0gmiMPAmMgD4OGYh17emN`AnPX04OhJ4186=S0>2TY44QING18RLW@B:X:<4SJJZ18nZ/@>@/;L4
TkFo19Fla`BH`/l4V<?@19Jmb@BD^<@3T[Bn18n_^0B<Z[84RZF]18NOY`B4VZ43P9FK17f@UPAjRY04
MXJ:17>1Q@A`O7l4K7Mj5Oooo`005?ooo`AZLG<4Jg1b16]_L0A/Kg04KFm_0fi^K@A_KV`4Kfe[171/
JPAaK6T4LV]X0g=[I`AcJVH4M6YU17EYI0AfJF<4MfUR17QXH@=iJ604N6MN17m]I@B1KfP4PG5Z189b
K0B2Lfh3PGA_189fLPB2MgD4PGQf185iMPB0N7H3OgUf17egM@AmNWP4OGek17j2P0AoQX@4PHf<0h:B
T@B5UiL4R9bM18ZPX`B=YZX4SjZa0i2`]`BC]Kl4UKc719S2c`BH`m04U[g919Bha0>B];h4Sjnh18bZ
/PB:YJd4QinW18BJX@>0UI/4OI2F17Z:T0AfQXX4Lh65171lO`A/MgXEoooo000Doooo16YaL`A[L744
K6m`16a_K`A]KVh3KVi]16m]K0A`KFX4LFaY179[J0AbJfL3LfYU17AZI0AeJF<4MVUR17MXH@AhJ604
NVQO0g]WGPB6LFL4Pg1W18=`J0B3LFX4PW5[189bK0>2Lfh4PgIb18AiM@B4NGL8PgUg0h5iM`AoN7H4
OWMe17mjN@AoOGd4Oh6018::RP>5TY44R9VI18^OW`B>XjH4TJV^19:]]0>C/[T4UKK019Nma`BI`/h4
VlOD19[3d0BH_/X3UKW419>d_PB@[[L4SJVa18ZSZ`B6WZD3PiRN17nBV0AkSI84N8N<17B2QPA`O804
KGMj5Oooo`005?ooo`AZLG<4Jg1a16a_L0A/Kfl4KFi^0fi^K@A_KF`4L6eZ175/J@AbJfP4LV]W0g=Z
I@AdJV@4MFUS17IYHPAgJ644N6QP17YXG`=kIeh4QW5W18=`I`B3L6P4Pg5Z189aJ`B2LV`3PW=^18=f
LPB4NGD4Q7Ug28=iM`>1NGL4OgQf17igM@AoNWT4Ogem17n1P0B2RXX3QI:A18RIV@B;Wil4SZ>V196Y
[PBB[K@3Tk:i19Ff`0BG_LL4VL;>19_7e0BJ`m04V;k:0iFia0BC];h4T:jg18fY/@B:Xj/4QYjU0h>H
WPAoTYP4NhfB17R7S0AdPXH4L7b016egNQGoool001Coool4JW5c16]`L@A/Kg04K6m_16e^KP=^KVd4
Kfe/171]JPAaK6T4LV]X179[I`=cJVD4M6YT17EYH`AfJF84MfQQ17QXH0AjJ5l3NfMN18IaI`B3L6L4
Pg1X18=aJPB2LF/4PW9/0h9cKPB3MW84Q7Ue18AiM`R3NGL3PGUg17mhMPAnMgD4OgYi17mmO@AoPH04
PXZ:0hFBT@B8VIT4RinO18jSYPBAZJh4TZfd0i>b^@BE]/04Ukg719W2cPBKam@4V/?@19RnbP>E^L@4
TkBn192^]`B=ZK44RZ>[18JNY@>3V9h4Oi:H17^=TPAhQh`4M8:6171lP0A]MgXEoooo000Doooo16Ya
L`A[L744K6m`16a_K`A]KVh3KVi]16m]K0A`KFX4LFaY179[J0AbJfL3LfYU17AZI0AeJF<4MVUR17MX
H@AhJ604NVQO0g]WGPB6LFL4Pg1W18=`J0B3LFX4PW5[189bK0>2Lfh4PgIb18AiM@B4NGL8PgUg0h5i
M`AoN7H4OWMe17mjN@AoOGd4Oh6018::RP>5TY44R9VI18^OW`B>XjH4TJV^19:]]0>C/[T4UKK019Nm
a`BI`/h4VlOD19[3d0BH_/X3UKW419>d_PB@[[L4SJVa18ZSZ`B6WZD3PiRN17nBV0AkSI84N8N<17B2
QPA`O804KGMj5Oooo`005?ooo`AZLG<4Jg1a16a_L0A]Kfl4KVi]0fm^K0A`KF/4L6aZ175/J0AbJfL4
LfYV0gAYI0AeJF<4MVQR17MXH@AhIf04NFMO17]WGP=mJ5h4Qg5W18I`J0B5L6P4Q75Z18=`JPB3LFX3
PW9]18AeL@R6NWL4QW]g18UlNP>3MgD4P7Me17edL`AmMWD4OWak17mmOPB2Q8D3QXb<18bGV0B?XJ84
TZJX19B[/0BE/;H3U[>k19Ng`0BH_<L4Vl;>19g8e@BNbMH4W<CA0iZobPBG^L<4U;>m192]]PB=Yjl4
RJ6X0hFKXPB1UI/4OHnD17V9SPAePhL4LGf116egNaGoool001Coool4JW5c16]`L@A/Kg04KFm_16i^
K@=_KV`4L6e[171/JPAaK6P4LV]W17=ZIP=dJF@4MFUS17IXHPAgJ644N6MP17UWG`AkIeh3OFQN18Ma
I`B6L6P4QG1X18AaJPB3L6X4Pg5Z0h9bK@B4MG48QWYg18IkM`B9O7X3PgMe181gM@AmM7<4OGIe17il
N`AoOGh4PXB50hJ<S0B<UiP4Sj6R19:VZ0BDZk04UK2f0iJc^`BG]l04V;c719_2cPBMb=D4W/WF19c4
d@>J_lX4UkW319Bc_@B@[KH4SJN_18VQZ0>5Vj84PIFK17f?U0AiRHh4MH>7175mP@A]Mg/Eoooo000D
oooo16YaL`A[L744K6m`16e_K`A^KVd3Kfi/171]J`A`K6X4LFaX179[I`AcJVH3M6UT17EYH`AfJ684
MfQQ17QWH0AiIel4NfMN0geXGPB7LFL4QW1X18E`J0B4LFX4Pg1Z18=aJP>2LVd4Q7Ea28IjM`B6NgL4
RGaj0h=gM@B0MgD4OGAc17efM@AnO7/4Ogen18:4Q@>6S8`4S9NH18nQXPBBYZP4U:^`19F`]P>F/k/4
UkO019Rla`BK`/h4WLSE19k9ePBLa=43V[o:19Ni``BD/kd4T:ff18fW[`B9XJP3QI^R186EV`AmSi@4
NHV>17F3Q`AaOH44KGMk5Oooo`005?ooo`AZLG<4Jg1a16a_L0A]Kfl4KVi]0fm^K0A`KF/4L6aZ175/
J0AbJfL4LfYV0gAYI0AeJF<4MVQR17MXH@AhIf04NFMO17]WGP=mJ5h4Qg5W18I`J0B5L6P4Q75Z18=`
JPB3LFX3PW9]18AeL@R6NWL4QW]g18UlNP>3MgD4P7Me17edL`AmMWD4OWak17mmOPB2Q8D3QXb<18bG
V0B?XJ84TZJX19B[/0BE/;H3U[>k19Ng`0BH_<L4Vl;>19g8e@BNbMH4W<CA0iZobPBG^L<4U;>m192]
]PB=Yjl4RJ6X0hFKXPB1UI/4OHnD17V9SPAePhL4LGf116egNaGoool001Coool4JW5c16]`L@A/Kg04
KFm^16i^K@=_KF`4L6eZ175/J@AbJfL4LfYV17AYI0=dJF<4MFQQ17IWH0AgIel4NFIN17YVG@AkIE/3
R71T18QaI`B7LFP4QW1X18EaJPB4L6T4PfiX0h9_JPB4Lg04QgQe18YlN@B4MW@4QGQf0h=eM0B1MG@4
OgIe17edL`AlNGT4O7]k17f0P@>1QXL4Ri>D19BPX@BFZJX4V:ja19Vc^0>I]K`4V;S019Vla`BL`/d4
W/OD1:3;f@BPbMD3WlG@19bob@BH^<84U;6j192[/`B;Y:`3QijU18>GW@AoTIH4NX^@17J4R@AbOX84
KGQk5Oooo`005?ooo`AZLG<4Jg1a16a_L0A]Kfh4KVi]0fm]K0A`KFX4LFaY179[I`AcJVH4M6UT0gAY
H`AeJ644MVMP17MWG`AiIUh4NVIM17]UF`>8L6@4R75W18MaJ0B6L6P4QG5Z18A`J@B3KVP3PVmZ18Ac
L0B7N7D4RWai18AfM0B5N7H3PgEd185eM0AoMWD4OGAc17aiN@AlNg/4OH210h66Q`B;Ti@4U:2Q19JY
ZPBH[[44VK>h0iVe_0BH^<04VKc719c2c@BNam@4X<_I1:39e@>OaM04W;o919Rh`PBD/KX4T:^c18^T
[0>7WZD4PiNM17nAUPAjRi04MXB9179nPPA]N7/Eoooo000Doooo16YaL`A[L744K6m`16e_KPA^KVd3
Kfe/171]JPAaK6T4LV]W17=ZIPAdJF@3M6US17EXH@AfIf04MfMO17UVGPAjIUd4NfEK0hQ`I0B8LFL4
Qg5X18I`J0B5LFX4Q71Y18=^J0>2KfX4Q7=`18MhM@B:O7T4Q7Id18EhMP>3MG@4PGEd17mfM@AmM7<4
O7Ui17akN`AmP843PHJ718^CU0BDX:44UZVZ19R^/@BI/kP3VKFl19Rh`0BI_<L4W<;=19k7e0BPbmT4
X<WE0io5d0BL_lT4V;S219Ba^PB@Zk<4RjB/0hNNY@B3Uid4Oi6F17Z;T0AfQ8T4LWj216ehNaGoool0
01Coool4JW5c16]`L@A/Kg04KFm^16i^K@=_KF`4L6eZ175/J@AbJfL4LfYV17AYI0=dJF<4MFQQ17IW
H0AgIel4NFIN17YVG@AkIE/3R71T18QaI`B7LFP4QW1X18EaJPB4L6T4PfiX0h9_JPB4Lg04QgQe18Yl
N@B4MW@4QGQf0h=eM0B1MG@4OgIe17edL`AlNGT4O7]k17f0P@>1QXL4Ri>D19BPX@BFZJX4V:ja19Vc
^0>I]K`4V;S019Vla`BL`/d4W/OD1:3;f@BPbMD3WlG@19bob@BH^<84U;6j192[/`B;Y:`3QijU18>G
W@AoTIH4NX^@17J4R@AbOX84KGQk5Oooo`005?ooo`AZLG84Jg1a16a_K`A]KVh4KVi/0fm]J`AaK6T4
LV]X17=[IPAcJVD4M6US0gEXHPAfIf04MVIN17MUG@AiIE`4O6IM17aUFP>?MFT4Rg9X18UaJ0B7L6L4
QW1Y18E_J0B3KFH3PVeX18=_K0B2LW04RWek18MlN@B6NWT3QGYi18=hM`B1NGP4OgUh181nOPAoOh04
OX>40gf4QPB2SHl4SYVK19ZYZPBL/K@4WKFj0i^g_PBJ^L44Vkc619g1c0BOam@4XLcK1:?<f@>Tb]H4
XLG?19bma`BH][l4Tjng18jW[`>:X:L4QIZP182CV0AlS944MhF:179oP`A^N7/Eoooo000Doooo16Ya
LPA[L744K6m_16e^KPA^KV`3Kfe[175/J@AbJfP4Lf]V17=ZI@AdJF<3MFQR17IWH0AfIUh4MfEM17UU
G0AlIUd4O6EJ0hmeJ@B;LVP4RG5X18M`I`B6L6T4QFmX18=]IP>2KFP4Pfm/189bL0B:OG/4Qgai18Ij
N@>5NWT4PgQg185iN0AoNGP4P7in17moP0AnPh@3OHB618:=S`B>VI/4VZVZ19ba]0BM]KX3VkNn19Zi
`@BK_<H4WL7<19o7e0BQc=/4XlcI0jC:ePBQaLl4W;g719Rf_`BC[kL4SZN_0hZPY`B5VZ04P9>H17b<
T@AgQHX4LWn316ihNaGoool001Coool4JW5b16]`L@A/Kfl4KFi^16i^K0=_KF/4LFaY179[J0AcJfH4
LfYU17AYH`=eJ684MVMP17IVGPAgIEd4NFEL17aVG@AlIEX3SgEY18]bJ0B9LFP4Qg1W18I`J@B5KfP4
PfeV0h9]J0B3Kf`4PW9`18YmN`B7O7T4QWYi0hEjN@B3N7L4PGUh17miN0B0OWh4Ogn017j3Q0=mQ8H4
PXf?18jIV`BJZJX4W;6d19fe^P>K]kh4V[W119^laPBM`L`4WlOD1:7<f`BSc=T3Y<[F1:75c`BL_LL4
V;Jo19>_]`B>Yjl3RZ2W18FJX0B0TiP4O8bA17N5RPAbOh<4KWQk5Oooo`005?ooo`AZLG84Jg1a16a_
K`A]KVh4KVi/0fm]J`AaK6T4LV]X17=[IPAcJVD4M6US0gEXHPAfIf04MVIN17MUG@AiIE`4O6IM17aU
FP>?MFT4Rg9X18UaJ0B7L6L4QW1Y18E_J0B3KFH3PVeX18=_K0B2LW04RWek18MlN@B6NWT3QGYi18=h
M`B1NGP4OgUh181nOPAoOh04OX>40gf4QPB2SHl4SYVK19ZYZPBL/K@4WKFj0i^g_PBJ^L44Vkc619g1
c0BOam@4XLcK1:?<f@>Tb]H4XLG?19bma`BH][l4Tjng18jW[`>:X:L4QIZP182CV0AlS944MhF:179o
P`A^N7/Eoooo000Doooo16YaLPA[L744K6m_16i^K@A_KF`3L6eZ175/J@AbJfL4LfYU17AYI0AeJ683
MVMP17IVGPAfI5`4MV=J17QSF@B0JEl4QFaQ0hedJ0B;LVP4RW5X18QaJ0B7L6T4QViW18=[I@>2K6L4
PFaY181]J`B6M784QWMe18IhMP>6NWP4Q7Ug189jN0B2NWX4PX2018:3P`B2R8T3PHR:18B?TPB8UYP4
UJ>V19nc]@BO^;/3W[Vo19bi`@BL_<H4W/7<1:36d`BQc=T4Y<kL0jG<fPBVb]D4X<;<19^j``BF/[/4
TJ^b0hbSZPB7W:84PYFJ17f>T`AhQh/4Lgn316ihO1Goool001Coool4JW5b16]`L@A/Kfl4KVi]16m]
K0=`KFX4LFaY179[I`AcJVD4M6UT17EXHP=fIf04MVIN17ITG0AfHeX4N6=I181YG`B5K643SGAX18]b
J0B:LFP4R75X18M`J@B6KVL4Pf]U0h9/I`B1K6T4P6e[18IdLPB6MgD4QWQf0hIjN0B4NGL4PWYh189j
NPB2P804PX>318:8R@>1R8X4Q8nB18RFV0BEXjH4Wk>e19nh^`>N^Kl4W;W119blaPBN`L`4X<KC1:7<
f@BTc]`3YLcJ1:K:e@BP`/`4Vk[319Jb^`BAZk83S:>Z18NLXPB2UIX4OHjC17R7R`AcOh<4KWQl5Ooo
o`005?ooo`AZLG84Jg1a16a_K`A^KVd4Kfe/0g1]JPAaK6T4LV]W17=ZI@AdJF@4MFQR0gIWH0AfIUh4
MVAL17ISFPAhHeT4P6UO18E/H@>=M6P4Rg9X18YaJ0B8LFP4Qg1Y18I^I`B3JfD3PVaW185/J@B0KF/4
QWAb18IgM@B6N7H3QWYh18AiM`B2NWP4PWYj18:0P0B2Ph<4PXR90h68RPB4Si84R9JH19FSYPBO/kD4
WkRk0iji_`BL^L44W;c619k1c0BPa]<4XLcI1:C>g0>Uc=X4Y/[E1:32c0BK^/<4U[:k196[/P><XjX4
QibR18:EVPAmSY<4N8N;17=oP`A^N7`Eoooo000Doooo16YaLPA[L704KFm_16i^K@A_KF/3L6aZ179/
J0AcJfH4M6YU17EYH`AfJ643MfMO17MUG@AfHeX4MF1G179MDPAnIU`4S75U0h]bIPR;LFL4RW5W18U`
J0B7KVH4QFaU0hE_J@B7Lfl4QW=`18McL@B7MG<4QWEc0hEeM0B4MG<4PWIe189gM`B2NW/4PWn118B6
Q`>5RH/4QXnB18VFV@B?WZ84W:nb1:6h_0>P^[l4WK[119fla@BN`L/4XLKB1:;;f0BVd=h3[]CR1:W>
f@BUa]44Wkk719Vf_PBD[[D3SZJ]18VNY@B3Ui`4OXnD17V8S0AdP8@4KWUl5Oooo`005?ooo`AZLG84
Jg1`16e_K`A^KVd4Kfe[0g1/JPAbK6P4Lf]V17AZI@AeJF<4MVQQ0gMWG`AgIEd4MV=J17EPE`AbGE84
OVIL18aaI@>;LVH8Rg5W18YaI`B9L6P4QfiV18E/I@>5KfT4Qg=_18IcL0B7Lg44QgEc18IeL`>5MG@4
Q7Ec189fM@B2MgL4PWYk189oP@B4QXL3QHV;18J?TPB9UYT4SijR19b_/PBQ^;`3X;Zo19fj`@BM_<D4
W/7;1:76dPBRbmP4Y]3N0jkDhPBYc]T4YLKA19nna`BI][h4U:je0hjV[@B9WZD4PiNL17j?U0AiR8`4
M82416iiO1Goool001Coool4JW5b16]`L0A]Kfl4KVi]16m]J`=`K6X4LVaX17=[IPAdJVD4MFUS17IX
H@=gIel4MfEM17ISFPAeH5L4LUeB17iVG0B<LFD3Rg9V28]aI`B:LFL4RG1X18M^IPB5K6D3QFmY18Mc
K`B6Lg04Qg=a18MeL`B6MG<3QGEd18AeL`B2MWD4PWMg189jN`B2Oh44Q8J70hF9R`B6Si84RIJI18nN
XPBL[k84XKRl0j2j_`BM^/44WKc519k1b`BQa]84X/_H1:K@gP>^e>84ZLkI1:G6d@BO_/L4VKJn19B^
]@>>YZd4RIjU18>GW0AnSi@4NHR<17B0Q0A^NG`Eoooo000Doooo16YaLPA[L704KFm_16i^K@A_KF/3
L6aZ179/J0AcJfH4M6YU17EYH`AfJ643MfMO17MUG@AfHeX4MF1G179MDPAnIU`4S75U0h]bIPR;LFL4
RW5W18U`J0B7KVH4QFaU0hE_J@B7Lfl4QW=`18McL@B7MG<4QWEc0hEeM0B4MG<4PWIe189gM`B2NW/4
PWn118B6Q`>5RH/4QXnB18VFV@B?WZ84W:nb1:6h_0>P^[l4WK[119fla@BN`L/4XLKB1:;;f0BVd=h3
[]CR1:W>f@BUa]44Wkk719Vf_PBD[[D3SZJ]18VNY@B3Ui`4OXnD17V8S0AdP8@4KWUl5Oooo`005?oo
o`AZL784K6m`16e^KPA^KV`4L6e[0g5/J@AbJfL4M6YU17EYI0AfJF84MfQP0gQVGPAhIE`4Mf=I17AN
E@A_FTl4MV1G18I^H`>;LFH4S75W18aaJ0B;LFL4RW5X18U^IPB7K6D3QfmX18YfL@R:Mg@4RGMd18Qg
M0>7MW@4QWId18AgM@B4NGP4Q7al18F0P@B6QHL3RHV<18Z>TPB<U9P4Si^Q19JV[0BN/kL3X;Rn19ji
`0BN^lD4Wl3:1:75d@BRbMH4X/_I0k;Hi0B_d]h4Z<[D1:;1b`BL^L44U[2h0i2X/0B;X:L4QIRN17n@
UPAjRHd4M86516miO1Goool001Coool4JW1b16a_L0A]KVh4KVi/171]J`=aK6T4LV]W17AZI@AeJF@4
MVUR17MXH0=hIUh4N6EL17MSF@AdGUD4KeY?17IPE`B6KV<3Rg5V18aaI`B<LFP4Rg5W18YaJ0B9KVH4
QfaU0hM_J0B:MW48RWMd18UgM0B8Mg@3QgId18IfM0B4MgD4Q7Uh18AlO0B5P844QXF70hV9S0B:SY84
S9BH18nKX@BFYZ`4W[>g0j2h_PBN^L04W[_519o0bPBQaM44X/WF1:;;f@>bf>@4[m;N1:S:e0BR`L/4
W;W119J`^0>@Z;04Rj2W18FHWPAoT9H4NXV=17B1Q@A_NG`Eoooo000Doooo16Y`LPA/Kg04KFi^16i^
K0A`KF/3LFaY179[I`AdJVD4MFUT17IYHPAgJ603N6IN17QUG0AgHeT4M5iE16mJC`AfH5L4QViS0h]a
IPB<LFL4S75X18]aI`B:LFP4RFiV18M/I@>7KfP4RWIa28YgM0B9Mg@4R7Md0hMfM0B6MW@4Q7Me18Ai
N0B4O7`4QH2118J5Q`>9RH`4RXjB18bDV0B?Vj44UZJ/19jc]`>P^;h4W[W019jka@BO`<X4XLGA1:;9
ePBRbmT3/]ST1:oBgPBXb]@4X/7;19bi`@BF/;P3T:R`18^PY`B5V9h4Oi2F17Z9S@AdPHD4KgUl5Ooo
o`005?ooo`AZL784K6m`16e^KPA^KV`4L6e[0g5/J@AbJfL4M6YU17EYI0AfJF84MfQP0gQVGPAhIE`4
Mf=I17ANE@A_FTl4MV1G18I^H`>;LFH4S75W18aaJ0B;LFL4RW5X18U^IPB7K6D3QfmX18YfL@R:Mg@4
RGMd18QgM0>7MW@4QWId18AgM@B4NGP4Q7al18F0P@B6QHL3RHV<18Z>TPB<U9P4Si^Q19JV[0BN/kL3
X;Rn19ji`0BN^lD4Wl3:1:75d@BRbMH4X/_I0k;Hi0B_d]h4Z<[D1:;1b`BL^L44U[2h0i2X/0B;X:L4
QIRN17n@UPAjRHd4M86516miO1Goool001Coool4JW1b16a_L0A]KVh4KVe/171/JP=aJfP4Lf]V17AZ
I@AfJF<4MfQQ17UWG`=jIUh4NVEL17YTF@AiHEL4Nf=H17mWG0B6KF83S75V18icJ0B>LVT8SG5X18]_
I`B9KVH3RG1Y18afL0B>NgH4SGYg18aiM@B:N7D3RGQe18QfM0B6MgD4QWYi18InO@B7PX84RHJ80hb<
SPB?TYD4TIRL19BOY0BHYj`4WK2e0ine^`BO^;l4W[_319nob@BQa<l4XLOD1:;;f@>ef^H4/]KQ1:c=
f0BUa<h4Wkc519Vc^`>CZk84SJ:Y18NJX0B1TYL4NhZ>17F2Q@A_NWdEoooo000Doooo16Y`LPA/Kg04
KFi^16i]K0A`K6X3LF]X17=[IPAdJVD4MVUS17MXH@AiIel3NVIN17YUG0AjI5T4NF5G17]SF0AoIe`4
QVeR0haaIPB>LfP4SW9Y28eaJ0B;KfL4RFiV0hU`J@B<MW04SW]f18ejM`B<NGD4RWQe0hUhM@B8MW@4
QWMe18IjN@B6OWd4Qh:218V6R0><S8h4Si:E196HW0BDWj@4V:N/19f`]@>O]K/4WkRo19jk``BO_lT4
XLC?1:77e0BRbmT3]M[V1;;Fh@B/cMP4YLC>19nla@BI/k/3Tj^b18fRZ@B7VZ04PI:G17^:SPAePXD4
KgYm5Oooo`005?ooo`AZL784K6m`16e^KPA^KF`4L6aZ0g5[J0AcJfH4M6YU17IYH`AgJ644NFMO0gYV
GPAjIE`4NVAI17UQE`AkHeP4OfML18I]HP><LFH4SW=X18ibJ@R=LFP4RfmW18U^IP>9L6T4S7I`18ik
MPB=NWL4S7Ue18YhM@>9N7D4R7Id18IgM@B6NWT4QWim18N2PPB9QXP3S8b>18nBU@BAV9`4U9nT19RW
[0BM/;D3WkFk19nh_`BN^l<4Wko91:74c`BQam@4X/_I0kGJiPBbe^44[<gH1:G4cPBO_<D4VK>k0i>[
/PB=XZT4QiZP186BU`AkRXh4MH:516mjOAGoool001Coool4JW1b16a_L0A]KVh4KVe/171/JP=aJfP4
Lf]V17AZI@AfJF<4MfQQ17UWG`=jIUh4NVEL17YTF@AiHEL4Nf=H17mWG0B6KF83S75V18icJ0B>LVT8
SG5X18]_I`B9KVH3RG1Y18afL0B>NgH4SGYg18aiM@B:N7D3RGQe18QfM0B6MgD4QWYi18InO@B7PX84
RHJ80hb<SPB?TYD4TIRL19BOY0BHYj`4WK2e0ine^`BO^;l4W[_319nob@BQa<l4XLOD1:;;f@>ef^H4
/]KQ1:c=f0BUa<h4Wkc519Vc^`>CZk84SJ:Y18NJX0B1TYL4NhZ>17F2Q@A_NWdEoooo000Doooo16Y`
LPA/Kg04KFi^16m]J`A`K6T3LV]W17AZIPAeJF@4MfUR17UXH0AjIel3O6MM17eVF`AnIEX4P6EI189X
G@B6KF84Rg5V0hmdJ0R@MFX4T7AZ18mcJ@B>LFP4SG1W0habJPB=MFl4Sg]f191mN@B>NgL4SGYf0h]j
MPB:NGH4R7Qe18QjN0B8Ogd4RXB318^8R0>>SXl4TIBF19BJW@BGX:@4VZN/19j_]0>O/kT4WkJm19nj
`PBP_/P4X<?=1:36dPBOb=H3^=cX1;KJi@B_dM`4ZLSB1::ob0BK][h3UJfd18jTZ`B8W:44PY>H17b;
S`AePXH4KgYm5Oooo`005?ooo`AZL784K6m`16e^KPA_KF/4L6aY0g9[I`AdJVH4MFUT17MYHPAiJ604
NVMO0gaWG@AmIU/4OVEJ181UF@B2J5d4QVeR18]aIP>?M6P8T7EZ191dJPB?LfT4SW5X18e`I`><LVX4
SGE_18mkMPB@OGT4SW]g18ejMP>;NWH4RWUf18QhM@B8NWP4R7mm18Z4P`B;R8P3SXj?196DUPBDVYd4
Uj2T19ZW[0BN[k@3Wk>i19nf_@BO^/84X;k81:33c@BPa]84WlSF0kSLj0Bff^D4[m7L1:W8dPBR_lP4
VkJn0iF]]0B>Y:/4R9bQ18:CV0AlRhl4MH:616mjOAGoool001Coool4JW1b16a_L0A]KVh4Kfe[171/
J@=bJfL4M6YV17EYI0AgJF84NFQP17YWG`=lIed4OFIK17iUFPB0IET4PVQM18I]HPB;LFH3SgAX291e
JPB@M6X4Sg=Y18iaJ0B=L6L3S79Z18eeK`B?NgH4T7ei18ikM`B=NWH3RgYf18YiMPB8N7D4R7Yh18Qo
O@B:Q8<4RhR80hj>S`BAU9H4U9ZM19NPY0BJYj`4WZnd0inc^@BO][d4Wk[21:2nb0BP`ld4X<KB19o8
eP>hg>P4]][U1:oAg0BYb=84X[o819^f_P>E[K@4SZB[18RLX@B2TiP4O8^?17F2QPA_NWdEoooo000D
oooo16Y`LPA/Kg04KFi^16m]J`A`K6T3LV]W17AZIPAeJF@4MfUR17UXH0AjIel3O6MM17eVF`AnIEX4
P6EI189XG@B6KF84Rg5V0hmdJ0R@MFX4T7AZ18mcJ@B>LFP4SG1W0habJPB=MFl4Sg]f191mN@B>NgL4
SGYf0h]jMPB:NGH4R7Qe18QjN0B8Ogd4RXB318^8R0>>SXl4TIBF19BJW@BGX:@4VZN/19j_]0>O/kT4
WkJm19nj`PBP_/P4X<?=1:36dPBOb=H3^=cX1;KJi@B_dM`4ZLSB1::ob0BK][h3UJfd18jTZ`B8W:44
PY>H17b;S`AePXH4KgYm5Oooo`005?ooo`AZL784K6m_16e^K@A_KF/4LFaY0g9[I`AdJVD4MVUS17QX
H@AjJ5l4O6MN0giWG@B0Ie/4PVMJ18EYG0B8K5l4S75U18mfJ`>CMf/4TgU]19=hK@BCMf`4TgE[199d
J`BALVX3T7=[191fK`BBNgD4Tgmj195mN@B?NWL3SGYf18ajMPB9NGD4RG]h18YnO@B<QH@4SHV90i6@
T0BDUYP4V9bN19VQY0BKYj/4WZfb0ina]`BP]K`4X;W11:2ma`BQ`/`4X<CA19c5e0>cf>D4^moZ1;?E
h0B/bmD4Y<7:19fh`0>G[kH4T:J]18ZMX`B3U9X4OHb@17J3Q`A`NWdEoooo000Doooo16Y`LPA/Kfl4
KFi]16m]J`AaK6T3LV]W17AZI@AfJF<4N6QQ17YXG`AlIeh3OVMM181WF`B2IeX4QFUL18Q/G`B<LFD4
SgI[0i=gJ`BCNFd4TgQ]19=gK0BCMF/4TWA[195bJP>@Lf/4T7I_199kM@BCOgX4TGei18mjM`>=NWH4
S7Yf18UiM@B9NgP4RWim18b5Q0B=RHT3TI2@19BFV0BHW9h4VJ6T19^WZ`BN[K83Wk6g1:2e_0BP^L44
X;g71:72c0BPa=44W<GD0k?Hi@BkgnX4/mGP1:c;e@BT`LX4WKS00iN_]PB@YZd4RYfS18>DVPAmS904
MX>7171jOAGoool001Coool4JW1b16a_K`A]KVd4Kfe[175/J@=bJfL4M6YU17IYH`AhJ644NVQO17aW
GP=nIed4P6MK189WFPB5JE`4R6aO18aaI@B?MV/3TgM[19=iK@BCN6d4TgM/19=eJ`BBM6/4TG9Z0i1c
J`B@MVl4TW]e19=oNPBAOGT4SgYg0hejMPB<NWH4RGUe18UkN0B:OWd4S8F418f9R@>AT904U9JH19RL
WPBIXJ@4VjN[19j]/P>O/KL4X;Fl1:2i`@BP_LL4XL;<1:34d@BLaM@3/mSU1;_OjPBceN04[<_E1:C1
bPBM^<03Ujnf192V[@B:WJ<4PiBJ17f<T0AfPhL4L7Ym5Oooo`005?ooo`AZL784K6m_16e^K@A_KF/4
LFaY0g9[I`AdJVD4MVUS17QXH@AjJ5l4O6MN0giWG@B0Ie/4PVMJ18EYG0B8K5l4S75U18mfJ`>CMf/4
TgU]19=hK@BCMf`4TgE[199dJ`BALVX3T7=[191fK`BBNgD4Tgmj195mN@B?NWL3SGYf18ajMPB9NGD4
RG]h18YnO@B<QH@4SHV90i6@T0BDUYP4V9bN19VQY0BKYj/4WZfb0ina]`BP]K`4X;W11:2ma`BQ`/`4
X<CA19c5e0>cf>D4^moZ1;?Eh0B/bmD4Y<7:19fh`0>G[kH4T:J]18ZMX`B3U9X4OHb@17J3Q`A`NWdE
oooo000Doooo16Y`LPA/Kfl4KFe]16m/JPAaJfP3LfYV17EYI0AgJ684NFQP17]WGPAnIed3PFML18AX
F`B7J5X4RVeO18e`H`BBMfX4UGU]0iIjKPRGNfl4UWU_19IhK@BEMfd4UGI/0iAfK@BCMfl4U7]e19Eo
NPBDOgX4TWeh0i1lN0B>NgL4S7Yg18]lN@B=PGl4ShJ5196:RP>DTI44UiNI19^NX0BMXjH4WZR[19n/
/@>P/;H4XKBk1::i`0BS_LH4Xl7;1:74d0BLa=83YloM1;KLj@BifnH4[/gG1:K3c0BO^/83VK6h19:X
[PB;WZ@4Q9FK17j<T@AgPhL4L7Yn5Oooo`005?ooo`AZL784K6m_16e]K@A_K6X4LF]X0g=ZIPAeJF@4
MfQR17UXH0AkIeh4OVMM0h5WG0B4J5/4QfQJ18Y]G`B=L6<4TWMZ19EiK@>FNVh8Ug]_19IiK`BFN6d4
UGM]19EfK0>DMVd4TgM_19AkM@BEOgX4U7mj199mN0>@O7P4SW]g18ajM`B;O7T4SH5o18n6Q@BARXX3
U96A19NGV@BKWZ04WJ>V19jXZ`BO[;43X;2f1:6d^`BR^L04Xkg61:?1b`BQa=04W<CB0jO?g@Bfg>T4
^M_V1:k=e`BV`l`4Wk[20iVa^0BBZ:h4RijT18BEV`AnS944Mh>7171jOQGoool001Coool4JW1b16a_
K`A]KFd4KfaZ175[J0=cJVH4MFUT17MXHPAiJ604NfMN17iWG@>1Ie`4Q6QK18MXFPB:KEl4SG1S199g
JPBENFd3UWY^29MkK`BFNFl4UWQ]19EgK@BEMV`3U7I]19=gK`BDNgD4UGmj19AoNPBBOGP3T7ah18ik
M`B<NWL4Rgai18f1O`B?QXD4THZ:0iBAT@BGUiT4VijP19fSYPBNZ:/4Wjba0j2`]PBQ];/4X[W01:>m
aPBS`L/4XLC@19c4dP>Wcmd4]]cY1;WKiPB^cML4Y/?<19nj`P>I/KP4TZR^18^NY0B4UI/4OXbA17N3
Q`A`NWhEoooo000Doooo16Y`L@A/KVl4KFe/16m/JPAaJVL3LfUU17EXH`AgJ644NVMO17eWG@B0Ie`3
PfMK18MXFPB:Je`4Sg5R19=gJ0BIOFl4Vga`1i]mL@BJOG84VWaa29UkL0NHNW04Ug]b19MmMPBGP7T4
UX1j19AnN@>BOWT4T7ah18imN0B=OW/4Sh>01968QPBESX`3Ui>C19bJV`BNX:84X:FW1:6Y[0BQ[;43
X[2f1:Be^`BT^L44YKk61:K2c0BVam44Y<SC0jK=fPB/e>44/]KQ1:k>f0BXaLh4XKc40i^b^PBDZK04
SJ2V18JGW0AoSI84MhB8171kOQGoool001Coool4JW1a16a^K`A]KF`4KfaZ175ZI`=cJFD4MFQS17MX
H@AjIel4OFMM181WG0>3Ie/4QfQJ18Y[G0B?LF84TgMX19UmK`BKO707Vgea19YmLPBJO748VG]`1iQj
L0BGNg84Ugef19N0N@BFP7X4U7ii0i9nN@B@O7P4SWeh18enN`B?Ph04THR619F>S0>GTi<4W9ZK19jP
XPBPYJL4XJV/1:6//@>R/;H4Y;Fk1:Bi`@BU_/H4Y/;<1:K7d@BTb=<3Y/gJ1:cDh@Bbe^44[/kH1:S5
cPBQ_<@3Vk:j19BY/0B=X:H4QYNL17n=TPAgQ8P4L7]n5Oooo`005?ooo`AZL744K6i_16e]K0A_K6X4
LFYW0g=YI@AeJ6<4MfQQ17YWG`AmIed4P6ML0h=WF`B7J5X4RV]L18maHPBCMfP4VGe_19]lL0NKOG44
VWeb19YlL@RINg07V7Y`19MkLPBGOGH4Uh1i19J0NPBDOWT3TWii191lN0B>OGP4SGik18n3P0BAR8H4
UHj<0iNCT`BLVY/4WZ2R1:2UY`BQZJ`4XJba0j:`]PBT]K/4Y;W11:FnaPBV`/`4Y/OA1:C8d`>VcMX4
[=CQ1;;Fh@B^c]P4Z<G>1:6la0>K/[X4U:V`18fPYPB6Ui`4OhfB17N4R0A`NghEoooo000Doooo16Y`
L@A/KVl4KFe/16m/JPAaJVL3LfUU17EXH`AgJ644NVMO17eWG@B0Ie`3PfMK18MXFPB:Je`4Sg5R19=g
J0BIOFl4Vga`1i]mL@BJOG84VWaa29UkL0NHNW04Ug]b19MmMPBGP7T4UX1j19AnN@>BOWT4T7ah18im
N0B=OW/4Sh>01968QPBESX`3Ui>C19bJV`BNX:84X:FW1:6Y[0BQ[;43X[2f1:Be^`BT^L44YKk61:K2
c0BVam44Y<SC0jK=fPB/e>44/]KQ1:k>f0BXaLh4XKc40i^b^PBDZK04SJ2V18JGW0AoSI84MhB8171k
OQGoool001Coool4JW1a16a^KPA]KF/4Kf]Y175ZIP=cJF@4MFQQ17QWG`AjIUd4OVIL185VFP>5IeX4
RVMI18i[G0BCLV<4VGa]19j1L`BPPG<3Wh1c19moL`BNOg<4WGmc29enL`BLOW<3W7id19aoMPBKPGT4
Vh9k19V1N`BFOgT3U7ii199lN0B?OGP4Sgmk1964P@BDRXL4V92>0iZEU0BNVi`4XJ6S1:>VZ0BTZZd4
Y:fa0jFa]PBV]K/4Z;[11:VoaPBZa<`4ZlWC1:c;eP>_d]h4/m[V1;;Eh@B_cmT4Z/O@1:BnaP>M];`4
UZ^a18nQY`B7V9d4P8jC17R5R0AaNghEoooo000Doooo16Y`L@A/KVh4KFe[16m[J@AaJVH3LfUT17EX
H@AhIel4NVIM17iVG0B1IUX3QFMJ18YWF@B>Je`4Tg9S19UlK@BNPG<4X85c0in0L`BOOg<4WWmc19eo
L`RMOW<4W7ic0ianM0BLOgH4Vh5i19^2N`BIPG/4UWmi0iAnN@BBO7P4Sgeh18moN`BAQ844U8Z719R@
SP>JUI@4WY^L1:6QX`BSYZP4Y:Z]1:B]/@>U/KH4Y[Fk1:Rj`@BY_lH4Z/C<1:_9d`B/bmH3[m;N1;?J
iPBbeN44[loI1:[7d0BT_/H3WKBl19J[/@B?XJL4QiRM182>T`AhQHP4LG]n5Oooo`005?ooo`AZL744
K6i^16e]J`A_JfT4LFYV0g=YI0AeJ644N6MO17YVG@AnIU`4PFIJ0hEWFPB:IeT4SV]L19=bH`BIO6d4
WX5c1:21L`>OP7<4Wgmc19ioL`BMOg<8WGic19anL`>LOW@4W7mf19^1N@BKPW/4VH5k19IoN@>DOWT4
TWah18mmN0B?Og/4THB119B:Q`BHT8h3VYFD19jKW0BQXJ<4XjJX1:BZ[@BT[K43YK6f1:Je^`BX^/44
ZKo61:[4c0B[bM<4[<_F0joBgPBcf^H4/]GQ1:o?f@BZam04Y;k60ifd_0BFZk44Sj6W18NHW@B0SY<4
N8F8175kOQGoool001Coool4JW1a16a^KPA]KF/4Kf]Y175ZIP=cJF@4MFQQ17QWG`AjIUd4OVIL185V
FP>5IeX4RVMI18i[G0BCLV<4VGa]19j1L`BPPG<3Wh1c19moL`BNOg<4WGmc29enL`BLOW<3W7id19ao
MPBKPGT4Vh9k19V1N`BFOgT3U7ii199lN0B?OGP4Sgmk1964P@BDRXL4V92>0iZEU0BNVi`4XJ6S1:>V
Z0BTZZd4Y:fa0jFa]PBV]K/4Z;[11:VoaPBZa<`4ZlWC1:c;eP>_d]h4/m[V1;;Eh@B_cmT4Z/O@1:Bn
aP>M];`4UZ^a18nQY`B7V9d4P8jC17R5R0AaNghEoooo000Doooo16Y`L@A/KVh4KFa[16mZJ0A`JFD3
LVMR17EVH0AhIUh4NfEL17iUFPB2IET3QfIH18eXF@BCKEh4VWIW1:60L@BUQGH4YHAf0jB4MPBSPWD4
XX5e1:61M@BPPGD4XH5e1:21MP>PPgL4X8Ai1:25O0BOQWh4W8Am19V2O0>FP7X4Tgeh195mN0B@P7`4
TXF119F;R0BITHl3WYNF1::NWPBTXj@4YZRY1:N[[@BX[[83Z;:f1:Zf^`B[^l44[L371:o5c@B`bm@4
/LgG0kCEh0BigNT4^=[U1;?Bg0B]bM84Y/380inf_@BH[K<4T:>X18VIWPB1Si<4NHF9175kOaGoool0
01Coool4JW1a16a^KPA]K6/4KfYX171YI@=bIf84MFIP17QVGPAkIE`4OVEJ189UF@>7IUP4SFQI19=]
GPBJMVL4XH1a1:F5MPBUQ7H3Y8Af1:>2M@BRPGD4XH5e1:21M@BQPGD4X85f0j23M`BPQ7T4X8El19n6
OPBLQ7d4VH9l0iJ0NPBCOGP4TGeh1920O0BBQH44UH^819VAS`>NUiH4XYjN1:BSY0BVZ:T4Yj^]1:R^
/P>X/[H4Z[Jk1:^k`@B]`<L4[lG=1;3;e0BacML3]=GP1;WMj@Bhf^D4/m;L1:g9dPBV`<P3WkJm19R]
/`B@XjP4RIVN186?T`AiQHT4LG]o5Oooo`005?ooo`AZL744K6i^16e/J`A_JVP4L6UU0g9WHPAeIV04
N6IN17]UG0AnIEX4PVEI0hMVF0B=J5T4TfeN19YfI`BQP744YHEf1:F4MP>TQ7H4Xh9e1::1M@BQPGD4
X85e1:61M@BPPGH3X8=g1:24N@BPQG`4WhIn19b4O@BIPW`3UX1j19=mN0BAOGP4T81l19:5P@BERhP4
VI6?0ijGUPBRWYh4Y:>T1:JXZ@BWZjd4Z:jb0jRb]PBZ][/4Zk_11:g0a`B_aLd4/<_D1;7=e`>deN04
^MgY1;SJi@Bcd]`4[LWB1:K0b0>O][d4V:fc192SZ0B9VIh4PHnC17V5R@AaNglEoooo000Doooo16Y`
L@A/KVh4KFa[16mZJ0A`JFD3LVMR17EVH0AhIUh4NfEL17iUFPB2IET3QfIH18eXF@BCKEh4VWIW1:60
L@BUQGH4YHAf0jB4MPBSPWD4XX5e1:61M@BPPGD4XH5e1:21MP>PPgL4X8Ai1:25O0BOQWh4W8Am19V2
O0>FP7X4Tgeh195mN0B@P7`4TXF119F;R0BITHl3WYNF1::NWPBTXj@4YZRY1:N[[@BX[[83Z;:f1:Zf
^`B[^l44[L371:o5c@B`bm@4/LgG0kCEh0BigNT4^=[U1;?Bg0B]bM84Y/380inf_@BH[K<4T:>X18VI
WPB1Si<4NHF9175kOaGoool001Coool4JVma16]]K@A/JfX4KVUW171XI0=bIV44M6EN17MTG0AjI5X4
OV=H18=SEP>8I5D4Sf]K19UcH`BTOFd4[8Mf1:f9N@BZR7T3Z8Ih1:J5M`BUPgH4Y89f1:>2MPBTPgL4
YHAh0jF6NPBUR7`4YHUo1:>9P@BPQgl4WHAm0iV1N`BEOWP4TWeh19:1O0BDQX84V8b919bCT@>PVIP4
Y9nO1:NUY@BYZJX4ZZf^1:^`/P>//kL4[[Nl1:nk`@Ba`LL4/lO>1;G=e@Bgd=P3^mWS1;cNj@Bmh>/4
]mKP1;3<e@BY`/X3X[Ro19Z^]@BBY:X4RYZO18:@U0AjQXX4LGao5Oooo`005?ooo`AZKg44Jfe]16a[
JPA^JFL4L6QT0g9VH@AdIEh4MfAL17YTFPAnHeP4Pf=F0hQTE@B?Je/4VG=S1:AmK@B/QgH4[HUi1:Z8
N@>XQWP4YXEg1:F3MPBTPWH4Xh9f1:B3M`BUQ7P3YHIj1:F8O0BURGl4XhV11:27O`BMQ7d3VH5k19En
N0BBOGP4TX5l19B6PPBHS8T4W9>A0j2IV0BTWil4YjFU1:VYZPBZ[Jh4Zk2b0jbc]`B^]k`4[k_11;71
a`Bcalh4]LgE1;O@f0>kfN<4_=kY1;gPj`Bge^04/<cE1:W2bP>R^;l4VZje19:TZPB:VYl4PY2D17Z6
RPAaO7lEoooo000Doooo16Y_L@A[KFd4K6]Z16iYI`A`J6@3LVIQ17AUGPAgI5`4NVAJ17iSF0B3HeH3
R6AE18m[F`BILf<4Y7e]1:b7MPB]RGT4ZXQi0jR6N0BVQGL4YH=f1:B2MPBSPWH4Y8=g1:F4N0>UQWX4
YHQl1:F9O`BSRH44X8Mo19f4O@>IPG/4UGih199mN0BBPG`4U8J219R<R@BLTi43X9VH1:BOW`BWYJD4
ZJVZ1:Z][PB[/;83[;>g1:jg_0B_^l44/L771;?7cPBecMD4]m3H0k_Ih`Blg^T4_N3[1;OFh0B`c=D4
ZL;:0j:h_`BJ[[D4TZBZ18ZJW`B2T9@4NXJ:175lOaGoool001Coool4JVma16]]K@A/JfX4KVUW171X
I0=bIV44M6EN17MTG0AjI5X4OV=H18=SEP>8I5D4Sf]K19UcH`BTOFd4[8Mf1:f9N@BZR7T3Z8Ih1:J5
M`BUPgH4Y89f1:>2MPBTPgL4YHAh0jF6NPBUR7`4YHUo1:>9P@BPQgl4WHAm0iV1N`BEOWP4TWeh19:1
O0BDQX84V8b919bCT@>PVIP4Y9nO1:NUY@BYZJX4ZZf^1:^`/P>//kL4[[Nl1:nk`@Ba`LL4/lO>1;G=
e@Bgd=P3^mWS1;cNj@Bmh>/4]mKP1;3<e@BY`/X3X[Ro19Z^]@BBY:X4RYZO18:@U0AjQXX4LGao5Ooo
o`005?ooo`AZKg04Jfe]16aZJ@A]J6D4KfIR0g5UG`AcHe`4MV9J17YRE`AnHUD4PV5C0hIQD0B>JET4
WGIU1:^2L@BgSW`4]8im1;2;N`>]RGT4ZXIh1:R4M`RVPgH4YhAg1:R5N@>ZRGd4Zhb01:Z>P`BXSH@4
YH^31:27O`>KPg`4UWmi19AnN@BCPG`4UXN219V=RPBOU983Xi^I1:NPW`BZYZH4[J^[1:j_/0B`/[@3
/;Fh1;:i_@Bc_L84]L;81;O8cPBjcM@4_=7H0l7Ki0C3h>X4`^C^1;cIh`BdcmL4[LG<0jFj`@BM/;H4
U:J[18bKX0B3TID4NhJ:179lOaGoool001Coool4JVm`16]]K@A/JVT4KFQU16mVHP=aIEl4Lf=L17IR
FPAjHUL4OV9E189QD`>6HE04SVUI19efI@B[PW44]hil1;B>O@B`Rg/3[HUi1:Z6N0BXQ7L8YX=f1:N4
M`BXQGT3ZXUm1:^<P0BZSX<4Z8f41:F;P`BPQgl3Vh=l19IoN@BDOWT4Th5l19J7PPBISHX4WiBB0j>K
V@BWX9l4ZZJV1:f[Z`B^[k04/;:d0k2e^0Bb^Kd4/kg21;G2b0Bgb<h4^/gD1;cAf0?1fn@4`n3Z1<;T
kPBlfN<4]<oG1:g5c0>U^/44WK2f19BVZ`B<Vj04Pi6E17^6RPAbO7lEoooo000Doooo16Y_L0A[KFd4
K6YY16eXI@A_IV83LFEO17=SG0AfHUX4NV9G17iRE@B2HE<3QV5@18iYF@BMMVD4Zh9a1;N>O0BdSWd4
/8]k0jf9N@BZQWP4Z8Ag2:J3MPBWQ7L4Z8Ei0jZ9O@B[S804ZXj31:R=Q0BURh<4X8Mo0i^3O0BFOgT4
U7ii19>1O0BFQh84VHf:19nDTP>SViT4Yj2O1:ZVYPB]Zj/4[Zn`1;2b]0>`]KP4/[Vm1;>m`PBe`/P4
]lS>1;[=e0BldMP3`M_T1<?PjPC2i>h4_=WS1;C?e`B]aL`3YK[119f`]PBDYZ/4S9^P18>AU@AkQXX4
LWao5Oooo`005?ooo`AZKg04JVa/16]YJ0A/If@4KFEP0fmSG@AbHEX4MF1G17UPE@AmH5<4PF1A0hEO
CPB:IUD4VgEU1:j5L`BnTgl4^Y:01;F>O@>aRg/4[HMh1:V5M`RXQ7L4ZXIj1:f9O0>`S7l4/8n21:nA
Q@B]TXL4ZHn61:>9P@>MQ7d4Ugmi19AnN0BCPG`4UXN219Z=RPBPUI83Y9bJ1:VQX0B]YjH4/:b/1;:`
/0Bc];D3];Ni1;Bj_PBf_l<4^<?81;_8c`BmcM@4`=;I0lOLi0C:i>d4bNSb1<7Mi@Bid]X4/LO>0jRm
``BP/[P4UjN/18jMX@B5TYH4NhN;179lOaGoool001Coool4JVm`16Y/K0A[JFP4K6MT16eUH0=_Hed4
LV5J17EPE`AiH5D4OF1C185PD@>5Gdh4RVIE19]eI@B^QG<4_Y=o1;ZBP0BeSWd3/H]k1:f7N0BYQGL8
Z8Ag1:Z6NPB]RG`3/8ao1;2?PPB_THD4[I:71:V?QPBSRH43WHAm19MoN@BDOWP4Th5l19J7PPBJSHX4
X9FB0jBLVPBYXJ04[JNV1;2/[0Bb/;04/kBe0kBg^@Bd^[h4][o31;S3b0Bkb<l4_LgD1<3Bf@?7g>@4
b^C]1<WXlPC1gND4^M;J1;77cP>X_L<4X;:h19NW[0B>WJ44QI:F17^7R`AbO7lEoooo000Doooo16Y_
L0AZK6`4JfUX16aWI0A]IF03Kf=M179QFPAeH5L4NF1E17ePD`B1H543QEm>18YVE@BKMFD4[XEc1;jC
O`BjTX04]Him0k6;N`B]QgP4ZHEg2:R4M`BZQWX4[HUl0k2<O`B`Sh84[i651:fBQ`BYShH4XhV10if4
O@BGOgT4U7ih19>1O0BFQh84VXf:1:2ETP>TW9X4ZJ6P1:fWYPB`[:`4/[2`1;>d]@>d]kT4];Zn1;Jo
``Bh`lP4^lS?1;g=e0C0d]T3amcT1<[Tk@C9j?84`MgU1;WBfPBaalh3Z;g31:2b^0BGYj`4SYfQ18FB
UPAkQh/4LWao5Oooo`005?ooo`AZKg04JVa/16]YJ0A/If@4KFEP0fmSG@AbHEX4MF1G17UPE@AmH5<4
PF1A0hEOCPB:IUD4VgEU1:j5L`BnTgl4^Y:01;F>O@>aRg/4[HMh1:V5M`RXQ7L4ZXIj1:f9O0>`S7l4
/8n21:nAQ@B]TXL4ZHn61:>9P@>MQ7d4Ugmi19AnN0BCPG`4UXN219Z=RPBPUI83Y9bJ1:VQX0B]YjH4
/:b/1;:`/0Bc];D3];Ni1;Bj_PBf_l<4^<?81;_8c`BmcM@4`=;I0lOLi0C:i>d4bNSb1<7Mi@Bid]X4
/LO>0jRm``BP/[P4UjN/18jMX@B5TYH4NhN;179lOaGoool001Coool4JFi`16U[J`AZJ6L4JVER16aS
GP=]H5X4L5mG17=NE0AgGU84OEiA189NC`>6HE44RfMF19mhIPBdR7D4aIN21;nDP@BiT7h3]8el1:n8
N@BYPgD4YX5c1:F0L`BWPWH4[HMj0k><O`BfTH@4/i:61;6DR@B^U8X4YHb40ij5O@BHOgP4U7eg19>0
NPBFQX44VXb:1:6ETP>TViT4Z:2O1:jWYPBb[Jd4]K:a1;Rf]`>h^K/4^;bo1;W0a0Bla<T4_/W?1<3=
d`C2dMP3b]_R1=3VkPC>jo@4a^3X1;gEg0Beb]03[;o51::d^@BIZJh4T9jR18JCU`AlR8/4Lgf05Ooo
o`005?ooo`AYKW04JF][16YXI`AZIF84K6=N0fePFPA`GeL4LeiD17MNDPAmGU44PUi?0hIQD@B;IeH4
WgQV1;B8M@C5Uh84_iB11;V@OP>dSG`4[hQi1:V3M@BVPG<4YH1c1:N2MPB]QgX3/hao1;JAQ0BcTXH4
/IB91:jDRPBUS8@3WXEm19QoN0BDOGL4Th1j19J6P@BJS8X4XIFB0jBKV@BXX9l4[ZNV1;:][@Be/[44
^;Jg0kRi^`Bh_;l4^L341;c4b@BnbLl4`<gC1<;Af0?:fn84d>K^1<k[m0C6h>P4_MGL1;G:d0>/_lD4
X[Bi19VY[PB@WZ84QY>G17b8R`AcOH0Eoooo000Doooo16U^L0AYJf/4JVQW16YUHPA/Heh3KF1J171O
E`AcGU@4MeiB17eND@B2GTl3QV5A18]WEPBON6H4]8Qe1<FGPPBoU844^I1n0kB=O0B_R7T4ZH=e1:J1
L`BUP7<4Yh9f1:f7NP>cS7l4]Y641;>BQPBaU8T4[YB:1:F<Q0>NQGd4V7mh19AmM`BCP7X4UXJ119Z<
RPBQUI83Y9^I1:RPW`B^YjH4/Zf]1;Fb/@Bh][L3^;Vk1;Rl_`Bi`<@4_<C91;k9c`C0cM<4`]7H0l[K
hPC@i^h4c^_d1<KPj0BmeM`4]L[@0jboa@BR];T4VJV^192NXPB6TiL4O8R;17=mP1Goool001Coool4
JFi`16U[J`AZJ6L4JVER16aSGP=]H5X4L5mG17=NE0AgGU84OEiA189NC`>6HE44RfMF19mhIPBdR7D4
aIN21;nDP@BiT7h3]8el1:n8N@BYPgD4YX5c1:F0L`BWPWH4[HMj0k><O`BfTH@4/i:61;6DR@B^U8X4
YHb40ij5O@BHOgP4U7eg19>0NPBFQX44VXb:1:6ETP>TViT4Z:2O1:jWYPBb[Jd4]K:a1;Rf]`>h^K/4
^;bo1;W0a0Bla<T4_/W?1<3=d`C2dMP3b]_R1=3VkPC>jo@4a^3X1;gEg0Beb]03[;o51::d^@BIZJh4
T9jR18JCU`AlR8/4Lgf05Oooo`005?ooo`AYKVl4J6YZ16QWI@AYHf04JF1L0fYME`A/Fe<4L5YA17EK
C`AlGDl4Pei?0hMSD`B9IUL4WWQV1;J:MPC9VXD4`iJ21;fBO`>hSWd4/HUi1:^4M@BTOW04X7e`19ak
K`BRP7<3[8Mj1;:=P0BbSX84[Xn51:bAQ`BURh<3WXEm19QnM`BCO7H4TWii19B5P0BHRXL4XYJC0jBJ
V0BYX9l4/JRV1;J_[PBh/k84_;Rh0kbk_0Bk_/04^l341;g5b@C1bLh4`lkC1<OCf@?Ag^@4e^S_1=C]
m@C;h^T4`]ON1;W<dP>_`LH4Y[Jk19bZ[`BBWj<4QiBG17f8S0AcOH0Eoooo000Doooo16U^K`AXJVX4
J6MU16USH0AYH5`3JUeG16aKD`A`FU44ME]?17aMC`B3GTl3Qf=C18UVE`BNN6H4]XYf1<VJQ@C3UX84
_I9o0kR>O@BaRGT4ZhAe1:AnL0BPOG04W7]_1::0L`>/QgX4/Xf01;:>PPB^ShD4[9671:F;P`>NQGd4
V7ig19=lMPBBOWT4U8F019R:Q`BRUY<3Y9ZH1:VPW`BaZ:H4]Zn^1;Rc/PBl^;P3_;^l1;^n`0Bk`<@4
_LG91<79cPC3c]<4am?I0m7Ni0CFj>l4e>ge1<_Rj@C2emh4^LcB0jo1aPBV][/4W:Z_19:OX`B7U9L4
OHR<17=mP1Goool001Coool4JFi_16QZJPAXIfD4JF=P16UPG0=ZGEL4K5]C171JD@AeFdl4O5e?18=N
C`>7He<4RFIG19ihIPBfRWH4bIZ51<>FPPBmTWl3^8im1;69N@B[Q7D4Y7i`1:1mL0BLNfl4XX1c0jb7
NPBbSH04/Xj21:j?Q@B/THL4YH^30ij5O@BHOWL4Tgaf199nN@BDQH04V8Z71::FT`>TVYP4ZJ2O1;6X
YPBf[jh4^;>b1;bh^0>l^k`4^kk01;_0a0BmaLT4`LW>1<?>d`C7dmT3dMkT1=KXk`CDkOD4bn;Y1<;G
gPBic=83[l761:Jf^`BLZZl4TYnS18NDU`AmR8`4Lgf05Oooo`005?ooo`AYKVl4J6YZ16QWI@AYHf04
JF1L0fYME`A/Fe<4L5YA17EKC`AlGDl4Pei?0hMSD`B9IUL4WWQV1;J:MPC9VXD4`iJ21;fBO`>hSWd4
/HUi1:^4M@BTOW04X7e`19akK`BRP7<3[8Mj1;:=P0BbSX84[Xn51:bAQ`BURh<3WXEm19QnM`BCO7H4
TWii19B5P0BHRXL4XYJC0jBJV0BYX9l4/JRV1;J_[PBh/k84_;Rh0kbk_0Bk_/04^l341;g5b@C1bLh4
`lkC1<OCf@?Ag^@4e^S_1=C]m@C;h^T4`]ON1;W<dP>_`LH4Y[Jk19bZ[`BBWj<4QiBG17f8S0AcOH0E
oooo000Doooo16Q^K`AWJVT4IfET16IQGPAVGET3IeYD16QGC`A[ED`4L5I:17YJC0B<IUD3SFQG18m[
F`BPNFP4^Hag1<jMQ`C7V8@4`9B10kZ?OPBdRg/4[XMg1:N0L@BROFl4VWU/19YjKP>POg<4YhIk1:b:
O`B/SH<4ZHj41:B:PP>NQ7d4Ugig199kM@B@O7L4TH5m19:5PPBJT8h3WYFB1:FLVPBaYj@4]Zj/1;Zc
/@C0^[T3_kfm1;k0`@Bl`LD4_/C91<78c@C4cM84bmCJ0mSRi`CPkO84fo3g1=7Uk0C8f^04_/oD0k?3
b0BY^;`4WZb`19BPY0B9UIP4OXV<17AmP1Goool001Coool4J6i_16MZJ@AWIF@4IV5N16IMF@=WFU@4
J5M?16]EC0A`ETX4NUY<18aVE@>=J5L4Sf]K1:1iJ0BiS7L4cYf71<NHQ0C0U843^Xmn1;B;N`B^QgL4
Yh1a1:9mK`BJNF`4VWY^0j1oL`BWQW/4[8Yo1:b=P`BYSX@4Y8Z20ij4O@BGOWL4TW]e191lM`BAPGd4
TXF219Z@SP>NUI84YIbJ1;6WY0Bf[Z`4^[>a1<2j^@>o_Kd4_/311;c1a@Bna<T4`LS=1<C=dPC;e=X3
f>;W1>3]lPCKl?L4dNG/1<SJh0Bncm@3/l?81:Vh_0BN[;04U:2T18VEV0AnRH`4M7f05Oooo`005?oo
o`AXKVl4IfYY16MUI0AVHEh4IUeI0fMJE0AXEdl4JeE<171FBPAjFT`4S6IE0heXE`B?Je/4X7UX1;V<
M`C>WHL4aiR41<2DP@>jSgh4]8]k1:j7M`BWP744XWe_19YiK0BJNVh3X7mc1:N6N`B/RWl4[8f31:V>
Q0BTRX83WXAm19MnM`BBNgD4T7ag1961O@BBQH84VY2>0ijETPBUW9X4/JNT1;J^[0Bj/k44`;Zi0knm
_@Bn`<44_<751;k4b@C1b<d4a<gB1<_DfP?Hh^L4h>gb1=_`m`CAiN`4b=[P1;k?e0>c`lP4ZKRl19j/
/0BDX:@4RIFH17j9S0AdOH0Eoooo000Doooo16Q^K`AWJVT4IfET16IQGPAVGET3IeYD16QGC`A[ED`4
L5I:17YJC0B<IUD3SFQG18m[F`BPNFP4^Hag1<jMQ`C7V8@4`9B10kZ?OPBdRg/4[XMg1:N0L@BROFl4
VWU/19YjKP>POg<4YhIk1:b:O`B/SH<4ZHj41:B:PP>NQ7d4Ugig199kM@B@O7L4TH5m19:5PPBJT8h3
WYFB1:FLVPBaYj@4]Zj/1;Zc/@C0^[T3_kfm1;k0`@Bl`LD4_/C91<78c@C4cM84bmCJ0mSRi`CPkO84
fo3g1=7Uk0C8f^04_/oD0k?3b0BY^;`4WZb`19BPY0B9UIP4OXV<17AmP1Goool001Coool4Ife^16IX
J0AUHf84I5mL16=JEP=REE04HU5:16=>A@AWCD44M5A618YTE0>EKUd4VG9Q1:QnK0BlSWT4d9n81<VJ
Q@C3UH83_91n1;N>O0BbRWX4ZhAe1:EnL0BQO6h4X7e_0j>0LPBVQ7L4ZXUm1:^;P@BXRh44Y8V00if3
N`BGOWH4TW]d18mkM@B?Og/4THB119>;RP>CSHd4U96A1:NOWPB/Z:L4/Jf/1;Zf]@>k^KT4_;fn1;^o
``Bl`lL4`<O<1<;<d@C>e]/3gNCX1>Oam@CSm_/4f>[_1<gNh`C3d]H3]lK:1:bj_PBQ[[44UZ6U18ZE
V@AoRH`4M7f05Oooo`005?ooo`AWKFh4IVQX16ESHPATGe`4HeYF0f9ED0ARDDX4Hdi516M=@@AdE4H4
RVAD0iE^G@BILV44Z7i/1;b>N@C@WhP4bIZ51<>EPP>lT7h4]hil1;::NPB[Q7D4YGi`1:5lKPBPOFl3
Xh1b1:J4M`BZRGd4Zh^11:R;P@BTRH03WH=k19MnMPBBNg@4Sg]e18moN`BAQ844Th^:0i>=S@BDTI44
YinN1:bXY`Ba[J`4^[Je0k^i^@Bl_Kh4^ko31;c3a`C0al`4`/cA1<kFf`?Mi>P4io7e1>?fn`CHj^l4
cMkS1<?BeP>ga/X4[;Zn1:6^/@BFXJD4RYFI17n9S0AdOH0Eoooo000Doooo16M]KPAVJ6P4IF=R16AO
G0ASFUH3HUE@169ABPASCTD4Ide117ADAPB:I5@3UFiM19UbH@BXOV`4_8ii1=2OR0C9VXD4`iF20kb@
OPBgSW`4/XYj1:^4M@BUOW04XGa^1:1mK`>SP784YXAg1:Z9O@B[Rh44Z8^11:B9P0>MPg/4Ugif199k
M0B?NgD4Sgmk1964P@BCRhX3Thf=19BAT@BWWih4[:RW1;6][0Bj][D3^kVi1;bm_PBk_l<4_<?71<37
c0C2c=44c]KK0mgTj0CWlOD4hoKk1=SZk`C=g^<4`m;F0kO6bPB/^[h4XJja19JQY@B:UIT4OhV<17Am
P1Goool001Coool4Ife^16IXJ0AUHf84I5mL16=JEP=REE04HU5:16=>A@AWCD44M5A618YTE0>EKUd4
VG9Q1:QnK0BlSWT4d9n81<VJQ@C3UH83_91n1;N>O0BbRWX4ZhAe1:EnL0BQO6h4X7e_0j>0LPBVQ7L4
ZXUm1:^;P@BXRh44Y8V00if3N`BGOWH4TW]d18mkM@B?Og/4THB119>;RP>CSHd4U96A1:NOWPB/Z:L4
/Jf/1;Zf]@>k^KT4_;fn1;^o``Bl`lL4`<O<1<;<d@C>e]/3gNCX1>Oam@CSm_/4f>[_1<gNh`C3d]H3
]lK:1:bj_PBQ[[44UZ6U18ZEV@AoRH`4M7f05Oooo`005?ooo`AWK6d4IFMW16=QH0AQG5T4GeIB0eeA
B`AKBd@4FTDm15Hm<`AYC404O5U;0hiXF0BILV44[85^1;n@N`CBX8T4c9b71<FGQ0>mT7h4]haj1;>:
NPB_R7P4Zh=e1:R0LPBWP743ZH=e1:^6N0B]RWd4[8b01:R:O`BSQgh3WH9j19MmMPBBNg@4Sg]d18mo
NPBBQ844U8Z80i><S0B?SHh4V9JF1:2NW`BVYZL4/:n_0kFe]@Bh^[`4^Kg01;[1a@BmaLT4`<W>1=3G
f`?PiNP4jo7e1>WioPCOk_84dn;U1<SEf@>lb<`4/;bo1:B_/`BHXjH4S9JI182:S@AeOX0Eoooo000D
oooo16M/K@AUIfL4Hf5P165LF@AOEU83GE5;15];A0AJACd4ESdc16U<@0AlFD/3SVQH19UbH@B/PFh4
_i1k1=:PR@C<W8L4aIN40kf@OPBgS7X4/hYj1:n8N0B[PgD4Z81b1:N0L@>YPgD4ZhIh1:f:O@B/S804
Z8Yo1:>7OP>MPWX4Ugef199kM0B?Ng@4Sgmj19:4P@BDRXP3Thb<18n=SPBHUYH4X9jO1:JVY`B`[jl3
]KFe1;Rj_0Bi_L04^/751;g5b@C0bLh4d=OK0n3Uj0C[lOD4jOWn1=o^lPCCh^D4b=GI0kc8c0B`_;l4
Y:nc19RSYPB<UYT4P8Z=17EnP1Goool001Coool4Ifa]16EWI`ASHF04HEaI15mFDP=MDD/4Fd]415Y5
?@AF?C<4JDa017aIB`>>J5P4VG9Q1:b1KPBoT7/4dZ291<bLQ`C5Uh@3_I1n1;N<NPBcRWX4[hQh1:^3
M@BXP784Yh1a0jV3M@B[QWP4[HYm1:b<P0BXRWl4XhMn0if2NPBGOGH4TW]d18mkM0B?OgX4TXB119B:
R0>CS8`4Shf>19RFUPBPWYl4YZJW1;2_[`>e]KD4^;Zl1;Vm`0Bj`LD4_LG91<39cPC@em/3h>GX1>_a
m@CYnOh4gnkb1=?Ri@C8eMT3_<S<1;2l_`BT[k<4V:>V18bFV@B0RXd4MGj05Oooo`005?ooo`AVJfd4
HfEU165OGPANFEL4Fe=?0eQ<A`AEACl4DChf14/d:`AOA3T4LeA70hIRE0BFL604[81]1<6@N`CCWhT4
cij91<NIQ@?0Th44^8ek1;66MPB/Pg@4Z85b1:InL0BRO6h3Xgi`1:F0L`BXQ7L4Z8Ql1:J7O0BRQ7/3
WH5h19MnM@BBNg@4SWYd18imM`BBQH04UXb80iN>S@BHTY44ViNG19nLW0BUXj@4[J^/0k:a/PBe]kT4
]k^m1;Vo`PBk`lL4`<S=1=?Hf`?Ui^P4jnob1>olo`CVl_D4f^KY1<gHf`?0blh4/kk11:Ja]0BJY:L4
SINJ186:S@AeOX4Eoooo000Doooo16I[K@ASIFD4HEmN15iIE`AKDdl3F4a715E5?`AA?SH4Bc@[15m4
>@AcE4L3QV9D19I`H0B/P6d4`I1k1=>OR@C?WXT4aiV50l2CP@BhSG/4/HIf1:b3M0BXPG84YWi`1:9l
KP>SOW04YH1c1:R4M`BXR7`4YXMl1::4N`>MPGP4Ugie199kM0B>NW@4SWeg19:5P0BFS8P3Uhj=19RB
T@BKUiL4WibL1:FSY0B]Zj`3/[6b1;Fg^@Bg^kd4^Ko21;_3a`C0b<d4dmSK0nGVj0C[ko84koco1>Kb
m@CJi^T4cMSK0l3;cPBc_/44Y[6d19ZTY`B=UiX4PHZ=17EnPAGoool001Coool4IV]]16=UI@AQGeh4
GUUG15]CC`=HC4L4EDDo154n=PA;=2/4Gd@i17=DA`>6HU@4UW1P1:b0K@C1T7/4din91<nNR@C7VHD3
`9>11;R=N`BaQWH4[8=d1:R1LPBVOW04XWa^0j=nL0BUP7<4Z8Ag1:R8O0BVQg`4XXAk0if1N0BGOWD4
TW]d18ijM0B>OGL4TXF019J<R0>GSXd4V9:A19^GU`BOW9`4YJ>T1:f[[0>b/K84]KNi1;Nk_@Bi_l84
^l?71<38c@CCf=/3iNKX1>__lPC_o?l4i_;e1=[Vj@C=f=/3`<_>1;>n`@BV/K@4VZBW18fGVPB1RXd4
MGj15Oooo`005?ooo`AVJfd4HfEU165OGPANFEL4Fe=?0eQ<A`AEACl4DChf14/d:`AOA3T4LeA70hIR
E0BFL604[81]1<6@N`CCWhT4cij91<NIQ@?0Th44^8ek1;66MPB/Pg@4Z85b1:InL0BRO6h3Xgi`1:F0
L`BXQ7L4Z8Ql1:J7O0BRQ7/3WH5h19MnM@BBNg@4SWYd18imM`BBQH04UXb80iN>S@BHTY44ViNG19nL
W0BUXj@4[J^/0k:a/PBe]kT4]k^m1;Vo`PBk`lL4`<S=1=?Hf`?Ui^P4jnob1>olo`CVl_D4f^KY1<gH
f`?0blh4/kk11:Ja]0BJY:L4SINJ186:S@AeOX4Eoooo000Doooo16E[K0ARI6@4GUeL15]GE@AGD4`3
DdQ314m0>PA:>304@bhU15@l<PAYCD43OUe?19=]G@BZOf`4`91k1=:OR0CBX8X4bib80lBGQ0BmTH04
]H]j1:j4M@BXP784Ygi`1:AlK@>SO6h4Xge_1:F0L`BVQ7P4YHAj1::2N0>NP7L4V7if19=lM@B>NW@4
RWUd18]nNPBBR8<3VHn;19nFT`BPVYP4XYjM1:JTY0B/ZZX3/:na1;>e]`Be^K/4][fo1;O0a0C0bLd4
e=SK0nWXj@C^l?84m?go1??ko@CQj^`4d]_N0lC=d0Bf_l84ZK:e19^UY`B?V9X4PX^=17EnPAGoool0
01Coool4IF]/169TI0ANGE`4FeME15M@C0=CB4<4Cd0j14Xh<0A3;RD4E3`b16U=@@=nGDl4TfeM1:Yo
K0C0T7/4dYn81=:PRPC;W8P3a9N41;fAP0BeRgX4[XAe1:R0LPBWOW04Y7a]0j=lKPBSOFl4YH1c1:J4
N0BUQ7X4XX9h0ij0M`BHOWH4Tgae18ijM0B:NG@4Rgij19:8P`>ISh/4WiJC1:2JV0BRWYd4YZBT1:bZ
ZP>`[k44/kFg1;Fi^`Bf_Kl4]l341<39c@CDf=/3jNSY1>k`lPCdoOl4lo_m1>7Zk0CBfmh3a<g@1;Jo
`PBY/[D4VjFW18nHVPB2Rhd4MGj15Oooo`005?ooo`AUJf`4HVAT15iMG0AKEeD4Ee1<0e=8@`A?@3X4
BSP`14<^9@AD?384JDe10giMC`BCKEd4ZWm/1<2@N`CBWhP4dZ2:1<^LR0?4Uh@4_I601;F;NPB^Q7D4
Z81b1:MnL0BTO6d3Xga^1:=mK`BUP7<4YXAh1:F4NPBRPWP3WX1g19QnMPBCO7D4SWYd18YiM0B;OWX4
TXR30iV?R`BOUY<4X9ZH1::NW@BVY:@4[:ZZ0k2_/@Bc]KL4]KVk1;Jm_`Bg`<@4`<W=1=CHf`?Yj>T4
k_3b1?Cmo`Ccnod4hN[/1=;KgP?4cM04][o21:Vb]@BKYJL4SiRJ18:;S@AeOX4Eoooo000Doooo16E[
K0ARI6@4GUeL15]GE@AGD4`3DdQ314m0>PA:>304@bhU15@l<PAYCD43OUe?19=]G@BZOf`4`91k1=:O
R0CBX8X4bib80lBGQ0BmTH04]H]j1:j4M@BXP784Ygi`1:AlK@>SO6h4Xge_1:F0L`BVQ7P4YHAj1::2
N0>NP7L4V7if19=lM@B>NW@4RWUd18]nNPBBR8<3VHn;19nFT`BPVYP4XYjM1:JTY0B/ZZX3/:na1;>e
]`Be^K/4][fo1;O0a0C0bLd4e=SK0nWXj@C^l?84m?go1??ko@CQj^`4d]_N0lC=d0Bf_l84ZK:e19^U
Y`B?V9X4PX^=17EnPAGoool001Coool4IFY/165SH`ALFeX4F5AB15==B@=?AD04BC`f14<c;0@m:B44
CCH/1616>`=fF4X4S6QI1:IlJPBmSWX4d9f61=>QS0C>Wh/3aiZ81<6EQ0BkT7l4]H]k1;27M`B]Q7@4
ZX9b0jV1LPBXPG84Z89d1:N3M@BUQ7P4XX9g0ij1M`BJOgL4UWig195mM`B<NgL4R7]h18V0O@><QX@4
Ui2=1:2IU`BVWih4Z:FT1:bYZ@>_[Zl4/K>e1;:f^0Bb^K`4/[c01<78c0CEf=X3jNKV1??al@Cen_/4
nOko1>O^k`CGg^03aloA1;W1``B[/kD4WJFX192HV`B3Rhh4MWj15Oooo`005?ooo`AUJV`4HF=S15aK
FPAHE584Dde90dm5@0A9?3H4@c</13dY8@A==R`4H4Hk0gIHBPB<J5T4YWaZ1;f>NPC@WHH4dj6<1<jO
R`?7VXP4`IF41;^@O`BeRg/4/8Mg1:f4M0BZPW83ZH5b1:R1LPBXPW@4Yh=e1:F4N0BRPWL3WX5g19Yo
M`BFOWL4TGeg18akM`B8NgP4RH1m0hb6Q0BGT8d4X9VG1:JOWPBXYJ@4[:VY0jn^[`Ba/kD4/[Jh1;:i
_0Bb_<04`LS<1=GHfP?Yi^H4lo7a1?Gjn`Cio_l4ink_1=ONh0?7cm44^L731:^c]@BMYJP4T9RK18>;
SPAfOX4Eoooo000Doooo16EZK0AQHf<4G5]J15QDDPACCDT3CdE014Tl=PA3<b`4?BTQ14df;0APAS/3
MUQ:18aXF@BVO6X4_Hij1=2MQPCCXH`4cYn;0lNJR0C1UH@4^i1o1;F;N`B`QgL4[HAd1:Z2LP>YPG84
Z85b1:R2M0BWPgD4YHAh1::2M`>NPGL4VWmg19InM`BAOGL4S7]g18QkN0B9P7d3S8J419N@S@BPVIL4
YYnN1:RUY0B/ZJT3[jj_1;6c]@Bb][P4/[Vl1;:l`0C1b<`4eMSJ0nWViPCclO44mO[k1?Wno`CWk^l4
emkP0lO?d@Bi`L<4Zk>e19fUZ0B@V9/4Ph^>17InPAGoool001Coool4IFY/165SH`ALFeX4F5AB15==
B@=?AD04BC`f14<c;0@m:B44CCH/1616>`=fF4X4S6QI1:IlJPBmSWX4d9f61=>QS0C>Wh/3aiZ81<6E
Q0BkT7l4]H]k1;27M`B]Q7@4ZX9b0jV1LPBXPG84Z89d1:N3M@BUQ7P4XX9g0ij1M`BJOgL4UWig195m
M`B<NgL4R7]h18V0O@><QX@4Ui2=1:2IU`BVWih4Z:FT1:bYZ@>_[Zl4/K>e1;:f^0Bb^K`4/[c01<78
c0CEf=X3jNKV1??al@Cen_/4nOko1>O^k`CGg^03aloA1;W1``B[/kD4WJFX192HV`B3Rhh4MWj15Ooo
o`005?ooo`ATJV/4Gf9R15YJF@AEDU04D4Y70dY1?@A5>3<4?RlX13LU7PA6<RT4F40f0g1BAPB6I5D4
X7QV1;R;MPC>Vh@4e::<1=6RS@?;WX/4aIZ81;nEQ0BjTH44]Xem1;:9NPB_QgL3[HEf1:b4M@BZQ7H4
ZHAf1:N4M`BTPgP3X89h19f1N0BIPGT4UH5j1960N`B=P7`4S85o0h^4PPB>RHP4Ti2?19ZGU`BPWil4
YJBU0jRYZ`B][k44[[>e1:nf^@B`^Kh4`<O:1=;Ee`?Th^84l^o_1?Win@Cmool4k?3a1=_Ph@?:dM84
^l;31:bc]@BNYZP4T9RK18>;SPAfOX4Eoooo000Doooo16AZJ`AOHV84FUYI15EBD0A@BTL3BT4m14Dh
<`@n;bP4=bDN14Hb:@AH@3H3L59618ITE@BPN6H4^8]f1<jKQ0CDXX`4dJ:=0l^NR`C5VXP4_iF41;ZA
P@BfSGd4/XUj1:n7M`>]QGH4[8Ae1:Z4MPBYQ7H4YhAg1:B3N0>PPWP4WH5h19V1N@BEPGX4TH1k18f0
O0B<PGl3RhB218j9R0BCT8l4VYNG1:2OW`BUY:D3Z:V[1:f_/@B^/kD4[kJi1;2i_PC0alX4d]GG0nCR
hPCbknl4nOWi1?goo`C/l?44fn3Q0l[AdPBk`/<4[;>e19jVZ0B@V9/4Ph^>17InPAGoool001Coool4
I6Y[15mRHPAJFUT4EE9@151:A`=:@Cd4ACPc13h_:0@g9Ah4AS8Y15Q0=P=`DTH4QVAE1:1hIPBhRgH4
cY^41=BRS0CAXXd3bij;1<FJR0BoUH@4^Y611;J=O@BbRGX4[hMg0jf5MPB/Q7D4ZXAf1:V4MPBWQ7L4
Y8=h0j22N0BMPGP4VH5i19F1NPBAP7/4SH1l18b1O`>;Q884SXV819>@S`BJUiL4X9nO1:FTY@>XZJ/4
[Jna1:jc]@B_][T4/;Vn1<37bPCBeML3i>;R1?;_k`CinOT4oOoo1>c`l@CKh>43b]7B1;_2``B//kD4
WZJX192HV`B3Rhh4MWj15Oooo`005?ooo`ATJV/4Gf9R15YJF@AEDU04D4Y70dY1?@A5>3<4?RlX13LU
7PA6<RT4F40f0g1BAPB6I5D4X7QV1;R;MPC>Vh@4e::<1=6RS@?;WX/4aIZ81;nEQ0BjTH44]Xem1;:9
NPB_QgL3[HEf1:b4M@BZQ7H4ZHAf1:N4M`BTPgP3X89h19f1N0BIPGT4UH5j1960N`B=P7`4S85o0h^4
PPB>RHP4Ti2?19ZGU`BPWil4YJBU0jRYZ`B][k44[[>e1:nf^@B`^Kh4`<O:1=;Ee`?Th^84l^o_1?Wi
n@Cmool4k?3a1=_Ph@?:dM84^l;31:bc]@BNYZP4T9RK18>;SPAfOX4Eoooo000Doooo16AYJ`ANHF44
FEUH15=@CPA=AdD3Achj140e<0@j;2D4<b8K148_9`AC?3<3JDe1185PD@BJM6<4/hMc1<VHPPCEXh`4
e:B@0lnQSPC9WH/4`iV81;jEQ@BjTX84]hmo1;B<O0>bRGX4/8Mh1:j7N0B/QWP4ZHEh1:J5N0>SQ7T4
X8Ak19f4O0BJQ7d4UXAn19>4P0BAQX83T8R5196;R@BCT8l4UYBD19^JV`BQX:83Y:JX1:R[[@BZ[k84
[;>g1;6i_@C0a/T4d=?E0mkOh0C^k>`4n_Sg1?ooo`Cam?<4g^;R0lcAdPBl`/<4[KBe19nVZ0BAV9/4
Ph^>17InPAGoool001Coool4I6U[15iQH@AIFEP4De1>14e7A@=7?SX4@3D`13X/9@@c8Q/4@RlW15<l
<`=YCD44PF1A19YdH`BcQg<4bIR21=FSS0CDY903cj6>1<VMR`C3VHP4_YF51;ZBPPBgSgl4]8al0k:9
NPB`QgP4[XMh1:b6N0BYQGP4YXEh0j>4N@BPQ7/4WHAl19Z4O@BFQ7h4ThB01966PP>@R8D4TH^919>@
S`BFU9@4ViZK1:6PXP>TYZP4Z:^]1:Z_/PB//kL4/KVm1<36b@C@dmD3g]oP1>k/k0Cjn?L4oooo1?7d
l`CNh^83c=7B1;c2``B]];D4WjJX196HV`B3Rhh4MWj15Oooo`005?ooo`ATJF/4GV5Q15UIF0ACD4h4
CDM50dLn>PA0=C04>R`U13<R6`A2;bL4Dc`c0fU=@@B1H544VWAS1;>7L`C9V884eJ><1=BTT0??XHh4
bIf;1<>IR0BnUHD4^Y:21;N?O`BdS7`3/XUj1;27N0B^QgP4[8Ih1:V5N0BVQGP3XhAi1:24N`BMQ7`4
VXAm19J4OPBCQ804THJ20i28Q@BARhT4Ti2?19JDU0BKVY/4XJ2R0jBVZ0BXZjd4ZZnb1:bc]`Ba^Kd4
`<K91=3Ce@?Ngn04k^c/1?[hm`Coool4lOCc1=kRhP?<dM84_<;31:fd]@BOYZP4TIRK18>;SPAfOX4E
oooo000Doooo16=YJPAMH644EeMG155>C@A:AD<3@c`h13db;P@e:2<4;QhG13h/90A>>Bl3HdPm17YJ
C0BDKUh4[H5^1<BCOPCCXHX4ejNA0m:TT0C<X8h4aif<1<:IR@BnUHD4^i:21;R@P0>eSGd4/h]k1;6:
NPB_R7T4[8Qj1:Z7NP>WQW/4Y8Mm1:67OPBNQh04VhR119R8PPBFRHD3UHb819F>S0BGTY04VIJE19bK
V`BPWj03XjBV1:JYZ`BX[:l4Z[6d1;>i_@C1aLP4cm7C0mgMg@C[jNT4n?Gc1?kln`CcmO@4gn;R0lgA
dPBl`/<4[K>e19nUY`BAV9X4Ph^=17InPAGoool001Coool4HfUZ15ePH@AGEeL4DDi=14Y5@`=3?3P4
?C8^13DX8`@^7QL4?R`T14hi;`=SB3d4NUY<19A^GPB]PFh4a9=n1=>QRPCGYi43dZB@1<bPSPC7WH`4
`YV91;jEQ@BkTX84^9200kF=O@BcRg/4/HYj1:n8N@B/R7X4ZXMj0jN6N`BTQgd4XHMn19j7P0BKR844
V8R219J9Q@>ES8P4UHj<19NBT0BIUYD4W9^K1:2OX0>SY:H4YZV[1:R/[`BZ/K@4/kVm1<75b0C?dM<3
gMgM1>_Yj@ChmO<4o_ck1??em0COh^83cM7B1;c2``B]/kD4WjFW196HVPB3Rhd4MWj15Oooo`005?oo
o`ASJFX4GF1Q15MGE`AACTd4BTE30d<l>0@m<Rh4=BPS12hN5`@n;2@4CST_0f=8?@AjFT`4U6iN1:f1
KPC4Tgh4dj6:1=NWT@?BY904c:2>1<NMS0C2VHT4_YF51;^BPPBhT803]Hem1;>;N`BaRWX4[hQi1:b8
NPBZQgX3YhIk1:B7O@BQQgh4WXN019^8P@BHR884UXV50iF<R0BESX`4Ui:@19VFU@BLVi/4X9nP0j>T
YPBVZJ/4Z:b_1:Za]0Bc^Kd4`LG81<oAd`?MgMd4jnWY1?Sel`Cno?/4loGd1=oRhP?=dM84_<;31:fc
]@BOYJL4TIRJ18>;S@AfOX4Eoooo000Doooo16=YJPAMH644EeMG155>C@A:AD<3@c`h13db;P@e:2<4
;QhG13h/90A>>Bl3HdPm17YJC0BDKUh4[H5^1<BCOPCCXHX4ejNA0m:TT0C<X8h4aif<1<:IR@BnUHD4
^i:21;R@P0>eSGd4/h]k1;6:NPB_R7T4[8Qj1:Z7NP>WQW/4Y8Mm1:67OPBNQh04VhR119R8PPBFRHD3
UHb819F>S0BGTY04VIJE19bKV`BPWj03XjBV1:JYZ`BX[:l4Z[6d1;>i_@C1aLP4cm7C0mgMg@C[jNT4
n?Gc1?kln`CcmO@4gn;R0lgAdPBl`/<4[K>e19nUY`BAV9X4Ph^=17InPAGoool001Coool4HVQZ15aO
H0AEEUH4CTe;14M3@@=0>CH4>C0[134U80@Y6a@4>BPQ14Xe;0=M@cP4LUA718]WF0BTNfP4_8eh1<fK
Q@CGYY03e:JB1<jST0C:X8h4aIf<1<:IR@BnUXD4_9>20kV@O`BgSWh4]8al1;:;N`B`RW/4[HUl0j^9
O@BXRWl4YX^11:>;PPBPRh@4WHb619^=R0>JSh/4VY:>19ZDTPBLUiH4WI^K19nOW`>RXjD4XjNY1:BZ
[@BX/;<4/[Vm1<34a`C>d=83fm_K1>SViPCdl>l4n_Of1?;bl@CMgml3c<o@1;c0`@B]/[<4WZFV196G
V@B3Rhd4MWj05Oooo`005?ooo`ARJ6X4G5mP15EFEPA>CD/4Ad=10d0i=P@i<2/4<BDP12TK50@i:244
BSD/0ee3>0AbE4L4RfMH1:AkJ0BlSGP4cI^51=NVT0?DYY84cZ>@1<ZPSPC5WH`4`YV91;jFQ@BlTh83
^I1o1;N>OPBdS7`4/X]k1;2:N`B]RG`3ZhUm1:R:O`BVRh44Xh^21:2;Q0BMS8H4Vhf80iZ?R`BJTXh4
VYBB19bGUPBMVi/4WinO0j:SY@BSYjT4Y:Z]1:R`/`Bb^Kd4`<C71<k@dP?Kfm/4j>KV1?C`k`CjmoH4
l_;a1=gOg`?<cm04_<311:fb/`BNYJH4TINI18>;S@AfOX0Eoooo000Doooo169XJPALGf04EEIF14i=
B`A7@d43@3Tf13T`:`@a9B04:A/D13TX8@A:=B`3GD<h179DA`B;IeP4Y7]X1;b=N0C=VhD4ejJ@0mBV
TPC>Xi04bZ2>1<FMS0C2VHT4_YJ51;bCPP>iT7l4]hin1;B<O0BbRg/4/8Yk1:f9O0>[RGd4Z8Yo1:J;
P@BSRh84X8^419f<QPBKSHP3VXn;19ZBSPBJU984W9NF19fKV`BOWil3XZ>U1:>WZ@BTZZd4Z;2c1;:i
_@C0a<L4c]3B0m_Kf`CXi^H4m?3_1?[gmPCbl_44gMoO0lc?d0Bl`<44[K:c19jUYPBAUiT4Ph^=17In
P1Goool001Coool4HVQZ15aOH0AEEUH4CTe;14M3@@=0>CH4>C0[134U80@Y6a@4>BPQ14Xe;0=M@cP4
LUA718]WF0BTNfP4_8eh1<fKQ@CGYY03e:JB1<jST0C:X8h4aIf<1<:IR@BnUXD4_9>20kV@O`BgSWh4
]8al1;:;N`B`RW/4[HUl0j^9O@BXRWl4YX^11:>;PPBPRh@4WHb619^=R0>JSh/4VY:>19ZDTPBLUiH4
WI^K19nOW`>RXjD4XjNY1:BZ[@BX/;<4/[Vm1<34a`C>d=83fm_K1>SViPCdl>l4n_Of1?;bl@CMgml3
c<o@1;c0`@B]/[<4WZFV196GV@B3Rhd4MWj05Oooo`005?ooo`ARJ6X4FemO15AEE@A=BdX4AD4o0cdg
=0@f;BT4;R<N12HH4P@e9Ah4AS8Y0eLo=0A[Cd84PV5B19eeH`BdQg<4aYJ11=>RS0?DYY84d:BB1<bQ
T0C8Whh4aIb<1<:IR@BoUXD3_9>21;ZAP0BhSgl4]Hen1;><O@B`S7h3[hb01:f=PPBZSX@4Yhj51:F?
QPBRShT4Wi2:0ijBS@BNU904WYJD19jIU`BNW9/4WinO0j6RX`BRYZP4Y:V/1:V`/`Bd^[d4_lC61<c?
d0?IfMX4iNCT1?3]k0Celo84jN[Y1=WKf`?9c<d4^[jo1:^`/PBMXjD4T9NH18>:S0AfOX0Eoooo000D
oooo169XJPAKGel4E5EE14e;BPA5@Cl3?CLd13H]:@@^8ah49QPB13DU7PA6<RT3Ecld16]?@PB2HE84
WGES1;B7L`C6UX44dj:<0mBVTPC@Y984c:6@1<ROSPC5W8`4`YV91;nFQ@>lTh84^Y601;R?O`BeSGh4
/ham1;2<OP>_S804[Hf21:Z>Q0BWSXD4YHn61::?R@BOT8X3WY:=19jDT0BNUY@4WYVG19jLV`BOWil3
XJ:S1::VZ0BTZJ`4ZK2c1;Bj_@Boa<H4c<o@0mWIfPCUi>@4l>g/1?GclPCYj^T4fM_K0lW<c@Bj_[l4
Zk2b19fSY@B@UiP4PhZ<17InP1Goool001Coool4HVQZ15]OG`ADEED4CD]:14E1?`<m=c@4=RdY12hS
7P@V6184=BDN14Hb:@=G?c@4Jdm2189QDPBMMF<4]8Mc1<JFP@CCXX`3e:JB1=2TTPC<XI04b9n>1<FL
S0C2VHT4_iJ50kbCPPBjTH04^8mo1;F=OPBcS7d4/8an0jn<P0B]SH84ZXj41:N>Q@BUShH4XXn919n@
RP>NTXd4WYB@19jFU0BNVIL4WYbK19nOW`>QXZ<4XZJX1:BY[0BY/;<4];Zm1;o4aPC<cm03fMWJ1>GT
i0C`kN`4mO?b1>WZj@CIfm/3bLc=1;Zn_`B[/;84WJ>U192GV0B3RX`4MWj05Oooo`005?ooo`ARJ6X4
FemO15AEE@A=BdX4AD4o0cdg=0@f;BT4;R<N12HH4P@e9Ah4AS8Y0eLo=0A[Cd84PV5B19eeH`BdQg<4
aYJ11=>RS0?DYY84d:BB1<bQT0C8Whh4aIb<1<:IR@BoUXD3_9>21;ZAP0BhSgl4]Hen1;><O@B`S7h3
[hb01:f=PPBZSX@4Yhj51:F?QPBRShT4Wi2:0ijBS@BNU904WYJD19jIU`BNW9/4WinO0j6RX`BRYZP4
Y:V/1:V`/`Bd^[d4_lC61<c?d0?IfMX4iNCT1?3]k0Celo84jN[Y1=WKf`?9c<d4^[jo1:^`/PBMXjD4
T9NH18>:S0AfOX0Eoooo000Doooo169XJPAJGUl4DeAD14]:B@A3@3h3>cDc138[9`@Z81`48QHA134R
70A1;bL3DS/a16A9?@AkFdd4TfiM1:b0K@C1TG/4cYf70m>TT0CAYI44cZ:@1<ZPS`C7WXd4a9b;1<:I
R0?0UXD4_I>31;^BPPBiT804]i211;F?P@>bT8<4/I241:nAQPB/THP4ZI:91:JBR`BTThd3XYB?1:6F
TPBPV9D4X9ZH1:2LV`BPWil3XJ6R1:6UY`BSZJ`4Zk6d1;Bj_0C0a<H4blg?0mSHf0CTh^84k^_Z1?Gd
lPCTi>@4eMKF0lK9b@Bg^k`4ZJj`19bRX`B?UIL4PXV;17EmP1Goool001Coool4HVQZ15YNG`ACE5@4
BdY914=0?P<k=C<4<R/W12XP70@R5Q44<B8L144_9`=B>c44I4Tm17]KC@BCKUd4[81]1<6AN`C>WHL3
djB@1=6UT@C>XY04bZ2?1<NNS@C4W8/4`YV80l2FQ@BmTh<4^i:21;V@P0BgT844]Hn10k:@P`BaT8@4
[i661:bAR0BYTXT4YY:;1:BCS@>RU8l4XIJB1:2HU@BPVYP4X9bK1:2OW`>QXJ84XJFW1:>Y[0B[/K@4
];Zl1<34aPC;cLl3f=SH1>CRhPC^jnX4mOCb1>CTi0CEe]H3a/W91;Nk_0BY[[04W::S18nEU`B2RH/4
MGf05Oooo`005?ooo`ARJ6X4FUiO15=DE0A;BTT4@d0n0c/e<`@b:bL4:R0L128F4@@a8Q`4@BlW0e8k
<@ATBCd4Ne]=19=^G@B/P6d4`I5k1<jMQ`?CY904dJFA1<jRT0C:X8l4aij=1<BLR`C2VHP3`9J51;fC
P`BkTX84^I201;N@P@BeSh43/Y231;6@Q0B_THH4[9681:VBR@BVTX/4Y9>=0j:DS`BQUY84X9RE1:2J
V0BPW9/4X9nO0j6QXPBQYJL4XjV/1:^a]0Bd^[`4`<C61<_=c`?Hf=P4i>;R1>k[jPCem?84i>CT1=GF
eP?6bLT4]k^l1:V^/0BLXZ<4SiFG18:9R`AeOH0Eoooo000Doooo169XJPAJGUl4DeAD14]:B@A3@3h3
>cDc138[9`@Z81`48QHA134R70A1;bL3DS/a16A9?@AkFdd4TfiM1:b0K@C1TG/4cYf70m>TT0CAYI44
cZ:@1<ZPS`C7WXd4a9b;1<:IR0?0UXD4_I>31;^BPPBiT804]i211;F?P@>bT8<4/I241:nAQPB/THP4
ZI:91:JBR`BTThd3XYB?1:6FTPBPV9D4X9ZH1:2LV`BPWil3XJ6R1:6UY`BSZJ`4Zk6d1;Bj_0C0a<H4
blg?0mSHf0CTh^84k^_Z1?GdlPCTi>@4eMKF0lK9b@Bg^k`4ZJj`19bRX`B?UIL4PXV;17EmP1Goool0
01Coool4HFQY15UNG`AADe@4BDU9144o?@<h=384;bPU12HM6@@M4Ph4;1lH13/[90=<=bh4GD@i17=E
A`B:IeL4XWUW1;V:MPC9Uh83dZ:=1=:UT@C?Xi44c::?1<VPSPC7WXd4aIb;0l>IR0C1UhH4_iF41;fD
P`BlTh@4^I:40kNCQPBfU8P4/iF91;6ER`B^UH`4ZYJ=1:RFS`>VUY44Y9RC1:>JUPBRViT4XIfL1:6O
W`>RXZ84XjJW1:J[[@B^/[D4]k^m1<;4aPC=c/h3f=SG1>CRh@C]jNP4l>o^1=oOg`C@d]83`/G51;Bh
^@BW[:d4VZ2Q18jDUPB1R8/4MGeo5Oooo`005?ooo`AQJ6T4FEiO155CE0A9BDT4@Clm0cPd<P@_:2D4
9QdI11dB3P@/7aP4>b/T0d`g;PAMA3T4LeE718YWE`BRNFL4^HYf1<VGPP?BXXd4dZFA1<nST@C<XXl4
bJ2>1<NNS@C5W8/3`iV81<6GQPBoUH@4_IB31;bCQ0BiTX@3]i>61;JDR0BcUHT4/IF;1:jES0BZUXd4
Z9J?0jJFT@BTV9<4XiZF1::KV@BQWI`4XInO0j:RXPBSYZL4YZ^]1:jb]@Bg^kd4`/C61<g>cP?Hf=L4
i>;Q1>gYj0C`knh4gmoO1=3BdP?2aLD4];Ri1:N/[@BJX:44SYBF1868R`AeOGlEoooo000Doooo165X
J@AIGUl4DE=D14U9B@A1?cd3>3@b12lX9@@V7AT47A8>12`O60@k:b@3C3L^15e4>@AcEDL4RVMG1:9i
I`BiRWH4bIN20m:RS@CBYI44cj>A1<bRS`C9X8h4aij=1<FLR`?3VHP4`IN61;nEQ0BmU8<4_9>41;VB
Q0>gThH4]YB81;>ER@BaUH/4[YF<1:ZFS@BXUXl3YYJA1:BHT`BSVYH4XY^I1:6MW0BQWil3XZ:R1:>V
Y`BVZjd4[[:e1;Nk_@C2a<H4cLk>0mSHe`CTh^44kNWX1?3_kPCOgml4d=;B0l;5a@Bd^;T4Yjb]19ZP
X@B>U9H4PHR;17EmOaGoool001Coool4HFMY15UMGPA@De<4B4Q813ln?@<f<c44;BLT128K60@H3`/4
9QXD13HV80=6<bX4Ecle16]?@PB2HE84V79P1:n3K`C1T7/3cij81=:TS`C@Xi04cZ:?1<^QS`C9Whd4
aif<0lJKRPC4VHP4`YN61<2FQ@BoUXH4_YJ70kbGR@BkV8/4^IV<1;JIS@BcV8h4[iV@1:bIT@>ZVI<4
YiZE1:FKU`BTW9T4XYjL1::OW`>SXZ<4YJNX1:V/[PBa];D4^Kbm1<;4aPC<cLh3emOG1>;Ph0CZj>L4
i>CS1=SIf0C;cLd3_/711;6e]PBTZJX4V9jO18bCU0B0QhX4MGao5Oooo`005?ooo`AQIfT4FEeN151C
D`A8B4P4?chm0cHc<@@]9b@48Q/H11P?2`@V6Q@4=RHP0dHc:PAG?cD4Jdm2189QDPBHLV04[h=_1<6@
N`??WXP4dZB?1=2ST0C>XXl4bj6?1<VOS@C7WH`3aY^:1<BIR0C2UhH4`9J51;nFQPBnUXL3_9N91;^H
R`BiVH`4]YV=1;>HSPB_VI04[9VA0jZIT`BWVYD4YI^G1:BLV@BRWY`4XYnO0j>RX`BUYjP4ZJb^1;6d
]@Bi_;d4`/C61<c=cP?GemL4h^3P1>[Xi`CTi><4f=WH1<_=c@>n`L44/KFf1:BYZPBHWYl4S9>D1827
RPAeO7lEoooo000Doooo165WJ@AIGEh4D5=C14Q8B0@o?Sd3=S<a12dW90@R6aP460l;12HJ50@f9R03
AS<Z15Lo=@A[Cd84PV5B19QbH0B_Pfl4`I1k0lnNR0CBY8l4d:>@1<jRS`C;XHl4bIn=1<NMS0?6VhX4
a9V81<:GQPC0UXD4_iJ61;jFQ`>lUhT4^iR;1;VIS0BfVHd4/iR>1:nIT0B/VI43ZYVC1:NJU@BUViL4
Y9bI1::NW0BRWil3Xj:S1:FWZ0BY[:h4/KBe1;Vl_@C2a<H4c<g>0mOGe`CRh>04j^SW1>CTh`CHfMP4
blg=0kk1`@Ba]KH4Y:VZ19RNW`B<Ti@4P8N:17ElOaGoool001Coool4HFMY15UMGPA@De<4B4Q813ln
?@<f<c44;BLT128K60@H3`/49QXD13HV80=6<bX4Ecle16]?@PB2HE84V79P1:n3K`C1T7/3cij81=:T
S`C@Xi04cZ:?1<^QS`C9Whd4aif<0lJKRPC4VHP4`YN61<2FQ@BoUXH4_YJ70kbGR@BkV8/4^IV<1;JI
S@BcV8h4[iV@1:bIT@>ZVI<4YiZE1:FKU`BTW9T4XYjL1::OW`>SXZ<4YJNX1:V/[PBa];D4^Kbm1<;4
aPC<cLh3emOG1>;Ph0CZj>L4i>CS1=SIf0C;cLd3_/711;6e]PBTZJX4V9jO18bCU0B0QhX4MGao5Ooo
o`005?ooo`AQIfT4F5eN151CD`A7B4P4?Sdl0c@b<0@Z9R@481TG11D<2@@O50l4;b4K0cl]9@A>>C04
HTPm17QIB`B>JUX4XgYX1;N8M0?8Uh44d:6<1=6SS`C?XXh4cJ6?1<^PS@C:Wh`3b9f;1<RLRPC6VXT4
a9R71<BIR0C3VXT3`YZ;1<2LSPBnWHl4^ib@1;RLT@BdW984/IbC0jjLU@B[W9H4Z9bH1:JMVPBSWY`4
XYnN0j>SX`BWZ:P4[:j_1;Be]PBl_Kh4`lC51<g=c@?HemH4hn3O1>cZj@CNg]d4d]?C1<G7b0>i_;d4
[K6b1:6VZ0BFW9d4RY6C17n6R@AdO7hEoooo000Doooo165WJ@AHGEh4D5=C14M8B0@n?C`3=38`12XV
90@P6AL45@`911lD3`@_8A/3?bdU14hi<0ARB3d4N5U;18iZFPBSNVP4]hQd0lRGP@C@XH`4dJ>?1<nR
SPC=XHl4bj2=1<ZOS0?8WH/4b9b:1<JJR@C4V8L4a9V81<>JR@?2VX/4`9b>1;jMS`BkW904^9bA1;BL
TPBaW9<3[YbE1:^LUPBXW9P4YYfJ1:>NW0BRWih3Xj>S1:NXZ0B/[Zl4];Ff1;bm_PC3a<D4cLg=0mSG
ePCSh=l4k>[Y1=kNg@CBdm<4aLO80kVl_@B]/K84XJJX19JLW@B:TI<4OhJ917AlOQGoool001Coool4
HFMY15QMGPA@De<4AdQ813hm?0<d<S04:RHT120I5`@E30T47a@?12lQ6`<o;BD4CST`1698?@AhFD/4
SVYJ1:=jJ0BgR7@3b9N11=2QS0CAXhl4cj:>1<fQS`C;X8d4bYn<0lRMR`C8W8X4aYZ91<BHQ`C4VHP4
`iZ90l:JR`C0W8h4_Yf?1;^LT0BhW944]9bB1;6LT`>^W9D4ZibF1:RLV0BVWIX4XijL1::OWP>SXj<4
YjRX1:b^[`Bd]KH4_;fn1<?4a@C=cLd3f=OF1>?Pg`C/j^T4g]kM1=;Cd`C5alP3^Kbm1:fa/PBQYZP4
UYbM18ZAT`AoQXT4M7an5Oooo`005?ooo`AQIfT4F5eN151CD`A7B4P4?Sdl0c@b<0@Z9R@481TG11D<
2@@O50l4;b4K0cl]9@A>>C04HTPm17QIB`B>JUX4XgYX1;N8M0?8Uh44d:6<1=6SS`C?XXh4cJ6?1<^P
S@C:Wh`3b9f;1<RLRPC6VXT4a9R71<BIR0C3VXT3`YZ;1<2LSPBnWHl4^ib@1;RLT@BdW984/IbC0jjL
U@B[W9H4Z9bH1:JMVPBSWY`4XYnN0j>SX`BWZ:P4[:j_1;Be]PBl_Kh4`lC51<g=c@?HemH4hn3O1>cZ
j@CNg]d4d]?C1<G7b0>i_;d4[K6b1:6VZ0BFW9d4RY6C17n6R@AdO7hEoooo000Doooo165WJ@AHGEh4
Ce=C14I8B0@m?Cd3<c4`12TU90@N6AH44P/811P@30@W6aD3=bLP14Lc:PAH@CL4KE55189RD`BEL5l4
Z7i/0kb=N@C:VXD4cj2;1<nQS@C>XXh4cJ6=1<bPS@?;Wh`4bYj;1<ZMR`S8VhT4b9f<0lNNSPC6Wi04
`j2B1<6PT`BmWi<4^InD1;FNUP>aWiL4[YnH1:^NV@BXWYX4YInM1:>OW`>UXj<4Z:RY1:j^[`Be]KH4
_Kfn1<G5a@C>cLd3f=KE1>3Mg@CViND4f=SH1<_=c@C0`/<3];Ri1:V][`BNXjD4TiVK18V?T@AnQHL4
Lg]n5Oooo`005?ooo`AQIfT4F5eN14mCD`A6B4P4?Cdm0c<a<0@Y9B@47QTF118;20@H40`49a/E0cLW
80A7<bX4F44g16eAA@B2HU<4UG1O1:QnK0>lSGT4bYZ51<nPR`C?XHd4cZ:>1<fQS@C<X8d3bin<1<ZN
R`C:WH/8b9^91<RMS0?7WXh4aYn@1<>PTPC1X9<4_InC1;VOU0BeWYH3/InG1:jOV0B[WYT4Z9jJ1:FO
W@BSWil3YJ>S1:RXZ@B^[Zl4]KFf1;fm_PC5aLD4c/g=0mSFe@CPgMd4i^GU1=SHf0C;cLd4`<;30kBh
^@BY[Jl4WZ>U19>IV`B9Si44OXF717=kOQGoool001Coool4HFMY15QMGPA?De<4ATQ813dm?@<c<C04
:BDT11hI5P@B2`P4610<12LK5@<g9b04Ac<Z15Q1=`A]DDD4PV9C19E`G`BXOV`3_8ei1<ZJQ@C?X8/4
cj6=1<jRSPC=XHd4c:2=0l^OS0C:WX/4bYf;2<RKR@C8WH`3aij>1<JOT0C3X984`J2C1;fOT`BiWi@4
]IjF0k6OU`B^WiP4ZijI1:RNVPBUWid4XinO0jFSX`BXZ:T4[Zj_1;Fe]PBm_Kh4aLG51<k=c@?He]D4
h=gM1>KUi@CHf=P4blg=1<32``>d^;T4ZJf_19jSY@BCVI/4RHnA17j5Q`AcNghEoooo000Doooo165W
J@AHGEh4Ce=C14I8B0@m?Cd3<c4`12TU90@N6AH44P/811P@30@W6aD3=bLP14Lc:PAH@CL4KE55189R
D`BEL5l4Z7i/0kb=N@C:VXD4cj2;1<nQS@C>XXh4cJ6=1<bPS@?;Wh`4bYj;1<ZMR`S8VhT4b9f<0lNN
SPC6Wi04`j2B1<6PT`BmWi<4^InD1;FNUP>aWiL4[YnH1:^NV@BXWYX4YInM1:>OW`>UXj<4Z:RY1:j^
[`Be]KH4_Kfn1<G5a@C>cLd3f=KE1>3Mg@CViND4f=SH1<_=c@C0`/<3];Ri1:V][`BNXjD4TiVK18V?
T@AnQHL4Lg]n5Oooo`005?ooo`APIfT4F5eO14mCE0A6B4T4?Cdm0c<b<@@X9RD47ATG10l:20@@2@H4
7QD@0bhP6P@n;BD4CCT`1659?PAfFD`4R6IG19YdH`>[PFh4_Hmk1<NGP`C=WHP4cZ2<1<fPS0C=XHd7
cZ2<1<fOS0C;WH/4c9f;1<jPSP?>XY44c:>C1<VSU0C6XiD4`Z>F1;fQUPBiXIL3]J2H1;6PV@B/WiT4
ZIjJ1:NPW0BTXIl3YJBS1:VYZ@B^[jl4]KFf1;bl_@C4a<@4cLc<0mSEe0CMfmX4f][J1<o@d@C5a/L4
^[fm0jnc]0BUZJ/4Vj2R196GV0B7SHl4OHB617=kOAGoool001Coool4H6MY15QMG`A?De@4ATQ913dm
?@<c<S44:2HU11dI5`@?2PP440T611hE40<^81X4?RdU14di<0AQBCh4MUU<18QVE`BJM6<3Zh5^1;f?
N`C7Uh<4cIf81<jPS0C=X8`4cJ6=1ljPS0C=Wh`4bif;1<bMR`C>X8h3cZ:A1<bST`C9Xi@4aZ>E1<:S
UPBmXIH4^J6G0kFPV0BaX9T4[9nI1:VNVPBWX9`4Y:6O0jFTX`BYZJT4[Zn_1;Fe]PBl_;d4a<C41<g<
c0?HeM@4gM_J1=[JfPC?d=44aLK71;Zm_@>_/k@4YJV[19^PXPBAUiP4Qhf?17f4QPAcNgdEoooo000D
oooo161WJ@AHGEl4Ce=D14I8B@@m?Cd3<c8a12PV9@@M6AL43`X811091P@N5A03;R0J13h]9@A=>C04
HDTn17IIC0B8IUL4VWAS0j^1KPBmSg/4aiN31<fMR0C>X8`4cJ2<1<fQS@O>X8`4cIn<1<^MR`C<WH/4
cZ2>0ljRT@C<Xi<4bJ>D1<JSU@C2XiH4_J6F1;VQU`>eX9P4/J2I1:bOV@BYWYX4Yj2L1:BQW`>UY:<4
ZJVY1:j_[`Be]KH4_;bm1<C4a0C=c<`3f=GD1=gKfPCJf]X4cm3A1<G6a`Bj_Kd3[k>d1:FYZ`BKX:84
TINH18N=S`AmQ8H4Lg]m5Oooo`005?ooo`APIfT4F5eO14mCE0A6B4T4?Cdm0c<b<@@X9RD47ATG10l:
20@@2@H47QD@0bhP6P@n;BD4CCT`1659?PAfFD`4R6IG19YdH`>[PFh4_Hmk1<NGP`C=WHP4cZ2<1<fP
S0C=XHd7cZ2<1<fOS0C;WH/4c9f;1<jPSP?>XY44c:>C1<VSU0C6XiD4`Z>F1;fQUPBiXIL3]J2H1;6P
V@B/WiT4ZIjJ1:NPW0BTXIl3YJBS1:VYZ@B^[jl4]KFf1;bl_@C4a<@4cLc<0mSEe0CMfmX4f][J1<o@
d@C5a/L4^[fm0jnc]0BUZJ/4Vj2R196GV0B7SHl4OHB617=kOAGoool001Coool4H6MZ15QMG`A?De@4
ATU913dn?P<c<c84:2LV11dJ6@@A3@/42P@211D>2`<U6QD4=BLP14@b:PAF@3H4Je1417YMD0B;JEX3
VGAS1:Z1K`BgRgP4`I9n1<NIQ@C9VhP4c9j:0lnPS0C?XHd4cZ2<2<fNR`C@XHh3dZBA1=6UU@C>YYH4
bjFF1<JTU`C2XiL4_Z>I0kVRV@BcXIT4[Z2I1:ZNVPBWWi`4YJ6O0jNTY0BZZJT4[Zj_1;Fe]@Bk^k/4
`l;21<_:bP?Dd]44g=_K1=7AdPC7bLT4_/311;Bg^0>Z[Zl4XJJW19NMWPB>U9H4QH^=17^3Q@AbNWdE
oooo000Doooo161WJPAHGEl4Ce=D14I9B@@m?Sh3<c<b12PW9P@M6QT44@d;10X40P@E3P/39AXE13DW
80A4<RX4ET0f16]@A0AjGE04RfUJ0iUdH`BZPFl4]h]h1<6BOPC7VHD4bI^81<bNRP??X8`4cj6=1<jP
S0S=WX/4d:6>0m:TT@CAYID4cZJF1<^UUPC6Y9L4`Z>G1;jSV@>iXYT4/j6I1:jPV@BZWYX4YinL1:FQ
W`>WY:@4ZZVY1:j^[`Be]KD4^k^k1<?2`PC;b/X3e=;A1=cKf`CAdM84alW91;k0`@Bd]kP3ZZj_1:6V
Y`BGWIh4SYBF18F;S@AkPhD4LWYm5Oooo`005?ooo`APIfX4F5eO14mCE0A6BDT4?Chn0c<c<P@X9bH4
7AXI114=2`@:10845@h;0bDJ5@@e9b04A38Z15I0=PA[D4@4NUe@18]YFP>IM6<4ZX5_1;N;N0C1TWh4
aiV51<VKR0C<WXX3cj2<1<nQS@C>X8`8cIj;1=2QSP?BY944dJFE1<jVUPC;YIH4aZBG1<:SU`BnXiT3
^J:I1;>QV@B^X9T4ZYjJ1:NOW0BUXIl3YjBT1:ZYZ@B^[Zl4]KFe1;^k^`C3`/84bl[:0mCBd@CLfm/4
dM7B1<O9b@Bn`<44];Nh0jZ^[`BQYZL4UifN18jDUPB5Rhd4Nh>5179jOAGoool001Coool4H6MZ15QM
G`A?De@4ATU913dn?P<c<c84:2LV11dJ6@@A3@/42P@211D>2`<U6QD4=BLP14@b:PAF@3H4Je1417YM
D0B;JEX3VGAS1:Z1K`BgRgP4`I9n1<NIQ@C9VhP4c9j:0lnPS0C?XHd4cZ2<2<fNR`C@XHh3dZBA1=6U
U@C>YYH4bjFF1<JTU`C2XiL4_Z>I0kVRV@BcXIT4[Z2I1:ZNVPBWWi`4YJ6O0jNTY0BZZJT4[Zj_1;Fe
]@Bk^k/4`l;21<_:bP?Dd]44g=_K1=7AdPC7bLT4_/311;Bg^0>Z[Zl4XJJW19NMWPB>U9H4QH^=17^3
Q@AbNWdEoooo000Doooo165XJPAHGV04CeAE14I:B`@m?d03<c@d12TY:0@N71`44a0?10L30P@<1`@3
71<@12XO6P@i:b@4BSP`15m7?@A^E4P4O5mB0hYYF`BGM6@4Y7i]1:n5M0BfS7X4_95o1<6EPP?6VHH4
bYb81<ZMR@C9W8T4bif91<fOS0??XXl4dJBC1=2VU@C=YIH4b:BF1<BSU`BoXYP3^j>I1;FQV@B_WiT4
ZYjJ1:ROW0BUXIl3YjBS1:VXZ0B][Jd4/k>d1;Vj^PC0`<04alO70lo>cPCBdm<4b<W:1;o1`PBf^KX4
[[:c0jFZZ`BMXZ<4U9ZK18^BT`B3RX`4NX64179iO1Goool001Coool4HFQZ15QNH0A?E5D4ATY;13do
@0<c=3@4:BTX11hL70@C40l41`<210`710<L4a04:QlJ13T[90A:>304GdLm16iDB0AlGe83RVUK19Md
I0BTOVd4[hEd1;J<NPBlTGl4`IF20lJIQPC:W8P4bYf91<VLR@C;WHT4cIn<0lnRS`CAY9<4d:JE1<fU
UPC8Y9H4a:>G1;nRV0>kXiT4]J6I1:nOV@BZWYX4Z9nL1:FQW`>WY:<4ZJRX1:f][@Bc/k@4^KZj1<30
`0C7alL3clk>1=;Cd`C8bLX4_l721;Ji^PB^/[<3YJZ[19fRX`BDVY/4Ri:C18>:S0AjPH@4LWUl5Ooo
o`005?ooo`AQJ6X4F5iP14mDE@A6BT/4?Cm00c<d=0@Y:BP47Q`L11<@3`@70`8430L40a`C40@Z7aX4
>B/T14Xh<0AOAcd4KUA817aODP>:JE/4UgAT1:AnK@B_QG@4]Xaj1;bAO`C1UH83aYV61<ZLR0C:WHT4
bIb91<^MR@C=Wh`3cj:?1=6TT`C@YYD4cJFF1<RTUPC4XiL4_j:H0k^SV@BeXIT4[inI1:ZNVPBXWi`4
YJ6O0jNTX`BYZ:P4[Jf]1;>c]0Bi^[X4`<301<O7a`??c/h4d]?C1<S9bPBo`L84][Vj1:jb/`>UZZ/4
WJ:S19BJV`B;TY<4PhZ<17Z1Q0AbNG`Eoooo000Doooo165XJPAHGV04D5EF14M;C0@n@D43=CHf12/[
:`@P7al45A<C10P61P@40@034Pd:124I5@@`91l4?S0Y150n=@AQBT44KUE:0gaOD`B9JU`4UG=T19mk
J`BUPG44[8If1;>:N@>iSgh4_I:02<6FQ0C3V8H4aYZ80lVMR`C;X8l4c:>B1<ZST`C6XY@4`Z:E1;jQ
UP>iXIL4]:2G1:jNV0BYWIT4YinL1:FPWP>VY:84Z:NW1:b/[0Ba/[84]kRi1;bm_PC1`l@3bLW:1<C6
a`Bn`<44]kZk1:nc]0BX[:d3X:FV19RNW`BAUYP4RHnA1868RPAiP8<4LGUk5Oooo`005?ooo`AQJ6X4
F5iP151EEPA7Bd`4?T510cDf=P@[:b/481lO11DC4`@81PH410400a8=2P@Q6AD4<2@O13h`:@A@?SD4
HDY116iEBP=lGe<4RFYL19EcI0BONf/4YH5a1:b6MPBcRWT3^Hmn1;fBP0S1UX@4`iR61<JJR0?9WH/4
bj2?1<bSTPC:Xi<4aZ:D1<:RU@BnXIH3^J6G1;BPU`B^WYP4ZIfI1:NOW0BUX9h3YZBR1:RWY`B/[:`4
/K:b1;Nh^@Bl_Kh4`L?40lW9bPC4a/L4_/311;Nj^`B_/k@4Z:b]0j2UYPBHWYl4TIJH18V?T@B1R8X4
NH23175iNaGoool001Coool4HFQZ15QNH0A@EEH4Ad]<13i1@@<e=SH4:b/[120O7`@E4a<420H610@1
00<B3@X48ATE130T7`@n<2T4D3he165:@@A^EDX3O5mC18UZG0BELf@4Wg][1:F1L@B/QWH4/hYi0kV?
OPBmTX08`IJ41<>HQPC6VXP3bIf;1<^PS`C<Xi84bZ>C1<JRU0C2XYD4_Z6F0kVQU`BdX9L4[YjH1:VM
V@BWWi`4YJ2N0jJTXPBXYjL4[:b/1;6b/PBg^;T4_;fn1<73a0?9bLX4a<K71;k0`@Bg^[/4[k>d1:R/
[@>PYJH4V9jO196FV0B9Si44PHR:17V0P`AaNG/Eoooo000Doooo165XJPAHGV04D5EF14M;C0@n@D43
=CHf12/[:`@P7al45A<C10P61P@40@034Pd:124I5@@`91l4?S0Y150n=@AQBT44KUE:0gaOD`B9JU`4
UG=T19mkJ`BUPG44[8If1;>:N@>iSgh4_I:02<6FQ0C3V8H4aYZ80lVMR`C;X8l4c:>B1<ZST`C6XY@4
`Z:E1;jQUP>iXIL4]:2G1:jNV0BYWIT4YinL1:FPWP>VY:84Z:NW1:b/[0Ba/[84]kRi1;bm_PC1`l@3
bLW:1<C6a`Bn`<44]kZk1:nc]0BX[:d3X:FV19RNW`BAUYP4RHnA1868RPAiP8<4LGUk5Oooo`005?oo
o`AQJ6/4FEmQ155FF0A8C4h4?d=40cHh>@@];Rh48R<S11PG5`@<2`/40P000`P510@H4Pl49QhJ13DY
90A5=Rl4Dd4i169<@`=]EDX4NUmC18EWF`B>KV44UWEW19akK@BRP743ZHEf1:b7N0BcSGd4]Hmo1;RA
P@BjTh<3_IN71<2IR@C1Vh`4_ib>1;fLS`BjWI44]ibB0k>LT`B]Vi@4ZY^E1:FKU`BTW9X4XijM0jBR
X@BVYZH4ZZ^[1:n`/@Be][L4^;Zk1;bo`@>m`<44^[bn1;Fh^@B_/k@4ZJf^1::WZ0>KX:84U9ZK18fC
U@B6S8h4OhJ817MoP@A`N7/Eoooo000Doooo165XJ`AIGf44DEIH14Q<CP@o@d@3=SPi12d^;P@R8b<4
61LG10`;2`@2000320D411PB3`@V7QX4=BTT14Df;`AC@CT4HTa30feEBPAjGe<4QFMK18i^H@BFMFL4
W7]]1::0L@>YQGH4[8Mh1;>=O@BeSgl4^9611;ZCP`>mUhL4`9V91<6KS0BoW8h4_Ib?1;ZMT@BgW983
/ibC1:fKU0BZViD4YI^G1:BLVPBSWYd3Y::Q1:JVYPBZZj/4[k2a1;Ff]`Bh^[/4_;o10kg0`@Bj_;h4
]KRi1:nc]0BY[Jh4XZNX0i^PXPBDVY/4SI>E18J<SPAoQXP4Mgn1171hNaGoool001Coool4HFQ[15UO
H@AAEUP4B4a>13m3A0<f>3T4;Bh^128S8`@H5aL430/;108000<81@@4618?12HN6P@e:B@4ACH_15=1
>@ARC4<3KEE:17YOD`B5Ie/4SViQ19IeI`BLNfd4XX1a0jV5MPB/QgP4/hem1;F?O`BhTH44^Y>30kfG
Q`C0VHT4`I^<1;nLSPBmW8l4^YfA1;NLTP>cW9<4[I^D1:ZKU@BUViL4Y9bJ1:>NW@>TXZ44YZJV1:Z[
Z`B_/;44]KJg1;Rj^`Bl_l43_L311;Zl_PBe^;T4[k>d1:V][PBRYjP3Vj2R19BJV`B=TiD4QXb>17n6
R0AgOh44L7Qk5Oooo`005?ooo`AQJ6/4FEmQ155FF0A8C4h4?d=40cHh>@@];Rh48R<S11PG5`@<2`/4
0P000`P510@H4Pl49QhJ13DY90A5=Rl4Dd4i169<@`=]EDX4NUmC18EWF`B>KV44UWEW19akK@BRP743
ZHEf1:b7N0BcSGd4]Hmo1;RAP@BjTh<3_IN71<2IR@C1Vh`4_ib>1;fLS`BjWI44]ibB0k>LT`B]Vi@4
ZY^E1:FKU`BTW9X4XijM0jBRX@BVYZH4ZZ^[1:n`/@Be][L4^;Zk1;bo`@>m`<44^[bn1;Fh^@B_/k@4
ZJf^1::WZ0>KX:84U9ZK18fCU@B6S8h4OhJ817MoP@A`N7/Eoooo000Doooo165YJ`AJH684DUMI14U>
D0A1ADH3>3/l12la<P@U9bL46a`L110@4@@510D30P4010l<2`@M5aD4:b8N13X^:@A7>384Dd8k0ee:
@PA[E4/4MeiC17iUFPB7K604SW5V19AfJP>LO6l4Wgmb1:B4MPBWQWP4ZhUk1:j<OP>`Sh44/i:41;FD
Q`BdUHP4/IF:1:nFR`B]UXd3ZYJ?1:FFT0BSUi84XIRD1:2JV0BOW9/3XJ2O1:>TY0BWZJX4[:j`1;6d
]@Bd^;X4]KVk0k>g^@B`];H4[;2b1:N/[@BRYjP4W:6S0iJLW@B@UYP4RY2B18>:S0AmQ8H4MWj0171h
NQGoool001Coool4HFU[15YPHPABEeT4BDi@1455AP<h>c`4;c4b12DW9`@K71`4410A10D41@<20@04
3``;11dG5@@[8Qh4>RhY14Lh<PAC@S/3GDY216]DB`AgGU<4OVEJ18M/H0B>LFH4U7IZ0ialK`BOOg84
Y8Af1:N6N0B[RG/4[Xan0k2?P@BcTX@4]IB71;BER0BaUHX4[iJ;1:fFS@>ZUXl4YIJ@1:>GTPBQV9@4
X9ZH19nLV`>QX9l4XjBT1:NYZPB/[[04/KBe1;Bh^PBe^K/3/kNi1;2d]PB//;84Yjb]1::WZ0BLXJ<3
UYbM192FV0B:T984PhZ<17f4QPAfOX04L7Qj5Oooo`005?ooo`AQJF/4FV1R159GF@A9CU04@DE60cPk
?0@_<C849BLW11/L70@@41441@@50`8100@?30/47ALE12/R7P@j;RT4AcPb15=2>`=MBT84JeA;17MN
D`AnIEX4QfaP18iaIPBDMVX3W7a_19moLPBTQ7H4YhIh1:^9N`B^S7h3/8n11;>BQ0BeU8L4]9F81;6E
RPB_UX/4[IJ=0jZFS`BUUY04XiNB1:6HU0BPVYP4WibK0j6PW`BSY:@4YjVZ1:b^/0Ba];D4];Rj1;Fi
^`>c]kT4/;Bf1:b`/PBW[:d4XZNX19bQX`>FW9d4T9JH18Z@TPB3RX`4OHB617InP0A`N7XEoooo000D
oooo165YJ`AJH684DUMI14U>D0A1ADH3>3/l12la<P@U9bL46a`L110@4@@510D30P4010l<2`@M5aD4
:b8N13X^:@A7>384Dd8k0ee:@PA[E4/4MeiC17iUFPB7K604SW5V19AfJP>LO6l4Wgmb1:B4MPBWQWP4
ZhUk1:j<OP>`Sh44/i:41;FDQ`BdUHP4/IF:1:nFR`B]UXd3ZYJ?1:FFT0BSUi84XIRD1:2JV0BOW9/3
XJ2O1:>TY0BWZJX4[:j`1;6d]@Bd^;X4]KVk0k>g^@B`];H4[;2b1:N/[@BRYjP4W:6S0iJLW@B@UYP4
RY2B18>:S0AmQ8H4MWj0171hNQGoool001Coool4HVU/15YQH`ACFE/4Be1B14=7B@<k?T04<SDf12T[
;0@O8B845AHG10T:2`<000041`H611@A40@P6aT4;BHS13/a;0A7>S@3D44k15]:@`AWDd/4KeYB17QR
F@AoIeh4QFeS0habJ0BAMV`4UWY_19YnLPBNPWD4X8Eh0j>7N`BVRWl4Yhb11:J>P`BTSX@4XXj61:6?
Q`>NShT4Vi2;19ZASPBKU944ViNE19^IV@>MWId4Wj6R1:BWZ0BZ[Jl4[[>e1:nd]PB]/[@3Zjna1:R]
[PBUZJ/4X:FW19bQX`BGW9h3TINI18bBU0B6SHl4PHR:17^2Q0AeOGl4KgMj5Oooo`005?ooo`ARJF`4
FV5S15=IF`A;D584@dM90c/n@0@b=CH4:B//11lQ8P@E5QL42@X;0`0000@71PH4514@120K6@@]9R<4
>c4/14Lj=0=@@C/4FdY316MCB`A_FU84N69I17mWGPB5KF<3S79X195fK0BFNVl4VWib19j2M@BPQGP3
XhMk1:J:O`BWS844YXj31:B>Q0BRSXH4XHn70ij?R@BKT8/4VY6>19^DT@BKUiD4ViVI0ifMW@BOXJ84
Y:NX1:Z][`B^/kD4[kBf1:fb]0>[[k44Z:f^1:FYZ`BPYJL4W:6S19NLWP>AUiT4S9:D18J=S`B1R8X4
Nh:417EmO`A_MgXEoooo000Doooo169YK0AJHF<4DeUK14]@DPA3AdT3>ci0138e=P@Y:b`47b4R11DF
5`@92P/3000010L61P@D4A0481/I12dV8`@k<B`4AcXd0e11>`AKBT<4Ie=;16mJDPAhHUT4OfMN18E]
H`><LVP4TGI/19IjK`BJOW84WX9e1:25N0>SQg/4YXYo1:N<P@BVSX<4Y8j41::>QPBQShL3WXn919^@
R`BJTHh4ViBA19^GU@BKVIT3WIfM19nQXPBTYjP4ZZf_1:jc]@B_];H4[K:d0j^_/@BX[Jh4YJV[1:2U
Y`BLXJ<4UibN0i6GV@B<TY@4QXf?1868RPAkPX@4MGeo16mgNQGoool001Coool4HVU/15YQH`ACFE/4
Be1B14=7B@<k?T04<SDf12T[;0@O8B845AHG10T:2`<000041`H611@A40@P6aT4;BHS13/a;0A7>S@3
D44k15]:@`AWDd/4KeYB17QRF@AoIeh4QFeS0habJ0BAMV`4UWY_19YnLPBNPWD4X8Eh0j>7N`BVRWl4
Yhb11:J>P`BTSX@4XXj61:6?Q`>NShT4Vi2;19ZASPBKU944ViNE19^IV@>MWId4Wj6R1:BWZ0BZ[Jl4
[[>e1:nd]PB]/[@3Zjna1:R][PBUZJ/4X:FW19bQX`BGW9h3TINI18bBU0B6SHl4PHR:17^2Q0AeOGl4
KgMj5Oooo`005?ooo`ARJV`4Ff9T15AJG@A=De@4ATY<0ci2A0@f>C/4;C0b12@W:0@K71h4414C0`<5
1P@00@842@X:11HD50@S7ad4;bTV13Xa;P=2>3@4C40j15I8@`ANCdT4JEQA171NE`AgHe`3O6QP189]
I@B7LFT4RWE/18miK`BCOG<3UGme19R3N@BIQ7/4VHIn19J6OPBFQh04U8R10i68P`B@RHD4T8^919:>
S@BCTY44U9FE0iNIVPBKWYl4WZ>U1:BYZ`B[/K@4Yjf`1:F[[@>SZ:X4XJJX19fSY@BJWj44UYbM19:G
V@>=TiD4R8nA18>:S0AnQHL4NH2317AkOPA^MWTEoooo000Doooo169ZK0AKHV@4E5YM14eCE0A6BT`3
?T9413Hi>`@]<38492LX11/L7P@@4A<30`D610010P@92PX45Q@D12<O7@@_:BH4>S4^0d8h=0A<@3X4
ETQ315i?B@AYF544L5iG17MSG0=lJ604PVeU18MaJ@B:MF`4SgU_19=mL`>EOgD4V8=i19V4N`BIQWh4
UXIn19J7P0BDR843THR31929Q@B@RhT4TXj=19>BT@BDUID3UiVJ19^NW`BNXjD4Y:V[1:^a]0BW[K04
YJ^]0j>XZPBQYZP4WJ>U19ZOX@BFW9d4TYNI0hfCU@B8Si44PhZ<17j5Q`AiP8<4M7]n16ifNAGoool0
01Coool4HVY/15]RI0ADFUd4CE=D14I:C0<n@T@4=STk12d`<P@T9bP46a`N110A4`<31@H4004210T:
2P@F51@48alM12lY9P@j<Bh3@SPd14a0>PAFB4<4GTm916UHD@A`GUL4Mf=L0gaXH0B2KFD4Qg5Y18Ye
K0B?NFl4Tgec0iEoM@BHPgT4VHAk19V6OPBFQWh4UXN019B8P@>AR8<4T8V5192;R@BBSXd4Ti:A19BE
U@>GVIX4VijO19jSY@BTZJ/4Zk6d1:N]/0BUZjd3XjRZ1:6VZ0BMXjD4VYnQ19JLW@BBUiT3SI>E18R?
T@B3RX`4OXF717V0P`AdNgh4KWIi5Oooo`005?ooo`ASJVd4G6=V15ILGPA?EEL4B4i@0d56B0@j?T04
<SHg12X];`@Q92D461XL0`h@4P@31PP40@<510/=3P@H61P49B8Q12lZ:@<g<Bl4?SLd14Lo>`A>AD84
F4e9161DC`AWFUD3K5mI179SGPAgJ684O6aV181`J@B5M6d3R7Q`18]kM0B=OWL4SX1i18^0NPB9OgX4
QWmk0hF0O@B5Ph04QXF418R8R0B;SHh4Si6B0i6EUPBFVY`4W:6R1:2VZ0BQYjX4X:JX19jTYP>LXZ@4
VYnR19NMW`BDVY`4T9NI18fCU@>9Si44Q8^=1827R@AlPhD4Mgn1179jO@A^MWPEoooo000Doooo16=Z
K@ALHfH4EUaN14mEE`A8CU03@DI813Xn@0@b=SL4:Rd_124T9@@H6Q`33Q0B10<620@10`D42`d>11PH
60@U8R44;bXY0cLa;`@n=c@4Aclk14i5@PAHCDT4H5A?16MJE@=/GeT4LV=N17MXHPAlK6H4P71Y18Ed
K@>8N704Rg]d18enM`B>P7T4Rh1j18UoNPB6Og/3QH1m18F3P0B6QH@4R8R818^=SPB?TI83TIFF19JJ
W0BLXJ84X:JX1:6WZPBPYZP4WZBV0ibRY0BJWj84UifO19BJW0B@UiT4SI>E0hV?T@B4Rhd4P8N917b3
Q@AgOh44LWYm16ifN1Goool001Coool4HfY]15aSIPAFG5h4CeEG14Q>D0=1ATP4>Si0138f=`@Z;Bl4
8B@U11PJ70<>41840`H810431@@;3@h461PH12DR8@@_:RT3=c4_13hg=0A7?c/4CTE215Q=B@APE4l4
IeYE0faOF@AbHeh4MfQR17a/IPB0L6T4QGA]0hQhL0B;Ng@4SGig18j0N@B;P7X4RGmj18IoN`>5P7d4
QH>018J5Q0B8R8P4Rhf>18nATP>AUIH4UYZL19bQXPBPYZP4XJNZ1:2VZ0BNY:H3W::T19ZOXPBGWIl4
U9ZL192GV@B=TiD3RHnA18B;S@B0QhT4O8>517MoP@AbNWd4KWIh5Oooo`005?ooo`ASJVd4G6=V15IL
GPA?EEL4B4i@0d56B0@j?T04<SHg12X];`@Q92D461XL0`h@4P@31PP40@<510/=3P@H61P49B8Q12lZ
:@<g<Bl4?SLd14Lo>`A>AD84F4e9161DC`AWFUD3K5mI179SGPAgJ684O6aV181`J@B5M6d3R7Q`18]k
M0B=OWL4SX1i18^0NPB9OgX4QWmk0hF0O@B5Ph04QXF418R8R0B;SHh4Si6B0i6EUPBFVY`4W:6R1:2V
Z0BQYjX4X:JX19jTYP>LXZ@4VYnR19NMW`BDVY`4T9NI18fCU@>9Si44Q8^=1827R@AlPhD4Mgn1179j
O@A^MWPEoooo000Doooo16=[KPAMIFL4F5iQ159HFPA;DE<3ADY<13i3A@@g?3d4<3@f12P/;@@P8bD3
5a/M10lB50@52@/40`L910hA4P@K71`49RDU0bl/;0@c<C04>SLf144m?0A8A484DT]915QACP=OEe<4
I5]H16UOG0A^I604LfQT17M/I`=kL6/4OW=^185gLPB3NWH4Pg]h185lN0AlNGL3NWUh17amO0AmOgl4
P8>418F9RPB:SY03SI:D192FV0BFWIl8V9nR19RNX@BGWIl3UI^N19>IW0BAUiT4SYFG18^BU0B8Si43
QH^>1868RPAmQ8L4NH6317EmO`AaNG`4KGEh5Oooo`005?ooo`ASJfh4GFEW15QNH@ABF5X4Be5C0dE:
C0@n@dD4=c`m130d=P@X;2d482<U0aLK7@@?4Q@41@T;10<72@@>4A846a`L12HU9@<_;2`4<c4`13Xg
=PA1?C`4B4A2159;B@AHDDh3GeMC16AKF0AYGe`4KVAP17=XI0AgK6L3Ng1[17icKPB1Mg84PgYf18=k
N0B1O7P4O7Ug0gYiN0AlOG`4OGmo1823Q0B5RHX4RXj@0hfBU0B@UYP4UYfO29ROXPBHWZ44UifO0iFK
WPBCVI`4TINI18jEU`B;TY@4R8nA0hF;SPB1R8X4OHB717V1P`AeOGl4LGUl16eeN1Goool001Coool4
Hf]^15eUI`AHGV44DUQJ14]AD`=5BT`4?T=513Ll?@@`=3H4:2`]120S9@<G6ad43a8D10D92`@31`T4
3Q4B11/L70@V9BD3;b`/13<a<0@j=cH4@Cdl14Q4@PABBdT4F55>0emGD`ATFeP4JEmL16iTH0AcJ6@4
MfaW0g]`J`AnLfh4PGMb18=jMPB3NgP4PGah17aiM`=jNGP4O7el17eoO`B0Ph@4QHV:18Z>T0>=TY@4
T9JH19JMW`RHWj84V9jQ19NMW`>EVih4TiVL196GV@B>UIL4Ri:D18R?T@>5Rhh4PHR:17f4Q`AiPH<4
MGeo175iO0A]MGPEoooo000Doooo16=[KPAMIFL4F5iQ159HFPA;DE<3ADY<13i3A@@g?3d4<3@f12P/
;@@P8bD35a/M10lB50@52@/40`L910hA4P@K71`49RDU0bl/;0@c<C04>SLf144m?0A8A484DT]915QA
CP=OEe<4I5]H16UOG0A^I604LfQT17M/I`=kL6/4OW=^185gLPB3NWH4Pg]h185lN0AlNGL3NWUh17am
O0AmOgl4P8>418F9RPB:SY03SI:D192FV0BFWIl8V9nR19RNX@BGWIl3UI^N19>IW0BAUiT4SYFG18^B
U0B8Si43QH^>1868RPAmQ8L4NH6317EmO`AaNG`4KGEh5Oooo`005?ooo`ATK6h4GfIY15UQH`ADFed4
CeEG0dU?D@A3B4X4?D9413Hk?@@_=3H4:2d_0b4U9`@I7R044QHH10T=40@83@l44QHI11dP8@<X:BT4
;Bh^138b<P@f=cL4?Sdm14A4@`A9B4P3D4i<15ECDPAKEeH4H5aJ16IQGPAZIF83KfUV175/J0AeL6d4
NGEb17]fM@AjMgD4MgMf0gQiN0AiNg/4NGen17^0PPB0QHL4Q8Z<0hV?TPB;TYH4T9RJ296HV`BAUiX4
T9NI0hnEV0B=U9H4Ri:D18V@TPB6SHl4Q8^=0h68RPAnQHL4NX:417MoP@AdNgh4L7Qk16eeMaGoool0
01Coool4I6a^15mVJ@AIHF<4E5]M14mEE`=9Ce44@dQ:13e2A0@f>cd4;c@f12P];`<Q9BL46AhP118F
60@93A0420d?118F6@@M8243:2TY12d^;P@b<S84=SLg13hm?@A4A4<4BDQ80e1>C0AEDe84FeMF161L
FPAVHEh4JVER0fmYIPAaK6P4MG1]17UeLPAkMWD4NWMe17MgMP=hNGP4NG]k17UmOPAkP884P8F718B:
S0>9Si84Ri:F192HVPRAV9/4TINJ192GV@>?UIP4SIBF18^BU0B9T984QXf?18B;S@>1R8X4OXF717Z2
Q0AgOh44M7]n171hN`A]MGLEoooo000Doooo16A/KPAOIVT4FF5S15AKG@A?EEL3BDmA14=8BP@m@T@4
=S/m12ld=P@X;Bl38BDW11TN80@B5QP42@d@10P=3`@B5QT47B0Q0bPY:@@];Rh4<S8b13Hg=`@n?Cd4
A4A314U8B0=@CT`4EE=B15]GEPAPG5X4IV5N16YUHP=_JFH4LFaX17E`K@AiMG84NgIe17YgM@AgMgH3
N7Uh17UkN`AiOGh4Nh221825Q`B4RX`3RHnB18^BUPB@V9X8TIRK196GVPB@UiT3SiFH18fDUPB;TY@4
RI2B18J=S`B4Rhd3PHR:17j5Q`AjPX@4Mgn117AkOPA`N7/4KGEg5Oooo`005?ooo`ATK6h4GfIY15UQ
H`ADFed4CeEG0dU?D@A3B4X4?D9413Hk?@@_=3H4:2d_0b4U9`@I7R044QHH10T=40@83@l44QHI11dP
8@<X:BT4;Bh^138b<P@f=cL4?Sdm14A4@`A9B4P3D4i<15ECDPAKEeH4H5aJ16IQGPAZIF83KfUV175/
J0AeL6d4NGEb17]fM@AjMgD4MgMf0gQiN0AiNg/4NGen17^0PPB0QHL4Q8Z<0hV?TPB;TYH4T9RJ296H
V`BAUiX4T9NI0hnEV0B=U9H4Ri:D18V@TPB6SHl4Q8^=0h68RPAnQHL4NX:417MoP@AdNgh4L7Qk16ee
MaGoool001Coool4IFe_161XJPAKHfD4EeiP159IF`==DeD4B4i@14=8BP@m@T@4=c`n134f>0<[<384
92T/11hS9@@G71h43Q<F10hD5`@G71l38RHX12T];P@]<C84<3<e13Hi>P@n@444@TE50dI8B@A9C4`4
CU1@15AEE@AIFUT4GUiM0f=RH@AVIF@4JVUX16a/J`AaLG04Kg5`16eaL@=^Lg<4KgEf175hNPAdNgh4
N7n217n6R0>3Rhh4QHfA18R@T`B9TI@8RY6D18V@T`>8Si84QhjA18J=S`B4Rhd4PXV;17n7R@=mQ8L4
NX:417QoPPAeOGl4LWYl16mgNPA/M7LEoooo000Doooo16E]K`APJ6X4Ff=U15MNH0ABFE/3CE=E14Q>
D0A3B4X4?D9413Ll?P@a=SP3:c0b12@Y;0@N8bD45a`N10hC5P@>51L45a`O0b8V:0@Y;Bh4;C4b130c
=@@f>CX4?T111495A@=6B4T4BDa<14i@D0ADEED4FEYI15iNG@=SHV44IVET16YYJ0A/K6/4LG5`16ma
L0A]LG43KW=c16meMPAaN7X4M7]n17QoPPAoQXP3Ph^>18F=T@B8T9<4RI6D28ZAU0B9T9<3R8nB18N>
T@B6SHl4Q8^=18:9R`AoQhT3OHB717Z2Q0AhOh84MGeo179jO0A_MgX4K7Ag5Oooo`005?ooo`AUKFl4
H6QZ15]SI@AGGV04DUUK0deCE@A8CU04@dQ:13e2A0@g?3h4<CHh0b/`<P@T:B`47R<U11LL7P@>4aH4
3Q@G11LL7`<R9RP4:Bd^12da<P@`<cD4=STj13i0@@A2ADD3ATQ914U<C0A>D504E5EE15UJF@ANGUd3
Hf9Q16IUI0AZJFP4K6a[175aL0A_LG04KG5a0ficL`A_MGH4LGQj17AkOPAhOh84OhJ80h>;SPB5SI44
R92C18VAU0R:TI@4RI2C0hR?TPB7SY44QXf?18B;S@B2RH/4OhN90gf4Q`AjPX@4N7n217EmO`AbNW`4
KgMj16adMaGoool001Coool4IFe_161XJPAKHfD4EeiP159IF`==DeD4B4i@14=8BP@m@T@4=c`n134f
>0<[<38492T/11hS9@@G71h43Q<F10hD5`@G71l38RHX12T];P@]<C84<3<e13Hi>P@n@444@TE50dI8
B@A9C4`4CU1@15AEE@AIFUT4GUiM0f=RH@AVIF@4JVUX16a/J`AaLG04Kg5`16eaL@=^Lg<4KgEf175h
NPAdNgh4N7n217n6R0>3Rhh4QHfA18R@T`B9TI@8RY6D18V@T`>8Si84QhjA18J=S`B4Rhd4PXV;17n7
R@=mQ8L4NX:417QoPPAeOGl4LWYl16mgNPA/M7LEoooo000Doooo16E]L0AQJF`4GVEX15YQH`AFGEl3
DEQJ14eDEPA9Ce44A4Y<13m5A`@j@483=CXm12le=`@Z;c8492X/11dT9P@F720451`P0a/R9@@V:bh4
;C8e134f>0@c>3X4=c`n13]0@P<nA4H4@dU:14I;C@A9CU04CE9D15AHFP=JGEd4GF5Q169TI0ASIfL4
JFa/16Q/K@AXKVl3J71a16UbM0A/MGL4L7Uk179lO`AlQ8L3OXJ:1828R`B2RHd4Ph^=18>;SPB4Rhh4
Ph^=0h>:S0B2RH/4P8R:17n6R@AmQHL4Nh>50gV1P`AgOh44MGeo17=kO@A`N7/4KWIi16]dMQGoool0
01Coool4IFe`165YK0ANIFP4FV5S15IMG`=AF5X4CEAF14U?D@A4BT`4?dE713Y0@P<e>Sd4;cDg12X_
<P@T:R`47B@V11HL80@D72036b8U12H[;P@]<SD4<CHh13<h>P@g?3h4>d120ci4APA3BDX4AT]=14U>
D0A=DU@4E5QJ0eYMG@AMHF44HVAT16=WI`AYK6`4J6a]16Q^K`=XL744JG9d16aeM`A`NG/4LWao17b4
Q`=nQXX4P8R;18:9S@B3Rhd4Ph^>18B;SPB3Rhd3PhZ<18:9R`B0R8X4OhJ917f5Q`AkPhD3NH6317Mo
P@AeOGl4Lg]m171hN`A^MWT4JgAf5Oooo`005?ooo`AUKG04HFU/15iUJ0AJHF<4EUeO0e5HFPA=E5H4
BDmA14A:C0@oADL4>T120cDj?@@_=CL4:Rlb12@Z;0@M92H45Q`P11@L80<K8RD49R/^12db=@@a=SP4
<cPj13Ll?P@k@483?TA614=9BPA6Bdd4BDi@14eBE0ADF5X3FUeM15eQH@ARI6@4HfMW16U/K0AXK6d4
J6i_0fQ`L@AYLW@4K7Eg171iN`AbO7l4O8B70gj6RPB0R8/4PXV=18>;S@B3Rhh4Q8^>18>;S@>3RX`4
PXV;1828RPAoQXT4OHF717^3Q@=iPH<4Mgn117EmO`AcNgd4L7Qk16ifN@A[M7HEoooo000Doooo16E]
L0AQJF`4GVEX15YQH`AFGEl3DEQJ14eDEPA9Ce44A4Y<13m5A`@j@483=CXm12le=`@Z;c8492X/11dT
9P@F720451`P0a/R9@@V:bh4;C8e134f>0@c>3X4=c`n13]0@P<nA4H4@dU:14I;C@A9CU04CE9D15AH
FP=JGEd4GF5Q169TI0ASIfL4JFa/16Q/K@AXKVl3J71a16UbM0A/MGL4L7Uk179lO`AlQ8L3OXJ:1828
R`B2RHd4Ph^=18>;SPB4Rhh4Ph^=0h>:S0B2RH/4P8R:17n6R@AmQHL4Nh>50gV1P`AgOh44MGeo17=k
O@A`N7/4KWIi16]dMQGoool001Coool4IVia16=[KPAPJ6X4GFAW15UQH`=FGEl4DUUL14mFF0A;DU@4
Adi@14=:C0<oADP4>d5313Hm?`@a>3/4;3<f12P_<P@S:Rh37bL[124Y;@@Z<SH4<3Pl13Hm?`@h?d84
>d950ca4A`@oB4/4A4]?14Q?DPA:DE@4CeII0e=JG0AIGf44GF9S161UIPARIfT4I6U[16A[K@=TK6l4
IVmb16QaM0A]MWT4KgQk17IoPP=iPH@4NX>617b4Q`AmQHP<OXF80gf5Q`AlQ8H4Nh>517Z2Q0AiPH<4
N7n20gInP0AdO7l4LgYm175iN`A_MgX4KGEh16]cMQGoool001Coool4IVia16=[KPAPJ6X4GFAW15UQ
H`=FGEl4DUUL14mFF0A;DU@4Adi@14=:C0<oADP4>d5313Hm?`@a>3/4;3<f12P_<P@S:Rh37bL[124Y
;@@Z<SH4<3Pl13Hm?`@h?d84>d950ca4A`@oB4/4A4]?14Q?DPA:DE@4CeII0e=JG0AIGf44GF9S161U
IPARIfT4I6U[16A[K@=TK6l4IVmb16QaM0A]MWT4KgQk17IoPP=iPH@4NX>617b4Q`AmQHP<OXF80gf5
Q`AlQ8H4Nh>517Z2Q0AiPH<4N7n20gInP0AdO7l4LgYm175iN`A_MgX4KGEh16]cMQGoool001Coool4
IVia16=[KPAPJ6X4GFAW15UQH`=FGEl4DUUL14mFF0A;DU@4Adi@14=:C0<oADP4>d5313Hm?`@a>3/4
;3<f12P_<P@S:Rh37bL[124Y;@@Z<SH4<3Pl13Hm?`@h?d84>d950ca4A`@oB4/4A4]?14Q?DPA:DE@4
CeII0e=JG0AIGf44GF9S161UIPARIfT4I6U[16A[K@=TK6l4IVmb16QaM0A]MWT4KgQk17IoPP=iPH@4
NX>617b4Q`AmQHP<OXF80gf5Q`AlQ8H4Nh>517Z2Q0AiPH<4N7n20gInP0AdO7l4LgYm175iN`A_MgX4
KGEh16]cMQGoool001Coool4Ifmb16A]K`ARJVd4H6MZ15eUI`=KHVD4F5mR15ELG`ABFU`4D5MI14eC
EP=9D5<4ATe@14=:C0@oATT4?4=613Q0@`@e?D03<CXn12`e>P@^=c`4<3Xo13Ho@`@mADP4?TM:0ci8
BPA1Bdh4A4iA14QAE0A;DeH4CUII0e1IG0ADG5l4EemQ15]RI@AMI6H4H6IX169XJ`=SJVd4IVia16A]
L0AWL7<4KGIj175jO@=dO7l4MGj117MoPPAhP88<N8230gR0PPAgOh84Mgj117InP0AeOGl4M7an0g=k
O@AaNG`4L7Qk16mgN@A]MWP4K7Ag16YcMAGoool001Coool4Ifmb16A]K`ARJVd4H6MZ15eUI`=KHVD4
F5mR15ELG`ABFU`4D5MI14eCEP=9D5<4ATe@14=:C0@oATT4?4=613Q0@`@e?D03<CXn12`e>P@^=c`4
<3Xo13Ho@`@mADP4?TM:0ci8BPA1Bdh4A4iA14QAE0A;DeH4CUII0e1IG0ADG5l4EemQ15]RI@AMI6H4
H6IX169XJ`=SJVd4IVia16A]L0AWL7<4KGIj175jO@=dO7l4MGj117MoPPAhP88<N8230gR0PPAgOh84
Mgj117InP0AeOGl4M7an0g=kO@AaNG`4L7Qk16mgN@A]MWP4K7Ag16YcMAGoool001Coool4Ifmb16A]
K`ARJVd4H6MZ15eUI`=KHVD4F5mR15ELG`ABFU`4D5MI14eCEP=9D5<4ATe@14=:C0@oATT4?4=613Q0
@`@e?D03<CXn12`e>P@^=c`4<3Xo13Ho@`@mADP4?TM:0ci8BPA1Bdh4A4iA14QAE0A;DeH4CUII0e1I
G0ADG5l4EemQ15]RI@AMI6H4H6IX169XJ`=SJVd4IVia16A]L0AWL7<4KGIj175jO@=dO7l4MGj117Mo
PPAhP88<N8230gR0PPAgOh84Mgj117InP0AeOGl4M7an0g=kO@AaNG`4L7Qk16mgN@A]MWP4K7Ag16Yc
MAGoool001Coool4Ifmb16A]K`ARJVd4H6MZ15eUI`=KHVD4F5mR15ELG`ABFU`4D5MI14eCEP=9D5<4
ATe@14=:C0@oATT4?4=613Q0@`@e?D03<CXn12`e>P@^=c`4<3Xo13Ho@`@mADP4?TM:0ci8BPA1Bdh4
A4iA14QAE0A;DeH4CUII0e1IG0ADG5l4EemQ15]RI@AMI6H4H6IX169XJ`=SJVd4IVia16A]L0AWL7<4
KGIj175jO@=dO7l4MGj117MoPPAhP88<N8230gR0PPAgOh84Mgj117InP0AeOGl4M7an0g=kO@AaNG`4
L7Qk16mgN@A]MWP4K7Ag16YcMAGoool001Coool4Ig1b16I^L@ATKFl4Hf]]165YK0=OIfX4GVEX15aS
IPAJHF@4F5mR15IMH0=DFeh4DUUL14mGFPA=EEL4Be9E14Q@D`A6CU83A4a@249;C`A1Bdl4@4U>14A=
D@A7Ce@3AdmC14M@D`A7DED4BUAG151HF`ACFed3E5eP15MOHPAHHF<4Ff=V15iUJ0APIfX4HVY]0eiV
JPASJfl4IVmb16QaM0A[M7L4KWIi0g1hN`AaNG`4LWYm179kO@acNgh3Lg]m279jO@AaNW`4LGUk171h
N`=_MgX4KgMi16ifN0A]MGP4K7Ag16]cMPAZLWDEoooo000Doooo16M`LPAVKW44I6e_16=[K@AQJF`3
GfMZ15iUJ0ALHfH4FV5T15QOHPAFGF03E5]N159IG0A?EeX4CEEG14]BE@A8D5<4ATiB0dA<D0Q2Bdl4
@D]?1419CPA4CE44AdmD0dM?D`A7D5<4Ae5E14YDE`A@F5/4De]M0eAMH0AGGf84F65S15]SIPANIFP4
H6MZ169ZK@=NIVX4Hf]_16I_LPAXLG@4JgAg16ifN@=`N7/4LGUl179jO@AbNgd<Lg]n0g=kO@QbNWd4
LGYl175iN`A`N7/3KgMj16mgN@A^MWP4KGEh16adM`A[LgH4JW9e5Oooo`005?ooo`AWL784IVia16A]
K`ASJfd4HFU/0emWJPANIFP4G6=V15YQI0AHGf84EUeP0eAKGPABFE`4CeMJ14eEE`A;DUD4B51C14I>
DP=4C508@T]?145;C`A0BDh4A4eA14M?E0=7Ce<4Ae1C14MAE@A:E5L4D5QK15=KG@=DGF04EemR15QQ
H`AKHfH4GVEX161WJPARJVd3GVIZ16=[K`AVKg84J75d16]dM`A^MWT3L7Qk175iO0AbNWd4LW]m37=k
OP=cNgd8LWYm175jO0AaNG/4L7Qk0fmgNPA_MgT4KWIh16eeN0A/M7L4Jg=f16YbMAGoool001Coool4
Ig1b16I^L@ATKFl4Hf]]165YK0=OIfX4GVEX15aSIPAJHF@4F5mR15IMH0=DFeh4DUUL14mGFPA=EEL4
Be9E14Q@D`A6CU83A4a@249;C`A1Bdl4@4U>14A=D@A7Ce@3AdmC14M@D`A7DED4BUAG151HF`ACFed3
E5eP15MOHPAHHF<4Ff=V15iUJ0APIfX4HVY]0eiVJPASJfl4IVmb16QaM0A[M7L4KWIi0g1hN`AaNG`4
LWYm179kO@acNgh3Lg]m279jO@AaNW`4LGUk171hN`=_MgX4KgMi16ifN0A]MGP4K7Ag16]cMPAZLWDE
oooo000Doooo16QaL`AWL784Ifmb16I^L@AUKG03I6a_16=[KPARJVd4HFU/161XJ`AOIfX3GVIY15eU
J0ALI6L4Ff=V15YRI@AIHF@4F61S0eMOHPAFGV8<EEiR15IOH`AGH6<3EemS15MPH`AFGf<4E5iR15IO
H`AGH6<3F65T15URIPAJHfH4FfAW15aTI`ANIfX4I6a_0fE]L0AVKW44Ig1c16UaM0AZLgD4JgAg0fae
M`A]MGP4KGIh5fifN@A]MWP8KGEh16eeM`M/M7L4JgAf16]cMPAZLgD4JW9e16UbMAGoool001Coool4
J75c16M`LPAWKg84IVia16E]L0=TK6l4Hf]^169ZK@AQJF`4H6Q[15mWJP=NIVT4GFEX15aTI`AKHfH4
FV9U15UQI0AHH6<3EemR15INHPaEGV84EUmS15MPH`=GGf<4Ef1S15IOH`ADGV84EUmS15MPH`=HHF@4
FF9V15YSIPAKI6L4G6AW15iWJPATK6l3IFe`16I^L@AWL7<4JG5d16YcM@A[M7L3K7Eg16eeN0A]MWPG
KWIi16efN0Q]MGP4KGEg1fadM`A[M7H4Jg=f16YcM@AZLWD4JG9e5Oooo`005?ooo`AXLG<4Ig1b16M_
LPAVKW44IFe`0fA/K`ASJfh4HVY]165YK0APJ6/4GfMZ0eiVJ@AMIFP4G6AW15]SIPAJHVD4FF5T15QP
H`=GGf84EUiR35ENHPAFGf<4Ef1S0eMOH`AGH6<4EUmS15ANHPAFGf<4Ef1S0eQQI0AIHVH4FV=V15]T
I`ALI6L4GVMZ16A/K`=UKG04IVia16M`L`AYLG@4JW=e16]dM`=/MGL4KGEh16efN1M^MWT4KGIh26ee
N0A]MGL7K7Ag16]dMPA[LgH4JW=e16YbM@AYLWDEoooo000Doooo16QaL`AWL784Ifmb16I^L@AUKG03
I6a_16=[KPARJVd4HFU/161XJ`AOIfX3GVIY15eUJ0ALI6L4Ff=V15YRI@AIHF@4F61S0eMOHPAFGV8<
EEiR15IOH`AGH6<3EemS15MPH`AFGf<4E5iR15IOH`AGH6<3F65T15URIPAJHfH4FfAW15aTI`ANIfX4
I6a_0fE]L0AVKW44Ig1c16UaM0AZLgD4JgAg0faeM`A]MGP4KGIh5fifN@A]MWP8KGEh16eeM`M/M7L4
JgAf16]cMPAZLgD4JW9e16UbMAGoool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool009Koool30000Qoooo`00VOooo`030000oooooooo08Coool0
07koool400000_ooo`@00003oooo100000;oool300000oooo`<00003oooo0P00087oool007koool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`040000oooooooo00000_ooo`030000oooooooo
00?oool010000?ooooooo`0008Koool007ooool00`000?ooooooo`03oooo00<0003oooooool00_oo
o`040000oooooooo00000_ooo`@00002oooo00@0003oooooool00026oooo0020oooo00<0003ooooo
ool00oooo`030000oooooooo00;oool300000oooo`800004oooo100008Goool007koool010000?oo
ooooo`0000;oool010000?ooooooo`0000Goool00`000?ooooooo`2@oooo001ooooo0P0000Coool2
00001Oooo`80002Boooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
6F74756F74756F74756F73756F73756F73746F73746F73746F73746F73746F72736F7273
6F72736F72736F72736F72726F72726F71726F71726F71716F71716F70706F6F6F6F6D6C
7070707071727072736F71726F72736F72736F71736F71726E71726E71726E71726E7173
6E71736E73746E73756F757670767870777970777971787A717A7C727B7E737C7F747E82
768286747E81737C7E737A7D72797C72787B72787B71787A717779717779717678707678
707577707577707576707476
6F74756F73756F73756F73746F72746F72746F72736F72736F71726F71726F71726F7171
6F70716F70706F70706F6F6F6F6F6F6F6F6F6F6E6E6F6E6D6F6D6D706D6B706B696F6967
706C6B706E6E706F6F6F6F6F6F70706E6F706E6F6F6D6F706E6F706D6F706C6F706D7071
6D70726D72746D73756F767870777A71797C727B7D727D80737F8275828677858978888E
7B8A9078858A768286758084757F82747D80747C7F737B7E737A7D727A7C72797B71787A
717779717678707577707576
6F73756F73746F73746F72746F72736F72726F71726F70716F70716F70706F6F706F6F6F
6F6E6E6F6E6E6F6D6D6F6D6C6F6D6C6F6C6B6F6C6A6F6B6A706A68706A67706865706662
716A67706B6A706D6C6F6D6D6F6D6D6E6D6D6D6D6C6C6C6D6D6C6D6C6C6D6B6D6E6B6F70
6C70716C72736D73756E767970797C717C7F737E8274818576858978888D7A8C927D9198
7D90967B8C9179888E78868A778488768286768084757F82747E81747C7F737B7E727A7C
72797B71777A717678707577
6F73756F72746F72736F72736F71726F71716F70706F6F6F6E6F6F6E6E6E6E6E6D6E6D6D
6E6C6C6E6C6B6E6B6A6E6B696E6A696F6A686F69676F686670686570676370666170645F
716764716967706B69706B6B6F6C6B6E6C6B6D6B6B6B6A6A6C6A6A6B6A6B6A6B6B6B6D6E
6B6F716C72736C74766D777A6F7B7E727F8274828676868A788A8F7A8E947D939A8199A2
7F959C7D91987C8E947B8B9079888D78868B788488778386768184757F82747D80737C7F
737A7D72797B717779707577
6F73746F72736F71726F71726F70716F70706E6F6F6E6E6E6E6D6D6E6D6C6E6C6B6E6B6A
6E6B696E6A686E69676E68666E68656E67646F66636F666270656170656071645F71625C
726562716765716967706A696F6A696E6A696D6A6A6C69696B69696B69696A6A6A6B6C6D
6B6F706B71736C74776D787A6F7D80728185748589778A8F7A8F957D949B809AA2839FA8
819AA280969D7E93997D90967C8D927A8A8F79888D78868A778488768285758083747E81
737C7E727A7C71787A707678
6F73746F72736F71726F70716F70706E6F6F6E6E6E6E6D6D6E6C6B6E6B6A6E6A696E6968
6E69676E68666E67656E66636E65626E64616E64606F635F70635E71625D72625D73625B
7365607266637168657068677069686F69686E69696D69696C69696B69696B6A6A6B6B6C
6B6E706B71746C75786D787C707E8173848875898D798D937C939A7F99A183A0A985A2AC
839EA7829BA380979F7F949B7E91977C8E947B8C917A898E79878B788488778286757F83
747D80737B7E72797B717678
6F73746F72736F71726F70706E6F6F6E6E6E6E6D6C6E6C6B6E6B6A6E6A686D69676D6866
6D67646D66636D65626D64606D635F6D625E6E615D6E605B6F605A71605A73615A75645D
7465607366627267647167667068676F68676E68686D68686D69696C69696C6A6A6B6C6D
6C6F716C73756D77796E7B7E70808473868A778C917A91977E989F829FA786A6B086A6B0
85A2AC849FA8829CA48198A080959C7E92987D8F957C8C917B8A8F79878B788488768185
757F82747C7F72797C717779
6F73746F72726F70716E6F706E6E6E6E6D6D6E6C6B6E6B6A6D69686D68676D67656D6664
6D65626D64616D625F6D615D6D605C6D5F5B6D5E596D5D586E5C566F5C5578635C78655E
7565607465617266637166657067666F67666F68676E68686D68686C69696C6B6B6C6D6E
6C70716D74766E797B6F7D8072828675888D788E947C959C809CA484A3AC88ABB688A9B4
87A6B086A3AC84A0A9839DA58299A180969D7F93997E8F957C8C927B898E79868A778387
768083747D80737A7D717779
6F73746F71726F70706E6F6F6E6E6D6E6C6C6E6B6A6D69686D68666D67656D65636C6461
6C63606C625E6C605C6C5F5B6C5E596C5C576C5B556C5A546C58526D58517E675F79655E
7664607464607365627265637166657067656F67666E67676D67676D69696C6C6B6D6F6F
6D72746E77786F7B7D717F82748589768B907A91977E989F82A0A886A7B18BAFBB8AADB8
89ABB588A7B187A4AD85A1A9849DA5829AA181969D7F93997E8F957C8C917A888D798589
778285757E81737B7D717779
6F72746F71726E6F706E6E6E6E6D6D6E6B6B6D6A696D68676D67656C65636C64616C625F
6C615D6C5F5B6C5E596C5D586B5B566B5A546B58526B57506A544D735C547B645C78635D
76635F74635F7364617265627165647066656F66656E66656D66666D68686C6C6B6D7070
6E75756F797A707E7F72828576888B788E937C949A7F9BA283A2AB88AAB48CB2BE8CB2BE
8BAFBA8AACB789A8B287A5AE86A1AA849DA5839AA181969D7F92987D8E947C8A8F7A878B
788387767F82747C7E71787A
6F72736F70716E6F6F6E6D6D6E6C6C6D6A696D69676D67656C65636C64616C625F6B615D
6B5F5B6B5D596B5C576B5A556B59536B57506B554E6A534C705850775E5677605977615B
75615D74625E7363607264627165637065646F65646E65646D64646D68686C6C6B6D7171
6E7676707C7C718081748587778A8E7B91957E979D819DA584A4AD89ABB68CB3BF8FB7C4
8EB4C08CB1BC8BADB88AA9B388A5AE87A1AA859DA58399A081959B7F91967D8D927B888D
788589768084747C7F72787A
6F72736F70716E6E6E6E6D6D6D6B6A6D6A686D68666C66646C64616C625F6B615D6B5F5A
6B5D586A5B566A5A546A58526A564F6A554D6A534B6C534A765C53765D55765E57755F5A
74605B73605C73625F7263627264637164647064646F64646D63636C66666C6A6A6D7070
6E7475707C7C728182758789798D907D9397819AA0849FA786A5AE8AACB68CB3BE90B9C6
90BAC78FB5C28DB1BD8CADB88BA9B389A5AE87A1A9859CA483989E8193997E8F947C8A8F
79868A778185747D8072787B
6F72736F70706E6E6E6E6C6C6D6A696D69676C67656C65626C63606B615D6B5F5B6A5D58
6A5B566A59536A575169554F6A544C6A524A6A5047785B52775C53765C55765D56755D58
735D59725E5A72605E7363617264637164637163647065646D64656C65656D696A6D6D6E
6D707170797A72818276888A7B90927F9599839CA286A1A988A7AF8AACB68DB3BE8FB8C5
92BDCB91BAC790B6C28FB2BD8DAEB88BA9B289A4AD87A0A7859BA282969C8091967D8C91
7A878B788286757E8172797B
6F72736E70706E6E6D6E6C6B6D6A686D68666C66636C64616B615E6B5F5B6A5D596A5B56
69595369575169554E69534C695149694F466D51477A5D53785C53775C54765D56745C56
725B56715B58715E5C7363627264637164637567677164646E66666C65656B66676B6B6C
6B6D6F6E7577717C7E7887897D919382989A859EA488A4AB89A8B08BACB68DB2BD8FB8C4
93BECB93BFCD92BBC891B7C290B2BD8EADB78CA8B189A3AB879EA584989F8193997E8E93
7B898D788487757E8172797B
6F72736E6F706E6D6D6D6B6A6D69676C67656C65626B625F6B605C6A5E596A5B56695954
69575168544E68524B685049684F46674C4278594E7B5D52795C53765B53765C56735A54
7158536F5855705C5A7160607667667264637467677165656F65656D66666A64646A6A6B
696C6E6A71746D7679778385809093849A9D88A0A58AA6AC8BA9B18BACB68DB1BC8FB7C3
92BCCA94C1D095BFCC95BBC893B7C291B1BB8FACB58CA6AF89A1A8869BA283959B809095
7C8A8F798588767F8273797C
6F71726E6F6F6E6C6C6D6A696D68666C66636C63616B615E6B5F5B6A5C57695A54695751
68554E67524B664F48664E45684D44694C427F5F527C5D53795C53775A53755B54735953
7056516E57536F5A586E5D5D786A697569687368677168686F66656D66666B66676B6C6E
6A6E706A72756A7477707E827B8A8E87999D8BA2A78DA8AE8CABB38CADB68CB0BB8FB5C2
91BCC994C1D096C1CF98C0CD98BCC795B6C092B0B98EAAB28BA4AB889DA484979E819197
7D8C907A8689768083737A7C
6F71726E6F6F6E6C6C6D6A696C67656C65626B625F6B605C6A5D596A5B5669585268564F
67534C664F48644C446249406A4E457354497F5F537C5D53795B52775B53755B54735852
6F55506E58546F5A586F5D5C7564637466657266657167676F65656C66666B66676C6C6E
6B6F716D76786D767A707E8375868A8294988DA4A88EAAAF8EACB48CACB68CB0BB8EB5C1
91BBC893C0CF97C3D299C2D19CC2CD98BAC595B4BD91ADB68DA6AE8AA0A7869AA0829399
7E8D927B878B778084737A7D
6F71726E6E6F6D6C6B6D69686C66646C64616B625E6B5F5B6A5C57695A5469575068544D
675149654D456248405D43396B4E447D5C507D5D517B5C52795B52775B53765B53735852
705651705A5573605D73615F7362617363627164637063636E62626C63636B65666B686A
6C6E706D74776F777C717E8375868B7D90958BA1A690ABB08FACB48CACB58CAFBA8EB4C0
91BAC793BFCD96C3D2A0C9D79FC5D19CBFCA98B7C194B0B990A9B18BA2AA879CA283959B
7F8E937B888C778184737A7D
6F71726E6E6E6D6B6B6C68676C65636B63606B605D6A5E596A5B5669585269564F68534B
675047654C4362473E5F44396A4D43795A4F7B5B517A5B52795B53775B53765B53745852
715751715A5575625F7563617464627363627164637063626E62626C63636C65666B696A
6D6D706E727672787D747F8478868B7D8F95869BA18DA7AC8EABB38CACB58CAEB98DB3BF
90B8C691BDCB92BFCFA5CEDCA3CAD69FC2CD9BBBC596B3BC92ACB48DA5AC899EA485979C
8190947C898D788285747B7D
6F71726E6E6E6D6B6A6C68666B65626B625F6A5F5B6A5C576A5A5469575069544D695249
684F46674C4266493F694B406E504675574C795B517A5C52795C54785B53775B53755952
725852725A5575615D7665637566647464637264627063626E62616C62626C65666C6A6B
6D6E706F737773797E7781867B898E809197859AA08AA3A98CA8B08CAAB38BADB88DB2BE
8FB7C490BBCA90BECEA8D0DEA7CDD9A2C6D19DBEC899B6C094AFB78FA7AF8BA0A686989E
8291967D8A8E798286747B7E
6E71716E6D6D6D6A696C67656B64616A615D6A5E596A5B5669585269564F69534B695148
694E456A4C426B4C406D4F4471544976594F7A5C517B5E547A5E55795D55785C54765B53
745953745B55745F5B7665627667657466647264627064636F63626C62626C65656C696A
6E6F71707477757B7F7982877D8A8F8191978599A08AA1A98BA5AE8BA8B28BACB78DB1BD
8EB6C38FBAC88DBCCCAAD2DFABD1DDA6C9D5A0C1CC9BB9C396B1BA91A9B18CA1A8879AA0
8392977E8B8F798386747B7E
6E70716D6D6D6C69686B66646A63606A605C695C58695A5469575069544D6952496A5046
6A4E436B4C406E4E4270514574574C785C527C5E547C60567B60577A5F56795D56785C55
765B54755C56755F5A7764617768667566657364637164626F63626C62626C65656C696A
6F6F71717477767C807B84887F8C9083929886999F899FA789A3AB8AA7B08BABB68DB0BC
8EB5C28EB9C78BBACAA6CEDCAFD5E2A9CDD9A3C5CF9DBCC598B3BC93ABB38EA3AA899BA1
8493987F8B907A8487757C7E
6E70716D6C6C6C69686B65636A625F695E5A695B5668585268554E68524B6950476A4E44
6B4D416D4C3F6F5044725348785C517C5F557D60567D62587C61587B60587A5F57795E57
785D56775E57765F5A7764607868657667657465647165636F63626D62626C65656D6A6B
707072737678777D807C858A818D9285939987999F889DA589A1AA8BA6AF8CAAB58EB0BB
90B5C190B9C78EBAC99CC7D6ABD4E1AED3DFA6C7D29FBEC89AB6BE95ADB58FA5AC8A9DA3
85949A7F8C907A8487757C7E
6E70716D6C6C6B68676A646269605D685D5968595467565067534C685148694E456A4C42
6C4B3F6E4C3F71514576594C7D61558062577F63597F635A7E635A7D62597C61587B6058
7A605879605978615C7965607968647767657566647266646F63636D63626C65666E6B6C
71717375787A797F827F878B838F9486949A88999F889CA489A0A98BA5AE8DAAB58FB0BB
92B5C194BBC896BECB9BC5D4A4CFDDABD1DEA6C9D4A1C0CA9BB7C096AFB791A6AD8B9EA4
86969B808D917B8588757C7F
6E70706C6B6B6A6766696361685F5C675B5766585266544E66514A674E46684C42694A3F
6C483C6F4B3F7453467B5E5280655983655A82655A81645B80645B7E635A7D625A7D625A
7C625A7B635C7B645E7A67627A69657868657566647365647063626C63626C66666E6C6C
72727377797B7B808380888C848F9486949A88989F889CA38AA0A88CA5AE8FAAB491B0BB
94B6C298BDC99BC0CDA1C9D7A8D3E1A9CFDCA6C9D5A2C2CC9DB9C298B1B992A8AF8D9FA5
87979C818E927B8589757D7F
6D6F706B6B6A6A666568625F675D5A65595565565064524B644F47654C4366493F68473C
6C473B704C4077564A80635686685C86685D85675D83665C81655B80645B7F635B7E635B
7E645C7D665E7E67617D6A657D6B677A6A677768657466647063626D63626C66666F6C6D
727374777A7D7D828582898D858F9487949A88989E899CA38BA0A88EA4AE91AAB493B1BB
97B7C29BBECA9EC2CEA4CBD9AAD4E2ABD3DFA8CCD7A4C4CE9FBBC49AB3BA94AAB18EA1A7
88989D828F937C8689767D7F
6D6F706B6A6A69656467605E655C5864575363534E624F49624C4463494064463B654337
6A473B7250437E5C4F89685B8B6C5F8A6B5F87695E85685D83665C81645B7F645B80645C
7F655E806860806A63806C677F6D697C6C687969677567657163626D63626C66676F6C6D
737475787C7E7D838682898D858F9488949989989E8B9CA38CA0A88FA5AE92AAB495B1BB
99B8C29EBECAA2C2CEA7CEDAACD3E1AFD8E4ABCFDAA7C6D0A1BEC69CB5BC96ABB290A2A8
8A999E8390947D878A767D80
6D6F6F6A6969676463655F5C635A5661555160514B5F4D465F494160463C614237613F32
654539735346836153926F609170628E6E618B6B5F87695E84665C82655B80645C80645D
81665E826962836E6684706A82706B7F6F6B7B6C697668657164636D63626C66676F6D6D
737476797C7F7D838682898D858F948894998A999E8D9DA48EA1A991A6AF94ABB597B1BB
9BB7C2A0BEC9A4C3CDABCEDAB0D4E1B3DCE8AFD2DDAAC9D3A4C0C99EB7BE98ADB492A4A9
8B9A9F8491957D878A767E80
6C6E6F696868666361635D5B6157545E524E5D4E485C49435C463E5D42395D3F345E3C30
6043377253478664569A74649774659270638E6D61896A5E84665C82655C80645B81655E
836760866B6388706888736C86746F83736F7D6E6B7769667164636D63626C66666F6C6D
727476797C7E7D838681888C868F9389949A8B999E8E9EA590A2A992A7AF95ACB599B1BB
9DB7C2A1BDC8A5C2CDAFCEDAB6D9E5B8E0ECB3D6E0ADCCD6A8C2CBA1B9C09BAFB694A5AB
8D9CA08692967E888B777E80
6C6E6E686767646160615B595E55525B4F4B594A4558453F58423A593F365B3C315C3D32
5F42377355488B6859A179689C77679673659170638B6B5F84665C80635A7D61597D635B
82675F896C648C726A8B746D8A77718878737F716E786A687164626C62616B65656D6B6C
717275777B7E7B81857F878B858E928994998C9A9F919FA592A3AA94A7AF96ACB59AB1BB
9FB7C2A2BDC7A6C1CCB1CED9BBDCE6BEE3EFB8D9E3B1CFD8ABC5CDA4BBC29DB1B796A7AC
8E9DA18793967F888B777E80
6B6D6E67666662605E5E59575B524F574C4854464153413A533D35553B325A3B305C3E34
5D433974564A8F6B5BA67D6BA07A699A75679472648E6D6187675D7F62597B6058765E57
7C635C866B628C726A8D736C8B767088787380726F786B687164626B61606964646B6A6B
6D6F72777C7E7980837D858A848D918B959A8E9BA093A1A695A5AB96A8B097ACB59BB2BB
9FB7C1A2BCC7A8C2CDB6D1DBC1DEE8C3E6F0BCDCE5B6D2DAAFC8CFA8BDC4A0B3B998A9AE
909EA288949780898C787E81
6A6D6E656665605E5D5C5755574F4C5348444F413C4C3B354B362F4E352C5E40345F4338
62483D76584C936D5DAB816EA57D6C9E7869977366916F638A6B6083655B7E6259775F57
7A615A80675F876F678C736C8B767086767180726E786B687064626A6160676262686769
696B6F71787B727B7F778186848C908A94998E9A9F96A2A797A6AC98AAB197ADB69AB1BB
9EB6C0A1BBC6AAC3CEBCD4DDC9E2EBC9E9F2C1DFE7BBD5DCB3CAD1ACC0C6A3B5BB9BAAAF
92A0A48A9598818A8D787F81
6A6C6D6464645E5C5B595452534C494E4340483B3743332E3E2B25462F275B3F3465493D
6A4E437D5E50977060AF8471A87F6EA17A6B9974669372658E6E6387695F82645B7E625A
7E645B826860866D658A736B89746E85746F7F716D776A677064616A6160676161676668
696B6F6C73786B767B6C79807F888D85919689969B94A0A596A4AA97A9B096ACB598B0B9
9CB4BE9EB8C4ACC5CFC0D6DED0E6EECFEDF6C8E2EAC0D8DFB8CED4B0C3C8A7B7BC9EACB1
95A1A58B9699828A8D797F81
696B6C6363635C5A595651504F4846483F3C413531392B262F1E19402C2451382F62473C
6D51468462549B7363B28672AB8270A47D6D9B76699472658F6F648B6D6286695F83665D
83675E856B62886E668A726B8A756F84736D7E6F6B7769666F6462696260666161666667
696C6E6C72776C757B6B787F7682887D8A908492988E9CA292A1A893A6AE94A9B295AEB7
98B2BC9BB6C1AFC6D0C4D7DFD4E6EED6F1F9CEE7EEC6DCE2BDD1D6B4C5CAAABABEA1AEB2
97A2A68D979A838B8E798082
686B6C6162625A5858534F4E4B4543443B383B302D3225212717133826204A352D5D443A
6F52468764559F7665B38673AF8473A780709F7A6D977467906F638B6C61866A6085685E
83675E846A60866C6387706887736C83706B7D6C687668656F6462696261666161646465
686C6D6D73766E777C717C817682887B888E8190968A989F8D9EA58FA3AB91A7B093ABB5
93AFBA99B5C0B1C7D0CADAE0D4E5ECDBF4FAD5EBF1CDE0E6C3D4D9B9C8CDAEBCC0A4B0B4
99A4A78F989B848C8E7A8082
686A6B606161585756504D4C4843413F3835362C292C201C21130F30201B443129594137
6E5145876456A07766B38673B28776AB8374A37E719C796C9474688E6E64896C62886A61
85695F846A60846A62856D65846F68816E687B6A667667647065636A6362666162626263
6367696970736E777A757E827984897C898E808F9586969C899BA38CA0A98EA5AE8FA8B2
8EABB69AB6C1B3C8D1CEDBE1D5E5EBDEF4FAE1F4F8D5E6EAC9D8DCBECBCFB2BEC2A7B2B5
9BA5A890999B858C8F7A8082
676A6B5F60605655554E4B4A45403E3C3533322926271D1A1C100C2B1C173E2D26543E34
6B4F438663559E7665B28572B48977AE8777A78274A07E7199796D93756A8F71678C6F64
896D63876C63866C62846C63826C647F6C667A69647667647166646D6564696465646466
616568636B6E667175707A7E7782877C898E7F8F9584949B8799A18A9FA88BA2AC8AA5AF
8AA8B39CB7C1B4C9D1CCD9DED9E6EBE0F2F7EBFAFDDCEAEECFDCDFC2CED1B6C1C4AAB3B6
9EA6A9929A9C868D8F7B8082
67696A5E5F5F5554544C4948423E3D3833312E2724231A17180E0A271A15382822503A32
674C418160529A7363B08371B58A78B18A7AAA8577A382759D7D72987A6F93766C8F7369
8C7066896F65876D63856C64826B647F6A647B69647667647367656F67666B6768686769
65696B656B6F656F7469757A6F7C8276848A7A8B9280919882969F869BA5869FA986A2AD
88A6B29CB7C0B3C7CFC8D7DCDBE6EAE7F4F7F1FCFFE3EEF1D5DFE2C7D1D3B9C3C5ACB5B7
9FA7AA939A9C878D8F7B8182
66696A5D5E5F5353534A4847403C3B36312F2B2422201815150B082419143526204B372F
63493F7C5D50957060AB806FB68B79B48C7CAD897AA78578A081759B7D7296796F92766C
8E73698B7067886E65866D64826C647F6A647B69647768647469667169686E696A6B6A6C
686C6E686E716872766A767B6D7B8171818776878F7B8E967E939C8097A1819CA683A0AB
89A7B39DB7C0B3C7CEC6D6DBDBE5E9EBF4F6F6FEFFEAF3F5DAE2E4CAD3D5BCC4C6AEB6B8
A1A8AA949B9D888E8F7C8182
66696A5C5D5E5252524847463E3B3A332F2D2923211D161412090622171332241E47332C
5D453B77584C8F6B5CA57C6BB48977B68E7EB08B7DA9877BA384789D8076997C7194796E
90766C8D72688A7066866E65836C64806B647C6A64796966766A68746B6A716C6C6E6D6E
6B6E706B70746B74786C787D6F7C8271818874868E778B947B919A7D959F7E99A3809EA9
8CA9B4A1B8C1B4C7CEC7D6DBDBE5E8EEF3F5F8FDFEF1F7F8DEE5E6CDD4D5BEC5C6B0B6B8
A2A9AA959B9D888E8F7C8182
65686A5B5D5E5151524746453C3A39312E2C26211F1B14120F07051F15112F221C423029
5740376F53478866589F7767AE8573B78E7DB28D7EAB8A7DA5867A9F83789A7F74967B70
92776D8E746A8B7168886F66846D65816C657E6B657B6B67786C69766D6B736E6E716F70
6F71736D73766E767A6E7A7E6F7D8371818873868D758A92788F9879939D7A97A2809EA9
8FABB5A3B9C2B6C8CFC9D6DBDDE5E8EFF3F3FAFCFCF4F8F8E0E5E5CFD4D5BFC5C6B1B6B8
A3A8AA969B9C898E8F7C8182
65686A5B5D5D5051514645453B3938302C2B24201E1913110D06041C13102D201B3E2D26
523C33684E43826154987263A8806FB38B7AB28E7FAC8B7EA6877BA184799C8176977D73
93796F8F756B8C7269897068856E66826D667F6C667D6C687B6E6B786F6E757070737172
71737570757870787B707B7F707E8471828872858D748A92768D9777929C7A97A283A0AB
93ADB7A5BBC3B9CAD0CCD8DCDFE6E8F1F3F3FCFDFCF1F3F3DFE3E3CFD3D4C0C4C5B1B6B7
A3A8A9969B9C898E8F7C8182
6568695A5C5D5051514544453A38382E2C2B221F1E1612100A05031A110E2A1E193A2A24
4B383061493F7A5B4E906C5DA37C6BAE8676B08C7DAC8B7EA7887CA185799D8277987E74
947A7190776D8D736A8A7169866F67846F68816E687E6F6A7D706D7B716F787372767474
74767772777A727A7D727D8171808572828972858D738992748D9676919C7B98A288A3AD
97B0B8ABBEC5BDCBD1D0DADDE3E8E9F4F4F4FFFFFEEEEFEFDEE0E0CED1D1BFC3C3B1B5B5
A3A7A8969A9B898D8F7C8182
6568695A5C5D4F50514444453938382D2B2B211E1D14100F070302170F0D261C18362822
46342D5B443B71554A8766589B7666A88171AE897AAC8B7DA7887CA2857A9D8277997F75
957B7291786F8E756C8A736A88716985706A836F6A81716C7F736F7D74717B7574797676
76787975797C747B7E737E8273808672838A72868D738992758D9679939D809BA58EA7B0
9EB3BBB0C1C7C2CED3D4DCDEE8EAEBF7F6F5FEFDFCEBECEBDBDDDCCCCFCEBEC1C1B0B3B4
A2A6A795999A888D8E7C8082
6568695A5C5D4F50514444453838382C2B2B201E1D13100F050101130D0A221916312520
41312A533F366950457D5F53916F619F7A6BAA8576AB8A7BA7877BA284799D8277997F75
957C729279708E766E8B746B89726A87726B85726C83736F8275728077747E78767C7978
797A7B787C7E767D8074808374818673848A72878E738A92768E977C969F869FA895ABB3
A5B7BEB5C4C9C7D1D4D9DFE0EDEDEDFBF9F7F6F5F4E7E7E6D8D9D9CACBCBBCBEBEAEB1B2
A1A5A5949899888C8D7C8081
65686A5A5D5E4F51524445453838392C2B2C201E1E1210100401010E09071D15132C211C
3A2C264C3A32604A4074594E856759957364A37F70A88678A58679A184789D8176997F74
957C729279708F776F8D756D8A736B88736C87746E867671857875847A77827B797F7B7A
7D7D7D7B7E8078808277818575838874858B73878E748A927890998299A28DA3AB9DAFB6
ADBBC1BBC7CBCDD4D6DFE2E3F2F0EFFFFDFBF0EFEEE2E2E1D4D5D4C7C8C8B9BBBBACAFAF
A0A3A3939798878B8C7B8081
65686A5A5D5E4F515244454638393A2C2C2D201F1F1311110402020A060617110F261C19
34282244342E57433B6A52487A5E53896A5D987668A18072A28376A082769C8175987E74
957C72927A7190786F8E776E8B746D89746D8A7771897974897B77877D79867E7B837E7D
807F7F7E81827B828479848777848976868C768990778C947D949C889DA594A7AEA3B3B9
B3BFC3C2CBCED3D7D9E6E5E5F3F1EFFDFAF8ECEBE9DEDDDCD0D1D0C3C4C4B6B8B8AAACAD
9EA1A1929596868A8B7B7F80
65696A5A5D5F505253454647393A3B2D2E2E212121141313050404050302110D0B1F1815
2E231F3B2E294D3C35604B426E564C7C6156896C5F9677699B7B6F9C7E729A7F73967C72
947C72927A719079708E786F8B766E8A766F8D79738E7C768D7E798B807C89807D868280
8382818183847E84867C858879878B78888D7A8C927C909783989F8EA1A89BABB1AAB7BB
B9C2C5C8CED0D9DBDBEBE8E6F7F2F0F4F1EFE6E4E3D9D8D7CCCCCBBFC0C0B3B5B5A7AAAA
9C9F9F91949585898A7A7F80
65696A5B5E5F5053544648493A3C3D2F30312323241616170909090000000B0808191412
271F1C34292544363057453D634F47715A507A6157866B608E726693766A93796E91796F
917970917970907A718E78708B766F8B77708E7A73917E7891817C8F837E8D837F8A8482
8784838586868287887F888A7D898C7C8A8F7E8F9482959A8B9CA295A5ABA2AFB4B0BABE
BFC5C7CED1D2DEDDDCECE9E6F9F4F2ECE9E7DFDEDCD3D2D1C7C7C6BBBCBCB0B1B1A5A7A7
9A9C9D8F92938488897A7E7F
65696B5B5F6051545547494A3C3E3F3132332626271A1A1B0D0D0E000001040303130F0E
201A172D24213B302B4D3E375A49416551496E595077615780685E856C62876F66877269
89736B8C756D8D776F8B777089766F8B78708D7A73907E7792817C92847F9085818C8583
8A868588878786898A838A8C828B8E818E9285939789989D92A0A59CA9ADA8B3B6B6BEC0
C4C9CAD3D4D3E0DEDDEEE9E6F2EEEBE4E1DFD8D7D5CDCCCBC1C2C1B7B8B7ACAEAEA2A4A4
979A9B8D9091838788797D7F
666A6B5C6061525557484B4C3E4041343536292A2B1D1E1F1112130405070000000C0B0A
19161426201D332A2743373250423C5A4A4363514A6C5951745F5778645C7A67607D6A63
806D6584706985726B87756E86756E8876708B79728E7D7790807B92847E9086818E8683
8D88858B88888A8B8B888C8D878E908791948B979A919CA09AA4A8A3ADB0AFB6B8BCC1C2
CACCCCD7D6D4E1DFDDECE7E5E6E3E0DBD9D7D0CFCEC6C6C5BCBCBCB2B3B3A8AAAA9EA1A1
9598988B8F8F828687797D7E
666A6C5D61625457584A4D4E40434436393A2C2E2F2123241617190A0B0D000102050606
131111201C1A2C26243A312E453A3650433E57494461514B6857506C5C556F605A73645E
7667617B6B657B6C6680716A81726C83746E857771897B758C7E798E827D8E84808C8582
8C87858B89888B8B8B898D8E8A90928C949691999C979FA2A0A8AAA9B0B2B5BABBC2C4C4
D0CFCED8D6D5E2E0DDE3DFDDDAD8D6D2D0CFC9C8C7BFBFBEB6B7B6ADAEAEA4A6A69B9D9E
929596898D8E818486787C7E
676B6C5E626355595A4C4F514346473A3C3E3032342628291B1D1F101214050608010304
0D0E0E1A1817252220322C2A3D3431463D394C423E5649455E504B615550665A556A5E5A
6E615D746661746863796C677B6E6A7E726C817570847873887C788A7F7B8B827E8A8481
8A86848B89878C8B8B8A8D8E8D9192909697969C9E9CA2A4A5AAACAFB3B4BBBDBDC7C7C6
D2D0CFDBD9D7DDDAD8D7D5D3D0CECDC9C8C6C1C0BFB9B9B8B0B1B1A8A9A9A0A2A2989A9B
909293888B8C7F8384777C7D
676C6D5F6365575B5C4F525346494A3D40413437382B2D2F21232517191A0C0D0F020405
090B0C1414141F1D1D2A272535302E3E3734433C394B423F534946574E4B5E5552625856
665D5A6B615D6E6461726864756B68796F6B7C736E7F7672847A76867D7987807D87827F
8885838987868A8A898A8D8D8E91929498989A9E9FA1A4A5AAACADB4B5B5BFBFBECBC9C8
D6D3D2D8D6D4D2D0CFCDCBCAC7C6C5C0C0BFB9B9B8B2B2B2ABACABA3A5A59C9E9E949797
8D909185898A7E8283777B7C
686C6E606466595D5E515556494C4E414446393C3D303334272A2B1E2022141618090C0D
06090A0E101119191A2323222D2B2A3632313B3635413C3B4843414D4847564F4D5A5452
5F5856635C5A68615F6B64626F6865736C6978706D7B74707F7875827B78857F7C83807E
868481878684878887898B8B8E91919597989C9E9FA3A5A6ADAEADB7B6B5C0BFBECBC9C7
D4D3D2CECDCBC9C8C6C3C3C2BEBDBDB8B8B7B2B2B2ABACACA5A6A69EA0A0979A9A919394
8A8D8E8387887D8182767A7C
696D6E6266675B5F605457594D505245484A3E414236393B2E313225282A1D2022141719
0B0F11090D0F1215171D1E1F282728302E2E3533333A3837413E3E4543434C4A49534F4E
5854535C5857615D5C6561606965636E6967736E6B77716F7B76737F7A77827E7B82807E
83817F838281848685888A8A8D90909496969D9E9EA6A6A6ADADADB8B6B5C2C0BECAC8C6
C9C9C7C4C3C2BFBFBEBABAB9B5B5B5B0B1B0AAABABA5A6A69FA1A1999B9C9396968D9091
878B8B8185867B7F80757A7B
696E6F6367695D6162575A5C5054554A4D4F4346483C3F4135383A2D313226292B1F2224
171B1D1013150E1214171B1C2224252B2C2D3232333536363A3A3B3E3F414545464C4C4C
5150515756555B5A5A5F5D5D6462616966656E6B69736F6D7773717C7876807D7B827F7E
83817F8081808183838789898C8E8E9395959D9E9DA7A6A5AEADADB6B4B3C0BEBDC1C1C0
BDBDBCBABAB9B5B6B5B1B2B1ADAEADA8A9A9A3A5A59FA0A0999C9C9497978F92928A8D8E
8588897F83847A7E7F75797A
6A6E7065696A5F6365595D5F5458594E5253484C4D4245473C3F4136393B2F3334292C2E
2226281C202215191B15191B1D2224262A2C30313334363737393B3A3D3F41434547494A
4C4D4E5152535557585A5A5B5F5F5F6564646A68676F6D6C72716F7875747D7B79807E7C
81807E7F80808384838889898C8E8E9395949D9D9CA5A5A4AEADACB4B3B2B8B8B7B5B6B5
B3B3B3AFB0B0ACADADA8AAA9A5A6A6A1A2A29D9E9F989A9B9496979092938B8E8F878A8B
8285867D8182797D7E74787A
6B6F71666A6C6165675C6062585B5D5356584D5153484C4E4347483E4143383C3E333739
2D3133282C2E2226291C20221C212424292B2E3234343739383B3D3A3E403F434546494B
4A4D4E4E51525154565558595B5D5E6161626566666B6B6A6E6E6D7473717676757E7C7A
7D7C7C7C7E7D8082828487878A8C8C929393999A9AA4A3A2ABAAAAACACADACADACAAABAB
A8A9A9A6A7A7A3A4A4A0A2A29D9F9F999B9C9698989295958F91928B8E8E878A8B838687
7F83847B7F80777B7D737879
6B7072686C6E6468695F64655B5F61575B5D5357594F53544A4E50464A4C4145473D4143
383C3E34383A2F33362B2F31252A2D262B2E2B303334383B3A3E413E424541454746494B
4A4D4F4C505250555654575A585B5C5C5E606164656769686B6D6D70706F7273737A7978
7A7A7A7C7D7D7F8181838686898B8B909191949696A1A1A1A3A4A4A2A3A3A1A2A2A0A1A1
9EA0A09C9E9E9A9C9C979A9A9597989295958F92928C8F90898C8D86898A838687808384
7D8081797D7F767A7C737779
6C7172696E6F666A6C6367695F64655C6062595D5E55595B5256574E52544B4F50474B4D
4348494044463C4143393D40353A3D33383B31373933393C3C414441474A484B4D4A4E4F
4C51524E525451565855595B585C5D5A5E605F6365646767696C6C6D6F6E717272757675
7878787A7B7B7D7F7F8184848688888D8F8E919393989A9A979999979999979999969898
9497979395969194948F92928D90918B8E8F898C8D868A8A8487888285867F83847C8081
7A7E7F777B7D75797A727678
6D72736B6F71686D6E666A6C6368696165675E62645C6062595D5F565B5C54585A515557
4E53554C5052494E50474B4D44494C42474A4146493E434742484A454B4E4A4E51505455
52565852575854595B575B5D595E605C6062606465626667676A6A6A6D6D6E7171727373
757676787A7A7B7D7D8183838184848588888A8D8E8C8F8F8D8F908D8F908C8F908C8F8F
8B8E8E8A8D8D898C8C878A8B86898A8487888286878184857F82847D81827B7F80797D7E
777B7D75797B737879717677
6E72746C71736B6F71696D6F676C6D666A6C64686A6267686165665F63655D61635B6061
595E60585C5E565A5C54595B53585A52565951555850555851565952575A51575A575B5D
595D60595D5F5A5E60595E605B606260646663666765696A686B6C696D6E6D7070707273
727576787A7B76797A7B7E7F7D80817E8282818485828586838687838687838687828686
8285868184858084857F83847E82837D81827C80817B7F807A7E7F787C7E777B7D767A7B
75797A737879727678717577
6F73756E72746D72736C71726B70716B6F716A6E70696D6F686C6E676B6D666B6C656A6B
64696B64686A636769626668616668616567606567606567606567616568616668636769
64686A63686A64696A63676A62676965696B666A6B686C6D696D6E6A6E6F6B6F706D7071
6F737475787974787975797A767A7B777B7C787C7D797C7E797D7E797D7E797D7E797D7E
787C7E787C7D787C7D777B7D777B7C767A7C767A7B75797B75797A74787A737879737778
727678717677717577707576
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?ooo`a_M7D8Kg=e4fmcM1=_LW<8Kg9b1fmaLPQ_LG44Kg1`16m_
K`A_KF`4L71`0g1aLPA`LW<4Kg5b26mbL`A_LG<3Kg5b36iaLPQ^LG<4KW=d0ficM@A_MGH4L7Ih271g
N@AaN7X3LGYl179kOPAcO7l4M7j217J2QPAdOX44Lgan0g=jO@AbNG`8LWQk175hNPMaMgT4LGIh171f
N0Q`MGL4L7Ef171dMQGoool001Coool<KgAe26mcMA=_Lg@CKg9c26mbLPM_LG88Kg5a16m`L0A_Kfl4
Kfe/171`L0=`LG84L79c16maLPQ_LW<4Kg5c0fmaLPa^LG88KW5c16icM0=^LgD4KgEf171fN0Q`MgT4
LGQj0g5jO0AbNgh4Lgao17AnPPAfPXH4M7j117=lOP=cNWd4LWUl279hN`AaN7X7LGMi175fN0A`MWP8
L7Eg171eMPA`M7HEoooo000Doooo36mdM@Q_LgDCKg=d4fmbL`Q_LW87Kg5b26maL@A_L704Kfm_16m]
K0A`L703L75b171bL`A_LG88Kg9c16maL`=_LG8<KW5b26iaL`A^Lg@3KW=e16meMPA`MWP8L7Mi175h
NP=aNW`4LW]n17=lO`AdOX84MX:617AnP@AcO7h3LgYm179iO0QbN7/4LGQj1g5gN@AaMWP4L7Ih271e
M`A`MGH4L7Af5Oooo`005?ooo`A_M7D8Kg=e16mcM0M_LW@8Kg9c36maLP=_LG44Kg1a26m`L0a_Kfl3
Kfi^16m^K@A_KFd4L6e[171[J@A_JFL4L6a[0g1^KPA`Kfl4Kfm_16m`L0A^Kg04KVm_0fe_L0A^Kg04
KFm`16a_L0A]L744KG1b16ebM0=]LgD4KgIh171gNPAaNG`4LW]m179mP0=cOh84MH:617N5R@AhR8h4
NhZ@17R5RPAfPXH3MH2417EoPPAdOH04M7ao17=kOPAcNWd3LWYl179iN`AaN7X4LGMi175fN0A`MGL4
L7Ef5Oooo`005?ooo`A_M7D8Kg=e16mcM0M_LW@8Kg9c36maLP=_LG44Kg1a26m`L0a_Kfl3Kfi^16m^
K@A_KFd4L6e[171[J@A_JFL4L6a[0g1^KPA`Kfl4Kfm_16m`L0A^Kg04KVm_0fe_L0A^Kg04KFm`16a_
L0A]L744KG1b16ebM0=]LgD4KgIh171gNPAaNG`4LW]m179mP0=cOh84MH:617N5R@AhR8h4NhZ@17R5
RPAfPXH3MH2417EoPPAdOH04M7ao17=kOPAcNWd3LWYl179iN`AaN7X4LGMi175fN0A`MGL4L7Ef5Ooo
o`005?ooo`A_M7D8Kg=e16mcM0M_LW@8Kg9c36maLP=_LG44Kg1a26m`L0a_Kfl3Kfi^16m^K@A_KFd4
L6e[171[J@A_JFL4L6a[0g1^KPA`Kfl4Kfm_16m`L0A^Kg04KVm_0fe_L0A^Kg04KFm`16a_L0A]L744
KG1b16ebM0=]LgD4KgIh171gNPAaNG`4LW]m179mP0=cOh84MH:617N5R@AhR8h4NhZ@17R5RPAfPXH3
MH2417EoPPAdOH04M7ao17=kOPAcNWd3LWYl179iN`AaN7X4LGMi175fN0A`MGL4L7Ef5Oooo`005?oo
o`A_M7D8Kg=e16mcM0M_LW@8Kg9c36maLP=_LG44Kg1a26m`L0a_Kfl3Kfi^16m^K@A_KFd4L6e[171[
J@A_JFL4L6a[0g1^KPA`Kfl4Kfm_16m`L0A^Kg04KVm_0fe_L0A^Kg04KFm`16a_L0A]L744KG1b16eb
M0=]LgD4KgIh171gNPAaNG`4LW]m179mP0=cOh84MH:617N5R@AhR8h4NhZ@17R5RPAfPXH3MH2417Eo
PPAdOH04M7ao17=kOPAcNWd3LWYl179iN`AaN7X4LGMi175fN0A`MGL4L7Ef5Oooo`005?ooo`A_LgD8
Kg=d16mbM0A_LW<3Kg9b16maLPQ_L744Kg1`16m_L0=_Kfl8Kfi^16m]K@Q_KF`4Kfa[0fm/JPA_JfX4
L6YX171ZI`A`J6D4L6IR175ZI`=`JfX4L6e/26m]K@A^KFd4KFe/0fa/K@A]K6d4K6a]16]]KPA[Kg04
K71a16abL`=]LgD4KWIi171iO0AaO7l4Lgj217B1Q@=fQHT4N8R=17Z<TPAmTIP4OI2F17^<T@AiR8h3
N8J:17N4R0AfPXH4MX2417EoPPAdOX43M7ao17=kOPAbNW`4LWUk175gNPAaMWP4L7Eg5Oooo`005?oo
o`A_LgD8Kg=d16mbM0A_LW<3Kg9b16maLPQ_L744Kg1`16m_L0=_Kfl8Kfi^16m]K@Q_KF`4Kfa[0fm/
JPA_JfX4L6YX171ZI`A`J6D4L6IR175ZI`=`JfX4L6e/26m]K@A^KFd4KFe/0fa/K@A]K6d4K6a]16]]
KPA[Kg04K71a16abL`=]LgD4KWIi171iO0AaO7l4Lgj217B1Q@=fQHT4N8R=17Z<TPAmTIP4OI2F17^<
T@AiR8h3N8J:17N4R0AfPXH4MX2417EoPPAdOX43M7ao17=kOPAbNW`4LWUk175gNPAaMWP4L7Eg5Ooo
o`005?ooo`A_LgD8Kg=d16mbM0A_LW<3Kg9b16maLPQ_L744Kg1`16m_L0=_Kfl8Kfi^16m]K@Q_KF`4
Kfa[0fm/JPA_JfX4L6YX171ZI`A`J6D4L6IR175ZI`=`JfX4L6e/26m]K@A^KFd4KFe/0fa/K@A]K6d4
K6a]16]]KPA[Kg04K71a16abL`=]LgD4KWIi171iO0AaO7l4Lgj217B1Q@=fQHT4N8R=17Z<TPAmTIP4
OI2F17^<T@AiR8h3N8J:17N4R0AfPXH4MX2417EoPPAdOX43M7ao17=kOPAbNW`4LWUk175gNPAaMWP4
L7Eg5Oooo`005?ooo`A_LgD8Kg=d16mbM0A_LW<3Kg9b16maLPQ_L744Kg1`16m_L0=_Kfl8Kfi^16m]
K@Q_KF`4Kfa[0fm/JPA_JfX4L6YX171ZI`A`J6D4L6IR175ZI`=`JfX4L6e/26m]K@A^KFd4KFe/0fa/
K@A]K6d4K6a]16]]KPA[Kg04K71a16abL`=]LgD4KWIi171iO0AaO7l4Lgj217B1Q@=fQHT4N8R=17Z<
TPAmTIP4OI2F17^<T@AiR8h3N8J:17N4R0AfPXH4MX2417EoPPAdOX43M7ao17=kOPAbNW`4LWUk175g
NPAaMWP4L7Eg5Oooo`005?ooo`A_LgD4Kg9d26mbL`A_LG83Kg5a16m`L0A_Kfl4KVm_16i^KPA^KVd3
KVe]16i/K0A^K6/4KV]Z16i[J@A^JVT4KfYX0fmYI`A_J6H4L6QU171WH`A`IV44L6AO175WI0=aJFL4
L6]Y171[J`A_K6/4KVa[16e[J`=[JVX4K6YZ16]ZJ`AZJf/4Jfe^16]_L@A/LW<3K7Af16egNPA_Ngh4
LWn217B2QPAfQXX3N8Z?17Z>U0AmTiX4PIVR17nEW0AmTIP4O8jD0g^;T0AiR8d4N8J;17R4R0AgPhH4
MX640gEoPPAdOH04Lgao17=jO@AbNG/4LGMi171eMaGoool001Coool4Kg=e16mbM0Q_LW<4Kg5b0fma
L@A_L704Kfm_16i_K`A^KVh4KVi]0fi]K@A^K6`4KVa[16i[JPA^JfT4KVYY16mZJ0=_JFL4KfQV171X
I@A`If<4L6IQ171TG`AaIf@3LFUW171[J@A`Jf/4Kfa[16i/J`A]Jf/3JfYZ16aZJPA[JV/4JV][16]]
KPA[Kg44K79c0fadMPA]MgX4Kg]n179oPPAdPXH4MXJ:0gR:S`AjSY@4OI>J186IXPAoUI`4OI6H17b>
U0=kRi04NHR=17R6R`AhQ8P4Mh>617J1Q0=eOh84M7f017=lO`AcNWd4LWUk175gN@A`MGLEoooo000D
oooo16mcM@A_LW@8Kg9c16maLP=_LG44Kg1`16m_K`A^Kfl4KVi^16i^K@=^KFd4KVa/16i/J`A^JfX4
KV]Y16iZJ@A_JVP3KfUW16mXIPA`J6D4L6MS171VH@A`I5l4LFMT0g5YI`A`JfT4L6][16m/J`A^K6/4
KF][0f]ZJPA/JVX4JfY[16Y[J`A[KFh4Jfma16abL`=/M7H4KGMj16mkOPAbOh84M8:617J6RP=hRXl4
NXjD17fCVPB1VJ84OiFL17fAV0AlSY@3Nh^@17V8S@AhQX/4N8B817N3QPAfPH@3MGn217AmP0AcO7l4
LgYm179iN`AaMgT4L7Eg5Oooo`005?ooo`A_LgD4Kg9d26mbL`A_LG83Kg5a16m`L0A_Kfl4KVm_16i^
KPA^KVd3KVe]16i/K0A^K6/4KV]Z16i[J@A^JVT4KfYX0fmYI`A_J6H4L6QU171WH`A`IV44L6AO175W
I0=aJFL4L6]Y171[J`A_K6/4KVa[16e[J`=[JVX4K6YZ16]ZJ`AZJf/4Jfe^16]_L@A/LW<3K7Af16eg
NPA_Ngh4LWn217B2QPAfQXX3N8Z?17Z>U0AmTiX4PIVR17nEW0AmTIP4O8jD0g^;T0AiR8d4N8J;17R4
R0AgPhH4MX640gEoPPAdOH04Lgao17=jO@AbNG/4LGMi171eMaGoool001Coool4Kg=d16mbL`Q_LG84
Kg1a0fm`L0A^Kfl4KVi^16i]K@A^KF`4KVa[0fi[JPA^JfT4KVYX16iYI`A^J6H4KVQU16iWI0=_IV<4
KfIR171UH@A`IF04LFAO175RG0AbIF83LFMU175YI`A`JVT4KfYY16iZJ@A]JVX3K6UY26]YJ@AZJVX4
Jfa]16]_L0A[LG<3K7Ag16ehNPA_OH04LX6517B5R@AgRXl3NXnE17fDV`B0VZ84PinX186JXPB0UYd4
OY>I0gf@UPAlSI84NXZ?17V8S@AhQXX4MhB80gJ2Q@AeP8<4M7j117=lOPAbNW`4LGQj171fN1Goool0
01Coool4Kg=d16mbL`Q_LG84Kg1a0fm`L0A^Kfl4KVi^16i]K@A^KF`4KVa[0fi[JPA^JfT4KVYX16iY
I`A^J6H4KVQU16iWI0=_IV<4KfIR171UH@A`IF04LFAO175RG0AbIF83LFMU175YI`A`JVT4KfYY16iZ
J@A]JVX3K6UY26]YJ@AZJVX4Jfa]16]_L0A[LG<3K7Ag16ehNPA_OH04LX6517B5R@AgRXl3NXnE17fD
V`B0VZ84PinX186JXPB0UYd4OY>I0gf@UPAlSI84NXZ?17V8S@AhQXX4MhB80gJ2Q@AeP8<4M7j117=l
OPAbNW`4LGQj171fN1Goool001Coool4Kg=d16mbL`Q_LG84Kg1a0fm`L0A^Kfl4KVi^16i]K@A^KF`4
KVa[0fi[JPA^JfT4KVYX16iYI`A^J6H4KVQU16iWI0=_IV<4KfIR171UH@A`IF04LFAO175RG0AbIF83
LFMU175YI`A`JVT4KfYY16iZJ@A]JVX3K6UY26]YJ@AZJVX4Jfa]16]_L0A[LG<3K7Ag16ehNPA_OH04
LX6517B5R@AgRXl3NXnE17fDV`B0VZ84PinX186JXPB0UYd4OY>I0gf@UPAlSI84NXZ?17V8S@AhQXX4
MhB80gJ2Q@AeP8<4M7j117=lOPAbNW`4LGQj171fN1Goool001Coool4Kg=d16mbL`Q_LG84Kg1a0fm`
L0A^Kfl4KVi^16i]K@A^KF`4KVa[0fi[JPA^JfT4KVYX16iYI`A^J6H4KVQU16iWI0=_IV<4KfIR171U
H@A`IF04LFAO175RG0AbIF83LFMU175YI`A`JVT4KfYY16iZJ@A]JVX3K6UY26]YJ@AZJVX4Jfa]16]_
L0A[LG<3K7Ag16ehNPA_OH04LX6517B5R@AgRXl3NXnE17fDV`B0VZ84PinX186JXPB0UYd4OY>I0gf@
UPAlSI84NXZ?17V8S@AhQXX4MhB80gJ2Q@AeP8<4M7j117=lOPAbNW`4LGQj171fN1Goool001Coool4
Kg=d16mbL`A_LG84Kg1a16m`L0=^Kfl4KVi^16i]K@A^K6/4KV]Z16iZJ@=^JFP4KVUW16iXIPA^IfD4
KVIS16iUHPA^I643KVAP16mSG`A`Heh4LF9M179RG@AcHU/4LfEP0g9VH`AaJ6D4L6QW171YJ0A_JFP4
KVUY0feYJ@A/JFT4JfUY16]ZJPA[Jf`4Jfi`16]aM0=/MGP4KGQl171nP@AcQ8P4MHV=17V=T`=lTiX4
OiVQ18>PZ@B5XZ`4PijW18:KX`B0Uil3OiBK17jAU`AlSY@4NhbA17Z9SPAiQh/3N8B817N2QPAeOh<4
M7f017=kOPAbNG/4LGIh5Oooo`005?ooo`A_Lg@4Kg9c16maLPA_L744Kg1`0fi_K`A^KVh4KVe]16i/
J`A^JfX4KVYY0fiYJ0A^JFL4KVQV16iWI@A^IV<4KVER16iTH@=^I604Kf=O171SGPAaHUd4LV9M17=R
F`AcIF03LVIS175XI@A`J6L4L6UX16mYJ0A^JFT3KFUY16aYJ@A[JFT4JfYZ16][K0A[KW04Jg5d0fae
N0A]N7`4L7j117>4R0AeRHd4NHfC0gbCVPAoVJ44Pj2Y18FR[0B3WZL4PY^S182GW`=oU9/4OY6G17b>
U0AkS944NXV>17V7R`=hQ8P4Mh:617EoP`AdOH04Lg]n179iN`AaMWPEoooo000Doooo16mcM0A_LW<4
Kg5b16m`L@A_L703KVm_16i^KPA^KFd4KVa[16i[JPA^JVT3KVUX16iYI`A^J6H4KVMU16iVH`A^IF84
KVAQ0fiTH0A_Hel4L6=N175RG@AbHUd4Lf9K17=UH0=bIV<4LFQU171XI`A`JFP4KfUX16iYJ@=]JFT4
K6UY16]YJ@A[JVX4Jf]/16]^L0A[LG@3K7Eh16ehO0A`OX44LhB817F9S@AiSI<3O9>J17nIX@B3X:T4
QJ:/18>NY`B2Vj<4P9NO0gnDV`AnTIL4O8jD17^<T@AjRHh4NHN;0gR4R0AgPXH4MGn317AmP0AcNgh4
LWUk175fN1Goool001Coool4Kg=d16mbL`A_LG84Kg1`16i_K`=^KVh4KVe/16i/J`A^JfX4KVYX16eY
I`=]J6H4KFMT16eVH`A]IF84KFAP16eSG`A]HUh3KV5M16iPF`A_H5X4LF1J17=QFPAeI5d4M6EP0g=V
HPAbIf@4LFMV171XI`A_J6L4KVQX0feXJ0A]JFT4K6UY16aZJPA[K6d4K6ma16acM@=]MgT4KW]n1720
Q0AcQXX4MhbA17ZAU`=nV9l4PYnW28JV/0B5XZ`4Q9nX18:LY0>1V:04P9FL17jBV0AmSiD4O8bA17^:
S`=iQh/4N8B817J1Q@AeOh84M7ao179iO0AaMgTEoooo000Doooo16mcM0A_LW<4Kg5b16m`L0A^Kfl3
KVi^16i]K0A^K6/4KV]Z16iZJ0A]JFL3KFQV16eWI0A]IV<4KFER16eTH0A]Hel4KF9N0fiQG@A^H5/4
Kf1J175PFPAcHEX4MFAM17AUH0=cIV84LVMT175WIPA`J6L4KfQW16iXJ0=]J6P4KFUY16aYJ@A/JVX4
Jfa]16a_L@A/LgD3KGMi16ikOPA`P8@4LhJ:17N<T@AjTIL3OYRO18:OY`R6Y[04QJ:/18BOZ0B2W:@3
PIRP182EW0AnTYP4OHnE17b<T@AkRXl3NHN;17R4R0AfPHD4MGn217AlO`AbNG`4LGMi5Oooo`005?oo
o`A_Lg@4Kg9c16maLPA_L704KVm_0fi^KPA^KF`4KVa[16i[JPA^JVP4KFUW0feXIPA]If@4KFIS16eU
HPA]I604KF=O16eRGP=^HEd4KV1K16mPFPAaH5X4Lf5J17ETG@AdIF03LfIR179WI0AaIfH4L6QW16mX
I`A^J6P3KFQX16eYJ@A/JFT4K6YZ16]/K@A/Kg44K7=e0fegN@A^Ngh4L82417>6RPAgS944NY6G0gjH
W`B2WjL8QZJ`18FR[0B4WjP4PYbT0h6HX0B0UI`4OY:H17f?U@AlS944NhZ?0gV7R`AhQ8P4MX6517Eo
PPAdO7l4LWUl175gNAGoool001Coool4Kg=d16mbL`A_LG84Kg1`16i_K`=^KVh4KVe/16i/J`A^JfX4
KVYX16eYI`=]J6H4KFMT16eVH`A]IF84KFAP16eSG`A]HUh3KV5M16iPF`A_H5X4LF1J17=QFPAeI5d4
M6EP0g=VHPAbIf@4LFMV171XI`A_J6L4KVQX0feXJ0A]JFT4K6UY16aZJPA[K6d4K6ma16acM@=]MgT4
KW]n1720Q0AcQXX4MhbA17ZAU`=nV9l4PYnW28JV/0B5XZ`4Q9nX18:LY0>1V:04P9FL17jBV0AmSiD4
O8bA17^:S`=iQh/4N8B817J1Q@AeOh84M7ao179iO0AaMgTEoooo000Doooo16mcM0A_LW84Kg1a16i_
L0A^KVh3KVe]16i/J`A^JfX4KFUX16eXI`A]IfD3KFIT16eUHPA]I644KF9O16eQG@A]H5`4KEmK0feN
F@A]GEP4KUaF16mLE@AhHe`4N6EN17EUH0=dIF44LVIS175VI@A`IfH4KfMV16mXI`=^J6P4KFQX16aY
J@A/Jf/4K6e^16a`L@A]M7H3KWUk16mmP0AbPXH4MHR=17R>U0AlUI`3P9bT18BS[0B8ZkH4R:Vd18NV
/0B6Xj`4Q:2Y0h>MY@B2VJ44P9JM17nCV@AnSiD4O8bB0g^9SPAiQXX4Mh>717J0P`AdOH04LgYm175g
NAGoool001Coool4Kg=d16mbLPA_L744KVm`16i^KP=^KFd4KVa[16i[JPA]JFP4KFQW16eWI@=]IV@4
KFER16eTH@A]HUl4KF5M16ePG0A]Ge/3KEiI16eMF0A^G5H4KeaE17QSG0AhIEh4MFEP0gAUH@AbIV<4
LFIU171WIPA_IfH4KfQW0fiXJ0A]J6P4K6UY16a[J`A/KFh4K71a16edMP=^NG/4Kgf017:2QPAeR8d4
N8jD17bEW0>0W:@4Q:>/18R[]PB8ZK@4QjJ`18JS[0B4X:T3PifU18:IX@B0UYd4Oi>I17j?U@AlS983
NhV>17V6RPAgPhL4MX2317AmP0AcNWd4LGMi5Oooo`005?ooo`A_Lg@4Kg9b16m`L@A^Kg04KVi^0fi]
K@A^K6/4KV]Z16eYJ0A]J6L4KFMU0feVI0A]IF84KFAQ16eRG`A]HEd4KF1L16eOF`=]GUT4KEeH16iL
EPA_G5D4N6=L17QUGPAeIF03M6EQ179VH`AaIVD4L6MV16mWIPA_J6L3KVQX16eXJ0A/JFT4K6][16a]
KPA/L744KGAf0fiiN`A_OH04LX:617F8S@AhSY@4O9FL0h2LY0B4Xj`4R:^f18RY]0B7Y[04QZ>/18BP
Z@>3WJD4PYVQ182FW@AoTiT4OXnE17b<TP=kRHh4NHJ:17N3Q`AfP8<4M7f017=jO@AaMgTEoooo000D
oooo16mcM0A_LW84Kg1a16i_L0A^KVh3KVe]16i/J`A^JfX4KFUX16eXI`A]IfD3KFIT16eUHPA]I644
KF9O16eQG@A]H5`4KEmK0feNF@A]GEP4KUaF16mLE@AhHe`4N6EN17EUH0=dIF44LVIS175VI@A`IfH4
KfMV16mXI`=^J6P4KFQX16aYJ@A/Jf/4K6e^16a`L@A]M7H3KWUk16mmP0AbPXH4MHR=17R>U0AlUI`3
P9bT18BS[0B8ZkH4R:Vd18NV/0B6Xj`4Q:2Y0h>MY@B2VJ44P9JM17nCV@AnSiD4O8bB0g^9SPAiQXX4
Mh>717J0P`AdOH04LgYm175gNAGoool001Coool4Kg=d16maLPA_L704KVm_16i^K@=^K6`4KV]Z16eY
J0A]J6H4KFMU16eUH`=/I644K6=P16aRGPA/H5`4K5mK16aNF@A/G5L3K5]E16aJE0A/F584KEQA17iW
G`AiIEh4MVAP0gATH0AcIF84LVES175VI@A`IfD4KfMV0fiWI`A]IfL4KFUY16a/J`A]Kfl4KG9d16ig
N0=_Ngd4LGn217B5R@AfRi04NY6G17jHW`>2X:P4QZNa18^_^`B:[KP4RJ^e18RW/@B7Y:d3QJ6Y18BM
Y@B2VZ44PIJM17nCV@AnSiD3O8bA17Z8S@AiQHT4Mh:517EnP@AcNgd4LGMi5Oooo`005?ooo`A_Lg@4
Kg5b16m`L0A^Kfl4KVi]0fi/K0A^JfX4KFUX16eXIPA]IfD4KFES0faTH@A/Hf04K69N16aPG0A/Ge/4
K5iI16aLE`=/FeD4K5YD16aHDPA]F544OVMO17UUGPAfI603M6AP17=UHPAbIF<4LFIU171WI@A_IfH3
KVMW16eWI`A]JFT4K6a[16e_K`A]LW@4KWMh0fmkO@AaOh84M8F917J;T0AjTIL4OYRO0h:PZ0B6Yk44
Rjnk18Z]^0B9ZkD4R:Na18NT[@>5XJT4Q9fU18:JX@B1UYd4Oi>I17j?U@=lS944NXR=17V5R@AgPXD4
MGj117=kO@AaMgTEoooo000Doooo16mcM0A_LG84Kg1`16i_K`A^KVd3KVa/16i[JPA]JFP4KFQV16eW
I@A]IF<3K6AQ16aSH0A/HUh4K61L16aOF`A/GUT4K5aG0faKE@A/FU@4K5QB16eHD@AnIel4NFEN17IT
H0=dI604LfER179UH`AaIVD4L6MU16mWIP=^IfL4KFMW16eYJ@A/K6/4KFm_16ebM0A^MgP3Kg]m175o
PPAdQHT4MX^@17ZAU`AnV9l3PZ2X18JW/@B;[k/4RZfh18V[]@B8Yk44QjB]0hFQZ@B4WJD4PYZQ186F
W@AoTiT4OXnE0gb<T@AjR8d4NHF917N2Q@AeOX44Lg]m175gNAGoool001Coool4Kg=d16maLPA_L704
KVm_16i^K@=^K6`4KV]Z16eYJ0A]J6H4KFMU16eUH`=/I644K6=P16aRGPA/H5`4K5mK16aNF@A/G5L3
K5]E16aJE0A/F584KEQA17iWG`AiIEh4MVAP0gATH0AcIF84LVES175VI@A`IfD4KfMV0fiWI`A]IfL4
KFUY16a/J`A]Kfl4KG9d16igN0=_Ngd4LGn217B5R@AfRi04NY6G17jHW`>2X:P4QZNa18^_^`B:[KP4
RJ^e18RW/@B7Y:d3QJ6Y18BMY@B2VZ44PIJM17nCV@AnSiD3O8bA17Z8S@AiQHT4Mh:517EnP@AcNgd4
LGMi5Oooo`005?ooo`A_LW@4Kg5b16i_L0A^KVh4KVe]0fi[J`A]JVT4KFQW16eWI@A/IF<4K6AQ0faR
G`A/HEd4K5mK16aNF@A/GEP4Je]F16]JE0=[F584JeM@16YDC@AcG5@4NfAL17QSG@AfHel3M6=O17=T
H@AbIF84LFET171VI@A_IVD3KVIU16eVIPA]J6P4K6a[16e`L0A^MGD4KgUj0g1nO`AbPXD4MXR;17R>
T`AlU9X4Oi^R0h>RZ`B8Z[@8S;:n18^_^PB:[;L4RJRb0hNU[PB6XJX4Q9fU18>JX@B1UYd4Oi:H0gf>
U0AlRXl4NXN;17R3Q`AfOh84M7an175hNQGoool001Coool4Kg9d16maLPA^Kg04KVi^16i]K@=^Jf/4
KFYY16eXI`A]IfD4K6ES16aTH@=/HUl4K65M16aOF`A/GUT4K5eH16]KEPA[FU@3JeQB16]GD0AZE4d4
LeaD17]TG0AhHed4MV=O0gASG`AcI644LVER175UI0A`IVD4KfIU0fiVI@A]IVH4KFQX16a/J`A]L704
KWEe16miNP=`OWl4LX:517J8R`AhSY<4O9BJ17nKXP>3XZ/4R:Zd28bb_PB;[kX4RZbg18VX/P>7YJh4
QZ6Z18BMY@B3VZ44PIJM17nBV0=mSY@4O8Z?17Z7R`AhPhL4MWn217AlOPAaN7XEoooo000Doooo16mb
M0A_LG84KVm`16i^KPA^KFd3KV][16eZJ@A]J6L4KFMU16aUH`A/I643K69O16aQG@A/Ge/4K5iI16aM
F0A[FeH4JeYD0f]HDPA[Ee04JUA=17=LE0AkI5`4N6=M17ISG`=dHel4LfAQ179UHPAaIF@4L6IU16mV
I@=^IVD4KFIV16eXJ0A/K6/4KG1`16ieM@A_NGX3L7io17:2Q@AfR8/4N8jC17bDVPAoVj83Pj:[18RZ
]0R</[h4Rjnj18Z/]`B9Z;83QjF^18JQZPB4WJD4PiZQ186FW@AoTYP3OHjD17b:S`AjQh/4N8>717Io
PPAdO7h4LGQj5Oooo`005?ooo`A_LW@4Kg5b16i_L0A^KVh4KVe]0fi[J`A]JVT4KFQW16eWI@A/IF<4
K6AQ0faRG`A/HEd4K5mK16aNF@A/GEP4Je]F16]JE0=[F584JeM@16YDC@AcG5@4NfAL17QSG@AfHel3
M6=O17=TH@AbIF84LFET171VI@A_IVD3KVIU16eVIPA]J6P4K6a[16e`L0A^MGD4KgUj0g1nO`AbPXD4
MXR;17R>T`AlU9X4Oi^R0h>RZ`B8Z[@8S;:n18^_^PB:[;L4RJRb0hNU[PB6XJX4Q9fU18>JX@B1UYd4
Oi:H0gf>U0AlRXl4NXN;17R3Q`AfOh84M7an175hNQGoool001Coool4Kg9c16m`L@A^Kfl4KVe]16i/
K0=]JVT4KFUW16eWI@A/IF<4K6AQ16aRG`=[HEd4JemK16]MF@A[G5L4JeYE16]ID`A[Ee03JeE>16YC
C0A`F504MeiF17MPF@AgHE/4MF5M0gARGPAcHf04LVAR175UH`A`IF@4KfET0fiUI0A]I6@4KFQX16a/
J`A]LG44KWIf171lO0=aP844M8F717N:SPAkTID4OYNM186MY@>4Y:d4RJ^f18bc_`B?]l@4S[C018ba
_0B;[KP3RZVc18RU[PB7XJX4QIfU18>IX0B1UI/3Oi6F17f=TPAkR8d4N8F917J0Q0AdO7l4LWQj5Ooo
o`005?ooo`A_LW<4Kg1a16i_K`A^KFd4KVa/0feZJ@A]JFL4KFMU16aUH`A/I644K69O0f]QG@A[Ge/4
JeeI16]LE`A[FUD4JeUC16]GD0=[EDh4JU=<171HD0AgGUH4Mf1I17MQF`AeHEd3M69N17=SH0AbI684
LFES171UI0A_IF@3KVET16eTI0A]J6P4K6a[16eaL@A^MWH4L7al0g60P@AdQHL4MhZ>17^AU@AnUid4
PIfU0hBT[@B9ZkH4S;>o18nga0B>]<04S;6l18^]^0>:ZK<4R:F^18NQZPB5WJD4PiVP186EV`=oTIH4
OHfB17^8S@AhQHT4MX2417AlO`AbN7XEoooo000Doooo16mbL`A_L744KVm_16i]K@A^K6`3KFYY16eY
I`A]IfD4K6ES16aTH@A/HUl3Jf5M16]OF`A[GET4JeaG16]JE@A[FE<4JeM@0f]ECPAZDd`4L5Q@17MN
EPAgH5T4Mf5K17EQG@=dHUh4Lf=P179THPAaIF<4L6ET16mUI0=^IF@4KFAT16eXJ0A/K6/4KG5a16if
MPA`O7`3LH2117B5Q`AgRXh4Ni6E17jGW@B1WJD3Q:B]18V[]PB</kl4SkO418jd`0B</K`4Rjfh0hZY
/`B8YJh4Qj6Z18FMY@B3VJ04PIFK0gnAUPAmSI84NhR=17R5R@AfP8@4M7ao179hNQGoool001Coool4
Kg9c16m`L@A^Kfl4KVe]16i/K0=]JVT4KFUW16eWI@A/IF<4K6AQ16aRG`=[HEd4JemK16]MF@A[G5L4
JeYE16]ID`A[Ee03JeE>16YCC0A`F504MeiF17MPF@AgHE/4MF5M0gARGPAcHf04LVAR175UH`A`IF@4
KfET0fiUI0A]I6@4KFQX16a/J`A]LG44KWIf171lO0=aP844M8F717N:SPAkTID4OYNM186MY@>4Y:d4
RJ^f18bc_`B?]l@4S[C018ba_0B;[KP3RZVc18RU[PB7XJX4QIfU18>IX0B1UI/3Oi6F17f=TPAkR8d4
N8F917J0Q0AdO7l4LWQj5Oooo`005?ooo`A_LW<4Kg1a16i^KPA^KFd4KF]Z0feZJ0A]J6H4K6IT16aT
H@A/HUl4Jf5M0f]OFPA[GEP4JU]F16YJE0AZF584JUI?16YEC@=ZDd/4K5=:17ILD`AfGED4MUiG17EO
FPAdH5/3Lf1L17=RG`AbHf84LVAS175TI0A`I6@3KfAT16eSH`A/IVH4K6YZ16e`L0A^M7D4L7al0g:1
PPAeQhT4NHf@17fCU`B1VZ04Q9nW0hJU[PB:[;H4S;>n192iaPB@^/L4SkG218fa_@><[KP4RjVc18VU
[PB7XJT4QIbT18>HWP>1TiT4OXnD17b:S`AiQXX4Mh6517AmP0AbN7/Eoooo000Doooo16mbL`A_L744
KVi^16i]K@A]JfX3KFYX16eXIPA/IV@4K6AQ16aRG`A[HEd3JemJ16]MF0AZFeH4JUYD16YHDPAZETl4
JUE=0fYCB`A/DdX4MUaC17IME@AfGUL4MEmJ17APF`=cH5`4Lf9O179SHPAbI6<4LFAT171TI0=_I6@4
KF=S16aVIPA/JVX4KG1`16idM@A`O7`3LX6217F7R@AiSI04OI>G186JX0B4WjL3QZF^18Z/]PB</kh4
T;W6192ja`B?]L84SK6m0hb]^0B;ZK<4RJF^18NQZ@B5W:@4PiRN0h6CV@AnSi@4O8Z?17V6RPAgPHD4
M7f0179hNaGoool001Coool4Kg9c16m`L@A^KVh4KVe]16e[JP=]JVP4KFQV16aVI0A/I644K69O16]Q
G@=[GeX4JeeH16YKEPAZFU@4JUQB16YFC`AZEDd3JU=;16aCBPAfG5<4MUeE17INE`AeGeX4M61K0g=P
G0AcHUl4LV=R179TH`AaI6@4L6AT0fmTI0A]Hf<4K6IV16aZJPA]L704KWAe171lO0=bPH84MHN917V=
T0AmTiL4PIZP18BOY`>6YJh4RZbf18bc_PB@^LH4T;[718ne`PB=/Kd3S:fh18^Y/`B9YJh4Qj6Y18FL
Y0B3V9h3PI>I17j?U0AlRXl4NHJ:17N1Q@AdOH04LWQk5Oooo`005?ooo`A_LW<4Kg1`16i^KPA^K6`4
KFYY0feYI`A/IfD4K6ER16aSH0A[HEd4JemK0fYMF0AZFeH4JUUC16YGD@AYEDl4JUA<16YBBP=ZD4L4
N5]B17MLD`AfG5D4MUeF17EMF0AcGET3LUiJ179PGPAcHf44LVAS175TH`AaHf@3L6ET16eTI@A/IFD4
KFUZ16e]KPA]L744L7Uj0g:1PPAfR8X4Ni2B17nEV@B3W:84QZ6Y0hRW[`B:[;H4SK>n18nha@BB_L/4
TK[7192f`P>?/[d4SJjh18^Y/PB9Y:d4Qj2W18FKXP>2UY`4P96F17f<T@AjQh/4N8:617EnP@AbNG/E
oooo000Doooo16mbL`A_L704KVi^16i/K0A]JVT3KFUW16aWI@A/IF84K6=P16]QG@A[Ge/3JUeH16YK
EPAZFE<4JUMA16UEC`AZE4`4JU9:0fY@A`AhFe84MeaC17ILE@AfGEH4MEeH17=MF@=bGUX4LV1N17=S
H@AbI6<4LFAS175SI0=`IF@4KFAU16aUI@A]JFX4KFe^16e`L@A`NGX3LX6217J8RPAkT984OiFI18>L
XPB6XJT3R:N_18Z/]PB=/kh4SkS519:mb`BA^/L4T;K20hnb_@B=[[P4RjVb18VT[@B7X:L4QI^R0h:F
W0B0TIH4OHbA17Z7R`AhPXH4MGj1179iNaGoool001Coool4Kg9c16m`L0A^KVh4KVa/16eZJ@=]JFL4
K6MU16aUHPA/Hf04Jf5M16]OF`=ZGEP4JU]F16YID`AZEe44JEE?16YDC0AZDTX3JU1717QKDPAgG5<4
MUaE17IMEPAeGEP4LeeI0g9NFPAbH5h4Lf=Q179TH`AaI6<4LF=T0g1UI0A]I6D4K6EU16eYJPA]KFh4
KG1a171iNP=bPH84MXR:17^@TPAoUIT4PibR18JQZ@>8Yjl4RZbf18fc_PB?^<D4T[g;196ja`B@]/83
Sk:m18f^^0B;ZK84RJB]18NPY`B5Vj83PYJL182AUPAmS944NXN;17R2QPAeOX44LWUk5Oooo`005?oo
o`A_LW<4Kg1`16i^KPA^K6`4KFYY0feYI`A/IfD4K6ER16aSH0A[HEd4JemK0fYMF0AZFeH4JUUC16YG
D@AYEDl4JUA<16YBBP=ZD4L4N5]B17MLD`AfG5D4MUeF17EMF0AcGET3LUiJ179PGPAcHf44LVAS175T
H`AaHf@3L6ET16eTI@A/IFD4KFUZ16e]KPA]L744L7Uj0g:1PPAfR8X4Ni2B17nEV@B3W:84QZ6Y0hRW
[`B:[;H4SK>n18nha@BB_L/4TK[7192f`P>?/[d4SJjh18^Y/PB9Y:d4Qj2W18FKXP>2UY`4P96F17f<
T@AjQh/4N8:617EnP@AbNG/Eoooo000Doooo16mbL`A^L704KVi]16i/J`A]JVP3KFQV16aVH`A/I644
Jf5N16]OF`AZGET3JU]F16UID`AYEe44JEE>16UCC0AYDDT4JDm60feAA`AjGE<4N5aC17MLE0AfGEH4
M5aF179KEP=aFeP4LEiL17=SHPAbI6<4LFAS17EWI`=aI6@4KVIV16aUI@A[IVL4Jf]/16]]K`A^MGL3
LGan17R7R@AmTI<4PYRJ18FNY0B8Y:/3RJR`18^/]PB=/[d4SkS419>nb`BC_ld4T[_80i6g`PB@/[d4
SZfg18bX/@B9Xj/4QijU0hBHW`B1TiT4OXjC17^9S@AhQ8L4MGj1179iNaGoool001Coool4Kg9c16i`
L0A^KVd4KVa[16eZJ0=]J6H4K6IS16aTH@A[HEh4JemK16YMF@=ZFeH4JEUC16UGD@AYEDh4JE=<16UA
B@AYCdH3KE5717YMD`AhG5<4MeaD17IMEPAdG5H4LU]F0g5KF0AaGU`4Lf=R179TH`AaI6<4MFMW0g5T
I0A^IVH4K6EU16]VI`A[Jf`4Jfe_16ieM`=aO7h4N8N917fAT`B2V9X4QIjT18RTZ`>9Z;04Rjbf18fb
_@B?^<@4Tkk;19>oc@BB^lP3TKO2192b_@B>[KL4S:Ra18VSZ`B7WZD3Q9RO186CV@AnSY<4NhV=17R4
Q`AeOX44LWUk5Oooo`005?ooo`A_LW<4KW1`16i^K@A^K6/4KFYX0feXIPA/IV<4K6AQ16]QGPA[Ge/4
JUeI0fYKEPAYFE<4JEMA16UECPAYDd`4JE5916U?AP=]DDL4NUeC17QLD`AgG5@4MUeF17ALEPAbFeH3
LE]H175NG0AcHf84LVAS175TH`AeIfL3LFAT16iVIPA/IFD4JfIW16][K0A[KFl4KWEg0g5lOPAhQhT4
OI6C18:HVPB5WZ@4R:B[0hVX/0B;[;H4SK:m18nha0BC_//4Tko=19:kb0>A]l84T;:m18j]]`B<Z;44
RJ>[18NNY@>4V9l4PI>I17j>T`AkRHd4N8B717EnP@AbNG/Eoooo000Doooo16mbL`A^L704KVi]16i/
J`A]JVP3KFQV16aVH`A/I644Jf5N16]OF`AZGET3JU]F16UID`AYEe44JEE>16UCC0AYDDT4JDm60feA
A`AjGE<4N5aC17MLE0AfGEH4M5aF179KEP=aFeP4LEiL17=SHPAbI6<4LFAS17EWI`=aI6@4KVIV16aU
I@A[IVL4Jf]/16]]K`A^MGL3LGan17R7R@AmTI<4PYRJ18FNY0B8Y:/3RJR`18^/]PB=/[d4SkS419>n
b`BC_ld4T[_80i6g`PB@/[d4SZfg18bX/@B9Xj/4QijU0hBHW`B1TiT4OXjC17^9S@AhQ8L4MGj1179i
NaGoool001Coool4Kg9c16i_L0A^KFd4KF]Z16eYI`=/IfD4K6ER16]RG`A[H5`4JUiI16YKEP=YFE@4
JEMA16QDCPAXDT/4J51916Q?APAWC483N5U>17]MDPAiG5<4MU]C17ILEPAcFU@4LEQC0fmHE@A`G5X4
LF1P17IWIPAbI6<4M6MW0g5UI@A_IFD4KFIV16YTI0AZJV/4JFa^16YaM0=]MWT4Mh>5182@T`B4VYd4
R:2U18ZV[0>;ZK44Rjbf18fa_0B?]l<4T[c:19C1d0BE_l`3UK_819>g`PBA/K/4Sjbe18bV[`B9XJP3
QY^R18>EV`B0T9D4O8Z?17V5R0AfOh84LgUl5Oooo`005?ooo`A_LW<4KVm`16i]K@A]JfX4KFUW0faW
I@A/IF84Jf9O16]PG0AZGUT4JU]F0fUIE0AYEe44J5A>16QBB`AXD4T4J4m616M<@P=hFDh4NeeB17UL
D`AfFe<4MUaF17=JE0AaF5<3KeQE171LFPAaH604MVMV179TH`AdIfL3LFEU16mUI@A]IVH4JVAT16YZ
J`AYK6h4JW5d0fefN@AgPhD4P92C18BJW@B8X:D4RZJ/0h^Y/@B;[;H4SK6l18ng``BB_<X4U<7@19Fo
c0>E^lP4TkO2196a^`B?[;D4S:J_18VQZ0>6Vj84PiFK182@U@AlRXl4NHF817IoPPAcNG`Eoooo000D
oooo16mbL`A^Kg04KVe]16e[JPA]JFL3K6MU16aUHPA[HUl4Jf1L16YNF@AZFeH3JEUD16UGD@AXE4h4
J59;16Q@B@AXCdH4Ida20gQICPAkGE84NEaC17IKD`AfG5H4LeYD175HD`=_F5D4L5aJ175PH0AfIfH4
LVAS17AWI`=aIFD4KfEU16eVIPAZI6@4JVY[16U/KPAZLG@3KGIi17N3Q@B0T9<4Q9ZM18RPY@B:YZ`3
RjVa18^/]PB=/K`4SkO319:lbPBD`M04UKo<0iFkb0BC]l84TK6k18n/]@B<YZl4RJ6X0hJKXPB3UI/4
P92E17b:S`AiQHP4MWn217=iO1Goool001Coool4Kg9c16i_L0A^KFd4KF]Z16eYI`=/IfD4K6ER16]R
G`A[H5`4JUiI16YKEP=YFE@4JEMA16QDCPAXDT/4J51916Q?APAWC483N5U>17]MDPAiG5<4MU]C17IL
EPAcFU@4LEQC0fmHE@A`G5X4LF1P17IWIPAbI6<4M6MW0g5UI@A_IFD4KFIV16YTI0AZJV/4JFa^16Ya
M0=]MWT4Mh>5182@T`B4VYd4R:2U18ZV[0>;ZK44Rjbf18fa_0B?]l<4T[c:19C1d0BE_l`3UK_819>g
`PBA/K/4Sjbe18bV[`B9XJP3QY^R18>EV`B0T9D4O8Z?17V5R0AfOh84LgUl5Oooo`005?ooo`A_LG84
KVm_16i/K0A]JVT4KFQV0faVH`A/Hf44Jf5N16]OF`AZG5L4JEYD0fUGD@AXEDh4Ie9;16I?B0AVCTD4
J4e416U<@P=oGe84O5eC17ULD`AgFU<4ME]D17=ID`A`EU43KUMC16mJF0A^GEd4N6YY17EYJ0AcJ6L3
LFQX16mVI@A]IVH4JfIW16]/KPAZKW04JW9e0fYdM`A`OX84NhZ>18NIW@B;XZL4SJR^0hb[/`B<[KH4
S;2k18ne`PBA_<T4U<7@19K1c`>H`<d4V;c719Ff`0BB/;T4SZZb18^TZ`>8WJ@4Q9NN186AU`AmS904
NXJ917J0P`AcNW`Eoooo000Doooo16maLPA^Kfl4KVa/16eZJ@A]J6H3K6IS16aSH@A[HEh4JemK16YL
E`AYFU@3JEMA16QECPAWDT/4ITm816I>A@AXCD@4JDa20gmODPAlGE<4NEaC17MJD`AeFe@4LeUC171F
D@=^Ee<4KeYH16iMG@AhJVT4MFUX17=XI`=aJ6P4KfIU16eVIPA[IVL4Jfa^16Y^L0AZLWD3JWAg171n
PPAkRXh4QiVM18^RY`B=Z:h3S:^c18b]]PB</;/4SkG2196lb@BD`M04U/7?0iS0c@BH_<L4UKK019:`
^@B>Z[84RjB[0hRMY0B4Uih4PI6G17f<T0AjQXT4MX2317=jO1Goool001Coool4Kg5b16i_K`A^K6`4
KFYY16eXIP=/IV<4K6=Q16]QGPA[Ge/4JUaG16UJE0=YEe44J5E>16MBB`AVCdP4ITi516Q=A0AYC483
OemB17aMD`AiG5<4MeYC17EKE0AcFE<4L5IA0fiGD`A_FUP4KUeM17QZJ@AeJFP4LfQW0g5XJ0A_IVD4
KFIV16]VI`A[K6h4JVi`16YbM@=ZM7L4L7j217^:SPB7VId4Rj:W18fX[P><Zk<4S:ff18b`^`B?]L84
TKc919C1d0BF`Ll3V<3=19Rla`BE]/04T[2i18jZ/PB;Y:/3R9fT18BGWPB1TIL4OHb@17Z6R@AfP8<4
LgYl5Oooo`005?ooo`A_LG84KVm_16i/K0A]JVT4KFQV0faVH`A/Hf44Jf5N16]OF`AZG5L4JEYD0fUG
D@AXEDh4Ie9;16I?B0AVCTD4J4e416U<@P=oGe84O5eC17ULD`AgFU<4ME]D17=ID`A`EU43KUMC16mJ
F0A^GEd4N6YY17EYJ0AcJ6L3LFQX16mVI@A]IVH4JfIW16]/KPAZKW04JW9e0fYdM`A`OX84NhZ>18NI
W@B;XZL4SJR^0hb[/`B<[KH4S;2k18ne`PBA_<T4U<7@19K1c`>H`<d4V;c719Ff`0BB/;T4SZZb18^T
Z`>8WJ@4Q9NN186AU`AmS904NXJ917J0P`AcNW`Eoooo000Doooo16maLPA^Kfl4KVa/16eZJ@A/IfD3
K6ER16]RG`A[H5`4JUeI16YKEPAYF583J5I?16MCC0AVCdP4I4a41699@0AZCTD4LeA90gmOD`AlGE<4
NE]B17MKD`AeFe@4LeQB16mED0=^F5@4KeYH16mMG0AeI6<4M6IU179VI@=aIfL4KfEU16aVIPA[IVL4
K6a^16]_L@A]MWP3KGIj171nP`AeQXX4PYBH18fTZ0B>ZZl3SZbd18b/]PB</;/4S[G1196kb0BC`<l4
Ul?B0iW2d@BL`/d4V;[519Fd_@BA[KH4SJJ^0hZPY`B6VZ04PY>I17j=TPAkQh/4Mh2417=jOAGoool0
01Coool4Kg5b16i_K`A^K6`4KFYY16aWI@=/IF84Jf9O16]PG0AZGET4JU]F16UHDP=XETl4Ie=<16I?
B0ATC4@4HTU016Y>A@AcE4T3OemC17aMD`AiFe84Me]C17EKE0AcF584KeE@0fiHE0A_FUP4KeeL17ET
H`AdIVD4LVIU0g5WI`A_IFD4K6IV16]VI`A/K6h4Jfma16efN0=]MWX4L7j317F6RPB2U9P4SJBX18jZ
[`>>[;@4S:bf18b`^`B>]L44TK_819?0c`BG`m83VL;A19c2c@BH^/D4UKBm196]]PB=YZh3RZ2W18JJ
X0B2TiT4OXfB17^7R`AgP8@4LgYm5Oooo`005?ooo`A_LG84KVm_16i/K0A]JVT4K6MU0faUHPA[HUl4
Jf1L16YMF@AZFeH4JEQB0fQFC`AWDd`4ITm816A<A0ARBD04JTi517=DB@=oGe<4O5eC17UKDPAgFe<4
ME]D17=HDPA_EE03KUQD16mJF0A_GE`4MFAS17AVI@AbIVD3LFMW16mUI@A/IVH4JfIW16a/KPA[Kg44
KGIh0fefNPA`OX<4MHJ:18:DV0B=Y:P4SZZ_0hj/]0B<[;H4S;2k18je`@BA^lP4Tl3?19O3dP>I`]44
W<;=19Rja@BE];d4TJff18fV[P>:X:L4QYZP18:CV@AnSI84NhN;17N0Q0AcNWdEoooo000Doooo16ma
LPA^KVl4KFa[16eYJ0A/IV@3K6AQ16]RGPA[Ge/4JUaG16UJE0AYEe03J5A=16MAB@AUCDD4HTQ015e3
>@A[CT@4OEa@0geMD@AkG584NE]B17MKD`AfFe<4LeQB171FD@=`FUD4Lf1M17=QG`AcHV44Lf=R175T
H`=`Hf<4KV9R16aSH`A[IFH4JfQZ16a^L0A]M7L3KgMl175nP`AeQX/4OI2E18^QYPB@Zk03Sjbd18b/
]@B<[kX4S[C0196ja`BC_ld4U/?B0j39e`BOaM44W;o:19Rg`@BD/;T4T:Va0h^RZPB7W:84PiFK17n>
T`AkR8`4Mh6417=jOAGoool001Coool4Kg5b16i^K`A]K6/4KFUX16aVI0=/I644Jf9N16]OF`AZG5L4
JEYD16UGD0=XE4d4Ie5916E=A@ARB404GD<i16]>A0AmG503OEeA17]LDPAiFe84Me]C17IKD`AcF584
L5IA0g1JE@AcH5d4Lf5O17=RH@AcHf84LFAS0g1SH`A^HV84K6=S16]UIPA[J6X4K6i`16edM`=_Mg`4
LGj317F6R`AmT9D4Rj6V192[/0>?[;@4S:be18b_^PB>]<04TK[719>oc@BF`m83X<WG19o5d@BL_lX4
V;O119B`^@B@ZK43Rj:Z18NLXPB3UI/4OhjC17^8S0AgPH@4LgYm5Oooo`005?ooo`A_LG84KVi_16e/
J`A]JFP4K6IT0faTH@A[HUh4JemK16YLE`AYFU@4JEM@0fQDC@AWDDT4IDe51698@0AM@cT4Jdi417eL
D0=mGE44NeaB17UKDPAgFe<4MU]C17=HDPA`EU43L5YE17=PG@AcHEl4Lf9Q17=SHPAaI6<3L6=S16iR
HPA/Hf<4JfEV16]XJPA/KW04KGAg0fmgO0AaOX<4MHJ;17f@U@B;XJH4T:^`0hn/]0B<[;D4S:nj18jd
`0BA^/L4Tko=19K3dP>PbML4WlGA19bobPBH]l44U;2i192Y/@>;XZX4QibR18>EV`AoSY<4NhR<17N1
Q0AcNWdEoooo000Doooo16maLPA^KVl4KFa[16eYJ0A/IV@3K6AQ16]RGPA[Ge/4JUaG16UJE0AYEe03
J5A=16MAB@AUCDD4HTQ015e3>@A[CT@4OEa@0geMD@AkG584NE]B17MKD`AfFe<4LeQB171FD@=`FUD4
Lf1M17=QG`AcHV44Lf=R175TH`=`Hf<4KV9R16aSH`A[IFH4JfQZ16a^L0A]M7L3KgMl175nP`AeQX/4
OI2E18^QYPB@Zk03Sjbd18b/]@B<[kX4S[C0196ja`BC_ld4U/?B0j39e`BOaM44W;o:19Rg`@BD/;T4
T:Va0h^RZPB7W:84PiFK17n>T`AkR8`4Mh6417=jOAGoool001Coool4Kg5b16i^KPA]Jf/4K6QW16aU
H`=[Hf04Jf1M16YNF@AZFeH4JEQB16UFC`=XDd/4Ie1716E<@`ARAch4Gd@i16Y=@`AiFTl3Ne]A17YK
DPAiFe<4Me]C17IKD`AdF584LEMA0g5JE@AeHUl4MF=Q17ATHPAcHf84LFAS0g1SHPA^HV84K6=S16aU
IPA[JFX4KFe`16ibMP=bN7d4M7n417R6R`AmSiD4QY^Q18fW[0>>Zk<4S:be18b^^@B=/kl4T;S6196m
b`BB_ll3YLkL1:?:ePBO`/d4Vk_519Jc_0BB[;@3SJF/18VNY0B5Ui`4PI2D17b9S@AhPXD4M7]m5Ooo
o`005?ooo`A_LG84KVi^16e[J`A/J6L4K6ES0f]SH0A[H5d4JUiI16YKEPAYF584JEI?0fQCB`AWD4L4
IDa31697?PAOA3T4JTe317UJC`=kFe44NU]B17UKD`AgFe<4MU]C17AHDPAaEe43LEYE17ERG`AeHf44
M6AR17=SHPAaI6<3L6=R16iRHPA/Hf<4K6EV16]YJPA]KG04KW9f0g9hO@AdOh@4N8J;17f?U@B6Vj44
SJN/0hj[/`B<[;D4S:ji18fc_`B@^<H4TKg;19:oc`>Uc]`4Xl[F19o2c@BK^lD4U[>l19:/]0>=YJ`4
RIjT18FGW0B1T9@4O8V=17R2Q@AdNgdEoooo000Doooo16maLPA^KVh4KF][16aXI`A/IF<3Jf=P16]P
G@AZGUT4JU]F16UHDPAYETl3J5=;16M@A`AUC4<4HTLn15m4>@AZCD<4NEY?0g]KD@AjFe84NE]C17MK
D`AfFe<4M5QB175GD@=aFUD4MF9O17ESH@AdI684Lf=R175TH`=`Hf84KV9R16aSH`A/IFH4JfUZ16e]
L0A^LWH3LWQm17AoQ0AhQX/4OHnE18JKX@B=Yj`3SZ^c18b/]@B<[[T4SK>o192haPBA_L/4T[o?0jG>
g0BSb]H4Wl;=19^ka@BF/k`4TZbd0hfU[0B9WZ@4QINL186@U0AlRHd4N8:517AkOAGoool001Coool4
Kg5b16i^KPA]Jf/4K6QW16aUH`=[Hf04Jf1M16YNF@AZFeH4JEQB16UFC`=XDd/4Ie1716E<@`ARAch4
Gd@i16Y=@`AiFTl3Ne]A17YKDPAiFe<4Me]C17IKD`AdF584LEMA0g5JE@AeHUl4MF=Q17ATHPAcHf84
LFAS0g1SHPA^HV84K6=S16aUIPA[JFX4KFe`16ibMP=bN7d4M7n417R6R`AmSiD4QY^Q18fW[0>>Zk<4
S:be18b^^@B=/kl4T;S6196mb`BB_ll3YLkL1:?:ePBO`/d4Vk_519Jc_0BB[;@3SJF/18VNY0B5Ui`4
PI2D17b9S@AhPXD4M7]m5Oooo`005?ooo`A_LG84KVi^16e[JPA/J6H4JfER0f]RG`AZGe/4JUaG16YJ
E0AYEe04JEA=0fUBB@AXCdH4Ida216I9?`AYBd04KU1617EGC0=iFe44NUaB17ULE0AhFe<4Me]C17EI
DPAbF583LUYE17EQG@AfIF<4MFIT17ATH`AbI683L6=R16iRH@A/HV84K6EV16aZJ`A]KW04Kg=g0g=i
OPAgPHH4NhV>182AU`B5VZ04RZ>Y0hbX/0B<Z[<4Rjfh18fb_PB?]l@4T;_:192ncP>Xd=h4YlgI1:;6
d@BM_/P4VKK019B_]`>?Yjl4Rj2V18JHWPB2TIH4OHZ>17V2QPAdNghEoooo000Doooo16maLPA^KVh4
KF]Z16aXIPA[IF83Jf9O16YOF`AZG5L4JUYD16UGD0AYE4d3JE9916Q?APAWC484ITTo16U;@0A^D4H4
MEM<0gUKD@AjG584NEaD17QKD`AgFe<4MEUB179HDP=bFUD4MF5M17IUH`AeIV@4M6AS179THP=`Hf84
KV9Q16aRHPA/IFH4K6Y[16e^L0A_LgL3LgUn17N1QPAkRHh4P96G18FJX0B:XjT3S:R`18bZ/`B;[KP4
SK:n18nga0B@^lX4T;k>0jS@gPBWcMT4X/KA19fnb0BI]/04U:ng0hnW[`B;X:H4QYRN18:AUPAmRXh4
NH:617AkOQGoool001Coool4Kg5b16i^KPA]JfX4K6QV16]UHP=[HUl4JUmK16YLE`AZFU@4JEM@16UD
C@=YDTT4J4m616M<@PAVBCl4JD]016i@APAeEd`3NE]A17YLDPAiG5@4N5]C17MKD`AeFE84LUQB0g9J
E@AeHEd4MVES17EVI0AdI6<4LVAR0g1SHPA^HV44K69R16aUIPA/JV/4KFi`16mcM`=cNGh4Mh6617^9
SPB0TIL4QIZP18ZSZ@><Z;04S:Zc18^]^0B=/[h4SkO4192kbPB@_/h3Z=3N1:O=f@BRa]44WKk819Vf
`0BD[kL3SjN_18^PYPB6V9h4PY6F17f:SPAiPXH4M7]n5Oooo`005?ooo`A_LG84KVi^16e[JPA/J6H4
JfER0f]RG`AZGe/4JUaG16YJE0AYEe04JEA=0fUBB@AXCdH4Ida216I9?`AYBd04KU1617EGC0=iFe44
NUaB17ULE0AhFe<4Me]C17EIDPAbF583LUYE17EQG@AfIF<4MFIT17ATH`AbI683L6=R16iRH@A/HV84
K6EV16aZJ`A]KW04Kg=g0g=iOPAgPHH4NhV>182AU`B5VZ04RZ>Y0hbX/0B<Z[<4Rjfh18fb_PB?]l@4
T;_:192ncP>Xd=h4YlgI1:;6d@BM_/P4VKK019B_]`>?Yjl4Rj2V18JHWPB2TIH4OHZ>17V2QPAdNghE
oooo000Doooo16iaL@A^KFd4KFYY16aWI@A[I643JV5M16YNF@AZFeH4JEQB16UFC`AYDd/3JE5816U>
A@AZC484Jda016e?A0AaE4T4MUU?0gYLD@AkGU@4NUiE17UME@AhG5@4MU]C17AID`=dFeD4M5mK17IU
HPAfIfD4M6IT179THP=`I6<4Kf=R16aRHPA/IFD4K6UZ16i_L@A`M7L3MG]o17V2Q`AmRXl4PI6G18FI
X0B:XJT3RjF^18^X/PB;[;L4SK6m18jf``B?^/P4SKc<0j[Bg`B[dMd4Y/WE1:31c0BK^L<4U[6j0i6Y
/@B<XJP4QiZP18>BU`AnRhl4NH>617AkOQGoool001Coool4KW5a16i]K@A]JVT4K6MU16]TH@=ZHEd4
JUiI16YKEPAYF584JEI?16UCB`=YDDP4JDi516Y<@PA[C404KDm4175DB@AfFDl3NUaA17]NE0AjGUD4
NEeE17QLE0AfFe<4M5UC0gAKE@AdGe/4MVER17IWI@AdIV@4LVAR0g1TH`A_Hf84K69R16aUI@A/JFX4
KVma171dM`=eNgl4NH:717f:S`B1TIL4QIVP18ZQZ@>;YJh4RjRb18^/]`B=/Kd4S[K318njb0B=_<`3
Z];O1:_Ag@BVbMD4X<7<19^i``BF/KX3TJVa18bQZ0B7VZ04Pi:G17j;S`AiPhH4M7]n5Oooo`005?oo
o`A^LG44KVe]16eZJ@A/IfD4JfAQ0fYQG@AZGUT4JU]F16UHDPAYETl4JE=;0fUAB0AYCTD4JTa216]<
@0A]Cd@4LEA917IIC`=jG544NeiD17YNE@AiGED4N5aD17IKD`AdFE<3M5]E17AOF`AfIF84MVMU17AV
I0AbI683L6AS16mSHPA/HV84K6EU16aYJPA^Kg44L7Ag0gEkO`AiPXL4OHZ?186AU`B5VJ04RZ6Y0h^U
[PB;Z;84Rjbg18fa_@B>]/<4Sk[818flc0>Zd]l4Zm7M1:K9e@BP`L`4VkW319Ja^P>AZK44S:6X18NJ
X0B3TYL4OX^?17V3QPAdNghEoooo000Doooo16iaL@A^KFd4KFYY16aWI@A[I643JV5M16YNF@AZFeH4
JEQB16UFC`AYDd/3JE5816U>A@AZC484Jda016e?A0AaE4T4MUU?0gYLD@AkGU@4NUiE17UME@AhG5@4
MU]C17AID`=dFeD4M5mK17IUHPAfIfD4M6IT179THP=`I6<4Kf=R16aRHPA/IFD4K6UZ16i_L@A`M7L3
MG]o17V2Q`AmRXl4PI6G18FIX0B:XJT3RjF^18^X/PB;[;L4SK6m18jf``B?^/P4SKc<0j[Bg`B[dMd4
Y/WE1:31c0BK^L<4U[6j0i6Y/@B<XJP4QiZP18>BU`AnRhl4NH>617AkOQGoool001Coool4KW1a16e]
K@A/JFP4JfIT16YSH0=ZH5`4JEaH16UJE0AYEe04JEA=16UBB@=ZD4H4JTi316]<@0A^CT84L55517AG
C0AhG583O5iD17aPEPAkH5L4NUmF17UMEPAhG5D4MU]D0gELEPAeGeX4MfAQ17MXIPAeIVD4LfAS0g5T
HPA_Hf84K69R16aUI@A/JFX4Kfma175dM`=fO804NhB817n<T0B3TYP4QYVO18VOY`>9Xj/4RZN`18^[
]PB=/;`4S[G218jia`B;^/X3Y/kL1:oEhPBYcMT4XlG?19fla@BH/k`3Tj^c18jSZPB9Vj44Q9>H17n;
T0AjQ8L4MGan5Oooo`005?ooo`A^L744KFe]16aYJ0A[IV@4JV=P0fYPG0AYG5P4JEYD16UGD0AYE4d4
JE990fY@APAZCT<4Jda016i>@PA`DDD4M5M<17QLDP=lGU@4O61F17]PE`AjGeH4NEeF17QLE@AfFe@3
MEaF17EOFPAgI644MfQV17EVI@AcI6<3LFAR16mSHPA/HV84K6EU16aYJPA_Kg44LGAg0gIlP0AkQ8P4
Ohb@18>BV0B6VIl4RInW0hVSZ`B:Yk04Rj^f18f`_0B>]L84S[W718^jbP>Vc]`4[mGR1:W=f@BSaLl4
WKc519Rc_0>CZk<4SZ>Z18VKX@B4TiP4Oh^@17Z4Q`AeO7hEoooo000Doooo16i`L@A]KFd4K6UX16]V
I0AZHf03JV1L16ULF0AYFU@4JEM@16UDC@AYDTT3JU1616Y>@`A[C404KTi2171AA@AdEd`4N5aB0gaN
E0AlH5H4Nf1G17YOEPAiGEH4N5aE17IKE0=eG5H4MEmJ17MTH@AgJ6H4MFIU17=TH`=aI684Kf=R16aR
HPA/IFD4K6UZ16m_L@AaM7L3MWb017^4R0AoS904Pi:H18JIW`B9WjL3RJ>[18ZW/0B;ZkH4SK2l18je
`PB>^LL4Rk[:0jK>g0B_eN84ZLgI1:?5c`BM_<D4V;>l0i>[/`B>XjX4RI^Q18BCV0AoRi04NXB717El
OQGoool001Coool4KW1a16e]K@A/JFP4JfIT16YSH0=ZH5`4JEaH16UJE0AYEe04JEA=16UBB@=ZD4H4
JTi316]<@0A^CT84L55517AGC0AhG583O5iD17aPEPAkH5L4NUmF17UMEPAhG5D4MU]D0gELEPAeGeX4
MfAQ17MXIPAeIVD4LfAS0g5THPA_Hf84K69R16aUI@A/JFX4Kfma175dM`=fO804NhB817n<T0B3TYP4
QYVO18VOY`>9Xj/4RZN`18^[]PB=/;`4S[G218jia`B;^/X3Y/kL1:oEhPBYcMT4XlG?19fla@BH/k`3
Tj^c18jSZPB9Vj44Q9>H17n;T0AjQ8L4MGan5Oooo`005?ooo`A^L744KFa/16aYJ0A[IF<4JV9O0fUN
FPAYFeH4J5QB16QECPAXDT/4JE170fY>A0A[CD44KD`o16m@A0AbDdP4N5aA17aOE@=mH5H4OF9H17aQ
F0AkH5P4NUmG17UNE`AhGEH3MeiG17IOFPAgI604N6QU17IWI@AdIF@3LFES16mSHPA]HV84K6EU16eZ
J`A`L784LgIh0gMmP0AlQHX4PHfB18FCV@B7VIl4R9fU0hVQZPB;YZl4S:Ze18j`^`B@]L44T;W718jj
b@>LamH4ZmCQ1:kCg`BVam84Wkk819Zf_P>E[KD4SjF/18ZMX`B5U9X4Ohb@17Z4Q`AeO7hEoooo000D
oooo16i`L@A]K6`4K6UX16]UH`AZHUl3JEiJ16UKEPAXF584J5E>16QBB`AYD4L3JTi416]=@@A]C3l4
Ke14179CB0AhG544O5mE0gePEPAmHUP4O65H17]PF0AjGeL4NEiG17QMEP=gGUL4MUmJ17MTH0AhJ6D4
MVMU17AUI0=aIF<4Kf=R16eRHPA/IFD4KFY[171`LPAcMWP3Mgf017b5RPB1SI84QI>I18NIW`B8WJD3
RJ6Z18^V[`B<Z[D4S[2k192e`@B@^LL4S[[90ic7ePB[e>44[]?O1:K7dPBO_/P4V[Jn0iF]]@B?YJ`4
RYfS18FDVPAoS904NXB717ElOQGoool001Coool4KW1a16e/K0A/JFP4JfES16YRG`=YGUX4JE]F16QH
DPAXEDh4J59;16U@A`=ZCT@4Jde116e<?`A_D4@4LU=817QLD@AlGeD3OF1F17eRF0AlHEP4Nf1H17YO
E`AiGUL4N5eF0gMNE`AfGeX4MfAP17QXI@AfIfD4M6ET0g5UH`A_Hf84KF9R16aUI@A]JV/4L71b17=f
N0=gOH04O8F:186=TPB5TiT4QiVO18RMY@>9XJX4RjJ_18bZ]@B>/;/4T;G1192ia`B>^/T3W<OF1:_D
h@B^dml4Y/OB19nnb0BJ][h3UJfe18nU[0B:WJ<4QIBJ17n<T0AjQ8L4MGan5Oooo`005?ooo`A^L744
KFa/16]XI`AZI684JF1M0fQMF@AXFE@4IeI@16MCC0AXDDP4JDi50fY<@PA/Bcl4KT`o175AA@AfFD`4
OF5E181RE`=oHeT4Of=J17iSFPAmHUT4O65H17]PF0AjH5P3NF1I17QQG0AiIF04NFQT17MWI@AeIV@3
LVIT16mSH`A]Hf84K6EV16i[K0AaLG<4MGQj0gUoPPAoQh/4PhnD18JDVPB8VIl4R9bT0hVPZ@B;YJh4
SJZe18n`^`BB]L44U;_819Jnb`>KaM@4Y<oM1:_AgPBVbM@4XL3:19^g`0>F[kL4TJJ]18^NY0B6UY/4
P8fA17^5R0AeO7lEoooo000Doooo16i`L@A]K6`4JfQW16YTHPAYH5d3J5eI16QIE0AWEU04Ie=<16QA
B0AYCTD3JTa216a;?`A^C3l4LE5517IIC0AmHED4P69G0gmSF@AoHeX4OV=J17eRF@AlHEP4Nf1H17YP
F0=iH5T4N65L17UUH0AiJ6@4MfMU17EVI0=bIV@4Kf=S16eSHPA/IFH4KV]/175aL`AeN7X3NGn217n7
R`B3Si@4QYBJ18RIW`B8W:@3RJ2Y18^U[PB=Z[D4Sk2k19:e`@BD^lP4U[k;0i_5e0BTcmd4Zm7N1:K9
e0BQ`<X4VkO00iJ_]`BAYZd4RijT18JFV`B0SI44NhF817ElOaGoool001Coool4KW1a16e/K0A[J6L4
JVAR16UPG@=XGET4J5UD16MFD0AWDd`4J55816U>A@=ZC484K4/o16i<?`AaDDD4MUU<17eQE@B0HUL3
Of=I17mSFPAnHeX4OF9I17aQF0AkH5P4NV1H0gUPF@AhHE`4NFEP17UXI0AgIfD4MFIT0g9VI0A_Hf<4
KF=R16aUIPA^Jf`4LG5c17EhNP=iOh84OhN;18>?U0B6U9X4R9VO18RLY0>9X:T4RjF^18fZ]@B?/;/4
T[G119Bkb0BF_//3VlGD1:C?g@B[dMh4Y/WD1:70bPBK]l03UZng196V[@B;WZ@4QYJK182=T@AkQHP4
MGao5Oooo`005?ooo`A^L744KFa/16]XI`AZI684JF1M0fQMF@AXFE@4IeI@16MCC0AXDDP4JDi50fY<
@PA/Bcl4KT`o175AA@AfFD`4OF5E181RE`=oHeT4Of=J17iSFPAmHUT4O65H17]PF0AjH5P3NF1I17QQ
G0AiIF04NFQT17MWI@AeIV@3LVIT16mSH`A]Hf84K6EV16i[K0AaLG<4MGQj0gUoPPAoQh/4PhnD18JD
VPB8VIl4R9bT0hVPZ@B;YJh4SJZe18n`^`BB]L44U;_819Jnb`>KaM@4Y<oM1:_AgPBVbM@4XL3:19^g
`0>F[kL4TJJ]18^NY0B6UY/4P8fA17^5R0AeO7lEoooo000Doooo16i`L0A/Jf/4JVMV16USH@AXGe`3
Ie]G16IHDPAVE4h4IU5:16M>APAXC483JDXo16a8?0A_Bcl4M5=617]NDPB0IET4PfEJ0h9UFPB1I5/4
P6AK17iSFPQmHUX4O69J0g]SG0AkI5h4NVMR17YYI@AhJ6D4MFIT0g=UI0A`Hf84K6=R16aVIPA^K6`4
LW9c17MiN`=kP8<4P8R<18B?U0B6U9X4R9RO18RLX`>:X:P4S:F^18nZ]0BA/;/4U;K219Rmb@BK`<d3
XLWG1:SCh@BYcm`4Y/WE1:;2c0BM^L83V;6i19:X[`B=WjD4QiNL186>TPAkQHT4MGeo5Oooo`005?oo
o`A^L704K6][16YWIPAYHf44J5mL0fMKE`AVF584IUA>16IABPAWCTH4J4a20fU:?`A/B3`4Kd/o17AC
APAkGU84P6EI18=UFP>2IEX4PFAK181TF`AnHeX8OF9J17aRFP=kHe`4NfAN17YWHPAjJFD4N6QU17EV
I0=cIF@4L6=R16aSHPA/IVH4KVa/179bL`AgNG/3Nh231828S0B4Si@4QYBJ18RHW`B8W:<3RZ2X18bU
[PB?Z[@4TK2k19Bf`PBH_LT4Vl3=0j79e`BXdn44ZLoL1:K9e@BR`/`4WKW20iRa^@BBZ:l4SInU18NG
W0B1SY84NhF917EmOaGoool001Coool4KW1`16a[J`AZIfH4JF=Q16QOG0=WFeL4IUQB16IDCPAVDDX4
Idi616Q<@P=YBSl4K4Pl16m;?`AdDdH4NeiB181UF@B3IEX3PVEJ185TF`B0I5/4OV=J27eRFPAlHUX3
Nf=L17]TGPAjIf84NVUU17QXI@AeIV@3LfET171SHPA/Hf84K6IV16i/K0AbLW<4MgUk0g^0P`B0R8`4
Q8nD18JDVPB8V9l4R9bS0hZPZ0B<YJh4SjZd196`^`BD]/84V;g919_0c@>QbML4Z=?Q1:W?g0BVbMD4
X/;<19fi`P>H/KT4TZR_18fOY@B7Ui`4PHjB17^5R@AeOGlEoooo000Doooo16i`L0A/Jf/4JVMV16US
H@AXGe`3Ie]G16IHDPAVE4h4IU5:16M>APAXC483JDXo16a8?0A_Bcl4M5=617]NDPB0IET4PfEJ0h9U
FPB1I5/4P6AK17iSFPQmHUX4O69J0g]SG0AkI5h4NVMR17YYI@AhJ6D4MFIT0g=UI0A`Hf84K6=R16aV
IPA^K6`4LW9c17MiN`=kP8<4P8R<18B?U0B6U9X4R9RO18RLX`>:X:P4S:F^18nZ]0BA/;/4U;K219Rm
b@BK`<d3XLWG1:SCh@BYcm`4Y/WE1:;2c0BM^L83V;6i19:X[`B=WjD4QiNL186>TPAkQHT4MGeo5Ooo
o`005?ooo`A]Kg04Jf]Z16YVI@AXHUl4IeeJ0fEIE@AUEU04I59;16A?A`AUC4<4ITTo0fQ7?0A/Ac/4
L4a017MFBPB0HeH4QVQL18IXG@>5Ied4PfIL185UF`B0I5/4Of=K17iSF`AnI5`3OFIN17iWH@AmJVD4
OF]W17YZI`AgJ6D3M6IT171SHPA]Hf84K6IV16m/K@AbLg@4MgYm0gf2Q@B2RHd4QHnD18NDVPB8V9h4
RIbS0h^PZ0B>Y:h4TJZd19>a^`BG]l84Vkk:19k2cP>TbmT4Z]CR1:_Cg`BXc=L4Y<C>19nka0>J/kX4
U:Za18jQY`B8V9d4PXnC17b6R@AfOGlEoooo000Doooo16e_L0A[JfX4JVIU16QRG`AWGEX3IEUE16EF
D0ATDT/4I4m716E<@`AVBCl3J4Ll16a7>`A`C404MeI:181SEPB6J5`4QVQM0hEWG@B3IU`4PFEK181T
F`AoHe/4OV=K17iTG0=mIUh4OVMQ17eZI@AmJfL4NVYW17MXI@=dIV@4L6=R16eSHPA/IVH4Kfa]179c
M0AgNWd3OH:518:9S@B5Si@4QiBJ18RHWPB9W:<3Rj2X18jT[PBAZ[@4Tk6k19Ng`PBK_/X4W/;>0jC;
f@BZe>84Zm?O1:S<e`BTa<h4Wk_40iZc^PBDZ[44SZ6W18RHW@B2Si<4O8J917ImOaGoool001Coool4
KFm`16][JPAZIVD4J69O16MMFP=UFED4IEI@16ABB`ATCdL4IDa316I9?`=XAc`4K4Lk171<@0AgETX4
P6=F18IXG0B6J5d3QFMM18=VG0B1IE/4P6AK17mSF`AnHe/4OVAL0geVGPAnIf44OFYU17e[I`AjJVL4
MfQU0gAVI0A`Hf84KF=R16aVIPA_K6d4LW=d17MjO@=mPXD4PXV=18F?U0B7U9X4R9RN18VLX`>;X:P4
SZB^196Z]0BC/K/4UkO219^nbPBN`/h3Y<_I1:[DhPB[dml4Z<cG1:C4cPBO^l@3V[>j19BZ/@B>XJL4
R9RM18:?T`AlQXT4MWeo5Oooo`005?ooo`A]Kg04Jf]Z16YVI@AXHUl4IeeJ0fEIE@AUEU04I59;16A?
A`AUC4<4ITTo0fQ7?0A/Ac/4L4a017MFBPB0HeH4QVQL18IXG@>5Ied4PfIL185UF`B0I5/4Of=K17iS
F`AnI5`3OFIN17iWH@AmJVD4OF]W17YZI`AgJ6D3M6IT171SHPA]Hf84K6IV16m/K@AbLg@4MgYm0gf2
Q@B2RHd4QHnD18NDVPB8V9h4RIbS0h^PZ0B>Y:h4TJZd19>a^`BG]l84Vkk:19k2cP>TbmT4Z]CR1:_C
g`BXc=L4Y<C>19nka0>J/kX4U:Za18jQY`B8V9d4PXnC17b6R@AfOGlEoooo000Doooo16e_L0A[JVX4
JFET16MPGPAUG5P3I5MC16=CCPARCdT4HTa416=9@0ATAS/3ID<g16Y7>`AbD4<4OUa?18UXF`B;K5l4
RV]O0hMYGPB5J5d4PfIL185TF`AoI5/4P6AL17mUGP>0J604P6YS181/I`AoKFT4O6aX17UYI`=eIfD4
LF=R16eSHPA/IVL4Kfa]17=dM@AhO7h3OH>618:9S@B5Si@4R9BI18VHWPB;W:<3S:2X18nU[PBBZ[@4
UK6k19Vh`PBN_/X4X/;>0jO>fPB/dn44[mST1:_?fPBWa]04XKk60ibe_0BFZk84T::X18ZIWPB3T9@4
OHN:17ImP1Goool001Coool4KFm`16]ZJPAYIF@4If1N16ELF0=TEe<4He=>169?B@ARC4@4HdU016A6
>`=U@cL4JTLk179@@`AnG4l4RFQK18]/G`B:Jel3QfUN18EXG@B3IU`4PFAK17mTF`B0I5`4OfEN0h1X
H0B0JV<4P6aW17m]J@AlK6P4NFUW0gEWI@AaHf84KF=R16aVI`A_K6d4LgAe17QlOP=mPhH4PXV=18F?
U0B8U9T4RIRN18^LX`><X:P4SjF^19:Z]0BE/K/4VKS219jnbPBR`/h3YlkJ1:cCh@B_f>@4ZloJ1:O6
d0BQ_/H3W;Fl19J[/PB@XZP4RYVN18>@U0AmQhX4MWf05Oooo`005?ooo`A]Kg04JfYZ16UUI0AWH5h4
IEaH0fAGD`ASDdh4HTm9169<A0ASBD04I4Hk0fE3=`AZAc/4LU1317iLC`B9J5/4RfaO18Y[G`>7JEh4
QFQM18=VG0B1I5/4OfAK181TG0AoIEh3P6QP181ZH`B0K6L4OfeY17a/J0AiJFL3MFMU175SHPA]Hf84
K6IW16m/K@AcM7D4N7an0gf3QPB2RHd4QHnD18RDV@B9V9h4RibS0hbPZ0B?YJh4TZZd19Fa^`BI^<84
W[k:1:;2cP>Wc]X4[=?Q1:oHi0B[cmX4YlK@1:6naP>L]K`4UZ^b192RZ0B:VIh4Pi2D17f7RPAfOH0E
oooo000Doooo16e_L0A[JVX4JFET16MPGPAUG5P3I5MC16=CCPARCdT4HTa416=9@0ATAS/3ID<g16Y7
>`AbD4<4OUa?18UXF`B;K5l4RV]O0hMYGPB5J5d4PfIL185TF`AoI5/4P6AL17mUGP>0J604P6YS181/
I`AoKFT4O6aX17UYI`=eIfD4LF=R16eSHPA/IVL4Kfa]17=dM@AhO7h3OH>618:9S@B5Si@4R9BI18VH
WPB;W:<3S:2X18nU[PBBZ[@4UK6k19Vh`PBN_/X4X/;>0jO>fPB/dn44[mST1:_?fPBWa]04XKk60ibe
_0BFZk84T::X18ZIWPB3T9@4OHN:17ImP1Goool001Coool4KFm_16YYJ@AWI6<4IEmL16=JEP=QEE44
H55;15m=APAOBD44H4Hl1652=`=Q?c84IDDi17=CAPB3HE<4TVmP195`HPB>KV43Rf]O18MYGPB4IU`4
PVEK181TG0B0I5d4PFIN0h9YHPB3KVH4Q71Z189`J`AoKf/4NfaY0gIXI@AaI6<4KF=R16aVI`A_KFd4
LgAf17UlO`=mPhH4PXV=18F?U0B8U9T4RYVN18fMY0>>XJT4TJJ_19B[]@BG/K/4VkO21:2nb@BT`ld3
ZlkJ1;3Dh@Bcg>P4[m;M1:[9d`BT`<T3W[Nn19R]]0BBY:T4RiZO18BAU@AmQhX4MWj05Oooo`005?oo
o`A]Kfl4JVUY16MTH`AUGe`4HeYF0f5ED@APDD/4Gde615m9@@APAS`4HD8g0f4o<PAUACT4Le=618=Q
D`BBKf04TG1R18i^H@>;Jel4QfUN18AVG0B2IE/4P6AL181TG@B1IUh3PVUR18=^IPB4L6X4PW1[17m_
J`AkK6T3MVQU175TH`A]Hf84K6IW16m]K@AcM7H4NGao0gf3QPB2RHd4QHnD18RDV@B:VIh4SIfT0hjQ
Z@BAYZl4U:^e19Na^`BK]l84X;k91:C3c@>[c]X4/=CQ1;?Lj0B_d]d4Z/WC1:C0b@>N]kh4V:fd19:T
Z@B;VYl4Q96E17f7RPAfOX0Eoooo000Doooo16e_K`AZJFT4IfAS16EOG0ASFUH3HEEA161AB`AOCDH4
GdU11616?0AQ@SL3HClb16E5>@AcDdH4Pf5C199_H0BAL684SViQ0h][G`B7JEh4Q6IL189UF`B0I5`4
P6AM185VGP>2JF84PfiV18A`JPB2L6/4Ofm[17]/J@=fJ6D4LFAS16eSHPA/IVL4Kfe]17=dMPAiO7l3
OH>618:9S@B5Si@4R9BI18ZIWPB=WJ@3SZ6Y196V[`BDZkD4Uk6k19^g`PBP_/T4Y<?=0j_>fPB`e>44
/mcX1:oBg@BZbM<4Y<390ijg_PBH[K@4TZBY18^JW`B4TID4OHN:17InP1Goool001Coool4K6i_16UX
J0AVHf44HeeK165GE0=NDTh4GDi815a9@`ALASh4GD8i15do=0=N?304H4<g179CA`B6I5H4VWAT19Md
I@BBL6<3SVeQ18UZGPB4IU`4PVEL181TF`B1IEh4PfMP0hI[H`B8L6P4R7=/18IdK`B3Lfl4OFi[0gMY
IPAaI6<4KF=R16aVIPA_K6d4LWAf17UlOP=mPhH4PHR<18J?T`B9U9X4RiVN18jNY@>@XZT4TZN_19F/
]@BI/K/4WKO21:6mb0BU`/d3[lkJ1;KIi@Bhh>`4/mKP1:g<ePBX`//3XKW019^_]PBDYJ/4SIbP18JB
UPAnR8/4Mgj05Oooo`005?ooo`A/KVl4JFQX16ISH@ASGE/4HEMD0eiBCPAMCTP4G4U315a6?PAM@ST4
GCld0ehl<0AP@cL4LU=718ITEPBJM6@4UgAU199`H`>>KF44RFYN18AVG0B2IE`4P6AK185UGPB3If03
QV]S18Q`J0B8Lf`4QWA_18=cK`AmKV/3MfUV175TH`A]Hf84K6IV16m/K@AbM7H4NGan0gf3QPB1R8`4
QXnC18VDVPB;VIh4SYjU0i2RZ@BBYjl4UJbe19Va^`BM]l84XKg81:G2c@>_c]X4]]WU1;SPk0Bce^04
[LcF1:S2b`>Q^L04Vjnf19BUZ`B=W:04QY:F17j8R`AgOX0Eoooo000Doooo16a^K`AYJ6P4IV=Q16=M
F`AQEe@3GU9>15e>B0ALBD<4G4Hn15e2>@AM?c@3GS``1613=`AbDdL4QVAF19YdI0BGM6D4TW1S0hi]
H@B9JUh4Q6IL189UG0B0I5/4PFEN18=WH0>6Jf<4R71X18QcK0B6M6l4Pg=_17e^J`=gJFH4LFAS16eS
HPA/IVH4Kfa]179dMPAiO7h3OH>61868S0B6Si<4RIBJ18^IWPB>WZD3T::Y19:W[`BE[;D4VK6k19fg
`PBQ_LP4YL;=0jo>fPBffND4^>3/1;?Fh0B]c=H4Z<;;0j6i`0BK[kH4U:F[18fLX0B6TYH4OXR;17Mn
P1Goool001Coool4K6i_16UXJ0AVHf44HeeK165GE0=NDTh4GDi815a9@`ALASh4GD8i15do=0=N?304
H4<g179CA`B6I5H4VWAT19MdI@BBL6<3SVeQ18UZGPB4IU`4PVEL181TF`B1IEh4PfMP0hI[H`B8L6P4
R7=/18IdK`B3Lfl4OFi[0gMYIPAaI6<4KF=R16aVIPA_K6d4LWAf17UlOP=mPhH4PHR<18J?T`B9U9X4
RiVN18jNY@>@XZT4TZN_19F/]@BI/K/4WKO21:6mb0BU`/d3[lkJ1;KIi@Bhh>`4/mKP1:g<ePBX`//3
XKW019^_]PBDYJ/4SIbP18JBUPAnR8/4Mgj05Oooo`005?ooo`A/KVh4J6MW16AQH0AQFeT4GUEB0e]?
B`AIBTD4F4Do15Q2>PAI?cH4Fc`a0e`m<PAO@SL4LeE818]XF@BQNFP4W7MW19IcI@>AL6<4Rf]O18AV
G0B0HeX4OF5I17eSF`B2Iel3RFaT18abJPB;M6d4RWMa18QhL`AoLFh3N6YX175THPA/HV44JfEU16e[
K0AaLWD4Mg]n0g^1Q@AoQh/4QHjB18VDV@B<VYl4TInU0i:SZPBDYjl4UZbe19Za^`BO]l84X[g71:K1
c0>ac]T4^mcV1;kSk`BhfN<4/LoH1:_5c@>T^l84WK6g19JW[0B>WJ44Qi>F17n8R`AgOX0Eoooo000D
oooo16a^KPAXIfL4I65P165KF@ANEE83Fdm;15U:A@AHACl4F48j15To=PAK?343G3db15m2=`AcEDP4
RfQI1:5iJ0BLMfL4UW=U0i5`H`B;Jel4Q6IL181SFPAmHET4OF=K189WG`>9K6@4S79Z18]dK@B:Mg44
R7Qc17maKP=hJVP4LFAR16aRH@A[IFD4KF]/175bM@AgNgh3Nh6517n7R`B5SY84RIBI18bJW`BAWjD3
TZ>Z19BW[`BF[;D4V[6k19ng`PBR_LL4Y/7<0k7>f@Bkg>H4_^?_1;SIh`BacmP4ZlG=0jBk`PBM/KL4
UZN/18jMX@B7TiH4OhR;17MnP1Goool001Coool4K6i^16QWI`ATHF04HE]I15iEDP=KCd/4FDY515Q5
?`AH@SX4FClf15/l<@=L?C84Gd8g17=EB0B;J5T4XGUX19agI`BFLfD3TG1S18][G`B4IU`4P6=J17eQ
F@AmHe/4PVMO0hU/I0B<LVX4RgA]18YgL@B8N7<4Og5^0gQZJ0AaI684K69Q16]UI@A]Jf`4LG9e17Mk
OP=kPHD4OhN;18F>TPB9U9T4S9ZO196OY@>BXjX4U:N_19J/]@BJ/K/4WkO21::ma`BV`L`3/LkI1;_L
iPBnhnl4^=WS1;7?f0B[aLd3Y;_219fa]`BFYj`4SYfQ18NCUPAoR8/4Mgj05Oooo`005?ooo`A/KVh4
J6MW16AQH0AQFeT4GUEB0e]?B`AIBTD4F4Do15Q2>PAI?cH4Fc`a0e`m<PAO@SL4LeE818]XF@BQNFP4
W7MW19IcI@>AL6<4Rf]O18AVG0B0HeX4OF5I17eSF`B2Iel3RFaT18abJPB;M6d4RWMa18QhL`AoLFh3
N6YX175THPA/HV44JfEU16e[K0AaLWD4Mg]n0g^1Q@AoQh/4QHjB18VDV@B<VYl4TInU0i:SZPBDYjl4
UZbe19Za^`BO]l84X[g71:K1c0>ac]T4^mcV1;kSk`BhfN<4/LoH1:_5c@>T^l84WK6g19JW[0B>WJ44
Qi>F17n8R`AgOX0Eoooo000Doooo16]]KPAWIVH4HV1N15iIE`AKDTl3Eda815A6@@AC@CX4Dcde15Dk
<PAJ>c03G3hd15e3>@AdETX4Sf]K1:ImJ`BPNVT4VWEW0iAbI0B>KF44QfMM17mRF@AkH5P4MUiG17aS
G0>6Jf84S79Z18ecK0B;MW04R7Qc181bK`=hJfP4LFAR16]QH0AYI6@4JfY[16e_LPAgO7h3NH2317f5
RPB4SI44RiFJ18jKX0BCXJH3UJF[19JX/0BG[;D4Vk:k19ng`@BR_<L4Z<;=0kKAf`C1g^P4`nK`1;cL
i@Bfd]X4[lS?0jRma0BP/kT4V:V^192NXPB8U9L4P8V<17QnPAGoool001Coool4Jfe^16MVIPARH5h4
GUUG15]BC`=GC4P4E4I115=1>PAC?CD4EC/b15Xk<0=L?S@4GD<i17AFBPB?Je/4YWe[1:1jJ@BJMFL3
U79T18i]H@B7Ied4Of9I17]PF0AfGUL4O6=L0hI[HPB<LVX4SG=/18]fL0B8N7<4P79_0gQ[J0AaI684
Jf5P16UTI0A[JV/4KFmb17MlOP=iP8<4OHF:18B=T@B;UIX4SY^P19>QYP>EYJ/4UZR`19N/]@BK/[/4
WkO11::la`BX`/d3]]7K1<7Nj0C3i_04_=cU1;KBfPB_b<l3Z;g41:2c^@BHZJh4T9jR18RDU`B0RH`4
N7j15Oooo`005?ooo`A[KFh4IfIV169PGPANFEL4Fe9?0eM<B0ADAT44Dd4j15<m=@AE>c84FS/`0e`n
=0AM@cT4M5I:18m[F`BVOF/4X7YY19YeI`>DLV@4SVeQ18MWG@AoHUT4Nf1H17INE`AlHe`3QV]R18ab
JPB=Lf`4RgI`18QhL`B0LVl3N6]X175THPA[HF04JFAT16]ZJ`A]Kg84Mgan0gV0P`AmQHX4Q8fA18^E
VPB>Vj04Tj6V0iFUZ`BFZ;04Ujbe19^b^`BO]l44X[c71:S2c@>fdM/4`MkX1<?Vl0Blg>D4]];J1:o8
c`>X_L@4X;>i19RY[PB@WZ84R9BG1829S0AhOX4Eoooo000Doooo16]]KPAWIVH4HV1N15iIE`AKDTl3
Eda815A6@@AC@CX4Dcde15Dk<PAJ>c03G3hd15e3>@AdETX4Sf]K1:ImJ`BPNVT4VWEW0iAbI0B>KF44
QfMM17mRF@AkH5P4MUiG17aSG0>6Jf84S79Z18ecK0B;MW04R7Qc181bK`=hJfP4LFAR16]QH0AYI6@4
JfY[16e_LPAgO7h3NH2317f5RPB4SI44RiFJ18jKX0BCXJH3UJF[19JX/0BG[;D4Vk:k19ng`@BR_<L4
Z<;=0kKAf`C1g^P4`nK`1;cLi@Bfd]X4[lS?0jRma0BP/kT4V:V^192NXPB8U9L4P8V<17QnPAGoool0
01Coool4JVe^16EVI@APGUd4G5ME15M?C0=CB4@4Cd4l14`k=@A;=Rl4CSD/15i0=0=O@cP4HTPm17IH
C0BCKEd4Zh5^1:EmK0BNN6T3Ug=V195_H`B:Jf04PfEK17iRF@AgGeL4NV5J0h1WG`B7KfL4S7=/18]f
L0B6MW44P79^0gQ[J0A`I684JV5P16MRHPAXIfT4JF]_175hN`=bNgl4Mh6618B<T0B:U9T4SYZO19JR
Y`>GYZ`4V:Za19N]]PBJ/K/4W[K01:6kaPBZ`lh3_=CM1<WRj`C9jO84`MoW1;_Eg0Bcb]43[<361:>e
^`BKZZl4TZ2T18ZEV0B1RXd4N7n15Oooo`005?ooo`AZKFh4IFIU161NG@ALEeD4Edm<0e=8A0A?@C`4
C3/e14/f;`A>=B`4GT0d0em3>0ARB3d4MUQ<19=]G@B[PFh4YGe/19ihJ@>GLfH4TFmS18Y[H0B3IE/4
OV9I17MOE`AjHEX3P6MO18M_I`B<Lf`4RgI`18IfL@B0LVh3N6]X171THPAZHF04If9R16QWJ@AYJfl4
LGQk0g9kO`AgPHH4Q8b@18ZDV@B>VYl4UZ:W0iNV[0BHZ[44Ujff19Za^`BN]/04XK_61:[3cP>le=d4
bN;[1<WYlPC1gnL4^mGL1;?:d@>/`<H4XkFk19^Z[`BBX:@4RYFH186:S@AhOh4Eoooo000Doooo16Y]
KPAUIVD4H5iM15aGE@AGCd`3DdQ414m1?0A<>cD4BcH_14he;0AN@3@3Gd<h1698?@AfF4`4TfeM1:^1
KPBUOF`4WWQY0iMcIPBAKf<4RV]P18=UF`AnHUT4MemG17YQFP>0Iel4QfmW18acK0B;MW04QWIa181b
KP=hJfP4L6AR16YQH0AWHV84J6MY16U[K`AaN7/3LW]o17N1QPB4S904RYBI18jJW`BFXZL3UjJ/19RZ
/@BG[KH4V[6k19jf`0BQ^lH4Z/?>0kcDg@C9h^/4bNWb1<7Oi`BkeM`4/l[A0jc0aPBS]K/4VjZ_19:P
Y0B:UIP4PHZ=17QoPAGoool001Coool4JVe^16EVI@APGUd4G5ME15M?C0=CB4@4Cd4l14`k=@A;=Rl4
CSD/15i0=0=O@cP4HTPm17IHC0BCKEd4Zh5^1:EmK0BNN6T3Ug=V195_H`B:Jf04PfEK17iRF@AgGeL4
NV5J0h1WG`B7KfL4S7=/18]fL0B6MW44P79^0gQ[J0A`I684JV5P16MRHPAXIfT4JF]_175hN`=bNgl4
Mh6618B<T0B:U9T4SYZO19JRY`>GYZ`4V:Za19N]]PBJ/K/4W[K01:6kaPBZ`lh3_=CM1<WRj`C9jO84
`MoW1;_Eg0Bcb]43[<361:>e^`BKZZl4TZ2T18ZEV0B1RXd4N7n15Oooo`005?ooo`AZK6d4I6AT15iL
F`AIE584Dda90di3@0A8>cL4@c<^13h[9@A6;bL4Fcld0fE9?@AZCT<4OEi@19M`H0B_Q744Z7m^1:5j
J`>IM6H4Tg9U18i^H`B7JEl4PVAK17iRFPAnI5/3PVQP18I]I@B:Lf/4RGA^18EdK`AoLFd3MfYW171T
H@AZHF04If5Q16MVJ0AYJfl4K7=h0f]fN`A/NH04OhR=18FAUPB9UY/4U:2U0iJTZPBGZK04UZbe19R`
^@BL];h4W[S41:c5c`?0e]h4d>K^1<o]mPC8h^X4`=SO1;S>e0>``lP4YkNl19j//@BEXJD4RiJI18::
S@AiOh4Eoooo000Doooo16Y/K@ATI6@4GUaK15UDDPACC4T3CT=014Pk=`A3<bh4?R/U14H_9`AK?c@3
IDTm16Y>@`AmGU04Ug1P1:n4L@BXOfh4XGY[0iUdIPBCLVD4SViS18MYG`B2I5/4OV9J17iTF`>2J604
QVeU18YcJ`B9M6h4QGA_17maK@=gJVL4L6AQ16YQH0AWHF44IfIX16U[K`A/LgP3JgIk16aiP0AoR8d4
QI6F18VFV`BDX:D3UZBZ19NY/0BF[;D4V;2i19bd_PBN^<@4[<G?0l3FgPC@i^h4cngf1<SRjPC0f=l4
^<kD0k33b0BW]k`4WZba19FQY@B;UYT4PXZ=17UoPAGoool001Coool4JVa]16ATI0ANG5/4FEAB15=<
B@=>@d04B3/g14<c;P@n:bD4ARlW15/o=0=UBCd4JTi317eND0BGL604[hAa1:QoKPBQNV/3VGAV19=b
I@B>KV<4QfUO189TF`AnHUX4OVAK0h9XH0B6KFD4RW=[18UdKPB5M6l4Og5]0gMZI`A`I644JV5P16MQ
H@AWIVP4JF]_16acN0=[MW/4K7V017n8S@B5TIH4RIJK19BPY@>FY:X4UjV`19J/]@BH/;T4W;Bn19jh
a0B/aLl3`=KN1=3VkPC?kOH4b>;Z1<3Hg`Bhc]@3/<?81:Ng_0BN[;44UJ6U18^FV@B2RXd4NGn15Ooo
o`005?ooo`AZK6d4I6AT15iLF`AIE584Dda90di3@0A8>cL4@c<^13h[9@A6;bL4Fcld0fE9?@AZCT<4
OEi@19M`H0B_Q744Z7m^1:5jJ`>IM6H4Tg9U18i^H`B7JEl4PVAK17iRFPAnI5/3PVQP18I]I@B:Lf/4
RGA^18EdK`AoLFd3MfYW171TH@AZHF04If5Q16MVJ0AYJfl4K7=h0f]fN`A/NH04OhR=18FAUPB9UY/4
U:2U0iJTZPBGZK04UZbe19R`^@BL];h4W[S41:c5c`?0e]h4d>K^1<o]mPC8h^X4`=SO1;S>e0>``lP4
YkNl19j//@BEXJD4RiJI18::S@AiOh4Eoooo000Doooo16U[K0ASHf<4G5YI15IAD0A?B4H3B3ll144e
<@@i:bH4;ahI140/90AA>2l3HTLl16eAAPB4HU@4Vg=S1;:6LPB[PW04Y7e]0i]fJ@BDLVD4SfmT18]]
HPB6JEl4PfIM18=WGP>5Jf84R6iV18YbJ`B:MFl4Q7=]17i_J`=gJFH4KfAR16URH0AVHF44IVIW16U/
KPA/LWL3K7Ek16]hO`AfPXP4OHZ@18BBV0B>W:83TZ6X19>V[PBDZK84UJjg19Rb_0BK]/44[lK@0lCG
g`CDi^h4e_7i1<kWkPC6g>84_M7F0kC5bPBZ^[h4XJjb19NRYPB=UiX4Ph^>17V0PQGoool001Coool4
JF]/16=SH`ALFUT4EU5@14m8AP=8?c`4@CDa13T[9P@_7QT4@2`T154h;`=RAc`4KE5618ARE0BKLf<4
/XIb1:^2L0BTOFd3VgIY19AbI@B?Kf@4RfeR18IYG`B3IUd4PfMN0hE[HPB8KVH4RW9[18YeK`B4Lfd4
OVm[0gMYIPA_I684JF9P16IQH@AVIVL4JFa^16abM`=/MG/4JgQo17J2R0AmRY04Q9:H18jLXP>BXJP4
TjJ^19BY/PBE[[L4V;:l19^f`@B_a]03a=OO1=CVkPCFlOT4c^O^1<KLhPBmdMH3]<G:1:Zj_PBQ[[84
Uj:V18fGVPB3Rhh4NH225Oooo`005?ooo`AYJf`4Hf=S15aJF@AFDE04CdQ60dPo?0A1=C44>B/V12lN
6@A0;2@4DCP_0f97?0A]DDH4Q69D19]cH`BbQW84Zh9`1:AmK@>KMVT4U79U18m_I0B;KF84QVUO18=V
G@B3Ieh3QF]R18Q^IPB:LV/4RWE_18AcK@AnKf/3MfUV16mTHPAYHV04IV5Q16IVI`AYK6h4K79g0fae
N`A[N7l4MX:817f:T0B4TYP4SYbR0i:QZ0BCYZh4U:Vb19F^]`BH/[`4VkK11:o6d0?4eml4e>K^1=Ka
n@C>inh4a]cR1;gAeP>daLX4Z[Zn1:6^/PBGXZH4SINJ18>;SPAiP88Eoooo000Doooo16Q[K0AQHV84
FUQH15=?CPA;AD<3A3/h13/`;@@b9B449aLC13PV80A:=Bd3GD@j16mBAPB7I5D4WgIU1;>6L`B_Q7<4
Yh1`0imjK@BGM6L4T6mS18]/H@B6JV04QFQN18=WGP>4JV04QVaS18M`J0B7Lf`4Pg1[17e/J0=fJ6D4
KfAR16URH@AVHF44I6AU16Q/K@A]LgH3KWMl175lP@AfPXP4NhR>186@UPB:V9l3SIjU18nSZ`BAYk04
Tj^e19>_^PBI]L04/LO@0l[Jh0CDiN`4foCj1=G[l@C=h>H4`mCI0kW8c@B^_<04Y;2d19VTY`B?V9/4
Q8b>17Z0PQGoool001Coool4J6]/165RHPAJF5P4Ddm>14]5@`=4>cP4>c0]138U8@@W5a<4>2HP14Xe
;@=MA3X4Ke9618MTE@BOMVD4/hIc1:n4L`BWP703WgY]19MdI`B@Kf<4RfaQ18IZH0B5J5h4PfMN0hAZ
H0B6K6<4Qg1X18McK0B3L6/4OFaX0gIXI@A_I684JF9Q16IQH@ATI6D4J6a]16ecMP=^Mg`4LGb117J2
R0AkR8h4PI2F18ZHW`>=WZD4Sj>[196W/0BCZkD4Tjnj19Ve`0Baam03b][P1=CUk0CKm?X4eN_a1<gP
iPC3e=T3^LS=1:jl`0BT/;@4VJBW18nHV`B4S8h4NX225Oooo`005?ooo`AXJf`4HF9R15YHF0ACCdh4
BdE30d@k>0@k<2d4<RDQ12LG4`@h9R04BSD]0ee4>PA_DTH4QfAE19mfI@BcQW<4[hAc1:N0L0>ONVd4
UgAW191_H`B;K644QVYP18EXGPB3Ieh3Q6YP18I/H`B7L6P4Qg=/18=`J`AmK6P3MVQU16mTHPAYHV44
IV5Q16ATI@AXK6d4KG=f0figO0AaO844MX:817^8SPB1T9H4RYRO0hfNY@B?Xj/4TJN`19>[]@BC[kX4
VKG01;77d0?:f^04e>G/1=_dnPCEjo44cN3V1<?Df@>ib<d4[[c01:B`]0BIY:L4SiRK18B<SPAjP88E
oooo000Doooo16Q[K0AQHV84FUQH15=?CPA;AD<3A3/h13/`;@@b9B449aLC13PV80A:=Bd3GD@j16mB
APB7I5D4WgIU1;>6L`B_Q7<4Yh1`0imjK@BGM6L4T6mS18]/H@B6JV04QFQN18=WGP>4JV04QVaS18M`
J0B7Lf`4Pg1[17e/J0=fJ6D4KfAR16URH@AVHF44I6AU16Q/K@A]LgH3KWMl175lP@AfPXP4NhR>186@
UPB:V9l3SIjU18nSZ`BAYk04Tj^e19>_^PBI]L04/LO@0l[Jh0CDiN`4foCj1=G[l@C=h>H4`mCI0kW8
c@B^_<04Y;2d19VTY`B?V9/4Q8b>17Z0PQGoool001Coool4J6Y[161QH@AHEeH4D4e<14Q3@@<o>3D4
=R`Y12`P70@Q4`l4<20K14@a:@=I@CL4KU5518MTEPBPMfH4/hIc1;:7MPB[Pg@3Xgia19aiK0BDM6P4
SViT18U/HPB8JV44QFUO0hAZH0B4JV84QFeU18A_J0B1KVP4NfYV0gIWI0A`IF<4JV=R16IQHPARHV<4
HfMY16U`L`=^MgX4MGj217V4R@AlRHh4P8nE18JFW0>9Vj<4S:2Y18jU[PB?Z;84SZ^f19Zf`@Bcb=43
c]_Q1=GUj`CNm?X4hOCh1=GVjPC9f=`3_/_?1;:n`PBW/[D4VjFX192IV`B5S8l4NX225Oooo`005?oo
o`AXJV/4H65Q15QGEPA@CD`4B4=10clh=@@f;2T4;20L124C3`@`81/4A34Y0eU1=`A^DDD4QfAF1:1g
IPBcQW<4/XMf1:^3M0>SOW44W7U/19AdJ0B>KV@4RFaR18QZH@B5JEl3Q6YP18AZHPB5KFD4Q6mX185^
J0AkJVH3MVMT171UH`AZHf84IV5R169RH`ASIfT4JG1c0figNPAeOX84NHB917b9SPB0SiD4QYJL0hVK
X`B<X:T4SZF^18nX/PB>ZkH4V[K11;?8d@?>fn44eNG[1=kdnPCQm?P4eNKZ1<WHg0>nbll4/[k21:Nb
]@BKYJP4T9VK18F<S`AjP88Eoooo000Doooo16QZJ`APHF44F5MF151=C0A8@d43?cPe13H/:@@/81`4
8A<?130P6`A4<BT3FD4g16iAA@B7I5H4X7MV1;>6L`BbQgH4Zh=d0j=nL@BLNF`4U7AX18i^I0B9K684
R6YQ18EYG`>4JV04Q6YR18E]I@B4KfP4PFiX17]ZIP=fIf@4L6ES16YSHPAVHF84HV9S16=WJ@AYL7<3
KWMj17EnPPAiQ8T4O8V>182?U@B6UY`3RI^S18bPZ@B>YJh4SjRb18j[]PBJ]/44/lSA0lkKh@CEiN/4
g_Cj1>7dn0CEi^X4bMSL0kk;c`Bb_/84Yk:e19^UZ0B@VI/4QHb?17Z0PQGoool001Coool4J6Y[161Q
H@AHEeH4D4e<14Q3@@<o>3D4=R`Y12`P70@Q4`l4<20K14@a:@=I@CL4KU5518MTEPBPMfH4/hIc1;:7
MPB[Pg@3Xgia19aiK0BDM6P4SViT18U/HPB8JV44QFUO0hAZH0B4JV84QFeU18A_J0B1KVP4NfYV0gIW
I0A`IF<4JV=R16IQHPARHV<4HfMY16U`L`=^MgX4MGj217V4R@AlRHh4P8nE18JFW0>9Vj<4S:2Y18jU
[PB?Z;84SZ^f19Zf`@Bcb=43c]_Q1=GUj`CNm?X4hOCh1=GVjPC9f=`3_/_?1;:n`PBW/[D4VjFX192I
V`B5S8l4NX225Oooo`005?ooo`AWJV/4Gf1P15IEE@A>BdX4AD0n0c`e<`@b:BH49adJ11`@30@[71L4
?RdV0e@n=0A[Cd<4QV=E19ifI@BbQG84]8Ug1:j7M`>WPW@4X7ia19UiK@BCMFX4Sg5W18a_I0B9KF<3
QfaS18I/HPB4K6<4PVaT17m/IPAjJF@3MVMT175VI0A]IF@4JFAU16ATIPAQIFP4Hf]^0fIaM@A`NWh4
Mh:717b9SPAoSiD4Q9BK0hNIX@B:WjP4Rj:/18ZU[`B:Z;<4W;O11;C9d@?<fMh4fNK[1>3bm`C[n_d4
g>[^1<oLg`?2c]44]/741:Zc]PBNYZT4TYZL18J=S`AkP88Eoooo000Doooo16MZJ`AOH604EUEE14i;
BPA5@3h3?3Dc138Y9P@W7AX4710<12/L5`@n;BH3E3hd16]?@`B6HeD4WWIU1;:5LPBdRGL4[XMg0jN2
M0BPOW44VGU]19=eJPB?LFL4S6mT18U]H`>7K6<4QVaR18A/H`B2K6@4OfaV17YYI0=fIf@4LFIT16eU
I0AYI6D4I6AV165UJ0ASJfh3IW5e171jOPAgPXL4O8V>17n?U@B4U9/3QiVQ18ZOZ0B;XZ`4RZF_18ZX
/`BL]l44]<WA0lcIgPCIi^/4h?;g1>_jo@CLj^h4cmcO0l;>d@Bf`L@4Z[>f19jVZ@BBVY`4QXf?17^0
PQGoool001Coool4IfY[15mPH0AFEED4CT]:14E0?P<l=C<4<RTV12LM6P@L40`4:a`G13h]9P=D?S@4
Jdm318ISE@BNMVD4/XEb1;B9M`B^QgL3Yh9d1:1nL@BINFd4TgEZ18maI`B<Kf@4RFeS0hM/H`B6K684
Q6aS189/I0AoK6H4NVUT0gIWI0AaIV@4KFET16UTI@ATI6H4HFEX16=[KP=VLGD4L7Yn17N2Q`AlRHh4
OhnE18BDV`>7VJ44RYnX18^R[0B:YJl4RZRc19bg`@BdbM43c=WN1=WVj`CPl_L4jo[m1=cZkPC?g=l3
`/kA1;K1a0BZ/kH4WZJY19:JW0B6SHl4Nh225Oooo`005?ooo`AWJV/4Gf1P15IEE@A>BdX4AD0n0c`e
<`@b:BH49adJ11`@30@[71L4?RdV0e@n=0A[Cd<4QV=E19ifI@BbQG84]8Ug1:j7M`>WPW@4X7ia19Ui
K@BCMFX4Sg5W18a_I0B9KF<3QfaS18I/HPB4K6<4PVaT17m/IPAjJF@3MVMT175VI0A]IF@4JFAU16AT
IPAQIFP4Hf]^0fIaM@A`NWh4Mh:717b9SPAoSiD4Q9BK0hNIX@B:WjP4Rj:/18ZU[`B:Z;<4W;O11;C9
d@?<fMh4fNK[1>3bm`C[n_d4g>[^1<oLg`?2c]44]/741:Zc]PBNYZT4TYZL18J=S`AkP88Eoooo000D
oooo16MYJPANGel4EEAD14a9B0A2?Sd3>3<a12hW90@S6QL460h:12LJ5@@h:283D3Xb16M<@@B1H584
VW=S1;23L@BeRWP4/HYj0jZ5M`BSPWD4WGeb19QjK`BCMV`4Sg=Y18a`IP>9KfD4QfeS18E/I0B2Jf@4
OfYT17]YI0=fIf@4LfMU16mWIPA[IfP4J6MY16EYJ`AUJfl3IFmd16UeNPA_O884MXB:17Z;TPB0TIP3
PYJO18JKY@B6WjT4QZ:]18RV/PBL]l04/lO?0lSGg0CKi^X4ioCg1?7lo`CSk_44eMoR0lOAd`Bi`lD4
[;Fg19nWZPBCVY`4Qhf?17^1PQGoool001Coool4IfUZ15iOG`AEE5@4C4U8148n?@<h<c44;RLT12<J
5`@H3PX49aXE13PX8P=@>S84Ida1185PDPBJLf<4/8=a1;F:N0BaRWX3ZXEg1:>2M@BMOG84V7Y_19=f
K0B?LfT4S71V0hU_I@B7KF<4QFaT189[I0AoJV@4NfUT0gIWI0AcIfD4KfMV16]WJ0AXIfT4IFU[16E[
K`=UKg@4JGEj16mlPPAfQ8X4NX^B182AV0>2UYl4QY^U18JOZ@B6XZd4R:Jb19bg`0Bcall3b=OL1=_V
jPCWm?L4lOco1>?^l@CEgn83am7C1;W3a@B/]KL4WjNZ19>JW0B7SHl4Nh625Oooo`005?ooo`AWJFX4
GUmO15EDE0A<BDP4@Shm0cPc<@@^9b@48aXG11P>2P@W6QD4>2PR0e0j<PAWC444PF1B19YcH`B`Pg44
]HYh1;6:NP>ZQGL4Xh9e19emLPBHNVl4TgI/18mcJ@B<L6H3RFmU18M]H`B5K6@4PV]T17mZI0AkJF@3
MVMT17=WI@A_IfH4JfMX16QWJ@AUJF/4IF]_0fE_M0AYMGX4Kgb217J4RPAjRi84P96H0h:FW`B6VjD4
QYnY18JR[@B8Y[84W;O01;?7c`?8em`4fnKZ1>Odm`Cao?l4hnka1=GOhP?7dM<4^L?51:be]`BOYjX4
TiZL18N=S`AkPH8Eoooo000Doooo16MYJPANGel4EEAD14a9B0A2?Sd3>3<a12hW90@S6QL460h:12LJ
5@@h:283D3Xb16M<@@B1H584VW=S1;23L@BeRWP4/HYj0jZ5M`BSPWD4WGeb19QjK`BCMV`4Sg=Y18a`
IP>9KfD4QfeS18E/I0B2Jf@4OfYT17]YI0=fIf@4LfMU16mWIPA[IfP4J6MY16EYJ`AUJfl3IFmd16Ue
NPA_O884MXB:17Z;TPB0TIP3PYJO18JKY@B6WjT4QZ:]18RV/PBL]l04/lO?0lSGg0CKi^X4ioCg1?7l
o`CSk_44eMoR0lOAd`Bi`lD4[;Fg19nWZPBCVY`4Qhf?17^1PQGoool001Coool4IVUZ15eNG`ACDe<4
BTQ7140l>`<f<Bl4:b@R120H5@@E2`P491TD13DV80=;=bl4HdTo17aMD0BEL604Zh1_1;J;N@BdS7`3
[HUj1:N5N0BPPGD4Vgeb19IiK`BBMV`4SW=Y0h]`I`B8KVD4QVeT189/I0AoJV@4NfUT0gMXI0AdJFH4
LFUX16iYJPA[JV`4J6a^16Q^L@=XLWH4JWIk16ekP@AaPHL4MXN?17^>UP=nTi`4P9NQ186LYPB3X:/4
RJNc19fg`0Bcalh3a]KK1=_Uj@C[m?H4m_ko1>[cm@CJh^@3b]?E1;c4aPB^][P4XJRZ19BKW@B8SXl4
O8625Oooo`005?ooo`AVJFX4GEiO15=CD`A:B4L4@3`k0cHa;`@[928481PE11D;20@T6A@4=BHP0d/g
;`ASBCl4O5e@19E`H0B[P6l4]X]i1;B<O0>]RGX4YhEh1:21M@BKOG84UWU_199fK0B>LfT3Rg1W18Q^
I@B6KF@4PVaT17mZI0AkJF@3MfQT17AYIPAaJFP4KVUZ16]ZK0AXK6h4J6ia0fQbMPAZMW/4KG^11761
Q`AfQhl4NhjF0gjCW0B0Uj44PIbV18>PZ`B9Yk<4WKO01;?7cP?6e]/4fnGY1>_dmPCfo_l4j_?e1=[R
i0?:dmD4_<C61:jf^0BQZ:X4U9^M18R>S`AlPH8Eoooo000Doooo16IYJPAMGUl4De=C14Y8A`A0?3/3
=S4_12/T8P@P61D45@/812@I50@e9R03BcL_16=9?`AlGE04UG1P1:^0K`BfRgT4]8al0jf9NPBWQGP4
X85e19]mLPBFNFl4TWI/18icJ@>;L6L4R6iU18I]I0B2K6@4OfYT17]YI0=gJ6@4M6UV175YJ0A^JFX4
JfY/16Q/KPAXKW43J79f16YfN`A]Nh44LH6717J7S`AkSYH3OY>L182GX@B1W:H4Pj2[18VW/`BM]l04
/lO>0lKFf`CKiNT4joCf1?Kno`CZloD4f^;T0l[Ce@Bla<H4[[Jh1:6XZPBDVid4R8j?17b1PQGoool0
01Coool4IVUZ15aMGPABDU84B4M613hk>P<c;bd4:B<Q11dF50@B2@H48QLC138T7P=7<b`4GDDk17MH
C0B?Je`4YGa[1;B9M`BfSWh3/8]m1:V7N`BSQ7P4WH1f19UlL@BDNFh4T7I/0hebJ0B:L6H4QViU18=/
I0B0Jf@4O6YT0gUYIPAfJVP4M6]Z175/K0A^KFh4Jfi`16]`M0=[M7P4K7Qm16mlPPAaPHP4M8J>17N;
U0=kTIX4OIFO17jIX`B0WZT4S:Vd1:6h`@Bdalh3amKK1=_Uj0C^loD4n?gn1?7gn0CNiNH3cMCE1;k5
aPB`][P4XZVZ19FKW@B8SXl4O8625Oooo`005?ooo`AVJFX4G5eN159BDPA8AdH4?S/j0c<_;@@Y8b44
7AHD11891P@R5a<4<R@N0dLc;0AMAC/4MeQ<18m[G0BUO6/4]8Ug1;J>OP>`Rgd4ZHMk1:>4N0BMP7H4
VGaa19AiKPB@MV`3SG9X18Y`IPB6KVD4PfaT181[I0AlJV@3NFUV17IZJ0AdJfX4LFa/16i]KPA[KW04
Jg1d0f]dN0A/N7d4Kgb21761R0AdQXh4Mh^D0g^AVPAmUIl4OYVS182NZ@B<ZK@4XKS11;C7cP?7e]/4
fnGX1>kcm@ChoOh4lOOh1=kUiP?=e=D4_/G61;2f^0BRZJX4UI^M18R>S`AlPH8Eoooo000Doooo16IY
JPALGEh4DU9B14Q7AP@n>cX3<bl]12TS8@@M5Q@44PT6128G4`@b91h3Ac</15e5>`AgF4`4Sf]L1:El
J`BdRGL4]Xin0k2;O@BYQg/4XhAh19f0MPBIO744U7U^191fK0>=LVP4RW1V18I^I@B3K6@4P6]T17aZ
I0=iJFH4MVYX17A[JPAaK6`4KVe^16]^L0A[L7@3JgAh16ahO@A_O884LH6817B6SPAgRi@3Ni6J17fE
W`AnVJ<4P9jY18bY]0BQ^<44]<O>0lOFf`CKiNP4k_?e1?SmoPCamoP4g^GV0lgDe@BnaLH4/;Jh1::Y
ZPBEVid4R8j?17b1PQGoool001Coool4IVUZ15aMGPABDU84B4M613hk>P<c;bd4:B<Q11dF50@B2@H4
8QLC138T7P=7<b`4GDDk17MHC0B?Je`4YGa[1;B9M`BfSWh3/8]m1:V7N`BSQ7P4WH1f19UlL@BDNFh4
T7I/0hebJ0B:L6H4QViU18=/I0B0Jf@4O6YT0gUYIPAfJVP4M6]Z175/K0A^KFh4Jfi`16]`M0=[M7P4
K7Qm16mlPPAaPHP4M8J>17N;U0=kTIX4OIFO17jIX`B0WZT4S:Vd1:6h`@Bdalh3amKK1=_Uj0C^loD4
n?gn1?7gn0CNiNH3cMCE1;k5aPB`][P4XZVZ19FKW@B8SXl4O8625Oooo`005?ooo`AUJ6X4FeeN155A
DPA7ATD4?3Xi0c4^;0@V8Al46a@B10l71@@O5A44;b8L0d8`:@AG@3L4Ke=718QVF0BOMfL4[XEc1;N>
O@>bSGh4ZhYm1:F6NPBOPgP4VWmd19IkL0BBMfd3SWAZ18]aJ0B8KfH4Q6eU185/I@AnJfD3Nf]W17Q/
J@AfKF/4Lfi^175_L0A_LG<4KG=f0fifNPA^NWh4Kgf31761R0AcQXd4MHZB0gR?V0AiTid4NYNR182N
Z@B?ZkD4XkW21;K8c`?9e]/4gNGX1>ocl`Cjo?`4m?Sh1>3Ui@??e=D4_lG61;6f^0BSZ:X4UY^L18V>
S`AlPH8Eoooo000Doooo16EXJPAKGEh4DE5B14M6A@@l>ST3<Bh/12HQ7`@K51843`L511lE4@@_8Q`3
@S0Y15M0=`A_DdL4R6IH19mgI`B^QG<4]him0k:=OPB[RWd4YHIj19n3N0BJOg@4UW]`199gK@>>M6X4
Rg5X18Q_IPB4KFD4PFaU17i[I@=kJfL4N6aY17I]J`AcKVh4LFm`16maL`A]LgH3KWIj16ijOPA_OH<4
LH6817>6S@AeRY83N8nH17VCW@AjUj84P9jY18n[]@BS^L84]/S?0lWFf`CMiNP4ko?c1?[lo0Cdn?P4
h>GU0loDe@BoaLH4/KJh1:>XZPBFVi`4RHj?17b1PQGoool001Coool4IFQZ15]MGPAADE84AdI513`j
>@<a;R`49R4O11/D4P@?1`D47aDA12lR70=2<2T4Ed0g16mCA`B8IUP4WgMW1:j5L`BgSWd3/Xen1:^:
O@BUQWX4Wh=h19YoM0BFNg04TWM]0hidJPB;LFP4R6mV18A]I@B1K6D4OV]U0g][I`AhK6T4MVe[17=^
KPAaKg04Kg5c16ecMP=^MWX4KWYn16mmP`AaPHP4LhJ=17F:TP=hSiP4NI>M17ZGXPB0WZT4Sj^e1:>i
`PBfb<l3bMKK1=gUj0C_lo<4n_cl1?Chn0CPiND3cmCE1;o5aPBa][P4XjRZ19JKW0B9SXl4O8625Ooo
o`005?ooo`AUJ6X4FeeN155ADPA7ATD4?3Xi0c4^;0@V8Al46a@B10l71@@O5A44;b8L0d8`:@AG@3L4
Ke=718QVF0BOMfL4[XEc1;N>O@>bSGh4ZhYm1:F6NPBOPgP4VWmd19IkL0BBMfd3SWAZ18]aJ0B8KfH4
Q6eU185/I@AnJfD3Nf]W17Q/J@AfKF/4Lfi^175_L0A_LG<4KG=f0fifNPA^NWh4Kgf31761R0AcQXd4
MHZB0gR?V0AiTid4NYNR182NZ@B?ZkD4XkW21;K8c`?9e]/4gNGX1>ocl`Cjo?`4m?Sh1>3Ui@??e=D4
_lG61;6f^0BSZ:X4UY^L18V>S`AlPH8Eoooo000Doooo16EXJPAKGEd4D55A14I5A@@k>CP3<2`[12@P
7P@I4a443@H411`C40@]81/3?RdV158l<`AXCT<4PV5D19QbH`BXP6l4/h]j0k:>O`B/Rgh4YXMk1:64
N@BLPGH4Ugec19=iK`>?MF/4S79Y18U`J0B5KVH4PVeV17m/IP=mK6P4Nfi[17Q_KPAeL704Lg5b175c
M@A`MGP3L7Qk171kO`A`OX@4LH:817:5S@AdRY83MXfG17NBW0AjUj84Pj2[19>]]`BU^l<4^L[@0lcH
g0COi^P4lO?c1?cmo0Calo<4gn?S0loCe0C0a<D4/KJg1:>XZ@BFVi`4RHj?17b1PQGoool001Coool4
IFQZ15]MG@A@DE44ATE513/i>0<`;2/4920N11TC4@@=1P@471<@12dP6`<n;BH4DS`c16Q>@`B2HE@4
V79S1:R0K`BcRgX3/Xio1:b;OPBVQg/4XHAi19b1MPBGOG<4TgU_0hmeJ`B<LVT4RG1X18E^IPB2KFH4
OfaV0ge/J0AkKV/4N6m^17E`L0AcLG84LG=e171eN0=`N7/4L7]o171nQ0AaPXP4LXF=17B:TP=fSIL4
Mi:L17ZGXPB3X:/4Tjfg1:Fk``Bib]03c=SL1=oVj0Calo<4o?gl1?7cl`COhn<3cm?D1<34a@Ba][L4
XjRY19JKW0B9SXl4O8625Oooo`005?ooo`AUJ6X4FeeM151AD@A6ADD4>cTh0c0/:`@T81h46A<A10d6
10@L4a04;B0K0ch]9PAB?3<4J4i3189QE0BHLV<4Z81_1;>;NP>bSWl4[8]n1:J7N`BQQ7T4W85f19Mm
L`BCNFl3SgE[18abJ@B9L6P4QFiV189]IPAoK6H3OFaX17]^J`AhKfh4MG1`17=aLPAaLgD4L7Eh0g1h
N`A`Ngl4L7j41762R0AbQHd4M8ZB0gJ=U`AgTY`4NYNR18>PZ`BC[KL4YK_31;W:d0?<f=`4gnKX1?7c
l`CloO`4lO?c1=oSh`??dm@4`<C51;6f]`BSZ:T4UY^L18V>S`AlPH8Eoooo000Doooo16EXJPAKGEd4
D55A14I5A@@k>CP3<2`[12@P7P@I4a443@H411`C40@]81/3?RdV158l<`AXCT<4PV5D19QbH`BXP6l4
/h]j0k:>O`B/Rgh4YXMk1:64N@BLPGH4Ugec19=iK`>?MF/4S79Y18U`J0B5KVH4PVeV17m/IP=mK6P4
Nfi[17Q_KPAeL704Lg5b175cM@A`MGP3L7Qk171kO`A`OX@4LH:817:5S@AdRY83MXfG17NBW0AjUj84
Pj2[19>]]`BU^l<4^L[@0lcHg0COi^P4lO?c1?cmo0Calo<4gn?S0loCe0C0a<D4/KJg1:>XZ@BFVi`4
RHj?17b1PQGoool001Coool4IFQY15YLG@A@DE44ADA513Xh>0<^;2/48QlN11HB40@:1@<46Q4>12XN
6@<j:R@4BcP`1659?`AjFdh4T6aM1:=lJ`B^QWH3/8am1:b;OPBWR7`4XHEi19f2M`BHOW@4U7Ya0i1g
K@B=LfX4RW5Y18I_I`B4KfP4PFiX0gi_JPAmL6d4Ng5_17QcLPAfM7@4M7Ig179gNP=bNWd4LWf11760
Q@AbPXT4LXF=17>9TP=dSIH4MY6L17^HXPB8Xjd4Uk2h1:^na@Bmbm43d=[M1>?Xj@Cdm?@4ooon1>k_
k`CNh>03c]7A1;o3``Ba]KD4XjNX19JJV`B9SHl4O8625Oooo`005?ooo`AUJ6T4FUaM151AD@A5A4D4
>SPh0bh/:`@R7ah45Q8@10X50`@J4@h4:QhI0cXZ90A;>304HDTo17YKCPB@K5d4Xga[1:j6MP>`S7d4
[8]n1:N8O0BQQGT4WH9g19QnM0BDNW43T7M]18ecJPB:LFT4QVmW18A_J0B1KVP3OVmZ17e`K@AkLFl4
N7=b17IdM0AdMWL4LWMj0g9jO@AbOH44LH2517:2R@AbQHd4LhVB0gB=UPAfTI`4NiRR18RS[@BG/;P4
Zkk51;g;d@?@f]d4hnSY1?Cdm0Coooh4k^o_1=kPh0?>dM44_l?31;6e]@BSYjP4UYZK18V=S`AlPH8E
oooo000Doooo16EXJ@AJG5d4D55A14E4A@@j>3P3;R`[128O7P@F4Q042PD311XA3P@Z7QT3>RXT14/h
<0AQBCl4NU]>191/G@BSO6/4[XIf0k2<O@B/Rgh4YhQl1:65N@BMPWL4V7id19AjL@>@Mfd4SG=Z18Ya
J@B6KfL4Q6mX185^J0=nKfX4OG1]17]aK`AhLg84MWAd17AfM`AbMgX3LWYm179mP@AaP8D4LX:917:5
S@AcRI83M8fF17JAW0AkV:84R:>]19N`^0B[_/D4_L_A0m3Jg@CSj>T4m?Cd1?oooPC^knl4g^3P0lkA
d@Bo`l<4/KFe1:>WZ0BFVY/4RHf?17b1PQGoool001Coool4IFQY15YLG@A@DE44ADA513Xh>0<^;2/4
8QlN11HB40@:1@<46Q4>12XN6@<j:R@4BcP`1659?`AjFdh4T6aM1:=lJ`B^QWH3/8am1:b;OPBWR7`4
XHEi19f2M`BHOW@4U7Ya0i1gK@B=LfX4RW5Y18I_I`B4KfP4PFiX0gi_JPAmL6d4Ng5_17QcLPAfM7@4
M7Ig179gNP=bNWd4LWf11760Q@AbPXT4LXF=17>9TP=dSIH4MY6L17^HXPB8Xjd4Uk2h1:^na@Bmbm43
d=[M1>?Xj@Cdm?@4ooon1>k_k`CNh>03c]7A1;o3``Ba]KD4XjNX19JJV`B9SHl4O8625Oooo`005?oo
o`AUJ6T4FUaM14m@D@A4A4D4>CPh0bd[:`@Q7Qd4510?10L30P@G3`d49Q`H0cHX8PA6=2d4Fd@k175E
BPB7IUP4VgIV1:R1L@>^RGX4[8]m1:N8O0BRQGX4WH9g19UoM@BENg83TGQ_18ieK0B:LfX4R75Y18E`
JPB3KfX3PG5/17mcK`AmM744NgEd17UfMPAfN7T4MGUl0gAkOPAcOX84Lh2617:3RPAbQXd4LhVB0gF=
UPAiTid4P9^U18jW/0BN/k/4/<771<;>d`?Dg=h4j>[[1?Ofm@CnoO`4jnc[1=_Mg0?<clh4_/711;2c
]0BRYZL4UIVJ18R=SPAlP88Eoooo000Doooo16EXJ@AJG5d4Ce1A14A4A@@i>3P3;B/[124N7@@D40l4
1`<211L?3@@V71P3=RPR14Hd;@AKA3/4LEE:18MVF0BKMVH4Z85a0jj9NPB/Rgd4YhQl1::5NPBMPWL4
VGme19EkLP>AN6l4SWE/18YcJPB8LFT4QG1Z18=_JP>1LF`4Og=_17edL@AkMG@4NGIf17IhN@AeNG`3
M7]n17=nPPAcP8H4LX>:17:6S@AcRI83MHfF17VCW@B0VjD4SZN`19jc^`B``LL4`/kC0mCLgPCXj^/4
moKe1?kmo0C[k>/4fmgL0lc?cPBn`L44/;>d1::VY`BEVIX4R8f>17b0PQGoool001Coool4IFQY15YL
G@A?D544A4A513Th>0<]:b/48AhM11@@3`@70`845`l=12HL60<f:284AS@]15]4>`AaEDX4QfIH19]f
IPBXPG43[XUj1:b;O@BWR7`4XXEj19f2M`BIOgD4UG]b0i5hK`B>MF`4RW=Z18QaJ@B5L6X4PfmZ0h5a
K0AoLfl4OGAa17]eM0AiMWH4MWQi17EiO0=dNgh4Lgj217>0QPAbPhX4LXJ=17>9TP=eSIH4NI>M182K
Y@B>Yk04W[>k1;31a`C2c]<3e=cN1>SZj`Cgm_D4o_gl1>_/j`CKgM`3c<o>1;k1`@B`/k@4XZJW19FI
VPB8SHh4O8225Oooo`005?ooo`AUJ6T4FUaM14m@D@A4A4D4>3Ph0b`[:`@P7Qd44a0?10D10@@C3@X4
8QTF0c4U80A1<BX4Dclf16U@A@AmGe<4TFmQ19mjJ`>ZQGH4ZhYk1:N7N`BRQ7T4WH9g19UoM@BEO783
TWU`18ifKPB;M6/4RG9Z18MbJ`B5LV`3Pg=_189eLPB0Mg@4OWQf17aiN0AiNW/4N7an0gImP0AdP8<4
M86617>4RPAbQhh4LhZB0gJ>U`AlUYl4QYnX19F[/`BU]kh4]LC91<OAe0?Ign04kNg]1?_im`CfmO@4
inOV1=SIf@?:bl/4_;jn1:ja/PBQYJD4U9RI18R<S@AlP84Eoooo000Doooo16EXJ@AJG5d4Ce1A14A4
A@@h>3P3;2/[120N7@@C40l41@4111<=2P@R6AH3<BDP144a:PAC?cH4JE1517eOD`BAKf44WgY[0jZ5
MPB[RW/4YhMk1::4N@BMPWL4VGme19ElLP>BNG04SWI^18]dJ`B9LVX4Qg9[18EbK0>3Lfl4PWEb181g
M0AnN7H4O7Uh17UjN`AhO7h3MWf017B0P`AdPHH4LhB:17:7SPAcRY83MXjG17bFW`B6WjP4UJ^c1:Fg
_PBea<T4am7D0mWOh0C]kNd4noWg1?Kem0CWinH4f=WI0l[;b`Bl_[h4[[6b1:6UY@BDV9T4R8b=17b0
PAGoool001Coool4IFQY15YLG@A?D544A4A513Ph>0</:b/481hM11<@3`@50@444`d:128I5P<a9B04
@C4Z15<o=PAYD4D4OEmC195_H@BONV/3ZXEf1:^:N`BWQg/4XXAi19f2M`BIOgD4UGab0i9iL0B>MVh4
RgA[18UbJPB7LV/4QG9/0h=cK`B2MG84P7Md17ihMPAlNGP4NGYk17QlOP=fOH04M82317B1QPAcQ8X4
LXN>17>:TP=fSYL4O9JO18JOZ0BEZk<4YKNn1;G4b@C7dM@3fMoP1>g]k@CknOL4m_Gd1>OWiPCHfMT3
b/_;1;bn_PB^/K84XJFU19BHV@B8S8d4O8215Oooo`005?ooo`AUJ6T4FUaM14m@D@A4A4D4>3Ph0b`[
:`@P7Qd44a0?10D10@@C3@X48QTF0c4U80A1<BX4Dclf16U@A@AmGe<4TFmQ19mjJ`>ZQGH4ZhYk1:N7
N`BRQ7T4WH9g19UoM@BEO783TWU`18ifKPB;M6/4RG9Z18MbJ`B5LV`3Pg=_189eLPB0Mg@4OWQf17ai
N0AiNW/4N7an0gImP0AdP8<4M86617>4RPAbQhh4LhZB0gJ>U`AlUYl4QYnX19F[/`BU]kh4]LC91<OA
e0?Ign04kNg]1?_im`CfmO@4inOV1=SIf@?:bl/4_;jn1:ja/PBQYJD4U9RI18R<S@AlP84Eoooo000D
oooo16EXJPAJGEh4Ce5B14A5A@@h>3T3;2//120N7P@B4104104110h91`@M5A<3;24L13X/9PA<>S84
H4Y017AICPB5IeT4UG=T0j=oL0BXQWP4YHIi1:64N0BMPGH4VGmd19ElLP>BNG04SgM_18eeK@B:Lf/4
R7=/18MdKP>6MW44QGQe18AjM`B2NgT4Og]j17emO@AkOX03N82217N1Q@AePhP4M8F;17>7SPAdRY83
N92I18:IXPB=Xj/4WJnf1:fk`@Bkal/4cMCF0moRh`Cbl>l4oogk1?3_kPCRh^44e=GD0lO8b0Bi^k/4
[:n_1:2SX`BCUiP4Qh^<17^0PAGoool001Coool4IFQZ15YMGPA?DE84A4E513Ph>@</:b`481hN118@
40@40@443PT711dE4`</8A`4>R`V14`j<PAPBT04M5U>18EWF@BELf@3Xgm`1:R6N0BUQWT4XHAh19f1
MPBIOg@4UGab0i9iL0B?Mfl4SGE]18YcJ`B8Lf`4QgA^0hIfL@B5N7D4Q7Yg189kN@AoNgX4OGem17]n
P0=hP884Mh6517F3R0AdQH/4LhN>17B:TP=hT9T4PYVR18fSZ`BM[kH4[K_11;_7b`C=e=H3gn;S1?;`
k`CooO/4l>o^1>;Rh@CDeM@3alS81;Vk^`B/[jl4X:>S19>GV0B7Rh`4Nh215Oooo`005?ooo`AUJ6X4
FUeN14mADPA4ADD4>3Pi0b`[;0@P7Qh44Q0@10@10@@>2@L47ADC0b`Q70@j;2H4C3Xb161:@0AdFDh4
QFMI19EcI0>SOg04Z8Ih1:F6N@BQQ7P4WH5f19UoM0BEO783TWU`18mgK`B=MFd4RW=[18QcK0B7M6h3
QWIa18EhM@B4NWL4PW]i17mkNPAmOGd4Ngj00gR0PPAgPHD4MH>817B5R`AcQhh4M8ZB0gR@V@B2VJ84
SJ>[19f_]PB]^l44^lO;1<gDeP?Oh^<4l_3_1?omn`C`knh4h^;Q1=CEe0?7b<P4^K^k1:b_[`BPXj<4
TiNH18N;S0AkP84Eoooo000Doooo16EXJPAJGEh4Ce5B14A5A@@h>3T3;2//120N7P@B4104104110h9
1`@M5A<3;24L13X/9PA<>S84H4Y017AICPB5IeT4UG=T0j=oL0BXQWP4YHIi1:64N0BMPGH4VGmd19El
LP>BNG04SgM_18eeK@B:Lf/4R7=/18MdKP>6MW44QGQe18AjM`B2NgT4Og]j17emO@AkOX03N82217N1
Q@AePhP4M8F;17>7SPAdRY83N92I18:IXPB=Xj/4WJnf1:fk`@Bkal/4cMCF0moRh`Cbl>l4oogk1?3_
kPCRh^44e=GD0lO8b0Bi^k/4[:n_1:2SX`BCUiP4Qh^<17^0PAGoool001Coool4IFQZ15YMGPA?DE84
A4E613Pi>P</;2d481lO11<A4@@40P842PH611LA3`<V71T4=2PR14@d;PAG@c/4JU9817YND`B9JUd3
V7IX1:60LPBRPgH4X89f19b1M@BHOW@4UGab0i9jL@B@N6l4SWM^18]dK@B9M6d4RWMa0hUiM0B9NgL4
Qgei18InN`B3OWd4P7mo17j1PP=kPX@4NHB717N4R@AfQX`4MXV@17N<U0=mU9`4R9fU19BW[PBS/kT4
/ko31<;;cPCCemT3i^GU1??ak`Cmn_P4k>_Y1=kMg0C@dM03`lC41;Jh^0BZ[:d4WZ6Q19:EUPB6RX/4
Ngn05Oooo`005?ooo`AUJ6X4FUeN14mADPA4ADH4>3Tj0b`/;@@P7al44a4A10@20P@:1PH45a4?0bHL
6@@d:284A3@^15M3>`AZDTP4NUiC18UZG@>HMVP4XH1b1::3MPBPPWH4W85e19QnM0BEO783TWYa191h
K`B>Mfh4RgA]18UdK@B:Mg43RGUd18UkM`B7OGT4QWik18=nO@B0Ogl4OX620g^2Q0AiQ8L4MhB917J6
S0AfRI04MhbD0gfDW0B8WJD4U:N^1:>c^@Bc_l<4`/_>1=?Gf@?ViND4lo7_1?gjn0C/jnT4g]gL1=3A
d0?3a<@4][Rh1:Z/[@BNXJ44TYFF18J:R`AkOh0Eoooo000Doooo16EXJPAJGEh4Ce5B14A5AP@h>CX3
;2`]120O7`@C4A44108210X61P@G4@l39Q`I13@X8PA4=2h4Ed<k16YBB0AjGU<4RFYM0iQfJ0BQP784
XX=f1:22MPBLPGD4V7id19ElLP>BNW44T7Q_18igKPB;M6d4RGA]18YgL@>9NG@4RG]g18MmN@B6OW/4
Pgim181oO`AnPH83Nh:417V4Q`AgQ8T4MXJ<17J9T0AgS9@3OIBL18RMY@BDYjh4Xk>i1;>o``C2blh4
dmOI0nKUi@CclNl4oO[h1>c[j@CNgM`4d=7@0l?4a0Bf^;P4ZZb]19jQX@BBUIH4QXZ;17]oP1Goool0
01Coool4IFQZ15YMGPA?DE84A4E613Pi>P</;2d481lO11<A4@@40P842PH611LA3`<V71T4=2PR14@d
;PAG@c/4JU9817YND`B9JUd3V7IX1:60LPBRPgH4X89f19b1M@BHOW@4UGab0i9jL@B@N6l4SWM^18]d
K@B9M6d4RWMa0hUiM0B9NgL4Qgei18InN`B3OWd4P7mo17j1PP=kPX@4NHB717N4R@AfQX`4MXV@17N<
U0=mU9`4R9fU19BW[PBS/kT4/ko31<;;cPCCemT3i^GU1??ak`Cmn_P4k>_Y1=kMg0C@dM03`lC41;Jh
^0BZ[:d4WZ6Q19:EUPB6RX/4Ngn05Oooo`005?ooo`AUJFX4FUeO151BD`A5ATL4>CXk0bd^;P@Q8B44
51<C10D410@50`844@d;0alH5@@^8al4>bhY14dl=@APBd84KUI<17aQEP>9K5l4UWMY19]kK`BLOW84
VWmc19IlLPBDO783TWYa191iL0B>N6l4RgI^18YfK`B=NG<3SWaf18enN@B;P7`4RH1m18J2P0B3PX44
PH>40gj4QPAlQHP4NHN;17R8S@AjS984O92G0h>HW`B>XJP4Vj^a1:Zg^`Bi`/D4b<k@1=WKf`?[j>H4
mo;`1?Cak`CVi><4fMSG1<c<b`>o`<04/kFe1:NZZPBLWil4TIBE18F9RPAjOh0Eoooo000Doooo16EY
JPAJGEl4D59C14E6A`@i>S/3;Bh^124Q8@@D4a<41@@410D30P@A3@/37aPE12hS7`@k;RT4CC`e161;
@PA^ET`4O65F0hU/G`BFMfT4Vg]_19anLPBJOg<4UWab19AlLP>BNW44T7U`18ihK`B;MVh4RWI_18ei
L`>>O7H4SGii18^0O0B9P7d4QX:018>2P@B1Ph@3OXB617b5R0AiQh/4N8R=17Z<TPAlT9L3PiRO18jQ
Z0BKZk44Z[Nk1;W2a@C8c]04fM_K0n_XiPCgl_04m?7_1>KTh`CIf=L4c<c;0ko0`0Bc]KD4YjZZ19bO
W`BAU9D4QHV:17YoP1Goool001Coool4IFUZ15YMG`A@DU<4ADI713Tj>`<];Rh48B4Q11@C4`@510@4
1@<2114=2`<O61D4;R<O13/^:@A=?3D4H4]216iFC0AlHEH3RFaO19IgJ@BKNfl4W7ib19YoL`BFO784
U7ab0i9jL@B@NG04SWQ_18]fKPB:MVl4SGUc0hilMPB=OWT4Rh1l18V0O@B6PX04Ph:11863Q0=nQ8H4
O8F817V7R`AhR8d4NXbB17b@U`>3V9l4SZ6X19^[/@BZ]k/4^L;51<S>d0CIfm/3jnSV1?Obl0CdlNl4
i^CS1=WHe`C<c</3_l301;>e]@BWZZX4W9nO196DU@B5RHX4NWn05Oooo`005?ooo`AUJFX4FUeO151B
D`A5ATL4>CXk0bd^;P@Q8B4451<C10D410@50`844@d;0alH5@@^8al4>bhY14dl=@APBd84KUI<17aQ
EP>9K5l4UWMY19]kK`BLOW84VWmc19IlLPBDO783TWYa191iL0B>N6l4RgI^18YfK`B=NG<3SWaf18en
N@B;P7`4RH1m18J2P0B3PX44PH>40gj4QPAlQHP4NHN;17R8S@AjS984O92G0h>HW`B>XJP4Vj^a1:Zg
^`Bi`/D4b<k@1=WKf`?[j>H4mo;`1?Cak`CVi><4fMSG1<c<b`>o`<04/kFe1:NZZPBLWil4TIBE18F9
RPAjOh0Eoooo000Doooo16EYJPAKGUl4D5=D14I8B@@j?3d3;c0a12<S90@F5QL42@T9100000@;20P3
6A@B12LO70@d:BD4A3H`15M5?@ASCdL4LEY@0gYQE`B6Jf04SW9V19=fJPBCNFh4TGU_1i5iL0B@NW44
SWQ`18]fK`B;Mg04SWYc0i5nN0BAPG`4Sh=n18f3O`B:Q884QhB318F6QP>2QhP4OhR:17f9S0AlRXl4
OXnD18:EVP>;W:84UJF[1::_]0B`^[h4_lG71<kAdPCNgM`3k>WV1?WdlPC/jNL4gmkL1=?Bd@C7alH3
^kbl1;2a/@BUYjL4VYbM18nBT`B4R8T4NWio5Oooo`005?ooo`AUJFX4FeiO151CE0A6B4T4>S`m0bl`
<@@S8b@45QHG10T92@@000042`P80aTD4P@W7a`4=2TU14@f<0AGACd4Hdm7175JD0=jHEL4QV]P18ib
IPBCMVX4TgU^195iK`NANG04T7Ya18ihL0B;MVl4RgM`18ijL`>AOWP4TH5l18n3OPB=Pgl4RXB218N4
P`B5QXH3PXN817n8RPAmRH`4O8Z?17j?U0B2UIX3RibR19FUZ`BR[k@4/;Zn1;o5a`C>dM84g]gL0ncY
iPCim?84k>WW1=oNg0CCd]44alO60k^l_0B`/K44YJNW19ZLW@B?TY<4Q8R917YnOaGoool001Coool4
IFUZ15]NG`A@De@4ATQ913Xl?@<_<3448b<T11HF5`@92@T4000010/820<I51849alL13@Y9@A4=S04
EdDm16=?A`AaFU03NV5G18I[H0B>LVH4TgIZ19=iKPBANFl7TGU`191jL@B>N704RgI_18]gL0B>NW<3
TGih1961O0B?Pgh4SH=o18Z4PPB7Q8<4QHJ60h:7R0AoR8X4OHV<17b:S`AnSi@4PYFJ0h^LXPBEYJ/4
XZnd1;2j_PBoaLL4c]7B1=kMg0?/jNH4nOCb1>cYi`COg]`4dm;A1<O7aP>k_;`4/;6a1:FWY`BJW9d4
Si:C18B8R@AjOWlEoooo000Doooo16EYJPAKGUl4D5=D14I8B@@j?3d3;c0a12<S90@F5QL42@T91000
00@;20P36A@B12LO70@d:BD4A3H`15M5?@ASCdL4LEY@0gYQE`B6Jf04SW9V19=fJPBCNFh4TGU_1i5i
L0B@NW44SWQ`18]fK`B;Mg04SWYc0i5nN0BAPG`4Sh=n18f3O`B:Q884QhB318F6QP>2QhP4OhR:17f9
S0AlRXl4OXnD18:EVP>;W:84UJF[1::_]0B`^[h4_lG71<kAdPCNgM`3k>WV1?WdlPC/jNL4gmkL1=?B
d@C7alH3^kbl1;2a/@BUYjL4VYbM18nBT`B4R8T4NWio5Oooo`005?ooo`AUJF/4FemP155DE@A7BDX4
?3ho0c4b<`@V9RL46QXK10d=3P@0004410<30a<?3P@P6QL4;B@Q13/`:`A=?SL4FTU116EAB@=^FE04
Mf5G181XGPB5K684QfmV18MbJ@B9Lf/3S7E]18egK`B;Mg04RGI_18]hL0B=NW<3T7ig19:1O0BBQ7l4
T8F118b5P`B:QXD4R8N70hJ9RPB3RX`4PX^>186>TPB5TiL4RIRM0i:PY@BLZJd4Z;>f1;Jn`0C4bLX4
dmCC1>3Ng@?^jNH4l^k[1>CQg`CHemD4cLc;1<72`@>g^;L4[:j^1::TY0BGVY/4SI2A18>7R0AiOGlE
oooo000Doooo16EYJ`AKGf04DEAE14M9BP@l?Sl3<C8c12HV9`@J6Q/43@d>10000@@40`<34`l>120J
5`@]9244>c0[14dn=`AJBD44IE590fiID0AgHEL4P6QN18E/HPB7KfH4Qg9Y18UcJ`><MFd4SGM_18]g
L0B9MVl4RgQ`18ejL`>@OWL4TX5l19:4O`B@QH44S8F318Z6Q@B8QhL3QXV:18>:S0B2Rhh4PHjB18FC
U`B9V9d3TZ2U19bY[@BX/kH4][k01<C9bPCCe=<4h=kM0nkYiPCbk^/4i>7O1=SGe@C=c</4`L;10kNh
]`B/[Zh4XZBT19NJV`B=T944PhN817UmOaGoool001Coool4IFU[15]OH0AAE5D4AdU:13`n?`<a<S<4
9RHW11XJ6`@=3@h4000110@30`<C3`h481XG12dT8@@k<2/4CChg15Y9@@AUDDT3KUU@17MQE`B0J5h4
QFaR18M_IPB7LVT4RG=[0haeK@B=Mfl4RgM`18UfK`B;N704SGYc0i1nM`BBPG`4TXAo1925P@B<QH<4
RXJ518R7Q`>6RHX4PhZ<18:;SPB1SY84QI>G18VHW@>BX:D4W:V]1:Rc]PBf_/04a<W:1=?Dd`CPg]d3
k^WV1?;^j`CThMl4f=OE1<g<b`C1`/43]kRg1:b^[PBRY:@4UiZK18f@T@B3QhP4NGeo5Oooo`005?oo
o`AVJV/4G61Q159EE`A8Bd`4?T110c@e=P@Y:R/47AhO114B4`@41@L400000``;2P@I5Q@49R0M13<Z
9`A3=c84D48l15Y:@`=SDDX4K5UA17AOE`AhI5`4NVMP17eZH`B0KFD3Q71Y18EbJ`B7MFh4QWE^18Qf
L0B;NG83SWeg1920N`BBQ7h4T8J118j6P`B=R8D4RhR80hZ;R`B8S8d4Qhj@18NAU0B;UiX4TIbP0iZT
Z0BS[K04[kJh1;c1`PC:c<`4emKD1>7Og@?/inD4i^?P1=_Ie`C@clh4a/K51;bl_0>b/k<4Z:ZZ19jQ
X@BEV9P4Rhn?18:6Q`AiOGhEoooo000Doooo16IZJ`ALH644DUEG14Q;C0@n@443=3Df12TZ:`@M7Ql4
4A8C10@51`@0000330/:11TF50@V81d4<bXW14<g<PA@@S`4FTY30f=ABPA/FE44M5mG17QTG0AjIf04
OFYS181]I@>4L6T4QG9[18MeKPB6MFh4R7I`18]iLP>>OGL4T81k19:4OPB@QX44SXJ318f8Q@B;R8P3
RX^;18R<S@B7SY04Qi6D18^GVPBAW:03VZBX1:>]/0B_][P4_<721<[<c0CGe]@4hMoM0ncWi@CVhn04
fmWG1=3?cPC6a/D4_;bl0k:c/`BXZZX4WZ6Q19FHV0B;Shl4PXJ717UmOQGoool001Coool4IVY[15aP
H@ABEEL4B4]<13i0@@<d=CH4:BX[11dN7`@A4Q<410D7100000<<2`X46AHD12HP7@@c:RL4@cLb1512
?0AJBT<3He5:16aID@AdGeL4N6AL17YWH0AmJV<4P6eU0hA`J@B5LV/4QgE^18IeKPB8MW04RgUb0him
M`B@P7/4TXAn1926P@B>QX<4SHR518^8R0>:Rh/4R8b=18N>T0B7TI@4RiNJ196LX0>JY:P4Xjf`1:nf
^0Bl`L84b/c<1=OFe0CQgmd3k>OU1>KSh0CKfML4d<o>1<K6a@Bl_;`3/[>c1:RZZPBNXJ44UIRH18^?
S`B2QXL4NGen5Oooo`005?ooo`AVJV/4G61Q159EE`A8Bd`4?T110c@e=P@Y:R/47AhO114B4`@41@L4
00000``;2P@I5Q@49R0M13<Z9`A3=c84D48l15Y:@`=SDDX4K5UA17AOE`AhI5`4NVMP17eZH`B0KFD3
Q71Y18EbJ`B7MFh4QWE^18QfL0B;NG83SWeg1920N`BBQ7h4T8J118j6P`B=R8D4RhR80hZ;R`B8S8d4
Qhj@18NAU0B;UiX4TIbP0iZTZ0BS[K04[kJh1;c1`PC:c<`4emKD1>7Og@?/inD4i^?P1=_Ie`C@clh4
a/K51;bl_0>b/k<4Z:ZZ19jQX@BEV9P4Rhn?18:6Q`AiOGhEoooo000Doooo16IZK0AMHF84E5MH14Y=
CPA0@d@3=STj12`^;`@Q8b@45QLI10X;3@@00@831@H611<A4@@P71X4;2HT13Xa;PA5>SH4D4<n0eM9
A0AQDD/4J5M@16aLE@A_H5X4LfAN17IWH@=kJfD4NfaV181aJPB1LV`4PgA^18EgL@>9NgD4S7ii18j2
O@B>Q804S8F218b7Q@B;RHP3Rh^;18V=SPB:T984S9BF196IW0BGWj83X:RZ1:V`/PBe^[/4`/C41=3?
cPCHe]D4h^3M0n?Og@CJf=H4d]3?1<W8a`Bo_kh4][Nf0jf^[PBTYZH4VifN19:EUPB9SHh4PHB617Ql
OQGoool001Coool4IVY/15eQHPADEeP4BTe>1413A0<f>CX4;2h_124S90@F5aT42P/=10010P<51PH4
4a4A120L6P@/9R@4>S4^14Dj=PA@@ch3EdU4165AB`AXEe04K5aE16mPFPAcI5h4MVMQ0g][I@AkK6H4
P75Z185bK0B3M6h4QGMa0hUkM@B<OWT4SX9m18j4P0B<QH84S8N518^9R0>;Rh/4RHf>18Z@TPB<U9H4
TIVL19NOXP>PZ:X4ZK2b1;Fj^`C2a<@4d<o>1=SFe@CRh=d3hmoM1=[HePCBd<l4bLS71;no_PBf]kH3
[Jj^1:BVYPBKWIh4TYFF18V=SPB1Q8H4N7an5Oooo`005?ooo`AVJV`4GF5R15AGF0A:CDh4@4=40cHi
>P@/;Rl48B<T11HG6@@:2`d400420`D61P@C4A4481`J12`V90@j<Bh4ACXf1513?P=GBD@4HE5;16QG
D0A/G5D4Kf1J17=TGPAfIf43Nf]U17]/IPB0LFX4PG9/18=dKPB5Mg43RG]e18anN@B>PWd4SXB018b5
PPB<QhD4RhV80h^;R`B9SHh4RY2B18bDUPBAVI`4UinR0j2XZPBY/;84]KZk1<;4a0C@clh4f=KE1>;P
g@?Sgmd4f]SF1=;@c`C9b<L4_knn1;Jg]P>][Zh4Y:JV19^MWPBBUIH4RHf>1864QPAhO7hEoooo000D
oooo16IZK0AMHF84E5MH14Y=CPA0@d@3=STj12`^;`@Q8b@45QLI10X;3@@00@831@H611<A4@@P71X4
;2HT13Xa;PA5>SH4D4<n0eM9A0AQDD/4J5M@16aLE@A_H5X4LfAN17IWH@=kJfD4NfaV181aJPB1LV`4
PgA^18EgL@>9NgD4S7ii18j2O@B>Q804S8F218b7Q@B;RHP3Rh^;18V=SPB:T984S9BF196IW0BGWj83
X:RZ1:V`/PBe^[/4`/C41=3?cPCHe]D4h^3M0n?Og@CJf=H4d]3?1<W8a`Bo_kh4][Nf0jf^[PBTYZH4
VifN19:EUPB9SHh4PHB617QlOQGoool001Coool4If]/15iRH`AEFEX4C4mA14=6A`<j?3h4<38d12HX
:@@K7Al4418D10D620<10`@43@h>11XH5`@U8R04<R`Z13dd<@A6?CT3C48n15I9A@AND4/4HEE@16IJ
E@AZGUX4KV5M0gAVH@AdJ6<4NFaW17]^JPAnLV`4PGE`0hAhL`B8O7P4RWmk18^2OPB:Q844RXJ418^9
Q`><Rh/4RXf>18fATPB@UYL4UYbN19bRY0>UZZ`4[k>d1;^m_@C7alH4d]3?1=_Ie`CMf]P3emGC1=3>
c@C9b<H4`L2o1;Vi^0B`/K43Z:VY1:2RXPBHVY/4T9:C18R;S0AoPh@4Mgam5Oooo`005?ooo`AWJf`4
GV9S15EIFPA<Ce44@dI70cXl?P@`<S@49RPY11/M7`@@4Q@41@H80`4310@=3Ph46QPG12DR80@b;2X4
?C@a14Hm>@=<@Sh4ETU515i@B`AQEE04IUYE16YNFPA^HEd3M6IQ17AXH`AiK6L4NfiZ17ibK0B1MG03
Q7Qc18QlN0B:Og/4Rh9n18Z4P@B:QX@4RhV70hb;R`B:SHh4SI6B192FU`BFW9h4W::T0jFZ[0B_/k@4
^kfm1<O7aPCBd<l4fmWG1=gJf0?GeM<4d<k=1<W8aPC1`;l4^KVh1;2a/@>XZJT4X::R19RJV`B@TY<4
R8^<17n3Q0AgO7dEoooo000Doooo16M[K0ANHV<4EEUJ14a?D@A3ATL3>S`n130b=0@V:2T46adO110B
50@51PP30@<410d>3P@J61L49B8P138/:P@m=344ASdi0da2?PAFBDD4GU1;165ED0AVFUD4JUiJ16iQ
G@=dIV44M6QS17U/I`AkKVX4OW9/185eL0>4N7<4R7ah18YoN`B;PWh4RXB118Z6Q0B;RHL3S8^;18Z=
SPB=TI84T9JG19JLWPBLXZ@3YJZ/1:nc]0Bk_Kd4alO61=;@c`CKfML4gM[H0mOEd`C@c/d4bLS61<70
_`Bi^KP4/;6a0jRYZ@BPXZ84V9ZK192BT`B8Rh`4Oh>417MlOAGoool001Coool4If]/15iRH`AEFEX4
C4mA14=6A`<j?3h4<38d12HX:@@K7Al4418D10D620<10`@43@h>11XH5`@U8R04<R`Z13dd<@A6?CT3
C48n15I9A@AND4/4HEE@16IJE@AZGUX4KV5M0gAVH@AdJ6<4NFaW17]^JPAnLV`4PGE`0hAhL`B8O7P4
RWmk18^2OPB:Q844RXJ418^9Q`><Rh/4RXf>18fATPB@UYL4UYbN19bRY0>UZZ`4[k>d1;^m_@C7alH4
d]3?1=_Ie`CMf]P3emGC1=3>c@C9b<H4`L2o1;Vi^0B`/K43Z:VY1:2RXPBHVY/4T9:C18R;S0AoPh@4
Mgam5Oooo`005?ooo`AWK6d4Gf=U15MKG0A?DU<4ATU:0ce0@@@d=cP4:bd_124S9@@G6AX430d?0`84
1@@92``451@D11lM7@@Z9bD4=C0^13hg=0=3?3T4Bd8o15=9APAGCT/4GUEB169HEPAVGEX3Jf5M16iT
H@AbJ6@4MF]X17U_J`AlLfh3OgIb18AjMPB6OGT4Qh1m18N2O`B8QH<4RHN60hZ:R@B:SHd4SY6B19BH
V0BJWYl4XJBU0jZ/[@Bd]KD4_knn1<_9b0CFdm84f=KD1=;@c`?=blX4alK51<30_`Bi^KP4/[:b1:^/
Z`>SYJD4W9jN19BGU`B=T944QHV:17j2P`AgNg`Eoooo000Doooo16M/K@AOHfD4Ee]L14mBD`A6BDX3
?D1113@g>0@[;Bl48B<U11LI6P@<3@l30P@510T;30@D51@47adM12XW9@@e<2h4?SLd0d<l>@A;@Sl4
DdU615M>B`ANEE84HUQF16IMFP=[HEd4KVAQ179XI0AeJfP4NFm[17acKP=oMW84Q7Yf18ImN@B7P7d4
Qh9o18R5P`B9QhH3RXZ918Z=S@B>TI84U9RH19ZNW`BQY:D3ZZb]1;Be]@Bo_kh4blW81=KCdPCHe]@4
d]3?0lg;bPC7a/D4`<2o1;Vi^0Bb/[84Zjb[0j>UY@BLWYh4U9NG18f@T@B5RHX4OX:317MkO1Goool0
01Coool4Ifa]15mSI@AGFe`4Ce9C14I9BP<m@444=3Lh12/];`@Q8bD45aTJ10`=3`<210D42@/<11@D
50@O7Ad4:RLU13D`;P@n=c@3@c`i14]2?`ACBDH4Edi;15iEDPARF5H4IUeJ0f]QG@A^I644LVQT17E[
J0AiKf/4O7=^0gmfLPB4NWH4QWei18N0O@B7PWl4R8F318V7QP>:RXT4RXf=18jATPBDV9P4VYjO1:6T
Y@>Z[:d4];Fe1;no_PC;bLP4e]?B1=SFe0CBd<l3cL_:1<O6a@C0`;l4^KVh1;:b/PB[[:/3XjFU19bN
WPBDUiL4SI2A18F9RPAnPX<4Mg]l5Oooo`005?ooo`AWK6d4Gf=U15MKG0A?DU<4ATU:0ce0@@@d=cP4
:bd_124S9@@G6AX430d?0`841@@92``451@D11lM7@@Z9bD4=C0^13hg=0=3?3T4Bd8o15=9APAGCT/4
GUEB169HEPAVGEX3Jf5M16iTH@AbJ6@4MF]X17U_J`AlLfh3OgIb18AjMPB6OGT4Qh1m18N2O`B8QH<4
RHN60hZ:R@B:SHd4SY6B19BHV0BJWYl4XJBU0jZ/[@Bd]KD4_knn1<_9b0CFdm84f=KD1=;@c`?=blX4
alK51<30_`Bi^KP4/[:b1:^/Z`>SYJD4W9jN19BGU`B=T944QHV:17j2P`AgNg`Eoooo000Doooo16Q/
KPAPI6H4FEeN155EEPA9C4h3@DA613Tl?@@`<c@49bX[11hP8P@D5QP32@`=10H92P@>41446ATJ12<S
8P@]:bX4=S8a0c/f=@A1?3/4B4=114e8A`AFCdd4FUAB15mHEP=SG5X4J65O16]THPA_J6D4LfaY17Q`
K@=kM704OgQe189kN0B5Og`4Ph1n18J4P@B7QX@3QhR718V;R`B>TI44UINH19bNW`BSYJH3[Jj]1;Nf
]@C0_kh4blW71=CCdPC>cL/4bLS60l?3`PBn_Kd4^;Rg1;:b/PB[[:`4YJJV0ijPX0BGVYX4TI>D18Z=
SPB3QhP4OH6217IjO1Goool001Coool4J6a^161TIPAIGEh4DEEF14U<CP=1A4H4>C`m130c=0@W:R/4
7R0R11@F60<930d41PT:10h@4@@I6AX48b<R12d[:P@f<S43>cHe144l>`A8@d44CDQ715I?C@AJE584
GeQF0f=LFPAXHEl4JfAR16mXI@AcK6T4N71]0g]dL0AoN7D4PW]h18EoO0B3P7h4QXB118N6Q0>7R8L4
RH^;18jAT@BEUiP4W9jO1:>UYP>][Zd4]kJe1<2o_PC;bLL4e=?B1<k=b`C9b<H3`l?21;jm_@Bh^;L4
/[:b1:^/[0BUYZH3WZ2P19NJVPBATi@4RXf>18>7R0AmPH84MWYl5Oooo`005?ooo`AXK6h4H6AV15UM
GPAAEEH4BDa>0d54AP@i?3d4<3<d12LZ:`@N828451HH0`T<3@@62@X43Q0A11TI6P@S8b84;B/Z13Hb
<@<k=SD4@C`k14Q3@@A=B4L4ETm=15YDDPAOF5H3HeaJ16QQG`A[I684KfQU17=/J@AhL6d3NgA`17mh
M@B2NgP4QGml18>0OPB6Q844QhJ40hN8Q`B9Rh/4SY6A19FGV0BLWYl4XjFV0jf^[@Bg][D4`;nn1<_9
a`CDdm84c/g;1<W8aP?3`l84_[fm1;Rh]`Bb/[84Zjb/1:FVYP>NX:04UiZJ196CU0B:SHh4PhN817f1
PPAfNW`Eoooo000Doooo16U]KPARIVL4FemP15AGF@A=D583ADQ:13i1@P@f>C/4;S4b12DX:P@M8283
51LI10/?4@@93@l44QDG11dN7`@X9bP4<2h^0cDc<`@j>3L4@Chn14E3@`A<BTT4Ddm>15QDD`=LF5L4
HEeL16EQH0AYIF<4KVUW17=^J`=gLFl4NgIc17mjM`B2OW/4PX1n18>1O`B3PX43Q8J518R:RPB=T904
U9JF19fNWPBVYZH3[Jf]1;Rf]@C2`;h4b/S61<W9a`C4`l84_knn0kZj^@Be]KD4/;6`1:Z[Z`BUYZH4
Wj6Q0iVKW0BCUYH4SI2A18N;R`B1QHH4Ngn017EjNaGoool001Coool4JFe^169VI`AKGf04E5MI14e@
DP=5B4X4?T5213Hi>`@^<C849BPZ11dP8P<D5aT42`lA10T=3`@B5AL47AhO12PW:0@`;Rh3=C<c13Xh
=`A1?Sh4AD=314a:B@ACCdh4F5AC0eaHE`AQGE`4IF5P16UUH`A^JFL4Lfi[0gMaK`AkMW<4OgYg189n
N`B2P7h4Ph5o18>2P@>4QXD4R8Z:18f@T0BDUYH4WIjN1:JVYP>][Jd4^;Je1<;0_PC:b<H4bLW71<C3
`PBo_kh3^[Zi1;Fe]@B`/K04ZZ^[1:FVYPBOXJ43VI^L19>FUPB=T944Qh^;1865QPAkOh04MGYk5Ooo
o`005?ooo`AYKFh4HVIW15]OH0ADEeT4CE1B0dE8BP@n@D84=STk12ha<P@U:2X47B0R0a@G6@@;3a44
2@d?118E5`@M7Ql4:2LX130^;P<e<c<4>SPg144n?PA5@d<4C4Y915=?CPAHE5<3G5QG165MG0AUHF04
JFES16iYI`AcKV/3Mg5_17]fL`AoNWL4PWik18:0OPB3PGl4Ph:10hB6Q@B8RXX4SI2@19BFUPBMWYh4
YZJV0jf][@Bh][D4`/2n1<[8aPC9bLL4a<?21;no_P>j^[T4]KFe1;2a/0BZZj/4YJJV19nQX@>IVi`4
TiJF18f@T@B7Rh/4PHF617]oP0AeNW/Eoooo000Doooo16U]KPARIVL4FemP15AGF@A=D583ADQ:13i1
@P@f>C/4;S4b12DX:P@M828351LI10/?4@@93@l44QDG11dN7`@X9bP4<2h^0cDc<`@j>3L4@Chn14E3
@`A<BTT4Ddm>15QDD`=LF5L4HEeL16EQH0AYIF<4KVUW17=^J`=gLFl4NgIc17mjM`B2OW/4PX1n18>1
O`B3PX43Q8J518R:RPB=T904U9JF19fNWPBVYZH3[Jf]1;Rf]@C2`;h4b/S61<W9a`C4`l84_knn0kZj
^@Be]KD4/;6`1:Z[Z`BUYZH4Wj6Q0iVKW0BCUYH4SI2A18N;R`B1QHH4Ngn017EjNaGoool001Coool4
JFi_16=WJ@AMHF84EeYL151DE@=:CDl4@dI813`o@@@e>3X4;C4b12HY:`<O8R@45a/M110C5@@>4Q@4
5a/L128T9@@[;2d3<S8c13Df=P@j>S/4?Sm114E5APA<C4`4DE1A0eMFE@AKFUX4GeeM16ARH@AYIVD4
KV]Y0g=_K@AgLg44O7Qf181mN`B2Ogh4Ph5o1821P0>1Ph<4QhV918b>SPBCUID4WIjM1:NVY@>^[Jd4
][Bc1<2n_@C1`L04_Kfl1;Zj^@Be][D3/K:a1:f^[@BXZJT4XjFU19nPX0BIW9`3U9NG18nBTPB:SHh4
QHR917n3Q0AjOWl4MGUj5Oooo`005?ooo`AYKVl4HfMY15eQHPAGFU`4D5AE0dY=C`A3ATP4?3m113Dh
>P@]<C849RT[0alR90@G6ad441<E10hB50@G6a`48R@U12//;@<b<S<4=CHf13Xj>`@n?d44ADE614a<
C0AAD543EeIE15]JFPAOGEd4I69Q16UVI@A^JfT3Lfm]17McL@AlN7H4P7ek189oOPB3PGl4P8600h63
P`B7RHT4S8j>19>EU@BMWYd4YjJU0jj][@Bf];<4`;jm1<71`0Bm_K`4^[Zi1;Ff]@>a/[44[Jj]1:RY
Z@BSYJD4Wj2P19VLW0>DUiL4Si:B18Z=SPB5R8T4Oh>417YnO`AeNGXEoooo000Doooo16U^K`ASIfT4
GF5R15MJG0A@E5D3BTe?14=6B0@l?d44=CPj12da<P@V:B/37b8T11LK7@@@4aD43Q8D11LK70@R92D4
:b`]0c8b<`@e=SH4>SXk13ho@@A5ADH4C4a<155@D@=GEUD4FeYJ15mMG@ATHV44JFIU16i[J@=cKfd4
Mg=a17ahMPB0OG/4PWmn18>1O`B0PH03PH>318N9R@B<SXh4TiFE19fNW@BWYZD3[Zf]1;Jd/`C0_[d4
`L701;fm_0Bj^[T4]KJe0k6b/@B][Zd4Z:VY1:>UY@BOX:04VIbL0iBGU`B?TY84RXf>18F8R@AoPh@4
NWio17EiNQGoool001Coool4JFi_16=WJ@AMHF84EeYL151DE@=:CDl4@dI813`o@@@e>3X4;C4b12HY
:`<O8R@45a/M110C5@@>4Q@45a/L128T9@@[;2d3<S8c13Df=P@j>S/4?Sm114E5APA<C4`4DE1A0eMF
E@AKFUX4GeeM16ARH@AYIVD4KV]Y0g=_K@AgLg44O7Qf181mN`B2Ogh4Ph5o1821P0>1Ph<4QhV918b>
SPBCUID4WIjM1:NVY@>^[Jd4][Bc1<2n_@C1`L04_Kfl1;Zj^@Be][D3/K:a1:f^[@BXZJT4XjFU19nP
X0BIW9`3U9NG18nBTPB:SHh4QHR917n3Q0AjOWl4MGUj5Oooo`005?ooo`AZKW04IFUZ15mSI@AIGEl4
E5QI0diBD`A8C4d4@TE713`o@@@f>C/4;c<d0bT/;P@R9RP4720R21DI6`@M8R@49RX/0c0a<`@d=SL4
=cTk13Xm?`A1@dD4AdU:14a=CP=ADU<4EEMH15YJF`AOGel4IFAT16YXI`=_KF`4LW5_17QeM0AmNgT4
P7il1860OPAoP803PhB318R9R@B<SXh4TiFD19fMW0BUYJ@3[Zf/1;Bc/PBh^;L4]KJe1;>c/`B_/;04
[:f]0jRZZ@BUYZH4XJ:R19fNW`BHVY/4U9JG0i2BT`B;SXl4QhZ;18:5QPAmPH84NGen17AhNQGoool0
01Coool4JVi`16EYJPAOHfD4FEeO15AHF@=>DU<4B4a=1495A`@l?d44=STk12lc=0<Y;2h48RHX11`P
8PPE6A/47B8T12HZ;0<`<C<4=3Hg13Li>`@j?Cl4@D=514M9BPA<CDh3DE9C15EGF0AJFU/4GemO16ET
I0AZJ6L3Kfe/179aK`AhMG@4OG]i181nO0B1P7h4Oh200h>4P`B8RHT4S8j>19>EU0BMWI`4YJFT0jj]
[0Bd/k84^;Rg1;Ff]@Bc/k<4[k2`1:b][@>XZZT4YJJV1:6RXPBMWYl4V9ZK19BFU`>@TY<4Rhj?18N:
R`B2QHH4OH6217UmOPAdN7XEoooo000Doooo16Y^L0AUJFX4Gf=U15UMG`ADF5T3CU9C14Q<C@A2ADL4
?3m113Hi>`@_<c@3:B`^128V:0@L82885ATK11dR90@V:R`3<34c13@f=`@g>C/4>Sdo1453A@A7BDX4
C4e>0e5BD`AEEeP4FUYK15mOG`AUI6@4JVQW0fm]K0AbLFl4N7Ed17ekN@B0OW`4PH1n17n0P0>3Q8<4
R8V918b>SPBCUI@4WIfL1:FUY0>^[J`4];>b1;Rh]`Be][D4/k>c1:n`/0B/[Jd3Z:ZY1:FVYPBQXZ84
WIjO19RJV`BDUYL3T9:C18^>S`B7RX/4PXF617f1PPAiOGh4M7Qj5Oooo`005?ooo`AZKW04IFUZ15mS
I@AIGEl4E5QI0diBD`A8C4d4@TE713`o@@@f>C/4;c<d0bT/;P@R9RP4720R21DI6`@M8R@49RX/0c0a
<`@d=SL4=cTk13Xm?`A1@dD4AdU:14a=CP=ADU<4EEMH15YJF`AOGel4IFAT16YXI`=_KF`4LW5_17Qe
M0AmNgT4P7il1860OPAoP803PhB318R9R@B<SXh4TiFD19fMW0BUYJ@3[Zf/1;Bc/PBh^;L4]KJe1;>c
/`B_/;04[:f]0jRZZ@BUYZH4XJ:R19fNW`BHVY/4U9JG0i2BT`B;SXl4QhZ;18:5QPAmPH84NGen17Ah
NQGoool001Coool4Jfma16IZK0AQIFL4G61R15QKG@=CEUP4CE5C14Q<CPA3AdP4?T5313Pl?P<c=cT4
;C4c12P/;P@R9RT4720R11`Q90@T:B/3;S8d13@g>@@h>cd4>Si013m3A@A6BD/4BTe>0diADPAAE5H4
EEQI15]MGPAQHF84IFIV0f][JPA^KVd4M7=a17IfM@AnO7X4OGal17anO@>0PX84Q8N718Z<S0BBTi<4
VIZJ1:BSXP>[ZZX4[:b]1:b][0BZZj/4Z:VY1:JWY`BSY:@3X::R19fOW`BIVi`4UYRH19:EU@B?TI83
Rhj>18N:R`B3QXL4Oh>417]oP0AgNgd4LgQi5Oooo`005?ooo`A[Kg44IVY/165UI`ALH684F5]M0e=F
F0A=DE<4B4a>14=7B0@n@D<4>3`n0c<g>@@]<C<4:2`^128V:@@L8284724T12@Y:`<^<S@4=3Li13Pk
?@@j?T04?d=514I9B`A:CDh3CU5B155DEPAEF5T4FeeN165QHPAUIVH3Jf]Z16i^K@AdLg44MWIe17il
NPAmO7`4O7im0h22PPB4QhL4RXb<19:CT`BIVYX4Y:>R0j^ZZPB/[:d4[:f/1:Z[Z`BXZJT4YZNW1:>T
Y0>PXZ84WInO19VKW0BFV9P4TYFE18nATP>;SXh4QhZ;18>6Q`AoPh@4Ngn017MkO@AcN7TEoooo000D
oooo16]_L@AVJV`4HFEW15aPHPAHFed3DeIH14eAD`A8C4h4@dM813i1@`@h?3h3<cLi12da<`@X;2h4
8RHY11`P8P@L8B@492T[0bhb=0@d=cT4>3/m13Xn@0@o@dD4ATU;14Y=CP=>DE84DEAF15EHF@AKGEh4
HF5R16EVIP=[JfX4KVi]17AcL@AfMWD4OWaj17elO0AlOWd3P8:218B7Q`B:S8`4TY>C19VJVPBTXj83
ZjZZ1:b/[@B/[J`4ZZ^[1:RYZ@BVYjL4XjBT0j2RXPBMWil4VI^L19JHV0BBUID4Si6B0h^>SPB7RX/4
PhJ717n3Q0AkOh04Mg]m17=hNAGoool001Coool4Jfma16IZK0AQIFL4G61R15QKG@=CEUP4CE5C14Q<
CPA3AdP4?T5313Pl?P<c=cT4;C4c12P/;P@R9RT4720R11`Q90@T:B/3;S8d13@g>@@h>cd4>Si013m3
A@A6BD/4BTe>0diADPAAE5H4EEQI15]MGPAQHF84IFIV0f][JPA^KVd4M7=a17IfM@AnO7X4OGal17an
O@>0PX84Q8N718Z<S0BBTi<4VIZJ1:BSXP>[ZZX4[:b]1:b][0BZZj/4Z:VY1:JWY`BSY:@3X::R19fO
W`BIVi`4UYRH19:EU@B?TI83Rhj>18N:R`B3QXL4Oh>417]oP0AgNgd4LgQi5Oooo`005?ooo`A[L784
J6a^16AXJ@AOI6D4FemQ0eMKG@ACEeT4Ce=D14Y>D0A6BT`4@DE70ce1@`@h?3h4=3Pj12lc=P@[;c44
9BX]12H[;P<[<3<4=3Pk13Xn@@@n@TD4@DE714I9B`A:CDl3C51B151EEPADEeX4F5]L15aNH0AQI6D3
IfUX16]]K@A`L6l4LW=c17YiN0AjNWX4O7em0gn1P@B3QXH4RH^;192AT@BDUYH4XJ6Q0j>TY0BRXj<4
XJ:R1:2QX@BNX:04W9jN19ZLW0>GVYX4UINH19:EU@B?TY84S8n@18V<S@>6RHX4PhJ71823Q0AmP844
NGeo17IjO0AcMgTEoooo000Doooo16]`LPAXK6h4I6QY15mTI@AKGf43Ee]M15=GF@A?De@4BTi@14I:
C0A1ADL3?D5313Pl?P@d>3X4;c<f12/_<@@U:Rd49R/^0b/`<`@d>3/4>Si113i2A@A1ADL4ATU;14Y=
C`=<D584D5EF15AGFPAHFe`4G5iP165TI@=WJFP4Jfe]171`K`AbLg<4NWUh17YjNPAlOGd3Oh6118>6
QPB9Rh/4T96A19BFUPBQXJ43XjBT1::SX`BQXZ84X:6Q19jPX0BLWYh4VYbL0iNJVPBEUiP4TYFE18nB
TPB<Si04RHb=0hJ9RPB3QXL4P8>417f0P@AiOGl4MWYl17=gNAGoool001Coool4Jg1b16Q/KPATJ6T4
GfAU15]OH@=GFed4DeMI14mCE0A:CU04ATY<1455A`<m@D<4>3`n13@h>P@_<cH4:bla12DZ;@@V:bh3
:c0c13@h>`@j?T44?T951455A`A6BD/4BTe?0da@DPA@EEH4E5MJ15QKG0ALGV04HFAU0fMYJ0A[KFd4
L71_179cL`AjNGP4NWYj17amO@=oPH44PhJ618V;R`B@TI44U9JF1:6QX@>SY:@4XZ>S1:6RXPBPXJ44
WZ2P19bNWPBJW9`3UiZJ19FGV0BBUID4Si:B18b?T0B9S8d3QXV:18>6Q`B0Ph@4OH2117UmO`AfNW`4
LgMi5Oooo`005?ooo`A[L784J6a^16AXJ@AOI6D4FemQ0eMKG@ACEeT4Ce=D14Y>D0A6BT`4@DE70ce1
@`@h?3h4=3Pj12lc=P@[;c449BX]12H[;P<[<3<4=3Pk13Xn@@@n@TD4@DE714I9B`A:CDl3C51B151E
EPADEeX4F5]L15aNH0AQI6D3IfUX16]]K@A`L6l4LW=c17YiN0AjNWX4O7em0gn1P@B3QXH4RH^;192A
T@BDUYH4XJ6Q0j>TY0BRXj<4XJ:R1:2QX@BNX:04W9jN19ZLW0>GVYX4UINH19:EU@B?TY84S8n@18V<
S@>6RHX4PhJ71823Q0AmP844NGeo17IjO0AcMgTEoooo000Doooo16aaLPAYKVl4IVY/16=WJ@AOI6D3
G61R15UMGPAEFE/4DUIG14iBE0A;Ce03Ad]=14=8B@A0A4H4?45313Tm@0@e>Sd4<cPk0c4g>@@c>C`4
?4541457BPA8Bdd4BTi?14aADP=>DU@4DEIH15EIF`AHG5d4FUiP15mSI@=TIfL4JFa/16e_KPAaLW84
MGIe17QhN0AjNg/3OGmo1864Q0B6R8P4SHn>196CT`BHVYX;UiVI19JHV0BDUiL4TiFF196DU0>?TY84
SI2A18^>S`B9S8d4QXZ:18B7R0>2QHH4Oh>417b0P@AjOWl4Mg]m17EiNPAbMWPEoooo000Doooo16aa
LPAYKVl4IVY/16=WJ@AOI6D3G61R15UMGPAEFE/4DUIG14iBE0A;Ce03Ad]=14=8B@A0A4H4?45313Tm
@0@e>Sd4<cPk0c4g>@@c>C`4?4541457BPA8Bdd4BTi?14aADP=>DU@4DEIH15EIF`AHG5d4FUiP15mS
I@=TIfL4JFa/16e_KPAaLW84MGIe17QhN0AjNg/3OGmo1864Q0B6R8P4SHn>196CT`BHVYX;UiVI19JH
V0BDUiL4TiFF196DU0>?TY84SI2A18^>S`B9S8d4QXZ:18B7R0>2QHH4Oh>417b0P@AjOWl4Mg]m17Ei
NPAbMWPEoooo000Doooo16aaLPAYKVl4IVY/16=WJ@AOI6D3G61R15UMGPAEFE/4DUIG14iBE0A;Ce03
Ad]=14=8B@A0A4H4?45313Tm@0@e>Sd4<cPk0c4g>@@c>C`4?4541457BPA8Bdd4BTi?14aADP=>DU@4
DEIH15EIF`AHG5d4FUiP15mSI@=TIfL4JFa/16e_KPAaLW84MGIe17QhN0AjNg/3OGmo1864Q0B6R8P4
SHn>196CT`BHVYX;UiVI19JHV0BDUiL4TiFF196DU0>?TY84SI2A18^>S`B9S8d4QXZ:18B7R0>2QHH4
Oh>417b0P@AjOWl4Mg]m17EiNPAbMWPEoooo000Doooo16ebL`A[Kg44J6e^16IZK0ASJ6T3HFEW15iR
I0ALH684FEeO15IKG0ADF5X3DEEG14iCE@A<D584BDi@14M;C@A4BD`4@TM:0d56B@@n@dL4@TQ:14E;
CPA:CU44D5AE159FF0=BEeP4E5UK15MKG@AIGV04G61R161TI@=RIVL4IfYZ16Y]K@A^LG44LW=c17Ef
MPAhNWX3Ngem1863P`B1Q8@4QHR818Z=SPB<Shl7SHn@18b?T0B<Shl4Rhj>18Z=S@B9S8`3QhZ;18J9
RPB4QhP4PXJ71864Q@AoPX@3OH6217]oP0AiOGh4Mg]m17EiN`AcN7T4LGIg5Oooo`005?ooo`A]LW<4
Jfma16Q]KPAVJV`4HfQY0f5UI`ANHV@4G61R15UMG`AFFe`4E5QJ0e5EE`A>DeD4C51B14U>D0A7Bdd4
A4U<1497BP=1ATT4?T=71498BPA5Bdh4BTiA151DE@ABEUP3DUMH15AIF`AGFed4FEiP15aPHPAPI6D3
HVIW16MZJPAZKFd4KW5a179cL`AeMWH4N7Yj0g]mO@B1Ph<4PHB418F8R0B:SHh4S8n?1hf?T0B<Si04
S8n?18^>SPB:SHd4RHb<0hN:R`B6RHX4Q8N818:6Q`B1Q8D4Oh:40gf1PPAkOh04NGen17MkO@AeNG/4
LgQi175fMaGoool001Coool4KG9c16]_L@AXKFh4IVY/16=XJ@=QIFL4GV9T15aPHPAIGEl4EU]L15AH
FP=AEEL4CU=E14a@DPA9CU04Ad]=14A9C0A2AdX3@DI913i3A`A2B4X4AD]>14Y>D@A@E5D4DUIH0e9G
F0ADFE/4Ee]M15UNH0ALH684H6AU0f9VI`AWJVX4JVe]16iaL@AbLg<4MGIf17QjNP=kOGd4PH>31864
Q0B5R8P4RXf>18b?S`N=Si04S8n@18b?S`B;SXh4RXf=18V<S0>7RX/4QXV:18B7R0B2QXL4PHB517n2
Q0=mPH84Ngn017UmOPAgNgd4MGUk17=hN@AaMWLEoooo000Doooo16ebL`A[Kg44J6e^16IZK0ASJ6T3
HFEW15iRI0ALH684FEeO15IKG0ADF5X3DEEG14iCE@A<D584BDi@14M;C@A4BD`4@TM:0d56B@@n@dL4
@TQ:14E;CPA:CU44D5AE159FF0=BEeP4E5UK15MKG@AIGV04G61R161TI@=RIVL4IfYZ16Y]K@A^LG44
LW=c17EfMPAhNWX3Ngem1863P`B1Q8@4QHR818Z=SPB<Shl7SHn@18b?T0B<Shl4Rhj>18Z=S@B9S8`3
QhZ;18J9RPB4QhP4PXJ71864Q@AoPX@3OH6217]oP0AiOGh4Mg]m17EiN`AcN7T4LGIg5Oooo`005?oo
o`A^LW@4K75c16]_L@AYKFl4Ifa]0fIZK0ATJ6X4HVMX165UIPAOHfD4GF5S0e]PH@AIGV04F5aN15IJ
G0ADFE/4DeQJ159FF@=AEEP4D5EH155FF@ABEeX4DEMJ15MKG@AIGF03FEeO15YNH0AIGV04Ff1R161T
IPASIVL3IFUZ16Q[K0AYKFh4KG1`171bL`AbMGH4N7Yk0gIiNPAkOWl4OH2117j2PPB1Q8D4PXF62h>6
Q`B2QXH4PXF61864Q@B0Q8D3Oh>417j2P`AmPH84O82117]oP0AjOWl3N7an17MkO@AfNW/4MGUj17=h
N@AbMWP4LGEg5Oooo`005?ooo`A^LW@4K75c16]_L@AYKFl4Ifa]0fIZK0ATJ6X4HVMX165UIPAOHfD4
GF5S0e]PH@AIGV04F5aN15IJG0ADFE/4DeQJ159FF@=AEEP4D5EH155FF@ABEeX4DEMJ15MKG@AIGF03
FEeO15YNH0AIGV04Ff1R161TIPASIVL3IFUZ16Q[K0AYKFh4KG1`171bL`AbMGH4N7Yk0gIiNPAkOWl4
OH2117j2PPB1Q8D4PXF62h>6Q`B2QXH4PXF61864Q@B0Q8D3Oh>417j2P`AmPH84O82117]oP0AjOWl3
N7an17MkO@AfNW/4MGUj17=hN@AbMWP4LGEg5Oooo`005?ooo`A^LW@4K75c16]_L@AYKFl4Ifa]0fIZ
K0ATJ6X4HVMX165UIPAOHfD4GF5S0e]PH@AIGV04F5aN15IJG0ADFE/4DeQJ159FF@=AEEP4D5EH155F
F@ABEeX4DEMJ15MKG@AIGF03FEeO15YNH0AIGV04Ff1R161TIPASIVL3IFUZ16Q[K0AYKFh4KG1`171b
L`AbMGH4N7Yk0gIiNPAkOWl4OH2117j2PPB1Q8D4PXF62h>6Q`B2QXH4PXF61864Q@B0Q8D3Oh>417j2
P`AmPH84O82117]oP0AjOWl3N7an17MkO@AfNW/4MGUj17=hN@AbMWP4LGEg5Oooo`005?ooo`A^LW@4
K75c16]_L@AYKFl4Ifa]0fIZK0ATJ6X4HVMX165UIPAOHfD4GF5S0e]PH@AIGV04F5aN15IJG0ADFE/4
DeQJ159FF@=AEEP4D5EH155FF@ABEeX4DEMJ15MKG@AIGF03FEeO15YNH0AIGV04Ff1R161TIPASIVL3
IFUZ16Q[K0AYKFh4KG1`171bL`AbMGH4N7Yk0gIiNPAkOWl4OH2117j2PPB1Q8D4PXF62h>6Q`B2QXH4
PXF61864Q@B0Q8D3Oh>417j2P`AmPH84O82117]oP0AjOWl3N7an17MkO@AfNW/4MGUj17=hN@AbMWP4
LGEg5Oooo`005?ooo`A_LgD4KW9d16ebL`A/LG84Jg1a0f]_L@AZKW04JFe_16Q/KPAWJfd4IV]/0fEZ
J`ATJF/4I6QZ16=WJ@ARIVP4HFIX165UI`]PIFL4HFEX165VJ0ASIfT4I6QZ0f=XJPATJFX4HfMZ169W
J@AUJF/4IVY[0fQ/K@AYKFh4JVi_16]_L0A]L744Kg=d17EhN@=dN7T4MGUj17IjN`AgNg`4N7am17Ul
OPmiOGh4N7an27QlO@=gNgd4Mg]l17IjO0AfNW/4MGUk17EiNP=dN7X4LgQi17=gN0AbMWP4LGIg175e
M`A`MGHEoooo000Doooo16mcM@A^LW@4KG9c16aaLPA[L743Jfma16Y^L0AYKFl4J6a^16M[K@AVJf`3
IFY[16AYJ`ATJ6X4HfMY169VJ0AQIVP4HFEW2f1UI`AQIFP4HFIX16=WJ@ATJ6X3HfQZ16AYJPASIfX4
HVMY16EYJ`AVJV/3J6a]16U]KPAZKVl4Jfm`16e`L@A_Lg@4MGQi0gAhN@AeNGX4MWYk17MkO0AhO7d4
NGan3gUmOPAhO7h8N7am0gMkO@AgNg`4MWYl17IjN`AeNG/4MGUj0gAhNPAcN7T4LgMh179fN0AaMWL4
LGEg171eMQGoool001Coool4Kg=e16ibM0A]LW<4K75b16]`L@=[Kg44JVi`16U]K`AXK6h4If]]16I[
K0=UJV/4I6U[16AXJPASIfT4HVIX165VJ0AQIFL;H6EW165UJ0AQIVP4HfMY16AXJP=SJ6X4I6UZ16=W
JPARIfT4IFU[16IZJ`=XK6d4JFe^16Y^K`A[Kg04KG1a16mcM0AeN7T3M7Qi17EiNPAfNW/4Mg]l17Ql
O@AiO7h?NGen17QlOPQhO7d3Mg]m17MkO0AfNW`4MWYk17EiN`AeNGX3M7Qj17=hN@AcMgP4LWIh175f
M`AaMGL4L7Ef5Oooo`005?ooo`A_LgD4KW9d16ebL`A/LG84Jg1a0f]_L@AZKW04JFe_16Q/KPAWJfd4
IV]/0fEZJ`ATJF/4I6QZ16=WJ@ARIVP4HFIX165UI`]PIFL4HFEX165VJ0ASIfT4I6QZ0f=XJPATJFX4
HfMZ169WJ@AUJF/4IVY[0fQ/K@AYKFh4JVi_16]_L0A]L744Kg=d17EhN@=dN7T4MGUj17IjN`AgNg`4
N7am17UlOPmiOGh4N7an27QlO@=gNgd4Mg]l17IjO0AfNW/4MGUk17EiNP=dN7X4LgQi17=gN0AbMWP4
LGIg175eM`A`MGHEoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo002Foooo0`0008Ooool009Woool00`000?ooooooo`24oooo0020oooo0`00
00;oool200001?ooo`@00002oooo0`0000?oool300000oooo`800021oooo0021oooo00@0003ooooo
ool00002oooo00@0003oooooool00002oooo00@0003oooooool00005oooo00@0003oooooool00026
oooo001noooo1@0000Coool010000?ooooooo`0000;oool00`000?ooooooo`0400000_ooo`040000
oooooooo0000Q_ooo`00O_ooo`040000oooooooo00000oooo`800004oooo0`0000?oool200001?oo
o`@00025oooo001ooooo00<0003oool000000oooo`030000oooooooo00Goool00`000?ooooooo`2@
oooo0020oooo0P0000?oool300001?ooo`80002Boooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(68) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
737677737677737577737576737576737576737576737475727475727475727474727374
72737472737472737372727372727372727272727272717272717172707072706F716E6C
727070727172727273727172727273717273717272717172717172707172707172707173
70717370737570747571757772767873777973787A73797B747A7D757C7F767E80778084
7A8388777F82767D80767B7E757B7D757A7C757A7C75797B74797B74787A74787A747879
747779747779747778747678
737677737576737576737475727475727474727374727273717273717172717171717171
717070716F70706F6F706E6E706E6E706E6D706D6D706C6C706C6B706B69706A68706865
716B69716C6C706D6D706D6D706E6E6F6E6E6E6D6D6E6C6D6E6C6D6D6C6D6D6D6E6D6D6F
6D6E706E70726E727470747671767872787B737A7C747C7F747F827782867985897B898F
7D8B917A868B798387788084777F82767E81767D80767C7F757B7E757A7D757A7C75797B
74787A74787A747779747778
737577737476727475727474727373717273717172717071707070706F6F706F6F706E6E
6F6D6D6F6C6C6F6B6B6F6B6A6F6A696E69686E69676E68666E67656F66636F64616F635E
6F66636F67666F69686E69696E6A6A6D69696C69696B68696C68696B68696A696A6B6B6C
6C6D6F6C6F716D70736E73766F767971797C727C7F747F8376838778878C7B8B917E9198
7E90967C8B917A888D798589788387788185778083777F82767E81767D7F757C7E757B7D
757A7C74797B74787A747779
737576737475727374727373717272717171707070706E6F6F6E6E6F6D6C6F6C6C6E6B6A
6E6A696E69686D68676D67656D66646D65636D64626D63606D625F6D615D6D605B6E5E59
6E615E6E63616D65646D66656C66656B66666A66666965666A65666A656769676869696A
6A6B6D6A6D6F6B6F726C73756E767A707A7E727E8274828777878C798B927D91988197A0
7F939A7D8F967C8C927B898E7A878B798589788387788285778083777F82767D80767C7F
757B7D757A7C74787A747779
737576727475727273717272717071706F6F6F6E6E6F6D6C6E6C6B6E6A6A6D69686D6867
6C67656C66646C64626B63616B625F6B615E6B605C6B5F5B6B5D596B5C586C5C566D5A54
6D5E5A6D605D6C61606C62616B63626A6363696363696363686263686364676465686668
68696B696B6E696F716A72756D777A6F7C8072808475858A788A907A8F977E969E829BA4
80969F7E939A7D8F967C8C927B8A8F7A888D79868A798488788286778184777F82767D80
767C7E757A7D75797B747879
737576727374717273717171706F6F6F6E6E6F6C6C6E6B6A6D69696D68676C67656C6564
6B64626A62606A615E6A5F5D695E5B695D59695B57695A556959546A58526B58526C5751
6C5B566C5D5A6B5E5C6A5F5E6A605F696060686060676061676061666161666263666465
666769676A6C686E716971756B777A6E7C8171818675868C788D947C939B809BA4829DA7
8099A27F969E7E929A7D8F967C8D937B8A907A888D79868B798489788286778184777F82
767D80757B7E757A7C74787A
7374767273747171727070706F6E6E6F6C6C6E6B6A6D69686C67666C66646B64626A6260
6A615E695F5C685D5A685C58675A5667585466575266555066544E67534D6A534C6C564F
6C59546B5A576A5B59695C5B685D5C675D5D675E5D665E5E655E5F655E5F646061646263
65656765696B666D706871756A777A6D7C8170838874888E798F977C979F819FA9829FA9
819BA57F98A17E959D7E929A7D90967C8D937B8B907A888E7A878B798489788286778083
777E81767C7F757A7C74787A
737475727273717071706F6F6F6D6D6E6B6A6D69686C67666B65646A63616A615F695F5D
685E5B675C58675A5666585465565165544F64524C64504A634E48634C456C534B6E5750
6C57526A5854695956685A58675B59665A5A655B5B645B5B645B5C635C5D635E5F636062
63636664686A656C6F67717469777B6C7D82708389748A9179929A7D99A282A1AC82A0AA
819DA7809BA47F98A07E959D7D929A7D90967C8D937B8B907A888E79868B798488788185
777F82767D80757B7D74787A
727475717272706F706F6E6E6E6C6B6D6A696C67666B65646A636169615F685F5C675D5A
665A5766585465565264544F63524D63504A624D47614B4460484160473F72574E6E564F
6B565169565268575467575566585765585764585863585962585961595A615C5C615F60
62636563686A646C6F66717469777C6C7E8370848A748C9379939B7D9AA482A3AE82A1AC
819FA9819DA6809AA37F98A07E959D7E92997D90967C8D937B8A907A888D79858A788387
778084767E81757B7E74797B
727475717172706F6F6F6D6D6E6B6A6C68676B66646A636269615F685F5C675C59665A56
65575364555163534E62504B614E48604B456049425F463F5C423B684C4371564D6D544D
6A534F68534F6754516554526455546355556255556155556055565F56585F5A5B5F5D5F
60636562686A636D6F65727569787C6C7F8470858B748C9478949C7D9BA582A3AF82A4AF
82A2AC819FAA809DA6809AA37F98A07E959C7E92997D8F967C8C927B8A8F7A878B798488
788185777F82767C7E75797B
727374717171706E6E6E6C6B6D6A696C67666A646269625F685F5C675C59655A56645753
63545062524D614F4A604C465F4A435E47405D443D5B403863473E6D4F466C50496A514B
68504C66514D65514E6452506353526253536152535F52535E51525E54565D58595E5C5E
5F626460686A626D6F65737669797D6C808571878D758D9578949D7D9BA580A2AD83A6B2
82A4B082A2AD81A0AA819DA6809AA37F979F7F949C7E91987D8E957C8B917B888D7A8589
788386777F83767C7F75797B
7273747170716F6D6D6E6B6B6C68676B656469636168605D675D5A655A57645753635450
62514C604E495F4B465E49425D463F5C433B5C40385F41386B4C426A4C43694D45684D48
664D48644D49634E4C62504E6150506051516050515E50515C4F515C53545C57595D5D5F
5D61635F686A606D70647477687A7E6D818672888E758E9678949D7C9AA47FA1AC82A7B2
83A8B482A5B082A2AD82A0AA819DA6809AA280979F7F949B7E90977D8D937B8A8F7A878B
798487788083767D7F75797B
7273747070706F6D6D6D6A696C67666A646269615F675E5B665B5764585463545061514C
604E495E4B455D48415C453E5B423A5A3F37593C3268473D694940684A42674B43654B45
644A45624A46614B49614E4D604F4F5F4F4F5F4E505D50515C52535A53545B595A5B5C5E
5B5E605D66685F6D6F647477697C7F6D828672898F768F9778959D7B9AA47EA0AB81A5B1
84AAB783A8B483A5B183A2AD82A0A9829DA68199A280969E7F93997E8F957C8C917B888D
798589788184767D80757A7C
727374706F706E6C6C6D69686B6564696361685F5D665C5964595563555161524D604E49
5E4B455C48415B443D5A4139593E35573A315D3D336C4A3F694940674940664943644843
6147425F46435E48475F4C4C5E4D4D5C4D4E6153545E53535C55565A56575A5758595A5C
585D5F5B64675D6A6D647376697D806E8387738A9176909879959E7A9AA47D9FAA7FA4B0
82A9B683ABB883A8B584A5B184A3AD839FA9829CA58198A080959C7F91977D8D937C898E
7A868A788285777E81757A7C
727273706F6F6E6B6B6C68676A646368615F675E5B655A5763565362534E604F4A5E4C46
5C48425A443D594139573D35563A3155362C6744386B493F69483F66473F654842624640
5F443F5C43405C46455C4A4A6052515F53526358585F55565C56575A5657585455575B5D
575D60586165596568616F736A7C7F708589748B9177929979969E7A99A37B9DA97EA2AE
80A8B583ACBA84ABB885A9B585A6B185A3AC849FA8839BA381979E8093997E8F957C8B90
7B878B798386777E81757A7C
7172736F6E6F6D6A6A6B676669636268605D665C5964585562545060514C5E4D475C4943
5A453E584139563C3554393054372E56362B6E4A3D6B493E68483E65473F63474160453F
5D423D5A423F5B45455A4A4A6557566256556055555E56565B535459545457535557595C
565B5E5760645863675E6D7167777B718488758D9278939A79979F7999A27A9CA77CA1AD
7FA7B481ABBA84ACB987ACB988AAB587A6B086A2AB849EA68399A181959C7F91967D8C91
7B888C798387777F82757B7D
7172736F6E6E6D6A696B6665696260675E5C655A5763565261524E5F4E495D4A455B4640
59423B563D365338304E322954352C603E326F4B3F6B493E67473E64473F6246405F443F
5C413D5B45415D49485E4E4D6455546055545E54545C54545A515257525356525456575A
565B5D5862655863675C6B716273786D7F85778E9479959B7997A07898A1789BA67A9FAC
7DA5B380AAB884ADBC87AEBC8BAFB989AAB488A5AE86A0A9849CA382979E8092987E8E93
7C898D7A8488787F82767B7D
7172736F6D6E6C69696A656468615F665C5A64595562545060504B5E4C475C48425A443D
583F38553A3250342C4A2E2459382E6C483C6C4A3E69483E66463E63473F6146405E443F
5B423E5B46435F4D4B5F504E5F51515E52525C53525A5252585151565152555354555659
565B5E5761645A63695D6B71617378697D83768D927A969B79979F7797A1779AA5799EAB
7CA4B17EA8B680ABBA8BB3C08DB2BD8CADB88AA8B288A3AC869EA68399A081949A7F8F94
7D8A8F7A8589788083767B7D
7171726E6D6D6C6868696462675F5D655B5863575360524E5E4E495D4A445B463F59423A
573D3555393051332A5132275E3D316B483C69483D67473D65473F62463F6046405E443F
5B433F5B46435F4E4C5E504F5E51505C51505B5151595050574F4F544F50545254535558
555A5D565F635A646A5D6C7162747A697E8471899078949A78969E7697A07699A4779DAA
7AA2B07BA6B57CA9B990B8C690B5C28FB1BC8CABB58AA6AF87A0A8859BA282969C809096
7D8B907B868A788184767B7E
7171726E6C6C6B6867696361665E5C6459566155515F504C5D4C475B48425A433C583F38
573B3355382E55342A58372B5D3D3263433865463C65473E6347406146406047405E453F
5B443F5B46435D4C495E504F5D51505B5050594F4F574F4F554E4E534E4F525052525557
53595C555E635A656A5F6D7364757B697E856F878E74909776949D75959F7497A3769CA9
79A1AF79A5B47AA8B892BAC894B9C591B4BF8EAEB88CA8B189A2AB869DA484979E819297
7E8C917B878B798184767C7E
7071726D6C6C6B6766686260655D5A62585560534F5E4E4A5C4A445A453F58413A573D35
56393056362C57352958382D5C3D3260423864453C64473F6248406147405F46405D4540
5C443F5B46425B4A475D504E5C51505A5050584E4E564E4E544D4E514C4E514F51515356
52595D555E635B666B5F6E7464767C697E856E868D728D9673909A73939E7396A2769BA8
77A0AE78A4B377A6B794BBC996BCC894B7C291B1BB8EABB48BA5AD889FA68599A0829399
7F8D927C878B798285767C7E
7071716D6B6B6A666567605F645B596156535E514D5C4C475A474158433C573E37563B32
55372D55342957352958382D5C3E3460443B63463D6248406148416047415F46405D4540
5C45405A46425A49455B4D4C5B515059504F574E4E554E4E534D4E504B4D4F4E50505255
52595D555E635B676C606F7565777D697E856D858D708B94708E9871919C7396A1759AA7
77A0AD79A3B277A5B590B8C69ABFCC97BAC693B4BE8FADB78CA7B089A0A8869AA183949A
808E937D888C7A8285777C7E
7070716C6A6A696564665F5D6259575F54515D4F4B5A4A4458453F564039553C3454382E
54342A54322656352A58382D5E413762453D62473F6249416149415F48415E46405D4640
5B45405A46425948455A4C4A5B5050594F4F564E4E544D4E514C4D4F4B4D4E4D504F5256
52595D555F645B676C606F7665787F6A7E866C848D6D88916E8C9670909B7295A1759AA7
789FAD7BA4B37CA7B68BB4C398BFCC9BBFCB95B7C291AFB98DA9B28AA2AA879CA384959C
808F947D898D7A8386777C7F
7070716C6A6A686463645E5C6158555D524F5B4C4858474256423C543D3652383052342B
523025522F24543429593C315F453C63473E6249406149416049425F48415D46405C4640
5B46415A47425948455A4D4A5A4F4E584F4F554D4D534D4E504A4C4D4A4C4C4C4F4E5256
51595D5660645A676D607077667880697E866B838B6B868F6D8A94708E9A7293A07599A6
799FAD7DA6B481AAB88AB3C295BFCD9CC1CE96B8C492B1BB8EAAB48BA4AC889DA485979D
8190957E8A8E7A8386777D7F
6F70706B6969676362635C5A5F56535B504C584A4555443F533F385139324F352C4F3027
4F2C22502E2354352B5B413661483E644A41634A416149426049425E47415D46405C4640
5B46415947435A49465A4D4B5A4F4E574E4E554C4D524C4D4F494B4C4A4C4B4C4F4D5256
51595D5661655A686E617178657880687D8569818A6A848E6C88936F8D9872939F7699A6
7A9FAD7FA7B484ABB98CB5C495C0CF96BDCB95B9C492B2BD8FACB58CA5AE899EA685989E
8291967E8A8F7B8487777D7F
6F6F706A6868656160615A595D5451594D4A55474352413C4F3B354D362E4C30284B2C22
4C2A204E2E2455382D5E453A644B41654B43634B436249426048415E47415C46405B4641
5A46425948445A4A475A4E4C5A4F4F574F4E554D4E524B4D4E494B4A494B4A4C504C5256
50595E5561675B696F60717864777E667B84677F8869838D6B87926E8C9872929E7698A5
7AA0AC80A7B585ABB98CB6C494BFCE96BECC95BAC693B4BF91ADB78DA7AF8AA0A787999F
8392977F8B8F7B8487777D7F
6E6F6F69676764605F5F59575B524F564B475244404F3D384C373149312A472C2345261C
46271E4B2E25573B3163493E674E44664D44654C43624A425F48415D46405B45405A4541
5946425A49455A4C495B4F4D5B504F585050554E4F514C4D4D494B4A494B494C504B5256
50595E5561675A696F5F6F7762757D647A82667E8768828C6A86916E8B9771919E7698A5
7B9FAC81A6B486AAB88DB6C493BCCB99C2D097BCC995B6C192AFB98FA8B18BA1A9889AA1
849398808C907C8588787D80
6E6E6F686666625F5E5D5755584F4D5348454F413D4B3A3547332D442D2642271F3F2017
3F241C4B31285A3F356A4E436C5146694F46664D44634B435F48415C4640594540594541
5846425A49465B4D4A5D514E5C52515A5252564F50514C4E4C494B49484B484B4F4A5256
4E595E54616758686F5C6E755F737C627881647D8667818C6986916D8B9771919D7697A4
7B9EAC80A5B285A9B78EB6C495BDCB9BC6D499BFCC97B8C394B1BB91AAB38DA3AA899CA2
859499818D917C8589787E80
6D6E6E676565615D5C5B5553554D4B4F45424A3D39463631422F294029223D231B3A1E15
3B231B4A322A5D42387254477054496C5147684F46644B435E47415A454057433F564440
5745425A49465D4F4B5F52505E55535C5555575252524E4F4C494C47484B464B4F495155
4C585E51606655666E596C745D727A607781637C8567818C6A86916D8B9771909D7596A3
7A9DAB7FA3B184A8B68FB4C299C0CE9EC9D79CC2CF99BBC696B3BD93ACB58FA5AC8B9DA3
86959B828E927D8689787E80
6D6D6E6664645F5B5B585351524A484B413F46393541312D3D2A253A241E381F17371D16
36211A49332B61463C78584B74574C70544A6B5148654D455E484159443F55423E534340
5646435C4B4761524E615351615755605A59595555524F504B4A4C46484B444A4E465055
49565D4F5E6652646C566A725A70795E767F627B8568828C6A86916C8B9770909D7596A3
7A9CAA7EA2B083A7B590B4C39DC3D1A2CDDB9FC5D19CBDC899B6BF95AEB691A6AE8C9EA5
88979C838E937E868A797E81
6C6D6E6463645D5A5A55504F4E4745473E3B4034313A2C2835241F341F19341C14351E18
35231D4B362E664A3F7E5D4F795A4E73574C6D534A674F47614A445A4640574541514240
5646435F4E49645551665754655B59635D5C5A57585250524B4A4C45474A42494D444E54
45525A4D5E664E626A506670566D765D757F627B8568828C6B86926D8B976F8F9D7495A3
799BA97CA0AF83A7B693B7C4A1C6D3A6D0DDA3C7D39FC0CA9CB8C198B0B893A8AF8EA0A6
89989D848F947E878A797F81
6B6C6D6363635B5858534E4E4A4443423A383A2F2D3225222C1C18281510341D1635211B
3927214D39316A4D428361537D5E5176594F70554C6A514A644E485D49445A4743554542
5949465F4F4B655652685A57675D5B615C5C5A58595251524A4A4C44474A41484D424D53
43515A495D65485E684A626D566C765D757F617A8469828C6C87926F8C986F909D7295A3
7799A8799FAE82A7B696B9C6A7C9D6AAD2DEA6CAD5A3C2CD9FBBC49BB3BA96AAB191A2A8
8B999E8590947F888B797F81
6B6C6D626262595757504C4C4741403D3634342A28291E1B1E100D20100C311D18382620
3D2C26533D356E51458765568061547A5C5272564E6C544C68524C614E485D4A465A4946
5C4C485F504C645652675B58655C5B605B5B5957585250524A4A4C44474B41484D414D53
43525A465A63465C66455F6A576D765C747E6079846B838D6D88936F8D996E8F9D7093A2
7398A7749CAC83A8B799BAC7ACCCD7AFD5E1ABCDD8A8C5CFA3BDC69EB5BD99ACB393A4A9
8D9B9F87929580888B7A7F81
6A6B6C6161615755554D4A4A433E3E3932312E26242118161207051F110E2C1B17392923
44322B5C443A7455498A67598464577D5F55755A516E574F69534D64514B5F4E495D4C48
5D4E4A60524E635653655A57645D5B5F5A5A595657515052494A4D43484C40484D404D53
42525A465962465C6748616C546B755A727D6079846A828D6B87926B8B986C8E9C6D92A1
6F95A57199AA86AAB89DBCC9B0CCD8B4D9E4B1D1DBADC9D2A8C1C9A2B8BF9CAFB596A6AB
8F9CA188939681898C7A8082
696B6C5F60605554544B4848403C3C352F2F2922211C14120D04021A0F0C281B17382923
49362F61473D78594D8C695B87675B806359795F56725A526C565067544F62524E63524D
61524E635551645754655A58645D5B5E5959575455504E51494B4E43494D40484E3E4B52
405159455962485D674C636D526A7457707B5D7883647F8B668490678896688C9A698F9F
6992A36F98A988ABBAA4BFCBB0CCD7B9DBE6B7D5DEB3CDD6ADC4CCA7BBC2A0B1B799A8AD
919EA28A9497838A8D7B8082
696A6B5E5F5F5453534947473D3A3A322D2D25201F181110090201150D0B261B17382923
4B373063493F7A5B4F8D695B8B6A5E84675C7D635A765F57705B546A5853675752675652
6456516457536357546359566059575B56565551524F4E50494C4F444A4F414A503E4B52
3E4F58425760465C664D636E516A75556F7A5975815E7B8861808E638594658999658C9C
648FA06F99AA8BADBBA7C0CBAFCBD6B9D9E4C1DCE4BAD2DAB3C8CFACBEC4A4B4B99CAAAE
949FA38C9598848B8D7C8082
696A6B5E5E5F5252524746463B39392F2C2B221E1E15100F070100130C0A241A16372823
4B3831644A407A5B4F8C695B8D6D60876A6080665E79635C735F596E5C576B5A56685954
6657536457536256536056535C5453595353534F514E4D4F4A4C4F464B51424C523F4D55
3D4F5840555E435A644A626C4E6873536E7A5674805B79865E7E8C618493628797608A9A
5F8C9E729BAC8CAEBCA3BEC9B2CCD6BDDAE4CCE4EBC2D8DFBACDD3B1C2C7A8B7BC9FACB0
96A1A58E9699858B8E7C8183
686A6B5D5E5E5151524645453A38382D2A2A201D1D130F0F050100120C0A211815362723
4A3731624940785A4E8A685B8D6E61896D628369617C665F76635D71605B6D5D58695A56
6658546357536155515E54515A5251565050524E4F4D4C4F4A4C50474C52444D54414E57
3F515A40555E415963465F6A4C6672516D795573805A78865B7D8C5E82925D85955C8899
5E8C9E749DAD8CAEBCA2BEC9B6CFD8C5DEE6D4E8EFCADDE3C0D1D6B6C5CAACB9BEA2AEB2
99A3A68F979A868C8F7D8183
686A6B5C5D5E5151524544453837372C2A2A1F1C1C120E0E040000110B0A1F1715332622
4836305E473F73584C8566598E6E628C6F65856C637E696278666073625D6E5F5A6A5C58
6659556356536054515C525059504F554E4E514D4E4D4B4E4A4C51474D53454E55425058
41525B41555F425A64455F6A4A65714D6A7752717E567685577B8A587E8F588293598597
608D9F769FAE8EB0BDA3C0CBBAD1D9CCE0E7DAEBF0D3E3E8C7D6DABBC9CDB0BCC0A5B0B3
9BA4A791989B878D8F7D8183
686A6B5C5D5E5050514444443737372B292A1E1C1C100E0E030000100C0B1E1715302421
44342E5A443D6E544A8163578C6D618E7167876E66806B647A676274645F6F605B6A5C59
6659566256535F53505B514F574F4E534D4E4F4C4D4C4B4F4A4D51474E53454F56435159
42535C425660435B65455F6B4864704B69764D6E7C507382527888537C8C547F91568496
6490A27BA2B191B2BFA6C2CCBDD2DAD2E2E8E0EDF1DCE9EDCDDADDC0CBCFB4BEC1A8B1B4
9DA5A892999B888D8F7E8283
686A6B5C5D5E5050514343443736372A292A1D1B1C0F0E0E0200000F0C0B1D17152E2320
40312C54413A6951487C6055886A5F8F7267897067816C657B69637565606F615D6A5D59
6659566255525E53505A504F564E4D524C4D4F4B4D4C4B4F4A4D51474E5445505744525A
42545D425761435B6645606B4663704868764A6D7B4C71804F76864F7A8B517E90578598
6A94A57FA5B396B5C1ACC5CFC3D6DDD8E5EAE6F0F3E3EEF1D2DDE0C4CDD0B6C0C2AAB2B5
9FA6A8949A9C898E907E8284
676A6B5B5D5E4F505243444536363729292A1C1B1C0F0E0F0100010E0B0B1D17152B221F
3C2F2A4E3E37654E45775C5284675C8C6F65897168826D667B69637565616F615E6A5D5A
6559566155535C5250584F4E554D4D514C4C4E4B4D4B4B4F4A4D52484F5545515844525B
43555F425862435C67445F6B456370466775486B7A4A70804B74854C788A517E905C899B
7099A985A8B69DBAC5B3CAD2CADAE1DEE9EDEEF6F9E5EEF0D5DDE0C6CED1B8C0C3ACB3B5
A0A6A8949A9C898E907E8284
676A6B5B5D5F4F515243444536373829292B1C1C1D0E0E0F0000020E0B0B1C161529211E
372C284A3B355F4A4370584F80645A876C62877067816D667A69647465616E615D695D5A
6459565F55535B514F574F4E534C4C504B4C4D4A4D4B4C504A4E5348505646525945545C
435760435963435C6744606C446471456775466B7A486F7F4973844D798B548193638E9F
769EAC8EAEBBA4BEC9BBCFD6D1DFE4E5EEF1F4FBFCE4ECEDD5DDDFC7CED0BAC0C2ADB3B5
A1A6A8959A9C8A8E907E8283
686A6B5C5E5F4F5152434446363739292A2C1C1C1E0E0F100000020E0B0C1A161527201E
342A2746383358463F69534B79605680675E846D64806D657968637364606D605D675C5A
6258565E54525A504F554E4D524C4C4F4B4D4D4B4E4B4C50494F5448515747535A46555D
445861445A65445D6844616D446471456876456B7A466F7F4974854F7B8D5985966B94A3
7FA3B196B4BFACC4CDC2D4DAD9E5E9EDF3F5F6FCFCE5EAECD5DCDDC7CDCFBAC0C1ADB3B4
A1A6A8959A9B8A8E8F7F8283
686A6B5C5E5F50525344454737383A2A2B2D1D1E200F10120001030C0B0B181515241F1E
31292640343052423C614E48705A527861588069617E6B6478676271635F6B5F5C665B58
6157555C5352585050544E4E514B4D4E4B4D4C4B4F4B4D524A505649525948545C47565F
455962455B66445E6A44626E446472446876446C7B466F804B7587547F90628B9B759AA9
8AAAB69FB9C4B5C9D1CCDADFE4EBEEF7FBFCF3F8F8E3E8E9D5DADBC7CCCDBABFC0ADB2B3
A1A5A795999B8A8D8F7F8283
686A6C5C5E60505254444648383A3C2B2D2F1E2022101214020305090A0B161415221D1D
2D26243B312F4A3E39594A4466534D705B5479645C7A68617565606F615D695E5B635A57
5E56555A5352565050534E4E4F4B4D4D4B4E4B4C504B4E534B52574A545B49565E485860
465B64465D6845606C44636F446573446978456D7C4871824F798A5B85956B92A180A1AE
95B1BCA8C0C9BECFD6D6E1E4ECF1F2FCFFFFEFF2F3E1E5E6D3D7D8C6CACBB9BDBEACB1B2
A0A4A695999A8A8D8E7E8283
686B6C5D5F615154554648493A3C3D2D2F31202224121517040608080A0C1313141E1B1B
292423352E2C443A365245415D4E4967564F705D5774635C71625D6C5F5B675C59615857
5C5554575252544F50514D4F4D4B4D4B4B4E4B4E524C50554C53594C565D4B5860495A63
485C66475F6A46626D466571456775466B79486F7F4C7585567F8F658C9B7799A78BA8B4
9FB8C1B3C6CEC9D6DBE1E7EAF2F5F5FDFFFFEDF0F0DFE2E2D1D4D5C4C8C8B7BBBCABAFB0
A0A3A4949899898C8E7E8183
686B6D5D606252555647494B3B3E402F323423252816181B080B0D06090B1011131A191A
262322302B2A3D36344B413E5549455E504B6556516B5C576B5C58685C58635A585D5655
595454555152524F504F4D504B4B4E494B4F4C4F534D52574E565C4D585F4D5A624B5D65
4A5F6849616C496470486774486A78496D7C4E7382537B8A6086957093A182A1AD96AFBA
AABEC6BECED3D5DEE1EAEEEEFAFBFBF9FBFAEAECECDBDEDECED1D2C2C5C5B5B9BAAAADAE
9EA2A3939798898C8D7E8182
696C6D5E6163545658494B4D3E404232353726292C1A1D200E111405080B0C0F11171819
2221212B2828373231453D3B4E4542574C485B504C6155516357546357555E5655585354
545152535051504F514D4E51494C50494D514C50554F555950585E505B614F5D644D5F68
4D616A4D646F4C67734C6A774D6E7B4F72805579885E83916C8E9B7C9BA78EA8B3A2B7C0
B5C6CCCAD5D9DFE4E6F1F2F2FFFFFEF2F3F3E5E6E6D7DADACBCDCEBFC1C2B3B6B7A8ABAC
9DA0A1929597888B8C7E8082
696C6E5F62645558594B4D4F40434535383A2A2D301F222513171A070B0E090D10151718
1E1F20282727322F2F403A384942404F4745544B49584F4D5B52505A5251575251535052
514F51514F524F50524D4F534A4E524B50544E535750575C525A60535F6452606750626A
51656E516872526C77526F7B54737F58798560818E6A8B977997A289A3AD9BB0B9AEBFC6
C2CED2D6DCDFE7EAEAF8F6F6FCFCFAEDEDEDDFE1E0D3D5D5C7C9C9BBBEBEB0B3B4A6A8A9
9B9E9F919495878A8B7D8081
6A6D6E60636557595B4D5052434648393C3E2E313423272A181C1F0D1115080C0F111517
1B1D1F2525262F2D2E3B3737433E3D4843424C4645504A49534C4B534E4E504E4F4E4E50
4E4E504F4F524D50534D51554B51554D53574F555A515A5E545D6356616756646B55666E
566972566C7659717B5A757F5E7A8563808C6D899478939D879FA896ABB3A7B9BFBAC7CC
CFD6D9DFE3E4EDEFEEFBF9F8F3F3F2E6E6E5D9DADACECFCFC2C4C5B8BABAADB0B0A3A6A7
999C9D90929386898A7D7F81
6A6D6F616466585B5D4F525446494B3C3F42323639282C2F1E222514181C0A0F120E1316
191C1E2324262C2C2D3634353C3A3A423F3F4542424A46464D49494C4A4B4B4B4D4B4D50
4B4D514E50534B4F544E53574E53584F555A50585D545D625760665A656A5B686E5B6A71
5C6E765E717A62767F647B8469818B6F889279919A859BA494A7AEA3B3B9B4C1C5C7CFD2
DADDDFE7E8E8F4F4F3F4F3F2E9E8E8DDDEDDD2D4D3C8C9C9BEBFC0B4B6B6AAACADA0A3A4
979A9B8E91928588897C7F80
6B6E6F6365675A5D5F525557494C4E404346373B3D2E323424292C1B1F231015190D1215
171C1E202426282B2C3132333838393E3D3E3F3F4044434447464746474A484A4D494C4F
494D514C50544B50554E54584F555A51595D535C605760655B64695E686E606C71606F75
63737A67777E6B7C846D818973888F7B90978699A092A3AAA0AEB4B0BBBFC1C9CBD3D6D8
E2E3E3EFEFEEF1F1EFE8E8E7DFDFDED5D6D5CBCCCCC2C3C3B8BABAAFB1B2A6A8A99DA0A1
9597988C8F908487887C7E80
6C6E706467685C5F615457594C4F5244474A3C3F4233373A2B2F3222262A191E21101619
161C1F1E232626292C2E3032353738393A3C3B3D3F3F4042424446424649474A4E474C50
494E524B51554D52574F555A51585D545C605860645B636860686D636C71667075677379
6B787E6F7D8272818775868D7C8D9487969C91A0A59EAAAFACB6B9BBC2C4CBCFD0DBDCDC
EAEAE9EEEDECE5E5E4DEDEDDD5D6D5CDCECDC4C5C5BCBDBDB3B5B5ABADADA2A5A59A9D9D
9295968B8D8E8385877B7E7F
6C6F7165686A5E6163575A5C505355484C4E414447393D40313639292E3121272A191F22
171D211C222624292C2C3033323538373A3C393C3F3C3F423F434641464A454A4E474C51
4A4F544B52564E555A51585C545B60585F635C636760676B656C706870746D75796D787D
737D8276818579858A7D8B90869397919CA09CA6AAA9B0B3B7BCBEC5C7C8D3D3D3E1E0DF
EBEBEAE3E3E2DBDCDBD4D4D4CCCDCDC5C6C5BDBEBEB5B7B7ADAFB0A6A8A89EA1A197999A
909293898B8C8284857A7D7E
6D707167696B6063655A5D5F5356584C505246494C3F4346383C3F3136392A3033242A2D
1E24271D232623292C2A2F32313639363A3D393D403B3F433F444740464B444A4F484E53
4B51564E545951585C545B60575E635C626660676A646B6E6970736E7578737A7D767E82
7A82857B84877E898C8590938E989B99A1A3A5ABADB2B6B7BEC0C1CBCBCBD8D7D6E2E1E0
E0E1E0D8D9D8D1D2D1CACBCBC3C4C4BCBEBEB6B7B7AFB0B1A8AAAAA1A3A49A9C9D949697
8D8F9087898A8083847A7C7E
6E7072686B6D6265675C6061575A5C5154564B4F5145494B3F4346393E4033383B2E3336
292E32242A2D23292D292F33303639363B3F3B3F433C42453F454941484D454C504A5055
4D545851585C545B5F575D625B6165606669646A6D696E726E737673787B797E817D8285
808586808789848C8E8C9496949B9D9EA3A5ABAEAFB8B9B9C3C3C3CECDCCDAD9D8DADADA
D3D4D3CDCECDC7C8C7C1C2C2BABCBCB4B6B6AEB0B0A8AAAAA2A4A59C9E9F969899909293
8A8D8E8587887F8183797C7D
6E7173696C6E6467695F62645A5D5F55595B5054564B4F51464A4C4145483C4043373C3F
33383B2F34382A30332A303430373B373D413D424640454942484C434A4F484F534D5458
50575B545A5E575E625A60655F646863696C686D706D7274717577777B7C7D8082818485
84878883888A888E90909597979C9EA2A6A6AFB1B1BBBBBAC6C5C5CECDCDD2D2D2CCCDCD
C7C8C8C2C3C3BCBDBDB7B8B8B2B3B3ACAEAEA7A9A9A2A3A49C9E9F97999A9294958D8F90
888A8B8385867D8081787B7C
6F72736B6E6F666A6B6265675E6163595D5F55595B5154574C5053484C4F44484B404548
3C4144393E41353B3E31373B32393D383E433F4549444A4E464D51484E534C535751575C
555B5E585E625A61655D636862676B676C6F6C70727174767477797A7D7D7D8081858686
858788878A8B8D91919497989C9FA0A7A8A8B0B1B1BDBCBBC5C5C5C6C7C7C3C5C4BFC0C0
BBBCBCB6B8B8B2B3B3ADAFAFA9AAABA4A6A6A0A1A29B9D9E9799999294958E9091898B8D
8587888083847C7F80787A7C
7073746C6F71696C6D65686A6165665E61635A5E60575A5C5357595054564C5053494D50
464A4D43484B4045483D43473B41453E444841484B474D514B51554E555952585C575C60
5A60635C62655E656863676B676B6D696D706D717473757777797B7B7D7D7E8080858686
8687888A8C8C8F91929598999EA0A0A7A8A7ADAEAEBBBBBABCBDBDB8B9BAB5B7B7B2B4B4
AFB0B0ABADADA7A9A9A3A5A6A0A2A29C9E9E989A9B9497979193948D8F90898C8D868889
8284867E81827B7D7E777A7B
7173756E71726B6E6F686B6D65686A6265675F63645C60625A5D5F575B5D54585A525658
4F53564D51544B5052494E51484D51474D51484E514A505450575A555B605B5F625D6164
5F646760656863686C676B6E696C6F6A6D706F727472757677797A7A7C7C7F8080838484
8787878B8C8C8F91929698989C9D9DA4A5A5A9ACACB0B1B1ADAEAEAAACACA8AAAAA5A7A7
A3A4A5A0A2A29D9F9F9A9C9C97999A9496979193948E90918B8D8E888A8B858788828486
7F82837C7F80797C7D76797A
7174766F72746D70726B6E6F696C6D666A6B6468696265676063655E62645C60625A5E60
585C5F575B5D555A5C54595B53585B53585B53585B52585C585E615C61655F6366636769
65696C666A6C676B6D686C6F6A6E706D707270737573767777797A7A7C7C7E8080828383
858686898B8B8D8F90959798989A9A9C9E9FA0A2A29FA1A19EA0A09C9E9F9B9C9D999B9B
9799999597979294959092938E90918C8E8F8A8C8D878A8B8587888385868183847E8182
7C7F807A7D7E787A7C76787A
7275767174756F72746E71726C6F716B6E6F696C6E686B6D676A6B65686A646769636668
6265676064665F63655F63655E62655E62655E62655F636661656862676A64686B6A6D6F
6B6E716A6D706B6F706B6F716B6F726F727471747573767777797A787B7B7B7D7E7E8080
818384898A8B898B8C8E90918F91928F91929092939092938F92928F91928D90908C8E8F
8B8D8E898C8D888A8B87898A8587898486878285868183847F82837E80817C7F807B7D7F
797C7D787A7C76797A757879
7375777275767174767173757073746F72736E71736E71726D70716C6F716C6F706B6E70
6A6E6F6A6D6F6A6D6E696C6E696C6E696C6E696C6E696D6F6A6E706B6E716C6F716E7173
6F72746F72746F72746E72746F727472757673767775777876797A777A7B797B7C7A7C7D
7D7F80828485808283808384818384818485828485828485818485818384808384808283
7F82837E81827E80817D80817C7F807C7E7F7B7D7F7A7D7E797C7D797B7C787A7C777A7B
76797A76787A757879747778
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?ooo`QcMWL4LgEg3g=eMPAcM7D8LWAe179dM0]bLg@4LW=c279b
L`MbLW84LW5b179aL@AbL704LW1_175^K0AbL703LW5b179bL`AbLG84LW9c175bL`AaLW87LG5b271a
LPQ`LG<4L7=e0g1dM@AaMGL4LWIh17=gN@AcN7X4LgUk0gAjO@AeO7l4MWj017N0Q0AjPhP4Mgn217Im
P0=fNgh4MG]m27EjO0AeNG/4M7Uk1gAhNPAdN7T8M7Mi17AgN0AdMWPEoooo000Doooo27=fM`AcMGL?
LgEf17=dM@QbM7D4LWAd2g9cM0AbLg<8LW9c1g9bLPAbLG84LW5a179`L0AbL6l4LFi/179`L0=bLG84
LW9c179aLPAbLW<4LG9c175bLPMaLG88L75b271aL`A`LgD3L7Ae175eM`AbMWP4LgMi17=hNPAcNG/3
M7Ym17ElO`AfOX04Mh2417Z3R0AgOh84MWf00gIkOPAeNgd8MGYl17EiN`AdNG/7M7Qj17AhN@QdMgT4
M7Mh17AfN1Goool001Coool8LgIg17=eM`mcMGH4LgAe279dM@AbM7@;LW=d179cL`QbLW<7LW9b179a
LPAbLG44LW1`179`K`AaKV`4LW1`0g9aLPAbLW<4LW5b179bL`AaLW<4LG9b1g5aLPQ`LG88L75c171c
M@=`M7D4LGEg179fN0AcMgT4LgQj17=iN`=dNWd4MGao17InP0AgP8@4NX>817MoPPAfOH03MW]n17Ek
O@QeNW`4MGUk17AiN`MdN7X4M7Qi27AgN@AdMgP4M7Ih5Oooo`005?ooo`AcMWL8LgEf17=dM@AbM7D3
LWAd179cM0AbLW<4LG9c175aLPMaLG44LG1`175_L0A`Kfl8L6i^171^K@=`KFd4L6a/171/J`A`JfT4
L6YX171XI@AaJfT3LFa/271]K@A`KVh4Kfi^16i]K@M^K6d4KFa]16e]KPA]KFl4KFi`16i`LP=^LW@4
L7Af175fN0AbN7/4LgYl17AlO`=dOh84Mh:617V5R@AkRHl4OH^A17Z6R`AiPhL3N82417MoPPAfOX44
MWf017IlO`AeNgh3MGYm17EjO0AeNG/8M7Qj17AgN@AdMgPEoooo000Doooo17=fM`QcMGH4LgAe179d
M@=bM7@4LW=d179bL`AaLW<4LG5b1g5aL@AaL704LFm`171_K`Q`KVh4L6i]0g1]K@A`K6`4L6a[171[
J@A`JVP4L6QU175[J@=aK6`8L6e]171^KPA_KVh4KVe]1fi/K@A]K6d4KFe^16e]K`A]KW04KW1b0fib
M0A`M7H4LGIh179hN`AcNW`4M7ao0gAoPPAgPXH4NHF917^9S`AmRi44NXJ;17V3Q`=hP8@4Mgn217In
P@AfOH04MWao17EkOP=eNWd4MGYl17EiN`QdN7X4M7Mi17AgN1Goool001Coool4LgIg27=eMPAcM7D4
LWAe0g9dM0AbLg@4LW9c175bL`AaLG87LG5a175`L0AaKg04L6m_271^KPA`KVd3L6e]171/K0A`K6/4
L6]Y171ZJ0A`J6D4LF]Y0g5/K0Q`KFd4L6i^16m^KPA^KFd7KVa]16e/K@A]KFh4KFe_16e^L0A^L783
KW9d171dMPAaMWP4LWQk17=jO0AdO7l3M7n217N2QPAiQHT4NhV?17f;T@AjQX/4NH>70gR0Q0AgOh84
MWj117ImP0AfO7l4MG]n0gEjO@AeNW`4MGUk27AhNPAdMgT4M7Mh5Oooo`005?ooo`AcMWL8LgEf17=d
M@AbM7D3LWAd179cM0AbLW<4LG9c175aLPMaLG44LG1`175_L0A`Kfl8L6i^171^K@=`KFd4L6a/171/
J`A`JfT4L6YX171XI@AaJfT3LFa/271]K@A`KVh4Kfi^16i]K@M^K6d4KFa]16e]KPA]KFl4KFi`16i`
LP=^LW@4L7Af175fN0AbN7/4LgYl17AlO`=dOh84Mh:617V5R@AkRHl4OH^A17Z6R`AiPhL3N82417Mo
PPAfOX44MWf017IlO`AeNgh3MGYm17EjO0AeNG/8M7Qj17AgN@AdMgPEoooo000Doooo17=eM`AcM7H4
LWAe179dM0AbLg<3LG9c175aLPAaL744L71`271_K`=`KVh4Kfe]16m/K0A_Jf/4Kf]Z16mZJ@A^JFP3
KVUW16iXIPA^IfD4KfIS16mTH@A_Heh4KfIS0fmWIPA_JFP4KVUY16iZJPA]JFT4K6UY0f]XJ@A/J6T4
JfQY16YYJPA[Jf`4K6e_16a_L@=]L7<4KW=f16mfN@AaNG`4LWao17AoP`=fPhL4N8N<17^;T@AnTIP4
OY2F17b;T@AjR8d3NHF917R3Q`AhPHD4Mh2317MoPPAfOX43MWeo17ElOPAeNgd4MGYl17AiN`AdN7X4
M7Mi5Oooo`005?ooo`AcMGL4LgAf179dM@AbM7@4LW=c0g5bL`AaLG84LG1a171`L0Q`Kfl3L6i^16m]
K@A_K6`4Kf][16m[JPA_JVT4KVUX0fiYI`A^J6H4KVMU16mVH`A_I644Kf=N16mVH`=_IfH4KfUX16iY
J@A^JVX4KFUY16aYJ@=[J6T4K6QY16]XJ@AZJFX4Jf]/16a]K`A/Kg43KG1c16icMPA_MWT4LGUl179l
O`AdOh<3MX>717R7S0AkRi44OY6H17j@UPAlRi44NXR=0gV5R@AhPhL4N86517N0P`AgOh84MWj10gIm
O`AeO7h4MG]m17EjO0AdNG/4M7Qj17AgNAGoool001Coool4LgEg17=dMPAbM7D4LWAd179cL`=aLW<4
LG5b175`L@A`L708L6m_0g1^KPA_KFd4Kfa/16m[J`A_JfX4KfYY16iYJ0=^JFL4KVQV16iWI@A_IV<4
KfAQ16mSGPA_IV<3KfMV16mYJ0A^JFT4KVYZ16eYJ@A/JFT3JfQY16aXJ@A[J6T4JVUZ16][K0A/KFl4
K6ma0fe`L`A^LgH4KgIi175iO0AbO7l4M7n30gJ3Q`AhQh`4Nh^A17jAV0AnT9H4O8^A17Z8S@=iQHT4
N8>717R1Q@AgP8<4Mgn217InP@=fOGl4MGan17EkO@AeNW`4M7Uk17AhNPAdMgTEoooo000Doooo17=e
M`AcM7H4LWAe179dM0AbLg<3LG9c175aLPAaL744L71`271_K`=`KVh4Kfe]16m/K0A_Jf/4Kf]Z16mZ
J@A^JFP3KVUW16iXIPA^IfD4KfIS16mTH@A_Heh4KfIS0fmWIPA_JFP4KVUY16iZJPA]JFT4K6UY0f]X
J@A/J6T4JfQY16YYJPA[Jf`4K6e_16a_L@=]L7<4KW=f16mfN@AaNG`4LWao17AoP`=fPhL4N8N<17^;
T@AnTIP4OY2F17b;T@AjR8d3NHF917R3Q`AhPHD4Mh2317MoPPAfOX43MWeo17ElOPAeNgd4MGYl17Ai
N`AdN7X4M7Mi5Oooo`005?ooo`AcMGH4LgAe179cM0AbLg<4LG9b0g5aL@A`L704L6i_16m^KPA_KF`4
Kfa/0fi[JPA^JVT4KVUX16eXI`A]IfD4KFIT16eUH`=]I684KF=P16eRG`A]HEd4KF1K16iNF@A^HEh3
KV=Q16eUI0A]IVD4K6IU16]VIPAZIVH3JFEV16YUIPAZIFL4JFMX16UYJPAZJfd4JVe_0f]_LPA/LgD4
KWIj171jOPAbOX84M8:70gN7S0AiRi84OI6H186GX0AoTiX4OHnF17b<TP=kRHh4NXN;17V5R@AhPhL4
N8:517N0P`=gOh84MWf017IlO`AeNgd4MGYl17AhNPAdMgTEoooo000Doooo17=eMPAcM7D4LW=d179c
L`AaLW83LG5a171`L0A`KVl4Kfi^16m]K0A_K6`3KV]Z16iZJ@A^JFP4KFQW16eWI@A]IV@4KFES0feT
HPA]Hf04KF9O16eQG@A]H5/4KUiI16iQGP=^Hf44KFET16eVI@A/IVD4JfIV16YVIP=YIFH4JVEV16YU
I`AYIfP4JFUZ16Y[K@AZKFl3Jfmb16acM@A^MWX4L7Yn179nPPAdPXL3MhN<17V;TPAmTIP4PINP17nC
VPAmSiH4O8bB0g^9SPAjQh/4NHF917R3Q`AhPXD4Mh230gMoPPAfOH04MWao17EkO@AeNW`4M7Qj17Ag
NAGoool001Coool4LgEf17=dM@AbLg@4LW=c175bLP=aLG44L71`171^K`A_KVh4Kfe/16m/K0=^JfX4
KVYY16iYJ0A]J6L4KFMU16eVI0A]IF<3KFAR16eSH0A]HUl4KF5M16ePF`A^GUT4KV5N0fiSH@A]IF@4
KFIU16aVI@A[IVH4JVIV0fUUIPAZIFH4JVEW16UWJ0AYJFX4JV]]16Y]K`=[Kg84K7=e16ifNPA`NWh4
LWj217B2Q`=gQh`4NH^B17fAV0B1Uj04Oi>J17f?UPAlS983NhV>17Z7R`AiQHT4N8>717R2Q@AgP8<3
Mgn217ImP0AfO7l4MG]m17EjO0AdN7X4M7Mi5Oooo`005?ooo`AcMGH4LgAe179cM0AbLg<4LG9b0g5a
L@A`L704L6i_16m^KPA_KF`4Kfa/0fi[JPA^JVT4KVUX16eXI`A]IfD4KFIT16eUH`=]I684KF=P16eR
G`A]HEd4KF1K16iNF@A^HEh3KV=Q16eUI0A]IVD4K6IU16]VIPAZIVH3JFEV16YUIPAZIFL4JFMX16UY
JPAZJfd4JVe_0f]_LPA/LgD4KWIj171jOPAbOX84M8:70gN7S0AiRi84OI6H186GX0AoTiX4OHnF17b<
TP=kRHh4NXN;17V5R@AhPhL4N8:517N0P`=gOh84MWf017IlO`AeNgd4MGYl17AhNPAdMgTEoooo000D
oooo17=eMPAbM7D4LW9c175bLPAaL743L6m_16m^KPA_KF`4KVa[16iZJPA]JFP3KFQW16aWI@A/IV@4
K6AR16]SH@A[HUl4Jf5N0f]PG0A[Ge/4JeeI16]LF0A/G5H4KEYD16eNFP=]H5d4K65P16aRH@A[Hf84
JV=S1fUSH`AXHV<4J6=T16MTI@AXIVP4J6U[16U[KP=YKg44JW9e16egNPA_O804LX2417F5RP=hRY04
NXnG17jFWPB2Vj@4P9JO17jCVPAmSiH3O8bB17^:S`AjR8d4NHJ:17V4R0AhPXH3Mh6417MoPPAfOH04
MWan17EjO@AeNG/4M7Qi5Oooo`005?ooo`AcMGH4LWAe179bL`AaLW84LG1a0g1_K`A_KVh4Kfe/16i/
J`A^JVX4KFUX0feXI`A/IfD4K6IT16aTHPA[Hf44Jf9O16]QGP=[H5`4JemK16]MF@A[G5P4K5aF16eJ
E0A]GUX3KF1M16aQH0A/HV44Jf=R16YSH`MYHf<4J69S16QSI0AWI6D4J6IX16QYJ`AYJfh3JFma16Yb
M@A]MgX4Kgb017:0Q0AeQHX3N8Z@17Z?U`AnUYh4PY^T182FW`AnTiX4OHnF0gb<TPAkRXl4NXR=17V6
RPAiQ8P4N8:60gN1Q0AgOh84MWf017IlOPAeNWd4MGUk17AhNAGoool001Coool4LgEf179dM@AbLW<4
LG9b175`L@=`Kfl4Kfi^16m]K0A^K6/4KVYZ16eYJ0=]J6L4K6MU16aVI0A/I684Jf=Q16]RG`A[HEh3
Jf1L16]OF`A[GET4JeaH16aLEPA]FU@4KEiJ0fePG@A/HF04K69Q16]SHPAZHf<7JF=S16QRH`AXHf@4
IfAU16QVJ0AXJF/4JF]^0fU_L@AZLWD4KGMj16mlP0AbP8@4MHF:0gR:T0AjSiL4OYJN18:KY0B0UYl4
OY>J17f?UP=lS984NhZ?17Z8S@AiQXX4NHB817R2QP=gPH@4Mgn217ImP0AfO7h4MGYm17EiN`AdN7TE
oooo000Doooo17=eMPAbM7D4LW9c175bLPAaL743L6m_16m^KPA_KF`4KVa[16iZJPA]JFP3KFQW16aW
I@A/IV@4K6AR16]SH@A[HUl4Jf5N0f]PG0A[Ge/4JeeI16]LF0A/G5H4KEYD16eNFP=]H5d4K65P16aR
H@A[Hf84JV=S1fUSH`AXHV<4J6=T16MTI@AXIVP4J6U[16U[KP=YKg44JW9e16egNPA_O804LX2417F5
RP=hRY04NXnG17jFWPB2Vj@4P9JO17jCVPAmSiH3O8bB17^:S`AjR8d4NHJ:17V4R0AhPXH3Mh6417Mo
PPAfOH04MWan17EjO@AeNG/4M7Qi5Oooo`005?ooo`AcMGH4LW=d175bL`AaLG44L6m_0fm^KPA_K6`4
KV]Z16eYJ@A]J6L4K6MU0faUI0A[I684JV9P16YQGPAZGed4JEiK16UMF@=YFeL4JEYE16UIE0AZF584
JeQB16aGD@A/FeH3K5eJ16]NG0AZGeh4JV1O16UPH0AXH607If1Q16IQH@AVHV<4IVAU16IWJ@AWJV`3
J6ia16UaM@A[MgX4KWb11761QPAeQX`3N8fD17bCV`B0Vj@4PYfW182IXPAoUYh4OY:J0gf?UPAlSI<4
NhZ@17Z8S@AiQX/4NHB90gR2QPAgPH@4Mgn217ImP0AeNgh4MGYl17AhNQGoool001Coool4LgEf179c
M0AaLW<4LG5a171_K`=_KVh4Kfa/16i[JPA]JFT4KFQW16aWI@=/IF@4JfAR16YRH0AZHEh4JUmM16UN
F`AYGET3JE]G16UJE@AYFE@4JUQB16]HDPA/Ee44K5]F0faMFPA[GU`4JUmN16YPG`AYH604J61P1fMP
H@AVHF44IV9S16ITI@AVIfT4IfY/0fQ^L@AYLGD4JgMj16ilP@AaPHH4MHJ<0gR=U0AlTi/4P9^T18:M
Y`B0VJ84OiJN17jBVP=mSiH4O8fC17^:T0AjR8d4NHJ;17V4R@=hPXH4Mh6417MoPPAfOH04MG]n17Ej
O0AdN7XEoooo000Doooo17=eMPAbLg@4LG9c175aL@A`Kfl3Kfi^16m/K0A^JfX4KFUY16eXI`A/IfD3
K6ET16]THPAZHV04JV5N16YOG@AYGU/4JEeI0fUKE`AYFUD4JEUD16YHDPA[F584K5MA16aKEP=/GEX4
JeiL16YOGPAZH5l4JF1P16QPH0MWH644IV5Q16IRH`AVI6D4IVMY16MZK0=XKW44JG5e16]gNPA^O844
LH6617F6S0=hSI@4O9>K182KY0B2WJL4P9VR17nFWPAnTYX3OHnF17b=T`AkRY04NXR=17V6R`AiQ8T3
N8:617N1Q0AgOh84MWf017EkOPAeNW`4M7Qj5Oooo`005?ooo`AcM7H4LW=d175aLPA`L704Kfi^0fm/
K0A^JfX4KFUX16aWIPA/IV@4JfAR0fYRH0AZHEh4JEmL16QMFPAXG5P4IeYF16MHE0=VEe84IUE@16ID
CPAWDdd4JU=<16aFC`A/FE@3JeYG16YKF@AYG5/4J5eL16MMG@AWGUd3IUiN26ENG`ATH644I69S16EU
I`AUJF/3IVe`16QaM@AZMgX4KGb11723R0AdR8h3NHnG17bGW`B1WjT4PYnY186KY@AoV:44OYFM0gjB
VPAmT9H4O8fC17^;T0AjR8h4NXN;0gV4R@AhPXH4Mh2317MnP@AfO7l4MGYl17AhNQGoool001Coool4
LgAf179cM0AaLG84L71`16m^KP=_K6`4KV]Z16eYJ0A/IfH4K6IT16]THP=ZHV04JV5N16UOG0AXGEX4
J5aH16MJEPAWF5@3IUMB16IED0AVE4h4Ie==16YCC0A/ETl4K5UD0f]JE`AZFeT4JEaK16QMG0AWGEd4
IeiM0fINGPQUGUl4I61Q16ARH`AUIFL4IFU[0fI]L0AXLGD4JWMj16elP@A`PhP4M8R>0gV?U`AlUil4
PInY18:OZ@B1VjD4OiRQ17jEW@=nTYX4OI2F17b=T`AkRi04NXR>17Z7R`=iQ8T4N8:617N0P`AgOX44
MWao17EjO0AdN7XEoooo000Doooo17=dMPAbLg@4LG5b171`L0A_KVh3Kfa/16i[JPA]JFP4K6MV16aV
I0A[I683JV9P16YQGPAYGe`4J5eJ16QLF0AWFUH4IeQD0fIGDPAVEE04IUA>16MCC@AZDd`4K5I?16aI
E0=[FUL4JU]I16ULF`AXGE`4IeeM16MNG@=VGUh8IEiO16APH@ATHV<4IFEW16EYJ`=VKG04J75e16Yg
NPA]O844L8>817B8SP=iSiL4O9NO186OZ@B2WjT4PI^U17nHX@AnUId3OY:J17f@UPAlSI<4Nh^@17Z8
SPAjQh/3NHB917R2QPAgP8<4Mgj117IlO`AeNW`4M7Qj5Oooo`005?ooo`AcM7H4LW=d175aLPA`L704
Kfi^0fm/K0A^JfX4KFUX16aWIPA/IV@4JfAR0fYRH0AZHEh4JEmL16QMFPAXG5P4IeYF16MHE0=VEe84
IUE@16IDCPAWDdd4JU=<16aFC`A/FE@3JeYG16YKF@AYG5/4J5eL16MMG@AWGUd3IUiN26ENG`ATH644
I69S16EUI`AUJF/3IVe`16QaM@AZMgX4KGb11723R0AdR8h3NHnG17bGW`B1WjT4PYnY186KY@AoV:44
OYFM0gjBVPAmT9H4O8fC17^;T0AjR8h4NXN;0gV4R@AhPXH4Mh2317MnP@AfO7l4MGYl17AhNQGoool0
01Coool4LgAe179bL`AaL744L6m_16m]K@=^JfX4KFUX16aWIPA[IF@4JV=Q16YQG`=YGed4J5iK16ML
F0AWFUH4IUQD16EFD@AUE4l3I59<16A@BPASCTP4Hda516aCB`A^Ee04K5MB0fYHE0AYFEH4J5YH16MK
F@AVFUX4IE]K0fAKF`ATFe`4HeaM16=NG`ASH684Hf=V16AXJP=UK6l4Ig5d16UgN`A/OH84L8>917B:
T@=iTYX4OIVR18:Q[0B2X:X4PIfW182KY0AoV:03OYFM17fBVPAmT9H4O8fC17^;T0AjR8h3NHJ;17V4
R0AhPHD4Mgn217ImP0AeNgd4M7Qj5Oooo`005?ooo`AcM7D4LW9c175`L@A`Kfl4Kfe]0fi[JPA]JFP4
K6MV16]UI0AZHf44JV5O0fUOG@AXGU/4IeaH16MJEPAVF5@4IEIA16EDC`=TDT`4I51:16=>B0ASC4D4
K5=;16iGD0A/Ee83JUQD16UIEPAXFUP4Ie]I16IJFPAUFe/3I5]K16AKG0ASG5d4HeiO16=PHPASHfH4
I6QZ0fE/K`AWLG@4JGMk16amPPA`PhT4M8ZA0gVBVPAmVJ84PZ6/18:PZPB1WJL4P9^T17nHX0=nUId4
OI:J17f@UPAlSI<4Nh^@17Z8SP=iQX/4NHB817R1Q@AgOh84MWf017EkO@AdN7XEoooo000Doooo17=d
M@AbLW<4LG1a171_K`A_KFd3KV]Z16eYJ0A/IfH4JfET16YSH@AZHEl3JEmM16QNF`AWG5P4IeYF16IH
E0AUEU44IEA?0fABC0ATD4X4Hdi816=<A@A/Dd/4KUM@16aGDP=ZF5@4JEUF16QJF0AWFeT4IUYJ16EK
F`=TFe/4I5]L16=LG@ASGUl4Hf1R16=SIPATJ6X3IFa_16MaM0AYMg/4K7f21723R@AdRY43NI:J17fI
XPB2XJ`4PZ2Z186MY`B0Vj@4OiRP0gjEW@AmTYX4OI2F17b=T`AkRi04NXR>0gV6R`AiQ8P4N86517Mo
PPAfOH04MG]m17AhNQGoool001Coool4LgAe179bL`AaL744L6m_16m]K@=^JfX4KFUX16aWIPA[IF@4
JV=Q16YQG`=YGed4J5iK16MLF0AWFUH4IUQD16EFD@AUE4l3I59<16A@BPASCTP4Hda516aCB`A^Ee04
K5MB0fYHE0AYFEH4J5YH16MKF@AVFUX4IE]K0fAKF`ATFe`4HeaM16=NG`ASH684Hf=V16AXJP=UK6l4
Ig5d16UgN`A/OH84L8>917B:T@=iTYX4OIVR18:Q[0B2X:X4PIfW182KY0AoV:03OYFM17fBVPAmT9H4
O8fC17^;T0AjR8h3NHJ;17V4R0AhPHD4Mgn217ImP0AeNgd4M7Qj5Oooo`005?ooo`AbM7D4LG9b171_
L0A_KVh4KVa[0feZJ@A/IfH4JfET16YSH@AYHEl4J5mL0fMMFPAVFUL4IUQD16EFDPATE4l4He9=16=@
BP=RCDL4HD]41618@@APAcl4LUM>16iFC`A[EU43JEIB16QGE0AWEeD4IUQG16EHE`ATF5P3HeQI169H
F@AQFEX4HEaL165OH0ARHfD4HfQZ0fA/K`AVLG@4JGMl16anP`A`Q8X4M8bC0gVCV`AmVZ@4PZ>^18:Q
[0B1WjT4PIfV182JX`=oV:04OYFM17jBV@AmT9H4O8fC17^:T0=jR8d4NHF:17R3Q`AgP8@4MWj117Ek
OPAdNG/Eoooo000Doooo179dM@AaLW84L6m`16m^KPA^K6/3KFYY16aWIPA[IF@4JV=Q16UQG`AXGe`3
IeeJ16IJE`AVF5@4IEIB16ADC`ASDTd4He1:0f9=A`AQBd@4H4Q11617?`AbEdh4KUI?16]FD@=YEU84
J5MD16MGE@AVF5L4IEQG16AHF0=SF5T4HUQI165IFPAQG5`4HEmP169SI@ASJ6X3I6a_16IaM0AYMg`4
K7j31724RPAdS9<3NI>K17fJY0B2Xjh4PZ6/186OZ@B1WJH4P9ZS0gnHX0AnUId4OY:I17f@UPAlSI<4
NhZ@0gZ8S@AiQHX4N8>717N0Q0AfOX44MG]n17AiNaGoool001Coool4LWAe175bLPA`Kg04Kfi^16i/
J`=]JVT4K6MV16]UI0AZHf44JF5O16QOG0=WGEX4IUYG16IHE0AUEU84I5A?16=BC@ASD4X3HTe7165;
A0APB444H4Lo179GCPA^ETl4JeIA0fUFDPAXEe@4IeME16IHE`AUF5L4I5QH0f=HF@ARF5T4HEUJ165L
G0AQGf04HV=U16=XJP=TK6l4IW5d16UgO0A/OX<4L8B:17B<T`=iTi/4OIZT18:S[PB2XJ`4PInY186M
YPB0VZ<3OiRP17jEW@AnTYT4OI2F17b=T`AkRY03NXR=17V5RPAhPhL4Mh2417InP@AeNgh4M7Uk5Ooo
o`005?ooo`AbM7D4LG9b171_L0A_KVh4KVa[0feZJ@A/IfH4JfET16YSH@AYHEl4J5mL0fMMFPAVFUL4
IUQD16EFDPATE4l4He9=16=@BP=RCDL4HD]41618@@APAcl4LUM>16iFC`A[EU43JEIB16QGE0AWEeD4
IUQG16EHE`ATF5P3HeQI169HF@AQFEX4HEaL165OH0ARHfD4HfQZ0fA/K`AVLG@4JGMl16anP`A`Q8X4
M8bC0gVCV`AmVZ@4PZ>^18:Q[0B1WjT4PIfV182JX`=oV:04OYFM17jBV@AmT9H4O8fC17^:T0=jR8d4
NHF:17R3Q`AgP8@4MWj117EkOPAdNG/Eoooo000Doooo179dM@AaLG84L6m_16m]K@A^JfX3K6QW16]V
I0AZHf84JF5O16QOG0AWG5T3IUYF16EGD`ATEE44He=>169@B`AQCTP4H4]50f19@PAOASl4G48k16Q<
@`AaETd4KEA=16YCC`=XDdl4IeAA16EDDPATEE@4HeEE169EE@=QEED4H5EF15mFF0AOFU/4GeeO161S
I@ARJ6X3Hfe_16EbM@AYN7`4K7n41725R`AdS9@3N9BL17fKY@B2Xjl4PZB_18:R[0B1WjX4P9fV0h2J
X`AoV:04OYFL17jBV@AmSiH4O8bB0g^:S`AjQh/4NHB817R1Q@AgOh84MWan17EiNaGoool001Coool4
LWAe175aLPA`Kfl4Kfe]16i[JP=/J6L4JfIT16YSHPAYHEl4J5mL16MLF@=VFUH4IEMC16AED@ASDdh4
HU1;165>B0APBdD3H4U215m6?`AL@S/4J4a3175FC@A]E4d4JU=?0fQCC`AWE544IEAB16AEE0ASEED4
HUEE0f5EE@APEEH4GeIH15mJF`AOGEl4H6=U169XJP=SKFl4IG9e16UhO0A/Oh@4L8F;17B<U0=hU9`4
OI^U18:S[`B2Y:l4PZ:/186OZPB0WJH3P9ZS17nHX0AnUI`4OY:I17f?UPAlS983NhZ?17Z7R`AiQ8P4
N86517MoPPAfO7h4MGUk5Oooo`005?ooo`AbM7D4LG5b171_K`A_KFd4KV]Z0faXI`A[IV@4JV=R16UQ
G`AXGe`4IeaI0fIJEPAUEe<4I5EA16=CCPARD4/4HDi8161;A@=PBD84GdHo15a2>`AXC4<4LEI=16eD
C@AZDdl3J5=?16MDD@AUE584I5ED16=EE@AREED3HEEE161EEPAOEUP4GeYK15mMG`APHfD4HVQZ0f=]
K`AULWD4JGQl16aoQ0A`QH/4M8bD0gRDW0AmVjD4PZ>_18:T[`B2XZ`4PInZ182MYP>0VZ<4OiRP17jE
W0AnTYT4OHnF17b<TP=kRXl4NXN;17V4R0AhPHD4Mgn217IlOPAeNG/Eoooo000Doooo179dM@AaLG84
L6m_16m]K@A^JfX3K6QW16]VI0AZHf84JF5O16QOG0AWG5T3IUYF16EGD`ATEE44He=>169@B`AQCTP4
H4]50f19@PAOASl4G48k16Q<@`AaETd4KEA=16YCC`=XDdl4IeAA16EDDPATEE@4HeEE169EE@=QEED4
H5EF15mFF0AOFU/4GeeO161SI@ARJ6X3Hfe_16EbM@AYN7`4K7n41725R`AdS9@3N9BL17fKY@B2Xjl4
PZB_18:R[0B1WjX4P9fV0h2JX`AoV:04OYFL17jBV@AmSiH4O8bB0g^:S`AjQh/4NHB817R1Q@AgOh84
MWan17EiNaGoool001Coool4LW=d175aL@A`KVh4KVa[16eZJ@=/IfH4JVAR16URG`AXGe`4IeaI16EJ
EP=TEe<4HeA@169BC@AQCdX4H4a615m:@`ANAd03GD@m15]0>0ASAch4KDm616a@B@AZDD/4J51<0fIA
C@AUDDh4I59@16=CDPARDe<4HE9C0emBD`ANDE84GUAF15eHF@ANG5h4Gf9T161XJP=RKFl4IG=f16Ui
O@A/P8D4LHN=17F=U@=hU9d4OI^U182R[@B3Y[84PZB`18:R[@B1X:X3PIfV182JX`AoUil4OiBL17jA
V0AmSYD3O8^A17^8S@AjQHT4N8>617MoP`AfO7l4MGUk5Oooo`005?ooo`AbLg@4LG5a171^KPA^K6/4
KFYY0faWIPAZI684JF9O16QOG0AWG5T4IEYF0fAGD`ASE504HU9=165?BPAPC4H4GdY315i7@0=MA3d4
Fd0h16=7?PA]CdH4K51916YAB`AXD4`3IU5=16EACPATDU04He=B169CD`AQDU<3Ge9C15iADPANE5H4
GEQI15iLGPAOHV@4H6QZ0f9]K`AULgH4JGUm16b0Q@AaQhd4MHfE0gRDW@AmVjD4P::]18>V/PB2Y;04
PZ:]186PZP>1WJH4P9ZS17nGW`AoU9`4OY6H17f>U@=lRi44NhR=17Z5R@AhPhH4Mgn317IlO`AeNG/E
oooo000Doooo179cM0AaLG44L6i^16i/J`A]JVT3K6MV16YTHPAYHUl4J5mL16MLF@AUFUH3I5MC16=D
D0ARDTd4HDm:161<APAOBT<4GTM00ee4?@AK@3P4HdLn16e?APA/D4T4JU5;16Q@C0=VDDd4IE5>16AB
D0ASDe84HU=C165BD`=ODU<4GU5B15iDEPAMF5T4GUaN15mRI0APJ6X3HVe_16EcMPAYNGd4K8251767
S@AeSID3N9BM17fKY@B0XZd4PjJb18:T/0B2XZd4PJ2Z0h6MYPB0VZ<4OiNO17nDW0AnTIP4OHjE0gb;
T@AkR8d4NXF917R3QPAgOh<4MWao17EiNaGoool001Coool4LW=d175aL@A`KVh4KVa[16eZJ@=/IfH4
JVAR16URG`AXGe`4IeaI16EJEP=TEe<4HeA@169BC@AQCdX4H4a615m:@`ANAd03GD@m15]0>0ASAch4
KDm616a@B@AZDD/4J51<0fIAC@AUDDh4I59@16=CDPARDe<4HE9C0emBD`ANDE84GUAF15eHF@ANG5h4
Gf9T161XJP=RKFl4IG=f16UiO@A/P8D4LHN=17F=U@=hU9d4OI^U182R[@B3Y[84PZB`18:R[@B1X:X3
PIfV182JX`AoUil4OiBL17jAV0AmSYD3O8^A17^8S@AjQHT4N8>617MoP`AfO7l4MGUk5Oooo`005?oo
o`AbLg@4LG1a16m]K@A^Jf/4K6QW0f]UI0AYHf44J61M16MMFPAUFUL4I5MC0f=DD0ARDD`4H4i915m;
APANBD84GDHo15a3>`=L@3P4Gd4h16]<@PAZC4<4JDe516Q=B0AVCDP3I4e916=>C0ARD4h4HE1@161A
D@APD543GU1A15a?D@ALDe@4G5MI15eMG`AMHF<4GfQZ0f1]L0ATM7L4J7Yn16f1QPAbR8h4MHjF0gRD
W@AlVZ@4Oj6/18:W/PB3Z;@4PZF`18:R[@>2X:X4PIfV182JXPB0Uil4OiBK17j@U`=mSI<4NhZ?17Z7
R`AiQ8L4N82317ImO`AeNG/Eoooo000Doooo179cM0AaL744Kfe]16i[J`A/J6L3JfET16USH@AXH5d4
IeeJ16EJE`ATEe<3HeA@169AC0APCTT4Gd]615i9@PAMASl4G4<k0ea0>0AO@CP4Jda216Y<@`AYCDD4
J4e816I=B0=TCDT4Hdi<169@CPAQD504H55A161@D@=ND544G4mA15aCE0ALEeT4GEeO15eQH`AOJ6X3
H6e`16AdM`AXNWh4KH6617:8SPAeSYH3N9BM17bJY0AoXJ`4PZNb18>X]0B2YK04PZ:]0h:PZPB1WJH4
P9ZR182GW`AoU9/4OY2G0gf=T`AkRXl4NXN;17V4Q`AhP8<4MWeo17EiNaGoool001Coool4LW=d175`
L@A_KFd4KV][16aXI`=[IF@4JF=Q16QPG@AWGEX4IEYG16AGD`=SE504HU5<161>B@AOBdH4GTU215e6
?`AL@c/3G40h15m1>0A[C484JTa316U=A@AXCDP4ITe80fA=B@ASCT`4HU1>165@D0APDE44H51A0ei@
D@ALCe44G5=D15aGF@AMGEl4GF5S15mXJP=PKG04I7Ag16QjOPA]PHH4LXR>17F>UP=hU9d4O9ZT17nQ
[0B2Yk84PjRd18:U/0B2XZd3PZ2Z186MYPB0VZ84P9NO17nDV`AnT9L3OHfC17^:S`AjQh/4NHB717R0
P`AfOGl4MGUk5Oooo`005?ooo`AbLg@4L71`16m]K@A]JVT4K6MV0fYTHPAYHEl4IeiK16IKE`ATF5@4
HeA@0f5AC0APCTT4GT]515e8@@ALACh4Fd8j15Xo=`=I?384J4Lm16U9@0AXBT84Id]316E;A@ATBTD3
HTY6165;B@AQCTd4H4m?15m?C`AOCU03GE1A15aBD`AJDe@4FeUJ15]LGPAKGV04GFIX0em]K`ATM7L4
JGao16f2QPAbRHl4MXnG0gREW@AkVZ@4OZ2[186U/@B4Z[L4PjRd18>U/@>3XZd4PZ2Y18:MYPB1VJ84
P9JN17nCV@=nSiD4O8bA17^8S@AiQHT4N86417ImP0AeNW`Eoooo000Doooo179cM0A`L704Kfe]16eZ
J@A/IfH3JVAR16UQG`AWGU/4IU]G16AHE0ASE503HE5<161>B@ANBdD4GDQ115a5?PAK@SX4FSlg0eTl
<PAXAcd4JDU016Q:@PAWBd<4ID]516A:A@=RBTH4HD]9165>C@APCdl4Gdm?15m>D0=MD544G59C15YC
E0AKFEX4FeaN15]NH0AMIVP3Gfe_16AdM`AYO7l4KH:617:9S`AfSiL3N9FM17^JY0AnX:/4PJFa18BZ
]`B3Z;@4PjFa0h>R[@B2X:T4PYfV186IXPB0UYh4Oi>I0gj?U@AlS944NhR=17V5R@AhPH@4MWf017Ej
O1Goool001Coool4LW=d171`L0A_KFd4KFYY16aWIP=ZI684JF5O16MNF`AVFeL4I5QD16=DD0=QDD`4
H4i915i;A@AMB444G4Dn15]2>PAJ?cL3FC`b16Q7?@AYBD04J4Y216M;@`AUBdD4I4Y50f9:APAQBdT4
HDi=161?C`AOCdl4Gdi@0ee@D@ALDU<4FU=D15]IFPAKG5h4FeiP15eVJ0=OKFl4I7Ag16UlO`A]PXH4
LXV?17J?U`=hUId4NiZT17jPZ`B1YK44Q:Zg18>X]0B3YK43Pj:]18:PZ@B2WJH4PIVR182FWPAoTiT3
OXnE17b<T@AkR8d4NHF917R1Q0AfOH04MGYl5Oooo`005?ooo`AbLg@4L71`16m]K@A]JVT4K6MV0fYT
HPAYHEl4IeiK16IKE`ATF5@4HeA@0f5AC0APCTT4GT]515e8@@ALACh4Fd8j15Xo=`=I?384J4Lm16U9
@0AXBT84Id]316E;A@ATBTD3HTY6165;B@AQCTd4H4m?15m?C`AOCU03GE1A15aBD`AJDe@4FeUJ15]L
GPAKGV04GFIX0em]K`ATM7L4JGao16f2QPAbRHl4MXnG0gREW@AkVZ@4OZ2[186U/@B4Z[L4PjRd18>U
/@>3XZd4PZ2Y18:MYPB1VJ84P9JN17nCV@=nSiD4O8bA17^8S@AiQHT4N86417ImP0AeNW`Eoooo000D
oooo179cM0A`Kg04KVa/16eYJ0A[IF@3JF=Q16QOG@AVG5T4I5UE16=ED@AQDTd3H4i915i;A@ALB444
Fd@m15Y1>@AI?SD4EcXa0edm<`A/BSl4JDU016M9@0AVBD<4I4Q31657@P=OAT<4GTQ715m<C0ANCDd4
G4e>165CE0=NDe<4G5EF15YFE`AJEeP4FEYL15QMG`AKI6L3GFY]16AcMPAYOH04KX>717>:T@AfT9P3
NIFN17ZJY0AmWjX4OjB`18:Y]PB3ZkP4PjRe0hBU/@B4Xjd4PinY18:LY@B1V:04P9FL0gnAU`AmSI<4
O8V>17Z6RPAhPXD4Mgj117EjO1Goool001Coool4LW=d171_L0A^K6`4KFUX16]UI0=YHf44J5mM16IL
F@ATFED4HeEA165BC@=PCTT4GT]515a8@@AKA3d4FT4i15Tn=@AG>S43GCdc16a:?`AYBD04IdU016I9
@`ATB4<4HDM20em6@`ANB4L4Gda<15i=C@ALCDh4HE=D0eiCD`ALEEH4FUIG15YGF0AIFU`4F5eO15]T
I`=MJVd4I7=f16UmP0A^PhL4LhZA17J@V0=iUIh4NYZT17fOZPAoY;04PZVf18>[^0B3Z;D3Q:Fa18BS
[@B3WjT4PYbU186HX0B0UI`3Oi6G17f=T`AlRHh4NXJ:17R2Q@AgOX44MGYl5Oooo`005?ooo`AbLg@4
L6m`16i/K0A]JFP4JfET0fUSH@AXGed4IUaI16AIE@ASEE44HE9=0f1>B@ANBdD4G4Q115]4?@AJ@CT4
FChe15Lj<@=M?C<4K4Xo16U9@0AWBD04ITU316A8@`AQAd83GdI315i8A`AOC4`4GTe=15a=CPAQDe@3
GU=C15aEEPAJEUL4FUMH15UJG0AHGEl4FfAW0eeZK@ATLgH4JGf016j3Q`AcRY44MY2H0gVEWPAjVZ@4
OInZ17nT/0B2ZKH4Pj^h18>X]@>4YK44Q:>]18>OZ@B2W:D4PIRP182EW0=oTIL4OHfC17b9SPAjQXX4
N8:517MnP@AeNW`Eoooo000Doooo179cM0A`Kg04KVa/16eYJ0A[IF@3JF=Q16QOG@AVG5T4I5UE16=E
D@AQDTd3H4i915i;A@ALB444Fd@m15Y1>@AI?SD4EcXa0edm<`A/BSl4JDU016M9@0AVBD<4I4Q31657
@P=OAT<4GTQ715m<C0ANCDd4G4e>165CE0=NDe<4G5EF15YFE`AJEeP4FEYL15QMG`AKI6L3GFY]16Ac
MPAYOH04KX>717>:T@AfT9P3NIFN17ZJY0AmWjX4OjB`18:Y]PB3ZkP4PjRe0hBU/@B4Xjd4PinY18:L
Y@B1V:04P9FL0gnAU`AmSI<4O8V>17Z6RPAhPXD4Mgj117EjO1Goool001Coool4LW9c171_K`A^Jf/4
K6QW16YTH`=XHEl4IeiK16EJE`ASEU<4HU=>161?BP=NC4H4G4Q215Y4?@AI@CT4Ecde15Hj<@AE=R`3
Id@h16]9?`AYB3l4ITLo16E8@PARAT04Gd@o0ea3@0ALATD4G4Y:161BD@AODe84HeQH0emEEPALEUL4
FUIG15QDE@AGFed4EeeP15QQI@=IIFP4HFmc16YlO`A`QHT4M8^A17NBV@=iUYh4NYVS17^MZ@AnXZh4
P:Re18>/^PB4ZkP3QJVe18FV/@B5Xj`4Q9nX18>KX`B1Uih3P9>I17j?U@AlRi04NhN;17V3QPAgOX44
MGYl5Oooo`005?ooo`AbLW<4L6m_16i[J`A/J6L4JVAS0fQQG`AWGU/4IEYG16=FD`ARDdh4H4m:0ei<
APALB484FT@m15U1>@AG?CD4ESXa15Df;0=WA3P4JdTo16U8?`AVAcl4IDQ21696@0AOA3l3G4=015a6
A@ALBTX4H59A15mCDPASF5P3GeEF15aFE`AJEUL4F5AE15MKG@AGGF04F65U0eUUJ0AQKg<4JWao1725
R@AdRi44Mi:I0gVFWPAjVJ<4NifY17jR[PB0Z;D4Pjbj18B[^0>5ZKD4QJJa18FS[0B4WjP4Pi^S186G
WP>0TiT4OXnE17b;T0AkQh/4NH>617MnP@AeNW`Eoooo000Doooo179bL`A`Kfl4KV][16aXI`AZI6<3
J65O16MNF`AUFUL4HeIC169CCPAPCdX3GTa615a8@PAJA3d4FD4i15Lm=@AF>S44ECH/0fM4>0A[BCl4
JDPo16I7?`AUB484HTI015m4?`=L@d04G4I515a:BPAPDU44Ge=B16=HF0=OEEH4G5IG15YFE`AHE5D4
Ee]M15MMH0AHHFD3FFEX165_L`AZO7l4L8F917B;T@AgTYT3NIJN17ZIX`AkWJT4OZ:^182X]@B3[;X4
Q:^h0hFY]@B5Y[44QJ>/18BOZ0B3Vj<4PINN0h2CV@AnSiD4O8^@17^7R`AiPhH4Mgj117EjO1Goool0
01Coool4LW9c171_K`A^Jf/4K6QW16YTH`=XHEl4IeiK16EJE`ASEU<4HU=>161?BP=NC4H4G4Q215Y4
?@AI@CT4Ecde15Hj<@AE=R`3Id@h16]9?`AYB3l4ITLo16E8@PARAT04Gd@o0ea3@0ALATD4G4Y:161B
D@AODe84HeQH0emEEPALEUL4FUIG15QDE@AGFed4EeeP15QQI@=IIFP4HFmc16YlO`A`QHT4M8^A17NB
V@=iUYh4NYVS17^MZ@AnXZh4P:Re18>/^PB4ZkP3QJVe18FV/@B5Xj`4Q9nX18>KX`B1Uih3P9>I17j?
U@AlRi04NhN;17V3QPAgOX44MGYl5Oooo`005?ooo`AaLW<4Kfi_16eZJPA[IfH4JF=R0fQPG@AVG5T4
I5QE169DD0APDD`4GTe70ea9@`AJACh4F44i15Hl=@AD>C04E3L^15Hf:`=^BSd4JdTn16Q8?PAUAcl4
HdM11615?`AM@Sd3FT8o15]5A@AJBTX4IEMF169FE@APEED3GUIF15]CE0AIE5@4Ee=E15MIG0AFFeh4
Ef1T0eQSI`ANKG44IgMk1764R0AeSI84N9>J0gVGW`AiVJ84NYbW17bQ[@AoYk@4PJ^j18B/^@>7[;T4
R:Ze18NV/0B6XZ/4Q9jV18>IX@>1UI`4Oi6F17f<T@AkR8`4NH>717MoPPAeNgdEoooo000Doooo175b
L`A_KVl4KFYZ16]WIPAYHf83J61M16ILF@ATF5D4HUA@161AC0ANCDL3G4U315Y5?PAH@CT4ES`e15@i
<0AD=bh4ESH[0fi:?@A[BCh4J4Pn16E7?`ASAd44H4Do15e2?@=J@Sl4FdE515Y:BPAUEeH4HUIE161E
E@=NEUH4Fe=D15UDE0AGDeD4EeUL15IKGPAGH6@3F6=W15i]L@AWMg/4LHB817F=TPAhTiX3NINO17VI
XPAjW:L4O:6]17nW]0B1ZkX4Q:bi0hN/^@B8Z[D4QjJ`18JRZ`B4WZH4PiVQ0h6EW0AoTIH4OHbA17^8
S0AiPhL4Mgn217EkOAGoool001Coool4LG9c16m^K`A]JVX4JfMV16USHP=XH5d4IUaI16AHE@ARE504
H55<15i=A`=LBD<4FTDn15Q1>@AF?3D4E3T`15@g;PAF=R/3KTXm16]9?PAXB3h4IDLo16=7@@APACl4
GD8m0eY2?`AKADD4FTY:16EGEPAREUD4H5EE0eiFEPAKDe@4FEAD15MCE@AGFE`4EU]N15MPI0=HHfL4
GVea16MgN`AaQ8P4MHfB17RCVP=iUil4NIVR17ZLY`AlXJd4OjNd186[^PB4[;T3Qjbi18RZ]@B7Y[04
QZ:[18BNYPB3VJ43PIFL17nAUPAmS944NhR<17V3Q`AgOh84MG]m5Oooo`005?ooo`AaLW<4Kfi_16eZ
JPA[IfH4JF=R0fQPG@AVG5T4I5QE169DD0APDD`4GTe70ea9@`AJACh4F44i15Hl=@AD>C04E3L^15Hf
:`=^BSd4JdTn16Q8?PAUAcl4HdM11615?`AM@Sd3FT8o15]5A@AJBTX4IEMF169FE@APEED3GUIF15]C
E0AIE5@4Ee=E15MIG0AFFeh4Ef1T0eQSI`ANKG44IgMk1764R0AeSI84N9>J0gVGW`AiVJ84NYbW17bQ
[@AoYk@4PJ^j18B/^@>7[;T4R:Ze18NV/0B6XZ/4Q9jV18>IX@>1UI`4Oi6F17f<T@AkR8`4NH>717Mo
PPAeNgdEoooo000Doooo175bL`A_KVh4KFYY16]VI@AYHV03IeiL16EJE`ASEU84HE9>15m>B@AMBTD3
FdI015U2>`AF?CH4DcP`14hb:@AD=B`4H3hb0fm;?`A[BCh4IdLn16A7?`ARAT04Gd@o15a1?@=KAD44
GDU815i>C@ATEE@4H5ED15iDE0=LE5@4FU5B15MBD`AFDU@4EUMJ15IKG@AHHVD3F6=W15a[L@ARLgP4
KGn517N>U0AiUI/3NINP17RHX@AhVjH4NYn/17fU/`B0Z[P4Q:fl0hN^_0B;[kT4RJZd18RU[PB6X:T4
Q9bS0h:GWPB0TYP4OXjC17b9S@AjQ8P4N7n217IkOAGoool001Coool4LG9c16m^KPA]JVT4JfIU16UR
H0=WGU`4IEYG16=FDPAQDTh4Gdi915e:A@=KAT04FD8k15Hm=PAC>304CS8Y15@e;0AP?S83Kd/o16]9
?PAWAch4I4Lo1696@0AOA3l4G44m0e]5@@AMBDP4GTi=16AEE0APEE@4GUAD0eaDE0AJDE84Ee9C15IB
E0AFEeX4EU]M15QRI@=HHfL4G6]a169cN0A]OhD4MhjD17VEV`=iUj04N9RQ17RKYPAjWj`4OJFc182Z
^0B4[K`3Qjjl18^_^@B9Z[@4R:F^18JPZ@B4W:<3PYNN182BV0AnSY<4O8V=17Z4R0AhOh84MW]m5Ooo
o`005?ooo`AaLW<4Kfi^16eZJ@A[IVD4JF9P0fMNG0AUFUL4HeIB165BCPAOCTT4GDY50e]6@0AI@S/4
ESdf15<h<0A><RT4E3D/160n<P=_Bcl4JdTn16M7?PATAcl4HTI015m4?`AL@Cd3FdE115e9B0ANCTd4
I5ED161EE0ANE5@3G5AD15YADPAGDU<4EU9D15IGFPAFFed4F69U0eQSI`ALJg44HW=h16eoQ@AgSY@4
NIFK0gVGX0AhV:44N9^V17ZO[0AmYK<4P:Zh18B]_0>7[[`4Rjni18VZ]0B8YJh4QZ2Y18BLX`>2Uih4
P9:H17j>T`AlRHd4NXB817QoPPAfNgdEoooo000Doooo175bL`A_KFh4K6UY16YUI0AXHEl3IUaJ16AI
E@ARE504H51;15i<A`ALB483FT@m15Po>0AE>S84D3@/14X^90AI>2h4K4Pl0fa:?PAYB3h4ITHn16=7
?`AQAT04GT@o15]2?P=KAT<4Gde;15m@CPAODE44GU9B15aCDP=JDU84F55A15IADPAEDe@4EEII15IK
GPAGHF@3FV=Y15e[L@AQLgP4JGf317J=TPAjUY/3NINO17NGX@AgVZD4NIj[17bT/@AnZ;H4P:^j0h^c
`0B=/[d4S:fh18ZX/PB8Xj`4QYjV0h>IX0B1U9X4OhnD17f:S`AjQHT4N82317IkOAGoool001Coool4
LG9c16m]KPA/JFT4JVET16QQG`=VG5X4I5UE169DD0APD4/4GTa715a8@P=JA3d4F3lh15Dj<PA@=2`4
BRhT15Th;PA/B3`3K4Xn16U8?PAVASh4HdLo1656@0ANA3l4Fd8n0e]6@`AOCD/4Ge1>15mAD@ANDU84
G5=B0eYBDPAHDE44EU5B15ECE0AEEUT4EU]N15MQI0=JHfT4GF]a165cN0AYOH<4MXfB17ZFV`=iUil4
MiNQ17NJY@AiWZ/4O:Ba17jX]PB0ZkX3Rk?018fb_@B<[KP4RZRb18RS[0B6WZH3PiVP186DVPAoSi@4
OHZ?17Z5R@AhP8<4MW]m5Oooo`005?ooo`AaLW<4Kfe^16aYJ@AZIF@4J65O0fILFPATFED4HUA@161@
B`ANC4L4G4Q20eY4?@AH?cP4ECXb150d;0A:;R@4FCP^16a8?0=/BSh4JDPn16I6?PASAcl4HDI015i4
?`AK@Sh3FdI315m=B`AOD4h4Ge5A15iBDPALDe83FU9B15QAD@AFDE84EE=D15EFF@AFFeh4Ef5T0eYS
J@AMJg44HG=h16UmP`AfSI84NYJK0gVGW`AgUj44MiZU17VNZ`AlY;44OZRf182[^P>;/l04SK:m18b]
^0B:Z;84R:>/18JNYP>3VJ04PIBJ17n?U0AmRXl4NXF917R0P`AfNgdEoooo000Doooo175bL`A_KFh4
K6UY16YUI0AXHEl3IUaJ16AIE@ARE504H51;15i<A`ALB483FT@m15Po>0AE>S84D3@/14X^90AI>2h4
K4Pl0fa:?PAYB3h4ITHn16=7?`AQAT04GT@o15]2?P=KAT<4Gde;15m@CPAODE44GU9B15aCDP=JDU84
F55A15IADPAEDe@4EEII15IKGPAGHF@3FV=Y15e[L@AQLgP4JGf317J=TPAjUY/3NINO17NGX@AgVZD4
NIj[17bT/@AnZ;H4P:^j0h^c`0B=/[d4S:fh18ZX/PB8Xj`4QYjV0h>IX0B1U9X4OhnD17f:S`AjQHT4
N82317IkOAGoool001Coool4LG5b16i]K@A/J6P4JFAR16MOG@=UFeP4HeMC161BCPANCTT4GDY415]6
?`=I@SX4Ecde15Di<0AA<bX4DC8W15hm<@A[B3`3JDPm16M7?@AUAcl4HTHo1616@0ANA3l4Fd<o0e]6
@`AOCT`4GU1?15iAD0ALDE04Fe5A0eU@D0AGCdl4E4m@15ABE0ACEEP4EEYM15IOH`=JI6X4GFaa169d
NPAYOX@4LHV@17RDVP=hUYh4MYNP17JIY0AgWJX4NZ:`17^V]@AlZKT3T;S6192e`PB?/K`4S:^e18ZV
[`B7X:P3QI^R18:FW0B0T9H4OH^@17^6RPAhPH@4MW]n5Oooo`005?ooo`AaLG84KVe]16aXJ0AYI684
IemM0fEKF0ASEe<4H59>15i>B@AMBT@4FdHo0eU2>PAG?CD4ECT`154c:PAA<RL4GSda16]8?0=YB3d4
IdLm16E7?`ARASl4H4I015i4?`AK@cl3FdI315m>C0AND4l4GU5@15aAD0AKDE43FE1@15M?C`ADCe04
E59D15=EF0AEFUd4EUmS0eYTJPAMK744HWAj16UnQ0AaRI04N9BJ0gRFWPAfUj04MYVT17NMZPAjX[04
NjJe17bY^@>@^<H4T;G218na_0B<ZkD4RZJ_18NPZ0>5Vj84PYJL182@UPAmRi04NhJ:17R1Q0AfNghE
oooo000Doooo175aLPA^KFd4K6QX16UTHPAWGed3IE]H16=GD`APDTh4GTi915e:A0AKASl3FD8j15Lm
=@AE>C04DC<Z154b9`AN?C44JdPl0fU8?@AWAcd4IDLo1696?`APAT04GT@o15]3?`=KAT<4Gdi<15i@
C`ANDE04G55@15]AD@=ID504Edm?15A?D0ADDU@4DeEH15EJG@AFGf<3FVAZ15e/L@ARM7X4JGj41769
T0AhU9X3N9JN17JGX0AfVJ@4MifZ17ZR/0AkY[D4O:Vi0i2haPB@]L84Sk6l18b[]@B:YZl4Qj2X0hFK
XPB2UY`4P92F17f;T0AkQXX4N86417IkOQGoool001Coool4LG5b16i]K@A/J6P4JFAR16MOG@=UFeP4
HeMC161BCPANCTT4GDY415]6?`=I@SX4Ecde15Di<0AA<bX4DC8W15hm<@A[B3`3JDPm16M7?@AUAcl4
HTHo1616@0ANA3l4Fd<o0e]6@`AOCT`4GU1?15iAD0ALDE04Fe5A0eU@D0AGCdl4E4m@15ABE0ACEEP4
EEYM15IOH`=JI6X4GFaa169dNPAYOX@4LHV@17RDVP=hUYh4MYNP17JIY0AgWJX4NZ:`17^V]@AlZKT3
T;S6192e`PB?/K`4S:^e18ZV[`B7X:P3QI^R18:FW0B0T9H4OH^@17^6RPAhPH@4MW]n5Oooo`005?oo
o`AaLG84KVa/16]XI`AYHf44IUiL0fAIEPAQEE44Ge1<15e<A`AKB484FT<l0ePo>0AG>c<4ECP^15Dd
:PAH=b/4GCdb16=3>0=UAS`4IDLn16=7@0AQAT04H4M015i5?`AKA3l3FdI315e<B@AND4l4GE5@15]@
D0AICdl3Edm?15E>CPACCTl4DU1B159EE`ACFE`4EEiS0eYUJPAOKG<4I7Ek16UnQ@A_Qhh4M92G0gJD
W@AeUIl4M9NS17JLZ@AiXJl4NJFd17ZX^0>B^/P4U;W5196d_`B>[[P4S:Ra18VRZ`>6WJ@4Q9NN186B
U`AnS944NhN;17V1Q0AfO7hEoooo000Doooo175aLPA^K6`4JfQW16USH@AVGU`3I5UF165ED@AOD4`4
GDa715]8@PAJ@c`3F3lh15Lk<`AE>2h4EC@Z15Pg:`AM?C84Hd<h0fE6?0AUAch4HdM01656@0APAd04
GTDo15]4?`=KAT<4GDa915i@C`AMDE04Fe1@15U?C`=GCdl4EDi>15=>C`ABD584DUEG15=IG0AEGV<3
FVEZ15m]L`ATMG/4JGj516n7SPAdT9L3MYBM17FEW`AdUj<4MYbY17VQ[`AiYK@4NZRh0i:jb0BD^LD4
TKBo18j^^0B<Z;44RJ:[0hJMY0B4Uih4PI:G17j<T@AkQh/4NH6417IlOQGoool001Coool4LG5b16i/
K0A[J6L4JF=Q16ING0=TFEH4HEEA15m@C0AMC4L4FdQ215Y3?0=H?cP4Ec/c15Dh;PAE=2X4F3L[15dm
<PAS@cP3IDHl16E7?PASAd04HDI01617@0ANACl4Fd@o0e]6@`AMC4T4GU1?15eAD0AKD504FDm?0eM?
C`AECTh4Ddi?159@DPABEEL4DeUL15ENH`=JIFX4Gfec16AeN`AYOXD4KhN>17B@U`=fU9d4MIFO17BG
X`AfW:T4NJ6_17VU]0AjZ;P3T[[819Bia@BA];l4SZjh18bX/@B9XZ/3QYfT18BGWPB1TYL4OXbA17^7
R`AiPH@4MWan5Oooo`005?ooo`AaLG84KVa/16]XI`AYHf44IUiL0fAIEPAQEE44Ge1<15e<A`AKB484
FT<l0ePo>0AG>c<4ECP^15Dd:PAH=b/4GCdb16=3>0=UAS`4IDLn16=7@0AQAT04H4M015i5?`AKA3l3
FdI315e<B@AND4l4GE5@15]@D0AICdl3Edm?15E>CPACCTl4DU1B159EE`ACFE`4EEiS0eYUJPAOKG<4
I7Ek16UnQ@A_Qhh4M92G0gJDW@AeUIl4M9NS17JLZ@AiXJl4NJFd17ZX^0>B^/P4U;W5196d_`B>[[P4
S:Ra18VRZ`>6WJ@4Q9NN186BU`AnS944NhN;17V1Q0AfO7hEoooo000Doooo171aLPA]K6`4JfMV16QR
H0AUGEX3HUQE161CC`ANCTX4G4Y415Y5?`AH@CX3Ecde15Hi<0AF=R`4EcDY15Ph;@AL?C84H48h0fA5
?0ATAcl4HTQ01657@0AOAT04GDE015a4?`=KAT84FdY715e@CPALDE04FU1@15Q>CP=FCTh4E4e>155<
CPAACe44DE=F159IG@AEGV<3FfI[15m^M0ATMW`4JGj516j6S@AbSIH3Li2J17>CWPAcUZ84MY^X17NP
[PAhY;<4MjJg0iBkb@BF_<P4U;O2196a^`B>Zk@4RjF]0hROYPB5VJ04PY>I17n=TPAlQh/4NH:517Il
OQGoool001Coool4L75b16e/K0A[IfH4J69P16EMFP=RF5D4H5=?15i>BPALBT@4FTDo15Q1>P=G?CD4
EST`15Hf;0AG=BT4F3P]15`m<PAP@SP3I4Dl16A7?`ARB404HDM015m6@0AMAD04G4@o0e]6@PAKBTL4
GE1>15aAD0AJD504F4i>0eI>CPADCDh4DDa>155?D@AADeH4DUUM15ENH`=KIV/4Gfid16AfO0AYOXD4
KXJ=17:=UP=cT9X4Li>N17>FXPAfVjP4Mj2^17RT/`AgY[L3U;_919Jlb0BD]l84TK6k18j[]0B;YJd3
R9nV18FIX0B2TiT4OhfB17b7R`AiPXD4MWan5Oooo`005?ooo`A`LG84KFa/16]WIPAXHV04IEeJ0f9H
E@APDdl4GTi:15a:A0AJACl4F44j0eLm=@AF>C04ESH/15Le:@AH>2d4G3db1612>0=TAC`4I4Lo1698
@0AQAd04GdI015e5@0ALA3l3FdI215]:A`AMD4h4G55@15Y@D0AHCTh3ETi>15A=CPAAC4h4DDmA155C
EPABFEd4EEiS0e]VJ`AOKW@4I7Il16UnQ@A^QXd4LXfF0g>@VPAcTih4LiJR17JKZ0AgX:h4N:Bc17NV
]`>D^lT4U[c819Bg`PBA/K/4SZ^d18^U[@>8WjH4QIVP18:CV@AoSI84O8N;17V2Q@AfO7hEoooo000D
oooo171aLPA]K6`4JfMV16QRH0AUGEX3HUQE161CC`ANCTX4G4Y415Y5?`AH@CX3Ecde15Hi<0AF=R`4
EcDY15Ph;@AL?C84H48h0fA5?0ATAcl4HTQ01657@0AOAT04GDE015a4?`=KAT84FdY715e@CPALDE04
FU1@15Q>CP=FCTh4E4e>155<CPAACe44DE=F159IG@AEGV<3FfI[15m^M0ATMW`4JGj516j6S@AbSIH3
Li2J17>CWPAcUZ84MY^X17NP[PAhY;<4MjJg0iBkb@BF_<P4U;O2196a^`B>Zk@4RjF]0hROYPB5VJ04
PY>I17n=TPAlQh/4NH:517IlOQGoool001Coool4L75a16e[J`AZIVD4If1O16AKF@=QEU<4GU5=15a<
A`AJAd44F4<l15Ln=`=F>c84ECL]15Dd:@AG=BT4F3P]15`n=0APA3/3HdHm1698@0AQB444H4M115m6
@0AMAD04G4E00eY6@PAJBDD4Fde<15]AD0AID4l4Edi>0eE>CPACCDh4D4]=14m>D0A@DUD4DUUM15EN
H`=KIf`4H6me16EgO@AYOXD4KHF=172;U0=`SYP4LI6L17>FX@AeVZL4Mj2]17VS/PAgYKD3T;S619Zo
c0BG^/H4TkBn18n]]`B<Yk03RJ2X18JJX@B3U9X4P8jC17f8S0AjPXD4Mgan5Oooo`005?ooo`A`LG44
KF][16YVI@AWH5l4I5]I0f5FD`ANDDd4G4a715Y7@@AH@c`4Echg0eHk<PAE=bd4EC@Y15Le:@AH>2d4
G3hd1614>`=SASd4HTQ01658@@APAd44GdI015e5@0ALAD03FTI215Y9A@AKCD`4Fe5@15U@C`AGCTh3
EDi>15==CPA@Bdd4Cdi@151BE@ABFEd4EEiS0e]WK0APKgD4IGMm16UnQ@A]QHd4L8^D0g2>V0AaTI`4
LiJQ17FJY`AgX:d4NJ>b17NU]@>@^<H4V[o<19NjaPBC];h4Sjfg18bW/0>9X:P4QYZQ18>DVPB0SY<4
OHR<17Z2Q@AgO7hEoooo000Doooo171aL@A]Jf/4JVIU16MPG`ATFeT3HEIC15iAC@ALC4L4FTM115Q3
?0AG?SL3ES/b15Dg;@AE=2T4EcDY15Ph;@AL?S@4H4@k0f=6?@ARB404HDQ11617@@AOAT04GDE015a5
@0=JAT84FTU515]=C0AKDE04FE1?15M>CP=ECTh4Dde>151;C@A?CU04D59E159IG@AEGV<3FfM/161_
M@AUMgd4JGj516f5S@A`Ri@3L8jH176AW0AcUZ44MIZW17NP[@AiXk84MjFe0i2haPBJ_l`4Uk[619>d
_PB?[KL4S:N`0hVPZ0B6VZ44PiBJ182>T`AmR8`4NX:517MlOQGoool001Coool4L75a16e[J`AZIVD4
If1O16AKF@=QEU<4GU5=15a<A`AJAd44F4<l15Ln=`=F>c84ECL]15Dd:@AG=BT4F3P]15`n=0APA3/3
HdHm1698@0AQB444H4M115m6@0AMAD04G4E00eY6@PAJBDD4Fde<15]AD0AID4l4Edi>0eE>CPACCDh4
D4]=14m>D0A@DUD4DUUM15ENH`=KIf`4H6me16EgO@AYOXD4KHF=172;U0=`SYP4LI6L17>FX@AeVZL4
Mj2]17VS/PAgYKD3T;S619Zoc0BG^/H4TkBn18n]]`B<Yk03RJ2X18JJX@B3U9X4P8jC17f8S0AjPXD4
Mgan5Oooo`005?ooo`A`L744K6YZ16UUI0AVGed4HUUG0emDD@AMCd/4FTY415Q5?`AF@3T4EC`d0e@h
;PAD=2X4E38V15He:PAH>2d4GT4g1695?@=RAcl4HTU11659@@AOB444GTI015e6@0AKAD03FTI215U8
A@AJC4X4Fe1@15U?C`AFCTh3E4e>155<C@A?Bdd4CTe@14mBEPABFEd4EEmT0e]WK0APKgH4IGQo16Yn
QPA/Q8d4KHRA0fj<UPA`T9/4LYFQ17FJY`AhWjd4NjBc17bW]P>;]<<4V;o<19^ob`BE]l84TJni18fY
/P>:XZX4QibS18BEW0B0Si@4OHV=17Z3QPAgO7lEoooo000Doooo171`L@A/JVX4JFET16IOG@ARFEL3
GeAA15e?B`AJBT@4F4Do15I0>@AE?3@3E3P^15@d:PAD<RH4ESDZ15Ph;@AN@CL4HTDm0f97?`ARBD44
HDU115m8@@ANAT04GDI015]5@0=JAT84FDQ515Y<BPAKD504FDm?15I>CP=DCDh4DDa=14m;C@A>CE04
Ce9F159IG@AEGf@3FfM/161_MPAUN7l4JWj616b4S@A]R943KXbF172@V`AbUJ44MIZW17RO[@AkY;<4
O:Nf0h^d``BH_l`4Vko;19Fg`PBA[kT4SJVb0hZRZPB7W:<4Q9FL182?U0AmRHd4NX>617MlOaGoool0
01Coool4L71a16aZJPAYIF@4IUmM169IE`=OE544GDm;15Y:A0AHACl4ET0i15Dl=0=D>2h4E3@Z15@b
9PAF=BX4F3P]15i1=`ARACd3HTLo1699@@AQBD44GdQ115i6@0AMAT04FdE00eY6@PAIB4D4FTa:15]@
D0AICdl4ETi>0eA=CPAAC4d4Cd]=14i=D0A?DUH4DUUM15EOI0=KIf`4H6mf16EhO`AZOXH4K8B=16f8
T@=^S9H4L92K17:EX@AeVZL4N9n]17^T/`AlYkH3RkC319Roc0BK_l/4UKO2196_^@B=ZK83RZ:Z18NL
X`B4UI`4P8nD17f9S@AjPhH4Mgao5Oooo`005?ooo`A`L744K6YZ16QTH`ATGU`4HEQE0eeBC`AKC4P4
F4M215I2?0AD?CH4DSP`0e8d:`AB<2D4DRlT15@d:@AI?344GdDl16=7?P=RBD04HDU11619@PAOB444
GDI015a6@0AKAT43FTM215U8A@AJCDX4FTm>15Q?C`AECDd3Dde>151:C0A=BT`4C4a?14iBEPAAFEd4
EV1T0eYWK@APL7L4IWR016UnQPA[Ph/4JhJ?0ff:U0A`SYX4LY>P17FIYPAiWjd4OJJd186Z^0>:/l84
UKo=19c1cPBF^<@4T[6k18jZ]0>;Y:`4R9fT18FGW@B1T9D4OXZ>17Z3QPAgOGlEoooo000Doooo171`
L@A/JVX4J6AS16ANG0AQF5D3GE9?15]<B0AHAd84ET8l15@m=PAB>303DS@[158`9@AB;b@4E3@Y15Tl
<@AOAC`4HdLn0f99@0AQBD44H4U215m8@@AMAT04G4I015]6@@=JAd84FDQ515Y=BPAJCdh4F4m?15E=
C@=CCDh4D4Y<14e:C0A<C4l4CU9F155IG@AFH6@3FVM]161`M`AVN804JGj616^3R`A[QXl3KHZD172>
VPAbTj04MIVV17VO[@AmY[@4PJZh0hZc`PBE_ld4W<7>19Jha0BB/K/4SZZd0h^T[0B8WJ@4QINM186@
U@AnRXh4NX>617MmOaGoool001Coool4L71a16aZJPAXI6<4I5iL165HE@=MDTl4Fda815Q7@PAF@S`4
E3df158h<0=B=2/4DS0U158_90AD=2T4FC`a15m5?0ASAch3HTU01659@@APBD84GdQ115e6@0ALAT04
FdI10eY7@PAIB4D4FTe:15Y?CPAHCdl4EDe=0e==CPA@BT`4CDY<14a<C`A>DUH4DEUM15IPI0=JIfd4
H71g16IhP0AYOXH4Jh>;16^6S`=]RY@4L8jJ17:CX0AeVJH4NIn]17fV]0B1Z[P3R[?219Foc@BL`Lh4
U[S419:a^`B>Z[@3RjB/18RMY0B5Uid4PI2E17j:SPAjPhH4Mgeo5Oooo`005?ooo`A`L744K6YZ16QT
H`ATGU`4HEQE0eeBC`AKC4P4F4M215I2?0AD?CH4DSP`0e8d:`AB<2D4DRlT15@d:@AI?344GdDl16=7
?P=RBD04HDU11619@PAOB444GDI015a6@0AKAT43FTM215U8A@AJCDX4FTm>15Q?C`AECDd3Dde>151:
C0A=BT`4C4a?14iBEPAAFEd4EV1T0eYWK@APL7L4IWR016UnQPA[Ph/4JhJ?0ff:U0A`SYX4LY>P17FI
YPAiWjd4OJJd186Z^0>:/l84UKo=19c1cPBF^<@4T[6k18jZ]0>;Y:`4R9fT18FGW@B1T9D4OXZ>17Z3
QPAgOGlEoooo000Doooo16m`L0A[JFT4If=R16=LFPAOEU<3Fe1<15Q:A@AEA3l4Dclh154i<PA?=B`3
Cc0W14l/8PA@;R<4E3D[15]1=PAQB3h4I4Y10f=:@@AQBD84H4U215i7@@AMAT04G4I015]6@@=IAd<4
FTU615Y=B`AJCdh4Edi>15E<C@=BC4d4CdU;14a:C0A;C4l4CE9F155IG@AFHFD3FVQ^165aN0AUN804
J7f516V1RPAZQ8h3K8RC16n=V0AbTil4MYVV17ZO[@AoYk@4Q:^i0hbea0BE`<l4U[g;19Fia0BB/[d4
Sjbe0hbU[PB9WZH4QIRN18:AUPAnRXl4NhB717MmOaGoool001Coool4Kg1`16]YJ@AWHf84HeaJ15mF
D`=KD4`4F4Y515E4?`AC?cP4DCTb14le;0=?<2L4Cb`R150^8`AD=B/4Fd4f1658?PATBT43HdY11659
@PAPBD84GTM115e6@0ALAT04FdI10eU7@`AJBDH4FTe;15Y?CPAGCTh4EDa=0e9<C@A?BD/4C4Y<14]<
C`A=DUH4DEUM15IQI@=JJ6h4HG5h16EhP0AXOHD4JH6:16Z4SP=/R9<4KhfH17:CW`AfVJH4NYn]17nW
]0B4ZkT3S;G419G0c`BF_L/4UKW419:b_@B?[;D3S:F^18VNYPB5V9h4PY6F17j:S`AkQ8L4Mgeo5Ooo
o`005?ooo`A_L704JfUY16MSHPASG5X4GeIC0e]@C0AHBTD4ED@o15<o>0AA>C84CcD/0dl`9`A?;284
D2hS15@e:`AK@CH4HDPn16A:@@=SBT44HDU21619@PANAd44GDI015a6@0AKAT43FDM315Y9APAJCD/4
FTm>15M>CPAEC4d3DTa=14m9B`A<BT`4Bda?14eBEPAAFEd4EV5U0eYXKPAQLGP4IGR016QmQ@AYPHX4
JXB>0fb8T`A_SIP4LY>O17JIYPAjWjd4OjNd18B[^@><]L@4UL3?19Jmb`BE^L@4T[:m18n/]@><YJh4
RIjV18FHWPB2TIH4OXZ?17^4Q`AgOGlEoooo000Doooo16m`L0A[JFT4If=R16=LFPAOEU<3Fe1<15Q:
A@AEA3l4Dclh154i<PA?=B`3Cc0W14l/8PA@;R<4E3D[15]1=PAQB3h4I4Y10f=:@@AQBD84H4U215i7
@@AMAT04G4I015]6@@=IAd<4FTU615Y=B`AJCdh4Edi>15E<C@=BC4d4CdU;14a:C0A;C4l4CE9F155I
G@AFHFD3FVQ^165aN0AUN804J7f516V1RPAZQ8h3K8RC16n=V0AbTil4MYVV17ZO[@AoYk@4Q:^i0hbe
a0BE`<l4U[g;19Fia0BB/[d4Sjbe0hbU[PB9WZH4QIRN18:AUPAnRXl4NhB717MmOaGoool001Coool4
Kfm`16YXJ0AUHF04HEYI15eDD@=ICDX4EDM31591?0A?>cD4CCH^14``:0=;;284C2XP14h^90AE>2d4
GTDj16A;@@AUBd<3Hd]31699@PAPB444GTM115a6@0AKAT44FTI20eU8A0AJBTL4FTi<15Y?C`AGCdh4
EDe>0e9;C@A>BD/4BTU;14Y<D0A<DUH4D5UN15EQI`=KJFl4H75h16AgOPAVNh@4Ign816V3S@=[Qi84
KXbH17:BWPAfV:D4NZ2/182W]@B5ZkT3S;K419BocPBF_/`4UK[619>d_`BA[KL3SJN_18ZPY`B7VIl4
Pi:G17n;S`AkQ8L4Mgeo5Oooo`005?ooo`A_Kg04JVQX16EQH0AQFUT4GEAA0eU=BPAEAd<4DT4l14lk
=@A==Rh4C30X0d//8PA<:R04CRhT15Dh;@ANACX4I4]116E;@`=SBd<4HTU21618@@ANAd44G4I015]6
@@AJAT83FDQ415Y:A`AJCT`4FTm?15M?CPAECDh3DT]=14i9B`A:BD/4BTa@14aBEPA@FEh4EF5W0e]Y
K`APLGP4I7Mn16IkQ0AWOhP4JH>=0f^7TPA^S9P4LY:N17JHY@AjX:`4P:Ne18F[^@><]/@4U;o>19Jn
c0BE^/H4TkBo196]]`>=Yjl4RZ2W18NIW`B3TYL4Oh^?17^4Q`AgOGlEoooo000Doooo16m_L0AZJ6P4
IF5P165JF@AME543FDe:15E7@`AB@C`4Cc/e14df;PA<<2P3Bb`R14`Z80A>;R@4ECP]15i5>PATBd44
ID]30f=;@`ARBD84H4Q115i7@@ALAT04FdI115Y6@P=IB4@4FTY715Y>C0AJCdl4Edm>15E=CP=BBdd4
CTU;14Y9B`A:C504C59F151IGPAEHFL3FfU_161aN0ATMgh4IW^416MoR0AYPhd3JhNB16j<V0AbTYh4
MYRU17ZP[0B0YkD4QJ^i0hbfa0BD_lh4U[k<19FjaPBC];l4TJfg0hfW[`B:X:L4QiVO18>BU`AoRhl4
NhB717MmOaGoool001Coool4Kfm`16YXJ0AUHF04HEYI15eDD@=ICDX4EDM31591?0A?>cD4CCH^14``
:0=;;284C2XP14h^90AE>2d4GTDj16A;@@AUBd<3Hd]31699@PAPB444GTM115a6@0AKAT44FTI20eU8
A0AJBTL4FTi<15Y?C`AGCdh4EDe>0e9;C@A>BD/4BTU;14Y<D0A<DUH4D5UN15EQI`=KJFl4H75h16Ag
OPAVNh@4Ign816V3S@=[Qi84KXbH17:BWPAfV:D4NZ2/182W]@B5ZkT3S;K419BocPBF_/`4UK[619>d
_`BA[KL3SJN_18ZPY`B7VIl4Pi:G17n;S`AkQ8L4Mgeo5Oooo`005?ooo`A^Kfl4JFMW16APG`AOFEL4
Fe9?0eI;A`ABA404Ccdh14`g<@A9<BX4Ab`S0dDV70A69ah4BbhU15Lk<@ASBCh4Idi416I=A0=UC4<4
HTY215m8@@AMAT04FdE015Y5@@AIAT83FTU515Y<B@AKCdd4Fe1?15Q@D0AECTl3DDa=14e9B`A:BD/4
BDa@14]BEPA@FEh4EF5W0eYYK`AOKgL4HWEm16AjPPAVOXL4J8:<0fZ6T@A^RiL4LI6N17JHY@AkWj`4
PJJd18JZ^0>=]/@4Tkc;19W2d0BG_<T4UKK119:_^@>?Z;44Rj6Y18RJX@B4TiP4P8b@17b5R0AhOH0E
oooo000Doooo16i_K`AYIfL4I61O15mIE`AKDTl3ET]71594@0A??CP4C3La14Ta:PA7;2<3ABHL14HW
7PA;;RD4Ec/a16=9?PAWCT@4ITe40fE<@`ARBT84GdQ115e6@0AKAD04FTE115U6@P=JBDD4FTa915]?
C@AKD4l4F51@15E>C`=AC4d4CDU;14Y9B`A9C504Be9F151IGPAEHFL3FVU_15m_M`ARMGd4I7Z216In
Q`AXPX`3JXJA16j;U`AaTIh4MYRU17^O[0B1Y[@4QZZh0hffa0BC_</4VL;@19Nlb@BE]/44TZni0hnX
/@B;XJT4R9ZQ18BCV0B0S904O8F817QmP1Goool001Coool4KVm_16UWI`ATH5l4GeUG15]BC`=FBdL4
DTA014lm>0A<=c44BC4Z14L/8`=59Q`4ARLN14/^9@AG>c44HdTn16M>A0AVCD@3IDa3169:@PAOB444
GDI015]5@0AJAD44FDI20eY9A@AJC4T4Fdm=15]@C`AHD504EDi?0e5<C@A=BD/4BTU;14U<D0A;DUH4
D5UN15EQI`=JJFl4Gfmg169eO@ATNX84IWj716R2S0=ZQY44KX^G176AWPAfV:D4Nin/186V]0B6Z[P3
SKK419>lb`BI`]04Ukc919Ff`@BB[kT3SjRa18^QZ@B8VZ44Q9>H182<T0AlQHP4N7f05Oooo`005?oo
o`A^Kfl4JFMW16APG`AOFEL4Fe9?0eI;A`ABA404Ccdh14`g<@A9<BX4Ab`S0dDV70A69ah4BbhU15Lk
<@ASBCh4Idi416I=A0=UC4<4HTY215m8@@AMAT04FdE015Y5@@AIAT83FTU515Y<B@AKCdd4Fe1?15Q@
D0AECTl3DDa=14e9B`A:BD/4BDa@14]BEPA@FEh4EF5W0eYYK`AOKgL4HWEm16AjPPAVOXL4J8:<0fZ6
T@A^RiL4LI6N17JHY@AkWj`4PJJd18JZ^0>=]/@4Tkc;19W2d0BG_<T4UKK119:_^@>?Z;44Rj6Y18RJ
X@B4TiP4P8b@17b5R0AhOH0Eoooo000Doooo16i^K`AXIVH4HUmN15eGE@AHCdd3DdQ514m1?@A;>SD4
Ac<]14@]9PA29al3?b0G13lT70A;<BP4FSle16Y>@`A/DDH4JDm60fI=A0ASBd<4GdQ115a6@0AIAD04
FDE115Q6@P=JBDH4Fde:15eACPALDU44FU9B15I?D0=AC4h4C4U;14U8B`A8Bdl4BU9F14iIGPADHFL3
F6Q_15a^M@AOLg`4HWR116AmQPAWPH`3JHJA16f;U`AaTId4MYNT17^N[0B0YK84QJVg0hjfa0BE_L/4
VlKD19Voc0BG^<<4U;6k0i6Z/`B=XjX4RIbR18FDV@B1SI44O8F917QnP1Goool001Coool4KVi_16QV
IPARGeh4GEME15Q?C@=CB4D4Cd4m14/j=@A7<bd4A2dV148W7`<o81L4?b@L14/a:0AJ?cD4JTi316aA
APAYCdH3ITe416=;@`AOB444G4I015U5@0AIAD44F4I20eY9APAKCDX4GE5>15aBD@AJDU84ETm@0e5<
CPA<BD/4BDQ;14Q;C`A:DUH4CUUN15AQI`=HJ6l4G6ie15mcO0ARN844I7f616N1S0=YQY44KH^G176A
W@AfUj@4Nij/182U/PB5ZKL3S[K419Fmb`BKa]@4VKo<19Nh``BD/K/3TJZc18fSZPB9W:84QIBI186=
T@AlQHT4N7j05Oooo`005?ooo`A^KVl4J6IV169OGPAMEeD4F4m=0e=8A@A?@Cd4BcXe14Lc;@A4;BH4
@RLO0clP5`@o91`4Bc4X15Xo=@AZCT<4K55616U?AP=VCD@4Hd]315m8@@ALAT04FDE015U5@@AHAT83
FTU615]=BPAMDDh4G59A15YBDPAFCe03DDa>14a9B`A9B4/4B4]?14YBEPA>FEh4E65W0eQXK`ALKWD4
Gg=l169hP@ATOHH4Ih6<0fV6T@A]RiL4LI6M17JGY0AkWZ`4P:Fb18FY]`>>]/@4UKg;19_6e0BI_l`4
UkS319Ba^`>AZ[<4SJ>Z18VLXPB5U9T4PHfA17b5R@AhOX0Eoooo000Doooo16e^KPAWIFD4HEeL15]E
D`AECD/3CdE214Xm>@A6=S44@RlY140Y8P@m8a/3>QhE13/S6`A:<RX4GD8h179DA`A`E4T4K5570fQ?
APATBd<4GTM115Y5@0AG@cl4ETA015M5@P=JBDH4GDm;15mBD0ANEE<4G5EE15MBDP=BCTl4C4U<14M8
B`A6Bdl4BE5E14aHGPAAH6H3EFI^15U/M0AMLWX4H7N116=lQ@AWPH`3JXJA16f;U`AaT9d4MIJS17ZM
Z`AoXk44Q:Rf0hnd`PBI`<h4W/WG19c2c`BI^lH4U[>m0i>/]@B?YJ`4RifS18JEV`B2SY84OHJ917Qn
P1Goool001Coool4KFi^16MUI@AQGE`4FeEC15E=B`=?AD84BSdi14Hf<@A2;bT4@2TR13dS6`<j7QD4
>b<K14Xb:PAM@SP4LUA7171DB@A/DDL3J4m616A;@`ANAd44FTE015M3?`AFA404EdE20eY9APAMCd/4
Ge9@15iED`ALEED4Ee9B0e9>C`A<BD`4AdQ;14I;C`A9DED4C5QN155PIP=EIVh4FFad15ebNPAPMh44
Hgb516N1S0=ZQY44KH^G176@W@AeUZ<4NYf[17nS/@B4Z;H3SkC219W0cPBNbML4W<;?19VkaPBF/kd3
Tjbe18nU[0B;WJ<4QYFK18:>TPAmQXT4N7j05Oooo`005?ooo`A]KVh4IfEU165MG0AKEE<4EDe;0dm5
@PA:?CT4ASHa148_:@A0:B84?B<K0cXN5@@k8a/4BS8Z15e2>0AbE4L4L5A916aAA`=XCdH4I4]315i7
@@AJAD04Ed<o15I4@0AGAD83FTU615e?B`AODU04GUEC15aEE@AGDU83DTi?14a9C0A7B4/4AT]?14UA
E@A<F5h4DF1V0eEVKPAIK7@4GG9j161gP@ASO8D4Ih6<0fZ6T@A]RiL4LI2M17FFX`AjWJ/4Oj>a18BX
]P>?]<84VL3>19k9e`BL`/l4VK_619Jc_@>C[;D4SjF/18^MX`B6UI/4PXjB17f6R@AhOX0Eoooo000D
oooo16e^KPAWIFD4HEeL15]ED`AECD/3CdE214Xm>@A6=S44@RlY140Y8P@m8a/3>QhE13/S6`A:<RX4
GD8h179DA`A`E4T4K5570fQ?APATBd<4GTM115Y5@0AG@cl4ETA015M5@P=JBDH4GDm;15mBD0ANEE<4
G5EE15MBDP=BCTl4C4U<14M8B`A6Bdl4BE5E14aHGPAAH6H3EFI^15U/M0AMLWX4H7N116=lQ@AWPH`3
JXJA16f;U`AaT9d4MIJS17ZMZ`AoXk44Q:Rf0hnd`PBI`<h4W/WG19c2c`BI^lH4U[>m0i>/]@B?YJ`4
RifS18JEV`B2SY84OHJ917QnP1Goool001Coool4KFe^16ITI0AOFe/4F5=A159:B0=;@Cl4ASTe144a
;@@m:RD4>R@N13PO5`<g7AH4=R4J14Tc:`AQAS`4N5Q;17AGC0A`E4X3Je5816E=A@ANB444FD@o15E2
?PAC@d04ETI30ea;A`AQDTh4HE=A165GE@APFUT4FEEE0e9?D0A;BT`4ATQ;14A:CPA6D5D4BEIM14mN
IP=BI6`4EVYb15Y`N@ANMWl4HW^516R2S0=ZQY44K8^G172@W@AeUZ<4NYbZ17jR/0B3YkD3T;C319g3
d@BRcM/4WlGA19bmb0BI][l3UJjf196V[PB<WZD4R9NL18>>T`AnQXX4NGj15Oooo`005?ooo`A]KFh4
IVAT15mKF`AHDe44DTY80d]1?`A6>CD4@C4]13dZ9@@j91h4>1lG0cLM5P@f8AX4BC<[1656?0AhF4/4
M5M<171DBP=[DDP4IDe515i8@@AIA3l4ED8n15=3@0AFAT<3G4]7165BCPAQDe44HEME161JF@AIEED3
DTm@14]:C0A6B4/4A4Y>14I@E@A9EUd4CeiV0e9TK0AFJW84FW1i15ifO`ARNhD4J8:<0fZ6T@A/RiL4
L92M17FFX`AjW:X4OZ:`18>W]@>@]<<4WL?A1:;=f`BOaM44W;g819Vf_`>E[[H4TJJ^18bNY@B8Ui`4
PhjC17j6RPAiOX4Eoooo000Doooo16e]KPAVI6@4Ge]K15QCD@ABBTP3Bd4o14Hi=@A1<Bd4?BXU13XT
7P@h7aL3=adF13HQ6PA9<b/4HDHl17QHB`AdEd`4L5A:0f]AB0AUCDD4GTQ115U4?`AE@Sh4Dd=015I6
@`=LBdL4HE9>165CD@AQEeD4H5YI15UEE@=BCe04BdY<14I8B`A4BTh4AU1E14UFG@A?GVH3DVA/15IZ
LPAJL7T4GWIo169kQ@AXPX`3JXJA16b;U`A`T9d4MIJS17ZLZPAnX[04PjNe0i2d``BM`m44X/gK19o5
d@BL_LP4VKJo0iF^]PBAYZh4S9jU18RGW0B3SY<4OXJ:17UnPAGoool001Coool4KFe^16ITI0AOFe/4
F5=A159:B0=;@Cl4ASTe144a;@@m:RD4>R@N13PO5`<g7AH4=R4J14Tc:`AQAS`4N5Q;17AGC0A`E4X3
Je5816E=A@ANB444FD@o15E2?PAC@d04ETI30ea;A`AQDTh4HE=A165GE@APFUT4FEEE0e9?D0A;BT`4
ATQ;14A:CPA6D5D4BEIM14mNIP=BI6`4EVYb15Y`N@ANMWl4HW^516R2S0=ZQY44K8^G172@W@AeUZ<4
NYbZ17jR/0B3YkD3T;C319g3d@BRcM/4WlGA19bmb0BI][l3UJjf196V[PB<WZD4R9NL18>>T`AnQXX4
NGj15Oooo`005?ooo`A/KFh4I6=T15eJFPAED4l4CTM50dLn>`A0=344>R`X13DT7`@d7aT4=1`D0cDN
60@e8ad4BcH^16I:?`AnGDl4NEY>17=GC0=]DdX4Idm7165:A0AJAT04EdE11552@0AFAT<3Gdi916AE
D@AVEe@4IE]I16=MG0AJEeP3DU1B14]:C0A5AdX4@TU=14A>E0A5DUX4CEiV0diRJPA@IW04EVef15ee
O`ARNhD4J8:<0f^6TPA]RiL4KhnM17BEX`AiVjT4O:2_18>W]P>C]l@4XLKC1:K@g@BSam<4Wl3:19bh
`@>H/;P4TjR_18jPYPB9V9d4Q8nD17j7RPAiOh4Eoooo000Doooo16a]KPATHf@4GEYJ15E@C`A>AdD3
Achk140d<@@j;2P4=B@O13@O6@@d71@3=AhH13DS7@A;=Rh4ITXo17iMC`AiFTh4LeM<0feCBPAWCdL4
HDY415Y6@0AGAD44DD9015I6@`=OCTT4I5EA16IGE0AUFeT4HeeL15YGF0=BD584BdY<14E7BPA2BDd4
A4iD14EBFPA=GVH3CV9Z151VL0AFKGH4GGEo169kQ@AXPX`3JhJB16f;U`A_Sid4M9FS17VKZ@AlX:l4
PjNf0i>ga0BQa]<4Y]3M1:?7d`BO`<X4W;S10iR`^0BCZ:l4SZ2V18VHW@B4Si@4OXN:17UoPAGoool0
01Coool4K6e^16ASI0AMFUX4EE1?14i7A@=7?S/4@3@a13X/:0@e91l4=1lI13@L50<e7QP4=B<M14/f
;PAVBSl4OUe?17UJCPAcEd`3KE=:16M?A`AQBT@4FTI015M5@@AA@T04ETI30em>B@ATEE44IUMD16EK
F@ASGE`4FUMH0e9@DPA;BT`4ADM:1499C@A4CU@4AE9J14eNIP=>HVX4D6I`15I]MPAMMGl4HW^516R2
S0=[QY84KH^G16n?W@AdUJ<4NI^Y17bP[`B3YkH3TkO41:76d`BVd=d4XlOC19o0bPBL^<43V;2h19>X
[`B>X:H4RIRM18B?U0AnQhX4NGn15Oooo`005?ooo`A/KFh4I6=T15eJFPAED4l4CTM50dLn>`A0=344
>R`X13DT7`@d7aT4=1`D0cDN60@e8ad4BcH^16I:?`AnGDl4NEY>17=GC0=]DdX4Idm7165:A0AJAT04
EdE11552@0AFAT<3Gdi916AED@AVEe@4IE]I16=MG0AJEeP3DU1B14]:C0A5AdX4@TU=14A>E0A5DUX4
CEiV0diRJPA@IW04EVef15eeO`ARNhD4J8:<0f^6TPA]RiL4KhnM17BEX`AiVjT4O:2_18>W]P>C]l@4
XLKC1:K@g@BSam<4Wl3:19bh`@>H/;P4TjR_18jPYPB9V9d4Q8nD17j7RPAiOh4Eoooo000Doooo16]/
K@ASHf<4FeQH15=>CPA:A4<3@SXh13X_;@@b9B84;1`H12PE40@d7AH3=B4K13TW8@A=>C44JTe218=Q
D`AmGU44MUU?0g1EC0AZDDX4I4i815e9A0AJAd<4EDE215U9AP=OCd/4IEIB16QJE`AWGE/4HEaL15YH
F@=BDE84BTY<14A7BPA1B4d4@TeC14=AFPA9GFD3B5iX14YRK@AFK7H4GGEo165jQ0AYPX`3K8NB16n<
V0A_T9d4LYFS17NIZ0AiWjh4PZNf0iJiaPBWbMH4Z];N1:K:e@BS`/d4Wk_40i^c^PBFZ[44TJ:X18^I
WPB5T9@4OhR;17UoPAGoool001Coool4Jfa]16=SH`AKF5P4Ddi>14Y4@`=2>SP4>Rl]138U8P@/71P4
:1D@13@M5P<e8A/4>BLQ14di<@AZCD84Pf5C17eND@AfFDl3L5E<16YABPATCTP4GDU415Y7@`AEAD84
FDU60em?B`AUEU84J5YG16MMF`AQG5`4FUQI0e9ADPA:BT`4A4M:1458C@A2CE<4@e5J14UMI@=8GVP4
BV9]15I/MPAMMGl4HGZ416V2S0=/Qi84KhbH16n@W@AbUJ<4MiVX17VO[PB2YkH3U[W61:O9ePBZd]h4
Y/[E1:?2c@BO^l@3Vk>j19JZ/@BAXZP4RiVN18F@U0AoR8/4NGn15Oooo`005?ooo`A[K6d4Hf=S15]H
F0ACCTh4BTA30d8j>0@j;bd4<RDR12`L60@X5A04=1dF0cDQ6`@i9b44CCTa16Y=@PB3HE<4OEiA17II
C`=`ED`4JU5:16A>B0AMBD@4FTM315E5@PAIBDH3Gdm;16EFDPAXFUL4IeeK165LG0AJF5T3DU5B14Y:
C0A4AdX4@DQ=149=D`A3DEX4BEeU0dQNJ0A:HVd4EVaf15eeO`AQNX@4JH:<0fb7TPA_S9P4Ki2M17:E
X`AgVJP4NIn^18:W]P>F^LH4YlWF1:[BgPBVb]D4Xl;=19nka0>K/kX4UZZa196RZ0B;VIh4QI2D17n8
R`AiOh4Eoooo000Doooo16]/K@ASHf<4FeQH15=>CPA:A4<3@SXh13X_;@@b9B84;1`H12PE40@d7AH3
=B4K13TW8@A=>C44JTe218=QD`AmGU44MUU?0g1EC0AZDDX4I4i815e9A0AJAd<4EDE215U9AP=OCd/4
IEIB16QJE`AWGE/4HEaL15YHF@=BDE84BTY<14A7BPA1B4d4@TeC14=AFPA9GFD3B5iX14YRK@AFK7H4
GGEo165jQ0AYPX`3K8NB16n<V0A_T9d4LYFS17NIZ0AiWjh4PZNf0iJiaPBWbMH4Z];N1:K:e@BS`/d4
Wk_40i^c^PBFZ[44TJ:X18^IWPB5T9@4OhR;17UoPAGoool001Coool4Jfa]169RHPAIEeL4D4a<14M1
@0<m=S@4=2XX12TN6`@N40d4810<134M60<h9R04?B`V15<m=@A^DDD4QfEF181QE0AjG583LUI>16aD
C0AXDT`4HDi815e:APAJBDH4G4a80em@C0ATEU84Ie]H16ELF`APFe/4FEMH0e9@DPA:BT`4A4M;1458
C@A1CE<4@e9J14IJH`=6G6H4AEmZ15M]MPALM7h4H7V416^3S@=]R9<4KhfI16j?W@A`Tj84LiRW17BL
[0B3Z;L3VK[71:c<e`B_eN44ZlgH1:S5c`BS_LH3W[Fm19V//`BCY:T4SI^O18NBU@B0R8/4NWn15Ooo
o`005?ooo`A[K6d4HV9R15UGE`A@C4`4Ad500cdf=0@d:RP4:AhK11h@3@@P40`4<AdH0cPV80@m;2H4
Dcde16iAA@B7IEH4P65D17YLDP=bETh4K5A<16QBC0AQCTP4GDY615Y9APALC4P3Ge1<16AFDPAWFeP4
IEaK161KF`AIEeP3DU1B14Y:C0A4Ad/4@DQ=145=D`A3DUX4AUYS0dILIPA5GfX4Efef15adOPAPNH@4
Jh>=0ff8T`A_SIT4KXnM172CXPAcV:L4M9b/18>X]`>I^/L4[<cG1:oEh@B[cMP4Z<G?1:>maP>N]Kd4
VJbc19>TZ@B=Vil4Qi:E1828R`AjOh4Eoooo000Doooo16]/K@ARHV84FEMG151<C0A7@D03?CHd13@Z
:0@Y7Q/47Q0=120@30@a7AP3>2HP13d/9PAC?CD4KU5518MUEPB0HE@4NUaB0g9FCPA/E4`4J59<165>
B0AMBTH4FTU615a<B0=OD4`4I5IB16MKF0AUG5/4H5]K15UGF0=BD584BTY<14A7B`A1B4d4@DeC14=B
FPA6FV<3AUaV14EOJPAGKGH4G7An161iQ0A[Phd3KHRC16n=V@A^Sid4L9>R17>HY`AdW:`4PjRg0iVj
a`B/c=L4[mGQ1:_=f0BXaLl4Xkg60ije_@BI[;<4TjBY18fKW`B7TYD4P8R;17YoPAGoool001Coool4
Jfa]169RHPAIEeL4D4a<14M1@0<m=S@4=2XX12TN6`@N40d4810<134M60<h9R04?B`V15<m=@A^DDD4
QfEF181QE0AjG583LUI>16aDC0AXDT`4HDi815e:APAJBDH4G4a80em@C0ATEU84Ie]H16ELF`APFe/4
FEMH0e9@DPA:BT`4A4M;1458C@A1CE<4@e9J14IJH`=6G6H4AEmZ15M]MPALM7h4H7V416^3S@=]R9<4
KhfI16j?W@A`Tj84LiRW17BL[0B3Z;L3VK[71:c<e`B_eN44ZlgH1:S5c`BS_LH3W[Fm19V//`BCY:T4
SI^O18NBU@B0R8/4NWn15Oooo`005?ooo`AZJf`4HF5Q15MEE@A=BTX4@chn0cTb<@@^9R@48APF1187
1@@O4@h4;1/G0cTY8`A4<R/4G4@j17AEB@B:IeT4Q6AG17eOE@=eFU44KUM?16UCC@ATDD/4Gdi915e<
B0AMCTX3H59>16=FD`AUFUL4I5eK15mJFPAIEUL3DE1B14U:C@A3B4`4@4Q=141=D`A2DUX4AUUR0dIL
I`A8HF`4E6]e15YbO@APNH@4JX:=0f^7TPA[RiP4K8jL16fBX@A_UJD4LIVZ18JZ^0>M_<T4/<cH1;CI
i0BadM/4[LWB1:S1b@>R^;l4W:ne19JVZ`B?W:44R9>F1869S0AjP88Eoooo000Doooo16Y[K0AQHF44
EeEE14e:BPA3?Sh3>C8a12hV90@Q61H44PL511lA3P@/6aL3>BTS14@b:`ALA3X4M5E918YWF@B4I5L4
OEmE0gEJD@A^Edl4JE==16AAB`AOCTT4GDa815e>BP=PDTh4HeIC16EJE`ATGE/4GeYJ15UFE`=AD584
BDY=14=8C0A0B4d4@4eC149BFPA6FF83AUaW14QQK0ADJgD4FW9m161iQ0AZPXd3JhNB16^;V0A/SY`4
KI:Q16nEY@AaVJX4QZZh0iflb@B`c=P4]=WT1;7Af`B]bM84Z<790j:h_`BL[kD4UZJ[18nLX@B8TiH4
PHV<17Z0PQGoool001Coool4JV]/165QH@AGEED4CDY:14<n?P<i<S44;RHT124H5P@B1`D47a4>12`K
5`<i:B<4A38[15a4>PAdEDT4RVMI18ATE`AmGeD3MEYA16iGC`AYDdd4I55;15m>B@AMC4P4GDi:0f1B
CPASEU<4IEYG16AMF`AOFUX4FEIG0e5@DPA9BTd4@dQ<1418C@A0CE<4@U9J14IIHP=6G6L4B65/15A[
M@AJLWd4H7V416Z2S@=[Qi84Jh^H16b>W0A]TZ44KiFU176IZPB6Z[P3WKc91;3<f0BdfN@4/M7K1:g9
dPBX`LT3X[Ro19b_]@BFYZ/4SibQ18RCUPB1RH`4NX225Oooo`005?ooo`AYJf`4Gf1P15EDE0A;B4P4
@3`l0cD_;`@Y8R4471@B10d40P@J3``4:1/G0cPY8`A9=Rl4HDLm17QIC@B<JE/4QfMK181SF@=iGeH4
LUYB16aFD0AWE4l4HU9>16=BC@AQDTh3HeEA16AGE0AUFUP4I5eK15iIF@AGE5D3D4iA14U;CPA3BDd4
@4Q>13i;DPA0DET4AEUR0dQMI`A<Hfd4DVYd15M`N`AMN8<4I7n;0fJ4T0AWR9H4J8bJ16V?W`AYTZ<4
KiRY18R[^P>T_l/4/<cG1;WKiPBgeMh4/lgF1:g4c0>W^l84X;6g19VX[@BAWZ84RYBG18>:S@AkP88E
oooo000Doooo16U[K0AOH604EEAD14]8B0A0?3`3=Bl_12TR8@@L51843@@211X?30@X6aL3>2TS14Tf
;`AQAcd4N5U=18aYF`B7Ie/4P6=I0gUOEPAbFU84K5I@16MDC`ARDTh4He9=165BCP=SEE44I5MD16EJ
F0ATGE/4GUUI15MDE@=@CU44BD]>14=9C@A0B4h4?T]B141AF@A5FF83B5eW14aSK@ABJW@4Eg1k15eh
P`ATOh/3IXB@16N8UPAXS9X4JHnO16VBX`A_V:T4R:^j0jBob`B`c=L4^M_V1;OEgPBccMH4[LC<0jNk
`PBP/KL4VJR]196NXPB:U9L4PhZ=17^0PQGoool001Coool4JF]/15mPH0AEE5@4BdQ8140l?0<e;bl4
:B8Q11`D4P@=10846Pl<12PK5`<h:B<4BCH_1657?@AhFDd4S6UK18MWF`B0HeT3NEmF179JDPA/EU04
IeA?169BCPASDTd4HE9>0f=ED@ATEe@4IEYH16AMF`ANFET4EeAE0e1>D@A9Bdh4@dU=1418CP@nBe84
@55I14EIHP=8GFL4C6=]159ZM0AGL7/4GGR316AoR`=VQ904IhRF16R<VPAYSil4JI:S16nHZ@B8ZkX3
Y;o;1;3<e`BifnH4]mGN1;?=ePB]a<`3Yk_21:2a]`BIZ:d4TIjR18ZDU`B3RXd4Nh225Oooo`005?oo
o`AYJf`4Gf1P15EDE0A;B4P4@3`l0cD_;`@Y8R4471@B10d40P@J3``4:1/G0cPY8`A9=Rl4HDLm17QI
C@B<JE/4QfMK181SF@=iGeH4LUYB16aFD0AWE4l4HU9>16=BC@AQDTh3HeEA16AGE0AUFUP4I5eK15iI
F@AGE5D3D4iA14U;CPA3BDd4@4Q>13i;DPA0DET4AEUR0dQMI`A<Hfd4DVYd15M`N`AMN8<4I7n;0fJ4
T0AWR9H4J8bJ16V?W`AYTZ<4KiRY18R[^P>T_l/4/<cG1;WKiPBgeMh4/lgF1:g4c0>W^l84X;6g19VX
[@BAWZ84RYBG18>:S@AkP88Eoooo000Doooo16UZJ`ANGel4E5=C14U7A`@m>SX3<Rd]12DP7`@H4A04
2@8111D=2`@V6aL3>2TS14/g<0ASBCl4NU]?18eYF`B;JUh4Q6ML0geSFPAfGeL4L5]D16YHD`AWEe84
IeIB16AFD@=TEe<4HeMD16=IEPAPFEL4FeIF15EADP=?CU04BDa?14A:C`A1BU04?T]B13i?F0A2Ef03
AUaV14eSKPAAJWD4EFmj15UeP@ANNhP3HH2>16>5U0AURIT4IHbL16B?X0A_VJX4Rjfk0jO0b`B_bmH4
^MWT1<7Li0Bjd]X4/lS?0jbna0BT];T4W:Z^19BOX`B<UIP4Q8^=17b0PQGoool001Coool4JFY[15iO
G`ADDe<4BDM713dj>P<b;Bd49B0O11PA40@90P445@d;12HK5`<h:B<4BcL`16=9?`AjFdl4SFUK18]Z
GPB4Ie`3OF=J17IOE`A`Fe@4JUQC16MGDPAWEU84I5IA0fAGD`ASEe@4HeUF161IE`AKEUH4EE5B0dm>
D0A9C4l4A4Y?145:D0@nBe84?TmH149GH0=6G6H4CF=^155ZM@AEKgX4FGF115ikR0=QP8h4HhFD16F9
V@AUS9`4I8nP16nIZPB;[K/3Yl3;1:o;ePBifN@4`McT1;[BfPBcb<l3[;k41:Bd^@BLZZh4U9nS18bE
V0B4Rhd4O8225Oooo`005?ooo`AYJV/4GUmO15ACD`A9AdL4?CXj0c8];@@U81l4614@10T20@@E3@/4
9Q/G0cPY8`A;=c04HdTo17YKC`B=JE/4RfYN18AWG0=mHeX4MUmG171KE0AZF5<4IeMB16MFDPATEU43
I5MC16=GE0ASFEH4H5UG15]FEPAEDE83Cdi@14U<C`A4BTl4@DY@13i;DP@nCeP4@UMP0dILIPA=Hfh4
DFYe15E_NPAIMH44GW^80f60SPASQI@4IHVI16F<W0ATSj04KiVZ18^]^`>W`</4[l_F1;WIi0C1g>@4
^];J1;?8c`>/_/@4Y;Bi19bZ[PBDWj<4S9FH18B;S@AlP88Eoooo000Doooo16UZJ`ANGel4E5=C14U7
A`@m>SX3<Rd]12DP7`@H4A042@8111D=2`@V6aL3>2TS14/g<0ASBCl4NU]?18eYF`B;JUh4Q6ML0geS
FPAfGeL4L5]D16YHD`AWEe84IeIB16AFD@=TEe<4HeMD16=IEPAPFEL4FeIF15EADP=?CU04BDa?14A:
C`A1BU04?T]B13i?F0A2Ef03AUaV14eSKPAAJWD4EFmj15UeP@ANNhP3HH2>16>5U0AURIT4IHbL16B?
X0A_VJX4Rjfk0jO0b`B_bmH4^MWT1<7Li0Bjd]X4/lS?0jbna0BT];T4W:Z^19BOX`B<UIP4Q8^=17b0
PQGoool001Coool4JFY[15iNG`ABDU84AdI613/i>@<_;2/48QhN11D@3`@70@044``:12@J5P<g:2<4
BcPa16A:@0AjFdl4S6UK18e]H0B7JV03P6IN17USG0AcGeT4KUaG16]JEPAXFE@4IUMC0fAGD`AREU<4
H5IC15aDD`AIDe<4DdmA0di=C`A:C4l4AT]A149<DP@oCED4?DmH141EGP=3FV@4BV9/14iXL`ACKWX4
EWB015]iQP=NOX`4HHBC16:7U`APRYX4GhbN17:K[0B<[[`3Xkk91;;<ePBmf^@4c>C[1<;Hg`BjcM<3
/L;71:Rg_0BO[;04UZ6U18jFV@B5Rhh4O8635Oooo`005?ooo`AYJV/4GUiO159BDPA7ATH4>cTi0bl/
:`@R7Qh45A0?10L100@C30X491XF0cLX8`A;>344I4Y017YKC`B<JE/4SFeP18MZH0>0IUh4NF=L17=O
F@A^G5L4JeYF16QIE0AVEe<3I5MC169FD`APEU<4G5AC15UCD`ACCe43CTe?14Y<C`A6Be44@TaB13m=
E@@mCeP4@5EN0d=JI0A:HV`4CVQc15=^NPAFM804FgV60einS0AQQ9<4HXNG162:VPAOS9h4LY^/18b^
_0>S_/T4//cF1;gJi0C<i>/4`]SO1;[=d`>a`/L4Z;Nl19n//0BFXJD4SYJI18F;SPAlPH<Eoooo000D
oooo16UZJ`ANGUl4DU9B14M6AP@k>CT3;b`[128N7P@E40l41`4011<<2P@T6QH3=bPS14/h<@ATBT04
NU]?18aYF`B=KF04QfYP0h1VGPAiHe`4LemI16iLE`A[FUH4J5UD16IGD`=TEe<4HUIC161FD`ALE5<4
FE=C15=?D@=>CDl4BTa?14I;D@A2C584?deE13e?F0A0EEh3@eYT14YRK0A>J7<4Dfij15IdP0AKNHH3
GWj<1664T`ARQiL4H8ZJ15n<WPAbVj`4S:jl0j>nb@Bbc=H4_M[T1<cTj`C2f=l4^/gC0k72a`BX]k`4
Wjb`19JQY@B>UYT4QH^>17b1PaGoool001Coool4JFY[15iNG`ABDU84AdI613/i>@<_;2/48QhN11D@
3`@70@044``:12@J5P<g:2<4BcPa16A:@0AjFdl4S6UK18e]H0B7JV03P6IN17USG0AcGeT4KUaG16]J
EPAXFE@4IUMC0fAGD`AREU<4H5IC15aDD`AIDe<4DdmA0di=C`A:C4l4AT]A149<DP@oCED4?DmH141E
GP=3FV@4BV9/14iXL`ACKWX4EWB015]iQP=NOX`4HHBC16:7U`APRYX4GhbN17:K[0B<[[`3Xkk91;;<
ePBmf^@4c>C[1<;Hg`BjcM<3/L;71:Rg_0BO[;04UZ6U18jFV@B5Rhh4O8635Oooo`005?ooo`AXJV/4
GEiN155ADPA6ADD4>SPh0bdZ:P@P7Ad44`l?10D100@B30X48APE0cHW8`A:=c44HTU017QJCPB:J5/4
SFiQ18U]HP>3JF44O6IO17ISG@AaH5/4KEeH16UJEPAVF5@3HeMC165ED@ANE544FU9A15I@D0ABCTl3
CDa?14Y<D0A7C584A4eD145>E`@oDEX4@5EN0d5IH`A6GfX4C6Ib155]N@AELh04FWR60e]mS0ANPY84
GHFE15b8V@ANS9h4M9f]18b^_0>R_/T4]/oH1<GNiPCDj>l4b]gS1<3AeP>faLX4[;Vn1::^/PBIXjH4
SiNJ18J<S`AmPH<Eoooo000Doooo16QZJ`AMGUh4DE5B14I5A@@j>3P3;BXZ120M7@@C3`l41@40118<
2P@Q61D3=RLS14Xg<@ARBD04N5Y>18YXF`B=KV44RFeR0h=YH@AlIUl4MV=M175PF`A]GEP4JEYF16IH
E0=SEe<4HEEA15iDD@AJDU44EU1@159>C`==C4l4BTa@14M<DPA4CE@4@DiG13mAFPA0EEh3@EUS14IO
JPA<IW84DFei15EcP0AJN8H3Fgf<15j2TPAMQID4G8RI15j<WPAdWJd4S:jl0j:nb@BfcmP4aMkV1=CX
k`C:gN<4`=7F0kK5bPB/^Kh4XZjb19VSYPB?UiX4QXb?17f1PaGoool001Coool4J6Y[15eNGPAADE84
ATE513Xh>0<]:RX481dM11<?3`@50@044P`:124H5@<f9b<4BSLa1699@0AhFTh4RVQK18e^H@B9KF83
PfUQ17aVG`AfHed4LF1K16eMF0AYFUH4IUQD0f=GD`AQEE44GUAA15YBD@AFD504DTi?0de<C`A:C504
AdaB14A=E0A1CUL4?e5J141EGP=1FF<4AUmZ14aVLPAAKGT4EG>015YhQP=KOH`4GX:B15f5U@ALR9T4
GXbN17BM[@B<[[`3X[k91;K?f0C5g^H4e>S_1<[Mh`C0dMH3]/G:1:bi_PBR[[84VJ>V18nGVPB6S8l4
OH635Oooo`005?ooo`AXJV/4GEiN155ADPA6ADD4>SPh0bdZ:P@P7Ad44`l?10D100@B30X48APE0cHW
8`A:=c44HTU017QJCPB:J5/4SFiQ18U]HP>3JF44O6IO17ISG@AaH5/4KEeH16UJEPAVF5@3HeMC165E
D@ANE544FU9A15I@D0ABCTl3CDa?14Y<D0A7C584A4eD145>E`@oDEX4@5EN0d5IH`A6GfX4C6Ib155]
N@AELh04FWR60e]mS0ANPY84GHFE15b8V@ANS9h4M9f]18b^_0>R_/T4]/oH1<GNiPCDj>l4b]gS1<3A
eP>faLX4[;Vn1::^/PBIXjH4SiNJ18J<S`AmPH<Eoooo000Doooo16QZJ`ALGEh4DE5B14E4A@@h=cL3
;2XZ11lL70@B3Ph41000114;2P@O5aD3<bHR14Pf<0ANAcl4LeQ<18EVF@B>KV84S6mU0hE/H`AnJF84
N6IP17=RG@A^GeX4JUaH16IIE@=SEU<4H5AA15aBD0AID4l4EDi>155=CP==Bdh4BTaA14M=D`A5CUD4
@U1H145BF`A1EEl3@UYT14EOJPA:IG44CFYg159aOPAFMXD3Eg^:15QnS`AHPY<4FHFG162=W`AfWjh4
S[2m0j?0b`BjdMT4c>3W1=[[l0CChnP4amKJ0k_9c@B`_<04YK2c19^TY`BAV9/4Qhf?17f1PaGoool0
01Coool4J6Y[15aMGPAADE84ADA513Pg=`</:RX47a`L118>3P@400044@/:11lG5@<c9R84B3H`15i7
?`AcF4`4QFII18i^HPB<KfD3QFaS17iYHPAhIV04Lf9M16iOFPAZG5P4IUUE0f=FD`APE544G59@15U@
C`AECTh4DDe>0de;CPA:C544AdeC14E>E@A2D5P4@E9K145EG`=2FV@4AEmZ14YUL@A=JWL4DW5n15If
Q@=GNhX4F7j?15R2T`AIQIL4H8fO17JO[PB>/;d3Xl3;1;[Af@C<h>L4f^_`1=?Sj0C7e]X3^lW=1;2l
`0BU/;<4VjBW196HV`B7SHl4OH635Oooo`005?ooo`AXJV/4G5eN155ADPA5A4D4>3Lg0b`Z:P@O71`4
4Ph>10@000@A2`X47aLE0c<V8PA8=S04GTLo17=HC0B5IUT4SViR18a_I@>5K6<4OVUR17QVH0AcHUd4
KUmJ16YLF0AVFED3HeIC161DD@ALDU04FE1?15E>CPAACDh3CD]>14Y<D@A7CE<4ADiE149@F0A1DU/4
@EEO0d9JI0A5GfX4BVEa14eZM`ABLGh4EWJ50eMkRPAHOXl4F8:C15V5U`APSIl4MYn^18j`_@>S`</4
^]7I1<cPi`CJjo04dn?X1<OFfP>kbLd4/;c01:F`/`BKY:L4TIRK18N=S`AmPH<Eoooo000Doooo16QZ
J`ALGEh4D51A14A4A0@g=cL3:bTZ11hL70@@3Ph40`00110<2`@N5aD3<2@Q14@d;PAJA3d4KUA:185S
E`B<KF44SW5W0hM^IPB0Jf@4NVMR17ATG`A_H5/4JUaI16IIEP=REU<4Ge=@15]AC`AGCdh4Dde>14m<
C@=<Bdl4BTeA14M>D`A5CeH4@e5I149CG0A2EV03@e]U14EOJ`A8I704BfUf14e^O0A@Lh83DWR815=l
S0ADOi44EXBF16B@XPAkX[44TK:o0jK2c0Bmd]X4d^;X1>3]l@CLjNd4cM[M0l3;c`Bd_/44Z;6d19fU
Z0BBVI/4R8f?17j2PaGoool001Coool4J6Y[15aMGPA@D544A4A413Lg=`<[:BX47Q`L110>3P@30004
40`;11hG5@<`9244A3@^15Y4?@A^E4X4PF=G18a]H@B>LFL3QfiV181[I0AjIf84M6AO16mPF`AZG5T4
IUUF0f9FD`AODe04Fe5?15M?CPACCDh4Cda=0da;C`A:CE44AdiC14E?EPA3DET4@U=L149FH0=3FfD4
AEm[14QTL0A;JGH4CFil151cPP=BN8P4Dgb<15AoT@AFQ9H4I92R17^R/@BA/[l3Y/;<1;gBfPCBh^P4
h>ga1=cYk@C=f]d3`<_?1;Bn`@BX/K@4WJFX19:IV`B8SHl4OX:35Oooo`005?ooo`AXJV/4G5eN151@
D@A4A4@4=cLg0b/Y:P@N71`440h>10<000@@30/47QLE0c0T8@A4=2h4FT@m16iDBPB1HeL4S6eQ18ia
I`>7KVH4P6]T17YWHPAdI5l4Kf1K16YLF@AVFEH3HUIC15mCD0AKDDl4Edm>15==CPA?C4d3C4]?14Y=
D@A7CU<4ADmF14=AF@A2De`4@UIP0d=KI@A5Gf/4B6A`14]YMPA=KW`4D7>20e9hR0ACO8`4E7nA15J4
UPATT:84Nj:a196b_`>V`/`4_M;J1=;Rj0CPkO44g>W]1<gJg@?0bll4];k11:Ra]0BMYJP4TYVK18R=
S`AnPX<Eoooo000Doooo16QZJ`ALGEh4D51A14A4A0@g=cL3:bTZ11hL70@@3Ph40`00110<2`@N5aD3
<2@Q14@d;PAJA3d4KUA:185SE`B<KF44SW5W0hM^IPB0Jf@4NVMR17ATG`A_H5/4JUaI16IIEP=REU<4
Ge=@15]AC`AGCdh4Dde>14m<C@=<Bdl4BTeA14M>D`A5CeH4@e5I149CG0A2EV03@e]U14EOJ`A8I704
BfUf14e^O0A@Lh83DWR815=lS0ADOi44EXBF16B@XPAkX[44TK:o0jK2c0Bmd]X4d^;X1>3]l@CLjNd4
cM[M0l3;c`Bd_/44Z;6d19fUZ0BBVI/4R8f?17j2PaGoool001Coool4J6Y[15aMGPA@D544@d=413Lf
=`<Z:BX47A/L10l>3P@200043``;11dG5@<^8b04@34/15A1>PAYDDP4O61E18QZG`B?LVL3RG1W185/
I@AkJF<4MFEP16mQG@AZGET4IUUF0f9EDPANDe04FU1?15I>C@ABC4d4Cd]=0da;C`A:CE44AdiD14E@
E`A4DUX4@UAM149GH@=3FfH4AF1[14ISL0A8J7H4BVek14aaP0=?MXH4CgZ;155nT0AGQIP4JYBU17nU
/`BF]L43[<G?1<?Fg@CHiNX4i_3c1>?^l@CBgN03a<g@1;K0`PBZ/[D4WjJX19BJW0B9SY04OX:45Ooo
o`005?ooo`AXJV/4G5eN151@D@A3@d@4=cHg0bXY:P@M6a`43`h>108000@?30/47ALE0bhS80A0<B`4
E44j16UAB0AlH5D4R6YO18mbI`>9L6L4PFaU17]YH`AeIF04Kf5M16YMF@AVFEH3HUEB15iCD0AJD4l4
ETi=159<C@A?Bdd3C4]?14Y=D@A7CU@4AE1G14ABFPA2E5d4@UMQ0d=KIPA5H6/4AV=`14QXMPA:KG/4
C7600dmfQPA?NX/4DGj@15N5V0AZU:D4OjFc19Je`@>/aLl4`mKM1=SUjPCVl?<4hnka1=;Mh0?4cM04
]/321:Zb]@BOYZP4U9ZL18V>T0AnPX@Eoooo000Doooo16QZJ`ALGEh4D51A14=3A0@g=SL3:RTZ11dK
70@?3Ph40P0010l<2`@M5aD3;R<P140a;0AD@CX4JE5817aPE@B8JUl4Sg9W0hU`I`B1K6D4NfUS17EU
H0A_HEd4JUeI16IIEP=REE84GU=@15Y@C`AFCTd4DTa=14m;C@=<Bdl4BTeA14M>E0A5D5L4A59J149D
G@A2Ef43@e]V14EPJ`A6Hg04B6Qf14Y]N`A<LH03CgJ614mjR`AAOY04EhFH16ZDY@AoYK<4U[G10jc5
c`C3e]d4f>GZ1>K`l`CSk_44d]gP0lC=d0Bf`<84Z[:e19nVZ0BDVY`4RHj@17j2Q1Goool001Coool4
J6Y[15aMGPA@D544@d=413Lf=`<Z:BX47A/L10l>3P@200043``;11dG5@<^8b04@34/15A1>PAYDDP4
O61E18QZG`B?LVL3RG1W185/I@AkJF<4MFEP16mQG@AZGET4IUUF0f9EDPANDe04FU1?15I>C@ABC4d4
Cd]=0da;C`A:CE44AdiD14E@E`A4DUX4@UAM149GH@=3FfH4AF1[14ISL0A8J7H4BVek14aaP0=?MXH4
CgZ;155nT0AGQIP4JYBU17nU/`BF]L43[<G?1<?Fg@CHiNX4i_3c1>?^l@CBgN03a<g@1;K0`PBZ/[D4
WjJX19BJW0B9SY04OX:45Oooo`005?ooo`AWJV/4FeeN14m@DPA3A4D4=SHg0bTY:P@L6a`43`h?1040
0@@>2`/47ALE0b/R7`@l;bX4CShg16E>A@AgG584Q6ML18a_I@>9LFP4PVeV17]YH`AeIF44Kf5N16YM
FPAUFEH3HEEC15aBD0AHCdh4EDe=155<C0A>Bdd3Bd]?14Y=DPA8CeD4AE5H14ABF`A3EEl4@UQR0d=L
I`A4Gf/4AF=`14IWM@A8JgX4BW200d]dQ@A<N8X4DGj@15b9V`A`VJT4QJRf19fja@>cb]84b][Q1=kY
k@C^m_T4iNk`1=GMh0?6c]44^<331:bc]@BPYZP4U9ZL18V>T0AnPX@Eoooo000Doooo16MZJ`AKGEh4
Ce1B14=4A@@f=SL3:BTZ11`K70@?3Pl40@0110h;2`@M5aD3:b8O13`_:PA>?SL4IDi517MLDPB4Ie`4
S6mU0hUaJ0B2KFH4NfUS17EUH@A_HEh4JUeJ16EIEP=QEE<4G59@15Q?CPAECDd4DDa<14i;C@=;Bdl4
BTeB14Q?E@A5DEP4A59K14=EG`A2F683@eaW14AOJ`A5Hg04AVMe14Q[NPA:L803BgB514ahRPAAOY04
G8VK172IZ@B5Z;H4WK[50k?:dPC:f^44g^W]1>kfn@CUk_04eMgP0lK>d@Bh`<<4[;>e1:2VZ0BDVY`4
RHj@17j2Q1Goool001Coool4IfY[15]MGPA?D584@dA513Hf=`<Y:BX471/L10l>3`@100443P/;11dG
5@<[8Ql4?2lZ14hn=`AUCTD4MeaB18AWG0B<KfD3RG5X189]IPAkJF<4MFEQ16mQGPAZGEX4IEUF0f5E
D`ALDU04F4m>15E=C@AAC4`4CT]=0d];C`A:CE84B4mE14EAF0A4DU/4@eEO149HHP=3G6L4A5m[14ES
L0A6IgD4B6]j14Y`P0=;M8D4C7R:155nT0ALRI/4L9VY18FX]PBM^/D3/l[B1<[Jh@CNjNd4k_Ki1>G^
l0CEgN03a/kA1;S0``B//kD4X:JX19BJW0B9SY04OX:45Oooo`005?ooo`AWJV/4FeeN14m@DPA3A4D4
=SHg0bTY:P@L6a`43`h?10400@@>2`/47ALE0b/R7`@l;bX4CShg16E>A@AgG584Q6ML18a_I@>9LFP4
PVeV17]YH`AeIF44Kf5N16YMFPAUFEH3HEEC15aBD0AHCdh4EDe=155<C0A>Bdd3Bd]?14Y=DPA8CeD4
AE5H14ABF`A3EEl4@UQR0d=LI`A4Gf/4AF=`14IWM@A8JgX4BW200d]dQ@A<N8X4DGj@15b9V`A`VJT4
QJRf19fja@>cb]84b][Q1=kYk@C^m_T4iNk`1=GMh0?6c]44^<331:bc]@BPYZP4U9ZL18V>T0AnPX@E
oooo000Doooo16MZJ`AKGEl4Ce5B14=4A@@f=cP3:BT[11`L7@@>3Pl4000210h;2`@L5QD3:B4N13L/
:0A:>cD4GdY3171HC`B0I5X4QfaR0hM`I`B1KFH4NVUT17AUH@A^HEd4JEeJ16AIEP=OEE<4Fe5?15M?
CPACC4`4D4]<14e:C@=;C504BTiC14Q@EPA6DUT4AEAL14=GH0A3FF<3@eaW14APK0A4I744AFMe14I[
NPA8Kgl3BG>414eiR`ADPI<4HhjO17JN[0B>[[/4Y;k90k_?ePCAgn@4iNka1?Cko0CTk>d4eMgO0lO>
d0Bj`<84[K>e1:6VZ0BEVY`4RXj@17j2PaGoool001Coool4IfY[15]MG`A?DE84@dA513Hg>0<Y:B/4
71`M10h>3`@000843P/;11`F5@<Y8Ah4=b`X14Xk=@AOBT<4L5Q?181TFPB7K683Qg1W185]IPAjJF@4
M6EQ16iQG@AYGEX4I5UF0emED`AKDDl4Edm>15=<C0A@Bd`4CDY=0d]<D0A:CU<4B51F14IBF@A5E5`4
@eMP14=IH`=3G6L4A61/14ATL@A5IgD4AV]j14Q_O`=9Lh@4CGV;15B1T`ASSYl4MYj/18j^^`BT_/T3
^loF1=7Oi0CUk_44m?_l1>C/k@CEgMl3alk@1;[0`PB]/kD4XJJX19FJW0B:SY04OX:35Oooo`005?oo
o`AWJV/4FeeO14mADPA3A4D4=SLh0bTY:`@L71d43Ph?10000P@>2`/471HE0bTQ7P@g;2P4BS/e15m:
@`A`F4l4P6AJ18M/HP>7L6L4PFeV17YYI0AdIF44KV5M16UMFPATFEH3GeEC15]AC`AGCdh4Dda<151;
C0A=BTd3Bda@14Y>D`A8D5H4AU9I14EDG0A3Ef04@eUS0d=LI`A4H6`4A6Aa14EWM@A6JgX4B6mo0dUc
Q0A=NH/4E86C16>>W`AfWZ`4SZjk1:Bnb@>kcmH4dMoT1>G^l@Cdno`4i>c]1=GMg`?7c]04^/321:fc
]@BQYZP4UIZL18Z>T0AnPX<Eoooo000Doooo16MZJ`AKGEl4Ce5B14=4A@@f=cP3:BT[11`L7@@>3Pl4
000210h;2`@L5QD3:B4N13L/:0A:>cD4GdY3171HC`B0I5X4QfaR0hM`I`B1KFH4NVUT17AUH@A^HEd4
JEeJ16AIEP=OEE<4Fe5?15M?CPACC4`4D4]<14e:C@=;C504BTiC14Q@EPA6DUT4AEAL14=GH0A3FF<3
@eaW14APK0A4I744AFMe14I[NPA8Kgl3BG>414eiR`ADPI<4HhjO17JN[0B>[[/4Y;k90k_?ePCAgn@4
iNka1?Cko0CTk>d4eMgO0lO>d0Bj`<84[K>e1:6VZ0BEVY`4RXj@17j2PaGoool001Coool4J6Y[15aN
G`A?DE84@dA613Hg>@<Y:R`471`N10h?40@000843P/<11XF5@<W81h4=2XW14Hh<`AHASl4JE=;17UP
EPB0Ieh3Q6eT181]I@AiJ6<4LfAP16ePG@AWG5X4HUQF0eiDDPAJD4l4EDi=159<C0A?Bdd4CD]>0d]<
D0A9Ce@4B55G14MCFPA6EEd4A5QQ14AJI@=4GFP4A65]14ATL@A5J7H4AF]j14I_O`=9M8D4Cg^=15V5
UPA[U:<4Oj>a19Jd_`B/a<d3`]CJ1=WUj@C]loD4m_cl1>GZk0CEg=d3alg?1;[0`@B]/k@4XJJX19FJ
V`B:SXl4Oh:35Oooo`005?ooo`AXJV/4G5iO14mADPA3A4H4=SLi0bTZ;0@L71h43Pl@10000P@>2``4
6QHE0bLP7P@d:RL4ASPc15Q6?`AYDd/4NF1F181WGP>4KF@4P6eU17UXH`AcI604KF1M16MLFPARF5H3
GUAB15Y@C`AECTd4DTa<14m;C@A=Bdh3Bda@14U?E0A8DEL4Ae=J14IEG@A4F644A5YU0dAMJ0A4HFd4
A6Aa14EXMPA5JgX4AVmo0dUdQ@A?Nhd4FHFF16^DX`AoXk44U[Bo1:c4c@?2e=X4fNGY1>gcm@Cfo?`4
iN[/1=GLg@?7cLl4^/311:fc]0BQYZP4UIZK18Z>S`AoPX<Eoooo000Doooo16QZJ`ALGUl4Ce5B14=4
AP@f=cT3:BX/11`L7P@>3a04000210h;30@J5QD39b0N13@Z9`A6>3<4F4Ho16UCB`AiH5H4P6MN0hA]
I0B0KFD4NFQS17=TH0A]H5d4IeaJ169HEP=NE584FU1?15E>C@ABC4`4Cd]=14e;CP=;C504BDmD14QA
E`A7DeX4AUEM14AHH@A4FVD3A5eX14AQK@A4I744AFQf14E[NPA6Kgl3BGB514mkS@AIQIH4JiBS17nS
/@BF];l4[<C=0l;DfPCIiNT4kO?e1?Klo0CUj^`4eMcM0lO=c`Bj`<44[K>d1:6VZ0BEVY/4RXj?17n2
PaGoool001Coool4J6Y[15aNG`A@DU<4A4E713Lh>P<Z:bd47AhP10l@4P@00@<430/;11PE5@<T7ah4
<BTV140d<0AB@S`4HDi8171JDPAhHEP3P6UQ17i[I0AhIf84LF=O16]OG0AVFeP4HEME0eaCDPAHD504
E4i>155;C@A>Bdd4C4]?0d]=DPA:D5H4BE9I14QDG0A7EUl4AEUR14EKIP=4GVX4A69^14ATLPA4J7H4
A6ak14I_P0=;MHL4E7n@16:;V`AeVZT4RZZf19nia0BebM43c=[O1>C[kPCgno`4loSh1>?Xj@CEf]/3
alc=1;Zo`0B]/[<4XJFW19FIV`B:SHl4Oh:35Oooo`005?ooo`AXJV/4G5iO151BD`A4ADL4=cPj0bX[
;@@M7R043a0B10010`@<2`/461DE0b@O7P@a:BH4@3@`1592?0AQCTP4L5YB17QQF0>0JF44OV]T17QW
HPAaHel4JemL16IKF0AQEeD3G5=B15Q@D0ADCTh4DD]=14i;C@A<Bdl3BdeB14Y@EPA9DUT4B5AL14MF
G`A5FF84AE]V0dANJPA4HVh4A6Ab14AXMPA4K7/4AVn00d]eQ`ADOi04HX^K17FJZ@B:Z[H4WkW41;G9
d@?<f]l4i>_^1?Oko0Ccn?P4hnSY1=GJf`?7c<d4^[o01:fb/`BQYJL4UIVK18Z=S`AoPX<Eoooo000D
oooo16QZJ`ALGUl4D59C14A5A`@g>3X3:R/]11dN80@?4184004310`;2`@H5AD391lN134Y9PA0=304
DT8l165>B0A`FU84N65H0h1YH@AnJf@4N6MR175SG`A[Ge`4IU]H165GE@=LDe84F51@15A>CPAABdd4
CT]=14a;C`=;CE84BU1F14UBF@A8E5`4AeIO14EIHPA5FfH3A5iZ14ARKPA4I784A6Qf14A/N`A6Kh03
BgF715AoT0ARRi/4MIZY18ZZ]PBO^L@4]LWA0lcJg`CTjnh4mo_l1??hn0CSj>T4eM[K0lO<c@Bj_l04
[K:c1:6UY`BEVI/4RXf?17n2PaGoool001Coool4J6Y[15aNG`A@DU<4A4E713Lh>P<Z:bd47AhP10l@
4P@00@<430/;11PE5@<T7ah4<BTV140d<0AB@S`4HDi8171JDPAhHEP3P6UQ17i[I0AhIf84LF=O16]O
G0AVFeP4HEME0eaCDPAHD504E4i>155;C@A>Bdd4C4]?0d]=DPA:D5H4BE9I14QDG0A7EUl4AEUR14EK
IP=4GVX4A69^14ATLPA4J7H4A6ak14I_P0=;MHL4E7n@16:;V`AeVZT4RZZf19nia0BebM43c=[O1>C[
kPCgno`4loSh1>?Xj@CEf]/3alc=1;Zo`0B]/[<4XJFW19FIV`B:SHl4Oh:35Oooo`005?ooo`AXJV`4
G5iP151BE0A4ATP4>3Xl0b/];`@N8284418D10831@@92P/45Q@E0b8M7@@]9R@4>c4_14Xn>@AIBT@4
IU==171KE0=iI5`4NVQQ17EUH0A_HEd4JEiK16=JE`ANEUD3FU=B15I@D0ACCTh4Cd]=14e;CPA;C503
BdiC14]BE`A:E5/4BEIN14QHH0A6Ff@4AUeX0dEPK0A4Hfl4A6Ec14AYN0A5KG`4B7620dmiRPAKQID4
Ji:Q182Q[PBE/K`4Z<391;k?eP?FhN@4k?7b1?coo`C_l_<4hNGV1=?Gf0?6b//4^Kfn1:ba/PBPY:H4
UIVJ18Z=SPAnPX<Eoooo000Doooo16QZK0ALGV04D59D14A6B0@h>S`3:bd_11hP8P@@4Q@40P<510T:
2`@F51D38QdM12dV90@k<Bl4BShi15U:A0AVDdd4L5]D0gUTG0AjJ644MFEP16mQG@AYGU/4HeYG15iF
E@=JDe84EU1@15=>CPA?Bdd4CD]>14]<D0=;CU<4Be9G14YDF`A9EUh4B5QP14IKI0A6GFP3AF1/14AS
K`A4IG<4A6Uh14E]O0A8LH83CgV:15^5U@A[TZ44P:6^19Fa_0BX`<T4_/oF0mKQi0C/lO84o?oo1>ob
l`CQiNH4dmOH0lK:b`Bi_Kh4[;6b1:2TYPBEVIX4RXf>17j2PaGoool001Coool4J6Y/15aNH0A@DU@4
A4I813Pj?0<[;Bl47R0R110B50@20`D42@X;11HD5@<R7Ad4;BHT13/a;`A:?ST4FDY416ICC@A`Fe@3
NFAL17YXH@AeIF04Kf5M16UNF`ASFUL4GUIE0eYCDPAFD504Ddi>14m;C@A=Bdh4Bda@0d]>D`A;DUL4
BUAK14UFGPA8F604AU]T14IMJ0=5H6`4A6=_14AUL`A4JGP4AFel14QaPP=?NHX4FhFE16^BX@B0XJh4
UK6l1:S0b@BncmH3e^7T1>calPClool4ko;c1>7UiPCCemP3a/[;1;Vm_PB//K84X:BV19FIVPB:SHh4
OX:35Oooo`005?ooo`AXJV`4G5iP151BE0A4ATP4>3Xl0b/];`@N8284418D10831@@92P/45Q@E0b8M
7@@]9R@4>c4_14Xn>@AIBT@4IU==171KE0=iI5`4NVQQ17EUH0A_HEd4JEiK16=JE`ANEUD3FU=B15I@
D0ACCTh4Cd]=14e;CPA;C503BdiC14]BE`A:E5/4BEIN14QHH0A6Ff@4AUeX0dEPK0A4Hfl4A6Ec14AY
N0A5KG`4B7620dmiRPAKQID4Ji:Q182Q[PBE/K`4Z<391;k?eP?FhN@4k?7b1?coo`C_l_<4hNGV1=?G
f0?6b//4^Kfn1:ba/PBPY:H4UIVJ18Z=SPAnPX<Eoooo000Doooo16Q[K0AMGf44DEAE14I8B@@j?3d3
;Bla120R90@B5AL410H810P:30@C4a@37Q/K12TT8`@e;R`4A3Xf1595@@AMCTT4IeI?0g1ME`AdHe`4
LF9M16aOF`AWG5T4HEQG15aEE0=GDU84E4m@155=C`A=Bdd4Bd]>14]>DP=<D5D4C5=I14aFG@A;F604
BEYS14QLIPA7GfX3AV9]14IUL@A5IgD4AV]i14Q_O`A<MHD3EWn?16F<V`AgVJL4RjRd19nh`@Bca/h4
bMKK0n7WjPCbmOD4oOoo1>g`l0COh^84dMCE0lC8b0Bg^k`4Zjn`1:2SY0BDV9T4RHb>17j1PaGoool0
01Coool4J6]/15eOH@AAE5D4ATQ913Xl?@<];c44828T118E5`@41PP420X<11<C50<N6a/4:B@S13D^
;0A4>SH4DTE115e>B@AWETl3L5eG17ASG0AaHUd4K5mK16MLF@AQF5L4G5ED0eMBDPADCe04DDe?14e;
C@A;Bdh4BdiB0da@E@A<DeT4C5IM14]HH0A9FV<4B5aV14MOJP=6HVd4AVEa14EWM@A6JgT4B6mo14ae
Q@=FOhl4IHbK17NIY`B;Z;@4WkS11;?6cPC9e]/3hNOZ1?;em@Cmool4kO3`1=oRhPCAe=D3a<S81;Nk
_0B[[k04X:>T19BHV@B9S8h4OX635Oooo`005?ooo`AXJf`4GEmQ155DE@A6B4T4>S`m0bd_<@@P8R@4
4QDG10@620@82P`44a<D0ahK6`@Y92<4=Bh/14@j=PABAD44GDi916MFC`=`GEL4M6=L175RG@A/Ge/4
IeaI165HE`ALEE@3Ee9B15A?D0AACDl4CD]=14];CPA;CU83C51E14aCF@A<EUd4BeQP14UJH`A8G6H4
AemZ0dIRK@A6IG44AFMe14I[N@A8Kgl4C7F50eIoS`AUS9/4MiVW18^X]0BO^<44/lK>1<WFf`?QinX4
l_Ge1?goo`C]l?04gn;R1=7De@?4b<P4]k^l1:^_/0BPXj@4U9RI18V<SPAnPH<Eoooo000Doooo16Q[
K0AMGf44DEAE14I8B@@j?3d3;Bla120R90@B5AL410H810P:30@C4a@37Q/K12TT8`@e;R`4A3Xf1595
@@AMCTT4IeI?0g1ME`AdHe`4LF9M16aOF`AWG5T4HEQG15aEE0=GDU84E4m@155=C`A=Bdd4Bd]>14]>
DP=<D5D4C5=I14aFG@A;F604BEYS14QLIPA7GfX3AV9]14IUL@A5IgD4AV]i14Q_O`A<MHD3EWn?16F<
V`AgVJL4RjRd19nh`@Bca/h4bMKK0n7WjPCbmOD4oOoo1>g`l0COh^84dMCE0lC8b0Bg^k`4Zjn`1:2S
Y0BDV9T4RHb>17j1PaGoool001Coool4J6]]15ePHPABEEH4AdU;13/n@0<_<S@48bDX11HH6`@82`d4
1PT;110A4`<J6AX49R<R130[:P@m=S@4Bd4n15E9A@AND4/3IEIA16]LE`A[G5P4J5aH16=JF0AMEUD4
FEAD0eEADPABCe04Cde@14];CPA9Bdl4C4mC0deBE`A>EU`4CEQO14eJHPA;GFD4BUmX14UQK0=9I704
B6Md14QZN0A9KG`4CW>215=kRP=PQYD4L9>Q18:Q[@BF[kX4Z[k61;k>d`CEg^43j^k^1?[kn`CinoX4
j^c/1=_NgPC>dM83`/G51;Fi^PBZ[Jh4WZ:S19>GV0B9S8d4OX625Oooo`005?ooo`AXJfd4GF1R159E
EPA7BD/4>ci00blb=0@S9BP45QPK10P;3@@62@/4414C0aXI6P@V8b84<2/Z13df=0A;@Ch4EDU515i@
B`=UEU44JeaG16]LF0AXG5P4HeYH15eFE@AIE5@3EE5B159?D0A?CE04Bd]>14U;C`A<Ce<3CE9G14iF
G0A=F5l4CEYR14]MI@A:GfP4BF5/0dUTL0A8Ig@4B6Yh14U]O0A>Lh84Dg^:0f26U@A`Tj44PZ6]19J_
^PBZ_/H4_/kC1=GNh@?Zk^h4n__k1?WknPCZk>`4fmkN1<kAdP?2aLD4]KVj1:Z][PBNXZ<4TiNH18V<
S@AnPH8Eoooo000Doooo16Q[K@AMH684DUEF14M9B`@k?T03;c8d12<U:0@F61/420/=10H92`@@4A<3
6QTJ12HS8P@`:bX4?CHd14]1?PAEBDD4GU1;0fEFD@A[G5L4JeaH16QLF0ASFUP4GEIE15UDE0=EDE84
DTm@14m=D0A;Bdh4BD]?14a?D`==DUL4CUIL14eHG`A=FV84BeeU14YOJ0A9HF`3BFA`14QWM0A8JWP4
BFel14icPPACNhX3H8JE172CX@B2XJd4UZnj1:ZnaPBnc]<4eMkQ0n[^kPCjno/4nO_j1>[/k0CKg]h4
c]7B0l;5a@Be^KX4ZZf^19jRX`BCUiP4RHb=17j1PQGoool001Coool4J6]]15ePHPABEEH4AdU;13/n
@0<_<S@48bDX11HH6`@82`d41PT;110A4`<J6AX49R<R130[:P@m=S@4Bd4n15E9A@AND4/3IEIA16]L
E`A[G5P4J5aH16=JF0AMEUD4FEAD0eEADPABCe04Cde@14];CPA9Bdl4C4mC0deBE`A>EU`4CEQO14eJ
HPA;GFD4BUmX14UQK0=9I704B6Md14QZN0A9KG`4CW>215=kRP=PQYD4L9>Q18:Q[@BF[kX4Z[k61;k>
d`CEg^43j^k^1?[kn`CinoX4j^c/1=_NgPC>dM83`/G51;Fi^PBZ[Jh4WZ:S19>GV0B9S8d4OX625Ooo
o`005?ooo`AYK6d4GV5S15AFF0A9Bdd4?T120c8e=`@V:B`46QdP10hA50@520/430lA0aLH6@@R8B44
:bPX13Lb<@A5?C/4CTE215M<B0=KD4`4HEEA16=GE0ASEeD4GUIE15QCE0ADDE83De1A151?D@A=CU44
BDa@14U=D@A<D5D3CeEI151HGPA@Ff44CeeT14eOJ0A=HFX4CFA_0daWL`A<JWL4CFik14mbP0AENHP4
GX>A0fb>V`AlVjL4SZRc1::g`0Bea/`4b]GI1=oTiP?al_84ooon1?;cl`CUi^H4em[J1<_=cP>o`L84
/kJg1:R[[0BMX:44TYFG18R;S0AnP88Eoooo000Doooo16U/K@ANHF<4E5IH14U;C@@n@483<SDg12HY
;0@J7B043Q4D10D82`@<3a435aPI128Q8@@[:2P4=c8a14Dm>`A>AD84Eda80e]@C0AQEE44HeMD16=G
E@ANEUD4F5=D15AADP=CD544D4mA14e>D@A9C504BDeA14a@E@=?EET4D5QN151KH@A?GF@4CEmX14eQ
JPA=I6l3C6Mc14aZM`A=KW/4Cg:015EiR0ANPi43K8jK17bKY`B>Z;<4X[O01;G6c0C:eMT4gnCV0o7b
lPCoooh4l_?c1>GViPCGf]X4blg>0ko1`PBc][L4Z:^/19fPX@BBUIL4R8^<17j0PQGoool001Coool4
JFa]15iQH`ADEUP4BD]=13i0@P<b=CL49RT/11XM80@>4A@41@P;10`?4@<G61T48R4Q12/X:0@g<S44
ACdk14i5@PAGC4P3Fe1<165ED@ASEe@4HeME15iFE@AHDe@4E55B0e=@D@A@Ce44CDiA14U<D0A9CE44
C51E0dmEF@A@F5h4D5]Q14mMI0A=GfP4CF5Z14eTK`=<Ig<4C6Yg14e^N`A?LX04EGV815j3T@=/SY/4
O9^W18jX/`BR]l04]LK<1<[Ef@COi>H3lO;b1?oooPCblo<4iNKV1=OJfPC;cLh3_l721;>f]`BXZj`4
WJ2Q19:EU`B8Rh`4OX225Oooo`005?ooo`AYK6d4GV5S15AFF0A9Bdd4?T120c8e=`@V:B`46QdP10hA
50@520/430lA0aLH6@@R8B44:bPX13Lb<@A5?C/4CTE215M<B0=KD4`4HEEA16=GE0ASEeD4GUIE15QC
E0ADDE83De1A151?D@A=CU44BDa@14U=D@A<D5D3CeEI151HGPA@Ff44CeeT14eOJ0A=HFX4CFA_0daW
L`A<JWL4CFik14mbP0AENHP4GX>A0fb>V`AlVjL4SZRc1::g`0Bea/`4b]GI1=oTiP?al_84ooon1?;c
l`CUi^H4em[J1<_=cP>o`L84/kJg1:R[[0BMX:44TYFG18R;S0AnP88Eoooo000Doooo16U/KPAOHV@4
EEQI14]=C`A0@dD3=CPj12X]<0@O8RD44aLJ10L;3P@93A035ALH11hO80@X9bL4<Rl_140j>0A9@T04
CdM50eA;B@AHCdd4Fe9@15YBD@AGDU44De1B155?D@=ACe84Ce1B14e?D`A:CU84Be1D14iCE`=@Ee`4
DUYP15=OI0ABH6L4D69Z155UKPAAJ783DVag159_N`ADLgl4F7V51621SPAZRiL3NINR18VS[@BK/;T4
[[o61<;>dPCFg=l4in[Z0oSfmPClo?X4kNg]1=oQh0CCeMD4alW90k^n_PB`/k@4YZRY19^NW`BAU9D4
QhZ;17f0PAGoool001Coool4JFa^15mRI0AEF5T4Bde?1413A@<e>3X4:Rd`11lR9@@C5aX41`/>10T=
40<E5aP47QlP12PW9`@b;bl4@3Xh14U2@0A?AdD3E4]915Q?C@AKDU04FU9A15MBD@ACD584DDmA0e5?
DPA?D584CDmC14Y>DPA;D5@4CU=G0e1GG0ABFV04DemT159PI`A@HVX4DFE^155XLP=BK7L4DVmk15Ac
O`AHNHD4H86>16Z;U`=iUj84RJ>]19^`^@B^_lH4`/kB1=KLg`CWj^X3n?Kf1?clnPC]kNd4gn7P1=?E
e@C7bLT3^kjn1;2c]0BVZ:T4VijO196DU@B7RX/4OH215Oooo`005?ooo`AYK6h4Gf9T15EHF@A;CDl4
@4=50cDh>P@Z;C047b8U11<G6P@72`h42@d@0aDG60@N7b04:2LW138_;`A0>SP4BD9014m7A@=DBdT4
F4m=15]BD0AJDU44Ee9A15=@DPAACe43DDmB14m@DPA=Ce<4BTiB14]@E0A>DeL3D5ML159JH0ACGf@4
DV1W151RJPAAIFh4DFQb0e9/M`ABKg/4E7=o15QiQ@APPHh4JX^G0gVGXPB9Xjd4Vk2i1:joaPC2c]84
e]cO1>OZjP?hm_H4o?cj1>g]k@COhN04dmGE1<O9b@>k_[h4/;>d1:JXZ@BKWYl4TIBE18N:R`AmP84E
oooo000Doooo16Y]KPAPHfD4EeUK14e@DPA3ATP3>C`n12ha=0@S9bX461`O10dA5@@830l34ADG11/M
7`@U9BH4;bd^13/g=`A3?Sd4B4=20da6A@A@BTT4Dda;15=>CPA@CTl8CTi@0dm?DPA=D5<4CE5E14]A
E@A=DeL4CeEJ0e5JGPADGF<4EV5W15ITJ`AEIVh4EVUb15I/MP=ILG/4FWEo15ijQ@ASP8`4KHVD17RC
W@>7WjP4UZ^c1:Ni_`Bjal`4cmKI1=oSi0C]knh3noWh1??clPCVi^D4fM[J1<k?c`C2a<D3^;Zj1:f`
/0BSYZL4VIbM192BT`B6RHX4OGn15Oooo`005?ooo`AZKFh4H6=U15MIF`A=D584@dI80cTl?P@^<C@4
8bLZ11PL7`@=4AD420`?0a4E5`@K7Al49BDV12l];P@k=cL4@chm14Q3@P=<ATD4D4Y915=<B`ACCTh4
D4i?24i>D0=?Ce84CE1C14eAE@A;DED4CE=G14mEFP=AFUh4E5eS15IQI`AFI6/4EFI^15IYLPAFK7H3
FG5k15YeO`ANNXD4Hh2<16f9U0AhTid3QinX19J[/`BW^Kl4^/O<1<oFf@COhn@4kNo^0o_in0Cclo84
i^KU1=WJfPC>cll4`/C50kRj^PB]/;04XjJW19VLW@B@TY<4QXV:17eoPAGoool001Coool4JVe^161S
I@AGFE/4CE1B14=6B0<i?3h4;S4d12<W:P@H71l43A4E10P<3`<A5AL46adO12DU9P@_;Bh4>cLg14<n
?@A8@d83C4I5151:B@ACC4/4Ddi>151>C`Q>CU03CdmB14e@D`A=DED4Be5E14eCE`A?EEX3DEYN15AM
H`AFHFL4EVA[15EVKPAFJG84EVaf0eUaN`AJMGl4GWZ516>0S0A]RI@4N9>M0hNOZ0BFZk<4YkVo1;[7
c0C?e]T4gn?T1>g_kP?knOP4lo?b1>KVi@CIf]X4c/o?1<;4a@>h^[X4[K2`1:>VY`BIW9d4T9:C18J9
RPAmOh4Eoooo000Doooo16Y]KPAPHfD4EeUK14e@DPA3ATP3>C`n12ha=0@S9bX461`O10dA5@@830l3
4ADG11/M7`@U9BH4;bd^13/g=`A3?Sd4B4=20da6A@A@BTT4Dda;15=>CPA@CTl8CTi@0dm?DPA=D5<4
CE5E14]AE@A=DeL4CeEJ0e5JGPADGF<4EV5W15ITJ`AEIVh4EVUb15I/MP=ILG/4FWEo15ijQ@ASP8`4
KHVD17RCW@>7WjP4UZ^c1:Ni_`Bjal`4cmKI1=oSi0C]knh3noWh1??clPCVi^D4fM[J1<k?c`C2a<D3
^;Zj1:f`/0BSYZL4VIbM192BT`B6RHX4OGn15Oooo`005?ooo`AZKFl4HFAV15QKG@A?DU@4ATU;0c`o
@P@b=ST4:2`_11hR9@@D61`42PlB0`hC5P@I71h48b@V12`/;@@f=3D4?3Xj148o?`=5@T84BTI614e9
B@A<BT/4Bd]=14]=D0A;CE43CU1C14]?E0A>DeL4CU=H14mEFPA@F5d3E5eR15MPIPAJIFX4FfQ^15]Z
L@ALKWH4GW5j0f9fO`ATNh@4JH6;16n8TPAiTIX4QI^T0iBW[PBS/kT4]<751<O?dPCJgMl4inSX1?Cd
l`?dlo84jNSX1=gNg@CBe=<4b<W91;jo`0>d][H4ZZb]1:2SY0BGVY/4SY6B18F8R@AlOh0Eoooo000D
oooo16Y]K`AQI6H4F5]M14mBE0A6BD/3?3m2138f>@@X;2l47R8U11@H70@:3a833Q<F11TL7P@S92H4
;2`]13Hd=@@l>SX4@Slo0dE2@PA:ATH4CDU914a:B`A;Bdd4Bde@14]=D@=>D5<4BdmD14iCE`A>DeP4
CeEJ151HG@=DGF84Ef1V15YUJPAKJ6h4FfYa15a^MPANLGX3HWIo16AkQ0AYPH/4KhRB17VAVPB5Vj@3
U:N^1:>c^@Bd`LD4aloB1=[Mg`CWj>P4m?Cc0oCclPCYj>P4gMkM1=;Dd`C8bLT4_[o00kBf]PBZ[:d4
X:>T19NJV`B>TI84QHR917aoP1Goool001Coool4JVe_165TIPAHFed4Ce9D14I9B`<l?d84<SHi12P/
;`@N8RD451PL10X?4P<>4aH46A`N12<T9P@/;2d4=S@e13`j>PA2?cl3AD9214Y6APA=BDT4C4Y;14];
C@A;CE04BdeA0di@D`A;Ce@4CU=G14iCF0A?EEX4D5QM0eAMHPAGH6H4FVEZ15]XKPAKJW44G6if15ia
NP=RMWl4I7^416V1R`A_R984NI6J18FKY0>DYjh4Xk>i1;C1a@C7cm84f]gO1>OXj0Cdm?<3m??b1>WX
j0CMg]d4d]CC1<S9b@Bn_l03];Jf1:Z/[@BPXj@4UiZK18jATPB5R8T4O7n05Oooo`005?ooo`AZKFl4
HFAV15QKG@A?DU@4ATU;0c`o@P@b=ST4:2`_11hR9@@D61`42PlB0`hC5P@I71h48b@V12`/;@@f=3D4
?3Xj148o?`=5@T84BTI614e9B@A<BT/4Bd]=14]=D0A;CE43CU1C14]?E0A>DeL4CU=H14mEFPA@F5d3
E5eR15MPIPAJIFX4FfQ^15]ZL@ALKWH4GW5j0f9fO`ATNh@4JH6;16n8TPAiTIX4QI^T0iBW[PBS/kT4
]<751<O?dPCJgMl4inSX1?Cdl`?dlo84jNSX1=gNg@CBe=<4b<W91;jo`0>d][H4ZZb]1:2SY0BGVY/4
SY6B18F8R@AlOh0Eoooo000Doooo16]^K`ASIFL4FUeO159EE`A9C4h3@4=613Lk?@@^<S@492T/11/O
8`@@5AT33A8E11LL7P@P92H4:2//134b<`@h>3T4?Sdn0clo@0A4@d@4AdI714I7BPA8BTd4BDa?14U=
D@=<D5@4Be1E14iDF0A?EEX4DEUM15=LH0=GH6D4FfAY15iXKPAPK744H6me16=cNPAWMgh3Jgb416f1
R@AcR8l4Ni2G18JIX0BBXjX3X:jd1;2k_`C1bL/4dmKH1>;Sh`C_knh4lO7_0nSXi`COgmh4eMKE1<_<
c0C2`l<4^;Zj0jna/PBVZ:T4WJ2Q19FGV0B<Si04Q8N817anP1Goool001Coool4Jfi_16=UI`AJGEl4
DUEG14U<CP=0@dH4=c/m12hb=0@T:B`46alS110E6@<=4QD45a`N120T9P@X:b`4<C8c13Ph>@@n?Ch3
?cm014A3A0A7ATL4ATM:14Q:C@A9C4l4BDeA0da@E0A;D5D4CUAH14mEFPAAFEd4DeaP0eMPI@AKI6T4
GVQ^161/L@APKgD4Hg=j16MgOP=[O8@4KH6917>8S`AkT9L4QYVP19:SZP>P[[@4/;^o1<79b`CCe]P4
h^?S1>o_kPCalNl3j>SW1=oOgPCEe]D4blc<1<;3``Bh^[X3[k6b1:JXZ@BMX:44UINH18b?T0B4QhP4
O7j05Oooo`005?ooo`A[KVl4HfEW15YMG`ABEEL4BDa>0d13AP@g>cd4;S8d12@Y;0@K7b<441DI0`dB
5@@G71h482@V12P[;0@a<S<4>3Pi13hm?P<o?d04A4=414M6A`A6AdX4B4Y=14U<C`A9CE43C51D14]@
E@A>E5P4CeEJ155IG@ACG603Ef1U15]TJ@ANJ6h4H6aa161_M@ASLgX4IgMn0f]lQ0A]PHT4LhR?17^@
U`B6VJ04TZ>Z0j2^]0B`^kl4`LW;1=?Ff0CRhn<4kno^1?7ak`?Xj>L4gmoN1=GFe@C;c<`4`/?31;Rj
^P>_/K84YZRY19fPX@BEUiP4S8n@18B7R0AlOX0Eoooo000Doooo16]^K`ASIFL4FUeO159EE`A9C4h3
@4=613Lk?@@^<S@492T/11/O8`@@5AT33A8E11LL7P@P92H4:2//134b<`@h>3T4?Sdn0clo@0A4@d@4
AdI714I7BPA8BTd4BDa?14U=D@=<D5@4Be1E14iDF0A?EEX4DEUM15=LH0=GH6D4FfAY15iXKPAPK744
H6me16=cNPAWMgh3Jgb416f1R@AcR8l4Ni2G18JIX0BBXjX3X:jd1;2k_`C1bL/4dmKH1>;Sh`C_knh4
lO7_0nSXi`COgmh4eMKE1<_<c0C2`l<4^;Zj0jna/PBVZ:T4WJ2Q19FGV0B<Si04Q8N817anP1Goool0
01Coool4K6i`16AWJ0ALGf44E5MI14a?DP=4AdX4?3m213<g>P@[;c848RHZ11TN8@<@5QT45Q`O11hS
9P@V:B`4;S0b13Dg>0@i>S`3>cdo13m0@PA2A4H4@TI914M:CPA7C504BDiB0d]AE@A=DUL4CeEJ155H
G@ADG604F61T0e]SJ0APJ6d4Hfaa16I`M@AWLgT4JgQn16mmPP=bPHL4MHJ=17b=U0B7UY`4TJ2U19jZ
[`>/][T4^l;41<_?d0CKg=`4j^[Y1>k]k0CUiN@3g]kM1=GFe@C=c/d4a<G51;bm_@Bc]KD3Zjf]1::U
Y@BJWId4TYFF18^=SPB3QHL4Ngio5Oooo`005?ooo`A/KW04I6MX15aOH@ADEeT4C4mB0dA7BP@l?d84
<cLj12/_<P@R9RX46AhQ0a0F6@@F71l47R<V12HY;0@^<384=CLh13Tj?0<k?Cl4?d121494APA2ATT4
AdY>14M<D0A9CU83Be5E14eBE`A?EEX4DEQM15ALH0AHH6@3Ff=X161XK@ASK744IW1e16McN@A[N7h4
Kgf20g:1Q`AeQXd4O8fD18NFW0BAX:D4WZZ_0jbf^@Bk`/@4blo@1=_Lg0CZj^T4k^g/1>GUi0?Ng]d4
eMKE1<g>c@C4aLD4_;fm1;>e]@>[[Jd4XZFU19ZMW@BBUIH4Rhf>18>5Q`AkOWlEoooo000Doooo16a^
L0ATIfP4G5mQ15AGF@A<Ce83A4M:13`o@P@c=cX4:blb128V:P@I7R4341HI11HL7`@N8bH49RT/12h`
<P@e=cP4>CXl0c/m?`@o@484@TA61496B@A7BTh4Ada@14U>DP=;DED4CE9G14mEFPAAF5d4E5aP15QP
I0=KHfP4H6Q]16=/L@AVL7D4Ig=i16]hOPA_OH83LX6717F6S@AlSI@4QiJL196PY@BNZZl3[;Ji1;_2
a0C;cm04fmcL1>[Zj@C^kN`4iNGT0mkNg@CEe]D4cLk=1<C5a@Bl_Kd4/kFe0j^][@BRYJD4VYfM19:E
UPB;SHh4PhF717]nOaGoool001Coool4K6i`16AWJ0ALGf44E5MI14a?DP=4AdX4?3m213<g>P@[;c84
8RHZ11TN8@<@5QT45Q`O11hS9P@V:B`4;S0b13Dg>0@i>S`3>cdo13m0@PA2A4H4@TI914M:CPA7C504
BDiB0d]AE@A=DUL4CeEJ155HG@ADG604F61T0e]SJ0APJ6d4Hfaa16I`M@AWLgT4JgQn16mmPP=bPHL4
MHJ=17b=U0B7UY`4TJ2U19jZ[`>/][T4^l;41<_?d0CKg=`4j^[Y1>k]k0CUiN@3g]kM1=GFe@C=c/d4
a<G51;bm_@Bc]KD3Zjf]1::UY@BJWId4TYFF18^=SPB3QHL4Ngio5Oooo`005?ooo`A/Kg44IFQZ15iQ
H`AGFU`4D5=E0dQ<CPA1A4L4>Ce0134f>@@Y;S448BLZ0aTO8P@G7B44728V12@Y;0@/<3<4<SDh13Lj
?0<i?3l4?3m213m3APA1ATX4ADY>14M<D@A:Ce@3Be9F14iEFPAAF5`4E5]P15QOH`ALHfL3H6M[16E/
L0AXL7@4KGEi16ehO@AcOH84MX650gV5RPAmRi04QY>G196LX0BLYZX4ZK2c0kNl_PC5alP4dm?C1>7P
g`C[jnX4hn?R1=_Lf`?De=@4c<g=1<G6a@Bm_[h4]KNg1:f_/0>VZ:P4WZ6Q19NIVPB@TY<4RH^<18:4
Q@AjOGhEoooo000Doooo16a_L@AUJ6X4GV5S15MJG0A@DeD3B4a>1454A`@i?D04<CHi12T^<@@Q9bX3
6AlR11LM8@@L8RH492T/12``<`@b=CP4=cXl0cTl?`@l?d84?d=61456BPA5BTh4AdaA14Y?E0=;DUH4
CUEJ155HG0ADFf04F5mS15aSI`=PIf/4IFa`16Q`M0A]MGT4KGQm17=mPPAfPHD3NHF:17f;T0B6TiL4
TIbP19bVZPBY/;<3]kbn1<G7b0CCdm<4hN3O1>_[jPCShn84fmcK0mCDe0C<cLd4aLK51;fn_PBe]kL4
[Jn`0jJXZ0BNXJ44UiVJ192BT`B9Rh`4PXB517YmOQGoool001Coool4K6ma16EXJPANHF<4EeYL151C
E@=8C4h4@DA713Tm@0@a=ST4:Bha124W:P<I7b845adQ11`R9P@T:B`4;30c138e>0@g>S`3>C`o13`o
@P@o@dH4@DI:14E:CPA7C544BTmD0d]BEPA>EEX4DEQL15AKH0AHGf<4G6=W0f1WJ`AUK704J71d16ee
N@A]N7d4Lgf217J1Q@=iQHX4OH^@18JCU`BAW:04W:JZ1:V`/`>g_;h4aLO81=?Cd`CQh=l4jn_Z1>?S
hPCKg=/3e=CD1<c=c@C5a/D4_Kjn1;Fg]`B][k03YZRX19jQX@BGVIX4T9:C18V;S0B2Q8D4NWen5Ooo
o`005?ooo`A]L744IfU[161SI@AJGEl4DeIH0da@DPA6BD`4?d=613Pl?`@a=ST4:S0c0b@Z;@@N92L4
7B<V12<Y;0@Z;c84<CHi13Hj?@<i?D04>cm313m4A`A0AT/4A4Y?14Q>D`A;DEH3CUAI155HG0ADFf04
EeiS15aRIPAPIfX3I6]^16U`L`A^MGP4LgYm17InPPAjPXD4NhB70gj9S0B5T9<4SYRK19VQX`BUZjd4
/[Jg0kk0`@C;bl/4f=OF1>;Qh0CPhN04f=WH1=7Bd@?:bl/4`lC41;bn_PBf]kL4[k2a1:RZZP>QXj@4
VYbM19BFU`B=Si04QhV:1823Q0AjO7hEoooo000Doooo16e`L@AWJF/4H6=U15YMG`ACEUP3C51B14I9
C0@o@dH4>3`o134f>@@Z<3<392X]11hT9`@M8bH48bT/12X_<P@a=ST4=SXm0cTm@0@k?d<4?dA71416
B`A4BTl4B4iC14]AEP=>E5T4DEQL15AKH0AGGV<4G69V161WJP=TJfh4JG1c16ieN0AcNWd4MWj217Z2
Q@AkQ8L3OXV<18F@T`B>V9/4VJ6S1:F[[@Bb][L3_/311<_;b`CHemH4h^7P1>3Qh0CHfMP4dM;A0l[;
b`C3a<@4_;jn1;Jg]`B_/;44Z:ZZ0j6SY0BJW9d4U9JG18f?T0B7RHX4P8>417YlOQGoool001Coool4
KG1a16MYJ`APHfD4FUeO15=FF0=<D584ATU<13m3AP@h?3l4<CHi12X`<`<T:Rd47R@W11dS9P@S:B`4
:Rlb134f>@@f>Sd3>Ce013/o@`@oA4L4@4I;14A:C`A8CU<4Be5F0diDF@AAF5`4E5]P15MNH`ALHVH4
H6MZ0fA[KPAYL7<4KWEh17=jO@AfOX84NX:517^4Q`=nRH`4QI2C18jHV`BIXJ<4YJ^]1;:f]`>n`<44
bl_;1=SGePCRhN04h>7P1=SIf0CAd]43b/_;1<?4a0Bl_[h4][Ng1:n`/@BXZZX3XJ>T19ZLW@BDUYL4
SHn@18N9RPB0Ph@4NWan5Oooo`005?ooo`A]L744IfU[161SI@AJGEl4DeIH0da@DPA6BD`4?d=613Pl
?`@a=ST4:S0c0b@Z;@@N92L47B<V12<Y;0@Z;c84<CHi13Hj?@<i?D04>cm313m4A`A0AT/4A4Y?14Q>
D`A;DEH3CUAI155HG0ADFf04EeiS15aRIPAPIfX3I6]^16U`L`A^MGP4LgYm17InPPAjPXD4NhB70gj9
S0B5T9<4SYRK19VQX`BUZjd4/[Jg0kk0`@C;bl/4f=OF1>;Qh0CPhN04f=WH1=7Bd@?:bl/4`lC41;bn
_PBf]kL4[k2a1:RZZP>QXj@4VYbM19BFU`B=Si04QhV:1823Q0AjO7hEoooo000Doooo16i`LPAXJfd4
HVEW15aPH@AGFU`3DEAF14]?D@A5BD/4?d=613Tn@0@c>3/3;S<f12T^<P@T:Rd48bT]12T_<`@`=ST4
=S/o0c/o@`@l@TD4?dE91458C@A5C504BU1E14eDF0=AF5`4E5]O15MMHPAKHFD4H6IY16AZK@=YKW84
KW=f17=hN`AiOX44OH:51825QPB0QhT3Q8b>18bDUPBDVid4WZ>U1:^^[`Bh^KT3`l?31<k=c0CJfMP4
f][J1=?Dd`C=c/d4alS70l72`PBj_;`4];Jf1:j`/0BXZZX4XZBU0ibNW`BFV9T4T9:C18Z=SPB5QhP4
Oh6317UlOAGoool001Coool4KW1b16Q[K@ARIFL4G61Q15MJG0=AE5H4BdmA14E9B`@o@dH4>Ci013<h
>`<^<cH4:Bhb12@Z;@@S:Bd4:Blc130f>@@f>cl3>cm313a2A@@oADT4@DQ=14E<D0A:D5D4CEAH0e5H
G0ADFel4EeeR15]QI@APIVT4I6Y]0fU^LPA^LgH4LgQk17UnP@AmPXD4P8F61827R@>4S8h4S9BF19BK
W@BNXjD4Zjj_1;Ri^@?3`l<4c/g<1=[If0CJf]X4dmCC1<g>c@C7b<L3`L;21;Zl_0Bd][H4[[2`1:RZ
ZPBRY:D3W9jO19JHV@B@TY<4RXf>18F7R0AoPH<4NGam5Oooo`005?ooo`A^L784J6]]169UI`ALH644
EeYL0e5DEPA;Ce44ADU;13m3AP@i?T04<cPk0bhc=P@Y;S8492X]12<Y;@@Y;c<4<3Hi13Hk?`<k?d<4
?49513m5B@A1B4d4ADa@14Y@E@A=E5P3DEQL15AKG`AGGF84Ff5U161VJ@ATJVd3JFib16icMPAcN7/4
NGj117f2Q@B0QHH4P8N90hB<SPB<U9H4U9^M19jSY@B[[Zl4^;Vi0l?3``C>cL`4f]WH1=[JfPCCe=<4
cLk=1<O8a`?1`/84^[bl1;Bf]PB^/;04Z:ZZ1::TY@>LWYl4UYRI192BT`B:SHh4QHN817n1P`AiO7dE
oooo000Doooo16i`LPAXJfd4HVEW15aPH@AGFU`3DEAF14]?D@A5BD/4?d=613Tn@0@c>3/3;S<f12T^
<P@T:Rd48bT]12T_<`@`=ST4=S/o0c/o@`@l@TD4?dE91458C@A5C504BU1E14eDF0=AF5`4E5]O15MM
HPAKHFD4H6IY16AZK@=YKW84KW=f17=hN`AiOX44OH:51825QPB0QhT3Q8b>18bDUPBDVid4WZ>U1:^^
[`Bh^KT3`l?31<k=c0CJfMP4f][J1=?Dd`C=c/d4alS70l72`PBj_;`4];Jf1:j`/0BXZZX4XZBU0ibN
W`BFV9T4T9:C18Z=SPB5QhP4Oh6317UlOAGoool001Coool4KW5c16U/KPATIfT4Gf9T15YMG`=EFE/4
D5AF14]?D@A6BT`4@DE813a0@`<g?3l4<cPk12ld>0@Z<3<4:S0d130g>`@g?D43?D961415B@A2B4`4
@dY?14Q?D`A=E5P4D5MK0eAJGPAGGV84FV1U15mTJ0ASJF`4J6e`0febM0AaMGL4Mg]l17f0PPB1Q8D4
Q8N818>8RP>8SY04T9FG19NLWPBRYZH4[k6a1;^k^P?6aLD4c/g=1=;BdPC<cLd4alS81<;3``Bl_Kd3
]kRh1;:c/`B/[Zh4YjVY1::SY0BLWYl3UiVJ19:DU@B=Si04R8Z;18>5QPAmP844N7]l5Oooo`005?oo
o`A^LG<4JFa^16AWJ@AOHV@4FUeO0eEIF`A@E5H4BdmA14I:C0A1ADP4?4130cLl?`@c>3/4;c@h12X`
<`@Z<3@4<3Lk13Lm@@<m@TH4@4E91498C0A3BTl4B4mC14eDF0A@Ee/3E5YN15MNHPAJH6D4GfAX16=Y
K0AXKG03KG9d175eM`AgNg`4OH221864Q@B4QhP4PhR:0hR>T0B@UIL4UibN1::VYPB_/K44^k^j0lK5
a@C>cLd4d];B1<c=c@C7b<P4`/?31;bm_@>g^;P4/[>c1:b^[PBWZJT4XZ>T19bNW`>GVIX4TYBE18f?
T0B8RX/4PhF617f0P@AhNg`Eoooo000Doooo16iaL`AYK6h4I6MY15mRI0AJGEl3EEUK151DEPA;Ce44
ATY<1455B0@l@4<3=c`o13<h>`@_=3P4:S0c12X`=0@`=c/4=ce10ce2APA0ADT4@TQ<14=:C`A8Ce<4
CEAH151GF`=DFUh4EeiR15YPI@AOI6P4HfU/16Q]L0=]LW@4LGEg17MkO0AmP884PHB518B7R0B3R8X3
R8j@192EU`BGW9h4XZJV1:na/@Bk^kX3a/G51<k=c@CBd]84c<g=1<O8b0C2`l<4_;fm0kNh^0Bb/k<4
[:j^1:NYZ@BRXj@4W9jO0iNIVPBBU9D4SHn@18R:R`B3QHH4OH2117QkO1Goool001Coool4KW5c16U/
KPATIfT4Gf9T15YMG`=EFE/4D5AF14]?D@A6BT`4@DE813a0@`<g?3l4<cPk12ld>0@Z<3<4:S0d130g
>`@g?D43?D961415B@A2B4`4@dY?14Q?D`A=E5P4D5MK0eAJGPAGGV84FV1U15mTJ0ASJF`4J6e`0feb
M0AaMGL4Mg]l17f0PPB1Q8D4Q8N818>8RP>8SY04T9FG19NLWPBRYZH4[k6a1;^k^P?6aLD4c/g=1=;B
dPC<cLd4alS81<;3``Bl_Kd3]kRh1;:c/`B/[Zh4YjVY1::SY0BLWYl3UiVJ19:DU@B=Si04R8Z;18>5
QPAmP844N7]l5Oooo`005?ooo`A_LW<4Jfi_16IZJ`ARIFL4GV5S0eUMG`AEFE/4DEAG14a@D`A8C4l4
A4Q;0d15B0@l@D@4>Ci113Dk?P@a=c/4<STm13Pn@`<oADT4A4Y>14I=D@A8CU<4C5=G155GG0AEFeh3
F5iR15YQI@AMHfP4HVM[16M/K`A/L783LGAf17AgN@AjOGd4OH2118F6QPB5QhP4QhZ;0hfAT@BDUiP4
W9nP1:NXZ0B`/K44_Kbk0lG5a@C6alL4`lG41;o0`0Bk_;`4][Rh1;:c/`>][jl4ZJZ[1:BVYPBPXJ84
VifN19NIV@>BU9D4SY2A18V;S@B5QhP4P8>417aoP0AhNW`Eoooo000Doooo16mbL`A[KVl4IVY[169U
I`ANHF<3FEeO15EIF`AAE5L4C51C14Q<C`A4B4/3@4E813a1A0@i?T44=C/n134g>`@b>Cd4>3i30cm5
B@A4BTh4ATeA14Q>D`A<DeL4DEML15EKGP=HGV84FV5U15eSJ0ARIf/4Ifa_16a`LP=aM7H4M7Mi17Ym
O@AmP844QHJ618F7R0B7RX/3SI6A19BGV0BLWj04YjRX1;2a/@Bm_;/3aLG51<K7a`C3aL@4_l301;^l
_0Bf^;P4/[>c0jf_[`BYZZ/4Y:JV1:2QXPBKWIh4UiVI0i:DU@B>T944RH^=18F7R0B0Ph@4O7n017Qj
O1Goool001Coool4Kg9c16]^K`AVJV/4HVEW15iQH`=IGEl4EEUK155DE`A<D5<4B4a?14A8B`=0ADP4
?45413Tn@@@e>ch4<CLk138i?@@h?T<3?dE914A:CPA6CE44B4iC14aCE`AAEe`4EE]N0eQNHPAJHFD4
GF=X169WJ`AWK6l4K71b0g5dMPAdMgT4NWem17f0P@B5QXH4QHN818N:R`>=TI44U9NH19bOX0BWZ:P4
/;6a1;fl^`?5aLD4a/O71<?5a0Bo`<04^kbl1;Jh^0Bb/k<3[Jn_1:VZZ`BTYZH4X:6R19^MWPBGVIT3
TYBE18j@T@B9Rhd4QHN81823Q0AlOh04N7Yl5Oooo`005?ooo`A_LW<4Jfi_16IZJ`ARIFL4GV5S0eUM
G`AEFE/4DEAG14a@D`A8C4l4A4Q;0d15B0@l@D@4>Ci113Dk?P@a=c/4<STm13Pn@`<oADT4A4Y>14I=
D@A8CU<4C5=G155GG0AEFeh3F5iR15YQI@AMHfP4HVM[16M/K`A/L783LGAf17AgN@AjOGd4OH2118F6
QPB5QhP4QhZ;0hfAT@BDUiP4W9nP1:NXZ0B`/K44_Kbk0lG5a@C6alL4`lG41;o0`0Bk_;`4][Rh1;:c
/`>][jl4ZJZ[1:BVYPBPXJ84VifN19NIV@>BU9D4SY2A18V;S@B5QhP4P8>417aoP0AhNW`Eoooo000D
oooo171cM0A/Kg44JFa]16EXJPAQIFH3GV5S15YNH0AGFU`4DeMI151DEPA<D5<3BDe@14I:C@A3B4/4
@4E813e3A`@k@DD4?TA80d58B`A7CE44Be5E14iEF@ABF5`4EeaP15YPH`=LHVD4GVEX16=WJ`AWJfd4
JFe`16eaM0=cMGL4MgUk17]mO@AnP804QHJ618J7R0B:S8`3Si6B19FHV@BNX:04YjRW1:f^[PBk^kX3
_;fm1;Ri^PBe]kL4/[Bd1:n`/0B[[Jd4YjVY0j>UYPBPXZ84W9jN19RJV`BDUiL4TI>D0hf?T0B9S8d4
QXR918:4QPAnPH84Ngen17MjNaGoool001Coool4L7=d16a_L@AYK6d4IFQZ165UIP=NHF<4FUiP15MJ
G0ACEeT4D5AF14a@D`=9CE04ATY=14=8B`A0ADP4?D=713]1A@@nA4P3@DQ;14M=D@A;DED4CUEI159H
G0AGG604FV1S0eaRI@ANIFP4HfM[16M[K@AYKG04KG5d0g=eM`AgNG/4Ngem17j0P0B5QXH4QXN818Z<
S0>?TI84UIRI19jPX0BWZ:L4[Jj^1;^k^P>l_Kd4^;Vj1;Fg]`Bb];@4[k2`1:^][@BWZJT3XjFV1:2R
XPBLWYh4V9ZK19BGU`BATi@3SHn@18V<S@B6R8T4PXB617j1PPAkOGh4MgYk5Oooo`005?ooo`A`Lg@4
K6ma16U/K@AUJ6X4HFEV0eiQH`AJGV04EeYL15=GF@A@E5H4C51C0dU=D0A6BTd4@dQ;1415B0@m@dL4
>d5513i4B0=1B4/4AdeA14]AE@A>EET4DUQL15MLH0AJH6<3G69U15iUJ0ASIf/4If]]16U]L0A]LG@3
LgEg17MiN`AkOGd4OX2018F6QPB6QhP4RXb<0hnATPBEV9T4WZ2P1:NXY`B][Zh4^k^j0kbm_@Bh^KX4
]KNg1;:d]0B_/;04Zjf]1:NYZ@>SYJH4X::R19bNWPBHVY/4U9NG196CU0>=Si04RHb=18J8R@B2Q8H4
OX6217]mOPAgNW/Eoooo000Doooo171cM0A/Kg44JFa]16EXJPAQIFH3GV5S15YNH0AGFU`4DeMI151D
EPA<D5<3BDe@14I:C@A3B4/4@4E813e3A`@k@DD4?TA80d58B`A7CE44Be5E14iEF@ABF5`4EeaP15YP
H`=LHVD4GVEX16=WJ`AWJfd4JFe`16eaM0=cMGL4MgUk17]mO@AnP804QHJ618J7R0B:S8`3Si6B19FH
V@BNX:04YjRW1:f^[PBk^kX3_;fm1;Ri^PBe]kL4/[Bd1:n`/0B[[Jd4YjVY0j>UYPBPXZ84W9jN19RJ
V`BDUiL4TI>D0hf?T0B9S8d4QXR918:4QPAnPH84Ngen17MjNaGoool001Coool4LG=e16iaLPA[KVl4
J6]]16EXJP=RIFL4Gf=T15aPHPAJGEl4Ee]M15AHFP=BEUP4Ce=F14eAE0A;D584BDiA14Q=D@A7CE43
B4iA14Y@E0A@EeX4EE]P15]OHPAMHF@4GfAW0f1UJ0ASJ6`4If]^16U/K`AZKG04Kg9d0g9eMPAgNGX4
NWal17n0P0B3Q8@4QhN718^<S0>?TI84UYRH19bMW@BTYJD4ZJb/1;2a/@>][Zh4ZZb/1:RZZPBUYjL4
XjBU1:2RXPBMWil3VYbL19NIVPBDUYL4TI>D18j@T@B;SHh3R8Z;18F7R0B2Q8H4Oh:317aoP0AiO7d4
MWUj5Oooo`005?ooo`AaLgD4KW5b16]^K`AXJfd4IFQZ0f9UI`AOHf@4G61R15YMG`AGFed4E5QJ0e9F
F0A?DeH4CE5D14]@DPA9CU44B4eA14M=D@=8CU44BU1D151GFPAEFf04FemR15eQI0AOI6L3H6EX16=X
K0AWJfh4JFa_16Y]L0A_LW@3LWEf17MiNPAjO7`4Oh2018>4Q0B7QhL4Rhb<0hnATPBFV9P4W9fM1:BU
Y@BY[:`4/;6a0jf^[PBZ[:`4Z:ZZ1:FWY`BSY:D4X::R19fOW`>JW9`4UiVJ19BFU`BATi@4SY2A18^=
SP>8RX/4QHN818:4QPAoPX<4O7n017UlO@AfNGXEoooo000Doooo175cM@A^LG84Jfi_16Q[K@AUJ6X3
HVEW15mSI0ALH684FUeO15MKG@ADF5X3DUIH14mCEPA=DE@4Be1B14U>D@A8CE44AdeA0dQ>D@A:D5@4
D5MJ15EKH0AKGf84GF5T15mTI`=PIFP4HfQ/16M[KPAYK6l4JVe`16mbM0=bMGH4MgUj17YlO0AoP804
PhB418N7Q`B;S8`3Si6B19JHV0BLWId4Y:FU1:V/[0B`/K43[Jj^1:Z/[0BXZZX4YJNW1:>TY@BPXZ84
WInO0iZLW0BGVIX4U9JG196CU0B>T944Rhf>0hR:R`B5QhP4PXB617n2P`AlOh04NGam17IiNQGoool0
01Coool4LGAf16mbM0A]L784Jfi_16U/K@=VJV/4I6QY169UI`APHfD4GV9T15aPHP=JGV04F5aO15MK
G@AEFU`4E5UK2e=HF`ABF5`4F5iQ15aQI@AOHfH4HfMY16EYK0=VJV`4If]]16Q/K`AZKW04KG1b171c
M@=cMWL4MgUj17YlO0AnP804PX>318F6QPB9Rh/3SHn@19FGV0BHVYX4W9jO1:2RXPBOXJ43WZ2P19bN
W`BKW9d4VI^K19NIV@BEUiL4TYBE0i2BT`B>T944S8j?18Z<S@B7RX/4QHN80h>5QPB1Ph@4OX6217ao
P0AjOGh4N7Yl17IhNQGoool001Coool4LGAf16mbM0A]L784Jfi_16U/K@=VJV/4I6QY169UI`APHfD4
GV9T15aPHP=JGV04F5aO15MKG@AEFU`4E5UK2e=HF`ABF5`4F5iQ15aQI@AOHfH4HfMY16EYK0=VJV`4
If]]16Q/K`AZKW04KG1b171cM@=cMWL4MgUj17YlO0AnP804PX>318F6QPB9Rh/3SHn@19FGV0BHVYX4
W9jO1:2RXPBOXJ43WZ2P19bNW`BKW9d4VI^K19NIV@BEUiL4TYBE0i2BT`B>T944S8j?18Z<S@B7RX/4
QHN80h>5QPB1Ph@4OX6217aoP0AjOGh4N7Yl17IhNQGoool001Coool4LGAf16mbM0A]L784Jfi_16U/
K@=VJV/4I6QY169UI`APHfD4GV9T15aPHP=JGV04F5aO15MKG@AEFU`4E5UK2e=HF`ABF5`4F5iQ15aQ
I@AOHfH4HfMY16EYK0=VJV`4If]]16Q/K`AZKW04KG1b171cM@=cMWL4MgUj17YlO0AnP804PX>318F6
QPB9Rh/3SHn@19FGV0BHVYX4W9jO1:2RXPBOXJ43WZ2P19bNW`BKW9d4VI^K19NIV@BEUiL4TYBE0i2B
T`B>T944S8j?18Z<S@B7RX/4QHN80h>5QPB1Ph@4OX6217aoP0AjOGh4N7Yl17IhNQGoool001Coool4
LGAf16mbM0A]L784Jfi_16U/K@=VJV/4I6QY169UI`APHfD4GV9T15aPHP=JGV04F5aO15MKG@AEFU`4
E5UK2e=HF`ABF5`4F5iQ15aQI@AOHfH4HfMY16EYK0=VJV`4If]]16Q/K`AZKW04KG1b171cM@=cMWL4
MgUj17YlO0AnP804PX>318F6QPB9Rh/3SHn@19FGV0BHVYX4W9jO1:2RXPBOXJ43WZ2P19bNW`BKW9d4
VI^K19NIV@BEUiL4TYBE0i2BT`B>T944S8j?18Z<S@B7RX/4QHN80h>5QPB1Ph@4OX6217aoP0AjOGh4
N7Yl17IhNQGoool001Coool4LWEf175dM@A_LW@4KW5b16a_L@=[KVl4JFa^16Q[K@AWJV/4IFQZ16AW
J@=SIVP4HVEW161TIPQOHfD;GV9U15mSIPAQIFP4HVMZ16AXJ`AZKFl4Jfia0fY]L0A[Kg04Jfma16]_
LPA_LW@4LGAe0g=fM`AgNGX4N7]k17]mOPAnP804PH>418V:R`>9Rh`4SY2A28nATPR@TY<3Si:B18nA
TPB=T904S8j?18^=SPB9S8d4R8Z;0hN9RPB5QhT4Q8J718:5QPB1Ph@4Oh:30gj0P@AlOh04Ngeo17Ul
O@AhNW`4MWUj17EhNAGoool001Coool4LWEf175dM@A_LW@4KW5b16a_L@=[KVl4JFa^16Q[K@AWJV/4
IFQZ16AWJ@=SIVP4HVEW161TIPQOHfD;GV9U15mSIPAQIFP4HVMZ16AXJ`AZKFl4Jfia0fY]L0A[Kg04
Jfma16]_LPA_LW@4LGAe0g=fM`AgNGX4N7]k17]mOPAnP804PH>418V:R`>9Rh`4SY2A28nATPR@TY<3
Si:B18nATPB=T904S8j?18^=SPB9S8d4R8Z;0hN9RPB5QhT4Q8J718:5QPB1Ph@4Oh:30gj0P@AlOh04
Ngeo17UlO@AhNW`4MWUj17EhNAGoool001Coool4LWEf175dM@A_LW@4KW5b16a_L@=[KVl4JFa^16Q[
K@AWJV/4IFQZ16AWJ@=SIVP4HVEW161TIPQOHfD;GV9U15mSIPAQIFP4HVMZ16AXJ`AZKFl4Jfia0fY]
L0A[Kg04Jfma16]_LPA_LW@4LGAe0g=fM`AgNGX4N7]k17]mOPAnP804PH>418V:R`>9Rh`4SY2A28nA
TPR@TY<3Si:B18nATPB=T904S8j?18^=SPB9S8d4R8Z;0hN9RPB5QhT4Q8J718:5QPB1Ph@4Oh:30gj0
P@AlOh04Ngeo17UlO@AhNW`4MWUj17EhNAGoool001Coool4LWEf175dM@A_LW@4KW5b16a_L@=[KVl4
JFa^16Q[K@AWJV/4IFQZ16AWJ@=SIVP4HVEW161TIPQOHfD;GV9U15mSIPAQIFP4HVMZ16AXJ`AZKFl4
Jfia0fY]L0A[Kg04Jfma16]_LPA_LW@4LGAe0g=fM`AgNGX4N7]k17]mOPAnP804PH>418V:R`>9Rh`4
SY2A28nATPR@TY<3Si:B18nATPB=T904S8j?18^=SPB9S8d4R8Z;0hN9RPB5QhT4Q8J718:5QPB1Ph@4
Oh:30gj0P@AlOh04Ngeo17UlO@AhNW`4MWUj17EhNAGoool001Coool4LgEg179eMPAaM7H4LG=e171c
M0=_LW<4KW5c16iaLPA]L744K6ma16a_L0=[KW04JVi_16Y]K`AZKFh?JFa^16U]K`AZKW04Jfia16a_
L@A^LG<;Kg9d16ibM0A_LW@4LWEf17=fM`=eMgP4MWUj17MjN`AiNg`4NWam17eoP0B2Q8D3P8:31823
Q0B1Ph@4PHB528:4Q@>1Q8D4PH>41823Q0B0PX<4Oh:317j1PPAnP843OH2117aoP0AlOWl4Ngeo17Ym
OPAiO7d3NG]l17QjO0AgNW/4MWUj17IhNPAeN7T4M7Mh5Oooo`005?ooo`AcMGL4LWEf175dMPAaLgD4
L7=d0fmbL`A^LG<4KW5b16e`L@A/Kg44K6m`0f]^L0AZKVl4JVe_16Y]KPmYK6h4JFe_16Y^L0A[KW44
K6ma16iaL`]_LW@4KW9d16mbM0AbMGH4LgIg0gEgN0AfNGX4MgYk17UkO0AjO7d4OGn018:4Q@>0PX<4
P8>41863Q0B1Q8D8PXB50h64Q@B1Ph@4P8>41822P`AoPX<4OX6217j0P@=mP844O7n017anO`AkOGl4
NWen17UlO@=iNg`4N7Yl17MjN`AfNGX4MWQj17EhN@AdMgPEoooo000Doooo17=eM`AbMGH4LGAf175c
M@A`Lg@3Kg9c16iaL`A^LG84KG1a16a_L@A/Kg03Jfi`16Y^K`AZKFl4JVe^3fU/KPAYKFl4JVi`16]^
L@A/Kg44KW5c2fmbM0A^LW@4Kg9d179eMPAcMWL3MGMh17IiNPAgNW/4NG]l17YlO@AmOh04PXB50h22
P`B0Ph@4PH>41864Q@R2Q8D3PHB51863Q0B0Ph@4P8:317n2P`AnPH84OX210gf0P@AlOh04O7io17]m
O`AjOGh4NGam0gUkO0AhNW`4MgYk17IiNPAfN7X4MGQi17AgN1Goool001Coool4LgEg179eMPAaM7H4
LG=e171cM0=_LW<4KW5c16iaLPA]L744K6ma16a_L0=[KW04JVi_16Y]K`AZKFh?JFa^16U]K`AZKW04
Jfia16a_L@A^LG<;Kg9d16ibM0A_LW@4LWEf17=fM`=eMgP4MWUj17MjN`AiNg`4NWam17eoP0B2Q8D3
P8:31823Q0B1Ph@4PHB528:4Q@>1Q8D4PH>41823Q0B0PX<4Oh:317j1PPAnP843OH2117aoP0AlOWl4
Ngeo17YmOPAiO7d3NG]l17QjO0AgNW/4MWUj17IhNPAeN7T4M7Mh5Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00U_ooo`<00027oooo002I
oooo00<0003oooooool0Q?ooo`00O_ooo`<00004oooo0P0000Coool400000_ooo`<00003oooo0`00
00?oool20000POooo`00O_ooo`040000oooooooo00000_ooo`040000oooooooo00000_ooo`040000
oooooooo00000_ooo`030000oooooooo00?oool010000?ooooooo`0008Koool007koool010000?oo
ooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool400000_ooo`040000
oooooooo0000Q_ooo`00O_ooo`<00004oooo0P0000Coool300000oooo`800004oooo100008Goool0
07ooool00`000?ooooooo`02oooo00@0003oooooool00005oooo00<0003oooooool0T?ooo`00Oooo
o`<00003oooo0P0000Goool20000T_ooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
75.000 12.813 moveto
(deg) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
7B7B7C7A7B7B7A7A7B7A7A7B7A7A7A7A797A79797A797979797979797879797878797878
787778787777787777787676787676787676787575787575787574787474787373777270
787474787575787576787575777676777576777576767575767475767575757475767576
76757676777876777977797A787A7B787A7C797B7D797C7E7A7E7F7B7F827C81837D8386
7F868A7D82857C80827C7F817B7E807B7E7F7B7E7F7B7D7F7B7D7E7B7D7E7B7C7E7B7C7D
7B7C7D7B7C7D7B7C7C7B7B7C
7A7B7B7A7A7A7A797A797979797879797878787777787677777676777575777575767474
76737376737275727275717175717075707075706F746F6E746E6D746D6C746C6A746B68
756D6C756E6E756F6F746F6F747070737070736F6F726E6F726E6E726E6F716E6F716F71
72707272727473747674767875787A767A7C777B7E787D807980837B83877D878B7F8B90
818D927F888C7D85887D83867C81847C80837B80827B7F817B7E807B7E807B7D7F7B7D7E
7B7D7E7B7C7D7B7C7D7B7C7C
7A7A7B7A797A797879787878787777777676777575767474767373757272757271747170
74706F736F6E736E6D726D6C726C6B726B69716A68716967716866716764716662716460
726764726867726A69716A6A716A6A706A6A6F69696E696A6F696A6E696A6E6A6B6E6C6D
6F6D6F70707270717471747672767974797C757C7F777F827983877B878B7E8B91829198
829096808B907E888C7D86897C84877C83867C81847B81837B80827B7F817B7F807B7E80
7B7D7F7B7D7E7B7C7D7B7C7D
7A7A7B797979787778787777777676767474767373757271747170736F6F736F6E726D6C
716C6A716A697069687068666F67656F66636E64626E63606E625F6E615D6E5F5B6E5E59
6F615E6F63616F64636E65646E65646D65656C65666C65666D65666C66676B67686C696A
6D6A6D6D6C6F6E6E716E727570757872797C747C8076808579858A7B898F7F8F9582959C
8191987F8E937E8B907D888D7D868A7C85887C83877B82857B81847B80837B80827B7F81
7B7E807B7D7F7B7D7E7B7C7D
7A7A7A797879787777777676767474757372747170736F6F726E6D716D6B716B6A706968
6F68666E66646D65626D63616C625F6B605D6B5F5B6B5D596A5C576B5A566B59546C5853
6C5C586C5E5B6C5F5D6B605F6B61606A61616A6262696262696162696263686364696567
6A686A6A6A6C6B6D706C70736E747770797D727C8175818678868C7B8C927F929982979F
80939A7F8F967E8C927D8A8F7C888D7C868B7C85897B84877B83867B81847B80837B7F82
7B7F807B7E7F7B7D7E7B7C7D
7A797A787878777676767474757372747170736F6E726D6C716B6A706A686F68666E6664
6D64626C62606B605D6A5E5B695C59685B5767595567575267555067544F68534E69534D
695752695956695A58685C5A685C5C675D5D675D5D665D5E665D5E665E5F666061666263
666466676769686A6D696D716B73766D787B707C8173818677878D7A8E957F959D8198A0
7F949B7E90987D8E947D8B917C8A8F7C888D7C868B7B85897B84877B83867B81847B8083
7B7F817B7E807B7D7F7B7C7D
79797A787777777575757373747171736F6E716D6C706B696F69676E67656C64626B6260
6A605D695E5B685C58675A5666575365555164534E63514B624E49634D47644D46675049
67534E67555266565466575665585864585864595963595A62595A625A5B625B5D625D5F
63606363646664676B666B6F6871746B767A6E7C8071818676888E7A8F977E96A07F97A0
7E949C7D91997D8F967C8D937C8B917C898E7B878C7B868A7B85897B84877B82857B8183
7B80827B7F817B7E7F7B7C7E
797979787677767474757271736F6F726D6C706B6A6F68676D66646C64616A615F695F5C
685C59665A5665575364555062524D61504A604D475F4A445D47415B443D644A42674F49
66504C65514E6452506353526254536154546054546054555F54555F55565E57585E595B
5E5C5F5F606361656862696D656F726875796C7B8070818774888F788F977D97A07D969F
7D949C7C92997C90977C8E947B8C927B8A907B898E7B878C7B868A7B84887B83867B8285
7B81837B80827B7E807B7D7E
797979777676767373747170726E6D706B6A6F69676D66646B63616A615E685E5B675B58
65585564565262534E61504B5F4D485E4A445C47415B443D594039583F37694D45674E47
644E49634E4B614F4C604F4E5F504F5E50505D50505C4F515B4F515B4F525A52535A5457
5B585B5C5E605D62665F676B626D7166747869797F6E808772878F768E967B96A07B959E
7B939C7B929A7B90987B8E967B8D947B8B917B8A8F7B888D7B878B7B85897B84877B8286
7B81847B80827B7E807B7D7E
797879777575757272736F6F716D6C6F6A686D67656B64626A615E685E5B665B57645854
63545061514D5F4E495E4B465C48425A453E59423B573E37543A3261443B6B4E45654B45
624B46604A475F4B485D4B495C4C4B5B4C4C5A4C4C594B4C584A4C574B4E564E50575254
585659595B5E5A60645C6569606C7064727768797E6C7F8670868E758D9579949D79949E
7A939C7A929B7A91997A8F977A8E957B8C937B8B917B898F7B888D7B868B7B85887B8386
7B82847B80827B7E807B7D7E
797878767575747171726E6E706B6A6E68666C65636A615F685E5B665B58645754625450
60514C5E4D485C4A445A464159433D574039563C3452372F5C3E3567483F654840624842
5F47425D47435C47445A474659484758484957474956474854454854474A534A4D544F52
555457565A5D575F625A64695E6B6F62727767787E6B7F856E858C738B9375909A78949E
79939D79939C79919A7A90987A8F967A8D947B8C927B8A907B898E7B878C7B858A7B8487
7B82857B81837B7F817B7D7E
787878767474747070716D6D6F6A686D66646A6360685F5C665B586458546254505F504C
5D4D485B494459454057423B553E37543A3352372F57393063433A62433B60443C5E443E
5C433E5A433F58434057444356444455444554434553444651434651474A504B4D515053
51545753595C545E615864685C6B6F60717666787E697E856D848C718992738F9876939D
77949E78939D78929C79919A7990987A8E967A8D947B8B927B8A8F7B888D7B868B7B8488
7B83867B81847B7F817B7D7F
78777876737373706F706C6B6E68676B646269605E675D5A6459556255515F514D5D4D48
5B494458453F56413B543D3652393250352D4E31285C3C315F3F355F41385D41395B403B
583F3A563E3A543F3D5441405341425241425241435144454F46484E494A4F4F504F5254
4E53554F585B515E615664685A6B6F5F717664787E687E856C838B6E8891718D9774919B
7795A077949F77939D78929C79919A7A90987A8E957B8D937B8B917B898E7B878C7B8589
7B83877B81847B7F817B7D7F
787777757373726F6E706B6A6D66656A6361675E5C655A5762565360524E5D4E495A4944
58454055413B533D365038314E342C4C2F275233286140355E3F355C3E365A3F38583D38
553B37513A37503B3A513E3F4F3E404D3F40524647514849504C4D4F4E4F4E4E504C5052
4B52554C595C4D5C60536266596B6F5F717664787F687E866B838B6D87906F8C95718F9A
74939E7595A076949F77939D79929B7A91997A90977B8E957B8C927B8A907B888D7B868A
7B84877B82857B80827B7D7F
787777757272726E6D6F69686C656369615F665C5A6358556053505E4F4B5B4B46584641
55413B523D364F38314D342C4B3027482B2259382D5F3E345D3E345A3C34583D37553B36
5238344E37344D39384C3B3C504444524949564E4F514D4E4F4E4F4D4D4E4B4C4D4B5254
4B54574B575B4B595D506065586A6E5E727763787F677F866A838B6B868F6C8A946F8D98
71929D7395A27595A177949F79949E7A939C7B91997B8F977B8D947C8B917C898E7C878B
7B85887B82857B80827B7E7F
777677747271716D6C6E68676B6462675F5D645A576156525E514D5C4C4859474256433D
533E374F39324C332C482E26472B23492A205F3D315E3D335B3D34583C34563C36533A35
4F37324B37344C3A3A4C3E3F564B4A544A4A514A4A4F4A4B4D49494A484948484A494D50
484F524A54584C585B51606556676C5E717663797F67808668838B69858E6A88926C8C97
6E909C7094A17395A07696A17996A07B959E7B939B7C91987C8F967C8D927C8A8F7C888C
7C85897C83867B80837B7E7F
777676747171706C6B6D6766696260665D5B6358556053505D4E4A59494556443F533F39
503A344C352D482E2641261E44271E5332266240345D3D33593B33563B34543B35513934
4D37334D3B384F4140524746574D4C524B4B4F49494C48494A454647454746454846494C
464D4F4854574A555A4E5D6353646A5C6E74647A8067808767838B67848D678691698A95
6C8F9B6E939F7296A37697A47B9AA37C97A17C959E7C939B7D90977D8E947C8B917C898D
7C868A7C83867B81837B7E80
7776767370706F6B6A6C666468605E645B586156535E514D5B4C4757474254423C513C36
4E37304B322A452B223F231A4C2D235F3D315F3F345B3C33573B33543B35523B354F3834
4C38344C3C394F43415046455048484E49494C49494B4848484747464747454849454C4D
4550524754574A565B4D5D62526469596C72637A8066818766838B65838C658590678994
698D996B909D6C92A0779AA67C9CA67D9AA47D97A07D959D7D92997D8F967D8C927D8A8E
7C878B7C84877C81837B7E80
77757673706F6F6A696B6463675F5D6359575F54515C4E4B58494455443E523F394F3A33
4D352D4A3027472B224A2B2057362B603F335B3C32583B33553B34523B35503B354D3935
4B39354B3C394E43414D44444D46454B464649464647454645434543444542464842494C
434D5144525648575C4C5F6352676C597076617A8065818764828A63828B63838F648793
678C98688F9D6991A07C9FAC7E9FAA7F9DA77F99A37E969F7E939B7E91977D8D937D8A8F
7D878C7C84887C81847B7E80
767575726F6F6E6968696362655D5B6157555D524E5A4C4856464253413B503C354D372F
4B322A492E25492A204D2D2251332855382E563A31543A33523B35503A354E3B364C3935
4A39354A3B394A403E4B43424A44444844444643444443444242434042433F43463F474A
404B4F42505547565C4B5E6351666C566E755C767D617D8462808961808B61828E628693
658B98668E9C6690A07DA1AE81A2AE809FA9809CA57F98A17F959D7E92997E8F957D8B91
7D888C7C85887C82847B7E80
767575716E6E6D6867686260645B595F55525B4F4C57494554433E503E384D38324B332C
492F26482B2148291E492B214C2F264F342C523830513A334F3A354D3A354B3A354A3935
483835473A37483D3C4842414843434642434440424141423F40413D3F423C41443C4549
3E4A4F414F5446565C4B5E6550666D556D755A747C5E7B845F7D875E7E895F818D618692
648A97658D9C648F9F7EA2AF82A4AF82A1AC819EA8819AA380979F7F939A7F90967E8C92
7D898D7D86897C82857B7F80
767475716E6D6B676667605F625A575D5350594D4955464251403B4D3A354A352E483028
462B2245271D46271D462920492E264D352D5037304E39334D3A344B3934493834483834
463734453936443B3A453F3F454242434142413F413F40413D3F413A3D413A40443A4448
3D4A4F3F4F5445565D4A5E654F666D546D7558737C5B79825B7A855C7D885E818D608592
638A97658D9C658F9E7B9FAC84A6B284A4AF83A0AA829CA68198A180959C7F91977E8D93
7E8A8E7D868A7C82857B7F81
757474706D6D6A6665655F5D6058555B514E564A4652433F4E3D384A373147312A442B24
43271E42231942241B43271E4830294C352E4D37314B39334A3934483834473733453633
443634433835423938423D3D434142413F413F3E403C3E403A3C3F373C3F363E42384247
3A494E3E4E5543565D485E654E666E536C7556727B56757F5778835A7B875C7F8C5F8491
638A97678F9D6C93A17A9EAC83A7B387A8B385A3AD839EA8819AA380969E8092997F8E94
7E8A8F7D878A7C83867C7F81
7574746F6C6C696464635D5C5E5654584E4C5347444E403C4A393446332D432D2640271F
3E21183D1E153E211941292147332C4A362F4A3831493832483833463632443531433532
413533403634403837413C3D413F403F3E403C3C3F3A3C3F373A3E343A3D333C41354147
38474D3C4E5440555D475D664D666F506B75526F7953727D5475815779855B7E8A5E8390
638997698F9D6F94A2799FAD85ABB88BADB985A5B083A0AA829BA481979F80939A7F8F95
7E8B907D878B7D83867C7F81
7473736E6B6B686362615B5A5B5351554C495044414B3D39463531422E293E28213B221A
391C14381C143B221B412E2647352E4A3730483732473732453632433531423430403330
3F33313E35333E37373E3B3B3E3D3F3C3D3F3A3B3F383B3F35393D32393D313B41324147
36474D3B4E5540555E465E674B656E4D69734F6C774F6F7A51737F557784597C895D8290
628896688F9E6E94A2789EAD81A9B884A8B584A5B083A0AB829CA68198A080949B809096
7F8C917E888C7D84867C7F81
7473736D6A6A6662615F595859514F5249464C413E47393541312D3C2A2438231C351C14
331810331B1438241D41302948373048373147373245363143343041332F3E322F3D312F
3C31303B34333C36363C3A3B3C3C3E3B3C3E383B3E363A3E33383C2F383D2E3B40314047
34474E394E563F565E445D6647626C4966714A69744C6C784E707D527582567B885B818F
608895678E9D6D93A2759DAC7DA6B581A7B483A5B183A1AC829DA78299A281959C809197
7F8D927E888C7D84877C8081
7372736C69696460605D5756564F4D4F4644483D3B4235323C2D29372520321D172D150E
2A140D2C191336251E43322C48383147383246373244353041332F3E312E3B302E3A302F
3930303933333A36373B3A3B3B3C3E3A3C3F373B3F34393D30373C2D373C2C3A402E3F46
32464E374D563C545D405A64435F6945636E466772496A774B6F7C507481547A88597F8E
5F8695658C9B6B919F739CAA7BA2B181A9B782A6B383A3AE839FA9829AA382969E819298
808D937F898D7D84877C8082
7372726B6868625F5E5B5555534C4B4B4341443A373D312E37282531201C2B1813250F09
21100B291A1537272246362F4939334839334637324335313F322F3B302E382F2E372E2E
362F2F3732323836363A393B3A3C3E393C40373B3F33393E2F373C2B363C2A39402C3F46
2F454D344C5538525C3B57623E5C6740606C436470466875496D7B4D7280517886577D8D
5C8493628A99688F9E719AA97AA2B182ACBB83A8B583A4B083A0AA839CA582979F819399
808E937F8A8E7E85887C8082
727172696767615D5D5853534F4A4847403E3F3634372D2A3124202B1B1725130E200D08
1E100D291D18392B254C3B334C3C36493A344738344236323D312F382F2D342C2B322C2C
322D2E3531323836373A3A3B3B3D3F3A3E42373D41323A3F2D373D29363C28393F2A3E45
2C444D314A5433505A36545F3959653D5E6A3F626F446875476C7A4B71804F7786547C8C
5A82925F8898648D9D6F97A77BA4B383AEBD84AAB884A6B284A2AC849DA68399A082949A
818F94808A8E7E85887C8082
7171716866675F5C5C5551514C4746433C3B3A32303128262A1E1B2416121F0E0A1A0B08
170D0B251C193C2E29513F37503F384C3D37483B364337333D3331382F2F332D2D2F2C2E
302E303533333A39393B3B3D3C3F413D4346384044333C412D383D28363C26383F273D45
29414C2D4853304E5932525E365663395B693C606E426774466B7A49707F4D7585517B8B
5781915C8797628C9C7099A97EA7B685B1C186ADBA86A8B486A4AE859FA8859AA283959C
829095808B8F7F86897D8182
7170716765665D5A5A534F4F4844443E3938342D2C2A22212118161B0F0D180A07170B09
16100E2A211D41332D57443C53423B4F3F3A4A3D394539364036343A3232383232333031
3532343C3939403F4043424344474942494C3A4348333E432C383E27363D24373F243B44
243D492A47532A4A562B4D5B2F5260355A673A606D416674446B79486F7F4B7484507A8B
557F905984955F8B9C709AAA7FAAB988B4C388AFBC88AAB688A5B087A1AA869CA385969D
839197818C907F86897D8183
7070706665655B5959504E4E4542413A35352E2928221C1B160F0E0C0302130805150D0B
1813122A23204436305B484057453E52423D4C3F3B473C394239383D36363B3636383535
3E3A3A44403F474545494849474A4C41494D3A454A333E442C383E26353D23373F233B45
243F4B2948552548562449592E5260355A68385E6D406574446A7948707F4A74854E798B
527E8F5482945C8A9C709BAB82ACBB8AB5C48AB0BE8AACB88AA7B289A3AB889DA586989E
849298828D9180878A7D8183
7070706464655958584E4C4C423F403532322825251A1616080404050000110A0814100F
1916162E2724493A33604C435A49425545404E403D493E3C453D3C403A3A3D39393C393A
3E3C3D424041464647484A4B454A4D40494D3A454A323E452B383F25373F233840233C46
25414C284854284957274B5A355664385C6A3C616F466977496E7C4A73834975864B788A
4E7C8E4E7F925C8B9D729CAC86ACBB8CB7C58DB3C08DAEBA8DAAB48CA5AD8A9FA7889AA0
869499838E9281888B7E8183
6F70706464645857584C4B4B3F3E3E323030242222141212020001080606100D0C1A1715
221E1D392E2A4F3F38644F465E4C455849445245424C4340463F3E423D3D3E3B3B3C3A3C
3D3D3E40414343454744484A444B4E3F494D39444A313E442A3940253840223741223B46
24414D274754284A582C505E3959663C5F6C416472496C7A496F7E47728347748648778A
497A8D4A7D915E8C9F769EAE89AEBC90BAC891B6C291B1BD90ADB68FA7B08DA1A98B9BA2
88959A858F9382888B7E8284
6F6F706363645656574A494A3D3C3D2F2E2F212021111011000001070707100F0F1C1A18
2B25223F342F54433D6551496150495B4D48554A475047454B4544474343434243454344
454545474849474A4B474C4E454D503E484D374349303D442A3A42253842223843203A46
213F4C254653284A582D505E335765385D6B3E6472436979436C7D436F82437285447488
43778B477C91608EA07CA2B189AEBC93BCCA95B9C596B5C095B0B993AAB290A4AB8D9DA3
8A979C86909483898C7F8284
6E6F7062626356555649494A3B3B3C2E2E2F1F1F20101011000102070809131212201D1C
2F282643373257464066524A64534C5E504C584D4B534B494E49484B48484949494A4A4A
484A4B484B4D474B4E464C4F414A4D3B454B3440462F3C44293B43253A43233A45213D48
21404D2345532548572B4F5E305565345B6A3860703C65763D697B3F6C7F407084407287
3D7389487D936390A37DA2B186ACBB91B9C79BBDC99CB9C49AB4BD98ADB594A7AD90A0A5
8C999D889195848A8D7F8384
6E6F7062626355555648494A3A3B3C2D2D2F1E1F210F1112000204080A0B141414231F1E
322B28473A3558484167534B66554F61534F5B504E554E4D514C4C4D4B4B4A4A4B48494B
46494A45494B43484A40464A3C4449384247323E442D3B43293A43263A45243C47233E4A
22414F264754284B592B505F2C5463305869335D6F3762743A66793D6C803E6F833B7085
3A72894B80956492A479A0B088ADBC96BCC9A8C7D2A4BFC9A1B8C19DB1B898AAB094A2A7
8F9A9F8A9396858B8D808385
6E6F706162635455564748493A3B3C2C2E2F1E20210F12130103050A0C0D14151524201F
342D2A473B3757484265524B6656506256515D535057504F524E4E4E4C4D4A4A4C47494B
4547494246493F44473C4246384045343E442F3C432B3942283A43253A45243C48223E4B
22414E244553264A582B505F2F5665335B6B355F703964763A687B3B6B80396D82376F85
3A738A4F83976594A67AA3B28EB2C09FC1CDB0CDD6ACC5CEA7BDC5A2B5BC9DADB397A5AA
929CA08C9497868C8E808385
6E6F7061626354555747484A3A3B3D2C2E301E20221012140104060A0D0E151616242120
342D2B453A3754464161514A6656516457535E55525852515350504E4D4E4A4A4C46484A
4246483F43463C4144383F43343D42303B412C3940283740263943243A45233B47213D4A
21404E224452254958284E5E2D546430596A345F7136637636667A36697D356B80346E84
3C758C52869A6997A97EA6B694B6C3A8C5CFB7CFD9B5CBD3AFC2C9A8B9BFA2B0B59BA7AC
949EA28E9598878D8F818485
6E6F7061626354565747494A3A3C3D2C2F301E21231013160205080B0F11161719242221
322D2B4239365045405E4F4A6556506559556056545953535351514E4E4F494A4C44474A
4044473C4144383E42353C41313A3F2D383F29363E263640243742223944213A47203D4A
1F404E204352224858254D5E2852632B56682D5B6E2F5F7330637830667B30697F326D84
40798F578A9E6E9BAC84AAB99ABAC6B0C9D3BFD4DCC0D3DAB7C8CEAEBDC3A6B3B89EA9AE
97A0A3909799898D90828486
6E6F7061636455565748494B3A3D3E2D30321F222411151703070A0D101317191A242223
312D2C4038364E44405C4E4A635550675A566058555954545351514D4D4F47494C424649
3E4346393F43353C41313A3F2D373D29353D26343D24353F2236412038441F3A471E3C4A
1E3F4E1E4352204758234C5D25506227546728596C2A5C712C61762D647A2D687F357087
487F945E8FA275A0B08CB0BDA4C0CCBAD0D8C9DBE2CADBE1BECDD3B4C1C6AAB6BAA2ACAF
99A1A592989A8A8E90828586
6E6F70626364555758484A4C3B3E402E313320242612161904090C0D1215181B1C232324
2F2C2C3C37354C4340594D4862544F6659556058565855545250514B4C4E45494B404548
3B4145363D41323A3F2E373D2A353B26333B23323C21333E1F35401E37441D39471D3B4A
1C3F4E1D42531E4657204A5C214F6123536625566B265B70285F7529637A2E69803B748B
4F84996695A77FA6B597B7C3AFC8D2C5D7DED7E6EBD2E0E4C4D1D5B8C4C8AEB8BCA4ADB1
9CA3A693999B8B8F91838586
6E6F70626465565859494B4D3C3F412F323521252813181B050B0E0F1316191C1D232324
2D2B2C3A373649413F544B475E524F6156545E5856575454505051494C4E43474B3D4347
383F43333B402E373C2A353B26323923313920303A1E323D1D34401C36441B39471B3B4B
1B3F4F1B42531C45571E4A5C1F4E6121526622566B235A70255E7529647B326D84437B90
588B9E719CAD89ADBBA1BFCAB9CFD8CFDEE5DFECF0D3DFE3C7D2D6BBC6C9B1BABDA7AEB1
9DA4A694999B8C8F91838586
6F707163646556585A4A4D4E3D414330343723272A151A1E060D10111518191D1F232426
2C2C2D383635443F3E4F484659504D5B53515A55545553534E4E50474A4D4045493A4145
353C412F383E2B343B263239223038202F391D2F3A1B313C1B33401A36431A39481A3C4B
193F4F1A42531B45581C4A5C1D4D611E51661F556B215A70255F752B667E3772884C8196
6392A57CA4B493B4C2ABC5D0C5D7DFDBE6EBE5EFF3D6E0E4C9D3D6BEC6CAB3BABDA8AFB2
9FA4A7959A9C8C8F91838586
6F7071636566575A5B4B4E503F4245323639252A2D181D2109101312171A1A1F21232627
2B2C2D353434403D3D4A4544514C4A544E4D5752525252524B4D4F44484B3D4347373E43
313A402B363C27333A2230381F2E371C2D381A2D3919303D193341193644193948183B4C
183F501942541A46581A4A5D1C4D621D52661D566B215A71266178316B8242798E588A9D
709BAC88ACBAA0BDC8B9CED7D3E1E6E9F2F6E7F0F3D8E1E4CBD3D6BFC7C9B4BBBDAAAFB2
A0A4A7969A9C8D9091848586
6F7172646667595B5D4D505241454735393C282D301B21240D141812191C1B2023232628
292C2D3233353C3B3C4442434A47474E4B4B524F4F4E4F50474B4D404549394146333C42
2C383F27343C22313A1E2F381A2C37182C37172D3A16303D173342173645183949173C4C
17405118435519475A1A4B5E1B4E631C53681E576D235C732B667D3A73884D82966593A5
7DA4B394B4C1ACC5CFC6D7DEDEE8EDEFF7F9E4ECEED8DFE2CCD3D5C0C6C9B5BBBDAAAFB1
A0A4A6969A9B8D8F91848586
7071726567685A5C5E4F525444474A383C3F2C31341F252911181C141B1F1B212422272A
282C2F2F3235383A3B4041424645464948494B4B4C494C4E43484C3C4247353E442E3941
28363E22323B1E2F391A2D38162A36142A37142D3A14303E163443163747173A4A173D4E
17415218445718485B1A4C601B50651D546A215A70286178346D83477C905C8B9E739CAC
8AADBAA0BDC8BACED7D4E1E6E8F0F2F4F9FBE5EBEDD8DEE0CCD1D4C0C5C7B5BABCAAAFB0
A0A4A697999B8D8F91848586
7072736668695C5E60515456464A4C3B4042303538242A2E181F23161D211B222621272B
292E302E323536393B3E404242444545464845484A44494C3E4449384046313D44293740
23343D1E303B1A2E39162C38122A370F2937112D3B133140153545163949173B4C173F50
1842541946591A4A5E1B4E631E536821586D285F7531697F42778B5686996B95A682A6B5
99B7C2B0C7D1CAD9DFE1EAEDF4F9FBF5F9FBE5EAEBD7DCDECBD0D2BFC4C6B4B9BAAAAEAF
A0A3A596999A8D8F90848586
71727367696A5D6061535658494D4F3F4346343A3D2A30331F262A171F231B232722292C
282E312D333634383C3C3F423F434542464941464941464A3C43493740462E3C43243640
1E323D1A2F3A172E3A132C390F2A380E2B3A112F3E143443153747173B4B183E4F184253
1845571B495C1D4E621F526723576C295E7332687D3F74885181946590A17BA0AF92B1BD
A9C1CBC1D2D9D9E3E7EDF2F4FCFEFFF0F3F5E2E6E8D6DADBCACDCFBEC2C3B3B7B8A9ACAE
9FA2A39698998D8E90848586
727374686A6B5F616356595B4C505243474A393E412F3539252C301B23271C2429232B2E
2830332E343733393C3B40423F44474045493F45493D45493B43493540472C3C44243742
1F343F1C323E18313E142F3D112E3D12303F143443173847183B4C1A40501B43541B4557
1D495C204E6123546727586C2D5F7334677B4173864F7F91638D9D779CAB8CABB8A3BCC6
BBCDD4D2DDE2E6ECEFF8F9FBFDFEFFEDEFF0DFE2E3D3D6D7C7CBCCBCC0C1B2B5B6A8ABAC
9FA1A29597988C8E8F848485
7273746A6B6D616365585B5D4F5355474B4E3E4346353B3E2C3236222A2F1E262A242C30
2931342F3639343B3E3C41443E44473E44483C44483A4348384248333F472C3C45263944
2237432037431C36421A36441835441837451A39481B3D4D1E4151204555214859224C5D
2550622854672D5B6E3261743A697B437284527E8E618A9A7598A789A7B49EB7C1B5C8CF
CDD9DEE1E7EAF1F4F6FFFFFFF7F9F9E8EAEBDBDEDFD0D2D3C4C7C8BABDBEB0B2B4A7A9AA
9D9FA09496978C8D8E838485
7374756B6C6E6365675B5E605356584B4F5142474A3A404332383C2A3135222B2F242D31
2B333731383C353C403A41453B43473C44493A43483A44493843493241492D3F48293E48
273C48273D49223B48223D4A203C4A213E4C22414F2445542849582B4E5D2D51612E5565
32596A365F703D6676426C7D4B7584567E8D658A987596A488A4B09BB3BDB0C3CAC7D3D9
DEE4E7EDF0F1FDFEFEFCFCFCEFF0F0E2E4E4D7D8D9CBCDCEC1C3C4B7B9BAAEB0B1A5A6A8
9C9E9F9395968B8C8D838485
7374766C6E6F6567695D606256595C4F5355474C4F404548393F4231383C293135262E32
2D3539323A3E363E423942463C44483E464B3A444A3A454B38444B32424B31424C2E424C
2C414D2C424D29414D2A434F2944512A46532C4A57304E5B345260375664395A683C5E6D
416472476A784D707F5377855C7F8D698A977895A188A2AD9AB0B8AEBFC5C3CFD3D8DEE1
EAEDEEFAFBFBFDFCFCF1F1F1E6E7E7DBDDDDD1D2D3C7C8C9BDBFC0B4B6B6ABADAEA2A4A5
9A9C9C9293948A8B8C828384
7475766D6F7067696A606365595D5F5357594C5153464B4E3F4548383F4232393D2B3437
2F393C343D413840443C44483E474B3E474C3C464C3B464D3A474E36464F364751344751
334752334852324854324A55334C58364F5B39535F3C5662415B68445F6C4964714C6975
526F7B5875815D7B8763818D6D8A957B959F89A0AA9AADB5ACBBC1BFC9CED2D8DAE4E6E8
F7F6F7FBFBFAF1F1F1E8E8E8DEDFDFD4D5D6CBCCCCC1C3C3B9BABBB0B2B2A8A9AAA0A1A2
98999A919293898A8B828384
7576776F7071696B6C6365675D6062575A5D5155584B5053454B4E4046493A4145363D41
353D413740443B43473E474B40494E424B50404A503F4A513F4C533C4B533D4D553B4D56
3C4E573B4F593C505B3D525D3F555F425863465C66495F6A4F656F536973596F795C737E
637983687F886D848E748B947F959D8DA0A79CACB2ACB8BDBDC5C9CED2D5DFE0E1F0EEEE
F9F8F8F0F0F0E7E7E7DEDFDFD6D6D6CDCECEC4C5C6BCBDBEB4B5B6ACADAEA4A6A69D9E9F
9697988F909188898A818283
7576777071736B6C6E6568696063655B5E6056595C5155584C5153474D5043494C3F4649
3C44473C44483F474B414A4E454D51464F54464F5545505545515843515944535B45545D
45555E4657604859624A5B654B5D674F616A53656E5768715C6D7661737B6779816C7E87
73848B76878F7B8D9484959C909FA49DA9AEABB5B9BBC1C4CACDCFD9D9DAE8E6E6F3F2F1
F0F0F0E6E6E6DDDEDED5D6D6CDCECEC5C6C6BEBEBFB6B7B8AFB0B0A8A9A9A1A2A39A9B9C
9495958D8E8F878889818282
7677787173746D6E70686A6C6366685F62645A5E60565A5C5256594E53564A5053474D51
454B4F434A4E434A4E464D514850554A53584C555A4C565B4D575D4C585F4D5A614F5C63
4F5D6552606753616954636B57666E5B6A715F6D7564727968767D6E7B827581887A868C
7F8A8F828E93889499939EA29CA6A9A8AFB3B7BBBEC6C8C9D3D3D3E0DEDEEDEBEAECECEB
E3E3E3DBDBDBD3D3D4CCCCCCC4C5C5BDBEBFB7B7B8B0B1B1A9AAABA3A4A59D9E9F979899
9192938B8C8D868787808182
7777787374756E70716A6C6E66696A6265675F62645B5F61575B5E54595B5156594F5457
4D53564B51554950544951544D555950585D535B60545C61545E63545F655661675A656B
5C676D5D686F5E6A71606C73636E756772786B757B707A7F747D827982877F878C838B8F
888F928891958F989B99A1A3A3A9ACB0B4B6BFC0C1CDCCCCDAD7D7E3E1E1E5E5E4DDDDDD
D6D6D6CFD0D0C9C9C9C2C2C3BCBCBDB6B6B7B0B0B1AAAAABA4A5A59E9FA0999A9B949595
8F8F908A8A8B858586808081
7778797475767072736D6F70696C6D66696A6366686063655D61635A5E61585C5F565B5D
54595C53585B51575B51575B52595D555C615960655C63685D656A5D666B60686E636B71
656D736870756972786B73796E767B72797F767D817B81857E848784888B868B8E8E9193
8F93969297999B9FA0A3A6A8AEB0B1BABABAC5C4C4D2CFCEDCD9D9DBDBDBD6D6D6D0D0D0
CACACAC4C4C4BEBEBEB8B9B9B3B3B4ADAEAEA8A9A9A3A4A59E9FA09A9A9B959696909192
8C8D8D8888898384857F8080
78797A7576777273756F71726C6E706A6C6D676A6B6567696265676064665E62645D6163
5B60625A5F62595E61595F625960635E646860666A62686D636A6F666D726A70756E7478
71777B71777C72797D767B807A7E827B7F837E828582858785888B898B8C8B8E8F939494
949597999B9BA0A1A2A8A9AAB3B2B2BDBBBBC3C2C2D1CFCFD1D0D1CBCBCBC7C7C7C2C2C2
BDBDBDB8B8B8B3B3B4AEAFAFAAAAABA5A6A6A1A1A29D9D9E99999A9595969191928D8E8E
898A8B8686878282837E7F80
78797A7677787475767273746F71726D6F716B6D6F696C6D676A6C66696A646769636668
62666861656761656861656862666A63686C666B6E686D716C71756F757973777B75797D
777B7E787C7F7B7F827D80837E80827E808382848685868787898A8A8B8B8F9090939394
9897979D9C9CA3A3A3ABABABB2B1B1BAB9B9C0C1C1C6C5C5C0BFC0BBBBBCB7B8B8B3B4B4
AFB0B0ACACACA8A8A9A4A4A5A0A1A19D9D9E999A9B9697979393949090918C8D8E898A8B
8687888384858181827E7E7F
797A7B7778797677787475767274757172746F71726E70716C6E706B6D6F6A6D6E696C6E
686B6D686B6D686B6D686B6E696C6F6A6E706C70726E727575797B787B7F797B7E7C7E80
7E80837E80837F80837F80837F81838283858586878687888B8B8B8D8D8D919090949393
9897979C9C9DA0A1A2AAAAAAAEAFAFB3B3B3B4B5B4B1B1B1AEAEAFABABACA8A8A9A5A6A6
A2A3A39FA0A09D9D9D9A9A9B9798989495969292938F90918D8D8E8A8B8C888989868687
8484858182837F80807D7D7E
7A7B7B787A7A7778797677787576777475767374767274757173747072737072736F7173
6F71726E71726E71726E71736F727370737571747673767876797B787B7D7B7D7E818283
8183848081838182848082848082848284858385858586878889898A8A8A8D8D8D8F8F8F
9293939B9B9B9E9E9EA2A2A2A1A2A2A0A1A1A0A0A19F9F9F9D9D9E9B9B9C99999A979798
9596969394949192928F90918E8E8F8C8C8D8A8B8B88898A878788858687848485828383
8181827F80807E7E7F7C7D7D
7A7B7C7A7A7B797A7B79797A78797A777879777879767778767778767778757678757677
75767775767775767775767775767875777876787977797A787A7B7A7B7C7B7C7E7D7E7F
7E7F807E7E807E7F807E7F807F80818383838484848585868787878888888989898B8B8B
8D8D8E9090918D8E8E8E8E8F8E8E8F8D8E8E8D8E8E8D8D8E8C8C8D8B8B8C8A8A8B89898A
8888898787888687878586868485858384858283848282838181828081817F80817E7F80
7E7E7F7D7D7E7C7D7E7B7C7D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?ooo`AkNg`4NW]k27YjN`AjNWX3NWUj17UiNPQiNGT4NGQi1gUh
N0AhMgP8N7Mg37QfMPMhMGD4N7Ed17QdM0AhLg<4Mg9`17QdM0=hMGD4N7Ef17QeM@AgMWH8MgEf0gIe
M@AfM7D4MWEe17EdM@QfMGH4MWMh0gIgN@AgNGX4N7Yk17QjO0AiNgd4NGan0gYnO`AkOh84O86317f3
QPAoQXX4OH:517b0PP=lOh44Ngj027]nO`AkOGl7Ngen17]lOPakO7d4Ngal17]kO1Goool001Coool4
Ng]l17YkN`QjNW/4NWYj0gYiNPAiNGX8NGUi17UhN@MiN7P4N7Mh27QgM`ahMWH7N7Ee17QeM0AhM7@4
N7=c17MbL0AhM7@3N7Ee17QeMPAhMGD4MgIf27MeMP=fMGD4MWAe17IeM@AeM7D8MWEf17IgN0=fMgT4
MgUj17QjN`AhNW`4NG]m17UlOP=jOWl4Ngn217b1P`AmPhH4OhJ:17f2Q@AlP883O7n117]nP0QkOWl4
Ngeo1g]mOPAkO7h<Ngam17]lO0AkNg`Eoooo000Doooo17]kO0AjNg/8NWYk17YjNP=jNGX4NGUj27Ui
N@AiN7T7NGQh17QgN0QhMgL<N7If1gQeM@AhMG@4N7Ad17QcL`AgLW04N7Ad0gQeM@AhMGH4N7Ee17Mf
MPQgMGH3MWEe17IdM@AfMGD4MGAe27IeMPAfMgP3MWMi17MiNPAhNW/4N7Yl17UkO@AiO7h3NWio17]o
PPAlPH<4OH>617n6RPAmPXD4O8220gaoP@AkOX08Ngio17]mO`MkOGh4Ngan37]lO@AkO7`4Ng]l5Ooo
o`005?ooo`AjNg/4NWYj17YiNPAiNGT4NGQi0gUhN0AhMgL4N7Ig17MfMPQgMGD3MWAd17IcL`AfLg84
MG9b17EaL@AeLG04MG1`0gE`K`AdKfh4M6i]17A]K0AdK6X4M6]X17E]K0=eKVh4MFm_17A_K`AdL704
Lg1`17=_K`=bKVl4LVi^179^K`AaKVl4LFma179`LPAbLW@3LgAf17AfN0AeN7X4MWYl17MkOPAhOH03
NH2317^3Q`AmQh/4Oh^@186=TPAoR8`4OHF80gf3QPAlPH@4O82317^0PPAkOh47Ngj017]mO`QkOGh8
Ngam17]lO1Goool001Coool4NW]k17YjNPAjNGX4NGUi17UhN@=iN7P4N7Mg17QfM`AgMWH8MgEe0gId
M0AfLg<4MW=b17EbLPAeLG44MG5`17E`L0=eL6l4M6m^17A^K@AdKF`4M6aZ17A[J0AeKF`3MFi^17E_
K`AdKfl4M71`17=`L0AcKfl3LVi_179^KPAbKVl4LFi_175_L@AbL784LW9d0g=dMPAdMWP4MGQj17Ij
O0AgNgh4N7f00gV0P`AkPhL4OHN;17n;T0B1SI84OhR<17f5R0=mPhH4O86417b0P`AkP884Ngn11g]n
P0AkOGl8Ngen27]lO@AkO7`Eoooo000Doooo17YkN`AjNWX4NWUj17UiN@AiN7T3NGQh17QgM`AhMWL4
MgIf27MeM@=fM7@4MW=c17IcLPAeLW84MG5a17EaL0AeL703MG1_17A_KPAdKVd4M6e/17A/JPAdJfP4
MFe/0gE^KPAeKfl4M6m_17A`L0AcL704Lfm_0g9^K`AbKVh4LVi_175^K`AaKg44LW1b179bM0=cM7H4
M7Ih17EhNPAfNW`4Mg]n17QmP0=iP8<4Nh>717f7R`AoRi04PHfB17n8S0AmQHP3OH>617b1Q0AlP8<4
Nh2217]oP@MkOX04Ngeo27]mOPQkO7d4Ngal5Oooo`005?ooo`AjNg/4NWYj17YiNPAiNGT4NGQi0gUh
N0AhMgL4N7Ig17MfMPQgMGD3MWAd17IcL`AfLg84MG9b17EaL@AeLG04MG1`0gE`K`AdKfh4M6i]17A]
K0AdK6X4M6]X17E]K0=eKVh4MFm_17A_K`AdL704Lg1`17=_K`=bKVl4LVi^179^K`AaKVl4LFma179`
LPAbLW@3LgAf17AfN0AeN7X4MWYl17MkOPAhOH03NH2317^3Q`AmQh/4Oh^@186=TPAoR8`4OHF80gf3
QPAlPH@4O82317^0PPAkOh47Ngj017]mO`QkOGh8Ngam17]lO1Goool001Coool4NWYk17YiNPAiN7T4
N7Qh17QgM`=gMWH4MgEe17IdM0AfLg<4MG9b17EbL@=dLG04M71_17=_KPAcKVd4LVe/179/J`AbJfT3
LFYX175YI`AaJ6H4LFMT175VHPAaI604LVMT0g9XI`AbJVT8LFYZ171ZJPA_JFT3KVUZ16mYJPA^JFX4
KVY[16i/K@A_KFl4L71b0g1aM0AaM7H4LWIi17AiO0AeO7l4Mgn20gV3Q`AkQh/4OX^A18:AV0B2T9H4
P8^@17j8S0=mQXT4O8B717b3QPAlPH@4Nh6317^0PP=kOh44Ngn017]nP0AkOGl4Ngen27]lOAGoool0
01Coool4NWYk17YiNPAiN7T4N7Qh17QgM`=gMWH4MgEe17IdM0AfLg<4MG9b17EbL@=dLG04M71_17=_
KPAcKVd4LVe/179/J`AbJfT3LFYX175YI`AaJ6H4LFMT175VHPAaI604LVMT0g9XI`AbJVT8LFYZ171Z
JPA_JFT3KVUZ16mYJPA^JFX4KVY[16i/K@A_KFl4L71b0g1aM0AaM7H4LWIi17AiO0AeO7l4Mgn20gV3
Q`AkQh/4OX^A18:AV0B2T9H4P8^@17j8S0=mQXT4O8B717b3QPAlPH@4Nh6317^0PP=kOh44Ngn017]n
P0AkOGl4Ngen27]lOAGoool001Coool4NWYk17YiNPAiN7T4N7Qh17QgM`=gMWH4MgEe17IdM0AfLg<4
MG9b17EbL@=dLG04M71_17=_KPAcKVd4LVe/179/J`AbJfT3LFYX175YI`AaJ6H4LFMT175VHPAaI604
LVMT0g9XI`AbJVT8LFYZ171ZJPA_JFT3KVUZ16mYJPA^JFX4KVY[16i/K@A_KFl4L71b0g1aM0AaM7H4
LWIi17AiO0AeO7l4Mgn20gV3Q`AkQh/4OX^A18:AV0B2T9H4P8^@17j8S0=mQXT4O8B717b3QPAlPH@4
Nh6317^0PP=kOh44Ngn017]nP0AkOGl4Ngen27]lOAGoool001Coool4NWYk17YiNPAiN7T4N7Qh17Qg
M`=gMWH4MgEe17IdM0AfLg<4MG9b17EbL@=dLG04M71_17=_KPAcKVd4LVe/179/J`AbJfT3LFYX175Y
I`AaJ6H4LFMT175VHPAaI604LVMT0g9XI`AbJVT8LFYZ171ZJPA_JFT3KVUZ16mYJPA^JFX4KVY[16i/
K@A_KFl4L71b0g1aM0AaM7H4LWIi17AiO0AeO7l4Mgn20gV3Q`AkQh/4OX^A18:AV0B2T9H4P8^@17j8
S0=mQXT4O8B717b3QPAlPH@4Nh6317^0PP=kOh44Ngn017]nP0AkOGl4Ngen27]lOAGoool001Coool4
NWYk17UiN@AhMgP4N7Mg17MfMP=fM7@4MW=c17EbL@AdLG04Lfm_17=_KP=bKF`4LFaZ175ZJ@A`JFP4
L6QV16mWI@A_IV<3KVAR16iSH0A^HUl4KV5M16iOF`A^GUT4Kf5N0fmSH@A_I6<8KVET16eUI@M/IFH4
KFEV16aVI`A[IfP4K6UZ16eZK@A]K6l3KVia16ibM@A`MGP4LWUl17AlP0AfP8D3NHF:17^9S`AoSiD4
PYFL186AV0AoSY<4OX^@0gf8S@AmQXX4O8F817b3Q`AkPXD4Nh640g^0P`AkP884Ngn117]nP0AkOGl4
Ngen17]lOAGoool001Coool4NWYk17UiN@AhMgP4N7Mg17MfMP=fM7@4MW=c17EbL@AdLG04Lfm_17=_
KP=bKF`4LFaZ175ZJ@A`JFP4L6QV16mWI@A_IV<3KVAR16iSH0A^HUl4KV5M16iOF`A^GUT4Kf5N0fmS
H@A_I6<8KVET16eUI@M/IFH4KFEV16aVI`A[IfP4K6UZ16eZK@A]K6l3KVia16ibM@A`MGP4LWUl17Al
P0AfP8D3NHF:17^9S`AoSiD4PYFL186AV0AoSY<4OX^@0gf8S@AmQXX4O8F817b3Q`AkPXD4Nh640g^0
P`AkP884Ngn117]nP0AkOGl4Ngen17]lOAGoool001Coool4NWYk17UiN@AhMgP4N7Mg17MfMP=fM7@4
MW=c17EbL@AdLG04Lfm_17=_KP=bKF`4LFaZ175ZJ@A`JFP4L6QV16mWI@A_IV<3KVAR16iSH0A^HUl4
KV5M16iOF`A^GUT4Kf5N0fmSH@A_I6<8KVET16eUI@M/IFH4KFEV16aVI`A[IfP4K6UZ16eZK@A]K6l3
KVia16ibM@A`MGP4LWUl17AlP0AfP8D3NHF:17^9S`AoSiD4PYFL186AV0AoSY<4OX^@0gf8S@AmQXX4
O8F817b3Q`AkPXD4Nh640g^0P`AkP884Ngn117]nP0AkOGl4Ngen17]lOAGoool001Coool4NWYk17Ui
N@AhMgP4N7Mg17MfMP=fM7@4MW=c17EbL@AdLG04Lfm_17=_KP=bKF`4LFaZ175ZJ@A`JFP4L6QV16mW
I@A_IV<3KVAR16iSH0A^HUl4KV5M16iOF`A^GUT4Kf5N0fmSH@A_I6<8KVET16eUI@M/IFH4KFEV16aV
I`A[IfP4K6UZ16eZK@A]K6l3KVia16ibM@A`MGP4LWUl17AlP0AfP8D3NHF:17^9S`AoSiD4PYFL186A
V0AoSY<4OX^@0gf8S@AmQXX4O8F817b3Q`AkPXD4Nh640g^0P`AkP884Ngn117]nP0AkOGl4Ngen17]l
OAGoool001Coool4NWYj17UhN@AhMgL4MgIf17IdM0=eLg84M75`17=_K`AbKVd4LFe[175[JP=`JFP4
KfQV16iVI0A]IF84KF=Q16aRG`A[H5d3JemK16]MF@AZG5L4JeYF16]IE0A/F5<4K5aH0faNF`A/Ged4
Jf1O16]QH0AZHF44JV9R0fURHPAYHF84JF9S16QSI0AYIFL4JVQZ16YZK0=[KG04K71c16idM`A`NGd4
LWb117F1QP=hQX`4NhbB17nBV@B2Uil4P9>J17n?UPAnS983OHZ?17b8S@AlQX/4O8F917^4Q`AkPhH3
Nh6417^0P`AkOh84Ngn017]nO`AkOGh4Ngam5Oooo`005?ooo`AjNWX4NGQi17QgM`AgMWH4MWAd0gEc
LPAdLG04Lfm_179^K@AaKF/4LF]Z0g1YJ0A_J6H4KVIT16eUHPA]Hf44K69O16]PG@=[Ge/4JeeI16YL
E`A[FUH4JeUD16aHD`A/G5P3K5iK16aOG@A[H5l4Jf5P16YQH@AZHV83JF9R16UQHPAYHV<4J6=T16UU
I`AZJ6X4JVY/0f]]L0A/L7<4KWAg171iO@AbO844MH660gR6S0AkS984Oi:I18:GW`B0TiX4OhnF17j<
TP=mRXl4O8R=17b6R`AlQHT4NhB717^3QP=kPH@4Nh2317]oPPAkOh04Ngio17]mOPAkO7dEoooo000D
oooo17YjNPAiN7T4N7Mg17MfMPAfM7@3MG=b17AaL0AcKfl4LVi]175]J`AaJfX3L6UX16mXIPA^IV@4
KFER16eSH@A/HUl4Jf1M0f]OF`A[GET4JUaG16]JEPA[FE@4K5QC16aLF0=/GU/4K5mM16]PG`A[HF04
JV5Q16YRHP=YHV84JF5R16URH`AXHf@4JFEW16YXJPAZJV`3Jfe`16a`L`A^M7L4L7Um179lP@AePHH3
N8J<17^<TPAoTYT4PYNO182CVPAoSiH4OXbB0gf:S`AlR8d4O8J;17b5R@AkQ8L4Nh>60g^1Q0AkP8<4
Ngn217]oP0AkOWl4Ngen17]lOAGoool001Coool4NWYj17UhN@AhMgL4MgIf17IdM0=eLg84M75`17=_
K`AbKVd4LFe[175[JP=`JFP4KfQV16iVI0A]IF84KF=Q16aRG`A[H5d3JemK16]MF@AZG5L4JeYF16]I
E0A/F5<4K5aH0faNF`A/Ged4Jf1O16]QH0AZHF44JV9R0fURHPAYHF84JF9S16QSI0AYIFL4JVQZ16YZ
K0=[KG04K71c16idM`A`NGd4LWb117F1QP=hQX`4NhbB17nBV@B2Uil4P9>J17n?UPAnS983OHZ?17b8
S@AlQX/4O8F917^4Q`AkPhH3Nh6417^0P`AkOh84Ngn017]nO`AkOGh4Ngam5Oooo`005?ooo`AjNGX4
N7Qh17MfMPAfM7@4MG=b0gAaL0AcKfh4LVe/175[JPA`JVP4KfQV0fiVI0A]I684K69P16]PG@AZGU/4
JEaI16QKE`=WFED4IeMB16MED0AWE4l4J5=>16UCC@AYEe83JEUF16UJF0AXG5X4J5aL26MMG@MVGEh4
IUiO16IPH@AVHV<4IVAV16MWJ@=XJVd4JFea16]cMPA]N7/4L7b117>1QP=gQhd4NXjE17nEW@B1V:04
OiBK17j@V0AmSY@3OH^A17b:S`AlR8d4O8J;17^5R@AkQ8L3Nh>617^1Q0AkP8<4Ngn117]nP0AkOGl4
Ngam5Oooo`005?ooo`AjNGX4N7Qh17MfMPAfM7@4MG=b0gAaL0AcKfh4LVe/175[JPA`JVP4KfQV0fiV
I0A]I684K69P16]PG@AZGU/4JEaI16QKE`=WFED4IeMB16MED0AWE4l4J5=>16UCC@AYEe83JEUF16UJ
F0AXG5X4J5aL26MMG@MVGEh4IUiO16IPH@AVHV<4IVAV16MWJ@=XJVd4JFea16]cMPA]N7/4L7b117>1
QP=gQhd4NXjE17nEW@B1V:04OiBK17j@V0AmSY@3OH^A17b:S`AlR8d4O8J;17^5R@AkQ8L3Nh>617^1
Q0AkP8<4Ngn117]nP0AkOGl4Ngam5Oooo`005?ooo`AjNGX4N7Qh17MfMPAfM7@4MG=b0gAaL0AcKfh4
LVe/175[JPA`JVP4KfQV0fiVI0A]I684K69P16]PG@AZGU/4JEaI16QKE`=WFED4IeMB16MED0AWE4l4
J5=>16UCC@AYEe83JEUF16UJF0AXG5X4J5aL26MMG@MVGEh4IUiO16IPH@AVHV<4IVAV16MWJ@=XJVd4
JFea16]cMPA]N7/4L7b117>1QP=gQhd4NXjE17nEW@B1V:04OiBK17j@V0AmSY@3OH^A17b:S`AlR8d4
O8J;17^5R@AkQ8L3Nh>617^1Q0AkP8<4Ngn117]nP0AkOGl4Ngam5Oooo`005?ooo`AiNGX4N7Mg17Me
M@AeLg<4M75a0g=_KPAaKF`4L6]Y16mYI`A^IfD4K6AR0f]RH0AZH5d4JEiK16QLF0AWFUH4IUMC16EE
D@=TDdh4He5;169>B@ASCDL4I4e616M@B@AWDdh3IeEB16IFE0AVEeH4IEQH16AHF0ATFET3HeUJ169I
FPARFU/4HU]M169MG`ASH6<4HfAV0fAWJ`AVJfl4J75d16]fNPA^O804LH660gJ8SPAjSiL4OYJP17nG
X0AnU9`4OI6I17f?UP=lSI<4O8^A17b9SPAkQh`4NhJ:17^5R@=kQ8L4Nh:517^1P`AkP884Ngn117]n
O`AkO7hEoooo000Doooo17UiNPAhMgL4MgEe17EcL`AdLG43Lfm^175]K0A`JfT4KfUW16iWI@A/I683
Jf9P16YPG@AYGU/4J5aH16MJEPAVEe<4IEEA0fACCPASDD/4HTi916==A`ATCDH4Ie1916MCCP=WEE84
IUID16IGEPAUF5P4I5QH16AIF@=SFEX4HUUJ169JF`ARFed4HUeO16=PH`ASI6H3I6M[16I[K`AXLG@4
JgIj16ilP0AaPHH3MXR>17Z?U`AnUZ04OiNP17jDW0AmTIT4OHnF0gb=T`AlRi44O8V>17^7S0AkQXX4
NhF90g^4Q`AkPXD4Nh6317^0PPAkOh44Ngio17]lOQGoool001Coool4NGUj17QgM`AgMGD4MG=c17Aa
L@=cKfh4LFe/171[J@A_JFL4KVMU16aTHP=[HV04JV1M16UNF`AXG5P4IeYF16IGD`AUEE43I5=>16=A
B`ARCTT4Hde716A=APAWD4T4Ie=>0fMEDPAVEU@4IUMF16EHF0ATF5P4I5UI0f=IFPARFEX4HUYK169K
G@ARGEl4Hf1S16=TIP=TIf/4IV]_16QaM0A[MWX4KWb01761QP=fR8h4NXnG17jFX0AoUj04OYBL17fA
V@AmSiH3O8fC17b;T@AlRHh4NhN<17^6RPAkQHT3NhB717^2Q@AkPH<4Nh2217]oP@AkOWl4Ngan5Ooo
o`005?ooo`AiNGX4N7Mg17MeM@AeLg<4M75a0g=_KPAaKF`4L6]Y16mYI`A^IfD4K6AR0f]RH0AZH5d4
JEiK16QLF0AWFUH4IUMC16EED@=TDdh4He5;169>B@ASCDL4I4e616M@B@AWDdh3IeEB16IFE0AVEeH4
IEQH16AHF0ATFET3HeUJ169IFPARFU/4HU]M169MG`ASH6<4HfAV0fAWJ`AVJfl4J75d16]fNPA^O804
LH660gJ8SPAjSiL4OYJP17nGX0AnU9`4OI6I17f?UP=lSI<4O8^A17b9SPAkQh`4NhJ:17^5R@=kQ8L4
Nh:517^1P`AkP884Ngn117]nO`AkO7hEoooo000Doooo17UiN@AhMWL4MWAd17EbL@AcKfl3LVe/171[
JPA_J6L4KFIT16aTH@AZHEl3JEmL16QLF@AVFUH4IEMC16AED0ARDTd4HE1:0f1=A`AOBT@4GDM115]4
?@ATBT84Idm916I@C0=UDDh4I59@16=CDPARE5<4HEAD161DE0=PE5D4GeAE15mEEPANEeP4GUUK15iL
G`AOH6<3HFEX169YK@AUKg84J7Ei16akP0A`PHL3M8R?17R?U`AmUj04OIJO17fDW0AlTYT4O92G0gb>
U0AkS984NhZ@17^9SPAkQh`4NhJ:0g^4R0AkPhH4Nh:517^1P`AkP884Ngj017]mOQGoool001Coool4
NGUi17QfM`AfM7@4MG9a17=_K`=bKF`4L6]Z16mXI`A]IV@4K6AQ16YQG`=YGe`4J5aI16IJEPAUEe<4
I5E@169BC@AQD4X3H4e715m:A0AMAd44Fd@m16A:@PAWCdT4IU1<0fEACPATDU04He=B169DD`AQE5@4
H5AD0f1DE@AOE5D4GeEF15iGF0ANFE/4GUaO15mPH`=QIFP4HVU]16E_LPAXMGT4K7^01721Q`=dR8l4
N8nG17fGX0AmUYl4OIBL17bBV@AlT9L3O8jD17^<TPAkRY04NhV>17^7S0AkQXX3NhB817^3QPAkPXD4
Nh6317^0PPAkOX04Ngen5Oooo`005?ooo`AiNGT4N7Ig17IdM0AeLW44Lfm_0g9]K0A`JfX4KfQW16eV
I0A/I644JV5O0fUOG0AXG5T4IUYF16EGD`ATEE04HU9=165@BP=PCDL4GdY415e7@@AKA3d4I4Y216M?
B@AVD4`3IE5>16ABD0ASDe84HUAC165DE0APE5@3H5AE15mDE@AOEEH4GUMH15iIF`ANG5l4Gf1S0f5U
J0ARJFd4IFmb16QeN@A/Nh04L8670gB8S`AhSiL4OINP17fFW`AmU9`4O9:I17b@U`=lSY@4NhbB17^:
T0AkRHh4NhN<17^6RP=kQ8P4Nh>617^2Q@AkPH<4Nh2217]nP0AkOGhEoooo000Doooo17UiN@AhMWL4
MWAd17EbL@AcKfl3LVe/171[JPA_J6L4KFIT16aTH@AZHEl3JEmL16QLF@AVFUH4IEMC16AED0ARDTd4
HE1:0f1=A`AOBT@4GDM115]4?@ATBT84Idm916I@C0=UDDh4I59@16=CDPARE5<4HEAD161DE0=PE5D4
GeAE15mEEPANEeP4GUUK15iLG`AOH6<3HFEX169YK@AUKg84J7Ei16akP0A`PHL3M8R?17R?U`AmUj04
OIJO17fDW0AlTYT4O92G0gb>U0AkS984NhZ@17^9SPAkQh`4NhJ:0g^4R0AkPhH4Nh:517^1P`AkP884
Ngj017]mOQGoool001Coool4NGUi17MfMPAfLg<4M75`179^K@=`JfX4KfUW16eVI0A[Hf44JV5N16QN
F`=WFeP4IEQE16AFDPARDdh4HE1;15m=B0ANBT@3G4M115]4?@AI@3T4F3lg16U=A@AWCTL4I4i90f=>
B`AQCd`4H4m>15m@C`AND504GE1@0ea?D@AKCe44FdmB15YBD`AJE5L4FeQK15aNH0=MHVH4GfM[169]
L@AVM7P4JGUo16j0Q`=bQhl4MXjF17^FX0AkUIh4Ni>L17^BVPAkT9P3NhjF17^=U0AkRi44NhZ?17^8
S@AkQh/3NhF917^4Q`AkPXH4Nh6417^0PPAkOX04Ngen5Oooo`005?ooo`AiNGT4MgIf17IcL`AdLG04
LVi]0g1[JPA_JFL4KFIT16]SH@AZHEh4J5iK0fMKF0AUF5D4I5IB169CCPAQD4/4Gde815i:A0=LAd44
Fd@m15U0>@AH?cL4JDe516M>A`ATCTT3Hdi;165?C0APCdh4Ge1?15i@D0AMD503G4mA15]?D@AKCe84
FU9C15YDE`AKF5/4G5iP0eeRIPAOIf/4HVea16IdN0AYNGl4KX270g:7S`AfSYH4NiJP17^EWPAkTi`4
Ni:J17^@V0=kSYH4NhfD17^;T@AkRXl4NhR=17^7R`=kQHT4NhB717^2QPAkPH@4Nh2217]nP0AkOGhE
oooo000Doooo17UiN@AgMWH4MW=c17AaL0AbKVd3L6]Z16mYI`A]IV@4Jf=Q16YQGPAXGU/3Ie]H16EH
E@ATEU84HU=>165@B`AOCDP4GTY40ea7@@AKA3d4FD0i15Po=`AYCDD4Idi716A>B@=SCT/4HDm<161?
CPAOD4l4GU1@15e@D0=LCe44FdmA15]?DPAJDU<4FUAG15]HF`ALGV03GF9V15mWJ`ARKG44IWAh16Ui
O`A^P8L3LXN?17J>UPAkUZ04NiFN17^CW0AkTYX4Ni2H0g^>UPAkSI@4Nh^A17^:S`AkR8d4NhN;0g^5
R@AkQ8L4Nh:617^1Q0AkP884Ngj017]mOQGoool001Coool4NGUi17MfMPAfLg<4M75`179^K@=`JfX4
KfUW16eVI0A[Hf44JV5N16QNF`=WFeP4IEQE16AFDPARDdh4HE1;15m=B0ANBT@3G4M115]4?@AI@3T4
F3lg16U=A@AWCTL4I4i90f=>B`AQCd`4H4m>15m@C`AND504GE1@0ea?D@AKCe44FdmB15YBD`AJE5L4
FeQK15aNH0=MHVH4GfM[169]L@AVM7P4JGUo16j0Q`=bQhl4MXjF17^FX0AkUIh4Ni>L17^BVPAkT9P3
NhjF17^=U0AkRi44NhZ?17^8S@AkQh/3NhF917^4Q`AkPXH4Nh6417^0PPAkOX04Ngen5Oooo`005?oo
o`AiN7T4MgEe17EbLPAcKfl4LFe/0fmZJ0A]IfD4JfAR16YQGPAXGU/4IU]G0fAHE0ASE504HE5=15m>
B@ANBdH4G4Q215Y5?P=I@S/4Echg15@j<PAQA3/4Jdi516E;A@ARBdH3H4Y715m;B0AMBdT4G4a;15]<
C0AJC4`3FD]<15Q:C0AGBdh4ETi@15MBE0AHEUT4FE]N0eYPI0ALIFT4H6a`16AbM`AXNGh4K7n60g26
SPAeSID4NIBM17VDWPAjTi`4NY:K17ZAV@=jSiL4NXjE17^<T`AkRi44NhV?17^8S@=kQX/4NhF817^3
QPAkPX@4Nh2217]nP0AkOGhEoooo000Doooo17UhN@AgMGD4MG9b17=_K`AaKF`3KfYX16eWI@A[I684
JV5N16QNF`AVFeL3I5QD16=DD0AQDDd4Gdi915i;APALB484FTDn0eU2>`AG?SL4E3Xb1654>`A[CTD4
ID]5169;AP=PBTL4Gd]815e;B@ALC4/4Fda<15Y<C0=IBd`4F4Y<15M;CPAFCU04Ee9D15QFF@AIFeh3
FV1T15aUJ@APK704I79g16QiOPA/OhH3L8J>17F=U@AiU9d4NIBN17ZCW0AjTY/4NY6I0gZ?U`AjSYD4
NhbC17^;T@AkRHl4NhR=0g^6R`AkQHP4Nh>617^2Q0AkP884Ngj017]mOQGoool001Coool4NGQi17Me
M@AeLW84Lfm_175]K0=_JVP4KFMU16]THPAZHEh4J5iK16IKE`=TF5@4HeA@165AC@AOCTT4GT]615a8
@PAJACh3FD8k15Ln=`AD>S84HD@k16]>A@AUBdD4HT]60f1:A`AOBdP4GD]915a<B`AKC4`4FTa<0eU;
C0AHBT`4Ed]>15I>D0AGDU@4F5II15UKGP=JH6@4G6EY161/L0ATLWL4J7Un16aoQP=`QXh4MHfE17VD
W@AiU9h4NY>L17ZBV`AjTIT3NXnG17Z>U@AkS9<4Nh^A17^9S`AkR8d3NhJ;17^5R0AkPhH4Nh:417^0
PPAkOX04Ngen5Oooo`005?ooo`AiN7T4MgEe17EbLPAcKfl4LFe/0fmZJ0A]IfD4JfAR16YQGPAXGU/4
IU]G0fAHE0ASE504HE5=15m>B@ANBdH4G4Q215Y5?P=I@S/4Echg15@j<PAQA3/4Jdi516E;A@ARBdH3
H4Y715m;B0AMBdT4G4a;15]<C0AJC4`3FD]<15Q:C0AGBdh4ETi@15MBE0AHEUT4FE]N0eYPI0ALIFT4
H6a`16AbM`AXNGh4K7n60g26SPAeSID4NIBM17VDWPAjTi`4NY:K17ZAV@=jSiL4NXjE17^<T`AkRi44
NhV?17^8S@=kQX/4NhF817^3QPAkPX@4Nh2217]nP0AkOGhEoooo000Doooo17UhN0AfMGD4M75a179^
KPA`JfX3KVQV16aUH`AZHEl4J5iK16IKF0ATEe@3HUA@161AC0ANCDP4G4Y415Y6@@AI@cd4Ed0i0eHl
=0AB=bl4G3he16M8?`AUB404HTQ215m7@P=MAd<4G4M415Y7APAIB4L4F4Q915M7B@=FAdP4E4E815A7
BPACBTd4E4mB15EDE`AFFUd3EemR15YTJ@ANJfl4HW9g16MhOPA[OhD3KXF<17>;T`AeT9X4N9BN17VC
W@AiTi`4NI6J0gZ@V0AjSiH4NXfD17^<TPAkRY04NhV>0g^7S0AkQHX4NhB717^2Q@AkPH<4Ngn117]m
OQGoool001Coool4NGQh17IeM@AdLG44LVi^171[JP=^J6H4K6ES16YQG`AXGU/4IU]H16AGE0=RE504
H55<15i=B0ALBT@4FTI115U3?@AG@3T3ES`d158g;`AL?SD4IdPo16E8@0ARB484GdM20ee7@`ALAd@4
FTM615U8A`AHB4T4EdM90eI7B0ADADP4E4M:15=:C@ADCe84EEAG15IJG@=GGf84FVAY15i[K`ARLWL4
IgQn16]oQ@=^QH`4Lh^C17F@VPAhU9h4NI>M17VCW0AiTIX3NY2H17Z?UPAjSI@4NhbB17^:T0AkRHh3
NhN<17^5RPAkQ8L4Nh:517^1P`AkOh44Ngen5Oooo`005?ooo`AiN7P4MWEe17AaL@AbKVh4L6]Z0fiX
IPA/IF<4JV5O16QNF`AVFeP4I5MD0f9DD0APDD`4GTe815a:A0AJAT44FD<m15M0>@=F?3@4DSL_15`n
=@AWB3l4IDQ01698@PAOAd83GDM315a7A0AJAdH4FDQ715Q8B@AGAdT3ETM815A5B0ADAdX4DdY=15A?
DPAEE5L4EUYM0eMOHPAJI6T4GV]_169bM`AWN7h4Jgn50fj5S0AcRi<4MI2J17RDWPAiTid4NI>L17VA
VP=jT9P4NXnF17Z=U0AkS984NhZ@17^9SP=kQh`4NhF:17^4Q`AkPXD4Nh6317]oP@AkOGhEoooo000D
oooo17UhN0AfMGD4M75a179^KPA`JfX3KVQV16aUH`AZHEl4J5iK16IKF0ATEe@3HUA@161AC0ANCDP4
G4Y415Y6@@AI@cd4Ed0i0eHl=0AB=bl4G3he16M8?`AUB404HTQ215m7@P=MAd<4G4M415Y7APAIB4L4
F4Q915M7B@=FAdP4E4E815A7BPACBTd4E4mB15EDE`AFFUd3EemR15YTJ@ANJfl4HW9g16MhOPA[OhD3
KXF<17>;T`AeT9X4N9BN17VCW@AiTi`4NI6J0gZ@V0AjSiH4NXfD17^<TPAkRY04NhV>0g^7S0AkQHX4
NhB717^2Q@AkPH<4Ngn117]mOQGoool001Coool4N7Qh17IdM0AdL704LFe]16mZJ0=]IV@4JV=P16QO
G0AVFeP4I5QD169DD0=OD4`4GDe815]9A0AIAD04Ed8k15Dn=`AD>S<3DSL_15Li<0AS@cX4HT<k1614
?0ANA3h4G4<n0eY3?`AH@d04EdA315I4A0AEA4D4E4=50e=4APAA@dH4DDM:151;C@AAD5<4DEAG15=I
G0=DGV44F6AX15a[K`APLGH4IWQn16UnQ@=]Q8`4LHVB17>?V0AfTid4MiBN17RCW@AhTY`3NI6J17V@
V0AjSYH4NXfD17^;TPAkRXl3NhR=17^6R`AkQ8P4Nh>617^1Q0AkOh44Ngeo5Oooo`005?ooo`AhN7P4
MWAd17A`L0AaKFd4KfYX0feVI0AZHf04J5mL16IKF0ATF5@4HUA@0em@C0AMCDP4FdU415U5@0AG@S/4
EChg15@j<`=B=bl4EcT`16=3>PAR@c/4H4@l15i4?PAL@ch3FT<o15Q3@0AGA4<4ETA415E4A@AD@dD3
DdA61553APAAAdX4D4]=155@D`AAE5L4DeUL0eANH@AHI6P4G6]_161aMPAVN7h4JGj50ff4S0AaRI84
LhnH17JCW@AgU9h4N9>M17RBW0=iTIX4NI2H17Z>UPAjSI@4Nh^B17^:S`=kR8d4NhJ;17^4R0AkPhH4
Nh6417]oP@AkOGlEoooo000Doooo17QhN0AfM7@4M71`175]K@A_JVP3KFIT16YSH0AXGe`4IU]H16AH
E0ARE503Ge1<15e=B0AKBD@4FDE015M2>`AE?SL4E3Xc0e8g;`AG>C04Hd<j1693>`APA3`4GT@n15a3
?P=J@cl4F4=015M4@`AFA4@4EDA515A3A@=CA4H4DD=61557BPA@Bdd4DE1C155DE`ACFE`3E5iQ15QT
J0ALJfl4H75f16IhOPAYOXD3KHB<1769TPAcSiP4MY>M17NDWPAhTid4N9:L0gVAVPAiT9P4NXjF17Z=
U0AkRi84NhZ?0g^8S@AkQX/4NhB817^3QPAkPH@4Ngn117]mOaGoool001Coool4N7Mh17IcL`AcL6l4
L6a[16iXI`=[I684JF1N16MMFPATFED4HUEA15mAC@=MCDP4FdU415Q5?`AF@C/4E3df158i<PA@=Bd3
CS4X15`l<@AO?cD4Gd4h15e1>@AK@3/4F3lj0eHn>PAD?cd4E45015=1@PAB@D84DT530e54A@A?ATP4
CTU:14m?D0A?DU@4CU=E14mHF`=AGV44EVAX15Y[K`AOLGH4I7Qn16QnQ@=/Ph/4KXRA176=U`AdTI/4
MiFP17NDW`AgTid3N9:L17VAVPAjT9P4NXjE17^=T`AkRi43NhV>17^7S0AkQHT4Nh>717^1Q0AkOh44
Ngeo5Oooo`005?ooo`AhMgP4MW=c17=`K`A`K6/4KVQW0f]THPAYH5h4IeeJ16AIE@AREE44Ge5=0ee=
B0AKBD@4F4Do15I1>`AD?CH4DSTb150e;@=><BP4G3`a15lo=@AO@CP4GD4i15]0>`AH?cX3EShj15@o
?@AD@D04Dd521591@PAB@D<3DDA514m6B0A>BDX4Cdm@14mBE0A>DeD4CeQK0e5NH@AFI6P4FV]_15ma
MPATN7h4J7j50fb3R`A^R944LHfG17BAV`AgUJ04MiBO17NCW@=hTY`4NI6J17Z@V0AjSYD4NhfC17^;
T@=kRHh4NhN<17^5R@AkPhL4Nh6417]oP@AkOGlEoooo000Doooo17QgN0AfLg<4Lg1_171/J`A^J6L3
JfAR16UPGPAWGEX4I5UE169ED@AODDd3GDe815]9A0AHACl4ET4k15@m=PAB>C84D3D]0dha:0AL?344
Gcle15m1>0AM@CT4Fd0k15Po>P=F?SX4E3lm15A1@0AC@D84DT521591@`=AA4D4CdI814i9BPA?Ce04
Ce9D14iCE@A?F5/3DEiQ15ITJ0AJJfl4Gg5f16AhOPAXOXD3K8>;16j8T@AaSIL4M96K17NEX0AgU9l4
Mi>M0gRBW0AiTIX4NY2H17Z>U@AkSI<4Nh^A0g^9SPAkQh`4NhF917^3Q`AkPH@4Ngn117]mOaGoool0
01Coool4N7Mh17IcL`AcL6l4L6a[16iXI`=[I684JF1N16MMFPATFED4HUEA15mAC@=MCDP4FdU415Q5
?`AF@C/4E3df158i<PA@=Bd3CS4X15`l<@AO?cD4Gd4h15e1>@AK@3/4F3lj0eHn>PAD?cd4E45015=1
@PAB@D84DT530e54A@A?ATP4CTU:14m?D0A?DU@4CU=E14mHF`=AGV44EVAX15Y[K`AOLGH4I7Qn16Qn
Q@=/Ph/4KXRA176=U`AdTI/4MiFP17NDW`AgTid3N9:L17VAVPAjT9P4NXjE17^=T`AkRi43NhV>17^7
S0AkQHT4Nh>717^1Q0AkOh44Ngeo5Oooo`005?ooo`AhMgL4MG=c179_KPA`JfX4KFIU0fYSH@AWGU`4
IEYG169FD`APDTh4GDi90eY9A0AHAD04ED4k15<m=PA@>344CS@/14`_9`=B<bP4HD0e15ho=@AL?SH4
FSlh15Pm>0AE>cL3DCXg150k>PAA?Sl4Cci014do@0ABATL3DDQ9151<C@A?CTl4CTi@14a@DPA;DUD4
C5UL0deLH0ACHVH4FF]_15maMPATN7l4J7j60f^3R`A]Qi04KhbE176?VPAdTih4MIFP17JDW`=gTid4
NI:K17ZAV@AjT9L4NhjE17^<TP=kRY04NhR=17^6RPAkQ8L4Nh:517^0PPAkOGlEoooo000Doooo17Qg
M`AeLg<4LVm^171[JPA]IVD3JV=Q16MNG0AUFUL4HUIC161BCPAMCTT3FTU415Q5@0AE@C/4Dcdf150h
<@A>=2`4C2lW0e8c:0AQ@3D4GSle15`n=PAJ?cP4F3dh15Dk=`=A>SL4D3/j154n?`A??T04CCm01596
A`=AB4T4D4a=14m>C`A>CU04C51B14]BE@A<FE`3CEaP15=RIPAIJfl4Gg5f16AhO`AXOXH3Jh>;16f7
T0A_S9D4LHnJ17BCWPAeUJ04MYBO0gNCW@AiTY/4NY6I17Z@U`AkSYD4NhbB0g^:T0AkR8d4NhJ:17^4
Q`AkPXD4Nh2217]mOaGoool001Coool4N7Mg17EcL`AbKfh4L6]Z16eVI@=ZHf44IeiL16EJE`AREU<4
H59>15e>B@=JBD@4F4E015E1>`AC?CH4D3Pa14hd;0A<;bL3DS<X1650=@AN?cD4G3hf15Xo>0AH?CP4
EC/g0e4j=`A@>cX4DCho14ln@0A=?d04DTI70e58B@A@C4d4Cdi?14i>D0A<D584Be9E14aIG0==G604
Df9V15U[K`AOLGH4I7Qo16QnQP=[Ph/4KHN@16n<U@AaSiX4M9>N17FEX0AfU9l3Mi>M17VBV`AjTIT4
NY2G17^>U@AkS983NhZ@17^8S@AkQXX4NhB717^2Q@AkP884Ngeo5Oooo`005?ooo`AhMgL4MG=c179_
KPA`JfX4KFIU0fYSH@AWGU`4IEYG169FD`APDTh4GDi90eY9A0AHAD04ED4k15<m=PA@>344CS@/14`_
9`=B<bP4HD0e15ho=@AL?SH4FSlh15Pm>0AE>cL3DCXg150k>PAA?Sl4Cci014do@0ABATL3DDQ9151<
C@A?CTl4CTi@14a@DPA;DUD4C5UL0deLH0ACHVH4FF]_15maMPATN7l4J7j60f^3R`A]Qi04KhbE176?
VPAdTih4MIFP17JDW`=gTid4NI:K17ZAV@AjT9L4NhjE17^<TP=kRY04NhR=17^6RPAkQ8L4Nh:517^0
PPAkOGlEoooo000Doooo17QgM`AeLW84LVi]16mYJ0A/IF<3JF5O16ILFPASF5D4H5=@15i?B`AKBdH3
F4I115E1>`AB?CH4CcPa14dd;0A;<2L4B2/R0eTh;@AO?S@4GChd15Xl=0AH?CL4EC/f158h=0=>=c@4
CCTh14`k?0A@A4@4DTU915I>C`=ACDh4Cdi?14e=CPA;C4d4Be9D14]DE`A;Ee/3BeUM151PI@AHJVh4
GW9g16=hO`AWOhH3JX>;16^6S`A/RY@4KhfH176BW@AcUJ84MIFQ0gNDW`AiU9h4NY>L17^AV@AkSiL4
NhfD0gb;T@AlRHh4O8N;17^5R0AkPXD4Nh2217]nOaGoool001Coool4N7Mg17EbLPAbKVd4KfUX16aU
H`=YHEl4IUaJ16=HE@APDe04GTm;15];AP=HAT44ED4k158m=PA?>344CC@/14/`9`A8:b83FCP]15ln
=0AM?S@4FS`d15Pm=`AE>cH4DSPd0dhg=0A=>CP4C3/l1514A0ABBDT4ETi?0e5=CPA?CTl4CDe>14]<
C@A;DU@4BeAG14]GF`=;FEd4D61U15QZKPANLWL4HgQo16MoQP=ZPh/4JhJ?16b:U0A_SIP4LI:M17>E
XPAeUJ43MiBO17VDWPAjTi`4Ni6I17^?U`AkSI@3O8^A17b9SPAlQh/4NhF817^2Q@AkP884Ngio5Ooo
o`005?ooo`AhMgL4MG9b179^K@A_JFP4K6ES0fUQG`AVG5X4HeQE161CD0ANCd/4Fd]60eQ6@@AE@C/4
DSdf14lh<@A==2`4Bc0W14P[8P=I>2d4Gchd15dn=0AJ?3@4F3dg15Dk=PAB>3@3CSLd14di>0A<>c`4
D4A41599B@AFCTl3DDe>14m>C`A=CDh4Bda=14]BE0A;E5L4BeMK0d]IG@A@H6D4F6Y^15ibM`ASN7l4
Ign60fZ3R`A[QXl4K8ZD16n=V0AaTYd4LiFR17FEX@=gU9l4NIBN17ZCW0AkTIT4NhnG17^=U0=lRi44
O8V>17b7R`AkQHP4Nh:517^0PPAkOWlEoooo000Doooo17QgM`AeLW84LVi]16mYJ0A/IF<3JF5O16IL
FPASF5D4H5=@15i?B`AKBdH3F4I115E1>`AB?CH4CcPa14dd;0A;<2L4B2/R0eTh;@AO?S@4GChd15Xl
=0AH?CL4EC/f158h=0=>=c@4CCTh14`k?0A@A4@4DTU915I>C`=ACDh4Cdi?14e=CPA;C4d4Be9D14]D
E`A;Ee/3BeUM151PI@AHJVh4GW9g16=hO`AWOhH3JX>;16^6S`A/RY@4KhfH176BW@AcUJ84MIFQ0gND
W`AiU9h4NY>L17^AV@AkSiL4NhfD0gb;T@AlRHh4O8N;17^5R0AkPXD4Nh2217]nOaGoool001Coool4
MgIg17AbL@AaKF`4KVQW16]THP=WGed4I5YG165FDPANDDd4G4a815U7@P=F@cd4Dchg14li<PA<<b`4
B2hV14L[8`A9:R03Gcda15hm<`AK?C@4F3`d15Hl=PAC>SD4CcLb0d/g=0A<>SX4C3ho15I;BPADBTX4
DDY:0dm:B`A=BDT4BTQ914Q8BPA9CE04B4mB14YDF0=<F5/4DF1U15IWK0ANLGH4HgUo16N0QP=XPh/4
JHF>16Z8TPA/S9L4KY2L172DX@AcUJ03MYJQ17VFX0AkUIh4Ni>K17bAV0AlSiH3O8fB17b:S`AlR8`4
O8F917b3QPAkP8<4Ngio5Oooo`005?ooo`AgMWL4M79a175]K0A^J6L4JfAR0fMOG@ATFUL4HEIB15iA
C@ALC4P4FDM20eI3?@AC?SL4CcTb14`c;0A8;RH4Ab/S14TZ80=O?C44GSdc15/m=0AH?3@4ES`f15<j
=@A?=c83BcLd14`j>PA<?Sl4ET]:15A:BPAABTX3CdY;14e9B@A:B4T4B4Q:14U=D0A8Ce84BUAH0daH
F`AAH6D4EVM/15iaMPASNGl4Ih260fR3R`AYQHh4JXRB16b<U`A^T9`4L9BQ17>EX0=fUZ44NIJP17^E
WPAkTi/4O96H17b?UP=lSI84O8Z?17b8S0AlQHT4O8>617^0P`AkOWlEoooo000Doooo17MfM`AdLW44
LFe/16iXI`A[I683IemM16AJE`AQEU84GU5=15a<B0AIAd83ET<m15<n=`A?>C84C3</14P^9PA7:b<4
BBXP0elm<@AN?C<4Fcdd15Pl=0AF?3H4DcXe14lg<P=;=c@4C3Xj14`n?`AFBdX4E4Y:155:BP=?BT/4
CDU914Y8B@A8B4X4BDe@14Q?DPA:E5P3C5QK155PI@AFIf`4GW5f16=iO`AWP8H3J8>;16V5SPAZR984
K8bG16j@W0A`U:44LiFP0gJFX@AiUZ04NiFN17^CV`AlTIP4O8nF0gb=TPAlRXl4O8R<17b5R@AlPhH4
Nh2317]nOaGoool001Coool4MgIg17AbL@AaKF`4KVQW16]THP=WGed4I5YG165FDPANDDd4G4a815U7
@P=F@cd4Dchg14li<PA<<b`4B2hV14L[8`A9:R03Gcda15hm<`AK?C@4F3`d15Hl=PAC>SD4CcLb0d/g
=0A<>SX4C3ho15I;BPADBTX4DDY:0dm:B`A=BDT4BTQ914Q8BPA9CE04B4mB14YDF0=<F5/4DF1U15IW
K0ANLGH4HgUo16N0QP=XPh/4JHF>16Z8TPA/S9L4KY2L172DX@AcUJ03MYJQ17VFX0AkUIh4Ni>K17bA
V0AlSiH3O8fB17b:S`AlR8`4O8F917b3QPAkP8<4Ngio5Oooo`005?ooo`AgMWH4M75a171/J`A]IfH4
JF9P0fIMF`ASF5D4H5=@15e>BPAIBDD4ET@o0e<o>@A@>S@4C3D]14P^9PA19Qh4A2LN15<b9P=R@3@4
GCdc15Tk<`AF>c@4E3/e154i=0A==c<3CC/h14m1@0ABAdH4Ede<159;B`A?BDT3C4Q914Y5APA7ADL4
ATE814I9C0A6CDl4B5AG0dYEFPA>GF<4DfAZ15a^M0ATNX04Ih270fN3R`AWQ8d4IhJA16V:U@A/Si/4
KY>O17:FX`=fUj@4NiZS17bGX@AlUIh4O9>K17f@U`=mSY@4O8^A17b9S@AlQXX4O8>617^1P`AkOX0E
oooo000Doooo17MfMPAdLG44L6a[16eWIPAYHV03IUeK16=HE@APDe04GDi:15U9A@AFA3l3Dcli150j
=0A<=Bd4B2hV144V7PA49ah4Dc8V0f90=0AM?C<4FC/c15Hk=0AD>cD4DCTd14dg<`==>cP4Cd501597
APAGCD`4DT];14m9B@=<B4T4BTE614M5A`A6ADP4ATU<14I=C`A8E5L3BUEJ14iMH`ACI6X4G6id16Aj
P0AWP8L3Ih>;16N4S@AWQY44JHZE16b?V`A^Til4LYJS0gJGY0AkVZ<4O9NQ17bEWPAlTi/4OI2G0gf>
U0AlRi44O8V=17b6RPAlPhH4Nh6317]nP1Goool001Coool4MgIf17AaL@A`K6/4KFMV16URH0=VGE/4
HeQE161CD0AMCTX4FDU515I4?`=C?cT4D3Xd14`e;@A8;RH4@BHN14@W7PAC<RH3HT0d15dm<`AI>c<4
ES/d15@k=@AA>C@4CCLc0ddk>0A?@D04DTM615M=C0ABBd/4CdU90da8B@A:ADH4AdE714I5B0A6BD`4
ATe?14QDE`=:EEX4CUeS15=TJPALKW@4I7Z016N0Q`=WPh/4IhB=16N6T@AYRYD4K8nK16jCW`AbUZ<3
MYNT17^JX`AlUj44O9FN17bCV`AmT9L3OHjD17b;T@AlRHd4O8J:17b3QPAkPH<4Ngj05Oooo`005?oo
o`AgMWH4Lg1`16m[JPA/IV@4J61N0fAKF0AQEU<4GU5=15]<A`AGAd84E48l0e4l=PA>=c04Bc8Z14D[
8P@o8aX4C2dS15lm<@=O?c@4Fc`c15Lk<`AD>cD4DS/e14lh=0A<>3@3C3`i14m3@@A@ATD4D4Q814i9
B@A<BDT3BdQ814Q7A`A6AdL4ADQ914E<C@A5D584AeAG0dYFF`A=GF84DVAY15U/LPASNX04IX670fJ3
R`AUPh`4IHF@16N9U0AYSIT4Ji2M16bBX0=gVZH4O9bV17fJY0AmUj04OIFM17fBV@=mSiH4OHbB17f:
SPAlQh/4O8B717b1P`AkOX0Eoooo000Doooo17MfMPAcL704Kf]Z16aVI0AXH5h3I5]H165FD`ANDDd4
Fda715M7@PAD@S`3DC`f14hg<0A;<RX4AB/R13lS6PA<;B<4Gcda0elo=0AK?3<4Ec/c15@k=@AB>cD4
CcPd14`h=0=<?3T4Cd=11516A@A@B4P4CTU914a9B@=;B4P4B4M714I7A`A5B4T4ADa=14E@DPA7E5L3
BUIK14eMHPABI6T4FFab16=jP0AVPHL3IX>;16F3S0AUQI04IhVD16V=V@A[T9d4K9:P0gNJYPAlW:H4
OIZT17fGX0AmUId4OI:I0gf?UPAmS984OHZ>17b7R`AlQ8L4O86317]nP1Goool001Coool4MgIf17=`
L0A_JfX4K6IT16QPGP=TFeP4HEIC15iAC@AKC4L4EdM215A2?0=A?3H4CSL`14/b:PA5:b84?b<J14`]
8`AO?C43Gcld15/l<`AG>c<4E3/e158k=@A?>3@4C3Pd0d`l>@A?@d44D4I51518B0A>BDT4C4U90d]8
B0A8AdL4ATM714E8B@A5C4d4AE1B14MDE`=:EU/4CEeR159TJ@AIK784HgZ016J1Q`=VPh/4IH><16F5
T0AWRI@4JHfI16^@W@A/TZ03MiZV17bLYPAmVZ@4OINP17fEW@AmTYT3OHnF17f<TPAmRXh4O8N;17b4
Q`AlPH<4Ngj05Oooo`005?ooo`AgMWH4Lg1`16m[JPA/IV@4J61N0fAKF0AQEU<4GU5=15]<A`AGAd84
E48l0e4l=PA>=c04Bc8Z14D[8P@o8aX4C2dS15lm<@=O?c@4Fc`c15Lk<`AD>cD4DS/e14lh=0A<>3@3
C3`i14m3@@A@ATD4D4Q814i9B@A<BDT3BdQ814Q7A`A6AdL4ADQ914E<C@A5D584AeAG0dYFF`A=GF84
DVAY15U/LPASNX04IX670fJ3R`AUPh`4IHF@16N9U0AYSIT4Ji2M16bBX0=gVZH4O9bV17fJY0AmUj04
OIFM17fBV@=mSiH4OHbB17f:SPAlQh/4O8B717b1P`AkOX0Eoooo000Doooo17MeMPAcL6l4KfYY16]T
H`AWGed3HeUG15mDD@ALCT/4F4U415E4?PAB?cT3CcXc14de;@A:<2L4Ab/R14X[80AG=R/4H3lc0e/l
<PAH>c<4EC/d158k=@A@>cD4CCTe14/i=@=;?3T4CT=114e4A0A=ATD4BdI614U6AP=7ADH4AD=514=4
A@A2ATP4@TU<14==D@A4DUH3B5ML14aOH`ABIf`4FG1f165jP0AUPHL3I8::16>2R`ASPhl4I8NC16N<
V0AXSid4JI6P0gbO[0AnWjX4OifW17nIX`AnUYl4OY>K0gjAU`AmSI<4OHZ?17f7S0AlQ8P4O86417]n
P1Goool001Coool4MgEf17=`K`A_JVT4JfAS16MOG@=SFEL4GeAA15a>B`AHBD@4ED@n158o>@=?>S<4
CCD]14X`9`A7:b84BR/P15Lf:`AP?c<3Fc`b15Pk<`AE>c@4DS/e150k=@A=>CD4BcTe0d/l>@A>@d44
CDA414e6A@A;ATH4BDI60dM5APA5@dD4@dA51496B0A2BD`4@deA14ABEP=8Ee`4C5mS159WK0AIL7H4
HGZ016F1Q`=TPXX4Hh:;16>3S`ATQi<4IhbH16R?W@AYTJ03O9n/17jOZPAoWJL4OiVS17jFW`AnTi/3
OY6G17f=T`AmRXl4OHN<17b4R0AlPH@4Ngj05Oooo`005?ooo`AgMGH4Lg1_16mZJ@A[I6<4IemM0f=I
E`AOE544G4i;15Q9A0AEA3h4DSli0dlj<`A==Bd4BS0W14L[8PA::b04EcH[160o<`=K?384F3/c15Dk
=0AB>cD4D3/e14di=@A;>CD3Bc`i14i3@@A=A4@4CDI514]6APA9ATH3AdE614E3A@A3A4D4@TI81499
C0A3CE44A59F0dQGG0A<Gf<4DVM/15U`MPAQNX04IH670fB2RPASPX/4Hh>?16B7T`AWS9P4J8nM16VA
X0=lWj`4OYnZ17nMY`AoVJ<4OYJO17jCV`=nTIL4OHfC17f:S`AmQh`4O8B817b1Q0AkOX0Eoooo000D
oooo17MeMPAcL6l4KfYY16]TH`AWGed3HeUG15mDD@ALCT/4F4U415E4?PAB?cT3CcXc14de;@A:<2L4
Ab/R14X[80AG=R/4H3lc0e/l<PAH>c<4EC/d158k=@A@>cD4CCTe14/i=@=;?3T4CT=114e4A0A=ATD4
BdI614U6AP=7ADH4AD=514=4A@A2ATP4@TU<14==D@A4DUH3B5ML14aOH`ABIf`4FG1f165jP0AUPHL3
I8::16>2R`ASPhl4I8NC16N<V0AXSid4JI6P0gbO[0AnWjX4OifW17nIX`AnUYl4OY>K0gjAU`AmSI<4
OHZ?17f7S0AlQ8P4O86417]nP1Goool001Coool4MWEe179_K`A^JFP4JF=R16EMF`=QEeD4GE9>15Y<
B0AFAT84Dd4k150l=@===bl4Bc8Z14T^9@A9:R04CBdR154c:0AE>2h3ESXa15@j<`AB>cD4D3Xe14hk
=PA<>CD4BSTe0dXk>@A:@3h4Bd=214Y4A0A8A4@4AT=40dA3A0A2@T<4@49313m3AP@oAdX4@4]?149@
E@=7EU`4BeiS155VK0AFKWD4G7Im165mQ0=RP8T4HH2;1662SPARQY<4IH^H16J>W0AVT:03OJ6^186R
[PB0WjT4P9bU17nHX@AoUId3OY:I17j?U@AmRi44OHR<17b5R0AlPX@4Ngj05Oooo`005?ooo`AfMGD4
LVm_16iYJ0AYHf84IEeK0f5GE@AMDTh4FTa815I6@PAC@C/4D3`e0ddg;`A;<RX4BBhU14TZ80A=;B84
DC<X15Dh;P=F>S44E3Xc158k=@A@>SD4CS/f14`i=@A:>CD3BS/i14Y0?PA;@d84BTA414Q4A0A6@d@3
A4=41492@`A0@T<4?d=613m7BPA0Bdl4@U1E0dMFG0A;GV<4DFI/15I^M@ALMWd4HGf40f:0R@AQP8/4
HH:>16:6T`AURiP4IXjL16J@X0=mXJh4PJ:^182OZ@B0W:D4OiRQ17nEW@=nTYT4OXnE17f;T@AmR8`4
O8F817b2Q0AkOX0Eoooo000Doooo17IeM@AbKfl4KVUX16USHPAUGE/3HEME15eBCPAJC4P4ETI215=1
>`A@?3D3CCL_14/b:PA9;RD4BBXP14d]8PAA<bP4ECP^0eHj<@AD>S<4DS/e150j=@A>>cH4C3Te14Xi
=@=:>cT4BT0n14]3@PA:A4@4B4A414I3A0=4@d@4@T931412@`@o@dH4?dM:141;C`A2D5D3AeIL14]N
H`AAIV`4EVie15afO@AQOH@3HX291660R`AQPXh4HXJC16F;V0AVSY`4IY2P0gfQ[PB1XZh4P9nY182L
Y@AoV:44OiFM0gjBV@AnSiD4OH^A17f8S0AlQHP4O8:417]nP1Goool001Coool4MWEe179_K`A^JFP4
JF=R16EMF`=QEeD4GE9>15Y<B0AFAT84Dd4k150l=@===bl4Bc8Z14T^9@A9:R04CBdR154c:0AE>2h3
ESXa15@j<`AB>cD4D3Xe14hk=PA<>CD4BSTe0dXk>@A:@3h4Bd=214Y4A0A8A4@4AT=40dA3A0A2@T<4
@49313m3AP@oAdX4@4]?149@E@=7EU`4BeiS155VK0AFKWD4G7Im165mQ0=RP8T4HH2;1662SPARQY<4
IH^H16J>W0AVT:03OJ6^186R[PB0WjT4P9bU17nHX@AoUId3OY:I17j?U@AmRi44OHR<17b5R0AlPX@4
Ngj05Oooo`005?ooo`AfMGD4LFi^16eXI`AXHV04I5]I0emEDPAKCd`4EdU515A3?PA@?SP4CCPb0d/c
;0A9;bH4B2/Q14PY7PA9:b44C2lV14ld;0=B>304DCXc14lj=@A=>SD4BcXe14Xi=@A8>3D3AcXg14Pm
?0A8@T44B4=314I2@`A4@483@D5213m0@@@m?d84?45413a5B@@nBTl4@DmD0dIFG0A;GVD4D6I]15E]
M@AJM7`4GW^40emmQ`ANOXT4Gh6=1666TPATRYL4IHfL16B?W`=nXZl4PZB_18:Q[0B1WZP4PIZS182G
W`=oTiX4Oi2F17j<TPAmRHd4OHJ917b2Q@AkOh0Eoooo000Doooo17IeM@AaKVh4KFQW16QRH0ATFeT3
GeEB15]?C0AGBDD4E4<n150n>0A=>383Bc</14T_9PA8:b44B2TN14T[8@A<;bH4Cc@/0e8h<0AA>S<4
CcXe14dj=@A;>SD4BSTe14Ph=@=7>SL4B3dl14Q2@@A8@d<4AT9314A0@P=1@D84?d1113do@P@l@D@4
?4E913i:C`A1Ce@3AUIL14]NI@A@IVd4EFee15YdO0ANNh@3Ggf715inR@AOPHd4HHJB16B:U`AUSI`4
I8nO0gjR[`B2Y:l4PZ6/186NZ0B1VZ<4P9NO0gnCVPAoT9H4OXbB17f9S@AmQXT4O8:517]oP1Goool0
01Coool4MWEe175^KPA]J6L4J69P16AKF@=OEE84Fdm<15M9A@AD@ch4D3hh14dh<P=;<b`4BBlV14P[
8@A8:Ah4BB/Q14`_9PA?=2`3DSP`154j<`A?>SD4CCXe14/j=@A:>CD4B3Pe0dLj=`A8?C`4B49114Q3
@`A6@T<4A4120d51@P@o@444?Cm213a1A0@lADT4?TY?145?E0=6EU`4BeiU151VK@AEKGD4FWAl15ik
Q0=OOHL4GWj915n1S@AQQY84I8ZG16F=W0ATSil3OZ:_18:T[`B2XJ`4PIjX186JX`B0Uil3Oi>J17n@
UPAnS984OHV=17f6R@AlPXD4Ngn05Oooo`005?ooo`AfMGD4LFi^16eXI`AXHV04I5]I0emEDPAKCd`4
EdU515A3?PA@?SP4CCPb0d/c;0A9;bH4B2/Q14PY7PA9:b44C2lV14ld;0=B>304DCXc14lj=@A=>SD4
BcXe14Xi=@A8>3D3AcXg14Pm?0A8@T44B4=314I2@`A4@483@D5213m0@@@m?d84?45413a5B@@nBTl4
@DmD0dIFG0A;GVD4D6I]15E]M@AJM7`4GW^40emmQ`ANOXT4Gh6=1666TPATRYL4IHfL16B?W`=nXZl4
PZB_18:Q[0B1WZP4PIZS182GW`=oTiX4Oi2F17j<TPAmRHd4OHJ917b2Q@AkOh0Eoooo000Doooo17Id
M@AaKVd4JfMV16MPG`ARFUL3GE=@15U=B@AEAT84DD0k14dj=@A:=Bh3B30X14H[8PA59ad4ARLM14HY
80A9;RH4CCD]0e0g<0A>>C<4CCXd14/i=0A9>3@4B3Pd14Hg=0=5>CH4A3/j14Do?`A5@T84@d52144o
@@<o@444?Cm113Xm@@@j@4@4>TA813e:C`@oCe@3AEIM14YNI@A?IVd4E6ee15QcO0AKNH83FgZ515am
R0ANPHd4H8FB16>:U`AUSI`4IHnN0g^O[0B4Y[84Q:B_18>PZPB2W:H4PIRQ0h2EW0AoTIL4OXfC17j:
SPAmQXX4O8:517]oPAGoool001Coool4MWAe175^K@A[IfH4If1O169JE`=MDe04FDe915E6@PAA@3/4
CCXe14Xe;P=8<2P4AR/R14DW7@A69ad4ARTP14T^9PA==Bd3D3L`14hi<`A=>S@4BcTd14Th=0A8>3@4
ASLd0dDi=PA4>cX4AClo14E2@PA3@D84@Cm10cm0@@@m?d44>Se113Y0A0@jA4P4?DY?13m?E0=5EUd4
BUiU14mVK@ADKGD4F7=l15]iPP=KNXD4G7f815j1S@APQI84HhZG16F=W0AUSih3Nin/18BV/PB4Y:l4
Pj2Z18:LYPB1V:43P9FL17nAU`AnSI<4OXZ>17f6RPAlPXD4Ngn15Oooo`005?ooo`AfM7D4LFi]16]W
IPAWH5l4HUYG0eeCD0AICDT4EDI21550>`A=>SD4BSD^0dP`:0A6:b84ABLM14HW7@A6:B04BBhV14de
;@=@=c04CSTc14dj=0A;>C@4BCPd14Ph=0A6=c@3ACTf14@k>PA5?cl4AD9214=1@PA1?d43?d1113do
@@@j?D44>T1413Y4B0@mBTl4?dmD0dEFG@A:GVD4CfI]15A]M@AHLg`4FgV20e]jQ@ALOHP4GX6=1625
TPASRYL4IHfL16F?WP=kWj`4Q:Jb18BT[`B3X:X4PYbV186HX@>0UI`4Oi6G17j=T`AnRXh4OHJ:17b2
Q@AkOh4Eoooo000Doooo17IdM@AaKVd4JfMV16MPG`ARFUL3GE=@15U=B@AEAT84DD0k14dj=@A:=Bh3
B30X14H[8PA59ad4ARLM14HY80A9;RH4CCD]0e0g<0A>>C<4CCXd14/i=0A9>3@4B3Pd14Hg=0=5>CH4
A3/j14Do?`A5@T84@d52144o@@<o@444?Cm113Xm@@@j@4@4>TA813e:C`@oCe@3AEIM14YNI@A?IVd4
E6ee15QcO0AKNH83FgZ515amR0ANPHd4H8FB16>:U`AUSI`4IHnN0g^O[0B4Y[84Q:B_18>PZPB2W:H4
PIRQ0h2EW0AoTIL4OXfC17j:SPAmQXX4O8:517]oPAGoool001Coool4MGAd171]K@AZIVD4IEmM161H
E@=KDDh4ETY61593?`A>?CP4BSLa14La:P=4:b@4@bLN148S6@A291/4@bLN14P`:@A<=Bh3CCLa14/i
<`A:>C@4B3Pd14Lg<`A5=S<4A3Hd0d<h=@A2>CP4@Sdm14=1@PA1?d44?ci00c`n@0@j?3l4=c`o13Hn
@P@h@TL4>TU>13i>E@=3EUd4B5iU14iVKPACK7D4EW9k15IeO`=GN8<4FW^715aoS0AOQ944HhZG16N?
W@A/Tj43NYj/18>W/`B7Z;<4QJ>]18>NZ0B1VZ<3P9JN182BV@AoSY@4OXZ?17f7RPAlPhH4O7n15Ooo
o`005?ooo`AeM7@4L6e]16YVI@AUGed4H5QE0e]ACPAFBTH4DT<o14hm>0A:=c44Ac4Z0d@[90A39ah4
@R<I148T6`A39ah4B30Y14`e;P===c44BcTc14Xi=0A8>3@4AcLc14Df<`A4=S@3@cPe148i>0A2?Cd4
@d52144o@@@o?T03?3i013Xl?`@g?3l4=Si213Q2A`@jBDh4?TiE0d=FG@A8GVD4CVI^15=/M@AFLW/4
EWEo0eMhP`AJNhL4G7n<15n4T@ASRYL4IhnM16bCX@=jWZ`4PjNc18NX/`B5Xjd4PijX186JX`>0UYh4
P9:I17n>U0AnRXl4OHN:17b3QPAlOh4Eoooo000Doooo17EdM0A`KFd4JVIU16EOG@APF5D3Fe5>15I:
APAB@cl4CSdh14Xg<@A7<BX3A2/T14<W7PA28aT4@R@K14<W7PA8<2T4C3D^0ddg<@A;>C<4BSTd14Ph
=0A7=c<4ACHc14@f=0=3>3D4@STh148m?@A3@D84@Cm113ln@0<l?T04>S`o13Ll?`@f?T84>49713Y9
CP@nCUD3@eIM14QNI@A>IVh4Dfae15IbN`AFMGl3EgR315YkQ`ALOh`4GhBA16>:U`AWSid4K9>Q0gZN
[0B3Yk<4QjRc18FS[@B3WZP4PIZS0h2FWPB0TYT4OhjD17j:S`AmQhX4O8>617aoPAGoool001Coool4
MGAd16m/K0AYI6@4HeeL15iFE0=HCT`4DdM414i0?0A:>C@4AS<]14<]9P=09al4?R4H13dN5@@n8AT4
@BTQ14Lc;0A:=Rl3BSPa14Th<PA8>3<4ASHb14@e<@A3=C84@CDc0d0f=0A0>3L4@C`m144o@0@o?T04
?3`o0cXl?`@g>Sh4=3Xm13<l@@@e@DL4>4M=13a>E0=0EEd4AeeV14eVK`A@JgD4DVmi15=bO@=DMH44
EgV515]nRPANPi04HhVG16V?W@A_U:83NIn]18F[^0B;[KT4QJF`18>PZPB2Vj@3PINO182CVPAoSiD4
OX^@17f7R`AmPhH4O7n15Oooo`005?ooo`AeM7@4Kfa/16UTI0ASGE`4GUID0eQ>C0ACAd@4CT0l14Xi
=0A6<bd4@bdV0d0W7`@n8AP4?AhE13hQ6@A1:B44Ac</14Xf;`=:>344BCPb14Ph<`A6=S84A3Da14<e
<PA1=C<3@3Hd140h=`A1?3d4@Cm013ln@0@l?3l3>S`o13Lj?P@d>Sd4<ca113E1A`@hAdd4?4iD0d1E
G@A7GFH4CFI_151[M@ABKgT4Dg9m0eAeP@AGNHD4Fgj:15j3T0ASRIL4JHnM16nDXP=iWjd4QJ^h18^]
^@B5YK04Pj2Z18:KY0>1Uil4P9>J17n?U@AnRi04OHN;17f3QPAlOh4Eoooo000Doooo17EdM0A_K6`4
JFAT16=MG0ANEU@3F4i<15=7A0A>@3`4BSTd14Hc;@A3;BH3@2LO13hQ60@m7QD4?R4I144Y8@A7<b`4
BSH_0dXh<@A9>384B3Pc14Hf<PA4=C44@cDb144e<`=0=S@4@3Pg144l?@A1?d04?ci013`l?`<j?3l4
=cXn13@j?@@c?444=D5713Q7C@@lCU@3@5EM14MMIPA=IVl4D6]e159_N@ACLWd3E7F115MiQ@AKOXX4
GX>@16>9U`AYSid4KiBR0gVO[@B5ZkP4Rjfi18FU/0B3X:X4PY^T0h6GW`B0TiX4OhnE17j;T0AmQh/4
OH>617aoPAGoool001Coool4MGAd16m/K0AYI6@4HeeL15iFE0=HCT`4DdM414i0?0A:>C@4AS<]14<]
9P=09al4?R4H13dN5@@n8AT4@BTQ14Lc;0A:=Rl3BSPa14Th<PA8>3<4ASHb14@e<@A3=C84@CDc0d0f
=0A0>3L4@C`m144o@0@o?T04?3`o0cXl?`@g>Sh4=3Xm13<l@@@e@DL4>4M=13a>E0=0EEd4AeeV14eV
K`A@JgD4DVmi15=bO@=DMH44EgV515]nRPANPi04HhVG16V?W@A_U:83NIn]18F[^0B;[KT4QJF`18>P
ZPB2Vj@3PINO182CVPAoSiD4OX^@17f7R`AmPhH4O7n15Oooo`005?ooo`AdLg<4KV][16QSHPAQFeX4
Fe=A0eE<B@A@A444Bcdi14He<@A2;RT4?RPQ0c/R6P@i71@4>1`D13/R6`A1;RH4AcD^14Xg<0=8=c84
AcLb14Df<PA3=C44@S@`140c<0@o<c43?SDc13hg=`@n>c/4?Sdo13`m?`@j>cl3>3/o13Di?@@b>Cd4
<C]11391A`@fAdd4>diE0d1EGPA6GVL4BfE^14eYL`A?K7L4Cfmj0e5cO`AEMh@4FGb915f2T0ARR9H4
J8nN16jDXP=hWZd4PJVh18BX]@B4YK04Pj2[18:LYP>1V:04P9BK182@UPAoS944OXR<17f4QPAlOh4E
oooo000Doooo17AcL`A^Jf/4J6=R165KFPAKDe43EDa91514@@A;?CT4ASDa148^:@@n:243>b8J13TL
50@h71@4>b8K144^9PA7=Bh4BSL`0dPg<PA7=c84ACHb14<e<@A2=304@3<`13lc<@<n=C<4?SLg13hk
>`@n?Cl4?3do13Xk?`<h>cl4=CTm138i?@@a>d44<T5713I7C@@kCUD3@5EN14INI`A;IFh4CFUc14m/
M`A?KgX3DG=o15EgQ0AIO8T4GH:@16:8UPAXSih4KYBR0gRN[@B1ZKP4Q:Re18BU/0B3X:/4PYbV0h6H
X0B0U9/4P92F17n<T@AnR8`4OHB617aoPAGoool001Coool4M7=c16i[J`AXHf84HE]J15]CD@=EC4T4
D4A114/m>@A6=C44@RhY13hX8@<k8QX4>A`D13PL50@k8Q/4@BhV14Le;PA:=c03B3Lb14Lg<PA5=S84
@cDa148d<0A0<c04?c<a0che<`@n=cL4?S/k13hm?`@l?Cl4>S/o0cPk?`@e>Cd4<STm134k@@@b@DL4
=TM=13]>E@=0EEh4AUiW14]UKPA=JG<4Cfag14m_NP=ALgl4EGN415UlR@AMPY04HXRF16R?WPA^U:83
N9j]186Y^0B4Z;D4Q:F`18>PZ`B2W:H3PIRP182DV`B0T9H4OhbA17j8S0AmQ8H4O7n15Oooo`005?oo
o`AdLg<4KV][16QSHPAQFeX4Fe=A0eE<B@A@A444Bcdi14He<@A2;RT4?RPQ0c/R6P@i71@4>1`D13/R
6`A1;RH4AcD^14Xg<0=8=c84AcLb14Df<PA3=C44@S@`140c<0@o<c43?SDc13hg=`@n>c/4?Sdo13`m
?`@j>cl3>3/o13Di?@@b>Cd4<C]11391A`@fAdd4>diE0d1EGPA6GVL4BfE^14eYL`A?K7L4Cfmj0e5c
O`AEMh@4FGb915f2T0ARR9H4J8nN16jDXP=hWZd4PJVh18BX]@B4YK04Pj2[18:LYP>1V:04P9BK182@
UPAoS944OXR<17f4QPAlOh4Eoooo000Doooo17AcL`A]JVX4IV9Q15mIF0AIDDl3DTU614a1?PA7>CD4
@C4]13`Z90@h8a`3=A`D13<H40@c6a@4>2@M144`:@A8=c04B3La0dLg<PA5=S44@c@`144c;`@n<Rl4
?C4_13`a<0<k=3<4?3Hf13`j>`@l?3h4>c`n13Pk?P<f>Sh4<cPl12lh?@@^>d04<D1713A7CP@iCUH3
?eIN14AMIPA7HV`4BFIa14YYM0A<K7P3CW1m159ePPAFNhP4Fh6?1628U@AWSYd4KI>R0gFM[0AmY[D4
PJNd18>U/@B3XJ`4PYfW0h:IXPB1UI`4P96G17n=TPAnR8`4OHB717b0PAGoool001Coool4M7=c16eZ
JPAVHV44GeUH15UAC`=BBDH4C44n14Li=@A1<Bd4?2XT13PS70<e71@4<aP@13<K50@h91d4@C0Y14Pg
<0A8=c43AcLb14Df<@A3=304@C<_13hb;`@m<Bl4?34`0c/d<`@l=SH4?3Xk13`l?P@k?3h4>3/n0cHj
?P@c>3`4;cPm12hk@0@a@4L4=4M>13U>EP<oEUh4A5eV14MRK0A9IW44BVUd14a/N0=>L7d4DWF215Ik
R0AKPHl4H8RE16N>W@A]Tj83MIf/17fV]@B1Yk@4PjFa18>Q[0B2WJL3PYVR186EW0B0TIL4OhfB17j8
S0AmQ8L4O8215Oooo`005?ooo`AdLg<4KFYZ16IRH@AOFEP4FE5?0e99APA<@Ch4AcTe144a;@@l:R@4
>2<L0cDL50@c6104<a/D13PT7@A1<2T4B3L`14Pg<@=7=c84ACHa14<d<0A1<bl4?S8_13da;`@l<C03
>c@c13`f=P@l>S/4?3`n13/l?P@h>ch3=SXn13<h?0@_>3d4;S]01350A`@dAdh4>DiF0cmFGPA4GFH4
Af9/14UVL@A:JG@4C6ah0di`O@ABMH84EW^815^1S`APR9D4IhjM16fCXP=eWJ`4OJJe186W]0B3YK44
Pj6/18:MY`>2VJ84PIFL182AU`AoSI84OXR<17f4Q`AlP84Eoooo000Doooo17AcL`A]JVX4IV9Q15mI
F0AIDDl3DTU614a1?PA7>CD4@C4]13`Z90@h8a`3=A`D13<H40@c6a@4>2@M144`:@A8=c04B3La0dLg
<PA5=S44@c@`144c;`@n<Rl4?C4_13`a<0<k=3<4?3Hf13`j>`@l?3h4>c`n13Pk?P<f>Sh4<cPl12lh
?@@^>d04<D1713A7CP@iCUH3?eIN14AMIPA7HV`4BFIa14YYM0A<K7P3CW1m159ePPAFNhP4Fh6?1628
U@AWSYd4KI>R0gFM[0AmY[D4PJNd18>U/@B3XJ`4PYfW0h:IXPB1UI`4P96G17n=TPAnR8`4OHB717b0
PAGoool001Coool4Lg9c16aYJ@ATH604GEMF15I?C@=?AT@4B3dk148e<P@l;BT4=bDP138M5`<]5@h4
:Q@=12`I4`@f9Ah4@c8/14Ph<@A7>383ASLb14@e<0A1<bl4?S4^13/`;P@j<2l4>C0`0cTc<`@j=SL4
>cXk13/l?P@j?3l4=c/o0c@i?@@`=c`4;CLl12`j@0@^?dH4<TI>13M=EP<lE5d4@5YT14=OJ@A5Hfh4
AVMb14UZM`=;Kg`4D7B115AjR0AIOhh4GhJE16F<V`A[TIl3LibZ17^R/@B1ZKL4PZJc18>S[PB3WjT3
PYZS18:FWPB1TYP4P8fC17n9S@AmQ8L4O8225Oooo`005?ooo`AcLW<4K6UY16APH0AMEeH4ETm=0dm6
A0A8?C/4@SDb13`]:@@g9B04<QdG0bdE3P@Z50d4;1TC13HU7PA3<R`4B3Pa14Lh<P=6=c84A3D`144c
;`@n<Bh4>c0^13X`;`@i<303>C<c13Xf=`@k>S/4>c`n13Xl?`@g>cl3=3Tm130g?0@]=c`4;3Y012ho
AP@bATh4=deF0caDG@A0FV@4@emY14ESKPA6Ig84BFYg0d]_O0A@M844E7Z815UoSPAOQYD4IHbK16^A
W`=cW:X4Nj:a186Y]`B2Y[<4Pj>^18>OZ@>2VZ<4PYJN186BV0B0SI<4OhV=17f4Q`AlP88Eoooo000D
oooo17=bL`A/JFT4I61P15eGEPAFCdd3CdI414Pm>`A2=C84?2dY13LU80@b7AL3;AD>12XD3@@/6A<4
=RDN14<b;0A8>344AcPb0dHg<PA4=C04@C<_13ha;P@k<2h4>S0_13T`<0<i<c<4>SHg13/j>`@k?3h4
>S`o13Lk?`<d>Cd4<3Ll12dg?0@/>T04;Sm61396CP@gCEH3?5AM141JI0A3GfT4AF=^14IWLPA9JWL3
Bfml151dP@ADNXP4FGn>15n6U@AUS9/4Ji6O0g>LZPAkX[44PJVg18:V/`B3Xjh4PinY0h:JX`B2UYh4
PI:H182=T`AoRHd4OHB717b0PQGoool001Coool4Lg9c16aYJ@ATH604GEMF15I?C@=?AT@4B3dk148e
<P@l;BT4=bDP138M5`<]5@h4:Q@=12`I4`@f9Ah4@c8/14Ph<@A7>383ASLb14@e<0A1<bl4?S4^13/`
;P@j<2l4>C0`0cTc<`@j=SL4>cXk13/l?P@j?3l4=c/o0c@i?@@`=c`4;CLl12`j@0@^?dH4<TI>13M=
EP<lE5d4@5YT14=OJ@A5Hfh4AVMb14UZM`=;Kg`4D7B115AjR0AIOhh4GhJE16F<V`A[TIl3LibZ17^R
/@B1ZKL4PZJc18>S[PB3WjT3PYZS18:FWPB1TYP4P8fC17n9S@AmQ8L4O8225Oooo`005?ooo`AcLW84
JfQX169OGPAKEED4Dda;0d]3@@A4>SL4?C4^13LX9@@a81`4:aPC0bD?2@@Q40/4:AXE13LW8PA6=Rl4
BCTc14Pi<`=6=c84@cDa13lb;`@k<2h4>2l^13L^;P@f;bl3=c8b13Pf=P@j>C/4>S`n13Tl@0@g>cl3
<cTn12lg?0@[=S`4:SU012`oAP@_ADd4=4aE0cQBG0@kEf84?UaW141PK0A3I704AVQe0dU]N`A=LX04
DGR615MmS@ALQ9<4HXZI16R?WP=aVZT4NZ:a18:/^`B3Z;D4PjB`18>PZP>3W:D4PYNO186CV@B0SY<4
OhZ>17j5R0AlP88Eoooo000Doooo17=bLPA[J6P4HUmN15]EE@ACC4/3Bd=114@j=`@m<Bh4=bPU134P
70@[61<39@l9124@2`@Y6QD4=bLR14Hf;`A9>C<4B3Tc0dHg<PA3=C44?c8_13/`;P@h;bh4=bh^13H_
;`<g<S84>3Hf13Xi>`@j?3h4>Ca013Lk?`<c>Ch4;cLl12/f?0@Z>D04;3m612m5C@@dC5D3>59L13]G
HP@nG6L4@61/14=TL0A6J7D3BFek14ebP0AAN8H4Egf=15b4T`ARRYT4J8nN0g6JZ@AjX[44PZbk18>X
]@B3Y;04Pj2Z0h>LY@B2Uil4PI>I182>T`AoRXh4OXF817b0PQGoool001Coool4Lg9b16]XJ0ARGeh4
FeEE15=<B`=;@d44A3Xg13da;P@g:2D4<B0L12/H4`<U3`T48A0;12TJ5@@g9b84ASH_14Ti<`A8>C<3
ASLb14<e<@@o<Rl4>c0^13P_;P@g;Rh4=Rl_0cLb<P@h=SH4>STk13Xl?P@i?404=c/o0c<i?P@_=c`4
:cHl12Xi@0@/?dH4;dE=13A<E@<hDU`4>eMR13iLI`A0H6`4@fA`14IXM@=9KG/4CG:0155hQPAGOHd4
G8BC16::V@AXSih3LIZY17ZR/@B2[;/4PjRe18>T/0B3X:X3PibU18:GW`B1TiT4P8jC17n:SPAnQHP4
O8225Oooo`005?ooo`AbLG84JFMW165MG@AHDe<4CdY80dM0?P@o=S@4=bdZ134T80@[6aL49A<>0b0=
20@N40d4:AdH13T[9@A<>c<4C3`f14Tj=0=7>3@4@SHb13da;`@h;bd4=2`[138/;0@b;Bh3=C4b13Pf
=`@j>S/4>cdo13Xn@P@g?D43<SXo12dg?@@Y=S`4:3To12XnA@@/A4d4<DYD0c=@FP@fE5l4>EUU13eN
JP@oHVl4A6Qe0dM/NPA;LH04CgN615AlS0AJPY84GhRH16B=W@=_UjL4NjBc18>^_@B4Z[P4Q:Jb18BR
[0>4WJH4PiVP18:DVPB1Si@4P8Z>17j5R0AlP88Eoooo000Doooo179aLPAYIfL4HEeM15QCD`A?BTP3
Ad0n13lf=0@g;BX4<B@P12/K5`@U4`h380d811h@3@@Y7AP4>B/U14`k<`A<?3H4BCXd0dLh=0A2=S84
?C4_13P_;@@d;2/4<R`/138];P<e<C84>3Hg13Xj>`@k?Cl4>Si213Lm@@<b>Sl4;CLm12Tf?0@X>Cl4
:Si512a4C@@aBU@3<e1J13IDG`@iFFD4?EiZ13mRK`A4J7D3Afaj14]aP0A?MhH4E7b<15Z2TPAOR9P4
I8fM0fnGY`AkY;<4Pjjm18BZ^0B4Y[84Q::/0hBMYPB3VJ04PYBJ186?U0B0RXh4OXF817b0PQGoool0
01Coool4LW5b16UWI`AQGEd4F5=C14m:B0=7@3h4?cHd13L]:P@a9204:a/G12DC3P<P3@P47Q0=12TM
60@i:bD4C3/c14`l=PA9>S@3AcPd148f<P@m<Bl4>2l]13@/:`@b;2`4<Rd^0cDa<P@h=SL4>SXk13/m
?`@j?T84=ce10c8j?`@]=cd4:CHl12Pi?`@Z?TD4;4A=135:E0<cD5X4=UAO13UII@@mGVX4?f9_14AX
M@=7K7X4Bg6014mgQPADO8`4FX:B15n8V0ATSId3KiNW17^T/`B3[[d4Q:Zh18BV/PB4XZ`3Q9fV18>I
X0B2U9X4PHnD182:SPAnQHP4O8225Oooo`005?ooo`AbLG84JFMW165MG@AHDe<4CdY80dM0?P@o=S@4
=bdZ134T80@[6aL49A<>0b0=20@N40d4:AdH13T[9@A<>c<4C3`f14Tj=0=7>3@4@SHb13da;`@h;bd4
=2`[138/;0@b;Bh3=C4b13Pf=`@j>S/4>cdo13Xn@P@g?D43<SXo12dg?@@Y=S`4:3To12XnA@@/A4d4
<DYD0c=@FP@fE5l4>EUU13eNJP@oHVl4A6Qe0dM/NPA;LH04CgN615AlS0AJPY84GhRH16B=W@=_UjL4
NjBc18>^_@B4Z[P4Q:Jb18BR[0>4WJH4PiVP18:DVPB1Si@4P8Z>17j5R0AlP88Eoooo000Doooo175a
L@AXIVL4GeaL15EAD@A<AdH3@c`k13Xb<0@a:2H4:QhK12@F4P@O3PX36P/811L=2`@U71T4?2hY154o
=`A@?cP4C3dg0dPk=PA3=c<4?C<a13P_;`@c;Bd4;b`^130^<0<e<c<4>STi13/k?@@l?d44?D=613Q0
A0<c?444;CPm12Pf?0@V>3l49ce512U1C0@]B5<3<4iI139BGP@fEV<4>E]Y13aPKPA2Ig@3AV]j14U`
O`A=MHD4DG^;15N1T@ALQiL4HXbL0g2IZ@AnYkH4QK7118J]^PB6Z;@4QZB^0hFOZ0B5VZ84PiFL18:@
U@B0Rhl4OhJ917f1PQGoool001Coool4LG5a16QVI`AOG5`4EE5A14a7AP=3?3/4>S8`134X9P@Z7Q/4
91HB11l>2P<J2`P45`d;12DL6@@l;RT4DClg150o>0A<?CL3B3/f14<g<`@m<c44>2l_13<];@@_;2h4
<2h`0cDc<`@j>CT4>c/m13`o@@@m@dH4>4140c<l@@@]>3d4:3Hl12Hh?`@W?DD4:D5<12e8D`<`CUT4
<U9N13IFH`@iFfT4?61^149WM0=6JgX4BG1o14eeQ@AANh/4Eh6A15b7U`ARS9`3L9VY17jW]PB5/L44
QZfj18JX]0B6Y:h3QInX18FJXPB3UI`4PY2E182;S`AoQXT4OH625Oooo`005?ooo`AaLG44J6IW15mL
G0AEDE44C4M60d<l>`@j<S04<BPV12XN6`@T5Q847`h:0aX;20@G3@/49A`I13`^:@AA?cL4D3lh14`m
=`=8>cH4@cLc13dc<@@h;bl4<bd]12l/;P@`;S03=C<c13Xi>@@k>cd4?3m113e3AP@h@4@3<ca112dh
?@@X=S`49SPo12LmA@@Y@D`4;DQC0c1>F@@bDUh4=UIS13UKJ@@lH6h4@VMd0dI[NPA9L7l4CGF5155k
R`AGPI44G8NG16:<W0=`VJT4OZNf18Fa`@B6[KX4QZRd18JT[P>5WjP4QIZR18>EW0B2T9D4P8^?17n6
R@AmPH8Eoooo000Doooo175aL@AXIVL4GeaL15EAD@A<AdH3@c`k13Xb<0@a:2H4:QhK12@F4P@O3PX3
6P/811L=2`@U71T4?2hY154o=`A@?cP4C3dg0dPk=PA3=c<4?C<a13P_;`@c;Bd4;b`^130^<0<e<c<4
>STi13/k?@@l?d44?D=613Q0A0<c?444;CPm12Pf?0@V>3l49ce512U1C0@]B5<3<4iI139BGP@fEV<4
>E]Y13aPKPA2Ig@3AV]j14U`O`A=MHD4DG^;15N1T@ALQiL4HXbL0g2IZ@AnYkH4QK7118J]^PB6Z;@4
QZB^0hFOZ0B5VZ84PiFL18:@U@B0Rhl4OhJ917f1PQGoool001Coool4LG1a16MUIPAMFUX4Ddm?14Q4
A0<n>CP4=2d/12XR8@@Q61H46`l=11P:1`<G2`T45Q0>12XQ7@A1<bd4Ed@l15=2>`A??cX3BSdi14Di
=PA0=S@4>S8b13Pb<P@c<344=C8d0c`i>@A0?d04@d9314A7B@A2BD`4>T=80c<n@`@/>3h49cHm12@g
?`@T>d@493e912Y7D`<ZBUH4:deK12mBH0@eFVL4>V1]145VM0=4JgT4B6mo14]dQ0A@NX/4EGn@15V4
U@AORi`3L9ZZ17nZ^@B8]<<4R:nl18RZ]PB8YK03Qj6Z18JLX`B5UYd4Pi6G186<T0AoQXT4OH635Ooo
o`005?ooo`AaL744IfEV15eJFPACCdl4B4A40chi>0@d;B`4:R8Q124H5P@K3`d460X70aL;2@@F40h4
:R4M144c;@AGA3`4Dd8k14lo>P=:?CT4ACTf140f=0@j<S84>38b13<`<@@e<S@3?3Ti140o@0A3@T<4
A4M91499C0@j@dP3<ci312`h?P@W=Sd493Lo12@kA0@T?DT4:TMC0bY:EP@[CE/4;e9P13EJI`@jH6d4
@FId0dA[N@A8Kgl4BgB4151jR`AEOi04FHBE15n;W0=`VZX4OjZi18Rd``B8[k`4R:Zf18RU/0>7XJX4
QYbS18FFW@B3TIL4PHb@17n6R@AmPH<Eoooo000Doooo175`L@AWIFH4GEYJ15=?C`A8A4@3?STh13@]
;0@Z8R448APF11/?3@@H2PL35`/911H@3P@Z8Ad4@C<]15M4?0AC@S/4Cclj0dXm>@A5>CH4@3Hd13Xb
<P@h<S84<c0a13Db=0<l>CT4@3m014=2@`A4AdT4@TU<13Y3B0<c?T<4;3Pn12Lf?@@T=cl493]412@m
B@@ZAe<3:TYF12]=F`@_DV04=EYW13YPK@A1IW@3A6]i14Q_O`A;M8@4D7Z;15EoT0AIQ9D4Gh^L0g2J
ZPAoZ[T4R;C318R__0B8Z[H4R:F`0hNQZPB6W:<4QIJM18>AU`B1S904OhJ917f1PaGoool001Coool4
LG1a16MUIPAMFUX4Ddm?14Q4A0<n>CP4=2d/12XR8@@Q61H46`l=11P:1`<G2`T45Q0>12XQ7@A1<bd4
Ed@l15=2>`A??cX3BSdi14Di=PA0=S@4>S8b13Pb<P@c<344=C8d0c`i>@A0?d04@d9314A7B@A2BD`4
>T=80c<n@`@/>3h49cHm12@g?`@T>d@493e912Y7D`<ZBUH4:deK12mBH0@eFVL4>V1]145VM0=4JgT4
B6mo14]dQ0A@NX/4EGn@15V4U@AORi`3L9ZZ17nZ^@B8]<<4R:nl18RZ]PB8YK03Qj6Z18JLX`B5UYd4
Pi6G186<T0AoQXT4OH635Oooo`005?ooo`A`L704IVEU15]IF@A@CTh4AD910cXe=@@^:BP48Q`K11H?
3P@<0`844`P50aD=2`@H4a84:R<P14@f<0AKB404EdDn1592?@=<?c/4Ac`i148i>0@m=SH4>cHf13Pe
=@@n>SX3A40o14M5A@A9B4T4AdY<1459C@@jADX3<ci412`h?P@V=Cd48cLo12<kA@@T?d/4:DQE0bE8
EP@TBET4;U9P13EJJ0@hGVd4@6Ed0dAZN@A8L7l4BWB514iiR`ABOXl4E8:D15b:W0=`Vj/4PZbk18Ze
a0B:/;h4RZbh18ZW/P>9Xj/4R9fU18JHWPB4TYP4PXfA1827RPAmPH<Eoooo000Doooo171`L0AVIFD4
FeUI151>CPA5@T43>SDe12hY:0@R71/45Pl>10`30P@C20D35@d;11PC4P@Z8b04A3H`15]8@0AGACh4
DT8m0d`o>`A7?3T4@STh13df=P@k=SH4>3De13hj>P=4@3l4AdE514U8B@A7BT`4@DU=13Y5BP<c?T@4
;3Pn12He?@@S=cl48c]512@oB`@YB5D39DQF12A9F@@^DV04=EYX13QNK@A0IG@3A6Yi14Q`O`A:M8D4
CWV;159nS`ADPY@4G8ZL0g2KZ`B2[;/4R[G418Z`_PB:[;P4RZNb0hVSZ`B8WJD4QYRN18BBV0B2SI44
P8N:17f1PaGoool001Coool4L71`16IUI@AKFET4D4i>14E2@@<j=CD4;RTX128L6`@F3`h430<211<8
1@<E3@/461<B12XS80A4=S04FdQ015M5?PAB@Sd3C3lk14Ll>@A2>CP4?CHf13/f=P@h=CD4?SXj0dA0
?`A7ADD4BDQ914M:C0A1BDd4>TE:0c<nA0@/>3h49SDm12<g?`@S>dD493m;12U8E@<UB5H494UI12iB
H0@eFVP4>5i]141UM0=4JWT4B71o14YdQ@A>NH/4DWj?15B2U0ALRY`3L9^[18:/^`B:]L@4R[2n18Z/
^0B:Yk83RJ>[18RMY@B6V9h4Q9:H18:=T@B0QhX4OH635Oooo`005?ooo`A`L704IVEU15]IF@A@CTh4
AD910cXe=@@^:BP48Q`K11H?3P@<0`844`P50aD=2`@H4a84:R<P14@f<0AKB404EdDn1592?@=<?c/4
Ac`i148i>0@m=SH4>cHf13Pe=@@n>SX3A40o14M5A@A9B4T4AdY<1459C@@jADX3<ci412`h?P@V=Cd4
8cLo12<kA@@T?d/4:DQE0bE8EP@TBET4;U9P13EJJ0@hGVd4@6Ed0dAZN@A8L7l4BWB514iiR`ABOXl4
E8:D15b:W0=`Vj/4PZbk18Zea0B:/;h4RZbh18ZW/P>9Xj/4R9fU18JHWPB4TYP4PXfA1827RPAmPH<E
oooo000Doooo171`L0ATI6D4FEQH14i<C0A2?d03=C8b12PU9@@J5QH420@410D000@A2PP3510?11TF
5P@^9b@4BCXc161<@`AJBD84EDE00di0?@A9?S`4ACdl140j>P@m>CT4?3Tj13hl?@=2@444ATI714Q:
B`A5BTd4@4U=13Y5BP<b?TD4:cPo12Dg?`@S>4048ca612E1C0@XB5@3:4UG12M;FP@eEV@4>5aZ13aQ
K`A6JGL3BFil14YcP`A9MHH4BgR:14ilSPA>Oi84G8^M0g:L[0B6[;/4S;O518fc`0B=[[X4SJZd0hbU
[@B:WjL4R9ZP18JDV@B3SY84PHR;17j1PaGoool001Coool4L71`16ATI@AIF5P4CTa<148o@0<e<S84
:2DU11XF5P@810@41@00114:20<D40l46AHF12hW90A9>S<4H4a315Y9@PAEAD03CT0m14Tn?0A5?C`4
@3Xj13di>@@l>CX4?S`m0d90@@A6ATL4B4Y;14E:C@A0BDd4>TE:0c8nA@@[>3l49CLo12<h@0@S?4H4
9D5<12Q8E0<XBEL49d]J13EFI0@hG6X4?65_14IYM`=9KW`4BW>314UeQPA;N8X4CWb>14ioTPALRid3
LYb/18J/^`B<]lD4SK?018f^^PB=Z[@3S:F]18ZOY`B8VZ04QYBI18>>TPB1R8/4OX635Oooo`005?oo
o`A`L704I6AU15UHF0A>C4`4@Sm00cDb<P@X9BD46QHF10P410@500044@X80a@@3`@I5QH4;RLT14Tj
<`APC4<4FTU215E5@0=>@3d4BChl14Dm?0A0>SX4?CTi13`i>P@n?3d3@T1114I6A`A8BT/4ADY=1419
C@@jADX3<Si512/h?`@U=cl48cQ012<lAP@U@D`4:4QD0bQ9E`@WBeX4=EIT13QLJP@lHFl4AVUg0dU^
O0A:Lh<4BGF614]hRPA>O8h4CWnB15b;W@=bW:`4QZbk18bga@B=/l04SJjj18fZ]0><YJd4RYnW18RJ
X0B6U9T4PhjB1868R`AnPH<Eoooo000Doooo171`L0ATI6D4FEQH14i<C0A2?d03=C8b12PU9@@J5QH4
20@410D000@A2PP3510?11TF5P@^9b@4BCXc161<@`AJBD84EDE00di0?@A9?S`4ACdl140j>P@m>CT4
?3Tj13hl?@=2@444ATI714Q:B`A5BTd4@4U=13Y5BP<b?TD4:cPo12Dg?`@S>4048ca612E1C0@XB5@3
:4UG12M;FP@eEV@4>5aZ13aQK`A6JGL3BFil14YcP`A9MHH4BgR:14ilSPA>Oi84G8^M0g:L[0B6[;/4
S;O518fc`0B=[[X4SJZd0hbU[@B:WjL4R9ZP18JDV@B3SY84PHR;17j1PaGoool001Coool4Kg1`16AT
I0AHEeP4C4];13ln?P<b<304928R11@B4P@2004420H6110=30<J5aD48QhM13T^:PA??cP4I4m615i<
A@AHBD@3DTE214a3@0A6?ch4@Sdm13hk>`@l>S`4?Cdn0d11@`A3ADL4A4Q:14A;CP@oBDd4>DA:0c4n
A0@Z>D049CQ0128g@@@R>dH4945=12M7E0<XBUP4;51N13UIIP@lGf`4@FAb14U/NP=9Kgh4Ag:314Md
QPA8MhX4BGZ=14YmT@ANS9l3MYj^18V^_0B@^/P4TKK2196a_@B@[KH3SjN`18fQZ@B;Vj84R9FJ18F?
T`B2R8/4OX:45Oooo`005?ooo`A_L704I6AT15QGF0A<Bd/4?chn0c8`<0@T8R84518B10800@@81PH4
40d<0aXG5@@R7Qd4>BhZ14lo>0ATCdH4GTa515Q9A0=BAD84C4=014Ho?PA2?Cd4?S/k13`j?0@m?Ch3
@45314=5A`A4B4X4A4]>13m9C@@iA4X3<Ci412Xi@0@U>4048SM1128kAP@T@Dd49dMD0bQ:F0@/D5h4
>EUV13aOK0A1I784BFaj0dU_OPA7LX<4AgB614QgRPA9NXd4BWfA15j<W`=fWZh4RJjl192jb0BA]/84
TK6m192]]P>?Yk04SJ6Y18^KXPB8UIX4QHnC18:8R`AnPX@Eoooo000Doooo16m`L0ATI6@4F5MH14a;
B`@o?Sh3<S0`12@R8P@D4Q840P0110P61P@@3@`36QLE128N7@@i;RX4Cclh16A?APANC4D4F4U40e95
@PA<@d04ASln148m?@@n>c/4?3Xl13dm?P=0@D<4@dE714A8BPA4Bdh4?dU=13U4BP<a?T@4:SU012Dh
@0@R=d448S]612A1C@@WAe@3:4YH12a@GP@iFFH4?5m/145TLPA9K7X3BFmn14MbP`A7M8H4B7N:14Uj
S@A:OI44GXbO0gJN[PB9[[`4T;[8196f`PBA/Kd4T:ff0hnW/0B=XJT4Ri^R18REVPB5Si<4PXR;17j2
Q1Goool001Coool4Kfm`16=SI0AFEUL4BTU:13dl?@<_;Rl48B0Q114@4@@000441`L7110?3`<L6QP4
:bDR13ld;`AD@cd4IE59165@B@AKCDP3EDY71517A@A;AD@4Ad=314=2@`A5@d@4ADE50dM8B@A7BT/4
Ada>14E=D0@nB4d4=d=90c0mA0@Z>T849CQ2128h@`@P>TH48Cm<12E6D`<XBUP4;E1N13=GI@@hGF/4
?VAb14=YN@=3K7d4@fn214=bQ@A4M8P4@gN;14MlT@APSZ03O::a18V^_0BC_<X4UKW519Je`0BE/;T3
TjZb192TZ`B=WJ<4RYNL18J@U0B3RH`4Oh:45Oooo`005?ooo`A_Kg04Hf=T15IFE`A:BDX4?C`m0bl^
;`@Q82444A0A10000@@71`L440l?0a`J60@[9B84?c@_15A3?@AUDDT4HE1915]=B0=EBTL4D4M514]5
A0A7@d<4@d9314E3A0A5ADD3AdQ914M:B`A7C4h4ADe@13i8C@@g@dT3<3e412Xj@P@U>4848SQ3120j
AP@Q?d`49DIC0bQ:F0@]D5h4<eMU13QMJ`@nI784@fUi0d=/O@A3Kh84@g:514AdR0A3Mh/4AgbA162>
X0=lX[44RJjl19>lbPBE^LD4U[G019F`^@>CZ[84T:B[18fMX`B:Ui`4QY2D18>9S0AoPX@Eoooo000D
oooo16m_L0ASHf@4EUIG14Y9BP@m?3d3;bh_124P8@@A4144000110L71`@@3`l371XH12/U8P@o=2l4
E4<m16EAB@AQD4T4Fde80eE:A`A@AdD4BdE414M3@`A3@T<4AD=414E5A@=7B4T4AdY;14M<CPA5CE04
?TQ=13M3B@<`?D@4:SY212Dh@P@R>4<483Y6124oC0@UAU<3:4YH12e@GP@cEfD4>5e[13iTLPA3JGT3
@fam14=_PPA3LXD4A7B814=gR`A7O944H8jP0gbR/@B9[[`4Tkc:19Fia@BF]L04UK2i0i>Z/PB@Y:/4
SIfS18ZGW0B6T9@4PhV<17n2Q1Goool001Coool4Kfm`16=SI0AFEUL4BTU:13dl?@<_;Rl48B0Q114@
4@@000441`L7110?3`<L6QP4:bDR13ld;`AD@cd4IE59165@B@AKCDP3EDY71517A@A;AD@4Ad=314=2
@`A5@d@4ADE50dM8B@A7BT/4Ada>14E=D0@nB4d4=d=90c0mA0@Z>T849CQ2128h@`@P>TH48Cm<12E6
D`<XBUP4;E1N13=GI@@hGF/4?VAb14=YN@=3K7d4@fn214=bQ@A4M8P4@gN;14MlT@APSZ03O::a18V^
_0BC_<X4UKW519Je`0BE/;T3TjZb192TZ`B=WJ<4RYNL18J@U0B3RH`4Oh:45Oooo`005?ooo`A^Kg04
HV9S15IEEPA9BDX4>c/l0bh^;`@O7b04410A10010P@720T44a8B0b0M70@_:2H4@cLb15M6@0AVDTX4
I5=<15i@C0=HCD/4Dd]914i9B0A;B4P4BDU914Y:BPA8BT/3B4]=14M;CPA6C4l4@DY=13]5B`@d@4H3
;ca412Tk@`@U>T<48cY5124mB0@Q@4d48dEC0bE8E`@[Ceh4<5EU13AKJP@hH704?6Ef0ceYN`@oK7l4
@724141bQ`@mLhT4B7fC16>@X`=mX[44QZbk196ia`BK_LT4W;W419Zd_@>H[KD4U:N]192PY@B<VId4
R96E18B:S@AoPh@Eoooo000Doooo16i_L0ARHV<4EUEF14U9BP@k>c`3;Rh_11lO80@@4144004210L8
2@@C4Q8381dL12lX9PA3=c84EdI016IBBPATDd`4GU1<0eQ=B`ACBdT4CTU814]8B0A9BDT4BTY:14Q:
B`=8Bdd4Ad]>14I<C`A1BTd4>dE;13A0AP<_?4@4:C]312Dj@`@S>TD48Ce81250C@@SAE<39DQG12]?
GP@`EFD4=5]Z13QPL0@lIGH3?FUk13m/O`A0L8@4@7:713ecR@A8OI<4Hi2S0gfR/@B6[;/4TKW719^m
b@BL^L@4V[Bm0iR]]@BDYjd4T:2U18bIW@B8TID4Q8Z=17n3Q1Goool001Coool4KVm`169RH`AFEEH4
BDU:13/k?0<^;Rl47alP110@4@@00@841`P911<B4P<P7A`4;bPV14<g<PAGAT04IU9:16ACC0AND4`3
F4e;15=;B@A>BDP4BdQ814U9B@A:BTX4B4Y;0dQ;C@A7Bdh4ATa?145:C@@kAD/4=4160bllA0@Y>d<4
9CY312<jA@@Q?DP48D1=12=5D`<UB5L4:dmN131EI@@dFfX4>61`13aUMP<mJG/4?fao141`Q0A0LXL4
?G>914QmT`AST:<3OJ:a18J/^`BA^LL4Vkg919bia0BJ];d3V:fe19BW[@B@X:D4S9VM18RAU@B4RXd4
Oh>45Oooo`005?ooo`A^Kg04HV9S15IEEPA9BDX4>c/l0bh^;`@O7b04410A10010P@720T44a8B0b0M
70@_:2H4@cLb15M6@0AVDTX4I5=<15i@C0=HCD/4Dd]914i9B0A;B4P4BDU914Y:BPA8BT/3B4]=14M;
CPA6C4l4@DY=13]5B`@d@4H3;ca412Tk@`@U>T<48cY5124mB0@Q@4d48dEC0bE8E`@[Ceh4<5EU13AK
JP@hH704?6Ef0ceYN`@oK7l4@724141bQ`@mLhT4B7fC16>@X`=mX[44QZbk196ia`BK_LT4W;W419Zd
_@>H[KD4U:N]192PY@B<VId4R96E18B:S@AoPh@Eoooo000Doooo16i_L0ARHV<4EEEF14Q9BP@j>c`3
;Bd_11hO8@@?4A84008410P:2`@D51@38alN138[:0A7>SD4F4Q116MCB`AVEDl4HE=?0e]@CPAECTd4
DDa<14e;B`A:BT/4B4U;14I9BP=5BD/4@dQ:1416BP@lA4T4>497138nA0<]>d<4:CY312HjA@@T?4L4
8ci:1291C`@VAe@3:4]I12]@G`@/E6<4<5QY13=MK`@gHW@3>VIi13e/P0@nKh<4>g2513YbR@A;P9D4
I9:T0gVP/0B8[K`4U[c91:S7dPBT_lT4XKS10ifa^0BHZ[04U::W18nJW`B:TiH4QH^=1823QAGoool0
01Coool4KVm`169RH`AEEEH4B4U:13Xk?0<];Bl47QlQ10lA4P@00P@420X;11@D50<S7ah4<R/X14Lj
=@AHB444Ie=;16IEC`AQDdl3Fe1>15E>C@AAC4`4CD];14Y:B`A8BD/4ATU:0dE9B`A3B4X4@4I:13a4
B@@h@TL4<Si40bdk@`@Y>T<49SY512@lA`@S?TX48T5?12I7E0<XBeT4:e1O12aDH`@`F6T4<ee_13MR
M0<jIWT4?Fb013i_P`@kL8D4>W:914^0U@ATTZ@3NJ2`18R]_0BF_<T4Z<OB1:Bob@BQ^<43WK6h19RZ
/0BDXZL4SiZO18ZCUPB5Rhd4P8>55Oooo`005?ooo`A^Kg04HV9S15EEEPA8BDX4>S/l0bd];`@N7b44
3a4B100210@82P/451@D0b<O7P@b:bP4AcXe15Q8@@AWDd/4IUE?165CC`=KD4h4EDi=155<C0A=Bd/4
BTY;14Q9B`A6BDX3ADU;14=8BPA0ATX4?4A913Q2A`@b?T@3;C]312Tj@`@V>TD493a712<nBP@R@Dl4
9TMD0bQ;F@@[D5l4;5AS131HJ@@cGFl4=f9d0cYVN@@mK804?Vn313]`Q@@jLXT4Bh2E16BBY0=iX;04
R:fl19Jlb@BXam84Y;o91:6h`@>M/KP4V:Z`19BRY`B?VYl4RY>F18F;S@B0PhDEoooo000Doooo16i_
L0ARHV<4EEEF14Q9BP@j>c`3;Bd_11hO8@@?4A84008410P:2`@D51@38alN138[:0A7>SD4F4Q116MC
B`AVEDl4HE=?0e]@CPAECTd4DDa<14e;B`A:BT/4B4U;14I9BP=5BD/4@dQ:1416BP@lA4T4>497138n
A0<]>d<4:CY312HjA@@T?4L48ci:1291C`@VAe@3:4]I12]@G`@/E6<4<5QY13=MK`@gHW@3>VIi13e/
P0@nKh<4>g2513YbR@A;P9D4I9:T0gVP/0B8[K`4U[c91:S7dPBT_lT4XKS10ifa^0BHZ[04U::W18nJ
W`B:TiH4QH^=1823QAGoool001Coool4KVm`165RH`ADEEH4AdQ913Xk?0</;Rl47R0Q10lB4`@10`D4
2P`=11@E5@<T81l4=2dZ14Lk=`AGB484IE9;16IFD0AREU43GE=@15M@C`ABCTh4CTa=14Y:C0A7BD/4
ADM90d96B@@oA4L4?49613Q0A@@d?T@4;ca30b/i@P@X>T<49CY512@lB0@R?T/48T5>12A5D`<VBUP4
:e1O12mFI@@cFf/4=Em`13UTMP<jJ7/4>f^013U]PP@gKhD4>W>:14n3U`AUU:H3NZ>b18jb`0BO`Ld4
/<gF1:c5cPBW_LD3X[Fl19f]/`BGYJX4TYbP18bDU`B6S8h4P8>55Oooo`005?ooo`A^Kg04HF9S15AE
EPA7B4T4>S/l0b`^;`@N82443a8C10431@@:30d451DE0b@P7`@d;BX4Ac/g15M8@PAUDT/4IUI@169F
D@=MDe04Ee1?159>CPA>C4d4BTY<14M9B`A5AdT3@TI913m4A`@l@TH4>41513@nA0@_?4<3:cU212Pj
@`@U>TD493a8128nB`@R@Dh494EC0bI:F0@[D5l4;eIU13=KJ`@eGg04>FAf0cYXN`@kJh04>Ff213M_
Q@@jLhX4Ch>G16FDYP=jXk84S[;019o1c@B`cMH4[<G>1:Nma@>R]K`4WJfc19NUZPBBW:04S9BG18J<
SPB0PhDEoooo000Doooo16i_L0AQHV<4E5EF14M8B@@j>c`3;2h_11hP8@@?4Q<40@<510X<3@@D5AD3
920O13@]:PA7>cL4EdQ216EBB`AVEU04HUIA0eeCD0AGD4l4DTi>14i<C@A:BT`4AdU;14E7B@=2ATT4
?dA713a2AP@h@4D4=3i412ll@`<[>D84:3Y312DjA@@T?4P48Si;1291CP@TAE<39TYH12]@G`@_EVD4
<e][13EOL0@iI7H3>VQk13][P0@iKH84=fn513YcRPA?PiL4IIBV0gZS/PB>//04Wl7=1;3=ePB/aLh4
Ykg50j:e_0BM[K<4UjFZ19:LX0B<U9L4QXb>1823QAGoool001Coool4KVm`165RH`ADEEH4AdQ913Xk
?0</;Rl47R0Q10lB4`@10`D42P`=11@E5@<T81l4=2dZ14Lk=`AGB484IE9;16IFD0AREU43GE=@15M@
C`ABCTh4CTa=14Y:C0A7BD/4ADM90d96B@@oA4L4?49613Q0A@@d?T@4;ca30b/i@P@X>T<49CY512@l
B0@R?T/48T5>12A5D`<VBUP4:e1O12mFI@@cFf/4=Em`13UTMP<jJ7/4>f^013U]PP@gKhD4>W>:14n3
U`AUU:H3NZ>b18jb`0BO`Ld4/<gF1:c5cPBW_LD3X[Fl19f]/`BGYJX4TYbP18bDU`B6S8h4P8>55Ooo
o`005?ooo`A^Kg04HF9S15AEE`A7B4X4>S/m0b`^<0@N8284418D10441P@:3@h45AHF0b@Q80@d;B/4
ACXg15A6@@AQDDX4IUIA16AGD`=NEE84F59A15=@D0A>CDh4BTY<14I8BPA2ATP3?d=613a1A0@h?d<4
=3e2130k@@@/>D03:3M012Hi@`@T>TD48c]7124mBP@Q@4h48TAB0bE9F0@XCUh4;EAT131IJP@dGg44
=V=f0cIVNP@fJGd4=F^013A^Q0@lMH`4DXJJ16VGZ@=nY[H4U;K31:S5c`BgcmT4]L_C1:o2b@>X^Kl4
X[2e19^W[0BDWZ84SYFH18N=S`B1Q8DEoooo000Doooo16i_L0AQHV<4E5EG14M8BP@j>cd3;2h`11hP
8P@@4Q@40@@610X=3P@E5QH3924P13@]:`A5>SL4E4I1165ABPAVEU44I5MC0eiEDPAHDU44De1@14i=
CPA:BT`4ATQ:1496B0<o@dH4?45413Po@`@d?D84<3]112`i@0<X=d049SU312@jA@@S>dL48Ce:1250
CP@RA5839DUH12Q>GP@]E6@4<5UZ13AOL@@fHgH3=VIj13IYO@@eJh04=6j413aeS0ABQYX4JINY0gjV
]PBD]/<4Z<G?1;O?f@Bebm<4[l;90jRi_`BR/;D4VjN/19BNXPB>UIP4Qhf?1864QAGoool001Coool4
KVm`165RH`ADEEL4AdQ:13Xk?@</;S047R0R110B50@110H42Pd>11DF5P<T8B04=2d[14Dj=`ADAT44
HE5:16IFD@ATEe<3GUEB15QBD@ACD504CTe>14Y:C0A6B4X4@TI80cm3AP@l@D@4>3m313@m@P@`>d44
;3U00bPg@0@V>D<493Y512<kA`@Q?DX48D1>1294DP<UBEP4:4iN12eDI0@`FFX4=5ma13ISMP<fIWX4
=VUm13E[P0@dKX@4?7F<15:6VPAYUjT3OZJf19Bf``BXaLl4]loI1;G;d`B_`/T3Z;Vo1::`]@BKYj`4
U9jR18jEV0B7SHl4PHB55Oooo`005?ooo`A^Kg04HF9S15AFE`A7BDX4>S`m0b`_<0@N8B<441<F1085
20@;3a445QLI0b@R8@@b;B/4@STf1515@0ANCdX4IEI@16EIE@=PEU@4FE=C15=AD@A>CTl4BDY<14A7
BPA0A4L3?45413Pn@P@e?444<CXo12dh?`@Y=Sh39SI012@g@P@R>D@48CY7120mBP@O@4h484=B0b98
F0@UCEh4:59S12]FJ0@]Ffh4;emc0c1SN0@`IW/4<6Uo139]Q0A0NHl4EhZN16jK[0>4Z[T4V[[61;39
d`Boe=`4`=?J1;O8cP>^_L<4Y[>h19jY[PBGX:<4T9NI18V=T0B2Q8HEoooo000Doooo16i_L0AQHV<4
E5IG14M9BP@j?3d3;2l`11hQ8`@@4aH40PD810/?4@@F5aT3928Q138]:`A2>CH4D4E015i?BPAUEU04
IEUE0f1FE0AIDe<4De5A14i>C`A9BT`4A4M:1414A`<l@D@4>3i213Dl@@@a>Sl4;CPo12Tf?P<V=T04
93M2128iA0@Q>TL483e:11m0CP@P@e838TQH12E=GP@XDV<4:eIX12eKKP@_Gg<3<6=h131VN`@`JGl4
<Vf4141iS`AGRYh4KY^/0hBZ^@BJ^/H4/<WC1;oDg0C0dmX4]lS>0jjm``BV/kP4WZV^19NPX`B@UiT4
RHf@18:4QQGoool001Coool4KVm`165RH`ADEUL4AdU:13Xl?@</;c047R4S110C5P@21@P42`lA11HG
6@<T8R44<Rd[148i=PA@AD04GTm:16EFD0AUFED3H5ID15UCD`ACDE44CTi?14U:C0A4AdX4@4A70ca1
A0@h?T84=Ca1134j?`@]>3l4:CHn0bHf@0@T=d848SU4124jA`@P?DX47d1>1213DP<RB5P49DeN12QB
H`@[EVP4;E]^12mOL`<`HgP4<6Ik131YO`@bKH@4@7V?15N:WPA^Vj`3Q:Zi19ZjaPB`bM<4_mCL1<3C
fPBgb<h3[[g31:Jc^0BNZJh4Uj2S192GV@B9SI04PXB65Oooo`005?ooo`A^Kg04HF9S15AFE`A7BDX4
>S`m0b`_<0@N8B<441<F108520@;3a445QLI0b@R8@@b;B/4@STf1515@0ANCdX4IEI@16EIE@=PEU@4
FE=C15=AD@A>CTl4BDY<14A7BPA0A4L3?45413Pn@P@e?444<CXo12dh?`@Y=Sh39SI012@g@P@R>D@4
8CY7120mBP@O@4h484=B0b98F0@UCEh4:59S12]FJ0@]Ffh4;emc0c1SN0@`IW/4<6Uo139]Q0A0NHl4
EhZN16jK[0>4Z[T4V[[61;39d`Boe=`4`=?J1;O8cP>^_L<4Y[>h19jY[PBGX:<4T9NI18V=T0B2Q8HE
oooo000Doooo16i_L0AQHf@4EEIG14Q9B`@j?Ch3;C0b11lR90@A5AL40`L:10d@4`@G6AX3928S134]
;0A0>3H4CTA015a>BPASEE04IeYF0f1HE@AIE5@4De5A14e=C`A7BD`4@TI913i3AP<i?d<4=Ca1134j
?`@]=cd4:CDm12Hd?@<T=Cl48SI1120hA0@O>TL47Sa:11hoCP@N@e8384MH12=<G@@UD6849eAW12QI
K0@ZG743;65f12eTNP@]J7l4=G2714QoU0ANSj84MJ2`0hb`_@BT`<`4^]3H1<WKhPC:fn44_/gC0kC1
aPBZ][X4XZb_19VQY@BBV9X4RXj@18:5QQGoool001Coool4KVm`165SI0AEEUL4B4U;13Xm?P<]<384
7b8T114E5`@31`X43A0C11LI6P<T8R<4<Bd/140h=PA>A404G4i:16=ED0AWFUH3H5QE15UDE0ACDE44
CDe?14M9C0A2ATT4?T=60cTo@`@e?444<CXo12dg?@@Y=Cd49S@m0b@e?`@R=T4483Q411ljA`@N?4X4
7Sm>11i3DP<PAeP48daM12E@HP@WE6L4:5U/12YLL@</HGH4;FAj12eXO`@eL8L4B7nD15j?XPAeX;03
S;2m1:C0c0Bjd=P4bM_R1<[Kh@BncM<3]<761:Zf^PBR[:l4VJ6U19:HVPB:SY04PXF65Oooo`005?oo
o`A^Kg04HF=T15EFE`A8BD/4>Sdn0bd`<P@O8R@44ADG10<72P@=41<45aTJ0b@R8`@a;B`4@3Pf14i4
@0ALCTX4HeE@16MJEP=PF5D4FEAD15=AD@A=CDl4AdU<1496B@@n@dH3>Cm313Dl@@@a>Sl4;CLm12Te
?@@V=3d393Do128f@@@P>4@47cY711hlBP@N?dh47T=B0b17F0@SC5d49E1R12MDI`@XFF`4:Uaa0baQ
MP@]I7X4;FQo13E`Q`A8Oi@4GXnR17FP/0></;d4Y<3<1;[@f0C9fn84b]_Q1;k=d`>d`LH4Z[Jj1::/
[`BIXJD4TYRJ18Z>T0B2QHHEoooo000Doooo16i_L0AQHf@4EEIG14Q9B`@j?Ch3;C0b11lR90@A5AL4
0`L:10d@4`@G6AX3928S134];0A0>3H4CTA015a>BPASEE04IeYF0f1HE@AIE5@4De5A14e=C`A7BD`4
@TI913i3AP<i?d<4=Ca1134j?`@]=cd4:CDm12Hd?@<T=Cl48SI1120hA0@O>TL47Sa:11hoCP@N@e83
84MH12=<G@@UD6849eAW12QIK0@ZG743;65f12eTNP@]J7l4=G2714QoU0ANSj84MJ2`0hb`_@BT`<`4
^]3H1<WKhPC:fn44_/gC0kC1aPBZ][X4XZb_19VQY@BBV9X4RXj@18:5QQGoool001Coool4KVm`169S
I0AEEeP4B4Y<13/n@0<^<C<482@V118F6@@42@`43A8E11PK70<S8b@4;b`/13`g=@A<@d04FDe8169D
C`AVFED3H5QF15QEE0ABD544Bda>14E9B`A0ADP4>d550cHm@@@b>Sl4;SLm12Xe>`@V<c/48c8l0b4c
?P@O=D047SM411diA`@M>dX473m>11e2D`<NAUL484YL125?H@@SDfH49EI[12IKL0<XGgD4:F=j12iY
P0@kM8/4ChBI16JEY`AoY[D3UkO31:o8dPC5emh4enK[1=;Pi0C4dMD3^<C81:jh_0BT[K44W:>V19>I
V`B;Si44PhF65Oooo`005?ooo`A^Kg04HV=T15EGF0A8BT`4>ci00bha<`@P92H44QHI10@930@=4QD4
61/L0b<S90@_;2`4?3Le14a3@0AICDP4HUA?16IIE@=PF5H4F5ED159@D@A;C4h4ADU;1415B0@k@DD3
=Se1138j?`@^=cd4:SDk12Hc>`@S<S`38C<n11le@0@N=d@47CU711dkBP@L?dh47D9C0ai6E`@PBU`4
8DmQ12=CIP@UEV/49U]`0bQOM@@YHgX4;VV013]dR`A?Q9T4IYFW17nV]@>G]l<4[lSB1<GGgPCGi^/4
d^3T1<CAe@>ha<P4[[Rl1:B]/@BLXjH4TiVK18^?T@B3QHHEoooo000Doooo16i_L0ARHf@4EEMH14Q:
C0@k?T03;S4c120T9P@B5QT410T<10dB5@@H6a`38b<T12l/;0@l=cD4C4=015U=B0ARE4l4IUUE0f1H
EPAHEE@4DU1A14]<CPA5BD/4@4E813]1A@<f?D44<SXo12hg?@@Z=C/49S<k12<b?0<Q<ch47cE011hg
A0@M>DL47C]:11`oCP@M@U<37TIG121:G0@QCf448e=V12EFJ`@VFg03:5me12USNP@^JH04>gB;14n4
V@AVUJL4OjJe0iNg``B_b=84aMON1=OVj`CBh>@4a=7E0kS4b0B^^;`4Y:fa19bSYPBCVI/4RhnA18>5
QQGoool001Coool4KVm`169SI0AEEeP4B4Y<13/n@0<^<C<482@V118F6@@42@`43A8E11PK70<S8b@4
;b`/13`g=@A<@d04FDe8169DC`AVFED3H5QF15QEE0ABD544Bda>14E9B`A0ADP4>d550cHm@@@b>Sl4
;SLm12Xe>`@V<c/48c8l0b4c?P@O=D047SM411diA`@M>dX473m>11e2D`<NAUL484YL125?H@@SDfH4
9EI[12IKL0<XGgD4:F=j12iYP0@kM8/4ChBI16JEY`AoY[D3UkO31:o8dPC5emh4enK[1=;Pi0C4dMD3
^<C81:jh_0BT[K44W:>V19>IV`B;Si44PhF65Oooo`005?ooo`A^Kg04HVAU15IHF@A9Bdd4?3m10blb
=@@Q9BP44aPK10D;3P@?4aH46A`M0b<S90@]:b`4>SLf14U1?`ADBdL4GU9?165FE0=NF5H4EeAD151@
D@A9C4h4@dM;13e3A`@h?d<3<c]012hg?0@Z=C/49S8i12<a>@@P<3X37S8m11dd@0@L=T@46cU711/k
B`@K?dl46d9C0aa5E`@NBU`47diQ125BIP@REV/48eY`0bENM@@YI7/4<Vf414=kT0AHRih4LIb]18V]
^`>Q_lX4^LoH1<oNi@COk?04dmoS1<OBeP>ka/T4/KZm1:N^/@BMY:H4U9VK18b?T@B3QHHEoooo000D
oooo16i_L0ARI6D4EUQI14U;C@@l?d43;c8e124U:0@C61/41@/>10lC5P@I71d38b<T12d[;0@j=cH4
BD4o15A;A`ANDTl4HEID0eiHEPAGE5@4D51A14U<CPA3Ad/4?D=713Po@`<c>d04;SLl12Xe>`@V<ST4
8c4i120`>P<N<Sd47CA011`fA0@K>DL46c];11/oC`@K@U<374EG11i:G0@OCV448E9V129FJ`@SFW03
9Eie12UTN`@bKH@4@g^@15R;WPAaW:d4RJfk0j6obPBicmP4cmkU1=o/l0CCgn<4am;F0k_6b@Ba^[d4
Yjja19fTYPBDVI/4S8nA18>5QQGoool001Coool4KVm`169TI@AFF5T4BD]=13`o@@<_<SD48BDX11<H
6`@52`h43a<F11TL7@<S8b@4;B//13Xg=PA9@Cl4E4]715iBC`AQEU@3GUQF15MDE0A@D544BDa>14=7
B`@m@dL4>3m30c<k@0@^=c`4:SDk12Hb>@@S<CT4830j0ahb?@@M=40473I411/iA`@K>d/46cm?11]2
D`<LAEL47TYL11m>H@@QDVH48UI[12=JL0<UGWD4:FAk139]Q0A3Ni04F8^N176L[@B9[K/3XKo:1;W?
f0C?g^D4gnc`1=?Oh`C7d]H3^lK91;6j_@BW[[44WJBV19BIV`B<Si44PhF65Oooo`005?ooo`A^Kg04
HVAU15IHF@A9Bdd4?3m10blb=@@Q9BP44aPK10D;3P@?4aH46A`M0b<S90@]:b`4>SLf14U1?`ADBdL4
GU9?165FE0=NF5H4EeAD151@D@A9C4h4@dM;13e3A`@h?d<3<c]012hg?0@Z=C/49S8i12<a>@@P<3X3
7S8m11dd@0@L=T@46cU711/kB`@K?dl46d9C0aa5E`@NBU`47diQ125BIP@REV/48eY`0bENM@@YI7/4
<Vf414=kT0AHRih4LIb]18V]^`>Q_lX4^LoH1<oNi@COk?04dmoS1<OBeP>ka/T4/KZm1:N^/@BMY:H4
U9VK18b?T@B3QHHEoooo000Doooo16m`L@ASI6D4EUQJ14Y=CP@m@D<3<3@g12<W:P@E6Qh41Pd@114E
60@I7Al38b@V12`/;@@h=SD4A3ln14m8APAID4d4Fe=A0eYEE0AEDe<4CTi@14M:C@A0ADT4>T5513Dl
@@<_>3h4:c@k12Hb>@@R<3P482li11d_>P<K<C`46c=011Xf@`@J>DP46Sa;11ToC`@J@U<36dEH11a:
G0@MCF447U5V11mEJ`@QFW039Eme12]VOP@gLXP4C86F16>BY@AlY;@4TkC20j_5d0C5eml4fnK[1>G_
l`CFh>@4bM?F0kk6bPBc^[d4Z:nb19nTY`BEVY`4S8nA18>5QQGoool001Coool4Kg1a16=TI@AFF5X4
BTe>13e1@`<`=3L48bLZ11DJ7P@63A044ADH11TM7`<S92H4;2`]13Pf=@A4?ch4CdQ615U@C@AKDe43
FUED15ECD`A>CU04AdY=1415B@@j@DD4=Ca10blh?P@[=3/49S8i128`>0@P;cT47Blj0a/a?0@K<d04
6SI311XiB0@J?4/46Cm?11Y2D`<KAEP474YL11e=H@@NDFH47eE[125JL0<UGgD4:fIn13MbR0A<PIH4
Hi:U17bT]0BC]<83ZlG@1<GGg`CKi^/4iNoc1=KPi0C9dmH3_/K:1;>j_@BX[k84WjBW19FJW0B<Si44
PhF65Oooo`005?ooo`A_L744HfAU15IHFPA:CDh4?D530c0d=`@S9bX45AXN10H=40@A5AP46AdO0b<T
9P@/;2d4>3He14@o?PA?B4H4FE1=15]CD@=JEE@4EE=C14i>D0A7BTd4@4E913Y1A@@e?443;cPn12/d
>`@V<ST48S0h120_>@@M;cX36c4l11/c@0@J=T<46SU811XlB`@I?dl46T9C0a]5F0@LBU`47DeQ11iA
IP@OEF/48EY`0bEOM@@[IWh4=g:814b1UPASTZD4O:Bd19>d`P>[aM04aMOO1=_Vj`CUko<4e^3T1<WC
eP>na/X4/kZm1:R_/PBOY:L4UIZL18b?T@B3QHHEoooo000Doooo16m`L@ASIFH4EeYK14]>D0@o@TD3
<SHi12DZ;@@H7B442A0C118G6P@J7b438bHW12//;@@e=3@4@3dm14Y5A0AAC4X4E4i=0eMBDPABDU84
Bde?14A8B`@m@dL4=ci3134j@0<[=S`49c<j128`>0@O;SL472dh11X]>@<I<3d46C=111TfA0@I>DP4
63]<11PoD0@I@U@36TIH11Y:G@@LCF847E9V11eFJ`@QFW439V5h135[PPA2NHh4F8ZM172K[0B8[;X4
X;g80kW>e`CChNH4jO;f1>O`l`CHhN@4bm?F0ko7b@Bd^kd4ZZnb1:2TY`BFVY`4SI2A18B5QQGoool0
01Coool4Kg1a16=UIPAGFU/4Bdi@13m2A@<b=ST49BX]11PM8@@941<44QLJ11XO8@<S9RL4:b`]13Dd
=0A0?Cd4BTE4155<BPADCTd3Ee9B159BDPA;CDl4A4Q;13e3A`@g?T<4<CY00b/f?0@W<cX48S0h11l^
=`@L;CP46Rdi0aT`?@@I<d446CI411TiB0@H>d`463m@11U2E0<JAUP46TYM11a=HP@MDVH47EI[125J
L@<VHGP4<F^2149iSPAHRYd4L9^/18R/^PBP_LP3^LkG1=?QiPCYl_H4io3c1=SQi0C;dmH3_lO91;Bk
_@BZ[k84X:BW19JJW0B=T944Q8F65Oooo`005?ooo`A_L744HfEV15MJF`A;CU04?d950c8f>@@U:Rd4
61dQ10T@4`@B5aX46QlQ0b<V9`@[;2d4=C@d140m?@A:AD@4DDa:15A>C@=GDU84DU9B14]=C`A4B4/4
?D=713Ln@`@a>T03:cHl12Lc>P@R<3P47bhg11`]>0@J;CT36C0m11Tc@@@I=T@46CU811PkC0@H?e04
6D9D0aY6F0@JBUd474eR11eBIP@MEV/48EYa0bIQN0@aJh84@WV>15R:W@A`Vj`4R:bj1:2mb0>ic]L4
dn7V1>WbmPCWl?<4f>7T1<_CeP>oalT4];^m1:Z_/PBPY:L4UYZL18f@T@B4QHHEoooo000Doooo16m`
L@ASIFH4EeYK14]>D0@o@TD3<SHi12DZ;@@H7B442A0C118G6P@J7b438bHW12//;@@e=3@4@3dm14Y5
A0AAC4X4E4i=0eMBDPABDU84Bde?14A8B`@m@dL4=ci3134j@0<[=S`49c<j128`>0@O;SL472dh11X]
>@<I<3d46C=111TfA0@I>DP463]<11PoD0@I@U@36TIH11Y:G@@LCF847E9V11eFJ`@QFW439V5h135[
PPA2NHh4F8ZM172K[0B8[;X4X;g80kW>e`CChNH4jO;f1>O`l`CHhN@4bm?F0ko7b@Bd^kd4ZZnb1:2T
Y`BFVY`4SI2A18B5QQGoool001Coool4Kg5b16AVI`AIFed4CE1B1455A`<e>C`4:2d`11/Q90@=51P4
4QTL11/P8`<S9RP4:B`]138c=@@l>c`4A49314Y7A`A>Bd/3DTm?14i?D0A7Bdd4@4E913U1AP@c?484
;3Po0bLd?0@R<CX47Rlh11X/=`@H;3L45bdj0aH`?@@G<d845cI511PiB@@G?4`45d1A11Q3E@<IAeX4
6T]N11]>H`@LDfP47UM]12=LL`<[IWd4>W>814f2UPAUTjD4OJBc19Bd`@B/aLl3a]ON1=kXk@C_moT4
i>c^1=SOhPC<dmD3`<K91;Fk_@BZ[k44X:BV19JJV`B=Si44Q8F65Oooo`005?ooo`A_LG84I6IW15UK
G@A=D584@DE70cDi?0@X;C046b4T10dD60@B6A`46b0S0b<V:0@Y;2d4<S<e13`k?0A4@T<4BTM714i;
B`=BCdl4CTm@14M;C@A0ADT4>D5613<l@P@/>3l39c@l128a>P@N;cP46R`g11P/=`@G;CX35S0m11Lc
@P@G=TD463U911LlC0@G@54464=E0aU7FP@JBeh46diS11aCJ0@NEfd48eac0b]VO@@jLhP4CH:F16FC
Y@AmY;<4U;C11:c5c`?6emh4g^S]1>ogn@CTk>h4f=oR1<cCe@?0a/T4]K^m1:Z_/@BPY:H4UYZK18f?
T@B4QHHEoooo000Doooo16maLPATIVL4FE]M14e@DPA1ADL3=CTl12P]<0@K8B@43A@H118I70@K82<3
8bHX12T/;@@b<cD4?3/l14A2@`A:AdL4CT];0e9?C`A>Ce04Ad]=1415B@@i@DH4<ca212`h?`<W=3`4
8S4j11h_>0@J;3L462`g11L]>P<F<3d45c=211LfA@@H>DT45ca<11M0D@@H@eD36DMJ11Y;GP@KCV<4
75=X11iGK@@SG7<3:fIm13YcR0A=PYH4II>U17fT/`BD]<44[<G?0lKGgPCNj>d4koOi1>C/kPCHgn84
c=?E0l36b@Be^kd4ZZna1:2TYPBFVY/4SHnA18B5QQGoool001Coool4Kg5b16AVI`AIFed4CE1B1455
A`<e>C`4:2d`11/Q90@=51P44QTL11/P8`<S9RP4:B`]138c=@@l>c`4A49314Y7A`A>Bd/3DTm?14i?
D0A7Bdd4@4E913U1AP@c?484;3Po0bLd?0@R<CX47Rlh11X/=`@H;3L45bdj0aH`?@@G<d845cI511Pi
B@@G?4`45d1A11Q3E@<IAeX46T]N11]>H`@LDfP47UM]12=LL`<[IWd4>W>814f2UPAUTjD4OJBc19Bd
`@B/aLl3a]ON1=kXk@C_moT4i>c^1=SOhPC<dmD3`<K91;Fk_@BZ[k44X:BV19JJV`B=Si44Q8F65Ooo
o`005?ooo`A`LG84IFMX15YLGPA?DU@4A4M:0cPl?`@/<C@47bDY114H70@D6al46b4T0b8W:P@X;2l4
;c8e13Pj>`A0@D84ATE614U8B@=;Bd`4BDa>14=8C0@l@TL4=Ci412hi@@@X=Sh38S8k11h_>@@J;CP4
5RXf11@Z=`@D;CX3530n11Hd@`@F=dL45cY:11LmCP@G@E8464AG0aQ8F`@JC6046e1U11eDJP@QFW04
:65h0cA]P`A7O904G8^N17>L[0B:[KX4X;g81;[>e`?DhNH4j?3b1?Cin`CUjnd4f=kP1<cAe0?0aLL4
]KZl1:Z_/0BPY:H4UiVK18f?T@B4QHHEoooo000Doooo171aLPAUIfP4FUaN14mBE0A4AdX3>3`o12`a
=0@O9BT44APL11@K7`@K8B@38RLZ12P/;`@_<SD4>3Xk1411@PA6ADH4BDQ90d];C0A9C4h4@dQ<13a2
A`@e?T@4;SU112Pf?P<R<S/47Rli11X]>0@F:SH452Xg11@]>P<D<3h45SA311HgA`@G>TX45ce>11M1
DP@HA5L364QK11Y<H0@KD6D47EAZ125JL0@XHGP3=6f314MlT0ALRih4Lib/18Z]^PBP_LP4^/kG0mCQ
iPCXl?84m?Wk1>G[k@CHg^04c=7D0l35a`Be^[`4ZZn`1:2TYPBGVI/4SHnA18B5QQGoool001Coool4
L75b16EWJ0AJG5h4Ce9D14A7BP<h?3l4;34d11lU:@@A61`451/O11/Q90<R9bX4:2`_12lb=@@h>S/4
@45214I5APA9B4T3Bd]<14U<CPA3B4`4?49713DnA0@^>D44:3Hn0b8b>`@N;cT46Rdh11HZ=P@D:SL4
52dj0a@`?P@F=4<45SM711LjBP@G?Dh45d5B11Q4E`<HB5/46TaP11]@I@@ME6X48EY`12QQN0<dKH<4
Agb@15b;WPAcW:`4RZfj1:2mb0Bjc]L3e>7V1>S`lPCdnO/4iN_]1=SNh0C<dM@3`<G71;Fj_0BZ[k04
X:BV19NIV`B=Si44Q8F65Oooo`005?ooo`A`LG84IFMX15YLGPA?DU@4A4M:0cPl?`@/<C@47bDY114H
70@D6al46b4T0b8W:P@X;2l4;c8e13Pj>`A0@D84ATE614U8B@=;Bd`4BDa>14=8C0@l@TL4=Ci412hi
@@@X=Sh38S8k11h_>@@J;CP45RXf11@Z=`@D;CX3530n11Hd@`@F=dL45cY:11LmCP@G@E8464AG0aQ8
F`@JC6046e1U11eDJP@QFW04:65h0cA]P`A7O904G8^N17>L[0B:[KX4X;g81;[>e`?DhNH4j?3b1?Ci
n`CUjnd4f=kP1<cAe0?0aLL4]KZl1:Z_/0BPY:H4UiVK18f?T@B4QHHEoooo000Doooo171bL`AVJ6T4
G5iP155DEPA6BT`3>d12130e>0@T:Rh461lS11HM8@@K8RH38BL[12T^<0@^<SD4=STk13i0@PA2A4D4
ADI80dE8BPA4BD`4?TA913Q0AP@a?D@4:CM012<d?@<N<3/46Rhi11H/>0@B:SL43bTg114]>`<C<D04
5CE511HiB@@G>d`45cm@11Q2E0@IAUT36TYN11]>H`@NDfP48EQ]12QOM@@aJGl3@WN;15J6V@A[UJH4
PZJe19Vg`PB`am44b]WO0n7Zk@CdnO/4mOWk1>GZj`CGg=h4bm3B0ko4aPBd^KX4ZZj_1:2SY@BFVIX4
SHn@18B5QQGoool001Coool4L79c16IXJ@ALGV04DEAF14I:C0<k@484<3Dh12@Z;P@H7b<45QdQ11/R
9P<Q9b/4:Bh`12hb=@@f>C/4?T121494A@A5ATP3ADQ:14A9C0@nA4T4>416134mA0@Y=d048c@m0ah`
>`@J;ST45R`h118Z=`@?:CL44Bdk0a<a@0@E=DD45SU911LkC0@G?e04649D11U6F@<JBUh46diS11iC
J0@QF6d4:5me135YO`=2Mh/4EXJI16^EYPB2Y[D4VKO21;37d@C:fMl3hN[]1?Cin`CenO/4iN[[1=OL
gPC;d=83_lC61;Bi^PBZ[Zl4X:>U19JIVPB=Si04Q8F65Oooo`005?ooo`A`LW<4IVQY15aNH0AAE5H4
ATY<0c]0@P@`=CP492X^11PO8`@F7B446b8V0b4W:`@Y;S04;S8e13Hi>`@n@484@TA514E6B0=5B4X4
A4U<13i4B@@h@4H4<Ce412Tg@0@S=3d37S0k11X^>@@F;3P44RXg10lY=`@A;C/34c5011DeA@@F>DT4
5c]<11LoD0@H@U@46DII0aY:GP@KCV<47U=X125HK@@XGgD4<FUo0d9gR`AFQYT4JiFV18:V]@BI]l84
/<OA1<[Ig`?Qj^d4m?Wk1?Gin`CUj^/4emcN1<_@dP>oa<H4];Vj1:Z^[`BPXjD4UYVJ18f?T0B4QHHE
oooo000Doooo171bL`AVJ6T4G5iP155DEPA6BT`3>d12130e>0@T:Rh461lS11HM8@@K8RH38BL[12T^
<0@^<SD4=STk13i0@PA2A4D4ADI80dE8BPA4BD`4?TA913Q0AP@a?D@4:CM012<d?@<N<3/46Rhi11H/
>0@B:SL43bTg114]>`<C<D045CE511HiB@@G>d`45cm@11Q2E0@IAUT36TYN11]>H`@NDfP48EQ]12QO
M@@aJGl3@WN;15J6V@A[UJH4PZJe19Vg`PB`am44b]WO0n7Zk@CdnO/4mOWk1>GZj`CGg=h4bm3B0ko4
aPBd^KX4ZZj_1:2SY@BFVIX4SHn@18B5QQGoool001Coool4LG9c16MYJPAMH644DeIH14U=C`<o@dH4
=3Xm12X`<`@O9RX45alS11/S9`<R:B`4:2ha12dc=P@d>3`4?3m213m3A@A2ATT3@DI91456BP@l@dT4
=d1612hl@`@T=T047S8m0aX_>P@G;SX44b`i10lZ>0@>:cX44Bln0a@d@`@E=dL45c];11PnC`@H@U<4
64EG11]9G0<MCV847e9W12=GK0@YGW<4<VQm13mdR0=API@4II2Q17^P[`BB/Kd4ZL7;1<7Bf@CIhnL3
kO;d1?cno`C`loD4h^KX1=KJf`C:cLl3_/;31;>g^0BY[:h4Wj:S19JHV@B=SY04Q8F65Oooo`005?oo
o`AaLW<4IfUZ15ePH@ACEUP4BDe?0cm3AP@d>Sd4:S0c11lV:P@G7b<46b<W0b8Y;0@X;S44;C<f13@h
?0@l?d84?d=51496B@=1ATT4@DI:13a3B@@g@4H4;Sa312@f@0@N<Sd36Rlj11L^>P@C;3T43bXh10h[
>P@A;ch353A311DgA`@G>d/463i?11Q2D`@HAEL46dUL0ae>HP@ODVL48eM/12UNL`@bJ7d4?gB80e61
U0AUT:44Nj2_19:a_@BY`L/4`M;I1=WSi`?]l_@4o?ko1?3cm@CRi^P4e][K1<[=c`>n`/<4/kNh1:V/
[PBOXZ<4UYRI18f>T0B4QHHEoooo000Doooo175bL`AWJFX4GF1Q15=FF0A9CDl3?d=613@j?@@Z<3<4
7bHZ11LO8`@K8bL38RT/12P^<@@]<cH4=3Pl13`o@P@o@dD4@TI90d56B@A1ATX4?4=913M0AP@^?4<4
93I011hb?@<J;cX45bhj11</>@@?:SP43R/j114_?P<D=4<45CM711LkB`@H?Tl4649C11Q5E`@KBE`3
7DiR11mBI`@SEf`4:Eic139XO@@oM8P3DH6D16F@X@AkX:l4T[6m1:W1b`C1d]T4fN?W0ngbm0Clo_l4
l??e1>;Vj0CFf]/4b/g?0kk2``Bc]kP4ZJb^19nRX`BFV9T4SHj@18B5QQGoool001Coool4LG9c16MY
JPAMH644DeIH14U=C`<o@dH4=3Xm12X`<`@O9RX45alS11/S9`<R:B`4:2ha12dc=P@d>3`4?3m213m3
A@A2ATT3@DI91456BP@l@dT4=d1612hl@`@T=T047S8m0aX_>P@G;SX44b`i10lZ>0@>:cX44Bln0a@d
@`@E=dL45c];11PnC`@H@U<464EG11]9G0<MCV847e9W12=GK0@YGW<4<VQm13mdR0=API@4II2Q17^P
[`BB/Kd4ZL7;1<7Bf@CIhnL3kO;d1?cno`C`loD4h^KX1=KJf`C:cLl3_/;31;>g^0BY[:h4Wj:S19JH
V@B=SY04Q8F65Oooo`005?ooo`AbLg@4J6Y[15mQH`AFFE/4C51B0d=7BP@i?T44;cDi12D/<0@K8bL4
72@Y0b<[;P@X<3<4;S@g13<i?0@k@484?dA71415B@<oADT4?DE913]3B@@e@4L4;3a412@g@P@O=3l3
738n11Pa?P@D;cd44Bhm118`?`@D=4<35cQ711PkC0@J@5046d=D11]5E`@MBE`484iQ0b=DI`@WF6`4
;Emc13AWN`A1LhH4CgnA0f>=W@AgW:/4S:^h1:>laPBkcM@4d]gR1>K/k`?hnO/4oOko1>g_l0COh^<4
dmKG1<O;c0>l`<44/[Ff1:R[[0BOXJ84UINH18b>S`B4Q8DEoooo000Doooo179cM0AXJV/4Gf5S15II
F`A<D583@dM:13Tn@@@_=CT49B``11/S9`@L92T38b/^12P`<`@^=3L4<cTl13]0@P@oA4L4@4E90cm5
B@@mADT4>d=913E0A`@/?4@493M211ld?`<L<Sh4634n11@_?@@A;Sd44S0o11@d@`<G>4L463]<11Y0
D0@K@e@46dEG11e9G0@PCV438eAW12MHK0@]Gg<4=6Mk145cQPA?Oi43HhfM17NLZ`B<ZkP4Xkc61;_=
e0CBgN84i^c_0oSin`Cmo_l4kNo`1=oRh`CCe]L4al_<0kc0`@Bb]KH4Z:^/19nQXPBEUiP4S8j?18B4
QAGoool001Coool4LW=d16QZJ`AOHF<4EUUK14a@DP=3AdX4>Ci112le>@@U;3046b<W11`T:@<S:bh4
:30c12hd=`@c>C`4>d1213m4A`A0ADT3?dE913e5B@@k@dT4=D1712`lA0@T=d847c@o0a`b?P@H<Ch4
52lm114^?@@B<3l453A30aLhA`@H>d`46T1@11]3E0@KAEL47DUL121>H@<SE6L49eQ/12eOL`@dIg/4
@G>614moT@=SSId4Mib[18b[^0BS_<H4^lgD1=;MhPCVk>l3n?Wk1?gno`C]ko04gn;S1=?Fe`C7bl`3
_<311;:e]PBXZj`4Wj6R19FGV0B<SXl4Q8B55Oooo`005?ooo`AbLg@4JV]]165SI@AHFed4Ce=E0dM;
CP@n@dH4=C/n12`b=P@R:Rl47RHZ0b@/<0@Y<C@4;cHi13@k?P@l@D@4?TA713i4B0<lA4P4>T=813Q2
B0@c?dL4;3a512HiA0@R=d<383M311`f@P@J=T@463E411PgA@@J>DP36ce=11i1D@@PAED48DQI129<
G@@UD684:5AW0beKKP@bHG@4>VUk14=bQ0ABOXh4HHZJ0gFHY`B9Yk@4W[O11;G8c`C=fMh4hNOZ1?7d
mP?oool4moWi1>SZj`CKg]l4d=;C1<C7b0>j_Kh4/;:d1:NYZPBMWj04U9JG18b=SPB3Q8DEoooo000D
oooo179cM0AZJfd4HF=U15QKG@A?DeD3Ad]>13i3AP@e>ch4;38f128Z;`@N9RX392``12Ta=0@_=ST4
=3/n13a1A0@nA4L4?TA80ca4B0@j@dP4>49813<oA`@/?4D49SU4128g@`<P=d<473I211XfA0@H=D@4
63M511XiB0<K?Dd47T5A1215E@@QB5T48TaM12E@HP@XE6L3;E]^139QM0@jJG/4@g:4159nSPAQRYX3
MIRW18VW]0BN]l44]LS?1<gIgPCQinX4lOCf0oooo`CgnOT4j>[[1=_Ng`C@d]<4a<O80kZm_PB`/[@4
YjVZ19fOX0BDUYL4S8f>18>4QAGoool001Coool4LW=d16Y[K@AQHfD4F5]M14mCE@=7Bdh4?T=613Dk
?P@/<SH48RX_11hV:P<T;304:C4d12lf>@@d>ch4?45413i4A`@nA4P3?4A813Y3B0@h@TP4<cm712`l
A@@V>D@48SM30b0g@`@L=T846SI411PeA0@H=dD46SU80a/mC@@N@E4484EE1258F@@RC5d49E1R12QD
I`<]Ffh4<V5d13YYN`A3LX@4DWj>166:VP=eV:L4RJNd19jg`@Beb<l4cMWN1>7WjPCam?H3oooo1?Oi
n@CXj^/4fmkO1=3Bd`C4alP3^[fn1;2b]0BWZJX4WInP19BFU`B<SHh4PhB55Oooo`005?ooo`AbLg@4
JV]]165SI@AHFed4Ce=E0dM;CP@n@dH4=C/n12`b=P@R:Rl47RHZ0b@/<0@Y<C@4;cHi13@k?P@l@D@4
?TA713i4B0<lA4P4>T=813Q2B0@c?dL4;3a512HiA0@R=d<383M311`f@P@J=T@463E411PgA@@J>DP3
6ce=11i1D@@PAED48DQI129<G@@UD684:5AW0beKKP@bHG@4>VUk14=bQ0ABOXh4HHZJ0gFHY`B9Yk@4
W[O11;G8c`C=fMh4hNOZ1?7dmP?oool4moWi1>SZj`CKg]l4d=;C1<C7b0>j_Kh4/;:d1:NYZPBMWj04
U9JG18b=SPB3Q8DEoooo000Doooo17=dM@A[K6h4HfEW15]NH0ACEUP3BdmA1497BP@j@4<4<SPl12Xa
=@@R:bl392da12/c=`@a>3`4=Ca013Y1A@@k@dL4?4A90cY3B0@jA4T4>4=91391B@@]?dP4:Ci812Ll
B0<W?DT48S]8128mBP@P?4X48Ci<1291C`<TAE@4:4UH12]>G@@]DF44;UEU139IJP@fGg03?FIf149/
O@A;MH@4EWj=16F:V0AeUZ@3R:B`19^c_@B``lX4am?I1=kTi`C]l?44oOkn0oclo0C_l?04h^CT1=OH
f@C;cLh4`L?40kNi^PB^/;44YJJX19bNW`BCUIH4Rhb=18>4QAGoool001Coool4LgAe16]/KPASIFL4
FeiP15=FF0=;Ce44@TM:13Y0@`@b>3`4:S4e128[;`<T;C44:c<g134h?0@e?404>T5513]3A`@lA4T3
>T=813Y4B@@h@dT4<T5912doB0@Y?TP49ca80bLmB@@R>dP48Se:120lBP@Q?T`48T5?0bA5E0@XBEP4
:diM12eAH@@^EFD4<UUZ13IOL0<mIWH4@Vam14]eQ0AFOXd4IHZH17FFY0>8Y;04Vk>m1;33bPC7dmT4
g^CW1>g`l@Cmo_h3o?cl1>o`l0CRi>@4emSI1<_=cPC1`l@3]kVj1:j`/@BUYZP4W9jO19>EUPB;S8d4
PhB55Oooo`005?ooo`AcM7D4Jfa^16=UI`AKGV04DeIH0d]?D@A2AdX4>T13138h?0@Z<CD48R/_0b@]
<@@[<cL4<CPl13Dl@0@j@DD4>d=713a4B@<j@dP4>TA913Q3B@@b@DT4;Cm812TnB0@W?4P39ce9128k
B0@R?DX483a:124nC0@R@Dl394ED12Q9F0@[CUd4;E5Q12iEI@@bFFX4=Um`0ceVMPA2K7d4BgF415In
S@AURYP4MIJT0hRT/0BK/kd4/<?:1<OCf@CNi>L4kO3a1?gnoP?lo?`4ko3`1>;Ti0CGf=T4blg>1<73
a0>g^KX4[[2a1:FVZ0BLWYl4TiFF18^<S@B3Q8DEoooo000Doooo17=dM@A[K6h4HfEW15]NH0ACEUP3
BdmA1497BP@j@4<4<SPl12Xa=@@R:bl392da12/c=`@a>3`4=Ca013Y1A@@k@dL4?4A90cY3B0@jA4T4
>4=91391B@@]?dP4:Ci812LlB0<W?DT48S]8128mBP@P?4X48Ci<1291C`<TAE@4:4UH12]>G@@]DF44
;UEU139IJP@fGg03?FIf149/O@A;MH@4EWj=16F:V0AeUZ@3R:B`19^c_@B``lX4am?I1=kTi`C]l?44
oOkn0oclo0C_l?04h^CT1=OHf@C;cLh4`L?40kNi^PB^/;44YJJX19bNW`BCUIH4Rhb=18>4QAGoool0
01Coool4LgAf16a^K`AUIfT4GF1R15IIG0=?DeD4Ada?1415B0@i?d84<CPl12Ta=@<V;S84;CDi138j
?P@f?T84>D9613a4B0@nAT/3>TA:13Y5B`@hA4/4<T9;1352C0@^@T`4;45=0ba2C@@Y@Dd4:T=?12U4
D@@ZAU<4;4YG0c1>F`@dDV04=eIT13UJJ0@lGVd4@FAb14MZN0==L7l4DgN515aoS@AYRYL4N9FQ18RR
[@>J/;P4[[o51<??d`CHg^44j^g^1?[kn`Cmo?`3lO7a1>KWi`CKgMd4dM;C1<O8b@Bm_l03];Jf1:^]
[PBRY:D4VYbL19:CU0B:Rh`4PX>45Oooo`005?ooo`AcM7H4K6i_16EWJ@AMH684EUUL0dmCE@A7C4l4
@4E813To@P@a>3`4:C4e0bH^<P@]=CT4<SXn13Hn@P@i@TH4?4A813i6B`<jA4X4>TE;13Q4B`@b@T/4
<D9<12i2C0@/@Dd3;49=12U1C@@Z@dl4:DAA12Y6D`@/BUL3<4iK13ABH0@gEV@4>EYX13aNK@A1I784
AfYh0de`O`ACMhD4G7n=16V:U`AhUJ44R::]0iZ`^0B^_lD4`loC1=SNh@CZkNh4n__k1?glo0?alO44
i^OW1=_Mg@CAd]<4alS91;fo`0>d][H4Zjf^1::TY@BJW9`4TY>D18Z;S0B2Ph@Eoooo000Doooo17=d
MPA/KVl4IFMY15ePHPAFFE`3Ce=E14M<C`A0ADP4>Cm2134h?0@Y<CD39Rhb12de>@@b>Sh4=Si213U2
AP@lA4P4?TI;0cY4BP@jAD/4>4A;1392B`@a@T`4;T9<12a1C@</@Td4:D5=12Y3C`@YA544:TIC12a:
E`<`CU/4=59P13MFI0@iFVP4?5i]145TLPA7JWP3CG1o15=gQ@ALOhd4JHZG17REX@B8XZd3V[2h1:jo
a@C3cm<4f=kQ1>[]kPCjno/4oOcl0o7al@CVinL4fmgM1=7Bd`C7b<T4_Ko00kBf]PB[[Jh4XZBU19ZL
W0BBTi@4RX^<18:3Q1Goool001Coool4LgAf16a^K`AUIfT4GF1R15IIG0=?DeD4Ada?1415B0@i?d84
<CPl12Ta=@<V;S84;CDi138j?P@f?T84>D9613a4B0@nAT/3>TA:13Y5B`@hA4/4<T9;1352C0@^@T`4
;45=0ba2C@@Y@Dd4:T=?12U4D@@ZAU<4;4YG0c1>F`@dDV04=eIT13UJJ0@lGVd4@FAb14MZN0==L7l4
DgN515aoS@AYRYL4N9FQ18RR[@>J/;P4[[o51<??d`CHg^44j^g^1?[kn`Cmo?`3lO7a1>KWi`CKgMd4
dM;C1<O8b@Bm_l03];Jf1:^][PBRY:D4VYbL19:CU0B:Rh`4PX>45Oooo`005?ooo`AdMGH4KFm`16MY
JPAPHfD4FEeO0e=GF@A<DE<4AT]>13m5B0@h?d84<STm0b/d=`@_>C`4=3e113Q0A0@lA4P4?TM;13i7
C0<lAT`4>dI=13Y7CP@fATl4=TMA13A7D@@cAe83<dQB1398E0@bBUD4<daH13I?F`@iDel3?5IR145K
J0A4Gf`4BFAa14aYM@ABKg/4F7F10eekQ`ASPHd4KHZE17^EW`B9X:X4VZfe0jbk`@BobLh4d]SJ1>CV
j0Cgm_L4no_j1?7al@?Xj>P4g]oO1=CEePC;c<`4`L?31;Vj^`>`/[84Z:VZ1:2QXPBHVIX4TI:C18V:
R`B2Ph@Eoooo000Doooo17AeMPA]Kg04IfUZ161SI@AIGEl3DeMI14aAD`A6Bdh4?dE813Po@P@b>Cd3
:c@g12li?0@d?D44>41413a4B0@nAd/4?TM<0ca6C0@kATd4>TM>13I6C`@fAe44=4MA13=7DP<cB584
<TQD139:E@@cC5P4=TmK13UCG`<lEV84@E]X14AOK0A9I744C6Ue159_N`AHMH43GG^716>1S@A]RYD4
NiFO18VPZPBJ[KD3[;_11;o9cPCBf=X4i>KX1?Ofm`CknoX4lO7a0nSXj0CNgml4e=GF1<_<c0C1`l<4
^KZk0k2b/PBXZJX4X:6R19RIVPBATY<4RHZ;18:3Q1Goool001Coool4M7Ef16e_L0AWJFX4H6=U15UM
G`=CEeT4C55C14I;CP@oADP4>3m2138i?@<[=3L4;cTl13@m@@@h@4@4?4A813i7B`@nAd`3?4I<13]6
C@@jAdh4=TI?13I7D@@dAe44<dMB0c=8DP@bB5@4<TYE13=<F0@fCe/4>E=O0caFHPA1FfP4A5m/14UT
L@A<JGD4DVmk15QeP@=MNhL4Hh6=16f:U@AkUIl4RJ2Z19Z]]@>/^l44_lW>1=;HfPCTi^P4moKg1?_k
nPCalO43j>SX1=kOg`CDeMH4blc<1<73``Bi^[/3/;:b1:RYZPBPXJ84V9VJ196BT`B9RX/4PX>45Ooo
o`005?ooo`AdMGH4KFm`16MYJPAPHfD4FEeO0e=GF@A<DE<4AT]>13m5B0@h?d84<STm0b/d=`@_>C`4
=3e113Q0A0@lA4P4?TM;13i7C0<lAT`4>dI=13Y7CP@fATl4=TMA13A7D@@cAe83<dQB1398E0@bBUD4
<daH13I?F`@iDel3?5IR145KJ0A4Gf`4BFAa14aYM@ABKg/4F7F10eekQ`ASPHd4KHZE17^EW`B9X:X4
VZfe0jbk`@BobLh4d]SJ1>CVj0Cgm_L4no_j1?7al@?Xj>P4g]oO1=CEePC;c<`4`L?31;Vj^`>`/[84
Z:VZ1:2QXPBHVIX4TI:C18V:R`B2Ph@Eoooo000Doooo17EfM`A_L744JF]/16=UI`AMH683EeYM155E
F0A;D5<4AD]>1416B@@j@DD3=Se113Dm@@@g@4@4>d=713i7B`A0BDh4@T]@0d1:D0@oBU44?daC13a;
D`@mCED4>deF13a>E`<kCeT4?51K13eBG@@oEEl4@UQS14ILIP=9GfX4CfE_15=YL`AIKgT4G7=n16=i
P`AXOhP3KHB>17B;U0AoUId4SJ2W19b//PB/^;d3_LG91<kBe@COh>44l>k^1?Whn0C`l?04inOW0mkO
g`CFe]H4cLk>1<C5aPBl_Kh4];Ff0jb][PBTYZH4WIjO19JGV0B?T944R8V:1862PaGoool001Coool4
MGIg16m`L@AYJf`4HfEW15ePHP=GFUd4DEEH14]@D`A5Bdh4@4I913Y1A@<f?D44=Ce113M0A0@k@dL4
?TM;1419CPA2Be03@4Y@13m:D@@oC5<4?4]C13e=E@@kCEH4?4iG0c]?F@@lD5/4?E9M13mEG`A2F6<4
AUaV0dUOJPA?IFl4DfUc15U_N@ALLgh4HgV316QoR0=]Q8h4M8^D17nEW@B=X:L4W:bb1:bh_@>maLT4
c];E1=oPh@C`k^h4nOSh1?3`l0CWinL3g]oO1=KFePC=c/h4a<G61;bm_PBd]KH3[:f^1:BVYPBMWYl4
UYNH18n@T@B8RHX4PH:35Oooo`005?ooo`AeMWL4Kg1a16U[K0ASIFL4GF1R0eMJG@AAEEP4Be1C14E;
CPA0ATT4>T550cHm@@@e?D44=d1413]3A`@nAd/4@4U>149;D0=0BU04?dYA13m<D`@lBe<4?DeE13]=
EP@lCUL3>dmI13a@F`@mDUd4?eEO149HH`A6G6H3BEmZ14mUK`ACJG<4FFmi15acOPASNH<4J7n80ff4
SPAdRi@4OiFM18fPY`BL[;84[;Rm0kg5b@C>d]D4gn3Q1?3^kPCin?P4l?3`1>OWi`?Ngml4e]KF1<g>
cPC4aLH4_;fn1;Be]P>/[Jh4Y:JV19fNW`BFUiP4Si2A18R9RPB1PX<Eoooo000Doooo17EfM`A`LG<4
Jfa^16EXJ@APHfD3FeiP15IIG0AAEEP4C55C14M=D0A3BD`3?dI913a4A`@lA4P4?dM;145:CPA5CE44
ATmD0dI?E@A5D5D4AE5H14=AF@A4De/4AEAM14EEGP=6Ef04B5UR14YKI@A;GFL4Cf5Z15=UKP=GJ744
G6ef165cN`AWNH44K7j717>4R`AfQhl3NhfD18BEW0B@Wj@4WJV^1:^e^@Bk`L@3b/g?1=WIfPCXi^H4
lo;a1?3`l0CVi^H4gMkN0mGFePC=c/h4aLK61;jn_`Bf]kP4[k2`0jRYZ@BQXZ<4VY^L19BEU@B=SXl4
QhR91862PQGoool001Coool4MGIg171aL`A[K6h4IFQY161SI@=KGV04EUUL155EF0A<DE<4Ade@14=9
C0<oATT4?4A713a4B0@oAd/4@DY>14E=D@A6Ce@3ATmE14E@E@A5DEP4@e5I14ACF`A5E5d4AEEN0dIG
H0A8FF84BU]U14]MI`A?HFX4DfE^0eMXL@ALKGH4HG=k16MiP@A/OXL4LhB;17J7S`=kSI@4Q9FL192O
Y0BMZJh4ZkFi1;_1a0?:cLl4fMWJ1>SViPCcl_44l?3`1>KViPCMg]h3eMKF1<g>cPC5a/H4_[jo1;Jg
^0B_/;03Z:VY1:6RX`BJVi`4U9FE18f>S`B7R8T4PH:25Oooo`005?ooo`AeMWL4L75c16]/KPAUJ6T4
H6=U0e]NH0AFFE`4DEEH14aAD`A7CE04@dU<0cm6B@@lA4L4?4A813m7B`A1BTh4ADeA14I?E0=6CeD4
AE1E14EAF0A3DET4A5=K14EDG@A5EEh3AUMP14QIHPA:FfD4BeeW14mQJPACIFh3EfQa15a]MPAQLg/4
IgV116anQ`AcQ8/4MXN?0g^=U0B4UI`4T9nT19fY[PB[]KT4^l740l[=c`CIfMX4j>KV1??bl@C`l?04
i^KV1=gNgP?Ee]H4cLk>1<G6aPBn_[l4][Nh1:n`/0>XZJT4XJ:S19ZKW0BDUID4SHj?18N8R@B1PX8E
oooo000Doooo17EfM`A`LG<4Jfa^16EXJ@APHfD3FeiP15IIG0AAEEP4C55C14M=D0A3BD`3?dI913a4
A`@lA4P4?dM;145:CPA5CE44ATmD0dI?E@A5D5D4AE5H14=AF@A4De/4AEAM14EEGP=6Ef04B5UR14YK
I@A;GFL4Cf5Z15=UKP=GJ744G6ef165cN`AWNH44K7j717>4R`AfQhl3NhfD18BEW0B@Wj@4WJV^1:^e
^@Bk`L@3b/g?1=WIfPCXi^H4lo;a1?3`l0CVi^H4gMkN0mGFePC=c/h4aLK61;jn_`Bf]kP4[k2`0jRY
Z@BQXZ<4VY^L19BEU@B=SXl4QhR91862PQGoool001Coool4MWMh175cM0A]KW04J6Y/16=VJ0=OHV@4
FUiP15IJG0ABEUT4CU=F14Y@D`=7CE44AD]?24=:CPA6CE44B51E14YCF0=<EEX4C5IK14eGG@A<F5l4
CEYQ14mLH`A?GFD3DV1W15=QJ@ADHf/4EfI^15]ZL@AOKGD3I79i16QfO@A^Nh84MH6817Z6S0AoRXl4
PXjC0hRDV@BCWZ84W:JY1:R_/`Bg^kh4a/S90m?Cd`CPg]h4kN_Z1>c/j`CShn<4fm_K1=?Ce0?<c<`4
a<G51;fn_`Bg]kP4/;6a1:VZZ`>SY:D4WIjO19NHV@BATY<4Rhb=18J7Q`B0PH8Eoooo000Doooo17Ig
N0AaLg@4KFi`16QZK0ASIVP3Gf9T15YNH0AFFU`4DUII14iCEPA:D5<3AdeA14E;C`Q3BTh4ATeA14Q@
E@A:DeP3C5EJ14aFF`A=Eed4C5QO14eJH@A?G6<4CeeU0e9PI`ACHFT4E6=[15MVKPAKJW44Gfee0fAb
N@AXMWd4KW^217F1R0AjQX`4OhZ?18:>T`>8U9T4TijR19bVZ@BX[k<4]k^n1<K8b@?Cdm<4h=kN1>g[
jPC/k>/4hn?S1=_Kf`CCdm@3c<c<1<C5a@Bm_[l4]kNh1;2a/@BYZZ/3XjBU19fNW`BGV9T4TI:C18^<
S@B6QhL4P8625Oooo`005?ooo`AfMgP4LG=d16e^L0AXJV`4HfIX0emRI0AJGV04EUYL159FF@A>DeH4
BU1C0dM=D@A5Bdl8@dY>14I=D@A8D5D4BU=H0daEFPA<EU/4CEMM14aHG`A=FV44CeaS14mMI@=BH6L4
Df5Y15ASJ`AGIVh4FfYa15m]M@=TLWT4J7Im16ikPPAePHP4NXJ<17n:S`B2SY<3R9BI19>NXPBLYZT4
Z:nc1;Nk_PC6b<T3dm?C1>3NgPC]jnX4k>c[1>?Sh`CKfm/4dm?D0lc<c0C4aLD4_Kjo1;Ng^0B`/K44
ZJZ[0j>TY@BMWYl4UiRI196BT`B;S8d4QXN71821PQGoool001Coool4MWMh175cM0A]KW04J6Y/16=V
J0=OHV@4FUiP15IJG0ABEUT4CU=F14Y@D`=7CE44AD]?24=:CPA6CE44B51E14YCF0=<EEX4C5IK14eG
G@A<F5l4CEYQ14mLH`A?GFD3DV1W15=QJ@ADHf/4EfI^15]ZL@AOKGD3I79i16QfO@A^Nh84MH6817Z6
S0AoRXl4PXjC0hRDV@BCWZ84W:JY1:R_/`Bg^kh4a/S90m?Cd`CPg]h4kN_Z1>c/j`CShn<4fm_K1=?C
e0?<c<`4a<G51;fn_`Bg]kP4/;6a1:VZZ`>SY:D4WIjO19NHV@BATY<4Rhb=18J7Q`B0PH8Eoooo000D
oooo17MgN0AcM7D4KW1a16Y/KPAVJFX3HVEW15mRI0AKGf44Ee]N15AIF`AAEUT3CeAG14eCEPA;DED4
BE1D14UAE0A=EET4D5QM0e=KH0ADG644E5iS15AOI@AFHFL4FVE[15aWK@=MJ6l4GVYa161/L`ASKWD4
Ig9h16]eN`=`NWl4M7f217V2Q`AoQh`4Ph^?18R?TPB8TID3SiRK19VQX`BSZJ`4/;Bf1;o0`@C=c<`3
f]OG1>?Qh@CUiN@4gMgM1=KFePC?d=04bLW90l;2``Bl_;d4][Jg1;2`/@BZZZ/4Y:FU0ijOX0BIVY/4
U9FE18n?T0B:RX/4QHF61820PAGoool001Coool4MgMh17=dM@A^L744JVa^16IYJP=RIFL4Gf9T15]O
H@AGFeh4E5UK155FF@=?E5L4CE=F14]AE@A9D5@4BE5D14eEF@A@F5d3De]P15ALH@ADGV<4E5mU15IQ
I`AJIF/4G6M]0eeXK`ANJW44H6ac16=^M@AWLWP4JgEk0g1jO`AdOH84NH:717n7S0B3Rhl4R8nB18RA
U@>?V9/4VJ6S1:>Y[0B`];H4_l311<g<c0?JemL4hn7Q1>GUi0CMgMd4e]KF1<o@d0C9bLT3`/;31;bl
_@Bf][L4/;2a1:ZZZ`BTYJD3WYnP19VJV`BDUID4Shn@18Z:R`B5QHH4P8215Oooo`005?ooo`AgMgP4
LgAe16i`L@AZK6h4IVUZ0f9UI`AOHV@4FemQ15MKGPADFE/4DEII0dmDE`A=DeH4Be5E14U@E0A9DE@4
CEEI151HG@=CFf04E5aQ15ANH`ADGfD4EV5W15YUJ`ALIfd3GFQ_15iZL@APK7<4Hfie16MbN0A[MG/3
L7Yo17AmPPAiPXL4OhN<18>;S`B8Si84R96E0hnHV`BIXJ<4XjV/1;2d]PBo`<44cLc<0m[Ge`CShN44
iNGT1=gMg@CFe]H4cm3@1<W9b@?2`/<4_;bm1;Jf]`B`/;44ZZZ[1:BUY@>NWj04VIZK19BEU@B?Si04
RXZ;18F5QPB0P84Eoooo000Doooo17MgN0AcM7D4KW1a16Y/KPAVJFX3HVEW15mRI0AKGf44Ee]N15AI
F`AAEUT3CeAG14eCEPA;DED4BE1D14UAE0A=EET4D5QM0e=KH0ADG644E5iS15AOI@AFHFL4FVE[15aW
K@=MJ6l4GVYa161/L`ASKWD4Ig9h16]eN`=`NWl4M7f217V2Q`AoQh`4Ph^?18R?TPB8TID3SiRK19VQ
X`BSZJ`4/;Bf1;o0`@C=c<`3f]OG1>?Qh@CUiN@4gMgM1=KFePC?d=04bLW90l;2``Bl_;d4][Jg1;2`
/@BZZZ/4Y:FU0ijOX0BIVY/4U9FE18n?T0B:RX/4QHF61820PAGoool001Coool4MgQi17AeMPA`LW<4
KFm`16U/K@=VJFX4HfIX161SI@AMHF<4FUiQ15QLG`=FFed4E5UL15=HF`QAEe/4DUUM15ELH@=IH6D4
G6=X15eUJPAMIV/4H6Q^16=[L@AUKG<3J71e16UbN0A[LgT4KWIk179iO`AfOH43Nh6517j4Q`B4R8/4
QX^>18jAT`B?TiH4TYNI0i^OX0BSYZP4[[2a1;Zj^PC5a<@4d/o>0mcIf@CKfm/4e]KF1=3@d0C:b/X4
a<C41;jn_P>h^KT4/k>d1:f^[PBXZJT4XjBU19jOX0>JVY/4UIJF192ATPB<SHd4R8R918>4Q@AoP80E
oooo000Doooo17MhN@AdMGH4L79c16e_L0AYK6d3IVUZ16=VJ0APHfD4GF5S15YNH@AHG5l3EU]M15AI
G0ACF5/8DEMK159IG@AEG643FF1U15aSJ0AMIFX4GFI[161XKPASJg44IFec0fQ`M@AYLWP4Jg=i16if
N`AbNGl4MWf10g^1Q@AnQ8L4Q8R;18J;SPB>TI<4Si>F19:GV@>KWj04XjJX1:j`/@Bj^[X4aLC41=;?
cP?LfMT4fm_K1=KFePC@d=04b/[:1<C4a0Bn_[h3^;Vi1;>c]0B][Zh4Z:VY1:>TY@BNWj03VYZK19FF
UPB@TI84S8f=18R8R@B3Q8D4Oh205Oooo`005?ooo`AgN7T4M7Ef171bL`A]Kg04JFa]0fIYJPASIVP4
H6=U15eQH`AJGV44F5aO0eIKG@ADFE`4DeQK255GF`ABFEd4EEaQ0eUPI@ALHfP4GFEZ15eVJ`APJ6h4
Hf]a16E]L`=XL7D4JG9h16]cN@A^MW/4LWUo17ImP@=kPHD4OXB718B8R`B6Rhh4SY6C18nCUPBBUiT3
VinP1:>VZ0B^/;44^[Zj1<G4a0CBclh3g=WI1=_Kf`CFe]H4d=3@1<[:bPC4a<@4_[jn0kRi^@Bc/k@4
[Jj^1:RYZ@BSY:D4WYnP0iZJV`BEUYH4T96B18b=S@B8R8T4PhB517n0P1Goool001Coool4MgQi17Ae
MPA`LW<4KFm`16U/K@=VJFX4HfIX161SI@AMHF<4FUiQ15QLG`=FFed4E5UL15=HF`QAEe/4DUUM15EL
H@=IH6D4G6=X15eUJPAMIV/4H6Q^16=[L@AUKG<3J71e16UbN0A[LgT4KWIk179iO`AfOH43Nh6517j4
Q`B4R8/4QX^>18jAT`B?TiH4TYNI0i^OX0BSYZP4[[2a1;Zj^PC5a<@4d/o>0mcIf@CKfm/4e]KF1=3@
d0C:b/X4a<C41;jn_P>h^KT4/k>d1:f^[PBXZJT4XjBU19jOX0>JVY/4UIJF192ATPB<SHd4R8R918>4
Q@AoP80Eoooo000Doooo17QiNPAeMWL4LW=e16maLPA/KW03JVa]16MZJ`AUIfT4HVEW161TIPANHV@3
GF5S15]PHPAJGf84FEiQ15UOHPAIH6<4GVAX0f1VJPARJ6d4HfY_16I]LPAZL7D4KWAh175gN`=aMg`4
LWUm17IkP0AjOX84Ngn317j2Q@>2QHL4QHR;18V;S0B;SXl4TiBD19BEU`BIVi/3X:6R1:RYZPBc/[84
_K^k1<?2`PCAcll3dM3A1<_;b`C7alL4`/;21;fm_@Bh^;P4/k>d0jj_[`BZZZ/4YJJV1:6QXPBMWIh4
VIVJ0iFEUPBATI84SHj>18V:R`B6QXL4PX:317ioP1Goool001Coool4N7Uj17EfM`AbLgD4Kg5b16a^
L0=ZK6d4IfY[16EWJ@ARIFL4H6AV15iRI0=MHF<4Ff1R15YOHPAIGV44FEmR15UPH`ANI6P3H6IZ169X
K@ASJVl4IVeb16Y`M@A^M7P4LGMk0g5gO0AbNGd4MW^017YnPPAkOh<4OX:50h:5Q`B5R8/4RH^<18^>
S`BCU9@4U9FG19VKV`>PXJ84Z:VZ1;>b/PBm^k/4`l;21=7?c`?Ad=44bl_;1<O7a`C2`/84_Kfm1;Rh
^0Bc/k@3[Zn_1:ZZZ`BUYZH4XJ6R19fMWPBIVIX3UIFF196ATPB=SXh4RHZ;18J6Q`B2PX<4OWn05Ooo
o`005?ooo`AhNGX4MGIg179cM@A_LG84K6i`0fY/K@AWJV/4IFMY169UI`API6H4GV9T0eeQH`AKH684
FUmR15UNH@AIGf84FF1S15iTJ0=PIVX4HVQ]16=ZK`AVKG84JW1e16idN0AaMg/3LGMl179iO@AfNh04
NWj217]oP`AnPXD3PXF718F8R`B9Rh`4Rhj?19>DU0BDUIL4VI^K0j2QXPBXZJX4/k:b1;fk^`C3`/84
dLo?0m7@d@C;bl/4alO71<;2`PBm_Kd4^;Rh1;>c]0>^[jl4ZZZ[1:FVYPBQXJ84WIfN19VIVP>EUIH4
TI6B18f>SPB9RX/4QXJ718:2P`AnOh0Eoooo000Doooo17QiNPAeMWL4LW=e16maLPA/KW03JVa]16MZ
J`AUIfT4HVEW161TIPANHV@3GF5S15]PHPAJGf84FEiQ15UOHPAIH6<4GVAX0f1VJPARJ6d4HfY_16I]
LPAZL7D4KWAh175gN`=aMg`4LWUm17IkP0AjOX84Ngn317j2Q@>2QHL4QHR;18V;S0B;SXl4TiBD19BE
U`BIVi/3X:6R1:RYZPBc/[84_K^k1<?2`PCAcll3dM3A1<_;b`C7alL4`/;21;fm_@Bh^;P4/k>d0jj_
[`BZZZ/4YJJV1:6QXPBMWIh4VIVJ0iFEUPBATI84SHj>18V:R`B6QXL4PX:317ioP1Goool001Coool4
N7Uj17IgN0AdMGH4LW=d16maLP=]Kg44Jfe_16U/K@AWJV`4IVUZ16AWJ@=SIVP4HVIX165UI`QQIFP4
HVIZ16=XK0=VJfh4J6ea16aaM@A_MGT4LgMk17EiO@AgNgh3N7ao17]oPPAmP8<4OX2217j0P`B2Q8H3
QHJ718N9RPB:Rh/4Si2@19>CU0BHUiL4WIbL0j>SX`B[Zj/4/[6a1;Zi^@C0`L44a/G50l2o`0Bk^k`4
]kRh1;>d]0B_/;04[:b/1:RXZ@>TY:D4X:6Q19fMWPBIVY/4UYNG19>CU0>@T944S8f>18V:R`B6QhP4
PhB51861PPAnOWlEoooo000Doooo17QiNPAfMgP4M7Ef179cM0A_LG83KFma16]]K`AYK6d4IfY/16IY
JPATIfT3HfIX169VJ0AQIFL8HFEX169VJPASJ6`3IV]^16Q]L@A/LGD4KgEi17=gN`AeNGd4Mg]n0gQl
O`AkOh84OH2317j0PPAnP8<4PXB60hF6Q`B7RHX4RX^;18n@T0BCTi@4V9NG19fLW0>SXj<4Zj^[1;:a
/@Bj^KT4`<711<K5a@?0_l04^k^l1;Nh^0Bc];@4[k2`1:b/[0BXZ:T3Y:BU1:2QX@BMWIh4VIZK19JG
U`BCTi@3T92A18b=SPB9RX/4QXN818>4Q@B1PH84OWio5Oooo`005?ooo`AhNGX4MWMh17AeMPAbLg@4
Kg5b0fe_L@A[KFl4JFa]16MZK0AVJFX4I6MY0f=VJ0ARIVP4HFEW265UJ0ARIVX4HfQ/0fI[KPAXKG44
K75e16meN@AcMg/4MGUm17MkOP=hO7l4Ngn217f0P`AnP884OX2318:4QP>5QXL4QhV:18Z;R`B?T904
Ti>D19RGU`BMW9`3Xj>S1:^[Z`Bb/K44^[Vi1<31`@C6aLD3`;o01;^k_0Bg^;P4/kBd1:n`/0B/[:`4
Z:RY0jBTY@BPXJ44WIfN19VJV`BFUiL4Ti>D0i2@T@B<SHh4RHZ;18J7R0B3Q8D4PH6217inOaGoool0
01Coool4NGYk17MhN@AfMgP4M7Ef179dM@=aLW@4Kg5b16i`L@A/KW04Jfe_16Y]KP=YK6h<J6]]16Q[
KPAYK6l4JVi`0fa`LPA^LWD4MGUk17QkO`AiNgh4O7j01gj0P`QoP8<4Oh6318:3Q@B5QXL3QXN818^;
R`B=SHd4TI2@19BCT`BHUiL4W9bM0j2QXPBZZZX4[Zn_1;>c/`Bd]K@4/K6a0jj^[`B[Zj`4Z:RY1:FV
YPBRXj<4Wj2P19fMW@>JVY/4UiRH19BEUPBBTY<4Si2A18f=SP>:Rh`4R8V918J6Q`B4Q8D4PH:317n0
P0AmOGhEoooo000Doooo17UjN`AgN7T4MWMh17AeMPAbM7D3LG9d16maLPA^L744K6i`16]]K`AZKFh3
JFa^36Q[K@AXJfh4JFa_16Y^L0=/L784KW9e17EiN`AhNgl4NG]n17anP0MnP8<8Oh2317n1P`B2PhD4
QHJ70hJ7R0B;Rh/4SHf=196@T0BDTi<4V9NG19bLW@>PXJ84ZZZZ1:j_[`Bc/k<4];Fd1;6a/@>^[Zl4
Zj^/1:RXZ@BUYZH4XZ>S19nPX0BMWId3VYZK19NHV0BDUIH4TY:C18n@T@B=SHh3RX^<18R9R@B6QXL4
Q8B51862P`AoP804OGen5Oooo`005?ooo`AiNW/4MgQi17IgN0AdMGH4LWAe0g5bM0A_LG84KW1a16a^
L0A[KFl4JVe^0fU/KPaXJfd4J6]^16U/K`AZKW03K71b16ibM@AeNG/4N7]o17UkOPAlOX07OX2327n0
P`AoPH<4PX>518F6Q`>6QhP4Rh^;18f=S@BAT904U9>C19RGU`BLW9d3X:6R1:ZZZPB^[jl4/k>c1;Be
]0Ba/K43[Zj_1:^[[0BXZ:T4YJJV1::SX`BOX:04WIfM0iZJV`BGV9P4U9FF19:BT`B?T944SHf>0hZ;
S0B8RHT4QXJ718B4Q@B1PX<4Oh2017emOQGoool001Coool4NGYk17MhN@AfMgP4M7Ef179dM@=aLW@4
Kg5b16i`L@A/KW04Jfe_16Y]KP=YK6h<J6]]16Q[KPAYK6l4JVi`0fa`LPA^LWD4MGUk17QkO`AiNgh4
O7j01gj0P`QoP8<4Oh6318:3Q@B5QXL3QXN818^;R`B=SHd4TI2@19BCT`BHUiL4W9bM0j2QXPBZZZX4
[Zn_1;>c/`Bd]K@4/K6a0jj^[`B[Zj`4Z:RY1:FVYPBRXj<4Wj2P19fMW@>JVY/4UiRH19BEUPBBTY<4
Si2A18f=SP>:Rh`4R8V918J6Q`B4Q8D4PH:317n0P0AmOGhEoooo000Doooo17YkN`AhNWX4MgQi17Ig
N0AeMWL3M7Ef17=dMPAbM7D4LG=d271bL`=_LG<4Kg5b26iaLPA^LG<4Kg9c171cM@=aM7H4LgIh17Ii
N`AhNgd4Ngen1862P`B1Ph@3P8631862Q0R0PX@4PXB518>5Q@>5QXL4R8V918Z:RPB=SHd4Shn?19:C
T`BKVi/3WYjN1::RXPBQXZ84X:6Q1:2PX@BOWil3WIfN19^KW0BIVIX4UiNH19FFUPBCU9@4TI:B0hn@
T@B>SXl4S8b=18Z;R`B8RHX4QhN80hF6Q`B4Q8D4PX>31861PPAoP804OWio17amOAGoool001Coool4
NW]k17QjNPAgN7T4MWMh17EfM`=dMGH4LgAf179dM@AaLg@8L79c0fmaL`A_LG88KW5b16iaL`A_LW<4
L7=e0g5dMPAcMWP4MWUk17QkO@AkOGh4PH:31863Q0>0PH<4PH:42822Q0B2Q8D4PhF50hF6Q`B8RHT4
RXZ:18f=S@B?Shl4TY>C19^KV`>NWYh4XZ:R1:6RXPBPXJ44X:2Q19nOW`>MWIh4Vi^L19VIVPBGUiP4
UIJF19>DU0BATY83Si2A18j>S`B<S8d4RX^;18R9RPB7QhP3QHJ718B4Q@B2Ph<4PH6217n0P0AnOWl4
O7em5Oooo`005?ooo`AjNg/4N7Yj17MhN@AfMgP4MGIg0gAeMPAcM7H4LWAe175cM0Q`LW<3Kg5c16ma
LPQ^LG84KW5c16mbL`A`LgD3LGAf17=fN0AfNG/4N7]m17]mOPB1PX<4PH>40h21P`B1PX@8P8:418:4
Q@B3QHD3QHJ718R9R@B:RXX4SHf=18n?S`BBTi<4Vi^K0ijNWPBRXZ84XJ:R1:2QX@BPX:44WinO0ifM
WPBKVi`4VIVJ19NGV0BEUYH4TiBD196BTP>?T944SXj?18b<S@B:Rh/4R8V:18N7R0>5QXL4Q8B518:3
P`B1PH84Oh2017inO`AlOGdEoooo000Doooo17YkN`AhNWX4MgQi17IgN0AeMWL3M7Ef17=dMPAbM7D4
LG=d271bL`=_LG<4Kg5b26iaLPA^LG<4Kg9c171cM@=aM7H4LgIh17IiN`AhNgd4Ngen1862P`B1Ph@3
P8631862Q0R0PX@4PXB518>5Q@>5QXL4R8V918Z:RPB=SHd4Shn?19:CT`BKVi/3WYjN1::RXPBQXZ84
X:6Q1:2PX@BOWil3WIfN19^KW0BIVIX4UiNH19FFUPBCU9@4TI:B0hn@T@B>SXl4S8b=18Z;R`B8RHX4
QhN80hF6Q`B4Q8D4PX>31861PPAoP804OWio17amOAGoool001Coool4NW]l17YjN`AiNW/4NGUj17Qi
NPMgN7T<MWMh17EfN1=eMWL4MGIh17EgN0=fN7T4MgUj17QjN`AjNg`4Ngan17enO`AnOh03OWj027io
P0AoP844Ph>318B4Q0>5QHH4QhN718R8R0B9RHT4Rh^;18f=SPB@T943SHj>28j>S`R=SXh4SHf>0hb<
S@B;Rh`4RXZ;18V9RPB8R8T4QhN818J7Q`>5QXH4Q8F518>4Q@B2Ph@4PX:31861PP>0PH44Oh2117io
P0AnOWl4OGen17amOPAkO7dEoooo000Doooo17YkO0AjNW/4NGYk17UiNPAhNGX7MgQi37IgN0AeMWPC
MGIg17EfN0AeMgP3MWQi17MiNPAhNW/4NW]l17]lOPAmOWl4OWn00ginP0QnOh04Oh2118>3P`B4Q8@3
QHF618N7Q`B8R8P4RHV918^;R`B=SHh4T92A0hf>SPR>SXl8SHj>18f=SP><S8d4Rh^<18Z:R`B9RHX4
R8R918N7R0B6QhL3QHJ618B5Q@B3Q8D4PX>418:2P`B1PH83P86117n0P@AnOh04OWio17emOPAlOGh4
Ngam5Oooo`005?ooo`AjNg`4NWYk17UjN`AiNGX4N7Uj1gMhN@afMgP4MGIh4gEfM`AeMWP4MGMh0gIh
N@AgNGX4N7Yk17YkO0AkO7h4OGio17ioP0=nOX08OWn017n0P@B3Ph<4Q8B40hF5QPB7QhL4R8R818V9
R@B;Rh/4SHf>192@T@>=SXh8SXj?28f>SPB=SHh3S8b=18^;S0B:RX/4RHV:18R8R@B7QhP4QXN70hF6
QPB4QHD4PhB518:3Q0B2PX<4PH620h21P@AoP844OWn017inO`AmOGh4O7en17]lOAGoool001Coool4
NW]l17YjN`AiNW/4NGUj17QiNPMgN7T<MWMh17EfN1=eMWL4MGIh17EgN0=fN7T4MgUj17QjN`AjNg`4
Ngan17enO`AnOh03OWj027ioP0AoP844Ph>318B4Q0>5QHH4QhN718R8R0B9RHT4Rh^;18f=SPB@T943
SHj>28j>S`R=SXh4SHf>0hb<S@B;Rh`4RXZ;18V9RPB8R8T4QhN818J7Q`>5QXH4Q8F518>4Q@B2Ph@4
PX:31861PP>0PH44Oh2117ioP0AnOWl4OGen17amOPAkO7dEoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo002Foooo0`0008Ooool009Woool0
0`000?ooooooo`24oooo001noooo0`0000Coool200001?ooo`@00002oooo0`0000?oool300000ooo
o`800021oooo0020oooo00D0003oooooooooool000000_ooo`040000oooooooo00000_ooo`040000
oooooooo00001Oooo`040000oooooooo0000Q_ooo`00Ooooo`<00002oooo00@0003oooooool00002
oooo00@0003oooooool00002oooo100000;oool010000?ooooooo`0008Koool007koool010000?oo
ooooo`0000;oool010000?ooooooo`0000?oool300000oooo`800004oooo100008Goool007koool0
10000?ooooooo`0000;oool010000?ooooooo`0000Goool00`000?ooooooo`2@oooo001ooooo0`00
00?oool200001Oooo`80002Boooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Ooo
o`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(112) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
92838292838192838192828091828091828091817F91817F91817F90807E90807E90807E
907F7D907F7D8F7F7C8F7E7C8F7E7C8F7E7B8F7D7B8F7D7A8F7D7A8F7C798E7C788E7A77
8F7C798F7D7A8F7D7B8E7D7B8E7D7B8E7D7B8E7D7B8E7C7A8D7C7A8D7C7A8D7C7A8D7C7B
8D7D7C8E7E7D8E7F7E8E807F8F81808F818090828190838290848491868692878793898A
958C8D938989938786928685928584928584928584928583928483928483928483928483
928482928482928482928482
92838192828091828091817F90807E90807E8F7F7D8F7E7C8F7E7B8E7D7B8E7C7A8D7C79
8D7B788D7A788C7A778C79768C78758B78758B77748B76738B76728B75718B746F8B736E
8B75718B75728B76748B76748A77748A7674897673887573887573887473887574887575
887776897978897A7A8B7C7C8B7E7D8C7F7F8D80808E82838F8586908889928B8C948F91
959193948C8D92898A928888918787918686918685918584918584918584928483928483
928483928483928482928482
92838191828090817F90807E8F7F7D8F7E7C8E7D7A8D7C798D7B788C7A778B79768B7875
8A77748A767389757189747088736F88726E87716D87706B876F6A876E69876C67866B65
876D68876F6B876F6C87706D86706D86706D856F6D846F6E856F6E856F6E846F6F857171
867373867575877777877979887A7B897D7D8A7F808B82838D86878F898B928D90959397
959295938E90928B8C91898A918888918787918686918685918585918584918584918483
918483928483928483928482
92828191817F90807E8F7F7D8E7D7B8D7C7A8C7B788B79778B78758A7774897672887471
87736F87716D86706C856E6A846D69846C67836A6583696482686282666182655F83645D
836761836864836965836A67836A67826A68826B69826B6A836B6A836C6B826D6C836E6D
836F6F847171847273847576857879877B7C887E808A82848C86888E8A8D918F92949498
939195928E91918C8E908A8B90888A908788908787908686908686908585918584918584
918483918483928483928482
91828090817E8F7F7D8E7E7B8D7C798C7A778B78768A777489757288747087726E86706C
856E6A846D68836B668269648167628066607F645E7F625C7E615A7E5F597E5E577F5E56
7F605A7F625D7F635F7F64617F65627E65637E66647E66657E67657E67667E69687F6A6A
806C6C806E6E817071817373837677847A7B867D7F8881838A85888C8A8E909094929499
919195908E918F8C8F8F8A8C8F898A8F88898F87888F86878F8686908585908585908584
918484918483928483928482
91828090807E8E7E7C8D7C7A8C7A778B787589767388747187726F85706C846E6A836C68
826A658168637F66617E645E7D625C7C5F597B5D577A5B547A59527958507A574F7B574F
7C5A547C5C577C5E597B5F5B7B605D7B605E7A605F7A605F7A61607A62617B64637B6565
7B67677C6A6A7C6C6D7D6F707F7474817778837B7D857F828784888A8A8E8E9196909399
8F90948E8D918E8B8F8E8A8D8E898B8E88898E87888E86878F86878F86868F8585908584
908484918483918483928483
9181808F7F7D8E7D7B8C7B788B787689767388747086726E856F6B836D69826A66806863
7F66617E635E7C615B7B5E58795C5678595377575076544D74514A744F47754E45775149
78554F785752785954785A56775B58775B58765B59765B5A765C5B765C5B765D5D765F5F
776262776565786868796B6C7B70707D74757F787A827D7F85838788898E8C90968D9196
8C8E938C8C908C8B8E8C898C8C888B8C888A8D87898D86888E86878E86868F85858F8585
908484918484918483928483
91817F8F7E7C8D7C798B79778A777488747186726E846F6B836C68816A657F67627E645F
7C615C7A5F59795C5677595376564F74534C735049714D456F49416C453C724A41765048
76524B75534E755450745551745552735553725553725554715554715555715756715959
715B5C725F60736364746768766C6D7971737C76787F7B7E82818586878C8A8E948A8E93
8A8C918A8B8F8A8A8D8A898C8B888B8B878A8C87898C86888D86878E86878E85868F8585
908585908584918483928483
90817F8E7E7B8C7B788A787588757286726F846F6C836C688169657F66627D635E7B605B
795D57775A5476575074544D725149704D456F4A426D463D6A4239694036764C43754E46
744E48734F49714F4B71504C70504D6F504E6E504F6E4F4F6D4F4E6C4E4F6C50506B5253
6C56576D5A5B6E5F606F636472686A756E707873757C797C7F7E82828489868A90878A8F
878A8E87898E88888C88888C89878B8A878A8A87898B86888C86878D86878E85868E8585
8F8585908584918483928483
90807E8E7D7B8C7A7789777487747085706D836D69816A657F66627C635E7A605A785C57
76595374554F72524B704F476E4B436C473F6B443B694037663C3171453A7A4F44744C43
714B446F4A456E4A466D4A476C4B486B4B496A4A4969494968494967494A674B4C674E4F
6852536956586A5B5C6C5F616F6567726B6D75707379767A7C7C8080818683868C83878C
84878C85878C86878B87878B87878A88868A8986898A86888B86888C86878D85868E8586
8F8585908584918484928483
90807E8D7C7A8B797689767286726F846E6B816B677F67637D635F7A605B785C56765852
73554E71514A6F4D466D49416B463D694239673E3463382D6C3F34764A3F74493F714840
6E47406C46406A464169464268464467464566454565444464424364444563464863494B
644E50655355665859685D5F6B62656E696B726F7276747879797D7C7D827E818680858A
81858A82868B83868B85868A86868A87868A8886898986898A86888B86878C85878D8586
8F8585908584918484918483
90807E8D7C798A787588747185706D826C698069647D65607A615B785D5775595373554E
70514A6E4C456B484069443C674037653C3263382E683B307244397044396F443A6D433C
6A423B68413B66413C65413E64423F6342406240406241416141426045455F4748604C4D
604F50615254625558645B5D6861636C676A706D7073727677777B7A7B807C7F857D8287
7F838980848A81858A83858A84858A85868A8786898886898986888B86888C86878D8586
8E85868F8585908584918483
8F7F7D8C7B798A7774877370846F6B816A667E66627B625D785E5876595473554F70514A
6D4C456B484068443B653F36633B3161362C5D3126683A2E6D3F336C40366B4037694038
663E37633C36613C38613D3B603E3D5F3E3D5F3E3E5E41405D44445D48475D4D4C5E5050
5C4F505D52535E5657615B5C6561636966686E6C6F71717574767A777A7F797D837B8086
7D83897D83897F848980848A82858A84858A8686898786898986898A86888B86878D8587
8E85868F8585908584918483
8F7F7D8C7B7889767386716E826D697F68647C645F795F5A765B5573565070524B6D4D46
6A484167433B643F36613A315F352B5C30256133276E3F326B3E33693D33673E35653C35
623A335F38335D38345D3A385B3A39593A3A5D42425E47465E4B4A5E4E4D5E4E4E5B4E4E
5950505A55565A56575E595B625F616765676C6B6F70717572757A74787D767B81777E84
7980877A81887C83897E838A80848A83858A85868A86868A8886898986888B86888C8687
8E85868F8585908584918483
8F7F7D8B7A7788757285706D816B687E67637A625D775D5874585271534D6E4E486A4942
67443C643F37613A315D352B5B3026582B2065372A6B3D31693D32663B32653C34623A33
5F38315B36315A36335737365B403E5F4846634E4C5F4C4B5D4E4C5C4D4C5A4C4B5A5151
5B53545A54565954565B595B605F616565686A6A6F6E717570747972777C73797F747C82
767F8677818A7982897C838A7F848A81858B84868A86868A87868A8986898A86888C8687
8D86868F8585908584918483
8F7F7C8B7977877471836F6C806A667C6560795F5B755A5572554F6E504A6B4B4468463E
644038613B325D352B592F25572B21582A1F693A2D693C30673B31643B32623B335F3932
5C3630593631593936593D3B6147456047455E47455C48465A4745584644564645574A4A
574B4B5850515B54555E5B5D605E6164636768696E6C70746E74786F757B70777E717A81
737D8474808876808779828A7E858B81868B83868B85878B87878A89878A8A86898C8688
8D86878E8586908584918483
8E7E7C8A7976867370826E6A7E68647B635E775D5873585270524C6C4D4669484065423A
623D345E372E59302651271C52251A5F30246D3E31683C31653A306239315F39325D3832
5A37315A3B375D423F604946634D4A5E4A475B4745594644574241544241534242534545
534747554E4E5750515B56595F5C5F636265686A6E6B70746C73786C73796D757C6E787F
707C83727E8675818979838C7E878D80878D83878D85878C87878B88878A8A87898B8688
8D86878E8586908585918483
8E7E7C8A787585726F816C697D666279605C755B567155506D4F496A4A4366443D633F37
5F39315C342A572D2351261B5A2E226A3C2F6A3E31653B306239315F3A325D39335B3732
583732583B375B413E5C45435C47455A4846584846574745554544534543524645524948
524C4C544F4F5650525955585D5B5E626265696C6F6A70746A72776A72786A747B6B767E
6D7A826E7C846E7C8577838B7E888F80888E83898E85888D86888C88888B8A878A8B8789
8D86878E8686908585918483
8E7D7B89777584716E806B677B6560775E5A7359546F524D6B4D46674740644139603C33
5D362D5B3128592D235E3023693A2C6D3F32663B30623A305F39315C39325B3933583833
563934573B3759413D58423F5744415644425444425343425142414F42414E44434E4646
4F494A504C4E53515356585A5C5F6162676A686F726A737668727767717868727A69757E
6B79816C7B846C7D877A88917E8A91818A91838A9085898F86898D88888C8A888B8B8789
8D87888E8687908585918484
8D7D7B88767483706D7E69667A635F755C587056516C504A68494364433C613E365E3830
5B332A592F24592C205C2F225F332861372C60382E5E38305B3932593932573933563833
543834543A36543D3A543F3D53413F52413F51403F4F403F4D3F3E4B3F3F4A40404A4343
4B46474C4A4C504F52545659595D605E6467626A6E66707466717765707865717A67747D
697881697A846A7C877B8A937F8C94818C92838B91858B90868A8F88898D8A898C8B888A
8D87898E8687908585918584
8D7D7B887673826F6C7D686478615D735A556E534E694D476546406140395D3A325A342C
582F25562B2056291D572A1F582D235931285B352C5A362F583731563731543732533632
523632513835513A38513E3B503E3D4F3E3D4D3C3C4B3D3C493C3C473C3C473D3F464042
4844474B484C4F4F52535559585D615C63675F686D636D73636E75626E7663707965747D
677881697A85687B877B8A937F8C94818D94838C93858C91878B90888A8E89898D8B888B
8C87898E87878F8686918584
8D7C7A877572816D6A7B6663765F5B7158536B504B66494462433C5D3C355A362E563027
542A2152261B52251A51261C532B2256302858332B56352E54352F5235305135304F3430
4E35314D37334D38354D3A394C3C3C4B3C3B493B3B483B3B463A3B44393B443C3E443F41
46444748474B4C4E5251555A555C615A61685D676E5F6B725F6C735F6D7661707964747D
677881697B856A7C87798891808E96828E96848E95858D93878C91888B8F898A8D8B898C
8C888A8E87888F8686918584
8C7C7A867472806C697A6461745D596E5551684E496346415E3F3959383155312A522B22
4F251C4D21164C21174C231A502B2353302853322B52342D50332E4F332E4D322E4C322E
4B322F4A3431493533493837493B3A483A3A46393944383943383941373940383B403C40
42414546474B4A4E524E545A535B6157616859656D5A676F5B69725D6C755F6F7862737D
6677816B7C8771818B7D8A93818F98849199859097868E95878D93888C90898B8E8B898C
8C888A8E87888F8686918584
8C7B798573717E6B6878635F725B576B524E654B465F433D5A3B3555342D502C254D251D
491E15471A11461B1348231B4D2C254F2F284F312B4E312C4C312C4B302C492F2B482F2C
472F2D46312E4533314637364639394538394336374136383F34373D34363C36393D3A3E
3F3F4443454A464B514B5259505A61535F6655626A55636C57666F5A68725D6C7760717B
6576816B7C8771828C7B8C968697A18A99A286929A868F97868E94888C92898B8F8B8A8D
8C898B8E87898F8686918584
8B7B798472707D6A6776615E6F585568504C6247435C3F3A563731502F294B2720472018
43191141180F421C1546261F4B2D264D2F294C302A4A2F2B492F2A472D29452C29442C29
432C2A422D2C4230304233344335374136384035373E35373C33363933363935393A393E
3C3E4440444A444B524A535A4D58604F5C64505E6751606953636D5666715A6A755E6F7B
637580687B876F808B77899480939E83939D84929A859097868E95878D93898C908B8A8E
8C898C8E88898F8687918584
8B7B7983716F7C6866745F5C6C5653654D495E4440573B3751332D4B2A2445221B3F1911
3C150C3A160E3D1D16432720492D27492E29482E29472D29452C28432A274129263F2827
3E28283E2A2A3E2D2E3F31323F33353E33363D33363B333639313536313536333837383E
3A3E443E444B424B5246505848545D4A58614B5A634C5C674F606B52636F5668745A6E79
5F747F657A856C7E8A738793798E9A7E909A81919A839098858F96878E93898C918A8B8F
8C8A8C8E888A8F8787918585
8A7A7882716E7A6764725D5A6A5451624A475A413D5337334C2E294525203E1C1637120B
320E0830110C371B16412722462D27472D29462D28442B27422A263F28253D27253B2625
3926263A29293B2C2D3C2F313C31343C32353B323639323536303434303533333835373D
373D433B434A3E4850414D5643505A44535D465661485A654A5D694E626E526773566C78
5C717E627783677A866E8490768A957D909B80919B829099858F97878E94898D928A8C8F
8C8A8D8E898A8F8787918585
8A7A7881706D786563705B5967514E5E4744563D3A4E332F4629253F201B371711300D07
290B072C120E351C18412924452D29452D29442C28422B273F29263C2625392524372425
35242536262737292B392D2F3A30333A3235393236373135342F34312F3430313832363C
343B4237404939454E3B49533D4C573F4F5B40535E435662465B674A5F6C4E6471536976
586F7C5D74816278846A818E7388957B929F7E929C81919A849098868F96888E938A8C90
8C8B8D8E898B8F8788918685
897977806F6D7764626D5A57644F4C5B4441513936482F2B402521381B1731120D2A0B06
270C092D1512361F1C452D28462F2A452E2A442D2A412B283C2726382423332121302021
2F202231242635292B372C2F3930333A33373833373632373230352F2F352E31372F353B
303942333E4734424C3545503749543A4D583C505C405561435966475E6B4B62704F6775
546C7B59727F5D7583667D8C7189967A94A17E939F81929C849199869097898E948B8D91
8C8B8E8E898B908888918685
8979777F6E6C7563616B5856614C4A57413F4D3533432A27391F1C3115122A0C08250805
1F080727131237221F48312B48322D46302C442F2C412C2A3D29283826263324252F2225
2E2225312628352B2D372E313931353B363A39363A3533393131362E2F352C30372C343C
2C37412F3C4630404B31424E334552354956374D5A3C5360405765445C6A47606F4B6574
506B7A55707E5A7483667F8E728C9A7A96A47E95A181949E84929B879198898F958B8E92
8D8C8F8E8A8C908889918685
8878777E6D6B7462606956545E4A48533E3C4832303C2523311916290E0C230805200706
1F0B0A2C19173C27234C35304A353048332F45312F422F2D3E2D2D3B2A2B3A2B2C36292B
372A2C3B2F303D34363F3739413C3F403E423B3A3F35363C3132382D2F362A303829323C
28333E2B3A452A3C48293D4A2B404E304654344C5A3A515F3E5664415A69455F6E496474
4D6979506D7D56728363808F728E9D7B99A77E96A381959F84949C8792998990968B8F93
8D8D908F8B8D908889918686
8878767D6D6B72615F6755535C4847503B3A432E2C361F1E2811101A01001B02011C0807
1F0E0E2C1B1A3E2A274F39334D37334A35324633314331304030303E2F303D2F313C2F31
423536463A3A483D3E484041454144403F443B3B4136363D3031382C2F372A31392A343E
2A37422C3E4A273C49233B4A2A41502F4756314A5938505F3C5564415A69435F6F466374
4A67784B6A7B517182618090718F9E7B99A77E97A38296A185959E88939B8A92988C9094
8E8E918F8B8D90898A918686
8778767C6D6B71605F6554535947464D3A383F2B2A301B1A1C0706150000190505180809
1D0F102E1E1C432E2A533D37503A374C38364734344433334233343F32343E32343E3336
413639443A3D463F424742454442464040453B3C4335373E30323A2C31392A323B2A3640
2C3A452E3F4B2E404C2C414F354856364C5A394F5E405664425A69445E6E436071446374
46657745677A507183628090738E9D7B98A77F98A58398A28697A089959D8C93998D9196
8F8F92908C8E91898A928786
8778777C6C6B70605E6453525846454B38383D2A292D1A191C08081C09091E0C0D211213
26181837252348332F56403B533E3A4F3C3A4B3A394739394336373F33353D32353C3337
3D3639403A3E423D414340444242473F40463A3C4334373E2F333B2B323B29323C293540
2A39452C3E4B2F414E3447543E4F5C3F5360415663465B69455D6C425F6F416071416274
41647742667A51738564829274909E7D9BA9819AA7859AA48899A28B979F8D959B8F9397
909093918D8F928A8B928786
8778767B6C6A705F5E6453525746454A38383C2A2A2D1B1B1D0B0B1E0D0E211112271818
30201F3E2C294C383458423E55413E51403E4E3E3E4A3D3E483D3F463C3F433C3F453E41
47414449444748454948464B45464B3F4148393B4333363E2F333C2B333D29323E273440
2737452A3C4A2D404F314654374C5A3B515F3E5665415A693F5B6C3F5C6F3E5E713E6073
3C61753F657A5274876986967591A07D9CAB829CA8879CA78B9BA48E9AA190979D919499
929195928E90928B8B928787
8778767B6C6A6F5F5E6353525746454A39383C2B2B2E1D1D200E0F2212122717182D1E1E
35252442302E503B3859443F5744415343414F41414C41424A40424941444944474B4649
4A474A4A484C49484D47474D41444A3C3E4636394131363E2E343D2C343E2B36412B3845
2A3B49293D4C293E4E2D4353324959354E5D3852623A55663B586A3B5A6D3B5D703B5E73
385E7440667C55778A698696718E9D7998A7859FAB8BA0AA8F9FA7919DA4929AA093979B
939396938F91938C8C938887
8778767B6C6B6F605F6354535747464A3A3A3D2D2D301F1F2211122516172B1C1C322222
3C2A29483432523E3B5A45415946445545445143444D43444B4244494246484347474348
4643484543494342484041473C3E45383B4233373F30343D2D333D2B343F2B36422B3946
2C3D4B2F42503044533046562E4858304A5C324E603552653756693A5A6E3A5C71375D72
365F75436A7F56788C658495718F9F7E9DAB90A9B492A6AF94A3AB95A0A7969DA296999D
969598959193948D8D938888
8778777B6C6B70605F6454545848474B3B3B3F2E2F3221222515162A1A1A2E1F1F362626
3F2E2D4A3735533F3C5945425847455546465145454E43454B4245484245464145444145
424045403F453D3D433B3B4237394034363E30343D2C323C2B323D29333F293542293745
2A3B492C3F4D2F4452334958364D5D3750613753643A56693A596D3A5B70365C70345D73
366077476E83587C8E6788997796A587A3B197AEB999ABB49AA8B09AA4AB9AA0A5999CA0
98979A979294958D8E948988
8778777C6D6B7061606555555949494D3D3D4030313424242717182B1C1C302122392829
41302F4A3836513F3C5744425847465648475246474E44474A4346474146444044413E43
3E3C423C3A4039383E36363D32343B2F323A2C303A292F3928303B27313E263340263543
273847293C4B2C41512F4657334C5C36506138546638566A37586C35596E335B70335C72
3963794A72865D80936E8E9E7F9CAA8FA8B49DB2BCA0B1B9A0AEB5A0A9AF9EA4A99C9FA2
9B999C999495978E8F958988
8778777C6D6C7162616556565A4A4A4E3E3F423233362627291A1B2E1F213325263A2B2B
4131314839384F3F3D5544435847465649495247484D4447494246454045413E433E3B41
3B393F37363D34343B31323A2E30382B2E37272C37252C38242D3A232F3C23313F233342
233646253A4A273F502B44552D485A2F4C5E31506331536730556A30576D2F5970305D74
3C677E50778B6285987493A386A1AF98AFBAA6B9C2ABBAC2A8B4BBA6AEB3A3A8ACA0A1A5
9D9B9E9B9597988F90958A89
8879777D6E6D7263626657575B4C4C50404144353538292A2C1D1E3123243628293C2E2E
4334344A3A3A504040564645584948584A4B5247494D4448484146433E433F3C413B393F
37363D33333A3030382C2E36292C35262A34232934222936212A38202C3B1F2F3E1F3141
203445213849243D4E2641532845582A495D2B4D612C50652D53692D566C2E5870346077
456E84577D906A8B9D7D9AA991AAB6A4B8C2B2C3CBB6C4CBB0BBC1ACB3B8A7ABAFA4A4A7
A09D9F9C9798999091968A89
8879787D6F6D7364636859595D4E4E5143434637383A2B2D2E2022332627392B2C3E3031
433536483A3B504141564645594948584A4A52484A4B4448464145403D423C394037363D
33333A2F30372B2D35282A332428322227311F26321D26341C28361C2A3A1C2D3D1C2F40
1D33441E3749203B4D223F5224425625465B274A5F284E642A51682A556C2E5A723A657C
4C74895F83967494A489A4B19EB3BEB1C2CAC2D0D7C0CCD2B7C0C5B1B7BBACAFB2A7A7A9
A29FA19E98999A9191968B8A
887A787E6F6E746564695B5A5E5050544546483A3B3C2E2F30232535282A3B2D2F3F3233
4336374A3C3D50424354464656494955494B50484B4A4448433F453E3B4138373E33333B
2F2F372A2C342628312326301F242E1D232E1A222F192432192635182938182B3C192E40
1A32441B35481D394C1E3D5120415622455A23495F254D642651682B576E335F76426C82
557C906B8C9E809DAB95ADB9A9BCC6BCCBD2CBD7DDC4CED3BCC4C8B6BABEAFB1B4AAA9AB
A5A1A2A0999A9B9292978B8A
897A797F706F7566666B5C5C6152525648484B3D3E403234342729392C2D3D3032413436
45393A4A3E3F4F424352464654484A50474A4D4649474347413E443A394035343C2F3038
2A2B3426283121242E1D222C1A202B181F2D161F2E152130142434152737152A3B162D3F
1731441834481A384C1C3D511E40551F445A20485F224C642651692C597137647B4A7389
5F84977594A58AA4B39FB5C0B5C5CEC9D4DBD3DDE2C9D1D5C1C6CAB9BDC0B3B3B6ACABAC
A7A2A4A19A9B9C9392978B8A
897B798071707668676D5E5E635555594B4C4F4142443638392B2D3D3031403436433739
463A3C493D3F4D42444F45474F46494C44484A44484441473E3C4237363E3031392B2D35
25283120242E1C212C181F2B151D2A131C2B111C2C101F2F11223411253712293B132B3F
142F4316334818374C193C511B40561D445B1E4860214D6527536C315E76416C82557D91
6C8D9F819EAE96AEBBADBFC9C4D1D8D9E3E7D9E2E6CDD4D7C4C9CCBCBEC1B5B5B7AFACAD
A8A3A4A39B9B9D9393988B8A
8A7B7A8172717869696F61606558585C4E4F524546483B3D3E313340343643373A453A3C
473C3E4A3F424C43454D45484C4548494348474348413F453A394132333C2C2E38262A34
2025301B212D161E2B131C2A0F1A290D19290C1B2B0C1D2F0D21330E24370F283B102B3F
122F4414334815384D173C521940571B455C1E4A62234F682C59713A667D4C758B628699
7897A88DA8B6A3B8C3BACAD2CFDADFDEE7EBD8DFE2CFD5D8C7CACCBFC0C2B7B6B8B0ADAE
AAA4A5A49C9C9E9493988C8B
8A7C7A827372796B6B716363685B5B60525357494B4D404243363843383A463B3D473D40
483F424A41444C43474D46494C464A4944494441473E3E453637402E313A272C36202632
1A222F151E2C111B2A0D192909172807172807192B081C2F0A20330B24380D273C0E2B40
102F4512344914384E163C531841591C465E214D6528556D3561794770865B80947091A3
86A1B19AB2BEB1C3CDC9D5DBDBE3E7E5ECEFDBE0E3D1D5D8C9CACDC0C0C2B9B6B8B2ADAE
ABA4A5A49C9C9E9493988C8B
8B7C7B8375747B6D6C7365656B5E5E6356575B4E4F5346484B3F41483D40493E414A4043
4C43464D44474E46494F484C4D474C49464B4442493D3E463337402B303B242A361B2432
151F2E0F1C2B0B192908172904152801152802182B041C300720350925390B283D0C2C42
0F314611354C143A51173F571B455D204A6327536B325E76436C82567C906A8C9E809DAD
95ADBAABBEC9C2CFD7D7E0E5E9F0F3EAF0F3DDE1E4D3D5D7CACACCC1C0C1BAB6B7B2ADAE
ABA5A5A59C9C9F9493998C8A
8B7D7B8476757D6F6E7668686E6161675A5A605354594C4E5246484B40424C42444D4447
4E46494E464A4F484D514A4E4F4A4F4C494F46454C404149373A442E333F232C39182433
101F2F0C1B2B08192A04172A00152900172B011A2F041E3306223808263C0A2B400C2F45
0E324911374F163D551A435B1F4962275169325C74406A8052788D66889B7B98A990A9B7
A6BAC5BCCBD3D2DCE1E4EAEDF0F5F7E8ECEEDEE0E2D4D5D6CACACBC2C0C1BAB6B7B3ADAD
ACA4A4A59C9B9F9493998C8A
8C7D7C8577767F7170786A6A7164646B5E5E6457595E5153574C4E50454850464952484B
524A4D534B4E534C50544E52534E534F4C5249484F43444C3C3E4832384326303E1C2939
1524341020320B1E31071C30041B30041D3206203507243909273D0B2C420C2F460E334A
12384F163D551B445C214A62295269335C7341697F51778A6486987995A68DA6B4A3B7C2
B9C8D1CFD9DFE1E7EBF1F4F7F5F8FAE8EAECDDDEE0D3D3D4CAC8C9C2BEBFBAB5B6B3ACAC
ACA4A3A59B9B9F9392998C8A
8C7E7D8678778072727A6D6C7467676E6162695C5D6357585D5253584D4F544A4C564C4F
564E51574F535851555A5357565257514E544B4A5144454E3E404A363B462C354224303F
1D2C3C192A3B1327391026390D25390D273B0E293D0E2C41102F4512334914374D173B52
1B405720465D264D642E556B375E7443697E5276896384957793A38BA3B1A0B4BFB6C5CE
CDD6DDE0E6E9EFF3F5FBFDFEF4F6F7E7E8E9DCDCDDD2D1D1C9C6C7C1BDBDB9B4B4B2ABAB
ABA3A2A59B9A9F9392998B8A
8D7F7D8779788274737D6F6F776A6A7265656D6061685C5D6357595F53555A50525A5153
5B52555C54575C55595C565A5854595451574E4D54494A524346503B414D323C4A2C3947
2836452534451F31431D31431B30431A31441A34471C374B1F3B4F22405424445826475D
2B4D62315368395B704163774B6D805778896785957993A28CA2AF9FB1BCB4C2CACAD3D9
DFE4E7EEF1F3FDFFFFFCFDFDEFEFF0E4E3E4DAD8D8D0CECEC8C4C4C0BBBBB8B2B2B1AAA9
ABA2A1A59A999E9291988B8A
8E7F7E897A798476757F71717A6D6D7568697164656D6061685D5E64595B6055585E5456
60575A61595C60595D5F595D5D585D5A575D5453594F4F57494B544046523B445037414F
323F4E2F3D4D2B3B4C2A3C4C293C4D283E4F2941522C445630485A334D5F355163395568
3E5B6E4562744D6A7B5471825F7B8B6C86957C93A18DA1AD9FB0BAB3C0C7C8D0D5DDE1E4
EEEFF1FDFEFEFFFFFFF4F3F4EAE9E9E0DEDED6D3D4CECACAC6C1C1BEB8B8B7B0AFB0A8A7
AAA0A0A499989E9291988B89
8E807E8A7B7A8577778173737D6F6F796C6C7568697165666E62636A5F61685D5E645A5C
665D60675E61665F62655F63635E635F5C615A585E55555C50525B494F59464D59424B57
3E49563C4855394756384756374858394B5A3B4E5E3E5161425666455A6A495F6F4E6474
546B7A5B728162788769808E7489978195A190A1ACA1AFB8B4BEC5C7CDD2D8DCDFEAEAEC
FBFBFBFFFFFFF6F5F5EDEBEBE4E1E1DBD8D8D2CECECAC5C5C3BDBDBCB5B5B5ADADAFA6A5
A99F9EA398979D9190988A89
8F807F8B7C7B8779788375757F72727C6F6F796C6C75696A7367687065666E64656E6465
6E65666D65676C65686C65686A64686863686360665F5D645B5B635559625257614E5560
4C545F4A535F4854604855614956634B58664D5B69505F6C5563715968755F6E7B637380
6A7A8670808C7686927E8E988998A198A3ACA7B0B7B7BDC3C7CBCFD8D9DBE9E7E8F8F5F4
FFFEFDF7F5F5EEECECE6E3E3DEDADAD6D1D1CEC9C9C7C1C0C0B9B8B9B1B1B3AAAAADA3A3
A79D9CA296959D908F988A88
8F817F8C7D7C887A798577778274747F72727C6F6F796D6D776B6C756A6B74696A74696B
746B6C756B6D746C6E736B6E726B6E706A6E6D686D69676C66666C62636B60626B5E616A
5C616A5A616B5B626C5B626D5B636E5D65705F6873626C7767707B6C7680717B8677828D
808992848D9689929B939BA39FA6ACABB1B6B9BCC1C8C9CCD7D6D7E5E2E3F2EFEFFCFAFA
F9F8F8EFEDECE7E3E3DFDBDAD7D3D2D0CBCAC9C3C2C2BCBBBCB4B4B6AEADB0A7A6ABA1A0
A69B9AA195949C8F8E978988
9081808D7E7D8A7C7B8779788477768274747F72727D71717B6F707A6E6F796E6F796E6F
796F707B71727B72747B7274797174777174767175747075736F746F6E746E6E746D6E75
6B6D756B6E766B6E776B6E776C70796E737B71757E747981787D857D818983888F898D94
8E919793979C9A9EA3A5A7ACAEB0B4B9BABDC7C6C8D5D2D3E2DEDEEEE9E9F9F5F5F8F5F5
EEEBEBE6E3E2DEDADAD7D2D2D0CBCACAC4C3C4BDBCBEB6B5B8B0AFB3AAA9AEA4A3A99E9D
A49997A093929B8E8D978987
9081808D7F7E8B7D7C897B7A8679788477768275758174747F73737E72727E72727D7273
7E73747F747680767780777981787A81797C80797C7E787D7D797D7B787D7C797E7D7A80
7D7B807D7B817C7B817C7B827D7D847F7F8581818885858B88888E8D8D91919095959498
9A999C9B9B9FA2A3A6ACACAEB6B5B7C3C0C2D2CDCDDED8D8EBE4E3F3EDEDF4F0EFEBE8E7
E4E0DFDDD8D7D6D0D0D0C9C9C9C3C2C4BCBCBEB6B5B9B0B0B4ABAAAFA5A4ABA09FA69B9A
A296959E92909A8D8B968887
9082808E807F8C7E7D8A7C7B887B7A877978857877847776837676827575817576817676
827777837879847A7B867C7D877F80877F81888083888184888185878186888387898488
8984898B868A8B878C8B878C8C888D8F8A8F918D919490939792959B96999D989BA39E9F
A5A0A2A9A4A6B2ACADBAB5B5C5BEBED1C9C8DAD3D2E6DDDCEEE8E7EDE8E8E7E2E1DFDAD9
D9D3D2D3CCCCCDC6C5C7C0BFC2BAB9BDB5B4B8AFAFB4AAA9B0A6A5ACA1A0A89C9BA49897
A094939D908E998C8A968886
9182818F817F8D7F7E8C7E7D8A7C7B897B7A887A79877979867978857878857878857979
857A7A867B7B887D7D897F808D838492888A91888A90878A8F878A90898D938C8F978F92
989093978F939690939A92959D94969D94969D94979F9698A1999AA49B9BA59D9DABA2A2
ADA4A4B3AAA9B9B1B0C1B9B8CBC2C1D5CBC9DBD2D1E6DEDDE5DFDEDED8D7D9D2D1D3CCCB
CEC6C5C9C1C0C4BBBABFB6B5BBB2B0B6ADACB2A9A7AFA4A3ABA09FA89C9BA49997A19594
9E91909B8E8C988A89958785
9182819081808E807F8D7F7E8C7E7D8B7D7C8A7C7B897C7B897B7B887B7B887B7B887C7B
897C7C897D7D8B7F7F8C81828F8485928889968C8D978D8F998F919A91939C92949D9496
9E94969F9597A19798A29798A19696A09596A39898A49998A59A99A79C9AABA09FAEA3A2
B2A7A5B7ADABBEB4B2C5BCBBCCC2C1D2CAC9D9D2D1DCD5D3D5CDCCD0C8C7CBC3C2C6BEBD
C2B9B8BEB5B4BAB1AFB6ADABB3A9A7AFA5A4ACA1A0A99E9DA69B99A49896A195939E9290
9C8F8D998C8A978988958685
9183819082809081808F807F8E807E8D7F7E8C7E7D8C7E7D8B7E7D8B7E7D8B7E7D8B7E7D
8B7E7E8C7F7F8D81808E8282908585938787968A8B9A8F8FA19696A39899A29697A29797
A4999AA59899A49898A39797A39797A49898A69A99A79B9AAA9E9CAC9F9DAEA2A0B1A4A2
B4A8A6B7AEACBCB2B1C4BBBACAC1C0CDC5C4CDC5C3C8BFBEC4BBBAC1B7B6BDB3B2BAB0AE
B6ACABB3A9A7B0A6A4AEA3A1ABA09EA89D9BA69A99A49896A195949F93919D908F9B8E8D
9A8C8A988A88968886948684
9284829183819182819082808F81808F817F8E807F8E807F8E807F8E807F8E807F8E807F
8E80808E81808F8281908382918584938686958988988C8B9B8F8E9E9191A19493A59997
A59998A49796A59897A49798A29696A39796A39795A49896A79A98A89B99AA9D9BAB9F9D
AEA2A0B6ABAABAB0AEBDB3B1BBB1AFB9AFAEB8AEACB6ABAAB4A9A7B1A6A5AFA4A2ADA1A0
AA9F9DA89D9BA69A99A59897A39695A19593A093919E91909D8F8E9B8E8C9A8C8B988B89
978988968886958685948583
928482928382928381918381918281918281908280908280908280908280908280908281
908281908281918382918482928483938584948685958887978988988B899A8C8B9B8D8C
9C8E8D9C8E8D9C8F8D9C8F8E9E918FA19491A29492A39693A49795A59896A69997A89A98
A99D9BAB9E9CA79B99A79B99A79A99A69A98A59997A49896A39695A29593A19492A09291
9E91909D908F9C8F8D9C8E8C9B8D8B9A8C8B998B8A988A89988A88978987968886958786
958785948684948583938483
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?ooo`BBPh88TX>119:2P0NAPX0<TH5o2i20OPR@Ogd4Sgml28mn
O0B?OW/3Sgek28mmNPB?O7T4SWah18ijM`B?O7T3Sgej18mmNa2>OG/3SWaj38elNPB=O7/4SGel18in
O@>>Ogh4SX1o28n1P0B@PX44T8>20i24Q0BAQXH4TXN719>9RPBES8d4ThV919>7QP>BQXD<TXF419:5
P`nBQ8<@TXB25Oooo`005?ooo`BBPh88TX>119:2P0NAPX0<TH5o2i20OPR@Ogd4Sgml28mnO0B?OW/3
Sgek28mmNPB?O7T4SWah18ijM`B?O7T3Sgej18mmNa2>OG/3SWaj38elNPB=O7/4SGel18inO@>>Ogh4
SX1o28n1P0B@PX44T8>20i24Q0BAQXH4TXN719>9RPBES8d4ThV919>7QP>BQXD<TXF419:5P`nBQ8<@
TXB25Oooo`005?ooo`BBPh88TX>119:2P0NAPX0<TH5o2i20OPR@Ogd4Sgml28mnO0B?OW/3Sgek28mm
NPB?O7T4SWah18ijM`B?O7T3Sgej18mmNa2>OG/3SWaj38elNPB=O7/4SGel18inO@>>Ogh4SX1o28n1
P0B@PX44T8>20i24Q0BAQXH4TXN719>9RPBES8d4ThV919>7QP>BQXD<TXF419:5P`nBQ8<@TXB25Ooo
o`005?ooo`BBPh44TX:01962P0BAPGl7T81n18moO@B?OW`4Sgik18imN`B>O7X3SGai18ekN0B=NWP4
S7Yg18aiMPB<N7D4RgQe0h]gM0B;MW<4RgIb18]eL@B;M6l4Rg=^18]eL@>;MG88RgId18YgM0B:MW@4
RGIc1hQeL`B8M7<4R7Ed18QeM@B8MgH4RGUh0hUjNPB;O7`4Rgim18aoO`B=P804SX:30hn5QPB@R8T4
TX^<19B?T@BETI<4U8b=19:9RP>BR8P4THN71966QPBAQXD;THF449:4P`RBQ88Eoooo000Doooo19:3
P@BBPX04TH:01961O`N@P7h4Sgmm18mnO0B?OW/4SWek18ilNP>=O7T4SG]h18ejN0B<NWL4S7Uf18ah
M@B;N7D3RgMd18]fL`B;MW84RgEa18]dK`B;Lfh4RgEa0h]eLPR;MW@4RWMd18YfM0B9MW<7R7Ec18Qd
L`B8MG@4R7Ee18QgMPB9NGP3RGYj18]lO0B;OWd4S7mo18f0P0B>PX<3ShF61928R@BBRh`4U8nA19FA
T`BDS8d4TXV:0i:8R0BAQhL4THJ61966Q@^AQH@@TXB329:4PQGoool001Coool4TX>119:2P0BAPX04
TH5o1i20OPB?Ogd4Sgil18mnN`B>OG/4SWaj0helN@B=NgP4SGYh18ajM`B<NGH4S7Qe18]hM@>;Mg@4
RgIc18]fLPB;MG44RgA_18]cKPB;MG43RgEb28]fM0B:Mg@4RWId18UfL`N8MG<4R7Ac18QeM0B8MGD4
R7Mf18UiN0>9NWX4Rgal18]nO@B<Ogl4SH2018j2P`>?QHH4T8R919:;S0BDSi44UI6C19B<S@BBRHX3
TXR81967Q`BAQXH4THJ52i65Q12BQ8<8TXB25Oooo`005?ooo`BBPh44TX:01962P0BAPGl7T81n18mo
O@B?OW`4Sgik18imN`B>O7X3SGai18ekN0B=NWP4S7Yg18aiMPB<N7D4RgQe0h]gM0B;MW<4RgIb18]e
L@B;M6l4Rg=^18]eL@>;MG88RgId18YgM0B:MW@4RGIc1hQeL`B8M7<4R7Ed18QeM@B8MgH4RGUh0hUj
NPB;O7`4Rgim18aoO`B=P804SX:30hn5QPB@R8T4TX^<19B?T@BETI<4U8b=19:9RP>BR8P4THN71966
QPBAQXD;THF449:4P`RBQ88Eoooo000Doooo19:3P@BAPX04T85o1920OPB?Ogd3Sgil18imNPB=O7T4
SG]h18ajM`B;NGH3RgQe18YgM0B:MW<4RGEa18UdL0B8Lfl4R79^0hMaK@B7L6/4QfmZ18M^J@B7K6L4
QV]U18M]J0>7Kf/4Qfm/18M`K@R6L6d4QFm]0hA_KPR5Kfh4Q6m_18EaL@B6Lg<4QWEe0hMgM`B7NGT4
R7Yk18UmO@B:Oh04Rh:30hf6Q`B?RH/4TXf@19FCU`BETYD4Thj@19:;S0>ARHX4THR81967Q`BAQXH4
THJ51965Q@NAQH@8THB329:4P`BBQ88Eoooo000Doooo19:3P@BAPX04T85o1920OPB?Ogd3Sgil18im
NPB=O7T4SG]h18ajM`B;NGH3RgQe18YgM0B:MW<4RGEa18UdL0B8Lfl4R79^0hMaK@B7L6/4QfmZ18M^
J@B7K6L4QV]U18M]J0>7Kf/4Qfm/18M`K@R6L6d4QFm]0hA_KPR5Kfh4Q6m_18EaL@B6Lg<4QWEe0hMg
M`B7NGT4R7Yk18UmO@B:Oh04Rh:30hf6Q`B?RH/4TXf@19FCU`BETYD4Thj@19:;S0>ARHX4THR81967
Q`BAQXH4THJ51965Q@NAQH@8THB329:4P`BBQ88Eoooo000Doooo19:3P@BAPX04T85o1920OPB?Ogd3
Sgil18imNPB=O7T4SG]h18ajM`B;NGH3RgQe18YgM0B:MW<4RGEa18UdL0B8Lfl4R79^0hMaK@B7L6/4
QfmZ18M^J@B7K6L4QV]U18M]J0>7Kf/4Qfm/18M`K@R6L6d4QFm]0hA_KPR5Kfh4Q6m_18EaL@B6Lg<4
QWEe0hMgM`B7NGT4R7Yk18UmO@B:Oh04Rh:30hf6Q`B?RH/4TXf@19FCU`BETYD4Thj@19:;S0>ARHX4
THR81967Q`BAQXH4THJ51965Q@NAQH@8THB329:4P`BBQ88Eoooo000Doooo19:3P@BAPX04T85o1920
OPB?Ogd3Sgil18imNPB=O7T4SG]h18ajM`B;NGH3RgQe18YgM0B:MW<4RGEa18UdL0B8Lfl4R79^0hMa
K@B7L6/4QfmZ18M^J@B7K6L4QV]U18M]J0>7Kf/4Qfm/18M`K@R6L6d4QFm]0hA_KPR5Kfh4Q6m_18Ea
L@B6Lg<4QWEe0hMgM`B7NGT4R7Yk18UmO@B:Oh04Rh:30hf6Q`B?RH/4TXf@19FCU`BETYD4Thj@19:;
S0>ARHX4THR81967Q`BAQXH4THJ51965Q@NAQH@8THB329:4P`BBQ88Eoooo000Doooo19:2P@BAPGl4
T81n18moO@B>OG/3SGaj18akN0B;NGL4RgQe18YgM0B9MW83R7Aa18McK`B7LFd4QW1/18E^JPB4KFT4
Q6aW0h=ZI@B3JF@4PVQR189VH@B2IEl4PfAM18=WH@>3J6@4PfUU28=ZI`B2JVP4PV]Y0h9[JPB3JfX4
Pfa[189]K0B3KVd4Pfm_18AaL@>4LW<4Q7Ef18EhN@B7Ng`4R7j018Z2Q0><QXP4SXZ=196?TPBDU9P4
Ti6E19:>T@BAS8h3T8Z;1928RPB@QhP4T8N72926QP>@QHD8THF42964P`BBQ8<4TXB25Oooo`005?oo
o`BBPX44TH5o1920OPB?Ogd4SWek0helNPB<NgP4RgUg18]hM@B:Mg@4RGIb0hQdL@B7Lfl4Qg5]18I`
K0B5KVX4Q6eY18A/I`>3JVD4PfUT189XHPB2IV44PVEO18=TG@B3If43PfQT18=YI@R3JVL4PVYX189[
J@>2JfX4Pf]Z18=/J`B2KF`4Pfi]18=_K`B4LG43Q79c18AeMPB5N7T4Qg]l18QnP0B:PX@3S8J818j:
S@BASi84U9BH19>AU@BBSY44THb>0i2:R`B@R8X4T8N81927Q`R@QXH3T8F52965Q0RAQ8<4TXB319:4
PQGoool001Coool4TX:11961O`B@P7h4Sgmm18imN`>=O7X4S7]h18]iM`B;N7D4RWMd18UfLP>8M744
Qg=_18MaK@B6L6`4QFiZ18A]J@B4K6L3PfYU18=YI0B2J684PVIQ189UG`B3I5d4PfMQ0h=XI0B3JFD8
PfYW189ZJ0B2JfT3PV]Z18=[JPB3K6/4PVe/18=^K@B3Kfl4Q75a0hAbL`B4MGH4QGQi18MkO0B8OX04
RX:40hb6R0B>RXd4THnB19BDV0BCTID4TXjA196<SP>@RX/4T8R:1927R0B@QhL8T8J60i25Q@RAQH@8
THB319:4P`BBQ88Eoooo000Doooo19:2P@BAPGl4T81n18moO@B>OG/3SGaj18akN0B;NGL4RgQe18Yg
M0B9MW83R7Aa18McK`B7LFd4QW1/18E^JPB4KFT4Q6aW0h=ZI@B3JF@4PVQR189VH@B2IEl4PfAM18=W
H@>3J6@4PfUU28=ZI`B2JVP4PV]Y0h9[JPB3JfX4Pfa[189]K0B3KVd4Pfm_18AaL@>4LW<4Q7Ef18Eh
N@B7Ng`4R7j018Z2Q0><QXP4SXZ=196?TPBDU9P4Ti6E19:>T@BAS8h3T8Z;1928RPB@QhP4T8N72926
QP>@QHD8THF42964P`BBQ8<4TXB25Oooo`005?ooo`BAPX04T85n18moO@B>OW/4SGai0hajM`B;N7H4
RWMd18UeLPB8M704Qg9^0hI`K0B5KVX4Q6eX18=[IPB2JF@4PFMR181VH0=oI5h4Of9L17iQFPAnGeT4
OUiG17mNEPAoH5X3Of9M17mSG`AoI644OfER17iUH`AnIV@3OVIU17iWI@AnIfH4OVUX17mZJPB0K6`4
P6i^0h5`L@B1Lg<4PgIg18AjN`B6OGl4R8630hZ5R0B<RXh4T92D19:DV@BATID4T8jA18n<S`>?RX`4
ShV:18n8R@B?QhP4ShJ718n6QPN@QHD4T8F41964Q0BAQ8<4TXB319:4PQGoool001Coool4TH:01921
OPB?Ogd4SWik18elN@><NWL4RgQf18YgM0B9MG84R7A`18MbKP>6L6`4QFiZ18A]J0B3JfH4PVUT185W
HPB0IV03OfAN17mRG0AnHEX4OUmI17iNE`AoGUH4Of1J0gmRG@AoHel4OfAQ17mUHPAnIF<4OVIT0giV
I@AnIfD4OVMV17iYJ0AoJVX4P6a/181^KP>1L744PG=c18=fM`B4NW/4QWeo18R1P`>:QHP4S8Z>192@
U0BBU9T4TI6E192>T@B?S8l3ShZ<18n9RPB?R8T4ShN818n6Q`B?QXH7T8F51925Q0BAQ8@4THB319:4
P`BBQ88Eoooo000Doooo1962P0B@PGh4Sgmm18inN`B=O7T3S7Yg18]hMPB:Mg@4RGEb18QdL0B7LVh3
QW1/18E^JPB4KFP4Pf]V189YI0B1If84P6IP0gmTGPAoHU`4OV5J17iOF@AnGUL4OeiF17mPFP=oHUd4
Of=O17mTH@AoIF84OVES17iVI0=nIVD4OVMU17iWIPAnJFP4OfYZ181/K0B0KVh3PG1a185cL`B3MWL4
Q7Yk18ImO`B8PH<3RXF818b:SPB@T9@4TYBI196AU@B@SY44Shb?0hn:S0B?RHX4ShR918n7R0B?QXL4
ShJ61i25Q@B@QH@4THB41964P`BBQ8<4TXB25Oooo`005?ooo`BAPX04T85n18moO@B>OW/4SGai0haj
M`B;N7H4RWMd18UeLPB8M704Qg9^0hI`K0B5KVX4Q6eX18=[IPB2JF@4PFMR181VH0=oI5h4Of9L17iQ
FPAnGeT4OUiG17mNEPAoH5X3Of9M17mSG`AoI644OfER17iUH`AnIV@3OVIU17iWI@AnIfH4OVUX17mZ
JPB0K6`4P6i^0h5`L@B1Lg<4PgIg18AjN`B6OGl4R8630hZ5R0B<RXh4T92D19:DV@BATID4T8jA18n<
S`>?RX`4ShV:18n8R@B?QhP4ShJ718n6QPN@QHD4T8F41964Q0BAQ8<4TXB319:4PQGoool001Coool4
TH:01920OPB>OW`4SGaj18ajM`>;N7D4RGIc18QdL@B7LVl4QG1/18A^JP>3K6P4PVYU185XH`AoIV44
OVAN17eRG0AlGeT3NeeG17YKE0AjFE84NEQ@17YGC`AkEdl4O5YD0gaLE`AlGUT4NemK17]PG@AkH5h7
NV1O17YQH0AjHV44NfAS17]UI@AkIfL4O6YZ0ga/K@AmKg04OgAd185gN0B3Ngd4QGn20hN4R0B:RXh4
SY6F192CV@B?T9@4SXfA18j;S`>>RXd4SXV;18j8R@B>QhP4SXJ718n6Q`>?QXH4ShF51925Q0B@Q8@8
THB319:4PaGoool001Coool4TH:01920OPB>OW`4SGaj18ajM`>;N7D4RGIc18QdL@B7LVl4QG1/18A^
JP>3K6P4PVYU185XH`AoIV44OVAN17eRG0AlGeT3NeeG17YKE0AjFE84NEQ@17YGC`AkEdl4O5YD0gaL
E`AlGUT4NemK17]PG@AkH5h7NV1O17YQH0AjHV44NfAS17]UI@AkIfL4O6YZ0ga/K@AmKg04OgAd185g
N0B3Ngd4QGn20hN4R0B:RXh4SY6F192CV@B?T9@4SXfA18j;S`>>RXd4SXV;18j8R@B>QhP4SXJ718n6
Q`>?QXH4ShF51925Q0B@Q8@8THB319:4PaGoool001Coool4TH:01920OPB>OW`4SGaj18ajM`>;N7D4
RGIc18QdL@B7LVl4QG1/18A^JP>3K6P4PVYU185XH`AoIV44OVAN17eRG0AlGeT3NeeG17YKE0AjFE84
NEQ@17YGC`AkEdl4O5YD0gaLE`AlGUT4NemK17]PG@AkH5h7NV1O17YQH0AjHV44NfAS17]UI@AkIfL4
O6YZ0ga/K@AmKg04OgAd185gN0B3Ngd4QGn20hN4R0B:RXh4SY6F192CV@B?T9@4SXfA18j;S`>>RXd4
SXV;18j8R@B>QhP4SXJ718n6Q`>?QXH4ShF51925Q0B@Q8@8THB319:4PaGoool001Coool4TH6018mo
O@B>OG/4S7]h18]hMP>9MW<4R7A`18IbKPB5Kf/4PfeY189ZIP>0J6<4OfIQ17iSGPAlHE/4NeiH17UL
EPAhFE<3MeM@17IDC@AdDDX4M4m717E>A@AgDDT4N5E?0gQGDPAhFE@4N5YF27MKF0AfFeT3MU]J27IL
F`AfGEd4MUmO17MRHPAgIFD3N6QX17U[K0AkL704OGAe17mhNPB2OGl3QH>718R9SPB<T9H4SI6F18b>
T`B<S904S8^>0hb9S0B<R8/4S8R:18f7R@B=QXP4SXJ70hj6QPR?QHD4T8B41964Q0BAQ8<4TXB35Ooo
o`005?ooo`BAPH04Sgmm18imN`B<NgP4RgQf0hUfL`B8M704QW9^18E_J`B3KFT4PVYV0h1XH`AoIV44
OV=N17aQF`AkGUP4NEaF17QID`=gEe04MUA=17AABPAdCdL4MDi517MAB@AhEDl3N5MB17QIE0AhFUH8
Me]H17IKF@=fFeX8MUaK17IMG@AfGel4Mf9R17MUI@=hJ6P4NF]/17]`L0AmM7D4OgQj189mO`>5PhL4
R8V>18b@UPB=TIH4S8jC18b<T0B<Rhh3S8V<18b8R`B<R8X4SHN918f6R0B>QXL3SXJ628n5Q@B@Q8@4
THB41964P`BBQ8<Eoooo000Doooo1961P0B?Ogd4SWek18akN0B;N7H3RGIc18QdL0B6LVh4QFm[18=]
J@B2JVH3P6QS17mVH@AnHeh4O65K17]NF0AiG5H4N5UC0gMGD0AfE4d4M55:17A?A`AeCTD4Me5917QE
C`=hEe84N5UD17QJEPQgFeP4MU]I0gIKFPQfG5/4MUeM17IOG`AgHV84MfEU0gQXJ0AiJf`4Ng1`17ed
M@AoN7X4PWeo0hF3Q`B8RHh4S92F18fAUPB<SY<4S8b@18b;SP><RH`4S8R;18b8RPB=QhT4SHJ818j6
Q`>>QXH8ShF51924Q0BAQ8@4THB319:4PaGoool001Coool4TH6018moO@B>OG/4S7]h18]hMP>9MW<4
R7A`18IbKPB5Kf/4PfeY189ZIP>0J6<4OfIQ17iSGPAlHE/4NeiH17ULEPAhFE<3MeM@17IDC@AdDDX4
M4m717E>A@AgDDT4N5E?0gQGDPAhFE@4N5YF27MKF0AfFeT3MU]J27ILF`AfGEd4MUmO17MRHPAgIFD3
N6QX17U[K0AkL704OGAe17mhNPB2OGl3QH>718R9SPB<T9H4SI6F18b>T`B<S904S8^>0hb9S0B<R8/4
S8R:18f7R@B=QXP4SXJ70hj6QPR?QHD4T8B41964Q0BAQ8<4TXB35Oooo`005?ooo`BAPGl4Sgil18el
N@B;NGL4RWMd0hQdL@B6LVh4Q6m[18=/J0B1JVD4OfMR0giTG`AlHE`4NUmI17ULEPAgFE<4MUI?17AC
C0=cD4T4LDe516m9@@A/AC`4LTY117I@B0AfDT/3ME=>17EDD0AdEE44M5EB17=ED`AbEE<3LUED175E
E0AaEED4LEMF175IF@AaFe`4LUmP0g=SI0AdIfP4MVa]17UaL`AlMWP4Og]n0h:1Q@B6Qh`4RXjD18Z>
T`B:S944RX^?18Z:S@>:RH`4RhR;18^7RPB<QhT4S8J818f6Q`>>QXL4SXF618n5Q@B@QHD4T8F41964
P`BBQ8<Eoooo000Doooo1961O`B?OW`4SGai18]iM`B:Mg@3R7Aa18IbKPB4Kf/4PfaX185ZI@AoIf83
OVAO17aQG0AjGeT4NEaF17MID`AfETl4M5=<0g=@B@AaCDD4KdU116a5?0AbBT44MU1817IBB`=eDdh4
MEA@17AED@AdEE84LeEC179ED`=bEE@4LEED175EE@AaEeH4LEUI175KG0AbGf03Lf=T17AWJ0AfK6d4
NG5c17afN0AoNgh3PX6518J7S0B:SY@4RXjC18Z<T@B:Rhl4RXZ=0hZ9S0B;R8/4RhN:18b7R@B<QXP4
SHJ70hj6Q`B>QHH4ShF51925Q@B@QH@4THB319:4PaGoool001Coool4TH5o18mnO0B=O7T4RgUg18Yg
M0>8M744QW9^18A_J`B3K6P4PFYU17mWHP=nI5l4O65L17YOF@AiG5H4MeUC17IFC`AdDd`3Le19175=
A@A_BD44K4Dl179:@@AfD4P4MU9;0gECCPAeE504M5EA17AEDPAcEE<4LUEC0g9EE0AaEE@4LEEE175G
EPAaFET4LE]L179OH0=cHf@4M6MX17I/K@AiLG<4O7Ih17mkOP>2PHD4QXN<18Z>U0B:SY<4RXbA18Z;
S`B:RXd3RXV<18^8R`B;QhX4S8N918b6R0B=QXL3SXJ718j5QPB?QHD4T8F51925Q0BAQ8<4TXB35Ooo
o`005?ooo`BAPGl4Sgil18elN@B;NGL4RWMd0hQdL@B6LVh4Q6m[18=/J0B1JVD4OfMR0giTG`AlHE`4
NUmI17ULEPAgFE<4MUI?17ACC0=cD4T4LDe516m9@@A/AC`4LTY117I@B0AfDT/3ME=>17EDD0AdEE44
M5EB17=ED`AbEE<3LUED175EE0AaEED4LEMF175IF@AaFe`4LUmP0g=SI0AdIfP4MVa]17UaL`AlMWP4
Og]n0h:1Q@B6Qh`4RXjD18Z>T`B:S944RX^?18Z:S@>:RH`4RhR;18^7RPB<QhT4S8J818f6Q`>>QXL4
SXF618n5Q@B@QHD4T8F41964P`BBQ8<Eoooo000Doooo1921O`B>OW/4S7]h18YhM@B8MG83QW9_18A_
K0B3K6P4PFUU17mVHPAmHeh3Nf1K17UME`AgFU@4MUM@17ADC@AbDDT4L4e50fm:@PA]ASd4JT8i16U0
=PAfC4<4MDi617A>B0=cCdT4LDm;175@C0A`D4d4Ke1>16i@C`=^Cdl4KDm>16a>C`A/D504Je9C16aF
E`A]FU/3KUmP16mSI0AbJ6X4MFi`17QcM@AlNG`3Ogj218:4R@B6RY04QhZ?18N:SPB7RHh7R8R<18V7
R`B:QhX4RXN918^6R0B<QXL3SHJ718j5QPB>QHD4ShF51925Q0BAQ8<4TXB35Oooo`005?ooo`B@PGl4
SWik18akN0B:N7D4R7Eb0hIbK`B4Kf`4PfaX185YI@AoIV84OF=N0g]PF`AiGEL4MeYD17IGD0AdE4d4
LU59171=A@=_BT84KDHm16Y2>@AY@3H4MTa317E>APAdCTP3Ldm9175?B`AaD4`4L51=16m@CPA^D4l3
KTm?16e?CPA/CTl4K51@16]BD`A/EUL4KEYK0fiOH0A_Hf@4LVQZ17E^L0AhLgD4O7Ul0gmnPPB2Q8T4
QXZ@18N:S`B7RXh4QhV>1hR8S0B9Qh/4RXN:18Z7R@B;QXP4S8J70hf6Q`B>QHH4SXF518n5Q@B@QH@4
THB319:4PaGoool001Coool4T85o18inN`B<NgP4RWQe18QeLP>6LVl4Q6m/18=/J0B1JFD4OfIR17eS
GP=kH5/4NEeG17MJE0AfEe04M5A=179AB@A`CDD3KdY216e6?@AZ@ST4JD0f17I<@`AeCTH4M4i80g=?
B@AaCd/4LE1<171@C@A_D4h4KU1?0fi?C`A]Cdh4K4i?16a@D0A[DU<4K5IG16eJF`=^Gf04Kf=T179X
JPAeKW04N7=e17aiO0=oOX84PXB918J:T0B7RXl4QhZ>18N9SPN8R8`4RHN;18Z7RPB:QhT4RhJ818b6
Q`>=QXL4SXF618j5Q@B?QHD4T8F41964P`BBQ8<Eoooo000Doooo1921O`B>OW/4S7]h18YhM@B8MG83
QW9_18A_K0B3K6P4PFUU17mVHPAmHeh3Nf1K17UME`AgFU@4MUM@17ADC@AbDDT4L4e50fm:@PA]ASd4
JT8i16U0=PAfC4<4MDi617A>B0=cCdT4LDm;175@C0A`D4d4Ke1>16i@C`=^Cdl4KDm>16a>C`A/D504
Je9C16aFE`A]FU/3KUmP16mSI0AbJ6X4MFi`17QcM@AlNG`3Ogj218:4R@B6RY04QhZ?18N:SPB7RHh7
R8R<18V7R`B:QhX4RXN918^6R0B<QXL3SHJ718j5QPB>QHD4ShF51925Q0BAQ8<4TXB35Oooo`005?oo
o`B@P7h4SWek18ajM`B9Mg@4QgA`0hE`K@B3KFT4PFYU17mVHPAlHeh4NV1J0gQLE`AfFE<4M5E?179B
B`A`CdL4KT]316a7?`=[A3/4JD0g16Hl<@AaACX4NTm417A<@`AaBd@3KdY516i:APA]BTL4K4]816];
B@AZBTT3JDU916Q9B@AWBDX4Id]<16M>C`AXDU<4JEIH0fYKG0A/Gf44KfEW179[K@AeL7<4NGIj0gal
P0B0PHH4PhJ<18>7S0B4Qh`4QHN<18J7R`>7Qh/4QhN:18R6RPB9QXT4RXJ818^6R0><QXL4SHF618j5
QPB?QHD4T8F41964Q0BBQ8<Eoooo000Doooo1920OPB>OG/4S7Yg18UgM0B7M703QG1]18=]J@B1JVD4
OfIR17aSGPAjH5X3N5aG17IID`AdEDl4LU9;171?A`A^Bd<4K4Lo0f]4>`AY@3L4IS`a1755>PAjCd@4
M4a3175;A0=_BTD4KTY616e:A`A/BdP4Jd]916Y:B@=YBDT4J4U916M9BPAWBd`4Idi?16QBD`AYEUP3
JU]L16aOH@A_IFL4LV]]17E`L`AiMWX3O7b01821QPB3QX`4PhN<18B7S0B5Qh`4QXN;0hN7R`B7QhX4
R8J:18V6R@B:QXP4RhJ80hb6Q`B=QHH4SXF618n5Q@B@QH@4THB419:4PaGoool001Coool4T81n18im
N`B<NWL4RGMd18MdL0>5L6d4PfeY185ZI@AoIV84O6=N17YPFP=hG5L4MUUC17AEC`AbDT/4L4m716i;
@`A/Acl3Jd@k16U0=`AV?344LDDj17Y?A0AdC4<4LD]40fm:A@A^BTH4KDY716a;B0A[BdT4JTY90fU9
B@AXBDT4IdU:16M;C0AWCTl4J59C16UFF0=ZFe`4K5mQ16mUI`AbJfd4MG1c17UfNP=lO804P86618>6
S0B3Qh`4Q8N<18F7S0B6Qh/3QhN;18N7RPB8QXX4RHJ918Z6R0B;QXP3S8J718f5QPB>QHH4ShF51925
Q0BAQ8@4TXB35Oooo`005?ooo`B@P7h4SWek18ajM`B9Mg@4QgA`0hE`K@B3KFT4PFYU17mVHPAlHeh4
NV1J0gQLE`AfFE<4M5E?179BB`A`CdL4KT]316a7?`=[A3/4JD0g16Hl<@AaACX4NTm417A<@`AaBd@3
KdY516i:APA]BTL4K4]816];B@AZBTT3JDU916Q9B@AWBDX4Id]<16M>C`AXDU<4JEIH0fYKG0A/Gf44
KfEW179[K@AeL7<4NGIj0galP0B0PHH4PhJ<18>7S0B4Qh`4QHN<18J7R`>7Qh/4QhN:18R6RPB9QXT4
RXJ818^6R0><QXL4SHF618j5QPB?QHD4T8F41964Q0BBQ8<Eoooo000Doooo1920OPB=O7X4RgUf18Uf
LPB6LVl3Q6i[185[I`AoIf<4OF=O17YPF`AhG5H3MUQB17=ECPAaDDX4Kde616e9@@A[ASd4JD8i0fLn
=0AS>2d4K3ld17I:?`AdBCl4LDQ016i7@0=/AT04JTI116U6@PAXAT@4IdI516I5A@=UA4@4I49316A4
A@ASATP4HdU;16A>D0AUDeD3IUQI16QMG`A[HVD4KVU[179_LPAfM7P3NGUm17amPPAnPHH4P8F:1865
RPB2QX/4PhJ;0hF6RPB6QXX4QhJ:18R6R@B9QXT4RXJ80h^6Q`B<QHL4SHF618n5Q@B@QH@4THB41964
PaGoool001Coool4T81n18elNPB;NGH4RGIb18IbK`>4KV/4PF]W17mWH`AmHel4NV1K17QLEP=fF584
LeE>175ABPA_CDH4KDU116]6?@AY@ST3Ichd16<h;@A/?c@4MTXo17A9?`AaB404KTM00fa6@0AZAT44
JDI216Q6A0AWATD4ITE50fE4A0AT@T<4I4A516=6B0ASBD/4I4i@16ECE@=VF5T4J5eO16]RI@A^JF/4
LVmb17IdN0=iNGd4O7f217j1QPB0QHX4PHF:18:6R`B3QX/3QHJ:18J6RPB7QXX4R8J918V6R@B:QXP3
RhJ718b5Q`B=QHH4ShF51925Q0BAQ8@4THB35Oooo`005?ooo`B@P7h4SGaj18]iMPB9MW84QW9_0hA^
J`B1JfL4OfMS17eSG`AjH5/4N5aF0gIHDPAcEDh4LE5:16m=APA]BD44JdHm16U2>@=W?S@4HcP]16`o
=0AfBSl4M4To1758@0A^Ad03K4I016Y6@@AYAT84J4I416M6A@AVADD3IDA416A2@`ATA4D4HdI816=9
B`ATCU04IE=E0fIHF@AXGEl4Jf9U16iYJ`AbKg84MWAh0gUiO@AlOH84OX661825RPB1QHX4PXJ;18>6
R`>5QXX4QXJ:18N6RPB8QXT4RHJ918Z6R0>;QXL4S8F718f5QPB?QHD4T8F41964Q0BAQ8<Eoooo000D
oooo1920OPB=O7X4RgUf18UfLPB6LVl3Q6i[185[I`AoIf<4OF=O17YPF`AhG5H3MUQB17=ECPAaDDX4
Kde616e9@@A[ASd4JD8i0fLn=0AS>2d4K3ld17I:?`AdBCl4LDQ016i7@0=/AT04JTI116U6@PAXAT@4
IdI516I5A@=UA4@4I49316A4A@ASATP4HdU;16A>D0AUDeD3IUQI16QMG`A[HVD4KVU[179_LPAfM7P3
NGUm17amPPAnPHH4P8F:1865RPB2QX/4PhJ;0hF6RPB6QXX4QhJ:18R6R@B9QXT4RXJ80h^6Q`B<QHL4
SHF618n5Q@B@QH@4THB41964PaGoool001Coool4T81n18elN@B:N7D4R7Aa18E`K@>2K6T4P6UT17eU
H0AjHE/4N5eG17EID`=cEDh4L55:16i<A@A[B404JD@l16M0=`AU?383HcP^16Pk<0AbA3T4L4@i16m4
>PA]@c`4JT8k0fQ1>`AV@C`4ID4n16A2?`AS@T04HT100f91@@AQ@D84H4E515m7B0APC4d4H4m@165B
E0=REEP4I5]M16QQH`A/IfX4L6e`17=bMP=gMg/4NW^017aoQ@AmPXL4Oh>91824RPB1QHX3PhF:18B5
RPB5QXX4QhJ918R6R@B9QXP3RhJ818b6Q`B=QHH4SXF618n5Q@B@QH@4THB35Oooo`005?ooo`B@P7h4
SGai18YhM@B8M744QG1]0h9/J@B0JF@4OFEP17YQF`AhGEL4MEUC0g=ECPA`DDX4KTa516]8@0AYA3`4
Id0g16Dl<P=S>2h4J3/`1794>@A`A3T4Kd@j16e3?0AZ@S/3J44k16I1?0AU@Ch4I48o16=2@0AR@403
HT511651@PAPADD4GdM8161<C@APCe04HE9D0f9EF0ATFed4J65S16aWJPA`KG04Lg9f0gMgN`AjNh04
O7n517f2Q`AoPhT4P8B:1865RP>3QHX4Q8F:18F6RPB7QXT4R8J918V6R0>;QXP4S8J718f5QPB>QHH4
ShF51925Q0BAQ8<Eoooo000Doooo1920OPB=O7T4RWQe18QdL@B5L6d3PVaY181YI0AmIF04NV5K17QM
E`AeFE<3LeE>171ABPA^C4D4JdQ016U4?0AW@3L4IC`b0f<h;PAX>c04LT@i1714>@A_A3X4KD<l16Y2
>`=X@C/4IT4l16E1?PAT@Sl4Hd901690@0=R@D44HD521615A@AOAdP4H4a=161?D0AQDU@3HUEH16AK
G@AXHF<4K6MZ171]L0AcLWH3MgMk17YkP0AlOhD4OH:717n3R@B0Q8X4PHF:0h>5RPB4QHX4QHJ:18N6
R@B8QXT4RHJ80h^6R0B<QXL4SHF618j5QPB?QHD4T8F41964PaGoool001Coool4Sgmm18akN@B:Mg@4
Qg=`18A_J`>1JVH4OVIR17]RG@AhGUP4MUUD17=EC`=`DDX4KDa516]8@0AXA3/4IClf16<k<@AQ=R`3
GC4V16Pj;PA]?c<4K40f16]0=`AY@3P4IShg0f<l=PAQ?3P4HCdk160n?@AO?Sd4Gchn0ei1@0AMA4@4
GDQ715e=C0AND504G4m@15eBD`=NEUL4HE]L16EQH`AYIVP4KVa_175aM@=dMWX4MgYo17UmP`AkP8H8
OH>917n4R@>0Q8X4PXF:18B5RPB6QXT4QhJ918V6R@>:QXP4RhJ718f5Q`B>QHH4ShF51925Q0BAQ8<E
oooo000Doooo18moO@B<NgT4RWMd18McL0B4Kf/3PFYV17iVHPAkHUd4N5iH17IIE0AcEDl3L55:16e<
A@A[B404J4@k16Do=PAS>c44HCH/0eda9PAX>Rh4KClc16a0=PA[@3L4JD0h16Hn=`=S?3H4HC`h164m
>`AP?Sd4Gchm15ln?P=N@D04GDA415e8A`AMCD`4GU1@15a?D0AMDU<3GUIG165KG0AUHF<4JFIX16i/
K`AaLGD3M7Ij17MjO`AiOH<4Nh2627f3R@AoQ8T3P8B:18:5RPB4QHX4QXJ918N6R@B9QXT3RXJ818^6
Q`B=QHL4SXF618n5Q@B@QH@4THB35Oooo`005?ooo`B?Ogd4S7]i18YgM0B7Lg04Q6m[0h5ZIPAnIV84
Nf9M17QNF0AfFE@4LeE?0g1ABPA]C4D4JdQ016Q4>`AU?cH4Hc/a164f;0=M<BH4J3X^16do<`A/@3H4
Jd0g16U0>0AV?SL3Hc`f164l>0AQ?C/4H3hm15ln?@AO?Sh3GT5015e4A0AMB4L4GDe<15i@D0ALCe04
GE9C0eiFE`AQFe`4IF5S16UVJ0A^K6l4LG5e0gAfNPAgNWl4NGf317^0QPQmPhT4OhB90h24RPB2QHX4
Q8F:18J6R@B7QXT4RHJ90hZ6R0B;QXL4SHF718j5QPB?QHD4T8F41964PaGoool001Coool4Sgmm18ak
N@B:Mg@4Qg=`18A_J`>1JVH4OVIR17]RG@AhGUP4MUUD17=EC`=`DDX4KDa516]8@0AXA3/4IClf16<k
<@AQ=R`3GC4V16Pj;PA]?c<4K40f16]0=`AY@3P4IShg0f<l=PAQ?3P4HCdk160n?@AO?Sd4Gchn0ei1
@0AMA4@4GDQ715e=C0AND504G4m@15eBD`=NEUL4HE]L16EQH`AYIVP4KVa_175aM@=dMWX4MgYo17Um
P`AkP8H8OH>917n4R@>0Q8X4PXF:18B5RPB6QXT4QhJ918V6R@>:QXP4RhJ718f5Q`B>QHH4ShF51925
Q0BAQ8<Eoooo000Doooo18moO@B<NgP4RGIc18IaKPB2KFT3OfQT17aTG`AiGeX4MU]E17=FD0A`DT/3
KDe616Y8@@AW@c/4I3lf164j<@AO=B/4G30U0f4c9`A^?c84Jchc16Tm<`AW?SD4IC`e168j<`=O>3<4
GCPd15dj>0AK>ST4FCXj15e2@P=NAdH4GT]:15i>C@ANCTh4Fdi>15U@D0AJEEH3FUIG15iIF`ARGf44
IfEW16a[K`A`LGD3LWEj17AhO@AfNh44Mgj417V0Q`AjPHP4O8>90gj3RPB0Q8X4PhF:18F6RPB6QXX4
R8J90hV6R0B;QXP4S8J718j5QPB?QHD4T8F41964PaGoool001Coool4Sgmm18akN0B9MW<4QW5^189]
J@=oJ6@4O6AO17UOFPAfFeD4LeI@171BB`=]CDH4JTQ116M3>`AT?cH4HCXa15le:`AL<2D3HC<W16ho
<PA[?S<4JCdc16Ln=@AU?3D4HSXc0elh<`AM>3@4GCXh15/j>@AI>SX4GD920ei7APANBdX4GTi=15i>
CPAKCTh4FE1@15YEEP=JEUL4GUUK169OH@AWIFL4K6]_171aM@=bMGX4M7Qm17IkP@AgOX@4NH2717Z1
R0AlPhT3OX>:1824RPB3QHX4QHJ:18J6RPB8QXT3RHJ818^6R0B<QXL4SXF618n5Q@B@QH@4THB35Ooo
o`005?ooo`B?Ogd4S7]h18UfL`B6LFh4PVeY0gmXI0AlI5l4NEmJ17IKE@AcEU04L59;0fe=APAZB444
Id<k16@o=PAQ>S44GcD[15``9@=Q<bL4KSlb16/n<`AY?C<4Iche16Dl=@AR>S<3GcPc15dh=0AM>SP4
FcXi15Tj>PAM@T83GTM615i;BPANCTd4GTi>15]>CPAID504FUEF0eYFE`ANFE/4HUmQ16MUI`A/Jfl4
L75e0g9eNPAdN7d4MW^117MnQ0AiP8L4NX6817b3R@=nPhX4P8B:18>5RPB5QXX4QXJ:18R6R@>9QXP4
RhJ818b6Q`B>QHH4ShF51925Q0BAQ8<Eoooo000Doooo18moO@B<NgP4RGIc18IaKPB2KFT3OfQT17aT
G`AiGeX4MU]E17=FD0A`DT/3KDe616Y8@@AW@c/4I3lf164j<@AO=B/4G30U0f4c9`A^?c84Jchc16Tm
<`AW?SD4IC`e168j<`=O>3<4GCPd15dj>0AK>ST4FCXj15e2@P=NAdH4GT]:15i>C@ANCTh4Fdi>15U@
D0AJEEH3FUIG15iIF`ARGf44IfEW16a[K`A`LGD3LWEj17AhO@AfNh44Mgj417V0Q`AjPHP4O8>90gj3
RPB0Q8X4PhF:18F6RPB6QXX4R8J90hV6R0B;QXP4S8J718j5QPB?QHD4T8F41964PaGoool001Coool4
Sgmm18]jM`B8MG84QG1]185[J0=nIf<4NV9M17MMF0AdF584LE==16i>B0=ZBD84Id@l16@o=`AQ>S44
GCD[15/`9PAH:b03ICLZ16/m<@AY?C84IS/b16Dl=0AR>S<4GcPa0e/f<@AJ=S<4EcLf15]0?PAOB4H4
Hdi<0em<B`AMCT`4G4e<15Y<B`AJDE44Fe=D15YDEP=IE5H4FeUK161OH@AUIFP4JVY_16iaM@=`M7T4
LWMl17=iO`AdO884MWn617N1RPAiPXT3O8>:17n4RPB1QH/4Q8J:18J6RPB7QXX3RHJ918Z6R0B<QXL4
SHJ618n5Q@B@QH@4THB35Oooo`005?ooo`B?Ogd4RgYg18QeLPB5L6d4PF]X0giWH`AjHUd4MeeH17AH
DPAaDdd4KTi80fY9@PAWA3`4I3lg164j<@AM=B/4Fc0V15P[80=U=bX4Jcda16Tm<PAV>c84IC`d168j
<`AO>343FcHa15Xf<`AG=cH4Fd0n15m8APASCT`3Gda;15e>C0ALCD`4FTa;15YAD@AKDe@4FUAF0eUD
EPAKFE/4H5mQ16EUJ0AZJVl4KW5e0g1dN@AbMg`4LgUo17AlPPAfOhH4Mh6:17V2R@=lPhX4OhB:1865
R`B4QXX4QXJ:18N6RP>9QXT4RXJ818b6Q`B=QXH4ShF51925Q0BAQ8<Eoooo000Doooo18moO@B;NWL4
R7Eb18E`K@B1JfP3OVMS17YRG@AgGEP4M5QB175CC@A^CTP3JTU216M4?0AT?cL4HCXa15de:`AK<2H4
F2/P0fDg:PA[?C44JCdb16Hk<PAU?3@4HSXc15lh<@=K=S44FSHc15Lg=PAK@3h4GdQ616=>C0=OC4/4
GDi<15a=C0AJC4/4FU5A15]CE0AJE5H3FEAF15]IF`APGf44IFEX16YZK`A^LGD3L7Ai179gO0AcNGl4
M7b217IoQPAgPHX4NH:90gb3RPAoQ8X4PHF;18B6RPB6QXX4QhJ:0hV6R@B:QXP4S8J718f6QPB?QHD4
T8F41964PaGoool001Coool4Sgmm18]jM`B8MG84QG1]185[J0=nIf<4NV9M17MMF0AdF584LE==16i>
B0=ZBD84Id@l16@o=`AQ>S44GCD[15/`9PAH:b03ICLZ16/m<@AY?C84IS/b16Dl=0AR>S<4GcPa0e/f
<@AJ=S<4EcLf15]0?PAOB4H4Hdi<0em<B`AMCT`4G4e<15Y<B`AJDE44Fe=D15YDEP=IE5H4FeUK161O
H@AUIFP4JVY_16iaM@=`M7T4LWMl17=iO`AdO884MWn617N1RPAiPXT3O8>:17n4RPB1QH/4Q8J:18J6
RPB7QXX3RHJ918Z6R0B<QXL4SHJ618n5Q@B@QH@4THB35Oooo`005?ooo`B?Og`4RgUg18MdL@B3Kf`4
P6YV0gaUH0AiGe/4MEYE179EC`A^D4X4Jd]40fQ6?PAT@3P4HC/b15de:`AI;bD4Eb/Q15PZ7`=Y>Rd4
JC``16Lk<@AT>c84HS/c15li<PAL=S03FCHa15Ti=PAI?C/4HDM51617A@ANAdD3G4Q615Y7A@AHAT@4
ETI515M:BPAGBd/4F51A0e]DE@ANFed4H5iQ16ASI`AXJFh4K71d0fidN0A_MG/4L7Mn175jP@AcOH@4
M82817J0Q`=iPXX4OXF;1866R`B3QX/4QHN;18N7RP>9QhX4RXJ918b6R0B=QXL4SXF61925Q0BAQ8<E
oooo000Doooo18moO0B;NGL4QgAa18=_K0B0JVH3O6EP17UOF`AeFUD4LUE?16i@BPA[Bd@3J4Hn16A0
>0AQ>c84GCD[15T_9@AG:b44F2XO0fTj;@AY?304Ic/a16@k<PAR>c<4GcTb15`f<0=I=S44FCTf15Tm
>`AQAdD4H4M515i7A@=LB4H4FTM515Q6A0AFATD4EdY:15M;B`AHD543FeAE15iKG@APGV44I6=W16QY
KPA/L7@3KWAh16meN`A`Mgh4LGZ117=mQ0AdP8P4MX270gV2RPAnQH/4PHJ;18>6R`B5Qh/4QhN:0hV7
RPB:QXT4S8J818f6Q`B>QHH4T8F41964PaGoool001Coool4Sgml18]iM`B7M744Pfm/181ZIP=lIF04
NEmK17EJE@AbEDl4KU1:16];A0=XASh4I40h164k<PAM=B/4FBlU15L[8@AH:Ql3JCX]16Tl<0AW>c44
I3/b168k<`AO>C84G3H`0eTf<@AI>CH4FCdk1657A@APAdD4GTM50ea8APAJAdD4F4I415I6A@AGBTX4
Ed];15Q@D@=KE5D4GU]M161NH@ATHfL4J6U^16a`M0=^M7P4KgEk171gOPAaNX44Lgf417B0R0AfP8L3
NH::17j5R`B1QX/4PhJ;18F7R`B7QhX3RHN:18Z6R@B<QXP4SHJ718j5QPB@QH@4THB35Oooo`005?oo
o`B?Og`4RgUg18MdL@B3Kf`4P6YV0gaUH0AiGe/4MEYE179EC`A^D4X4Jd]40fQ6?PAT@3P4HC/b15de
:`AI;bD4Eb/Q15PZ7`=Y>Rd4JC``16Lk<@AT>c84HS/c15li<PAL=S03FCHa15Ti=PAI?C/4HDM51617
A@ANAdD3G4Q615Y7A@AHAT@4ETI515M:BPAGBd/4F51A0e]DE@ANFed4H5iQ16ASI`AXJFh4K71d0fid
N0A_MG/4L7Mn175jP@AcOH@4M82817J0Q`=iPXX4OXF;1866R`B3QX/4QHN;18N7RP>9QhX4RXJ918b6
R0B=QXL4SXF61925Q0BAQ8<Eoooo000Doooo18inO0B:NGH4QW=`189^JPAnJ6@3Nf=N17MMF0AcF584
L59<16a=APAYB403ID8j168m=0AN=bh4FC0V154W70AB9AX4Gc0T0fdn<@AX?344ICX`168i<@AO>C84
GCPb15Xg<@=J>cL4GD8o1619APASCDX4GTY715]7A@=IAT@4Ed9115A2@@AC@T84DdE515=7A`AECTh3
Ee1A15]FF@AOG5l4Hf9U16QZKPA[L7@3K7=h16acN@A]MG`4KWQo171lP`AbOXH4MH690gV3S0AnQhd4
P8N=18>7S@B5Qh`4QhN;0hR7RPB:QhT4RhJ818f6Q`B>QHH4T8F51964PaGoool001Coool4SWil18Yi
MPB6Lg04PViZ17iXI0=kHeh4MeeH17=HDPA`DT`4K4e616U8@0=U@SX4HSdd15hg;PAI<2H4DBLL158U
6PAO<2@3KCha16Pl<@AU>S04HSTa15li<PAM>384FSLa0eXk=`AM@Sl4H4U616==BPANBTL4FdM50eU6
A0AG@T44E49115=2@PACADD4DdM715E>CP=GD544FeII15mLG`ASHVD4J6Y^16]`M0=/LgP4K7=i16ee
O0A^N7l4L7b3179nQPAePHT3NH><17j7S@B0Qhd4PhN=18F7S0B7Qh/3R8N:18Z7R@B;QXP4SHJ718j5
QPB@QHD4THB35Oooo`005?ooo`B>OW`4RWUf18IcL0B2KVX4OVQT0g]SGPAgGEP4LeQB171BC0A/CDH4
JDQ00fE2>PAR?C@4GSL^15T`9PAA9a`4DRDJ15l`90=]?S44J3`a16Dj<0AR>C44GcTb15dh<PAJ=c43
FS/g15e2?`APBDH4Hde:15i:A`AKAdD3FDI415M2@@AD@T44Dd9215=5A@ACAdL4EDi>0eM@D@AKEUT4
GeaO16=RI@AXJVh4Jg1d0facN0A/LgT4KGEl16ihO`A`O8<4LWj617F1R@=iPh`4OXN=1827S@B3Qhd4
QHN<18N7R`>8QhX4RXN918^6R0B=QXL4SXF61925Q@BAQ8<Eoooo000Doooo18inO0B:N7D4QG9_185/
J@AmIV83NF1L17EKEPAaEE04KDm916Y:@`AVA3d3Hclg15li<@AL=2X4EbdS154V6`AJ;R84JS`_0fXn
<@AU>c04HSTa15lj<PAM>C<4FcLb15Pg<P=H>cL4Fd4n15a5@`ALAdD4FTQ615Q8AP=GAdD4EDE415=5
@`ABATD4DTU8159<C0ADCdl3EU1B15UEF0AMFeh4HV9U16U/K`AZL7@3JW9g16YbN0AZM7/4JgIn16ej
PPA^O8@4KWb50gN3R`AnR8l4P8R>18>9SPB5R8d4QXR<0hR8R`B:QhX4RhN918f6Q`B>QXH4T8F51964
PaGoool001Coool4SWil18YhM@B5LVl4PFaY17eVHP=iH5`4ME]F175ED0A]CdT4JTY316I4?@=S?cL4
GcTa15`d:PAG;B<4DBHK15X^8PAZ?2l3JSha16Dk<0AR>C44GcXb15di<`AK=c84F3Lb0ePk=`AK@Ch4
G4E315a7A@AJB4H4F4Q60eM7A@AEAD@4DdE31596A@ABBDP4DTa<15A?C`=FD584FEEH15eKGPARHVD4
JFa_16Y`M0=ZLWL4JW9h16YdN`A[MWh4KGZ216ilQ0A^O8D3Mh>;17j8S`B0R8h4PhV>18F8S@B6R8`3
R8R;18Z7RPB;QhT4SHJ718j6QPB@QHD4THB35Oooo`005?ooo`B>OW`4RWQe18EbK`B1K6T4OFIR0gUP
G0AeFeH4LEE@16e?B@AZBT<4IT@m0f<o=`AO>C44G3@Z15L]8`AA9Q/4FRhR16Xl;`=Z?S44IC/`168i
<@AO>S84GCTc15/g<PAH=c83F3/g15]1?PALAD<4G4M515Y8APAHB4H3EdM515E5A0ACAD<4DTI51599
B0ABC4`4E4m?0eI@DPAIEEP4GE]N169RI@AYK6l4JW1d0fYbM`AZLWP4JWAk16]fOPA]NX84KWb416il
Q@=gPh/4OXR?1828SPB3RHh4QHR=18J8S0>8R8/4RXN:18^7R@B=QXL4SXJ61925Q@BAQ8<Eoooo000D
oooo18inO0B:N7D4QG9_185/J@AmIV83NF1L17EKEPAaEE04KDm916Y:@`AVA3d3Hclg15li<@AL=2X4
EbdS154V6`AJ;R84JS`_0fXn<@AU>c04HSTa15lj<PAM>C<4FcLb15Pg<P=H>cL4Fd4n15a5@`ALAdD4
FTQ615Q8AP=GAdD4EDE415=5@`ABATD4DTU8159<C0ADCdl3EU1B15UEF0AMFeh4HV9U16U/K`AZL7@3
JW9g16YbN0AZM7/4JgIn16ejPPA^O8@4KWb50gN3R`AnR8l4P8R>18>9SPB5R8d4QXR<0hR8R`B:QhX4
RhN918f6Q`B>QXH4T8F51964PaGoool001Coool4SWek18UgM@B4LFh4P6]W17]UH0=gGUX4LeUD16mB
C@A[CDH4IdM016A1>@=P?3<4GCH]15/a:0AI;B<4GS0S16Tj;0A]?c83IS/`168j<0AO>C44G3Tb15/i
<`AH>3<4ESTd0eLk=`AI@Cd4F48o15M4@@AFA484E4A20e=3@PAA@T44Cd9114i4@`A>ATH4CdU:151<
CP=CDE<4EUQJ15aOH@ARIfX4J6mb16YcMP=XLWL4Ig5h16QbNPAYMGh4JgV116akQ0A/OHL3NXRA17j:
T@B1RY44PhZ@18F9S`B6RHd3R8R<18Z8R`B;QhT4SHN818j6Q`B@QHD4THB45Oooo`005?ooo`B>OG/4
RGMe18AaKPB0JfL4NfEP0gMNFPAcFE@4Ke9=16]=APAWAd04I44i0f0l<`AM=Rd4Fc4X15T]8`AN<2<4
JCX/16do<P=V>c04HSX`15li<@AL>C84FcTc15Ph<`AF>C@3Ec/g15U1?@AH@Sl4EdA115I4@PADA483
Dd=21552@@A?@T44CTA314i6APA?BDX4D4a>0e=AD`AFF5X4G5mQ169WJPAXKg84JW=f0fQbM`AWLGP4
J79j16UeOPA[NH44K7^416amQ`=jR944OXZA186:T@B3RY04QHV?18J9S@>8R8`4RXR;18^7R@B=QhP4
SXJ71925Q@BAQ8@Eoooo000Doooo18imN`B9MgD4Q75^181[I`AkIF03MeiJ17=IE0A_DTd4Jde616M7
@0AT@CT3H3`c15df;@AK<BP4FBdS15h`8`AY>R`4KClb0fHk<0AR>S04GcTa15`i<PAK>C<4F3Pc15Hi
=0=G>cL4FD4m15Q2?`AGA444ETA215A4@P=C@d84DD9114m2@@A>A4<4CTI614m9BPA@C4h3De5C15IH
FPALGf44HVMZ16Q_LPAZLgH3J79g16MaN0AXLWX4JGEn16]iP@A/Nh@4K7f70gZ8T@AnRY44PHZA18>:
T0B5RHl4QXV=0hR8S0B:R8/4RhN918f7R0B>QXL4T8F51964Q1Goool001Coool4SWek18UgM@B4LFh4
P6]W17]UH0=gGUX4LeUD16mBC@A[CDH4IdM016A1>@=P?3<4GCH]15/a:0AI;B<4GS0S16Tj;0A]?c83
IS/`168j<0AO>C44G3Tb15/i<`AH>3<4ESTd0eLk=`AI@Cd4F48o15M4@@AFA484E4A20e=3@PAA@T44
Cd9114i4@`A>ATH4CdU:151<CP=CDE<4EUQJ15aOH@ARIfX4J6mb16YcMP=XLWL4Ig5h16QbNPAYMGh4
JgV116akQ0A/OHL3NXRA17j:T@B1RY44PhZ@18F9S`B6RHd3R8R<18Z8R`B;QhT4SHN818j6Q`B@QHD4
THB45Oooo`005?ooo`B=OG/4R7Id18=`K@AnJFH4NV=O0gELF0A`EU44K51:16Q9@`AT@c`4HChf0ehh
<0AK<bX4FBlT15T/80AL;b84Gc<X164g;0=P>2h4GSP`15/i<PAI>C84EcTc15Hh<`AD>3@3E3Xf15@m
>PAD?cd4Dd4o1591?`AA@3l3Cd0o14do?PA;?cl4BT1014Y3@`A;ATL4C4Y<0e1?DPADEUT4FEeP15iT
I`ARJVh4IW1d0fIaM`AUL7P4IG5j16MdO@AYN844JGZ416YlQ`=kRY<4OhbD186<TPB3Ri44QH^@18J:
S`>8RHd4RXV<18^8RPB=QhT4SXJ71925Q@BAQH@Eoooo000Doooo18emN`B8MW@4Pg1]17iYIPAjHel3
MEaH171FD@A/D4X4J4U316A3?0AQ?SH3GSP`15/c:PAI;b@4FB`P15`_8PAO<bP4HCL/0f0h;PAN>304
FcTb15Ti<PAG>C<4ESPc15@h=0=D>SH4E3dj15@o?@AC@Cl4DT4o1550?`=?@3l4CCln14/o?`A:@404
BT=314]6A`A<BT`3D4mB15AFF@AIGF04GVAW169ZKPAVL7@3IW5g16E`N0AULGX4IgAm16UhP@AYNX@4
JWb70g^:T`AoS9@4PHbB18>;T@B5Ri04QXZ?0hR9S@B:RH`4RhR:18f7R@B>QXL4T8F51965Q1Goool0
01Coool4SGek18QfM0B3L6d4OVUV17YSG`=eG5P4L5IA16a@BPAXBD<4I4<l164n=P=N>304Fc<Z15T_
90AI;204G2lR15lc:0AQ=b`3H3P^15hh<0AK>C84FCTb15Li<`AF>3<4E3Pd0e@j=PAD?CX4E3lm15=1
?`AB@Cl4DD0o0dm0?`A=?ch4Bclo14Y0@0A:@d<4BdI714a:C0=@Ce84E5II15UMH0ANI6L4HVY^16I`
M0=VLGL4IG1h16EaNPAWM7d4JGR116UjQ0AZO8L3NhZC17n<U0B1S984Ph^A18F;T0B6RXl3R8V=18Z9
S0B;R8X4SHN918j6Q`B@QHD4THF45Oooo`005?ooo`B=OG/4R7Id18=`K@AnJFH4NV=O0gELF0A`EU44
K51:16Q9@`AT@c`4HChf0ehh<0AK<bX4FBlT15T/80AL;b84Gc<X164g;0=P>2h4GSP`15/i<PAI>C84
EcTc15Hh<`AD>3@3E3Xf15@m>PAD?cd4Dd4o1591?`AA@3l3Cd0o14do?PA;?cl4BT1014Y3@`A;ATL4
C4Y<0e1?DPADEUT4FEeP15iTI`ARJVh4IW1d0fIaM`AUL7P4IG5j16MdO@AYN844JGZ416YlQ`=kRY<4
OhbD186<TPB3Ri44QH^@18J:S`>8RHd4RXV<18^8RPB=QhT4SXJ71925Q@BAQH@Eoooo000Doooo18em
N`B8MW<4PVm/17eXI0AhHEd3LeYE16iCCPAYCDL4IDI01650>@AM>S83FS@/15P_9@AF:b04ERTM15LZ
7`AH;B<4FC4X0e/e;0AJ=Rl4F3La15Hg<@AD=c84DcHb158f<P=A>3D4DCXh154n>`A@?Sd4Cchm14dl
?0=;?C`4BC`l14Ll?0A7?Cl4AT1214Q4A`A;B4`3CdmB15=EF@AHGF44G6=W15mXK@ASKG<3Hfie169^
MPASL7T4IGAm16MhP@AYNXD4J7^70g^:T`AoS9@4PHfD18><T`B5S944Qh^@0hR:SPB9RHd4RhR;18b7
R@B>QhL4ShJ61965Q1Goool001Coool4SGek18QfL`B2Kf`4OFQT17QQG@=cFUD4KU=>16U=A`AUAT04
HD0i15dj<P=J=2`4F2lU15H[80AF:Ad4EbXO15P]8`AI<BP3FcD/15Xf;`AH=c44ESLa15@g<PAC=S84
DSHb0e4h=@AA>SP4DChk150n?@A??Sd4CC`l0d/m?0A9?3`4Ac`l14Lm?`A6@484B4A714]8C0=?Ce84
DeEI15QMH@ALHfL4GfQ]16=]L`=SKWD4HVif16=`N@AUM7d4IgR116UjQ@AXNhL3NhZC17n<U0B1SI@4
PhbC18F<T@B7Ri03R8Z>18V9S@B;R8/4S8N918j7Q`B?QXH4THF45Oooo`005?ooo`B=OG/4R7Ic189_
K0AmJ6@4N65M0g=JE@A^Ddh4JDe716E6@0AQ@3T4GCXb0eXd;0AH;bD4ER/P15HY7@AG:Ql4F2dS15Ta
:0=K=B`4FSH_15Pg<@AF=c44E3Lb15<f<PAB=S83DCPe154j>0AA?S/4D3hm14ln?@A=?3`3Bcdl14Tl
?0A7?3`4Acdo14I0@PA8A4L4BdQ<0dm?DPACEET4F5eQ15aSI`AOJ6d4Hfec0f=^M@ARKWH4Hg1i16Ed
O@AWN844JGZ516QkQ`=kRY<4OhbD186=U0B3S9<4QHbA18N;T0>8RXh4RHV=18^8R`B<QhT4SXN718n6
QPBAQH@Eoooo000Doooo18emN`B8MW<4PVm/17eXI0AhHEd3LeYE16iCCPAYCDL4IDI01650>@AM>S83
FS@/15P_9@AF:b04ERTM15LZ7`AH;B<4FC4X0e/e;0AJ=Rl4F3La15Hg<@AD=c84DcHb158f<P=A>3D4
DCXh154n>`A@?Sd4Cchm14dl?0=;?C`4BC`l14Ll?0A7?Cl4AT1214Q4A`A;B4`3CdmB15=EF@AHGF44
G6=W15mXK@ASKG<3Hfie169^MPASL7T4IGAm16MhP@AYNXD4J7^70g^:T`AoS9@4PHfD18><T`B5S944
Qh^@0hR:SPB9RHd4RhR;18b7R@B>QhL4ShJ61965Q1Goool001Coool4SGaj18MeLPB1KFX4NfIS17IO
F`=aF5<4Je1;16I9A0AR@c`4GC`e15Xf;P=F<2L4E2XQ158V6`AB9AX4DBHL15<[8PAF<2P3F3<[15He
;PAD=Bl4DSD`154e<0A?=304CSDa0ddg<`A=>3D4CCXi14`l?0A;?3/4BC/k0dPk>`A6>S/4A3Tk14@l
?PA4?d44ATA714Q7B`=<CU84DEEJ15ELH@AJHFP4GFM^15m[LP=OK7<4Gfef165`N@ATM7d4IgR116Uk
Q@AZO8L3NHRA182>UPB2SYH4Q8jE18F=T`B7S943R8^?18V:S@B;RH`4S8R:18j7R0B?QXH4THF45Ooo
o`005?ooo`B=O7X4QgEb185]JPAkIV<4MUmK0g5HD`A[D4/4ITU41693?0AM?3D4FSH^0eH`9`AD:R44
DRHK158U6PAA9Q`4Db/R15H`:0=H<b/4ESD^15@e;`AB=C04DCD`14ld<0A>=C43CCLc14dh=@A=>ST4
C3`l14/l>`A9>c/3B3/k14Hj>`A4>C/4A3`n14@o@@A6A4L4B4M;0da>DPAAEEX4EEaQ15YQJ0AMIfh4
Gf]b0em/L`AOKGH4HG1i16AdO@AWN844JG^516YlQ`=iR944P8jF18:>UPB4SYD4QHfC18N<T@>8Rhl4
RHZ=18^9S0B<R8X4SXN818n6QPBAQH@Eoooo000Doooo18elNPB7MG84PFeZ17]VH`AfGe/3LEQC16]@
B`AVBD@4HT<l15dl=@AJ=Rh3ES0W15@Z8@AB9Q/4DRDJ154V70AC:b84ES0X0ePc:`AF=Bh4E3D_158e
<0AA=C04Cc@`14he<@===c<4CCPe14dj>@A<?3`4Bc`k14Tk>`=8>c/4ASXk14@i>`A4?3h4A3m114I4
A`A8Ad/3C4iB155EFPAEG644FV5X15eWKPAOJg83Gfac15m]MPAQL7T4I7Am16MhP@AYNhD4JWb70gV8
T@B0SYH4PXjF18B>U@B5SI<4QhbA0hR;S`B9RXd4RhV<18b8RPB>QhP4ShJ61965Q1Goool001Coool4
SGaj18MeLPB1KFX4NfIS17IOF`=aF5<4Je1;16I9A0AR@c`4GC`e15Xf;P=F<2L4E2XQ158V6`AB9AX4
DBHL15<[8PAF<2P3F3<[15He;PAD=Bl4DSD`154e<0A?=304CSDa0ddg<`A=>3D4CCXi14`l?0A;?3/4
BC/k0dPk>`A6>S/4A3Tk14@l?PA4?d44ATA714Q7B`=<CU84DEEJ15ELH@AJHFP4GFM^15m[LP=OK7<4
Gfef165`N@ATM7d4IgR116UkQ@AZO8L3NHRA182>UPB2SYH4Q8jE18F=T`B7S943R8^?18V:S@B;RH`4
S8R:18j7R0B?QXH4THF45Oooo`005?ooo`B<O7X4QWAb181/J@AjI644M5eI0fiED@AXCTT4HdI115ho
>@AI>344EC4Z0e8[8PA?9A`4CB4F14`Q5`A<8aX4D2/S15<`:0=C<R/4DS@]150c;PA?<bh4CC8^14`b
;PA;<Rl3BS@a14Te<`A9>3L4BC/j14Pj>PA6>CT3A3Pi14<h>@A1=cT4@3Pk140l@0A2@DD4ATM;0dY>
DPA>E5X4De]Q15MQJ0AIIFd4FVM_0e]YLPAMK7D4Gfmh169cO@AVMh44Jgb71761R`=mRY<4PHnH18BA
V@B5T9L4QXjE18N=T`>8S904RH^>18^9S0B<R8X4SXN818n6QPBAQH@Eoooo000Doooo18alNPB6M784
P6aY17YTH@AdGET3KUEA16Q>B@ASAT44GSli15Th<@AE<BX3DR/R14lU70A=8AH4C24G14`S6PA@:b<4
Dc0X0e<b:`AB=2d4D3<^14lc;PA=<Rh4C38^14/b;`=:=344BCDc14Th=`A9>cX4B3Xj14Hi>@=4>3T4
@cPi144g>@A0>3/4@3a01491A@A6Ad/3BTiB14iDFPACFf44Ef5X15UUK@AJIfl3FfUb15e/M@AOKgP4
HW=m16IgP@A[O8L4LH6;0gf:T`B1SiP4Q96I18F@U`B6SYD4QhfC0hR<T0B9Rhh4RhV<18b8RPB>QhP4
ShJ61965Q1Goool001Coool4S7aj18IdLPB0K6T4NVAQ17AMF@=^EE44J4i916=6@@AN?cT4FCPa15Da
:P=B:b84CbDL14dQ5PA<8AL4C2<J150[8`AC<2P3Dc8[158d;@A@<bh4Cc<^14db;PA<<Rh4Bc8_0dXd
<@A9=C<4BCPg14Tk>PA8>SX4ASTi0d@h>@A3>3T4@CLi140h>`A0?404@T5514I7B`=:CU84CUAJ15=K
H@AGHFP4FFE]15YWK`=KJG84GFae15m_N0ARLgd4IWN116]lQ`AaPH/3OHZC186?V0B4TIT4QI2G18J>
U@B7SI<3R8b@18V;SPB;RH`4S8R:18j7R0B?QXH4THF45Oooo`005?ooo`B<NgT4QG=a17i[J0AhHel4
LU]G0f]BCPAUBdH4Gd<m15Xk=@AE=2d4D2`U0ddU7@A97QD4AaXA14HK4`A88a/4CB`U14l_:0=?<B/4
CS4/14`a;0A;<2`4BBl[14P_;0A7;bd3AS4^14Dc<@A6=cH4ASTi14Dh>@A3=SL3@CHh13ld=`@m=3H4
?3Hi13dj?P@o?d@4@dE:0dI;D@A;DUT4D5YQ15=OIPAEHVX4EF=/0eMVK`AJJ784GFag161aN`AUMX44
Jgb71762S0=kS9H4QYNQ18ZIXPB6TYX4QXnG18J>U0>8S984RH^?18^:S@B<RH/4SXN918n6QPBAQH@E
oooo000Doooo18akN@B5Lg44OV]X17QSG`AbFeL3Je9>16E;APAO@cd4FS/e15Dd;@A@;2D3CBDM14TN
5@A76Q44AQ/C14PS6`A=;2D4CblX0dla:`A><B`4C34/14/`;0A9;b/4B2l/14L_;@=6<Bh4AC<a14Hg
=PA6>CT4ACPi14<f=`=1=SP4?c@g13dd=P@l=ST4?CXn13loA0A3ADX3AT]A14]BF@A@FV44DemV15ER
JPAEHf`3EfI_15YXLPAMK7L4H75k16EfP@A[O8L4LH:<0g^<UPB6Uj44RYVR18JBVPB6SiL4QXjD0hR<
TPB9Rhl4RhZ=18b9R`B>QhT4ShJ61965Q1Goool001Coool4S7]i18EcL@AnJfP4N6=O179KE`=[DTh4
ID]615m3?@AJ>cD4EC@]150/9@==9Ad4BAhE14LJ4@A66a<4B2<K14d/9@A?;bP3Cc4[14ha;0A<<B`4
Bc0/14T_:`A8;b`4Abl]0dHa;PA5<c44ASLf14Hi>@A5>3T4@cHg0d4f>0@o=3L4?C@f13`f>@@m>Sh4
?cm414=5BP=6Be44Be9I151JH@ACGfH4EF9Z15ESK0=GIVl4FVQb15e/M`APLG/4IGJ116]lQ`AaPX`3
NhbF18JGX@B:VJ84QY:J18J?U`B6SY@3R8bB18V;S`B;RXd4S8V;18j7R@B?QXH4THF45Oooo`005?oo
o`B<NgT4QG=a17i[J0AhHel4LU]G0f]BCPAUBdH4Gd<m15Xk=@AE=2d4D2`U0ddU7@A97QD4AaXA14HK
4`A88a/4CB`U14l_:0=?<B/4CS4/14`a;0A;<2`4BBl[14P_;0A7;bd3AS4^14Dc<@A6=cH4ASTi14Dh
>@A3=SL3@CHh13ld=`@m=3H4?3Hi13dj?P@o?d@4@dE:0dI;D@A;DUT4D5YQ15=OIPAEHVX4EF=/0eMV
K`AJJ784GFag161aN`AUMX44Jgb71762S0=kS9H4QYNQ18ZIXPB6TYX4QXnG18J>U0>8S984RH^?18^:
S@B<RH/4SXN918n6QPBAQH@Eoooo000Doooo18]kN@B4LW04OFYW17IQGPA_F5D3J51<1697@`AL?cX4
ESLa150_:@A;9b03Ab0H14<I4@A160l4@Q`E14HV7`A;;BH4CBlY0d``:PA:;b/4BBlZ14L]:@A5;2T4
A2`Y14</:P=2;B`4@S0`148c=0A3=CL4@CHh140e=`<n=CL4?3<f13Tc=P@i=CT4>STn13`nA0A0A4X3
A4]B14YCFPA=F604CeaT151NI`AAH6T3Df=]15IVL@AJJWD4GVmk16=eP0AXNhL4Kh2;0gN9U0B0Tih4
Pi>M18BBVPB5T9L4QXjE0hN=T`B9S904RhZ>18b9S0B>R8T4ShJ71965Q1Goool001Coool4Rg]i18Ab
L0AmJVL4MV5N16mHE@=XD4`4HTM315`o>PAF=c44D2lY14/W80=781P4@aTA144H3`A271D4ARHO14/]
9PA=;bT3C30Z14X_:`A9;bX4AbdY14D/:@A4;2T4@b`Z0d8];0A2<304@S<d14<e=`A1=SP4@3Dg0che
=`@l<cH4>C<f13Te>@@j>Ch4?3i41414BP=4Be84BU=J14eHH0A?G6@4D5iW155PJ@=CHfd4EVIa15YZ
M@ANKg/4HgF016QkQ`A_P8/3MhVD182CWPB3Tid4Q9:J18F@U`B6SYD3QhfC18V<T0B;RXh4S8V<18j8
R@B?QXL4THF45Oooo`005?ooo`B;NgT4Q79`17eZI`AfHEh4KeQE0fQ@C0ARAd<4G3lj15Hg<@A@;bT4
BbLP0dLP60A36A44@AP?148L5@A69Ql4BbdV14d_:@=<<2X4BRl[14T_:PA7;BT4AB`Y14@/:@A3;2X3
@Rd/148`<0A2<c@4@cDg144f>0A0=CL3?SDg13`c=P@i<cH4>CDi13Xi?P@l?T@4@4A:0dA;DPA:DeX4
CEQP14mLI0A@GVL4DF1Y0e=SK@AFIW44FVYe15i_N`ASMH04J7^716n0R`=gRI@4P9>N18>CW@B4TYX4
QI2G18J>U@>7SI<4RHb@18^:SPB<RH`4SXR918n6Q`BAQH@Eoooo000Doooo18]kN@B4LW04OFYW17IQ
GPA_F5D3J51<1697@`AL?cX4ESLa150_:@A;9b03Ab0H14<I4@A160l4@Q`E14HV7`A;;BH4CBlY0d``
:PA:;b/4BBlZ14L]:@A5;2T4A2`Y14</:P=2;B`4@S0`148c=0A3=CL4@CHh140e=`<n=CL4?3<f13Tc
=P@i=CT4>STn13`nA0A0A4X3A4]B14YCFPA=F604CeaT151NI`AAH6T3Df=]15IVL@AJJWD4GVmk16=e
P0AXNhL4Kh2;0gN9U0B0Tih4Pi>M18BBVPB5T9L4QXjE0hN=T`B9S904RhZ>18b9S0B>R8T4ShJ71965
Q1Goool001Coool4Rg]i18=aK`AlJ6H4M5mL16aFD`=UCDT4GTA015Lk=`AA<bd4BbXT14DR6`<o6A44
?1D<13XF3P@m7AH4@bLP14T]9`A9;RT3B2hY14L]:@A5;2P4@bXW144Y9P@o:2L4?RPX0chZ:P@n;Bh4
?c4b13lc=@@n<cH4?C<f0c/c=P@i<CD4=S4e13Hc>0@g>3h4>Si413i4B`=2Be84AU1H14QDG@A:F644
BeYS14aLI`=?H6/4DV=_15IXM0AJKWT4GgAo16EjQ@A/OXX3LhNC17V>VPAnT9X4PI6J18>@V0B5SiH3
QhjC18V<T@B:Rhl4S8Z<18j8RPB?QhL4THF55Oooo`005?ooo`B;NgT4Pg5_17aXIPAdGe`4K5IC0fE=
B@ANA404Ec/g154c;@A;:R@4AB8K0clI4@@l5@`4>QH>13dM5PA39b04BBdW14T^:@=8;RT4AbdY14D/
:0A3:RL4@BTV13lX9`@n:2P3?RXZ13h];P@o<C84?c<e13hc=P@m<cH3>c<f13Ta=@@f<CD4=S<h13Lh
?P@j?T@4?TA;0d9;DPA6D5P4B5AM14YHH@A;FV<4C5aW0dmPJ`ABHfl4EVQd15Y^N@AOM7l4IGZ516an
RP=cQi<4NHjJ17j@VPB1TIX4Pi2H18F?UP>7SY<4RHbA18Z;S`B<RX`4SXR:18n7Q`BAQHDEoooo000D
oooo18]kN@B3LFl4O6QV17AOG0A/EU<3IDe915i4@0AG>cL4DC<]14/Z90A58Q/3?aTA13`E30@j5Ph4
?AdF14<W80A9;BL4BBhY0dP^:@A7;BT4AB`X14<Z9`A1:BH4?bPW13hX:0<n:RX4?Rd^13la<P@o<cD4
?S<f13dc=P<k<cH4>C4e13Ha=@@f<cP4=cPn13XnA0@nA4/3@T]B14I@F0A8E5d4BUQQ14]JH`A<G6L3
Cf1[159SK`AFJ7@4FVii15mdO`AUNXD4K7j:0g>7T`AiSYX4OY2J186AVPB3T9P4QHnF0hN>T`B9S944
RX^?18b:S0B>R8X4ShN71965QAGoool001Coool4Rg]i18=aK`AlJ6H4M5mL16aFD`=UCDT4GTA015Lk
=`AA<bd4BbXT14DR6`<o6A44?1D<13XF3P@m7AH4@bLP14T]9`A9;RT3B2hY14L]:@A5;2P4@bXW144Y
9P@o:2L4?RPX0chZ:P@n;Bh4?c4b13lc=@@n<cH4?C<f0c/c=P@i<CD4=S4e13Hc>0@g>3h4>Si413i4
B`=2Be84AU1H14QDG@A:F644BeYS14aLI`=?H6/4DV=_15IXM0AJKWT4GgAo16EjQ@A/OXX3LhNC17V>
VPAnT9X4PI6J18>@V0B5SiH3QhjC18V<T@B:Rhl4S8Z<18j8RPB?QhL4THF55Oooo`005?ooo`B:NWP4
PW5^17YWI0AbGEX4JUAA0f9:A`AJ@Cd4DcLc14`^:@A59B04?Q`F0cLB2`@b3PP4<14<13LK5PA19b84
ARdW14L]:@=6;BP4A2/W148Z9P@o:2D4?BLU13/V9@@i9RH3>RTY13//;@@l;c44?34d13`b=@@k<SH3
>C8e13H`=0@d<3D4<c<h13Dg?@@g?D<4>d=:0ci8D0A1CEH4@e1J14ACG@A6EV44B5YU0dYMJ@A>HVh4
DVMc15I/N0ALLGh4HWN316MjQP=^Q904MXZE17f@V`B0TI/4PY2I18F?U`>7SY@4RHfB18Z<S`B<RXd4
SXV:18n7Q`BAQHDEoooo000Doooo18YjN0B2LFh4NVMT179MFPAZE543HTY715Y1?@AC=c<4C2hY14DU
80@n71H3=a8;138>20@`4@`4=a/F144W8PA6;BL4AbdY0dH]:0A4:bL4@RXV13lX9@@m9bD4>bHU13TV
9P<j:BT4>b`]13`_<@@l<C@4?38e13/b=P<i<SD4=S0d13@`=@@c<cP4=CLm13Lm@`@k@dX3?TQ@145=
EPA3D5X4A5=M14IFH@A8FVD3BUeY14iRKPABIg<4EVah15aaOPARMh<4IgZ60fj4T0AfRYD4OI2K182A
V`B2T9T4QHnG0hN>U0B9SI84RXb?18b:S@B>RHX4ShN71965QAGoool001Coool4RWYh189aKPAjIf@4
LUeJ16YDD@=RBTL4FT4m15<g<`A<;RT4ABDP13hL5P<g4P/4<Ph8130A30@g6aH4@BLR14H]9`A7;BT3
ARdX14@[9`A2:RH4?bPU13dW9@@k9RD4>BHV0cXY:@@k;2d4?2la13`a=0@l<SD4>c8f0cTb=@@f<3@4
=30e13<c>0@e=cd4=ce313]3BP<nB504@DeF14=@FPA4Ded4AUIQ14QJI@=:GFT4CV9^159WL`AFK7P4
G75n169gP`AWNXH3KXB@17J:U@AmT9/4P96K18:@V@B5SiL3QhjD18V=TPB:S8l4S8Z=18j9RPB?QhL4
THF55Oooo`005?ooo`B:NWP4PW5^17YWI0AbGEX4JUAA0f9:A`AJ@Cd4DcLc14`^:@A59B04?Q`F0cLB
2`@b3PP4<14<13LK5PA19b84ARdW14L]:@=6;BP4A2/W148Z9P@o:2D4?BLU13/V9@@i9RH3>RTY13//
;@@l;c44?34d13`b=@@k<SH3>C8e13H`=0@d<3D4<c<h13Dg?@@g?D<4>d=:0ci8D0A1CEH4@e1J14AC
G@A6EV44B5YU0dYMJ@A>HVh4DVMc15I/N0ALLGh4HWN316MjQP=^Q904MXZE17f@V`B0TI/4PY2I18F?
U`>7SY@4RHfB18Z<S`B<RXd4SXV:18n7Q`BAQHDEoooo000Doooo18YjN0B1L6d4N6ES171KF@AWDDh3
GTM415Hm>PA><bl4ARTU13lP6`@g5a43<0d712T;1`@/4Ph4=A`H144Y90Q5;BT3A2`X148[9`@o:BH4
?2HU13TU90@g92D4=B@U0cHV9`@g:B/4>Bd_13X`<`@j<SD4>C8f0cLa=@@d;c@4<Bld130a>0@b=S`4
=3]213M0B@<iADh4>dUC13e<E`@oCe/4@5=N14=FHP=6FfL4BUm/14iTL@ACJGH4F6ml15edP@ARN8@3
JX6>17>8U@AkTYl4OY:L186AVPB4T9P3QXnF18R>T`B:S904S8^=18j9R`B?QhP4THJ55Oooo`005?oo
o`B:NWP4PG1]17QUH`A`FeT4Ie5>0ei7A0AF?CX4CS<_14HY9@@o81/4=aLA0c0=1`@Y2`L4;18>13DL
60A1:B@8ABdY0d@/:0A2:bL4?bTV13`V9@@i9B@4=b@U13DT9@<f9RL4=bT[13T];`@j<3<4>S8e13Tb
=P<g<CD4=2ld134_=0@`<CP4<SHl13@k@P@g@4T3>DE>13]9D`@mC5L4?dmK141CGPA3EV83AU]W14YO
K0A>I744DfUf15Q_O0AMM844HWR40fZ1SPAcR9D4Ni:O17jBW0B1TIX4Q92H0hJ?UPB8SY<4RXb@18b;
S@B>RH/4ShN81966QAGoool001Coool4RWYh185`K@AhIF<4L5]I16MACP=NAd@4ESdj14hc;`A6:BD4
?b0K13LG4@<`3@L4:@/712`B3P@e71P4@BTT24D]:@=4;2P4@R/W13lY9P@l9RD4>BDT13LT9@@e92D3
=RHW13LY:`@i;Bl4>S0c13Xb=@@i<SH3=c4e13@_=0@a;c@4<34h138f?0@d>d84=d190cU5CP@kBE<4
?DaG13m?F`A0Deh4@eIR0dIKI`A:Gf`4CVAa15=YMPAHKg`4GGB1169hQ0=ZPHh4LhRE17^BW`AnTY`4
PI6J18B@V0>6SiH4R8jC18Z<T0B<Rhd4SXV;18n7R0BAQXDEoooo000Doooo18UiM`B0Kfd4MfAR16eJ
E`ATCd`3FdA1154i=PA8;b/4@2DQ13PK5`@a4Pd3:P/612L<2@@]5A84=QlL14D]:0A6;bX4ABhZ0d@]
:PA1:bP4?2LV13PT8`@c8B44<20Q12lP8P<a92H4=BT[13L/;`@i<3<4>S<g13Pc=`<f<SL4<S0e12l_
=@@^<CL4;cDk130i@P@c?TL3=49<13E5D0@gBE@4>TeH13a@G0A0EF43@eUV14MNJ`A;HW04CfMe15A/
N`AILWl4GGF30fImS0AaRIH4NYBQ17jCW`B1TY`4Q96I0hJ@U`B9SY@4RhfA18b;SPB>RH/4T8R81966
QAGoool001Coool4RGUg181_K@AgI684KEYG16A?C0=KA444DCTf14P_:`A09B44>1/G134B3@<Z2`H4
9``912dE4P@f7a`4ABdX14H_:PA5;RX3A2dZ144[:0@l9bH4>2@S13<Q8@@`8244;b0R0c4T9P@e:B/4
=b`_13T`<`@j<cL4>3<g0cHb=`@b<3D4;ble12ha=`@_=C/4<3U213<nA`<d@T`4=DE@13M9E0@jCEP4
?51L141EH@=3FFH4Aei[14]RL0A?IgD4E6ak15UbO`AMMH<3IWf<1769UPAjU:44OY>O186BW0B4TIT3
QY2G18V>U0B;SI44S8^>18j9R`B@R8P4THJ55Oooo`005?ooo`B9NGL4P6m]17MTHPA]FUL4I4m<0e]4
@@AA>CH4B2l[140U8@@h6aL4<A8=0bX;1P@W30T4;ADB13HO70A5;BP4ARlZ14D^:P=4;BX4@B/X13`W
9P@h92<4<b4Q130P8@@_8283<B@V13DY:`@g;2l4>C0c13Xc=`@h<cL3=S8g138`=@@_;cD4;S4g12le
>`@`>D84<ci70cA2C0@eAE04=dUD13Y=F0@lD5`4@5EQ0d=IIPA7GV/4Bf9`14mWM@ADK7/4FG9o15ee
P`=VOH`4LHVF17ZDX@AnTil4PI:L18BAV@>6T9L4RHjD18^=T@B<Rhh4SXV;1928R0BAQXDEoooo000D
oooo18UiM`B0Kfd4MfAR16eJE`ATCd`3FdA1154i=PA8;b/4@2DQ13PK5`@a4Pd3:P/612L<2@@]5A84
=QlL14D]:0A6;bX4ABhZ0d@]:PA1:bP4?2LV13PT8`@c8B44<20Q12lP8P<a92H4=BT[13L/;`@i<3<4
>S<g13Pc=`<f<SL4<S0e12l_=@@^<CL4;cDk130i@P@c?TL3=49<13E5D0@gBE@4>TeH13a@G0A0EF43
@eUV14MNJ`A;HW04CfMe15A/N`AILWl4GGF30fImS0AaRIH4NYBQ17jCW`B1TY`4Q96I0hJ@U`B9SY@4
RhfA18b;SPB>RH/4T8R81966QAGoool001Coool4RGUg17m^K0AeHf44JeQF165<BP=G@Cl4CCDc14<Z
9`@i7a`4<ADB12X<20<U20D47`P712LC4P@g8Ql4B34[14Pb;@A6<2`3A2l/144/:P@m:BP4>2HV13<T
9@@_8RD4;R8U0c4V:0@e:bd4=bha13Ta=@@k=SX4>CHj0cDc>@@a<CH4;Rle12``=`@/=3`4;3M112ll
AP<`@4/4<D9>13=5DP@eBEH4=deJ13aCH0=0EfD4A5aZ14MPK`A;IG@4D6]j15E`OPAJM8<3IWn>17:<
VPAjUZ@4OYFQ186DWPB4TY/3Qi6H18V?U@B;SY84SHb?18j:S0B@R8T4THJ55Oooo`005?ooo`B9NGL4
Ofi/17ESH@A[F5H4HDa:0eM1?`A==C<4@bXW13TO70@a5A84:P`80bD81@@O20L49a<B13LR7`A8<B/4
B38]14H`;0=4;b`4@B`Z13dY:0@h9RH4<b@U12lR9@@^8RD3<BHX13D[;@@g;S44>C4e13/f>P@i=SX3
=C<i134a=P@^;cD4;30g12`d?0@/=d44;ca60c10B`@a@Th4<dEB13E9EP@gCEX4?5=P0d1GI@A4G6X4
Af1_14]UM0A@JgX4EG1n15YdP`=VOhh4LXbJ17ZFY0AnUJ44PIBN18BBV`>7TIP4RHnE18^>TPB=S8l4
SXZ<1928R@BAQXDEoooo000Doooo18UiM`AoKV`4MF=Q16]HEPAQC4X3Ed4o14de<`A3:RL4>AlL134E
4P@Z30P39@P511l81`@W4a84=b8O14Pa:`A8<Rd4AS0/0d@_;0A1;2X4?BTX13PV9P@c92D4;b8U12hR
9@<a9RP4=B/]13L^<@@i<CD4>cHj13Tf>P<e<cT4<C4f12h_=@@/<3L4;3@l12`g@@@_?4H3<41;1352
CP@cAE84=DUF13M=FP@lDf03@5MU14ALJPA7H6l4BfEd151[NPAEL7h4FWB30fIoSPAbS9X4NYJT17jE
X@B1U9h4Q9:K0hNAV0B9SiD4RhjB18f<S`B>RX`4T8R91966QAGoool001Coool4RGUg17m^K0AeHf44
JeQF165<BP=G@Cl4CCDc14<Z9`@i7a`4<ADB12X<20<U20D47`P712LC4P@g8Ql4B34[14Pb;@A6<2`3
A2l/144/:P@m:BP4>2HV13<T9@@_8RD4;R8U0c4V:0@e:bd4=bha13Ta=@@k=SX4>CHj0cDc>@@a<CH4
;Rle12``=`@/=3`4;3M112llAP<`@4/4<D9>13=5DP@eBEH4=deJ13aCH0=0EfD4A5aZ14MPK`A;IG@4
D6]j15E`OPAJM8<3IWn>17:<VPAjUZ@4OYFQ186DWPB4TY/3Qi6H18V?U@B;SY84SHb?18j:S0B@R8T4
THJ55Oooo`005?ooo`B8N7L4OVe[17ARH0AYEU@4GTY80e<n?0A8<S04?2DS134I5P@Y3P`48`P50b07
1P@O2`X4;1TG13`W8`A<=C04BSD`14Pc;`=5<Bl4@Rl]13h];@@k:R/4>R//13HY:`@g:R`3>bl`13dd
=P@o=cT4@C`o140n@P@k>Sl3=CHl134b>0@];cH4:S0h12Tb?0@X<ch4:cY50bXlB0@Y?DX4:d1>1316
E0@dC5X4>U5O0ciFI0A1FVT4AEm^14UTM0A=JGT4D6em15IbP`=SP8l4LXjM17^IY`AnUZ<4PIFO18BD
W0>7TYT4RI2F18^?T`B=SI04Sh^=1928R@BAQXHEoooo000Doooo18QhM`AnKF/4M69P16UFE0ANBTP3
Dchl14Pb<0@l9B<4<ATF12T>30@S20D380L611l;2P@/6AL4?2LS14`e<0A:=C04B3<_0dDa;`A2;bd4
?Rd]13/Z:`@j:b`4=RT[13LZ;0<k;c04?C@f13lg>@A1?3l4@3i213/j?`<e=S`4<C8h12d_=P@Z<3P4
:C8l12Pc?P@[>TD3:Sa812TmBP@[@4h4<4ID13A<FP@jDEl3?UIT145JJ@A5Gfh4BFAd14eYN@A@KGd4
EW:30f>0S`AbSYd4NiVW17jFX`B1UIl4Q9BL0hNBV@B9T9H4RhnC18f=T0B?Rhd4T8R91966QQGoool0
01Coool4R7Qg17i]J`AdHV04JEID15i:B0=C?S`4B38`13`U8`@a6AH4:@h<12<81@<P1`H47`/:12`I
5`@l9b<4C3D`14Xe<0A8<bl3AC4_148_;@@n;Bd4>bX[13X[;0@f:B/4=bX/0c/_<0@m=3H4?cLi144l
?`A0?T84>cXo0cDf?0@a<SP4;Blf12X`>0@Y<S`4:3<n12/jA@<Z?4P4:Ce:12]0CP@`AU@4=4aJ13YA
G`<nEV@4@EYY14EOKPA9I7@4CFUi151]O@AFLX<3Hh2?17:>W@AkVJL4OYJS186EW`B4U9`3Qi:I18V@
UPB;Si<4SHf@18n;S@B@R8T4THJ65Oooo`005?ooo`B8N7L4OVe[17ARH0AYEU@4GTY80e<n?0A8<S04
?2DS134I5P@Y3P`48`P50b071P@O2`X4;1TG13`W8`A<=C04BSD`14Pc;`=5<Bl4@Rl]13h];@@k:R/4
>R//13HY:`@g:R`3>bl`13dd=P@o=cT4@C`o140n@P@k>Sl3=CHl134b>0@];cH4:S0h12Tb?0@X<ch4
:cY50bXlB0@Y?DX4:d1>1316E0@dC5X4>U5O0ciFI0A1FVT4AEm^14UTM0A=JGT4D6em15IbP`=SP8l4
LXjM17^IY`AnUZ<4PIFO18BDW0>7TYT4RI2F18^?T`B=SI04Sh^=1928R@BAQXHEoooo000Doooo18Qh
MPAmKF/4LV5O16MED`ALB4L3D3/j14<^;0@f7ah4:14@11X100@K0P4370P711l>3P@/6aX4?RXW14li
<`A==c<4BSDb0dHc<@A3<C04@30`13h_<0@m;c44?2la148e=P=6>SX4B3dn14Q0@@A5@D@4@3m413/k
@@<f=Sd4<34h12`_=`@Z<CT4:S@n12Xg@P@/?TX39ca912<kBP@Z@E04;dMF135:F@@hD5l3?5ET145J
J@A3Gfl4AV=d14YWN0A;JW/4DG620f60T0AaSih4NiVW17jGX`B2UZ44QIFN0hRCV`B:TYP4S92D18j>
T@B?Rhd4T8V:1966QQGoool001Coool4R7Qf17e]J`AbHEl4IeEC15a8A`=@>cX4@bh/13HO7P@X4A04
6P4011/20@<L20L47`h>12`K6P@n:RL4CcTc14dg<`A:=C83AS<a14<a<0A0<304?Rl`13d_<@@l;c44
@SDf0dHj>PA8?Ch4B41114E1A0A0?d@4>c]10cHf?@@`<CP4;2lg12Xa>@@Z=3h4:SM212`nBP<W?4T4
8c]:12Y1D0@_AeH4<DYI13Q@G`<lEF@4@EYY14=OK`A6Hg@4BVMh14]ZN`AALH83HH2@176?WPAkVJL4
OYNS18:FX@B5UIh3R9>K18ZBV0B<T9@4SXjA18n;S@B@RHX4THJ65Oooo`005?ooo`B8N7H4OFe[179Q
G`AWEE<4G4Q70e0k>PA3;R`4=QlN12PA40@J0@046`810a`81`@O3Ph4;1/J13hZ9`A?>C<4CCLc14Xe
<P=6<c44@c4`140`<0@n;c04?Bla13`_<@A2=CH3ASXj14Pm?PA8@444AD54140oA0@k>d43=SHm130a
>0@/;cL4:S4i12Xd?P@Z=d84;3i:0bLlB@@S>dX4:T5@12m7EP@aBUT4>51O0caEI0A1FVT4@em_14IS
M0A:IgP4BfYk155aPP=QP904LHnN17^IY`AnUj<4PYJQ18FEWP>8Ti/4RY:H18b@U0B>SY44Sh^=1929
RPBAQXHEoooo000Doooo18QhMPAmKF/4LV5O16MED`ALB4L3D3/j14<^;0@f7ah4:14@11X100@K0P43
70P711l>3P@/6aX4?RXW14li<`A==c<4BSDb0dHc<@A3<C04@30`13h_<0@m;c44?2la148e=P=6>SX4
B3dn14Q0@@A5@D@4@3m413/k@@<f=Sd4<34h12`_=`@Z<CT4:S@n12Xg@P@/?TX39ca912<kBP@Z@E04
;dMF135:F@@hD5l3?5ET145JJ@A3Gfl4AV=d14YWN0A;JW/4DG620f60T0AaSih4NiVW17jGX`B2UZ44
QIFN0hRCV`B:TYP4S92D18j>T@B?Rhd4T8V:1966QQGoool001Coool4QgQf17a]J`AaH5l4IEAC15U7
AP==>SP4?b/Z130K6P@L1`H45@0011T51@<H20T47@l@12hN70A3;RX4Dcdg150j=`A<>3H3Ac@d14@c
<`A2<c@4?c8d13hb=0@n<cH4@CHi0d@j?@A6?d84Ad9514A2APA0@4D4>ca30cDg?P@`<SX4;34i12Xb
>`@Z=T04;3Y512hoB`<^@4`4;45?13E8EP@fC5X4>DmN141FI0=2FVT4A5i^14=PL@A4Hg@4AVEg14EW
NPA@LH<3HX2@17>>W@AkV:L4OiRU18>HXPB6Uj03RIFM18bCV@B=TIH4ShnB192<SPBARHX4TXN65Ooo
o`005?ooo`B7N7H4O6e[175PG`AUE5<4FDM60ddj>0@o:bX4<1/J11`71P@E00046@D50aP82@@M3a04
;QhL14<^:PAC?CL4D3Xg14`h=P=7=3@4A3<c148c=0@o<S@4?S8d13hc=PA1=ST3A3Xm14Ho@PA7@TD4
A4961410A@@k?4<3=CLn130b>P@/<CT4:S8k12Xf@0@/>TD4;Sm;0bi0C0@/@Dl4=DQF13I<FP@iCeh4
@5IT0d9JJ@A4GVh4@f1a14ASM0A6IGL4AFMj151aP`=RP904LhjM17^HY`AoV:D4PiRR18JGX0>9UId4
S9>I18fAUPB?Si84T8b>1969RPBBQhHEoooo000Doooo18MhMPAlKF/4LF1O16EDD`AIAdH3CCXh13l[
:P@`6aX470L611D000@I1@D360P911d?40@^7Q`4@bhZ15<m=`A@>SL4C3Pf0dLd=0A4<c<4@S<d13lb
=0@n<S@4?S<f144f>@=4>Sd4ASm214M2A@A4@TH4@41513/l@`<e=ch4<38j12`a>@@Z<S/4:SI012`j
A@@^?d/3;T1<12a1C`@eB5H4=TaJ13U?GPA0EV@3@UYY14ANKPA3H744A6=d14IUM`A5IgX4D7630f:0
T0AcSYd4NiRW17nHY@B3V:84QYNP0hVEW@B<TiT4SI6F18n?TPB@S8h4THV:19:7QQGoool001Coool4
QgQf17a]J`AaH5l4IEAC15U7AP==>SP4?b/Z130K6P@L1`H45@0011T51@<H20T47@l@12hN70A3;RX4
Dcdg150j=`A<>3H3Ac@d14@c<`A2<c@4?c8d13hb=0@n<cH4@CHi0d@j?@A6?d84Ad9514A2APA0@4D4
>ca30cDg?P@`<SX4;34i12Xb>`@Z=T04;3Y512hoB`<^@4`4;45?13E8EP@fC5X4>DmN141FI0=2FVT4
A5i^14=PL@A4Hg@4AVEg14EWNPA@LH<3HX2@17>>W@AkV:L4OiRU18>HXPB6Uj03RIFM18bCV@B=TIH4
ShnB192<SPBARHX4TXN65Oooo`005?ooo`B7N7L4O6a[171PGPATDe84F4I50d/h>0@m:RT4;AXI11`8
20@L2@T47P`=0b4B4`@V61P4=bDS14Pc;`AF@3/4Dchj14ll>P=;>ST4AcTi14<f=`@o<cD4?C8e13`c
=`@m=ST3@3Xn148m@@A3@4@4@T9713m0AP@j?4<3=3Ln12lc>`@[<S/4:C8l12Te@0@Z>DD4;3i;0bm1
CP@dAe@4?TmL13mCH0A1EV<4AU]Y0dEMK0A2Gfl4@F1a145RM0A1I7L4@VIj155cQ@=TPY84M92N17fK
Z@B1VZL4QIZT18RIXP>;Uil4SIFK18nCU`B@T9<4THf?19::R`BBQhHEoooo000Doooo18MhM`AlK6/4
L61N16ACDPAHATD3BcPh13dZ:@@]6QT470P811`92@@N30d38A8C12HH60@g9B<4B3<_15I0>`AC?SX4
Cc`j0d/j>@A7>CT4@cHg13lc=@@m<SD4?3<g13df>@=0>Sh4@Se114=0A0A2@TL4?d1613Xl@`<d=ch4
;c<k12/b>`@Y<S`4:CE012XiA@@/?T/3;d5>13A7E0@nCe`4?e=P145FH`A6FfT3AEe/149OK`A1H744
@F9d145TM`A2IWX4DG>50fB2TPAdT9h4OI^Y186JY`B5VZ@4R9VR0h^GW`B=UI/4Si>G192@T`BASHl4
TXZ;19:7QQGoool001Coool4QgQg17a/J`A`H5h4I5=B15Q6A@=;>3P4?BXY12dJ6@@L20P470T911h<
3@<Q4Q<49QPH13LU8`A8<bl4ET0k15<n>PA??3X3BcXi14Li>@A3=SL4?c<e13db=@@l<cL4?CHi0d0j
?PA2?D44@d141492A`@o@4H4>Sa30c@g?P@_<c/4:c8k12Tb?0@Y=D04:SU512`nB`<_@Dh4=4MD13i?
G0@oDf04@EIS14IKJ@=5GF`4@Um_145PL@A1HW@4@FAg149VNPAALhD3I8:B17B@WPAmVjT4PIZW18FJ
Y0B8VJ83RiNO18fEV`B?TiL4T92C196=S`BBRX/4TXN65Oooo`005?ooo`B7N7H4NfaZ171OGPATDe84
EdI50dXh>0@l:RX4;A/K11d;2`@N3@h48A4B0bLH60@`81l4?R`Y14`h=0AH@Sh4ED4n1550?P=>?Sh4
BSdn14Pm?`A6?3l4@c`o14Dn@@A7@D@3BDA714Q5B@A8AT/4ADI;13m1B0@i>d<3<cHn12lc?0@[<cd4
:C8n12Ld@0@W=dD4:Sa:0be0C`@aAU@4=daJ13]AG`@nEVD4@EYY0cmKK0@oG6l4?Uia13iPL`@lHGD4
?fEj159dQ`=YQYH4MI6P17fLZ`B2W:P4QibW18^KY0>>VZ44T9NM196DV@BBTID4TXj@19:;R`BBQhLE
oooo000Doooo18MhMPAkK6X4L5mN16ACDPAGATD3BSPh13`Z:P@]6a/47@/;11h=3P@Q4A839aPH130P
7`@n;2T4C3Pd15Q2?PAE@Ch4DD0n0dhn?PA:?Ch4B3do14Hl?`A3?3l4ACi114M1A0=9A4L4B4E914Q6
B`A5AT/4?d5813Tk@`<c=Sh4;c<l12/c?@@Y<Sh49cA012LgA@@Z?4X3;D1?1356E0@gC5X4>e5O13iF
I@A1FVT3?e]/13mLK`@nGW44?V1c13aQM@@oIGX4DWB70fV6UPAeTJ04OIb[18:LZ0B7W:L4Ri^T0hjJ
X@B@Uid4TIBI19:AU@BBSY04TX^;19:7QaGoool001Coool4QgQf17]/JPA`Geh4I5=B15M6A@=:>3P4
?2XZ12dK6`@M2`/47Pd>124A4P<W61P4<20O13h/:@A<>3@4F48n15E1?PAA@3h3CShn14Xm?PA8?Cl4
AS`o14<l?`A5?T44Ad540dU4A`A8ADT4B4I;14E6B`@o@DP4>C]30c<f?P@_<c`4:c<m12Tb?P@W=404
9cM512XlBP<]@4l4<DID13M<FP@kDEl4?UIU145JJ@<oFf`4?ea_13iNL@@nH7<4?65e13mUNPABM8L3
JHJF17FAX0AmW:/4PYbX18NLY`B;Vj@3SYZQ192GW@BAU9T4TY6E19:>T0BBRh/4TXN75Oooo`005?oo
o`B7N7H4NfaZ171OGPATDe84EdI50dXh>0@l:RX4;A/K11d;2`@N3@h48A4B0bLH60@`81l4?R`Y14`h
=0AH@Sh4ED4n1550?P=>?Sh4BSdn14Pm?`A6?3l4@c`o14Dn@@A7@D@3BDA714Q5B@A8AT/4ADI;13m1
B0@i>d<3<cHn12lc?0@[<cd4:C8n12Ld@0@W=dD4:Sa:0be0C`@aAU@4=daJ13]AG`@nEVD4@EYY0cmK
K0@oG6l4?Uia13iPL`@lHGD4?fEj159dQ`=YQYH4MI6P17fLZ`B2W:P4QibW18^KY0>>VZ44T9NM196D
V@BBTID4TXj@19:;R`BBQhLEoooo000Doooo18MhMPAkK6X4KemN16=CDPAGATD3BSTh13`[:`@^7Ad4
80h?128B4P@W5aP3;AhN13DU90A2<2h4D3/h15U4?`AGA444Dd=10dm1@@A<@D84BT1214U1A0A9A4L4
BdI914Y7BP=:B4`4BDQ=14M7C@A1A4X4?3i613Hi@@<a=Sh4;S@m12`d?P@[=T44:cQ512XkB@@Y?D`3
:Ci>12e3D`@bBET4=DiM13QBHP@jEFH3>eQZ13]JK@@kGG04>eic13QNM0A0IW`4EGN:0fV6UPAaSYd4
NIRW18FOZ`B;X:X4SinW0i6MY0BBVZ04TiNK19>CUPBCSi44Thb<19>8QaGoool001Coool4QgQf17]/
JPA_Geh4He=B15M6A@=:>CP4?2/[12hM7@@P3Pl48Q8B12LG60<]7Qh4=BDT148`;PA@>cP4FD@o15M4
@@AC@d43Cd5114a1@PA:@484BD5414U4A`A;ATT4BTM:0dY8C0A9B4d4AdM=1454BP@l?TH4=SU10c4f
?P@^=3d4;3@n12/f@@@[>4D4:S]912TmC0<Y?Th4;D=C1399F@@eCUd4>59R13YEIP<kF6X4>eY]13]M
L0@kGW<4>5id141VO0AEMhX3JHJF176>W@AiV:L4QIn[18^PZPB?WjL3TIfT19:JX0BCUi/4Ti>F19>?
T@BCS8`4ThR75Oooo`005?ooo`B7N7H4NfaZ16mOGPASDe84EdI50dXi>0@l:b/4;QdM120>3`@R4Q84
9aLH0bdN7P@e9B@4@S0^150k>0AIA3l4EdA115=3@@=?@D44C45214Y0@PA9@D@4BDA714]6B@A:AdX3
BTQ<14U8C@A7Add4@DA:13`nAP@f>D43<CHn12hd?@@/=3h4:cI112/hA@@Z>dT4:Ce<0bTnCP@]@e<4
<TUI13E>G@@hDV84>UEV0c]HJP@kFVd4>ee`13]NL`@hGW@4@6Il15EgRP=YQYH4LHjM17VHY`B5Wj/4
Rj2Z18nOY`>AWJ@4TYZP19>GV`BCTiH4ThnA19><S0BCR8LEoooo000Doooo18MhMPAkK6X4KemN16=C
DPAGATD3BSTh13`[:`@^7Ad480h?128B4P@W5aP3;AhN13DU90A2<2h4D3/h15U4?`AGA444Dd=10dm1
@@A<@D84BT1214U1A0A9A4L4BdI914Y7BP=:B4`4BDQ=14M7C@A1A4X4?3i613Hi@@<a=Sh4;S@m12`d
?P@[=T44:cQ512XkB@@Y?D`3:Ci>12e3D`@bBET4=DiM13QBHP@jEFH3>eQZ13]JK@@kGG04>eic13QN
M0A0IW`4EGN:0fV6UPAaSYd4NIRW18FOZ`B;X:X4SinW0i6MY0BBVZ04TiNK19>CUPBCSi44Thb<19>8
QaGoool001Coool4QgQf17]/J`A_H5l4HeAC15M7AP=:>SX4?Bd]130O7`@R4A849AHG12/L70<b8R84
?2XY14Pd<PAB?S/4FTE115U6A0AEAD@3DD=414e3A0A;@T@4BD9614Q3A`A7@dP4AT=80dE3B@A3@TP4
@45713`nA@@h>d84<cLo0c0d?@@]<cd4:c@o12/f@P@[>DH4;3e;12m2D0<`A5<4<4IF12i8F0@`BU`4
<TiP13EBI@<gEVT4>UY^13YLL@@gGG84=Ume14=ZO`AFN8`3IHBE176?W`AnWJ/4T:Vd19:V[`BDXj/3
UJ2W19JMXPBFVId4UYFH19FAT`BDSHd4ThR85Oooo`005?ooo`B7N7H4Nfa[16mPG`ASE5<4EdM60dXj
>P@m;Bd4<1lO128A4P@U5QL4:a`L0c8R8P@l:RT4B3@b158n>`AJAD44FDI415E5A0=A@d@4CD=414]2
A0A9@TH4B4=714M3B0A6@dP3AD=914=2B0A0@DL4?3i513Pk@P@c=cl3<3@m12dc?@@[=3l4:cI212/i
AP@/?D/4;d9@0c14D`@`AUH4;TQH131:G0@bCV04=E9U0cMFJ@@jFVh4>Uaa13MMLP@fGgD4@fYo15Ih
S0=UQ9D4LHnO17jMZ`B@ZK@4TZJ_19BSZ`>EX:L4UYfR19JIW@BFUIP4UI6C19B=S@BCR8PEoooo000D
oooo18MhMPAkK6/4Kf1O16=DD`AGAdH3BSXj13d];@@`7al48Q4B12DF5`@[71`3<R8R13`Z:@A8=384
DShk15Y5@@AIAT@4EDE40e53A0A=@d@4Bd9414U2APA8@dL4Ad=814I3B0=5@dT4@d981411A`@l?TD4
>3]213<g?`<`=3d4;C<m12/d?`@[=T84:cU612`mB`@_@U03<4AC1316EP@^B5P4<4YL139>H0@eDVD3
=eIY13YJKP@jG744=eeb13IOM@A3JWl4EWR<0fF4U@AaSil4OYf[192Y]0BBYZl4U:>[0iFPY`BFWJ84
UYVM19JEV0BETI<4U8f=19>8R1Goool001Coool4QgQf17]/J`A_H5l4HeAC15M7AP=:>SX4?Bd]130O
7`@R4A849AHG12/L70<b8R84?2XY14Pd<PAB?S/4FTE115U6A0AEAD@3DD=414e3A0A;@T@4BD9614Q3
A`A7@dP4AT=80dE3B@A3@TP4@45713`nA@@h>d84<cLo0c0d?@@]<cd4:c@o12/f@P@[>DH4;3e;12m2
D0<`A5<4<4IF12i8F0@`BU`4<TiP13EBI@<gEVT4>UY^13YLL@@gGG84=Ume14=ZO`AFN8`3IHBE176?
W`AnWJ/4T:Vd19:V[`BDXj/3UJ2W19JMXPBFVId4UYFH19FAT`BDSHd4ThR85Oooo`005?ooo`B7N7L4
Nfa[171PG`ATE5@4F4Q70d/k>`@o;Rl4<R4R12DE5P@Z6QX4;QlO0cHV9P@o;Rd4BSLe15<o?0AIAD84
F4M515E6AP=AADD4CT=514]2A@A8@TD4AT5514A1A@A2@4D3@3m513dm@`@k>d84=cU013@f?P@`=3d3
;38l12/b?@@Y<cl4:CE212TgA@@Z>dT4;3m=0bm4DP@cBEP4=TeM13M@H@@gDf@4>UIY0cYIK@@jFg04
=Ua`13AML`@fH7L4Afj315QlSP=WR9T4MiJU18NS/@BG[[T4VJ^d19ZX/0>JY:/4VZ2U19VLX0BHUiX4
Ui:D19F=SPBDRHPEoooo000Doooo18MhM`AkK6/4L61O16ADE0AHB4L3Bc/k13l^;`@b8B849ADF12XJ
6P@^7al3=RHV13l^;@A:=cD4Dcll15U5@PAHAdD4EDI60e55A@A>@dD4Bd9514Q2A@A6@DD4A4551490
A@=0?dD4?Ce313/k@P@g>D04=3Hn130d?@</<S`4:c8m12Tc?`@Y=D84:CM512XkB@@/?dd3;dAB13=9
F0@fCEd4=e1Q13MCI0@jEVT3>UU]13YKL0@fG704=5ec13IPM`A7KX<4F7b>0fN8V@AgUZD4Qj>a19N^
^@BIZk@4VZR`0iZTZ`BJX:D4VIbP19RGVPBGTY@4UHf>19B9R1Goool001Coool4QgQg17]/J`A`H5l4
I5AD15Q8A`=;>c/4?bh_138Q8P@U5AH4:QXJ12hO7`<f9RH4?bh]14Xg=@AC?c`4FDE215Q7A@AEATH3
DDE514i3A@A;@TD4B49514I1A@A4@DD4@T150d0oA@@m?D<4>c]213Li@0@d=Sh4<3@m0b`b?0@[<Sd4
:C<o12Te@P@Y=dD4:S]912`oC@<_A584<dUH13I=G@@gD644=e=T13YFJ@<jFFd4>U]`13ILL0@dGG<4
=V1g14M^P`AHO8h3IhRI17NFY@B7Xk44Ujji19V[]0BJZ;03VZB[19ZPY@BIW:04V9NJ19NBU0BESHh4
U8V85Oooo`005?ooo`B7N7L4Nfa[171PG`ATE5@4F4Q70d/k>`@o;Rl4<R4R12DE5P@Z6QX4;QlO0cHV
9P@o;Rd4BSLe15<o?0AIAD84F4M515E6AP=AADD4CT=514]2A@A8@TD4AT5514A1A@A2@4D3@3m513dm
@`@k>d84=cU013@f?P@`=3d3;38l12/b?@@Y<cl4:CE212TgA@@Z>dT4;3m=0bm4DP@cBEP4=TeM13M@
H@@gDf@4>UIY0cYIK@@jFg04=Ua`13AML`@fH7L4Afj315QlSP=WR9T4MiJU18NS/@BG[[T4VJ^d19ZX
/0>JY:/4VZ2U19VLX0BHUiX4Ui:D19F=SPBDRHPEoooo000Doooo18MhM`AlKF/4L65P16EEE@AIBDT3
CCdm140`<@@d92@49aLH12/L70@`8B83>BPY144`;`A:>3H4DCll15M4@PAHAdH4ETQ70e96A`A>A4L4
BT=614M1APA4@4@4@Ci313hl@P<l>T04>CPn13Hf?@@b=3/4;c8j12``>P<Y;cT4:30k12La?P@V<d04
9SE312LhA`@Y?4/3;45A12m6E`@cC5`4=U1Q13QDIP@hEVX3=eQ/13EIKP@cFg04<eab13USN@A:LXH4
GH2C0fj>WPAoW:X4SjRd19fb_0BP/KT4X:je0j2Y[`BNY:T4W9nR19^IW0BIU9D4Uhj?19F9R1Goool0
01Coool4QgQg17a]J`A`HF04IEEE15U9B@==?Cd4@30a13@T90@W5aP4:a`L130Q8P<i:2T4@C0_14Xh
=PAA?c`4EdA215Q7APAFB4L3DTI714i4A`A:@dH4Ad5614A0A0A1?T<4?Sa20c`j@0@i>3h4=SHm138d
>`@_<SX4;30j0bT_>@@X<3/49c4n12Hc@0@V=D<49cQ712TlB`</@E44;dIG13=<G0@fD644>5AV13QF
JP<gF6`4=EU^13=KL0@cG784>F=i14YbQPAMP9<3KXjN17nLZPB?Z;@4WK:l1:2a^@BP[[D3X:V_19jT
Z@BLWj84ViVL19VDU@BGSXl4UHV85Oooo`005?ooo`B7N7L4O6e[171QH0AUEED4FDU90ddm?@A0<344
=2@T12LG60@[71`4<24R0cTX:@A1<2l4BSPf154o?0AGA484F4M615I8A`=BATL4CTA714Y3APA7@DH4
A414144n@`@n?483?3Y013Th?P@f=Sd4<S@k12lb>P@/<3X3:Bli12P`>`@W<Ch49S=012He@`@W>4L4
:Ca;0ba1D@@_AUL4<daL13I@H@@hE6H4>5IZ0cMHK0@eFFh4<e]`13=LLP@iHgT4BW:615f0T`=^SYh4
OibZ18nX]0BM/[`4X;6i1:2^]@>PZJl4WZBY19bOXPBKVI`4VIBE19N>S`BERHPEoooo000Doooo18Mh
M`AlKF`4LF9Q16EFEPAJBTX3CSho148b<`@f9RL4:AXK12hO8@@c9BH3>R/[144a<@A8>CP4Cclm15E4
@`AHAdH4ETU90e97B0A=A4L4BD9614E0A@A1?T<4?S]113/i?`<g=Sd4=3@k134b>P@^<3P4:bhg12L/
=`<U;3P492dj12<_?0@S<Cl48c=212<fAP@U>TX39cm@12]4E@@]B5X4;daN135@H`@aDfL3<5EZ131G
K@@_FG04<5ed13aWOPA@Mh/4HXFH0gBCX`B6XJl4V:nj1:Ji`PB[^/84Z;Bk0jJ^/`BSZ:`4X:6U19fK
WPBKUIL4V8n@19F:RAGoool001Coool4QgQg17a]K0AaHV44IEIF15Y:BP=>?Sl4@S8c13HV9`@Y6Q/4
;QlQ13<U9P<j:b/4@C4a14Pi>0A??cd4EDA315Q7APAFBDT3DTM814e4A`A9@TH4AD15144n@`@n>d44
>cTo0cLf?@@d=3/4<C8j12h`>0@[;SL49b`g0bD/>0@T;CX48bll12<a?`@S<d848cI612DjBP<W?e04
:dAE12e8FP@_C5h4<E1S135CI`<`EFX4<5M]12mIL0@`GG@4?6Mn151gR`ARQIP3M9>S18JQ[`BH[kX4
Y[W21:^j`PBX];/3YZjc1:>X[0BPXJD4WI^N19^EU`BHSi04UHZ95Oooo`005?ooo`B7N7L4O6e/175R
H@AUEUH4FTY:0dhn?`A2<S<4=RHW12TJ6`@^7b44<bDV0cX[:`A1<C44B3Th14lo?@AEA4<4F4M615I9
B@=BAdP4CDA714U2APA5@4D4@Ci313hk@@@k>Cl3=cHm13@d>`@a<SX4;S0h12/^=`@W;3L39B`h12@]
>P@S;c`48c4o12<c@P@S=TH49CY:0bLoD0@[A5D4;DQJ12m<GP@aD6<4<E=W0c1EJP@`Efd4;eU`131M
M0@lIgh4D7N;16:5V0=dTj<4QZ6_19R_^PBV^L84Zk[21:Rd^`>V[[<4XjR/1:2QY@BMVih4ViFG19R?
T0BERXTEoooo000Doooo18MhM`AlKF`4LF9Q16EFEPAJBTX3CSho148b<`@f9RL4:AXK12hO8@@c9BH3
>R/[144a<@A8>CP4Cclm15E4@`AHAdH4ETU90e97B0A=A4L4BD9614E0A@A1?T<4?S]113/i?`<g=Sd4
=3@k134b>P@^<3P4:bhg12L/=`<U;3P492dj12<_?0@S<Cl48c=212<fAP@U>TX39cm@12]4E@@]B5X4
;daN135@H`@aDfL3<5EZ131GK@@_FG04<5ed13aWOPA@Mh/4HXFH0gBCX`B6XJl4V:nj1:Ji`PB[^/84
Z;Bk0jJ^/`BSZ:`4X:6U19fKWPBKUIL4V8n@19F:RAGoool001Coool4R7Ug17e^K@AbHf84IUMG15]<
C0=@@444A3De13PY:P@/7Ah4<B<T13HX:@<l;Rh4@c@d14Xj>PA@@404ETI515Q9B0AHBT/3DTM914e4
B0A8@DH4@ci313ll@@@k>Cl4=cHm0c<c>P@`<3P4;2hf12T/=@@V:S@48bTd0b8Y=P@Q:SP482`k11l_
?P@O<D4483A5124hB@<T?Dh49T5C12Q5F0@ZBEd4:deQ12a@I@<]DfT4;EI/12iHL0@dH7L4AFj415Mm
T0AZRid3OIZY196Z]PBT^<84//?;1;K4b`B`^l43[;>h1:N[[`BTY:L4X9fO19bGV0BIT944UXZ95Ooo
o`005?ooo`B8NGL4OFi]179SHPAVEeL4Fda<0e10@@A4=CD4>2TZ12`M7P@a8b@4=RPY0c`^;PA3=3@4
BSXj1510@0AFATD4F4U815Q:B`=BAdT4CDA814Q1APA3?T<4?ca113/i?`@g=Sd3<c<j130`>0@/;SH4
:B`e12HZ=0@S:C@38RTf124Z>0@P;3/47bln11la@@@P=4D48CQ90b@mCP@V@E<4:4EH12Y9G@@[CF44
;51U0beCJ@@]EV`4;UQ`13APM`A5KX@4Egf@16Z;W@=mVZT4TJZf1:Bh`PBb`l/4]/C;1;2k`@>//kP4
Yj^_1:BTY`BPWIl4W9NH19V@T@BFRXTEoooo000Doooo18QiM`AmKVd4LV=R16IGE`AKC4`3D41114@e
=@@h:BX4;1dN134S90@f:2T3?2h^14<d=0A:>SX4D41015I6A@AHBDP4F4Y;0e97B@A=A4P4B45614<n
@`@o?444>cTo13Lf?@<c<cX4<30h12`^=P@Y;3D49RXd12<Y=0<R:CH48BXh120/>`@O;ch47c51120d
A@@Q>4T393e>12I1D`@XAEP4:TUM12]=H@@/D6D3;E=Y12eFK0@^F704=61g14E^Q0AGOI04JX^M0gfJ
Z@BAZ[H4Y;S21;;3b`Bfa</4/;_10jbc^0BWZjl4Y:BW1:2MW`BLUiP4VI2A19J:RAGoool001Coool4
R7Ug17e^K@AbHf84IUMG15]<C0=@@444A3De13PY:P@/7Ah4<B<T13HX:@<l;Rh4@c@d14Xj>PA@@404
ETI515Q9B0AHBT/3DTM914e4B0A8@DH4@ci313ll@@@k>Cl4=cHm0c<c>P@`<3P4;2hf12T/=@@V:S@4
8bTd0b8Y=P@Q:SP482`k11l_?P@O<D4483A5124hB@<T?Dh49T5C12Q5F0@ZBEd4:deQ12a@I@<]DfT4
;EI/12iHL0@dH7L4AFj415MmT0AZRid3OIZY196Z]PBT^<84//?;1;K4b`B`^l43[;>h1:N[[`BTY:L4
X9fO19bGV0BIT944UXZ95Oooo`005?ooo`B8NGP4OFm]17=TH`AXFET4GDi>0e53@`A6=cP4>R/]12hP
8P@c9RL4>B//0ch`<@A3=CH4B3Xk1511@@AFATD4FDU815Q:BP=BB4X4BdA814I1A@A0?D84?3U013Lf
?@@c<cX3;c0g12/]=@@X:S<492Pb128W<@@O9S837BHd11`X=P@L:SX472dm11`_@0@M<d@47SM90b0k
C@@R?e84949F12E6F`@WBUl4:4iT0bYAJ0@ZEF`4;UYb13YUO0A<M8T4Gh>F17BDY0>9Y;44W[>n1;72
bPC2d=L4`<cB1;O0a@>a]k/4[:nb1:NWZ@BRWj44WYRI19ZAT@BFRhXEoooo000Doooo18QiN0AmKfd4
LfAS16QIF@AMCTh3DD=314Hg>0@j:bd4;R0R13<V9`@i:b`3?S0a14<e=PA8>S/4D45115I6A@AIBDP4
F4Y:0e98BPA;A4P4AT55140m@P@l>D04=cHm13<c>P<_<3L4:bde12PZ<`@T:3848RLa11lV<P<M9S@4
72Pf11`Z>P@L;Cd472m011dcA0@N=dT383]=128oDP@T@UH49DIK12M:G`@XCV@3:U5X12YEK0@^FW84
>VEl14adR@AOPiH4M9BT0hVT/@BN/kh4/L;:1<;@e`C0c=84]l350k6g^`B/[k84YjNY1::OX@BNV9T4
VY6A19J;RQGoool001Coool4R7Uh17e_K@AcI6<4J5UI15e>CP=A@d<4ASLh13X[;@@^8284<bHW13T[
;0<n<344@cDf14Pj>`A@@D44ETI515U9B0AHBTX3DTQ:14]4B0A6@DD4@3e213`i@0@g=Sd4<c<j0bl`
=`@[;CD4:2Xc12@X<P@R9c447bHb0adV=0@L:3H472Xj11`]?@@L;d047C=411hgB@<P>dd48SmB12A2
EP@UAU/49dYO12Q>I0<ZDFP4:UE/12iJLP@jIG`4C7B915n3UPAdU:@3RJBa19jc_PBa`/X4`]3G1<3<
dPBg`<D3/KNk1:b_/PBWYjT4XYnQ19jHV@BJTI44UX^:5Oooo`005?ooo`B8NGP4OFm]17=TH`AXFET4
GDi>0e53@`A6=cP4>R/]12hP8P@c9RL4>B//0ch`<@A3=CH4B3Xk1511@@AFATD4FDU815Q:BP=BB4X4
BdA814I1A@A0?D84?3U013Lf?@@c<cX3;c0g12/]=@@X:S<492Pb128W<@@O9S837BHd11`X=P@L:SX4
72dm11`_@0@M<d@47SM90b0kC@@R?e84949F12E6F`@WBUl4:4iT0bYAJ0@ZEF`4;UYb13YUO0A<M8T4
Gh>F17BDY0>9Y;44W[>n1;72bPC2d=L4`<cB1;O0a@>a]k/4[:nb1:NWZ@BRWj44WYRI19ZAT@BFRhXE
oooo000Doooo18QjN0AnKfh4M6ET16UKFPAND503E4E614Pj>`@l;Rl4<2<U13DX:P@k;Bl3?c8c14<f
=`A:?3d4D49315A6APAFBDT4EDU;0e18B`A:A4P4@cm513hk@@@h=ch4<c<k12l_=`<Z;3@49RPa12<V
<0@O92h47B<^11XR;`<I93846BHe11PY>0@H:c`46Bi011XbA0@K=DP37CU<11hmD@@P@EH48TEJ12=9
G`@UCF@39U5X12]GKP@cGgH4@Vb215ElT0A[S9h4P9f[0iF]^@BY_<H4_<_B1<_Gg@C4c]<4_<C80kJj
_PB_/K@4ZZV[1:FQXPBPVIX4Vi:B19N;RQGoool001Coool4R7Yh17i_KPAdIF@4JE]J15i@D0=DADH4
B3Xk13`^;`@`8bD4=BPZ13/];`<o<S<4@cHg14Xl?@A@@T<4E4I615I9B@AEBD/3D4Q;14Y4B0A3?dD4
?S]113Pg?P@c<c/4;blg0bX/=0@V:3448bH`11lT;P@M8bh46R8_0aTT<P@I9SD462Th11P[?0@I;T04
6S9411/eB0<M>D`47SeA1211EP@RAEX48dUO12E=I0<VDFP4:eM^13=OMPA2K884EGb@16^<WPB0WJ/3
UJfi1:VlaPBlbm84bmOM1<C>d`Bla<P3][Zn1:na]0BZZJ/4YJ6R1:2IVPBKTY84Uh^:5Oooo`005?oo
o`B8NWP4OVm^17AUI0AYFeX4GU1@0eA5APA8>S/4?2h_130S9@@e:2X4>bd_0clb<`A3=SL4BS`m1512
@`ADATH4ETU915E9B`=@B4/4BTA814<oA@@n>d44>3Ln13<c>`@_;cL3:R`d12HX<@@S9S047b@^11dS
;P@J8Rl36B@b11TV=@@H:CP462/l11T^@0@J<T@46cE80adiC0@N?E44845F1295FP@SBEl49DeT0bIA
J0@[Efh4<emf149/PPAEO904JhbN182MZ`>E[KT4ZKc61;c;dPC;emd4a<kC1;c4b0>f^[h4[k6d1:ZY
Z`BUXJ84X9VJ19^BTPBGRhXEoooo000Doooo18QjN0AnKfh4M6ET16UKFPAND503E4E614Pj>`@l;Rl4
<2<U13DX:P@k;Bl3?c8c14<f=`A:?3d4D49315A6APAFBDT4EDU;0e18B`A:A4P4@cm513hk@@@h=ch4
<c<k12l_=`<Z;3@49RPa12<V<0@O92h47B<^11XR;`<I93846BHe11PY>0@H:c`46Bi011XbA0@K=DP3
7CU<11hmD@@P@EH48TEJ12=9G`@UCF@39U5X12]GKP@cGgH4@Vb215ElT0A[S9h4P9f[0iF]^@BY_<H4
_<_B1<_Gg@C4c]<4_<C80kJj_PB_/K@4ZZV[1:FQXPBPVIX4Vi:B19N;RQGoool001Coool4RGYi17m`
K`AeIVH4JeaL165BDP=FB4P4Bcdn140b=0@d9bT4>B`]13d`<P=1=3H4ACTj14Xn?`A?@T<4DTI615A8
BPA@AdX3CDI914M3A`A1?T@4>SU013Dd?0@_<3P4:R/d0bHX<@@Q92h47B8/11XP:`@H7bd45Ql^0aDQ
<0@D93@45BLg11DZ>`@F;Cl45c5411PdB0<J>4`473eA11i0E@@OA5X484QO129<I0<VDFT4;5Ua13MT
N`A:LhT4GhBG17FDY@B:Y;<3WkG01;G5cPC9e=/4dmgR1<WAe@C1a/X3^Kg01;>c]PB/Zj`4Yj:T1:6J
V`BLTi84Uh^:5Oooo`005?ooo`B9NWT4Og1_17EVIPA[G5`4HE9B0eI8B0A;?Ch4@38d13@W:@@i;2d4
?C0b0d4d=PA5>CX4BSho14m2@`ABATH4E4Q:1517BP==ATT4Ad=7144nA0@j>D04=C@l12l`>0@Z:c@3
9RPa124T;P@M8R`46R0[11PO;@@F7bh35B4`11@T=0@E9cL45BXk11H]?`@G<D@463A80aXhC0@L?E44
7T1E11m4FP@PB5l48TaT0bIAJ@@/FG44=fAk14YcR@AOQ9L4MIBU18ZT/`>O]L04]LG>1<WDf`CCgN84
bM7E1<76bP>i_L04/k>f1:b[[0BWXZ@4XIZK19bCTPBGRhXEoooo000Doooo18UjN@AoL6l4MFIV16]L
G0AQDU83ETQ814/m?PA0<S@4=2LY13T/;@@m<383@C@f14Di>PA:?Sl4Cd931596APADB4X4D4M:0de6
B@A7@dL4@Ci413Xi@0@e=3`4;c0h12X[=0<V:3448B@^11dR;0@J82/461l]11HO;P<E8C0452@d11DW
=`@E:S/45Rdo11LaA0@H=4P36SQ<11`mD@@N@5D47dAJ1218G`@RC6@39U5Y12aIL@@gI7/4BW>915n4
U`AeU:D4RZBc0ine`0BeaLh4bMCK1=?MhPC9dMD4`LK:0kVm`0Bc/kH4[:^/1:NRY0BQVY/4W9>B19N;
RQGoool001Coool4RG]i181aL0AfJ6L4KEiN16=EE@=IBd`4Cd5214@f>0@i:bd4?C0a140d=P=3=cT4
ASXl14Tm?`A=@T@4CdE714m6B@A<A4P3BTA814A1A`@n?484=cHn130a>@@[;CD49BPa0b0T;P@L8B`4
61l[11DM:P@C72/44A`/0a0O;`@A8S@44BDg118Y>`@C:cl452m311HcB0<H=d`46CaA11]0EP@MA5/4
7TQP125=I@<WDf`4<Eif145/PPAEOI44K8fO186N[PBF[[/3[Ko91<CAf0CIhnL4fN;V1<gDe`C4bL`3
_;k11;Fe]`B_[:d4Z:>T1:>KV`BMTi<4V8^:5Oooo`005?ooo`B9NgT4P75`17IXI`A]GUh4HeEE0eU;
C0A?@D84A3Hh13T[;@@m<344@3@f0d<g>@A6>S`4BCdo14e2A0A?ADL4CdI914a4B0=:A4P4A45713hl
@P@g=Sh4<34i12/]=@@U:34382@^11`Q;0@H7b/45AdZ11<L:`@A72`341l_114R=0@A9CL44RTk11<[
?`@D;d<45S=80aPgC0@I?5446d1F11e4F`@NB6048DeU0bMCK0@aGWH4@Fb215EmT@A/SIl4PIj^19J^
^`>]_lT4a=7H1=WSi`CIh^H4cMCG1<C9c0>l_/44]KFg1:n/[@BXXj@4Xi^K19fCT`BHRhXEoooo000D
oooo18UkN@B0LG04MVQW16eNGPASEED3FD]<14m1@PA4=SP4>B/]13d`<@A0=3H3@cLi14Hj?0A9?Cl4
CD9414m5A`A?ATT4C4A80dY4B0A4@DL4?Sa213Lf?P@`<CT4:bde12DX<@<P92h4724/11PO:`@E7BX4
4a`[114L;0<@7bl44B8d114U=`@B:C/44b/o11@_@`@F<dP363M<11TlD@@K@5H47DAK11i8H0@QCFD3
9e=/135NMPA1K884EGfA16b=W`B1WZh4UZjk0jfob@C4dMP4fN?W1=WRiPC=e=L4a<W<0kbn`@Be]KL4
[jb]1:RSY0BSVi/4WI>C19R;RQGoool001Coool4RG]i181aL0AfJ6L4KEiN16=EE@=IBd`4Cd5214@f
>0@i:bd4?C0a140d=P=3=cT4ASXl14Tm?`A=@T@4CdE714m6B@A<A4P3BTA814A1A`@n?484=cHn130a
>@@[;CD49BPa0b0T;P@L8B`461l[11DM:P@C72/44A`/0a0O;`@A8S@44BDg118Y>`@C:cl452m311Hc
B0<H=d`46CaA11]0EP@MA5/47TQP125=I@<WDf`4<Eif145/PPAEOI44K8fO186N[PBF[[/3[Ko91<CA
f0CIhnL4fN;V1<gDe`C4bL`3_;k11;Fe]`B_[:d4Z:>T1:>KV`BMTi<4V8^:5Oooo`005?ooo`B:NgX4
PG9a17QYJ@A_HF04IEQH0ea>C`ABADH4B3/m13ha<`A0=3H4@cLj0dDj?0A7?3h4BSm214a3A@A=ADP4
C4E814U3B0=7@dP4@Cm513Xi@@@b<c`4;2hh12HZ=0@P9C036b4]11HN:`@C72X43aXY10dI:@@<6b/3
31d_10dQ<`@>93L43bPk110[?`@B;d@453=80aDhC@@G?5846D1G11]5G0@NBV848dmX0baIL@@jIWd4
C7F;16:6V@AhUjP4SJRf1:>h``>jb]84cm[O1=kWj`CHgn84cmGH1<O:c0>o`<84]kJh1;2][PBZY:D4
Y9bL19jDT`BHS8/Eoooo000Doooo18YkNPB1LW44N6UY16mQH0AUF5P3G4i?1595APA8>cd4?S4c140d
=PA3=cX3ACXl14Ll?PA:?d84C4=514e5B0A<ADP4BD=80dM3B0A1?dD4>SU1138c?0@/;SP49RXd120U
<0<K8Bd45Qh[11<L:P@?6RT43ATY10`K:`<<7Bl43B4c10hT=`@?:3/442/o118_A0@D<dP35CQ=11Ll
DP@I@5L46dEL11i:HP@SCfP3;5Ua13YVO@A<MH/4HXJI17RGZ0B=Z;H4XkS30k[:dPC?f]l4g^O[1=SO
hPC?eMP4al[<0ko0`PBg][P4/:f^1:ZTY@BTW9`4WYBC19R<RaGoool001Coool4RW]j185bL@AhJFT4
Kf5P16EHF0=LCTl4DTE614Pk?@@n<C<4@3@f14<g>P=5>S`4Ac`n14Xo@PA<@dD4CDE814a5B0A9@dP3
Ad=8144oA@@j>D44<S<l12`^>0@V:S@482D`0a/Q;@@F7R/44a`Z10lJ:@@=6BT431/[0``M;`@=8C<4
3R@g10lX>`@@:cl44Rm411@cB0<E>4d45caB11U0E`@KAE`47TYR12=?J0</FG44>VIm14aeR`ARQYT4
N9NX18fX]PBS^<<3^/[B1<oJg`CNin/4f=oR1<oEf0C7b/`3_l321;Nf^0B`[Jh4ZZBU1:BLW0BNU9<4
V8b;5Oooo`005?ooo`B:NgX4PG9a17QYJ@A_HF04IEQH0ea>C`ABADH4B3/m13ha<`A0=3H4@cLj0dDj
?0A7?3h4BSm214a3A@A=ADP4C4E814U3B0=7@dP4@Cm513Xi@@@b<c`4;2hh12HZ=0@P9C036b4]11HN
:`@C72X43aXY10dI:@@<6b/331d_10dQ<`@>93L43bPk110[?`@B;d@453=80aDhC@@G?5846D1G11]5
G0@NBV848dmX0baIL@@jIWd4C7F;16:6V@AhUjP4SJRf1:>h``>jb]84cm[O1=kWj`CHgn84cmGH1<O:
c0>o`<84]kJh1;2][PBZY:D4Y9bL19jDT`BHS8/Eoooo000Doooo18YlNPB2Lg84NF][175SH`AXFe/3
H59C15M9B`A=@484@cHh14<h>PA6>cd3Ace014Po@PA:@D@4C4=714e6B@A<ATX4BDA90dA1A`@n?TD4
=SM012ha>P@W;3H482Hb11XR;`<E7R`44A/Z10dI:@@95bP41aLX10LI:`<872l42R0c10/T>0@=9c`4
3R]0110_A@@B=4T353Q>11HlD`@H@ET474IN125=I@@XEFd3=F5i14M`QPAKP9@4L96S18JQ/@BJ/[h4
/L?=0lWEf`CKhnL4iNc_1=_Ph`CAeMP4bL[=0l30`PBi][P4/Zf^1:^TY@BTW9`4WYBC19R<RaGoool0
01Coool4RWaj189cLPAiJf/4LF=S16QKF`=PDU<4EdU;14e0@PA3=SP4@cPj14Hk?@=7?D04B3m214Y1
A0A<@dL4CDI914a6BPA9A4T3A45713hnA@@f=d04;S4j12L/=P@P9S846R8_0aDN;0@A6bX43ATY10TG
:0@75bP41aT[0`PL;`@:83<42b@h10dW?0@>:d0442m5118dB@<D>4h45SaC11Q1F@@LAUh48DeU12QE
K@<eHGT4Ag2615^0U0A`TJ<4QZ6a19Zb_PBa`ld3bMGK1=_Si`CUk>l4fn3S1=7Ef0C9b/d3`<321;Vf
^0Bb[Jh4ZjBU1:BLW0BNU9<4V8b;5Oooo`005?ooo`B:O7X4PW=b17U[J`AaHf<4J5]K0f1BD`AGBD/4
CD1214<f>0A3>3X4AS/m0dLm@0A8?d84BT5414a3A`A=ATT4C4I:14U4B@=4@DL4?Si513Hg@0@^<CX4
9b`f120V<P@J8Rl35Ah/114K:P@=6BT42ALX10LG:0@76B/321`_10XP<`@;93P43BLl10h[@0@@;dD4
4SA90a@hCP@F?5<4645I11a6GP@QCFD4:5E]0cEQN@A7L8H4Fh2D172AX`B6XK44V[:n1;73c@?9eM/4
fn?W1>G/k`CKh><4dMGH1<W:c@?0`<84^KJh1;:][PB[Y:D4Y9bL19jDT`BHS8/Eoooo000Doooo18Yl
NPB2Lg84NF][175SH`AXFe/3H59C15M9B`A=@484@cHh14<h>PA6>cd3Ace014Po@PA:@D@4C4=714e6
B@A<ATX4BDA90dA1A`@n?TD4=SM012ha>P@W;3H482Hb11XR;`<E7R`44A/Z10dI:@@95bP41aLX10LI
:`<872l42R0c10/T>0@=9c`43R]0110_A@@B=4T353Q>11HlD`@H@ET474IN125=I@@XEFd3=F5i14M`
QPAKP9@4L96S18JQ/@BJ/[h4/L?=0lWEf`CKhnL4iNc_1=_Ph`CAeMP4bL[=0l30`PBi][P4/Zf^1:^T
Y@BTW9`4WYBC19R<RaGoool001Coool4Rgak18=eM0AkKF`4LfEU16]NGP=SEUL4Fdi?15=6B0A;?d44
B3e014Tn@@=:@4<4C4=614e4A`A>ATT4CdQ<14e7C0A9AT/3A49913dnAP@c=d04:c0k12@Z=P@K9384
5Al^0`lL:`@;6BT421LY10@E:0@15BP40QP[0`@L<0@783D42BDi10/X?@@<;4843c56114eC0<D>U44
5cmG11]5G@@PBV<49e=[139NMP=3K884EWb@16Z<WPB0WJd4UJfj1:^nb@C2cmL3en3U1>W`l`CZl?<4
gN7T1=?Ee`C:b/`3`L311;Zf]`Bb[Jh4ZjFU1:FLW0BOU9<4VHb:5Oooo`005?ooo`B;O7/4PgEd17]]
K0AcIFD4JeiN0f=FE`AKCTl4DdI814/o@@A8?D04BCi10dY0@`A<@dH4CDA714i6B@A?B4`4CDM<14U6
B`=4@TT4?Ci613<g@0@[<3/492Xf11/T<P@E7bh33a`[10/I:@@85bT411DX104E:0@262/311``10LP
=@@99CT42bPm10`/@P@?<DH44CE<0a@jD@@G?eL46dEM121:H`@WDf/4<Uif0d=/PPAFO904JXbN182M
[@BE[KX4Zkk91<;?e`?Gh>D4jO3c1>[`l`CMhN@4dmGG1<[:c0?1`<44^[Jg1;:][PB[YJD4YIbL19nD
T`BIS8XEoooo000Doooo18]lN`B3MG@4Nfe/17=UI@A[GUh3HeIG15]>C`ACATP4Bcm114Pm@0A9?T43
BT1314a3APA=A4L4CTI914m8C0A=Ad`4BDI;0dA2B@@m?TH4<cM012/`>`@T:SH46b@b11DO;P<?72/4
2aTY10PG:@@45BP40ADX108H:`<473041b0e10TU>@@;:3d432a210laAP@A=D`353YA11LoE`@KAEd4
84YS12MCJ`@bGWH3@fb215IlT0AZS9h4P9f]19F]^PB[_/T4`/oG0mOPi@CYl?<4j_3c1=gQi0CCeML4
b/[<0l70`@Bj][L4/Zf^1:^UY@BUW9`4WiBC19V<RQGoool001Coool4Rgak18=eM0AkKF`4LfEU16]N
GP=SEUL4Fdi?15=6B0A;?d44B3e014Tn@@=:@4<4C4=614e4A`A>ATT4CdQ<14e7C0A9AT/3A49913dn
AP@c=d04:c0k12@Z=P@K93845Al^0`lL:`@;6BT421LY10@E:0@15BP40QP[0`@L<0@783D42BDi10/X
?@@<;4843c56114eC0<D>U445cmG11]5G@@PBV<49e=[139NMP=3K884EWb@16Z<WPB0WJd4UJfj1:^n
b@C2cmL3en3U1>W`l`CZl?<4gN7T1=?Ee`C:b/`3`L311;Zf]`Bb[Jh4ZjFU1:FLW0BOU9<4VHb:5Ooo
o`005?ooo`B;OG/4Q7Ie17e_KPAfJ6P4KV5Q0fMJFPAPDe@4FDa>1596B0A;@484C4940de4A`A>ATT4
CTI:14m8C@AABTh4CdY?14a9C`=6AD`4@45913LjA0@^<cl48b`i11PT<`@@7bl331/[10PI:P@45bX4
01DY100G:`@16Rl311hc10HR>0@89S`42R]010`_A@@><TT44CM?0aHmE@@J@e/47dUR12MAJ@@bG7@4
@6Z00e9hS@AVR9/4NiRY192Y]`BV^/D4_<_C1=;Lh@?Tj^d4l?Gg1>S/kPCNh>84e=GF1<[:b`?2`<44
^[Jg1;>][@B/Y:@4YIbK19nDT`BIS8XEoooo000Doooo18]mN`B4MWD4OFm^17IXJ0A^HF43IeYJ161C
E0AIC4h4DTI814]0@PA<@T@3CDA714i6B@A>ATX4CdQ=155:CPA?BTl4C4U?0dI5C0A0@DT4=cY412hc
?`@S;3T462@c110O;`<<6b/421TZ10@G:P@05BT401L[104J;`<47S<41R8h10PV?0@::d0432m510hb
B@@A=dl35SeE11Y3F`@OBF849e5Y139LM0A0JX03DWR=16J8V`AkV:T4T:Vg1:Jja@Blbm<4d]cQ0nCZ
k@C`mOL4j>c^1=kPhPCDeMH4b/[;0l;0`@Bj][L4/jf]1:bTY0BUW9/4WiBC19V<RQGoool001Coool4
Rgek18AfM@AmKfh4MVQX16iQH@=WFUX4H5=D15U<CPABATP4Bd1214a2A0==A4L4CTI914i6BPA?B4d4
DDY>14m:C`A<BDl3ATE<1411B@@g>T@4;S<o12</>@@H93<441l_0``K:`@86BX411LZ100E:@@05b/4
0AX_0`@N<`@68SP422Hl10X[@0@<;dD43S99114gC`<F?ED46T=K11m9HP@WDFT4<Uad141ZP0=BN8d4
IXRK17^HZ@B@ZKL4Y[[51;c;d`CBg>43i>[]1?3em`CXk>h4g^3R1=CEePC:b//3`/311;Zf]`Bc[Jd4
[:BT1:FLV`BOU9<4VHb:5Oooo`005?ooo`B;OG/4Q7Ie17e_KPAfJ6P4KV5Q0fMJFPAPDe@4FDa>1596
B0A;@484C4940de4A`A>ATT4CTI:14m8C@AABTh4CdY?14a9C`=6AD`4@45913LjA0@^<cl48b`i11PT
<`@@7bl331/[10PI:P@45bX401DY100G:`@16Rl311hc10HR>0@89S`42R]010`_A@@><TT44CM?0aHm
E@@J@e/47dUR12MAJ@@bG7@4@6Z00e9hS@AVR9/4NiRY192Y]`BV^/D4_<_C1=;Lh@?Tj^d4l?Gg1>S/
kPCNh>84e=GF1<[:b`?2`<44^[Jg1;>][@B/Y:@4YIbK19nDT`BIS8XEoooo000Doooo18amO0B5MgH4
Og5`17QZJPAaI6@3JeiN16AGF@ANDE<4Eda>1515B0A@ATT3DTQ;159:C@ACBdh4Dda@15A>DPACCU<4
CdaB0dU8C`A3A4`4?3i8138h@`@V<3h472Ti11DT=0<@83842aha10LL<0@46c0411db10HP=@<793T4
2BLm10//@P@<;dH43S=:118hC`@F?ED36dAL125:HP@YDVT4<eac145YO`AAMhX3I8JH17VEYPB=Y[@4
XkO21;W8d@C?fMl4hNO[0o7dm`Cen?X4j>[/1=gNh0CCdm@4b/S90l:n_`Bj]KH4/jb/1:bTX`BUVi/4
Wi>B19V<RQGoool001Coool4S7el18EgMPAoLG04N6YZ175TI0=[GUh4I5MI15iAD`AGC4h4D4E81516
B@=BB4/4DTY=15=;CPACC504E4iB15=>D`A?C583BDQ?14=4C0@l?TP4<SQ312H`?P@L:CT45B@d0a0P
<P@;7S441a``10@K<0@47C841R0e0`LT>@@99cd42ba210`_AP@><dX44SQ?11HmE@<KA5`48DYR12UB
J@@cG7<4@FUo155gRP=TQYP4NIFV18fV]0BS]l84^LSA1<oIg`CQin/3lOCg1?GhnPCXj^`4gMkP1=?C
e0C:b<T3`[jo1;Ze]PBc[:`4[:BS1:FKV`BOTi84VHb:5Oooo`005?ooo`B<OG`4QGMf17maL0AhJVX4
LFAT0f]NGPATEeT4GU5C15M<CPA@ADP4D4I90e98B`ABBTd4Dd]>15=<D0ADCU84DdiC14m<DP=9B4l4
@dA<13`nB0@b>4<49S0n11`Y>@@E93@3420b10/N<@@7730411/`10@M<P@683D31b@i10TW?@@;;484
32m610hcBP@B>4l45SeE0a]4G0@QBV84:E9Y13=LL`A1JGl4DGN:0fB6V0AiUJH4SJJd1:>g`PBib=44
cmWO1>7Wj`?am?L4mOSj1>SZk0CMg^04dm?D1<[8b@?2_[l4^[Ff1;>/[0B/Y:<4YI^K19nCTPBIS8XE
oooo000Doooo18anO@B6N7L4P79b17Y]K0AdIfL3KV5R16ULG@ASEeP4GE9C15Q=C`ADBT`3ETa?15I>
D@AGCe<4F55E15YCE`AFDUL4DDiD0d]:D@A4ADh4?T1:13HkAP@/=D84930o11d/?0<I:S/44bLi110V
>@@=9CT43BLk10hY?@<>;44442m5118cB@@D=dd45c]B11]0E`@PAUd39TeT12iEJ`@gGW@4@fUn159f
R@ASQ9D3Mi>S18^S/@BP];l4]/G>1<gFg@CPi^T4ko?e0o_moPCdm_L4inSY1=cLg@CBdM44bLK70l6m
_@Bi];@4/Z^[1:^SXPBUViX4Wi>B19V;RQGoool001Coool4S7im18IhM`B0LW84NVe/17AWI`=^HF84
JEaM16=GF0AMDU<4F4e?15A:C0=FC4l4ETiA15M?D`AHDED4FU=G15IBE`AACU@3BdYA14A5CP@n@4X4
=S]612`e@P@T<3l47B`l0aTZ>`@C9cT442Hi10dU>@@=9c/43RTm0`h/@@@@;dD44S=911@gC@@G>e84
6d1G1216G@<VCF@4;UE[13MNM0A3JGh4DWJ916>4U@=gTj<4Rj>a1:2d_`BfaLh4cMKM1>3Vj@C_loD3
nogn1?Cfm`CWj>T4g=cM1=;Ad@C9a/L3`Kfm1;Vd]0BbZj/4Zj>R1:FKVPBOTi84VH^:5Oooo`005?oo
o`B<OWd4QWQg181bLPAjKF`4M6MW0fiQHPAYG5d4HeMH15eBD`AHCDl4E4Y<0eI<C`AFCU44EdmC15QA
E@AJDeL4EU9G155>E0=;BU44A4E>13i0BP@f>dH4;3E212@`?`@M;3`36BXk11<W>@@@9ST43BDi10dW
>`@>:Cd33Ra1110_A@@B<dT453M=11LkDP@K@5L484IM0bI=I0@^EF/4=eid14=YOPABMXT4HhBE0gNC
X`B;Xk44X;Bo1;K5cPC=e]d4h>KY1>ocm@?koOh4m?Kg1>OXj@CLg=d4d]7A1<W6a`?1_Kd4^KBd1;:[
Z`B[Xj84YI^J19nCTPBIRhXEoooo000Doooo18anO@B6N7L4P79b17Y]K0AdIfL3KV5R16ULG@ASEeP4
GE9C15Q=C`ADBT`3ETa?15I>D@AGCe<4F55E15YCE`AFDUL4DDiD0d]:D@A4ADh4?T1:13HkAP@/=D84
930o11d/?0<I:S/44bLi110V>@@=9CT43BLk10hY?@<>;44442m5118cB@@D=dd45c]B11]0E`@PAUd3
9TeT12iEJ`@gGW@4@fUn159fR@ASQ9D3Mi>S18^S/@BP];l4]/G>1<gFg@CPi^T4ko?e0o_moPCdm_L4
inSY1=cLg@CBdM44bLK70l6m_@Bi];@4/Z^[1:^SXPBUViX4Wi>B19V;RQGoool001Coool4SGmm18Mi
N0B2M7<4OFm_17MZJP=bIFD4KF1Q16QLG@ASEeT4Ge=E15Y@DP=JDE<4Fe9E15aDE`ALEET4G5IJ15QD
F@ADDEL3CTeD14U:DPA3AU04>d5=138lBP@/>DL4:3I50bDdA@@O<D<47C5311/`@`@J<D@46SA70a`g
B`@O>dl48T1D12A4F0@VAed4:deR135CJ0<iFg04@F=g14]]P0AGN8T4IhFE17VCXP><XZl4Wk6l1;C2
bPC:dmT4gnCW1>kal`Cmool3o?gm1>o_l0CThn@4f]SH1=3>cPC8a<@3`;^k1;Rb/PBaZZT4Zj:Q1:FJ
V@BNTY44V8^:5Oooo`005?ooo`B=Ogd4QgUh189dL`AmKfl4MfYZ0g9UI@A]H644J5aM16=GF@AODeD4
FU1B0eYAD`AKDUD4G5AG15aEF@ALEUX4F5AI15AAE`=>CE@4BDYB14=6D0@k@Dd4<Sa:12`iA`@X=TD3
9CA511la@`@M<D<46c1311XaA0@J=4L373M;11lkC`@R@5@494AH12I7G@@[CF84<E=X0cUKL0A1HgL4
Bff015MhR@AWQID4NI>R0hbR[`BO/K`4]<;:1<[Cf@COi>L4k_7c1?goo`?loOd4kno`1>CSi0CJf=P4
d<k>1<S4a0?0^k/4^;:b1;6ZZ@B[XZ44YIZI19jBT@BHRhXEoooo000Doooo18eoO@B7NGP4PWAc17e_
K`AgJVX3LVEU16ePH@AXG5d4HeMI15mCE@AJD583FU5C15]BE@ALE5L4G5EI15aFFPAHE5T4E55G0di=
E0A9BU84@dI@13]1C@@b?4X4;3U712PfA@<U=4D47c5311da@`@K<4<46S5411XdA`<L=d/47c]?1290
E0@TA5P49TMM12]=HP@aDfP3>E]`145SM`A;KH04EgR916N5U@AiTj83S::_19na_0Bd`/X4b]?I1=oT
i`C^lO<4oOoo0ocmo@C_ko04i>?T1=[Hf0C@c/h4b<C40l2k^`Bh/[84/JZY1:^RX@BUVYT4WY:A19R;
RQGoool001Coool4SGmm18MiN0B2M7<4OFm_17MZJP=bIFD4KF1Q16QLG@ASEeT4Ge=E15Y@DP=JDE<4
Fe9E15aDE`ALEET4G5IJ15QDF@ADDEL3CTeD14U:DPA3AU04>d5=138lBP@/>DL4:3I50bDdA@@O<D<4
7C5311/`@`@J<D@46SA70a`gB`@O>dl48T1D12A4F0@VAed4:deR135CJ0<iFg04@F=g14]]P0AGN8T4
IhFE17VCXP><XZl4Wk6l1;C2bPC:dmT4gnCW1>kal`Cmool3o?gm1>o_l0CThn@4f]SH1=3>cPC8a<@3
`;^k1;Rb/PBaZZT4Zj:Q1:FJV@BNTY44V8^:5Oooo`005?ooo`B>Ogh4RGYi18AfM@AoLG44NVe]0gEX
J@AaI6D4KF1Q16QMGPATFE/4H5EH0eiDEPAPEeX4HEUL161IG@AOFEd4GEQM15YGG@=DDeT4CdmG14U;
E0A0AU84>dA@13M1C`@b?dh3;ce=12/kC0@Z?4`4:Ca=12PnC`@Y@E83;4AF1318FP@cCEl4=E5S13UE
J0@nFfh4AF9d0deZN`ADLH84Gg^;16b6U@AlTj44SJ6]0in`^PBc`<L4b=3E1=gQi0C^ko44oOkn1?oo
o`?dlo@4j^WY1>3NgPCFdm@4c/[:1<K1`@>n^;P4]k2_1;2XY`BZX:04Y9VH19jBT@BHRhTEoooo000D
oooo18ioOPB9NWT4Q7Ie17maL@AjKFd3MFQY175TI@A]H644J5eN16AIF`APEEP3GUAF161GFPAQFE`4
H5UM15mIG@AMF5d4FUMM0eACF@A?CeL4BD]D1416DP@kA504=d5?138oCP<_?Dd4:c]<12XlC0@Y?4d4
:3i?12U1DP</A5H4<4QJ13==G`@eDF<4>EEX13iKKPA5HW@3CFYk15AaPPAONh/4K8JE17bCX@B=XJd3
Wk2j1;?0a`C8d=D4gN7T1>k_l@Cmo_h4oooo0oCcm0CZjNT4h=kN1=KCe0C>b/X4a/710kjh^0Bg/:l4
/:RW1:ZPX0BTVIP4WY:A19R;RAGoool001Coool4SWmn18UjN@B4MWD4Og5a17Y]K@=eJ6T4LFAU16eP
H@AXGEh4I5UK161EF0=NE5H4H5MJ165IG0APFEd4GeUM15eHG@AJEed3E5=I14m?E`A9Be@4@4IB13]4
D0@g@Dl4<Sm>0blmC@@[>d`4:Sa<12TlC@@X?Tl4:D5B0ba4EP@`B5X4<deO13EAH`@iEFP4?U]^14ER
M0==JW/4E76215mkR`A/QYD4O9>Q18fQ[@>O/;X4/l371<S@e@CMhN@4k^oa1?gnoPCoool3m??d1>[Y
j@CPg]h4e]?D1<k:bPC6`L43_[Rh1;N`[`B`Z:L4ZZ2P1:BIV0BNTY44V8^95Oooo`005?ooo`B>Ogh4
RGYi18AfM@AoLG44NVe]0gEXJ@AaI6D4KF1Q16QMGPATFE/4H5EH0eiDEPAPEeX4HEUL161IG@AOFEd4
GEQM15YGG@=DDeT4CdmG14U;E0A0AU84>dA@13M1C`@b?dh3;ce=12/kC0@Z?4`4:Ca=12PnC`@Y@E83
;4AF1318FP@cCEl4=E5S13UEJ0@nFfh4AF9d0deZN`ADLH84Gg^;16b6U@AlTj44SJ6]0in`^PBc`<L4
b=3E1=gQi0C^ko44oOkn1?ooo`?dlo@4j^WY1>3NgPCFdm@4c/[:1<K1`@>n^;P4]k2_1;2XY`BZX:04
Y9VH19jBT@BHRhTEoooo000Doooo18j0OPB:NgX4QGMg185cL`AmKfl3NFa/17EXJ@AaIFH4KV9S16YO
H@AXGEh3I5YL16IMH0AWGV44IUmR16EOH`ASGV<4GeaQ0eYHGPAEEE`4D59K14U?F@A6CET4@T]G13i9
EP<lB5D4>DMF13Q7EP@gB5P4>D]J13]>GP<nDF44@UIV14EJJPA9Gfl4CVAd15A[NPAKLX43HWR716V0
SPAdRIL4PIFQ192Q[0BQ[kP3];k51<O=dPCHg=l4j^[/1?_kn`Coool4m_Ge0ng[j`CThN44fmSH1=;>
cPC:aLD4`kfm0kbe]@Be[Jd4[jJU1:VOWPBSV9L4WI6@19R:RAGoool001Coool4SX1n18YkNPB5MgL4
PG=c17e_K`=iK6`4MFQY175UIPA^HV<4JUmQ16QMGP=TFU`4IUeP16MNH@AVGf84IEmS16=NH`AOG643
FUQN15EEG0A@DU/4BDmI14I=F@A2BeL4?TUF0ca8E@@iAeH4>4MF13M8F0@iBeX4>diN0ciAH@A2EVH4
AEYZ14UOK`A>I7@4E6]j15]bP@=RN8L4JH2>17B9U`B1UJ44T:6/1:6_^0>d_/D4algB1=SLg`CZj^`4
no_k1?ooo`CfmOD3kN_[1>CQh@CKf=P4d/k>1<[5a@C3_Kd3_;Fe1;F][@B_YZD4ZInN1:>HU`BMTI04
V8Z95Oooo`005?ooo`B>P7h4RW]j18EgM`B1Lg<4OFm_0gU/K0AeJ6T4LFEV16iRH`AZGf44J5eN0fAJ
G0AVGF04IeiQ16IOHPAUGf<4HeiS15mLH@=JF5h4EEEL151BF`A9CeT4ATeI149;E`@nBEH3?4QE13U7
EP@hAeH4=dQH13U;FP@kCUh3?U5Q149FIPA5FVX4BEm_14iTM0ADJgX4Fg:10f9hQ`AYP8h4M8VG186E
X@B@XJ`4XJnh0kBna@C7cM84f=cO1>[Zk0Ckno/4oooo1?Kem@?]jn/4i>7Q1=_Hf0CBc/h4b/G51<>m
_@>l]KD4]Jf]1:nVY@BYWih4XiRG19fAT0BHRXTEoooo000Doooo18j0OPB:NgX4QGMg185cL`AmKfl3
NFa/17EXJ@AaIFH4KV9S16YOH@AXGEh3I5YL16IMH0AWGV44IUmR16EOH`ASGV<4GeaQ0eYHGPAEEE`4
D59K14U?F@A6CET4@T]G13i9EP<lB5D4>DMF13Q7EP@gB5P4>D]J13]>GP<nDF44@UIV14EJJPA9Gfl4
CVAd15A[NPAKLX43HWR716V0SPAdRIL4PIFQ192Q[0BQ[kP3];k51<O=dPCHg=l4j^[/1?_kn`Coool4
m_Ge0ng[j`CThN44fmSH1=;>cPC:aLD4`kfm0kbe]@Be[Jd4[jJU1:VOWPBSV9L4WI6@19R:RAGoool0
01Coool4Sh1o18]lN`B7NGP4PgEe17mbLP=lKfl4NFa/17EYJPAcIfP4L6EV1fiTI@A^IFH4KFEW26aU
J0AZI6P4J6=X0f=PIPAOGF@4Fe]S15EIHPABEf44CUEP14aDG`=:Del4B5AP14QEH@A9EV<4BeQV14eK
J@=@Gf`4EF=a15UXM@AOKW/4Hg>016YjQPA`P8`3MXJB17j>V0B9V:44V:>/1:N`]`Bg_L<3al_?1=SI
f`CYinP4n?Gd1?ono@CgmOD4k^c/0nKSh`CNf]X4e]7A1<k9b@C7`L04`;Vh0kVa/@BcZZX4[J>S1:NM
W0BRUYD4WI2?19R:R1Goool001Coool4Sh1o18]lN`B7NGP4PgEe17mbLP=lKfl4NFa/17EYJPAcIfP4
L6EV1fiTI@A^IFH4KFEW26aUJ0AZI6P4J6=X0f=PIPAOGF@4Fe]S15EIHPABEf44CUEP14aDG`=:Del4
B5AP14QEH@A9EV<4BeQV14eKJ@=@Gf`4EF=a15UXM@AOKW/4Hg>016YjQPA`P8`3MXJB17j>V0B9V:44
V:>/1:N`]`Bg_L<3al_?1=SIf`CYinP4n?Gd1?ono@CgmOD4k^c/0nKSh`CNf]X4e]7A1<k9b@C7`L04
`;Vh0kVa/@BcZZX4[J>S1:NMW0BRUYD4WI2?19R:R1Goool001Coool4Sh1o18]lN`B7NGP4PgEe17mb
LP=lKfl4NFa/17EYJPAcIfP4L6EV1fiTI@A^IFH4KFEW26aUJ0AZI6P4J6=X0f=PIPAOGF@4Fe]S15EI
HPABEf44CUEP14aDG`=:Del4B5AP14QEH@A9EV<4BeQV14eKJ@=@Gf`4EF=a15UXM@AOKW/4Hg>016Yj
QPA`P8`3MXJB17j>V0B9V:44V:>/1:N`]`Bg_L<3al_?1=SIf`CYinP4n?Gd1?ono@CgmOD4k^c/0nKS
h`CNf]X4e]7A1<k9b@C7`L04`;Vh0kVa/@BcZZX4[J>S1:NMW0BRUYD4WI2?19R:R1Goool001Coool4
Sh5o18amO0B8NWT4QGMg189dM0=oLW84O6m_17U]K@AgJf`4MFY[17AYJP=dJF/4M6]/17E[K@AdK6h4
Lf]^179[KPA`JVh3KFQ]16UWK0AVIV`4HV=[161RJ`ANHFX4G65Z0eYQJ`AKHV`4Ff9]15]SKPAMIG04
GfQc0f9/M`AWL7/4K7J0175kQPAgPXd4P8VB18B=UP>9TY/4Ti^S19nV[0B[/KH4^Kc11<S9c0?Ge]L4
iN;S1?;_k`Cln_X4nOSh1>o]k0CWhn<3gm_J1=OCdPC@blX4bL?21<:l^`Bl];@3]Zj]1;2WYPB[XJ04
YY^J1:6EU0BLShh4UhV85Oooo`005?ooo`B?PGl4S7el18QjN@B5MgL4PWAd0gmbLPAlKfl4NFe]17M[
K0AeJV/4M6UZ0gAYJ`AdJf`4MF]]17A/KPAcJfh4LV]^171ZKP=]J6d4JFM/16IVK0ARHf/4H69[15iQ
JPALHFX3FV5[15]RK0AKHVd4Ff=^15eUL0AOJ7<3HVag16M`N`A/MX04LG^617N2S@B0RI84Q8fF0hVB
V`BCVj<4WjJ/1:^a]PBi_<44b<W<0mOFe`CUh^<4l^o_1?cjnPCin?P4kng/1>OSh`?OfmX4em?B1=3;
bPC9`l84`[bk1;bd]0>f[Zd4/:NV1:^QX0BVViX4XIFD19b?SPBGRHPEoooo000Doooo18n1O`B<OG`4
R7Yi18EgM`B2M7@3Og9b17a_K`AiKFd4Mf]/17EZJ`AdJFX3M6U[17A[K0AeJfd4M6a^17=[KPAbJfh4
L6Y^0feXK@AYIf`4IVI/169SJ`APHV/4GV5Z15aQJP=JHF/4Ff9/15]RK@AKHfh4GFE`15mXL`=RK7L4
Ig1k16afP0AaNhH4Mh:=1829TPB4SIH3RI:K19>KX`BOYZ`4Zk6f1;Vl`@C8bL`3emKG1>GRh`Cbknl4
o?[j1?Whn0C_kN`4in?S0moKfPCGdm84d<_:1<W3`PC2_;/4_;Bd0kJ^[@B`YjH4Zj6P1:JKVPBQUI@4
W8n>19N9R1Goool001Coool4Sh5o18amO0B8NWT4QGMg189dM0=oLW84O6m_17U]K@AgJf`4MFY[17AY
JP=dJF/4M6]/17E[K@AdK6h4Lf]^179[KPA`JVh3KFQ]16UWK0AVIV`4HV=[161RJ`ANHFX4G65Z0eYQ
J`AKHV`4Ff9]15]SKPAMIG04GfQc0f9/M`AWL7/4K7J0175kQPAgPXd4P8VB18B=UP>9TY/4Ti^S19nV
[0B[/KH4^Kc11<S9c0?Ge]L4iN;S1?;_k`Cln_X4nOSh1>o]k0CWhn<3gm_J1=OCdPC@blX4bL?21<:l
^`Bl];@3]Zj]1;2WYPB[XJ04YY^J1:6EU0BLShh4UhV85Oooo`005?ooo`B@PH04SGim18YlN`B7NGP4
Q7Mf0h9dM0AoLW84OG5a17]_L0AjKVl7NFi_17U_L0AkLG88Ng9d17UaM0AgLG@3MW5e17A`M@AcKg@4
Kfid16i^M0A]KWD4Jfee0f]^MPQ[KWL4K71i16icN`AaMGh3M7V117QmQ@AmPHT4PhR?18V=U0B>TIL4
TiNL0iZNX`BUYj`4[[2d1;Vj_@C7a/P4eM;C0n;NgPC^jNT4nOGe1?Sem@C^jn/4i^?R1=kJfP?Gd]84
d<_:1<[4``C4_K`4_[Je1;R`[`>cZZT4[ZBS1:VNW@BTVIL4X9>B19^>S@BGRHLEoooo000Doooo1921
P0B=OWd4RWak18MiN0B4MgH3PWAd17mbLPAmLG44Nfm`17Y^K`MiKVl4NFm`17]aLPQkLW@4NG5d17Ma
M0=fLGD4M71e17=_M0A_KW@4KVid16e^M@A[KGD3Jfif26]^M`A/L7T4KW=k175eOP=dNH44N7f517f1
R@B3R8l4RHfD18jAU`BCUi`3VYjS1:FW[0B^/;@4^KZm1<O6b0CEd]<3h]kN1>kYj@CimOD4n?Ge1>k[
j`CVhn84g][J0mOBdPC@blX4b/C31<Bm_0Bn][D4^;2_0k>ZZ@B^Y:<4ZIjM1:BIU`BPTi84Vhj=19N9
QaGoool001Coool4T86018enO@B:O7/4QgUh18AgMP>2M7@4Og9b17eaL@AkKg04NVi_1gU^K`AiKg04
Ng5b27]bM0AiLG@4Mg5d0gIaM@AdL7D4Lfmd16m^M0A^KW@4KFie16]]M@=[KWH8Jfig16a`N@A^Lg/4
LGEn0gAiP@AhOHD4OH6918>8S`B9SI@4SY6G19>GW0>JWZ<4YJN/1:j`]0Bi^[d4alK81=GBd`?Rg]h4
k^WY1?Wem@ChmOD4k^_[1>KShPCNf]X3em;B1=3;bPC:a<<4a;fl1;jf]@Bh/:l3/jZY1:jTX`BYWYd4
Y9VG1:2CTPBKSXd4UhV75Oooo`005?ooo`B@PH04SGim18YlN`B7NGP4Q7Mf0h9dM0AoLW84OG5a17]_
L0AjKVl7NFi_17U_L0AkLG88Ng9d17UaM0AgLG@3MW5e17A`M@AcKg@4Kfid16i^M0A]KWD4Jfee0f]^
MPQ[KWL4K71i16icN`AaMGh3M7V117QmQ@AmPHT4PhR?18V=U0B>TIL4TiNL0iZNX`BUYj`4[[2d1;Vj
_@C7a/P4eM;C0n;NgPC^jNT4nOGe1?Sem@C^jn/4i^?R1=kJfP?Gd]84d<_:1<[4``C4_K`4_[Je1;R`
[`>cZZT4[ZBS1:VNW@BTVIL4X9>B19^>S@BGRHLEoooo000Doooo1921P0B=Ogh4Rgel18UkNPB6NGP3
Q7Mf189eM@B1M7@4Og=c27ibLP=mLW<4OW=d17mdMPB0MWL4P7Mi185hNPB1NG`3P7Ul17ihO@AmNGd4
NgQm17aiOPAmNX04OG^00gekP@AlNh44O7^217emQ0AoOhD4PH680hF5R`B8R8h4SHfA196@U@BEU9P4
VYVL19^KW`>RXjH4[:b^1;Je]`C3`<84d/g=1=kHf0?[i><4lng]1?C`k`C[j>L4i>3O1=gHe`CFd=03
d<W91<W3`PC4_;`4_[Je1;V`/0BdZjX3[jFT1:^PW`BVViX4XYJE19jBT0BJSH/4UXR75Oooo`005?oo
o`B@PH04SGmn18]mO0B9NgX4QWUh0hAgMPB2MGD4PGAd17mcL`QnLW83OG9c17icM0AoM7H4P7Ig181g
N@B1N7X4PGUl0h1iO0AnN7d4OGUm17]hO@AlNGh4OGZ017ekP0=mNh44O7^117akPPAmOH@4Ogn51861
R0>5QH/4R8R>18f=T@BAT9D4UIBH19ZIW0BKVil3XZ>V1:b/[PBf]KL4`l321=;=c@CNf=P3jnCS1??]
k@Cdl>l4jnSW1>CPg`CMf=L4e]3@0m39b@C9`l84a;bl1;jf]@Bi/;04]:^Z0jnUY0B[X9l4YY^J1::F
U@BNTY04VXf;19J8QaGoool001Coool4T86018eoOPB;OG`4RG]j18IiN0>4MgH4PWEe185dM0AoLg<8
OW9b0gebL`AnLg@4OgAf181fM`B0MgT4PGQj185iO0>0NG`4OWQm17eiO@AkN7d4O7Un17ejP0AmNh03
OG^117akP@AlNh84OGf417moQ@B1PHP3QHF;18R8SPB=SI44TI2E19FDV0BJVI`4Vi^O0j:SYPB/[:h4
][Fg1<?0`PCBcLd4g]SH0n_Th`CckNd4m?3_1>_Xi`CTh=l4gMSG1=K@d0?@bLT4bL?21<Bl_0Bn][D4
^K2`1;B[ZP>_YJ@4Zj2O1:JKVPBRUYD4WY:@19Z=R`BFR8LEoooo000Doooo1921P0B=Ogh4Rgel18Uk
NPB6NGP3Q7Mf189eM@B1M7@4Og=c27ibLP=mLW<4OW=d17mdMPB0MWL4P7Mi185hNPB1NG`3P7Ul17ih
O@AmNGd4NgQm17aiOPAmNX04OG^00gekP@AlNh44O7^217emQ0AoOhD4PH680hF5R`B8R8h4SHfA196@
U@BEU9P4VYVL19^KW`>RXjH4[:b^1;Je]`C3`<84d/g=1=kHf0?[i><4lng]1?C`k`C[j>L4i>3O1=gH
e`CFd=03d<W91<W3`PC4_;`4_[Je1;V`/0BdZjX3[jFT1:^PW`BVViX4XYJE19jBT0BJSH/4UXR75Ooo
o`005?ooo`B@PX04SX1o18anO@B:O7/4R7]j0hMiN0B5N7L4Q7Mf18=fMPB2MGD4PGEf0h5fMPB2MgL4
PgQi18AjN`B6O7d4Qgn018MoP@>8P8<4R86418R1Q@B7PHH4R8>718V4R0B9Q8T3RhJ:28^7S0B<R8d4
ShZ?196=T@>DT9<4Ui:E19^FV@BMV9/4XijO1:FPXPBYY:H3/Zb]1;Ze]@C5_[h4dLW81=[CdPCVgM`3
k^SW1>gXj0CWh^44gm[I1=WCdPCCc<`4cLK50lO0_`C2^[T4_KFd1;R_[`BdZZT4/:JU0jbQX0BXW9/4
Y9RG1:2DT`BMT8h4VHb:19J8QQGoool001Coool4T8:018j0O`B<OWd4RWak18QkNP>7NGP4QGQg18Ag
MPB3MWH4PWEe185eMP>1MWH4PWMg18=hN@B4NW/4QWam18MoP0B7Oh43R82318R1Q0B8PHD4Qh6618R3
Q`B9Q8P4RHB90h^6RPR;Qh`4S8R=18n:S`BASI43U92C19NBU@BKUYT4WIRK1:>NW`BUX:84ZJBV0k:/
[@Bj]KD4aKjn1=79b0CJdm84i]gL0nkXi`C]j>P4in;Q1=oJf@CIdm84dlc<1<g6a@?7`;l4`[Zi1;fe
]0Bh[jl4]:ZY1;2VY@>/XJ04Z9bK1:BHU`BPU9<4WI2>19V<RPBFR8HEoooo000Doooo1922P0B>P7l4
S7im18YlN`B8NgX3QgUh18EhM`B4MgH4PgIf189eM@B1MGH3PGIf189gM`B3N7T4Q7Yk18IlO@B7Oh04
Qgn10hR0P`B8PH@4R86518N1QPB8PhL4RHB818V4R@>;QXX8RhN<18b8S@B?RXl4THfA0iB@T`BGTYD4
ViJI19fHV`BSWYl4YJ2R1:VTYP>b[:d4^[Fe1<Fn_PCAbLP4f]?B1>KMg0?^j>L4kNSX1>ORh@COf]T4
fM?B1=?<c0C=a/D3al2o1<:j^@Bm]K@4^:n_1;BZZ@B`YZD3[:6P1:RLV`BTV9L4X9BC19f@SPBIS8X4
UXR65Oooo`005?ooo`B@PX04SX1o18anO@B:O7/4R7]j0hMiN0B5N7L4Q7Mf18=fMPB2MGD4PGEf0h5f
MPB2MgL4PgQi18AjN`B6O7d4Qgn018MoP@>8P8<4R86418R1Q@B7PHH4R8>718V4R0B9Q8T3RhJ:28^7
S0B<R8d4ShZ?196=T@>DT9<4Ui:E19^FV@BMV9/4XijO1:FPXPBYY:H3/Zb]1;Ze]@C5_[h4dLW81=[C
dPCVgM`3k^SW1>gXj0CWh^44gm[I1=WCdPCCc<`4cLK50lO0_`C2^[T4_KFd1;R_[`BdZZT4/:JU0jbQ
X0BXW9/4Y9RG1:2DT`BMT8h4VHb:19J8QQGoool001Coool4TH:118n1O`B=Ogh4S7im18YlN`>9NgX4
R7Yi18MiN@B6NGP8QGQh0hEiN@B5NWX4QW]k18QmO@B9Oh04SH>419:8RP>AR8X4T8N:18n7RPB@RHd4
Thb?19N?TPBHT9<3UhnC19J@T`BJTYD8WIBF19fDU`>OUYP4XIVJ1:BKV`BUWId4Zj:R1:fTY0BcZZT3
^K6`1<6i^0C;`/44eL_91=_Bd@CVg]d3iMoN1=kHe`CId]44dlc;1<k6a@C9`L04a;^j0knf]@Bk/[04
]Zf/1;:YY`B_Y:<4Zj2O0jRLV`BTVIL4XIFD19jAT0BKSX`4V8Z919F7QAGoool001Coool4TH:118n1
O`B=Ogh4S7im18YlN`>9NgX4R7Yi18MiN@B6NGP8QGQh0hEiN@B5NWX4QW]k18QmO@B9Oh04SH>419:8
RP>AR8X4T8N:18n7RPB@RHd4Thb?19N?TPBHT9<3UhnC19J@T`BJTYD8WIBF19fDU`>OUYP4XIVJ1:BK
V`BUWId4Zj:R1:fTY0BcZZT3^K6`1<6i^0C;`/44eL_91=_Bd@CVg]d3iMoN1=kHe`CId]44dlc;1<k6
a@C9`L04a;^j0knf]@Bk/[04]Zf/1;:YY`B_Y:<4Zj2O0jRLV`BTVIL4XIFD19jAT0BKSX`4V8Z919F7
QAGoool001Coool4TH:118n1O`B=Ogh4S7im18YlN`>9NgX4R7Yi18MiN@B6NGP8QGQh0hEiN@B5NWX4
QW]k18QmO@B9Oh04SH>419:8RP>AR8X4T8N:18n7RPB@RHd4Thb?19N?TPBHT9<3UhnC19J@T`BJTYD8
WIBF19fDU`>OUYP4XIVJ1:BKV`BUWId4Zj:R1:fTY0BcZZT3^K6`1<6i^0C;`/44eL_91=_Bd@CVg]d3
iMoN1=kHe`CId]44dlc;1<k6a@C9`L04a;^j0knf]@Bk/[04]Zf/1;:YY`B_Y:<4Zj2O0jRLV`BTVIL4
XIFD19jAT0BKSX`4V8Z919F7QAGoool001Coool4TH:118n1O`B=Ogh4S7im18YlN`>9NgX4R7Yi18Mi
N@B6NGP8QGQh0hEiN@B5NWX4QW]k18QmO@B9Oh04SH>419:8RP>AR8X4T8N:18n7RPB@RHd4Thb?19N?
TPBHT9<3UhnC19J@T`BJTYD8WIBF19fDU`>OUYP4XIVJ1:BKV`BUWId4Zj:R1:fTY0BcZZT3^K6`1<6i
^0C;`/44eL_91=_Bd@CVg]d3iMoN1=kHe`CId]44dlc;1<k6a@C9`L04a;^j0knf]@Bk/[04]Zf/1;:Y
Y`B_Y:<4Zj2O0jRLV`BTVIL4XIFD19jAT0BKSX`4V8Z919F7QAGoool001Coool4TH:11921P0B>P7l4
SGmn18anO@>;OG`4RWak18UlN`B9Ng/8R7]k0hQlN`B9O7`4RGem18]oO`B<PH84ShB519:8R@>FS8d4
Uhf?19V?T@BJTI<4W9:D19fDUPBNU9H3WiFG1:6GV0BRUiP4XIJF1:2EUPBSV9P3Y9VH1:FJV@BWW9X4
Zj2O1:jSXPBbYjD4]jf[0kjd/PC5_;/4c<;11=;:b@CId]44g=GC0mG=c0C@b<L4bl?21<Jn_@C2^KP4
_[Fd1;Za[`>f[J/4/jVW1:nUY0B/XJ04ZIjM1:JKV@>TV9H4XIFC19jBT0BLShd4VHb:19N9R0BEQXDE
oooo000Doooo1962P@B@PH04SX1o18eoOPB<OWd3Rgel18YlN`B9O7/4RG]k28QkN`>8O7/4RGal18Um
O@B;Ogl4S86218n4Q@BBR8T3UXb=19N=S`BISi44VY6C19bBU0BMU9H4WYBF0inEU`BQUiP4XYNH1:6F
UPBPUIH4XiRH0jBIV0BUVYT4YibJ1:^PW`B^Xj84/ZNU1;N]Z`>n];84aKbk1<c2`@CBb/T4fM;A1=cE
d`?EcL`4d<S71<_3`PC6_[d4`[Vh1;je]0Bj/Jl3]Zf[1;>YY`B_YJ@4[:6P1:VNW@BVViT3Y9RF1:6E
T`BNTY04W8n=19V<RPBGRHP4UHJ55Oooo`005?ooo`BAPX44T86018j0O`B=Ogh4S7im0h]mO0B:O7/4
RGak18UkN`R8Ng/3R7ak18UlO0B9OGd4Rgmo18b1PPB?Q8D4TXR90iJ<S@BGSHl4VHnA19ZAT`BLTY@4
WIBF19jDUP>OUIL4XINH1::GV0BQUYH4X9FF1:>HV0>TVIP4YIZI1:NLVPB[X9l4[Z>R1;:WY@Bg[J/3
_[Bb1<Fl^`C<`/44d/[91=WBd@CLeM<3eLg<1=38a`C;`l84a[jm1<:i^0Bn]K@4^[6_0kJ]Z`BcZJL4
[jFT1:bQX0BYWYd4YY^I0jBHUPBQUI<4WY:@19b?S@BIS8X4UhV819F6QAGoool001Coool4TH>11922
P0B@PH04Sh1o18j0OP>=Ogh8S7im3h]nO@B;OWh4S7mo18f1P0B>PX84T8F519>7Q`>FRX/4VXn?1:6F
UPBSV9T4XYJG1::GU`BTVIX3YIRI1:BHV0RSUiL4Y9RH1:JJV@>WViX4ZYjL1:bOW@B^XZ04/JBR1;BX
YPBg[Z`3_;:a1<Bk^PC:`L04cLG41<g5``C8_kh3a;^j1<6g]PBm/k84^[2^1;J/Z`BcZJL4/:JT0jjS
X@B[X9h4Z9fK1:JJV@BTV9H4XIFD0inCT@BMT8l4Vhj=19Z<RPBHRXP4UXR619B6Q1Goool001Coool4
TH>11922P0B@PH04Sh1o18j0OP>=Ogh8S7im3h]nO@B;OWh4S7mo18f1P0B>PX84T8F519>7Q`>FRX/4
VXn?1:6FUPBSV9T4XYJG1::GU`BTVIX3YIRI1:BHV0RSUiL4Y9RH1:JJV@>WViX4ZYjL1:bOW@B^XZ04
/JBR1;BXYPBg[Z`3_;:a1<Bk^PC:`L04cLG41<g5``C8_kh3a;^j1<6g]PBm/k84^[2^1;J/Z`BcZJL4
/:JT0jjSX@B[X9h4Z9fK1:JJV@BTV9H4XIFD0inCT@BMT8l4Vhj=19Z<RPBHRXP4UXR619B6Q1Goool0
01Coool4TH>11922P0B@PH04Sh1o18j0OP>=Ogh8S7im3h]nO@B;OWh4S7mo18f1P0B>PX84T8F519>7
Q`>FRX/4VXn?1:6FUPBSV9T4XYJG1::GU`BTVIX3YIRI1:BHV0RSUiL4Y9RH1:JJV@>WViX4ZYjL1:bO
W@B^XZ04/JBR1;BXYPBg[Z`3_;:a1<Bk^PC:`L04cLG41<g5``C8_kh3a;^j1<6g]PBm/k84^[2^1;J/
Z`BcZJL4/:JT0jjSX@B[X9h4Z9fK1:JJV@BTV9H4XIFD0inCT@BMT8l4Vhj=19Z<RPBHRXP4UXR619B6
Q1Goool001Coool4TH>11922P0B@PH04Sh1o18j0OP>=Ogh8S7im3h]nO@B;OWh4S7mo18f1P0B>PX84
T8F519>7Q`>FRX/4VXn?1:6FUPBSV9T4XYJG1::GU`BTVIX3YIRI1:BHV0RSUiL4Y9RH1:JJV@>WViX4
ZYjL1:bOW@B^XZ04/JBR1;BXYPBg[Z`3_;:a1<Bk^PC:`L04cLG41<g5``C8_kh3a;^j1<6g]PBm/k84
^[2^1;J/Z`BcZJL4/:JT0jjSX@B[X9h4Z9fK1:JJV@BTV9H4XIFD0inCT@BMT8l4Vhj=19Z<RPBHRXP4
UXR619B6Q1Goool001Coool4TXB21963P@BAPX44T8:018n1P0>?PGlGSX1o18j0P0B>PH04Sh:11923
PPBAQH@4ThJ60iF9R0BHS8/4Vhn>19jAT@BQU9<4YIVG1:FIV0>TUiH4YIRG1:BGV0BRUYH4XiNF1:>G
U@>TV9H4YiZH1:RKV@BZWI/4ZinM1:jRX0BfZjX3^[2^1;fc/@Bk/Jl4^Jn^1;R^[0BfZjX3]:VW1;6V
Y@B_Y:84[J6P1:ZOW@BXWI/4YYZI0jFHU`BSUYD4XIFC1:2CT@BNTI04WHn>0i^>S0BJS8/4V8^919N9
R0BFR8H4UHJ519B5PaGoool001Coool4TXB21963P@BAPX44T8:018n1P0>?PGlGSX1o18j0P0B>PH04
Sh:11923PPBAQH@4ThJ60iF9R0BHS8/4Vhn>19jAT@BQU9<4YIVG1:FIV0>TUiH4YIRG1:BGV0BRUYH4
XiNF1:>GU@>TV9H4YiZH1:RKV@BZWI/4ZinM1:jRX0BfZjX3^[2^1;fc/@Bk/Jl4^Jn^1;R^[0BfZjX3
]:VW1;6VY@B_Y:84[J6P1:ZOW@BXWI/4YYZI0jFHU`BSUYD4XIFC1:2CT@BNTI04WHn>0i^>S0BJS8/4
V8^919N9R0BFR8H4UHJ519B5PaGoool001Coool4TXB21963P@BAPX44T8:018n1P0>?PGlGSX1o18j0
P0B>PH04Sh:11923PPBAQH@4ThJ60iF9R0BHS8/4Vhn>19jAT@BQU9<4YIVG1:FIV0>TUiH4YIRG1:BG
V0BRUYH4XiNF1:>GU@>TV9H4YiZH1:RKV@BZWI/4ZinM1:jRX0BfZjX3^[2^1;fc/@Bk/Jl4^Jn^1;R^
[0BfZjX3]:VW1;6VY@B_Y:84[J6P1:ZOW@BXWI/4YYZI0jFHU`BSUYD4XIFC1:2CT@BNTI04WHn>0i^>
S0BJS8/4V8^919N9R0BFR8H4UHJ519B5PaGoool001Coool4TXB21963P@BAPX44T8:018n1P0>?PGlG
SX1o18j0P0B>PH04Sh:11923PPBAQH@4ThJ60iF9R0BHS8/4Vhn>19jAT@BQU9<4YIVG1:FIV0>TUiH4
YIRG1:BGV0BRUYH4XiNF1:>GU@>TV9H4YiZH1:RKV@BZWI/4ZinM1:jRX0BfZjX3^[2^1;fc/@Bk/Jl4
^Jn^1;R^[0BfZjX3]:VW1;6VY@B_Y:84[J6P1:ZOW@BXWI/4YYZI0jFHU`BSUYD4XIFC1:2CT@BNTI04
WHn>0i^>S0BJS8/4V8^919N9R0BFR8H4UHJ519B5PaGoool001Coool4TXB219:3PPBBPh44TH>11i62
PAB@PX0;T8:11963PPBAQ884TXB319>5Q0>DQXD4UHR719N9R0BHRhT4VXb;19^=S0NLSXd4W8n=19b?
SPBNTHl4XIBA1::DTP>SUY<4Y9NE1:FHUPBVVIL4Z9ZH1:VMV`B[WY`7Yi^I1:NJV@BVVYP4YIVG1:BH
UP>SUYD4XYFC1:6DTPBPTY44WY6@19f@S`BLShd3W8j<19^=R`BJS8/4VH^:19R:R@BHRXP3UhV719J8
QPBEQhH4UHN519B6Q0BDQH<4ThB35Oooo`005?ooo`BBQ884TX>219:3P@BAPh47TH:15922P0^@PX44
TH>21964PPBBQ8<4ThF40iB6Q@BER8L4UhV819R;R@BJS8/4Vhf<1ib>S@BLShd4W8n>19jAS`BQU944
XYBB0j>FT`BTUiD4YIRF1:JIU`BXVYP4ZIfK1:^NW0NWViT4YiZI1:JJV0BUVIL4Y9RF0j>FU@BRUI<4
XIBB1:2BT@BNTI04WI2?19b?S@>LSX`4Vhf;19Z<R`BIRhX4V8Z919R:R0>GRHL4UXR619F7QPBEQhD4
U8J419B5P`BCQ8<Eoooo000Doooo19:4PPBBPh84TX>11963P@NAPX4DT8:02i22P@BAPh84THB219:4
P`BCQH@3U8J519F8Q`BGRHP4V8^919Z<R`BKSH`7W8j=19b?S@BLShh4WY6?1:6DT@BRU983XiJC1:BG
U@BUV9H4YYVG1:RJV0BYWI/4ZijL1jNKV@BWVYT4YYZH1:FIU`BTV9H3XiJE1::ET`BQU984X9:A19jA
T0BMT8l4W8n=0ib>S0BKSH/4VXb;19V;RPBHRXT4V8Z80iN9Q`BFR8H4UHN619F7Q@BDQX@4U8F319>4
PaGoool001Coool4TXB219:3PPBBPh44TH>11i62PAB@PX0;T8:11963PPBAQ884TXB319>5Q0>DQXD4
UHR719N9R0BHRhT4VXb;19^=S0NLSXd4W8n=19b?SPBNTHl4XIBA1::DTP>SUY<4Y9NE1:FHUPBVVIL4
Z9ZH1:VMV`B[WY`7Yi^I1:NJV@BVVYP4YIVG1:BHUP>SUYD4XYFC1:6DTPBPTY44WY6@19f@S`BLShd3
W8j<19^=R`BJS8/4VH^:19R:R@BHRXP3UhV719J8QPBEQhH4UHN519B6Q0BDQH<4ThB35Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00VOoo
o`<00024oooo002Loooo00<0003oooooool0POooo`00Noooo`D000000oooo`0000000003000000?o
ool0000000000P0000?oool400000_ooo`<00003oooo0`0000?oool20000O_ooo`00OOooo`030000
oooooooo00?oool01@000?ooooooooooo`000005oooo00@0003oooooool00002oooo00<0003ooooo
ool00oooo`040000oooooooo0000Poooo`00OOooo`030000oooooooo00?oool00`000?ooooooo`02
oooo00<0003oooooool00_ooo`040000oooooooo00000_ooo`@00002oooo00@0003oooooool00023
oooo001moooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`02oooo0`00
00?oool200001?ooo`@00022oooo001moooo00<0003oooooool00oooo`050000oooooooooooo0000
00;oool00`000?ooooooo`03oooo00<0003oooooool0SOooo`00O?ooo`800004oooo0P0000Coool2
00001Oooo`80002?oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(135) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
B1978CB1968CB1968BB1968BB0958BB0958AB0958AB0948AAF9489AF9489AF9388AF9388
AE9388AE9287AE9287AE9186AE9186AD9185AD9085AD9085AD9084AD8F84AD8F84AD8F83
AD8F84AD8F84AD9084AD9084AD9085AD8F84AD8F84AC8F84AC8F84AC8E84AC8E84AC8F85
AC8F85AD9086AD9186AD9187AD9288AE9288AE9389AE9389AE948AAF958CB0968DB0988F
B19990B0978EB0968CB0968CB0968BB0968BB0968BB0968BB0968BB0968BB0968CB1968C
B1968CB1978CB1978CB1978D
B1968CB1958BB0958AB09489AF9388AF9388AE9287AE9186AD9186AD9085AC8F84AC8F83
AC8E82AB8D81AB8C81AA8B7FAA8B7FA98A7EA98A7DA9897CA9887CA9887BA8877BA9877A
A9887BA9887CA9887CA9887CA8887DA8887CA8877BA7867BA7867BA7867BA7867BA7867C
A7887EA8897FA88A80A98B81A98C82AA8D83AA8E84AB8F86AB9188AD938AAE968DAF9991
B09A92AF978EAE958CAE948AAE948AAE948AAE948AAE948AAF948AAF948AAF958AB0958B
B0968BB0968BB1968CB1978C
B1968CB0958BAF9489AF9388AE9287AD9186AD9085AC8F83AB8D82AB8C81AA8B7FA98A7E
A9897DA8887CA7877BA7867AA68578A58477A58375A48274A48173A48072A47F72A47F71
A47F72A48073A48074A48174A48175A48075A38075A38075A38075A37F75A38076A48278
A5837AA5857BA6867CA6867DA6877DA6887EA68A80A78C82A98E85AA9188AC948CAE9891
AE9890AD958CAC938AAC9289AC9288AC9288AC9288AD9288AD9388AE9389AE9489AF948A
AF958AB0958BB0968BB1968C
B1968BB0948AAF9388AE9287AD9085AC8F84AB8E82AA8C81A98B7FA88A7DA7887CA6867A
A68578A58376A48275A38073A27F71A17D6FA17C6EA07A6C9F796B9F78699F77689F7768
A0786AA0796BA0796CA07A6DA07A6DA07A6EA07B70A17C72A27D72A17D73A17E74A27E74
A27E75A37F76A38077A38178A38379A3847BA4867DA5897FA68B82A88E85A99189AB948C
AB938BAA9289AA9187AA9086AA9086AA9086AB9086AB9186AC9187AC9287AD9288AE9389
AE9489AF958AB0958BB1968C
B0958BAF9489AE9287AD9186AC8F83AA8D81A98B7FA8897DA7887BA68679A58477A48275
A38073A17E71A07D6F9F7B6C9E796A9D77689C75669B73639B71619A70609A6F5F9A6F5F
9B71619B72629B72649B73659B74679C74689C756A9C766B9D776C9D786D9D796E9E7A70
9F7B709F7B719F7D72A07E74A07E75A08177A18379A2857BA3877EA48A81A78E86A89189
A88F87A78E85A78D84A78D83A88D83A88E83A98E84A98F84AA8F85AB9086AC9186AD9287
AE9388AF9489B0958BB1968C
B0958AAF9388AD9186AC8F84AA8D81A98B7FA8897DA6877AA58578A48275A28073A17E70
A07C6E9E796B9D77699C75669A7363997060986E5E976B5B956958956756956655956756
966959976B5C976C5D976D5E976D60976E61976E62976F63987064987166997368997469
99746A9A756B9A776C9A786D9B7A6F9C7B709D7D739E80769F8379A1867DA48B83A58D85
A48B82A48A81A48A80A58A80A58A80A68B80A78C81A88C82A98D83AA8F84AB9085AC9186
AD9287AE9389AF958AB0968B
B0958AAE9287AD9085AB8E82A98B7FA8897DA6867AA48477A38174A17F71A07C6F9E7A6C
9D77699B7566997263986F5F966C5C956A5993675692645290604E8E5D4B8E5B48905E4B
92625293645593665693665893675993675A93675B93685C93685C93685D93695E936B60
946C61946E62956F6495716696746897766A98786C9A7A6F9C7E749E8278A0867DA0877E
A1867CA1867CA1867BA2867CA3877CA4887DA5897EA68B80A78C81A88D82AA8E84AB8F85
AC9186AD9288AF948AB0968B
B0948AAE9287AC8F83AA8C80A8897DA6877AA48477A38174A17E719F7B6E9D796A9B7667
9A7364987060966D5D946A599366559163528F604E8D5C498A584586513D8954408E5B48
8F5D4C8F5F4F8F60518F60528E60528E60538E60538E60538E5F538D5F548D60548D6156
8D63588E655A8F685C8F6A5E906D6192706494736796756A98796E9A7D729C80769C8176
9D81769D81769E82779F8378A08479A1857AA3877CA4887DA58A7FA78B81A88D82AA8F84
AB9186AD9288AE9489B0958B
AF9489AD9186AB8D82A98A7FA7877BA58478A38174A17E719F7B6D9D786A9A7566987162
966E5F946B5B9367579164538F614F8D5D4A8B594688554186503C844D398B55418C5845
8C59488B5A498B5A4A8A5A4B8A5A4B8A5A4C895A4D89594C88574B88564A87564A87574C
875A4E885D528961558963578B675B8D6A5E8F6D6191706493726795756997786D98796D
997A6F9A7C709B7D719C7F739D80759F8277A08479A2867BA4887DA58A7FA78C81A98E83
AA9085AC9287AE9389B0958B
AF9489AD9085AA8D81A8897DA68679A38276A17F729F7C6E9C786A9A7566987162966D5E
936A5A9166558F62518D5F4D8B5B4889574487533F854F3A824B358A533C905A458B5643
895543885443875443865444855445855345845345845245835044824F44825044825146
82534882564B83594D855D518660548864588B675B8E6B5F8F6D61916F63927164937164
95746796766A97786C997B6F9B7D719C7F739E8176A08478A2867BA4887DA68A7FA88C82
AA8F84AC9186AE9388B0958B
AF9389AC9084AA8C80A7887CA48578A281749F7D6F9D796B9A7567987162956D5E936959
9065558E61508C5D4B89594787554285513D834D387F4630864D378E57418B544088523F
86513E844F3D834E3D824E3D814E3E804E3F804D3F7F4B3F7F493E7E483D7E493E7E4A40
7E4C427E50457E534880574B825B4F845F538763568966598B685B8D695C8D695B8F6B5D
906E6092716494746796766A98796D9A7C709C7F739E8176A08479A2867BA4897EA78B80
A98E83AB9085AD9388AF958A
AF9388AC8F84A98B7FA6877BA38376A07E719E7A6D9B7668987263956E5F936A5A906555
8D61508B5D4B885846855441834F3B804B367F4631844B348A513B88503A864F3A844E3A
824C39804A377E48377D48377C48387C48397B47397B473A7B483C7A4B3E7A4C3F7A4E42
794F43794F437A4F457B53487D584B805C4F835F538562568865588966598A67598B6657
8C67588E6C5E906F6292726695766997796D997C709C7F739E8277A1857AA3887DA68A80
A88D82AA9085AD9288AF958A
AE9388AB8E83A88A7EA58579A281749F7C6F9C786A997365966F60936B5B9066568D6151
8A5D4B875846845340814E3B7F4A357C452F793F297E442C834A33834B35824B36804A36
7E48347B4532794332784333774334764334774436774639774B3D774F42775446775648
7653467550447550447752467955497C584C7F5C4F826052846255866456876456886456
8965568A67588C6B5D8F6E6191726694766A97796D9A7D719D80759F8378A2867BA5897E
A78C81AA8F84AC9287AF948A
AE9287AB8E82A7897DA48477A17F729D7A6D9A7668977162946C5D9067578D62528A5E4C
875947845341814E3B7E49357A442F773E287C41298349318148327F48337E48347C4734
7A443177412E743E2D733E2F723E30703E31734739764F4177544678584C78574B755447
73564872574A7154477251447552467856497C5A4D7F5D51816153836254846254846254
8561528662538866588B6A5D8E6E6291736795776B987B6F9B7E739E8277A1857AA4887D
A68B81A98E84AC9187AF948A
AE9287AA8D81A6877CA382769F7E719C796B987365956E5F91695A8E64548B5F4E875A48
845442814F3C7D493579442F763F29733A247A41298047307E47317D46317B4532794431
774230743F2E713E2E6E3C2D70433476504279564877564976574A755648755648755A4D
765A4E74594D7255496F534671524575544879584C7C5C4F7E5E52806053806052815F52
8160528261548362558766598B6B5F8F706492756996796D997D719C8075A08479A3877C
A68B80A98E83AC9186AF948A
AD9287AA8C81A6877BA282759E7C6F9A7669967163936C5D8F66578C6150885B4A855644
81513E7D4B37794430753E287239237339227C422B7D452E7C45307A4531794532764331
744130714230714333724737764C3C764D3D744D3D734E3F724E3E714D3D704D3E704E40
714F4173524475564976594C73554A72524775554979594D7B5D507C5E517D5E517E5E50
7E5E507F5E50805F5083625587685C8C6E6290736794776C987B709B7F749E8378A2877C
A58A7FA88D83AB9186AE9489
AD9186A98C80A5867AA080739C7A6D987466946E6090695A8D6353895E4D855847825341
7F4D3A7B473376402B6E361F6B3019763B238047307C453079432F774330754331744331
724332734737764F407957477A5848755243724E3F704C3C6E48396D47396C47396C4738
6D48396E4D3E704F4173524675554973544874544977584C785A4E795B4E7A5B4F7A5C4F
7B5D507C5D4F7F5F5182625586675A8A6C608F716593766A967A6F9A7E739D8277A1867B
A4897FA88D82AB9086AE9489
AD9186A88B7FA485799F7E729B786B967264926C5D8E66578A6050865A4A8355437F4F3D
7C4A37794430753E29703822753C257E462F7E47317A4430774330744331724332714232
704333704636714B3C734F417251437152427051426E50416D4E3F6C4E3E6B4E3E6B5040
6B50416C4F416E4E4170514473544675574A76584C75584C76594D76594D775A4E785A4E
785B4E795A4E76574A7C5D50846759896B5F8D706591756A95796E997D729C8177A0857A
A4897EA78D82AB9086AE9489
AD9186A88A7FA383779E7D70997669957062906A5B8C6354875D4D83574680513F7D4C39
7A463378422E77402B7D452E864D35824B347A453076432F7343317143327043326E4433
6D45356D46376E48396D493A6D4B3C6C4C3D6B4B3D6A4B3C69493C67493B674A3B664A3C
674C3E674D3F6950426C5546705A4C755F52776154765E52745A4E74594E74594E755A4E
765A4E765A4F775B507D6155826659886C608C706490746994796E987D729C81769F857A
A3897EA78C82AA9085AE9489
AC9085A7897EA282769D7B6F977567926E608E6758896051855A4A8053427D4D3B794735
76422F753F29753D25783F2779422C77432E74412D71402E6F41306D42316C43336B4233
6A43346A4436694435684435684637674739664739654638644638634638624537624638
62473A63493D654C406850436C55486F594C715B4F735C50725B5072584E72584E73584E
745A4F745A4F745A507D625782675C866B5F8B6F648F746993786D977C729B80769F847A
A2887EA68C82AA9085AE9389
AC9085A6887DA181759B7A6D967365906B5E8B6456865D4E8156467D4F3F794937754330
723D2A7039246F36206F37216F37226E3A266E3C2A6D3D2C6B3E2E693F2F683F30673F31
6640326641336642346542336441346342346241346141346042345F42355E42365E4236
5E443861473B634A3F664F446953486C574B6E594E6F5A4F6F584F6F574E6F574E71594F
735A50745B51745B517C6155806558856A5E8A6F648E746992786D967C719A80769E847A
A2887EA68C81AA9085AE9389
AB8F84A5887C9F80749A786C9470638E695B886153835A4B7E5242794B3A754433713E2B
6D38246B321D69301A68301C68321F6936236A3826683929663A2A643B2B633B2C623B2D
623D2E613E30613F31603E315F3E315F3F325E3F325D40335C3F335B3F345B40345B4136
5C43395D453B60493E624D4366514869554C6C584F6C59506B574E6C564E6D574F705950
725B51755D53775E537C60547F635785695E896F648D746991786D957C729980769D847A
A1887DA58C81A98F85AD9389
AB8F84A5877B9E7F7398776A926E618B6659855E508056477A4E3F754736703F2E6B3825
68311E652C17622915612916622F1C6433226435246237266136276037285E37285D3729
5D382A5C392C5C3A2E5B3C2F5B3C2F5A3B2F5A3B2F593B30583B30573B30563B30563D33
57403659433A5C473E5F4B42624E4665524B67554D67554D67554D69554D6A564E6D5850
715B52765F567E645A84695D82665B84695E8970668D746A91786E947C729880769D837A
A1877DA58B81A98F85AD9389
AB8F84A4867B9D7D729675698F6C5F896456825B4D7C5344764A3B7042326A3A29653220
6129165D230F5B200E5B25145D2D1C5E31205E33225D33235C32235B3223593123583224
57322557332757362A57382D57392E57392D55372C55372C54362C52362C52372D523930
533C3355403757433B5A48415E4D4560504861504962504963514965514A67534C6B564E
6F5951745D557B635A836B628B756B8D756C8A72688C746B90786E937B72987F769C837A
A0877DA48B81A98F85AD9389
AA8E83A3857A9C7C719473678D6A5E8661547F584A784F417146376B3D2D6534235F2C1A
5A241156200E552110572716592B1B5A2E1E592F20582F20572E20562D1F542C1F532C1F
522C20522E2252302552322853342A52352B52362C51362C50352B4F352B4E352D4E372F
4F3A32513D3654423C5847415A4A445B4B455C4C455C4C465E4D47604E4863504A67534D
6B56506F5B54755F577C665D826D64856F668771688A746A8E776E927B72977F769B837A
9F877DA48B81A88F85AD9389
AA8E83A284799A7B709372668B685C835F527C5548744B3D6D42336638295E2F1E582513
521E0C4E1D0B4D200F51251554291A552B1C552B1D542B1D522A1C51281B4F271A4D261A
4C261B4C281D4C2A204D2D234E2F264E31274E32294D332A4C322A4B322A4B332C4B362F
4D39324F3D3651413A53433D54443F5546405646415747425949435B4B455E4D4861504A
65544E6B5851705C5576615A7A655D7F6860846E6588726A8C766E917B72967F769A837A
9F877EA48B81A88F85AD9389
A98D83A18479997A6F91706489665A805C4F78524570483A683E3060342558291A501E0D
47160542140444190B4B22134F271850281A50281A4F271A4E27194C25184A2417482217
46221746231947261D482920492C234A2E254A2F274A312949312948322A48322B48342E
4937314B3A344D3C374D3E3A4E3F3B4E403B4F413D51433F534541564844594B475C4E49
61504C65534E69564F6F5B54755F577B655D816C648671698B766E907A72947E7699837A
9E877EA38B82A88F85AD9389
A98D82A0837898796E8F6F638664587D5A4D754F426C443763392C5B2F21522416491A0B
4012053D130640180B461F124B24174D26194D26194C26194A2418472317452117432016
411F16411F1641201843241B45281F472B23482E26482F28472F28452F2944302A45322C
45342E463631473834473935473A36483A37493C384B3E3A4D413D504440544744584A47
5B4D495F504B63534D695751705C5678665F7E6B6483706989756E8E7A72937E7698827A
9E877EA38B82A88F85AD9389
A98D82A0827897786D8D6D628462577B574B714C406740345E3528552A1D4C201245180B
40160B3E160B401A0E4721154A24184A25184B261A4A251A4723184320153F1C123B1910
3919103A1B133D1E1640211A42251D452A22462D27462F29452F2A43302A42302A42312B
42322E42332F413430403431413532423734433836463B39493E3C4C423F4F4442534745
564B485A4D4A5D4F4B62524F6B5A567465607B6B6581706A87756E8D7972927E7698827A
9D877EA28B82A78F86AC9389
A88D829F827796776C8C6C6182615678554A6D493D633D315830244E2518461A0D3F1408
37110737130A3E1B1047231749251A4A261B4A271C49271C47261C44241B4021193C1E17
381C15381D153C20183E221B41251E442A24452F2945312B44312B42302B41302B3F312C
3E302D3E312E3E32303D32303C31303C32303E3432413836453B39483E3D4B41404D4543
514846554B49594E4C6155536A5D5A726662796B667F706A86756F8C7973917E7797827B
9D877EA28B82A78F86AC9389
A88C829E817795776C8B6B618060557654496A473B5E392E522B1F471E123F15093A1207
38140A3C1A10421F1549261B4A281D4A281E49281F492820482921482A23492C25462B24
442922442A23442C26462F294A352E4A363047342F45332F43322E41312D3F302D3E2F2D
3B2D2C3A2E2D382E2C352C2B342B2B362E2D3931313D3534413837453C3B48403F4B4342
4D45454F4747534B4B5C5453675F5D706765776B687E706B84756F8B7973917E7797837B
9C877FA28B82A78F86AC9389
A88C819E817794766C8A6B617F5F5574534867453A5A362B4B241A391005330A00341006
36150C3C1B134322194A291E4B29204A2A214A2A22482A22482B24492E284A302A4D332D
523932543B34533B34513B354E3B364B393448363245343043322F41312F403230403332
4035343E3636373132312C2E332C2E362F31362F313A32333E3637433B3B463F3F484243
4A44454A45464D494A575151635C5B6D6664756A677C6F6B8375708A7A74907E7896837C
9C877FA28B83A78F86AC938A
A88D829E827894776D896C627F605673534966453B57352B441E14371208320F072D0C05
30120B3A1B1345251B4D2C224C2C234C2C254A2B24492B25492D2749302B4A332F4C3632
4F3834503C37523E3A503E3A4E3D3A4B3B38483835453533433331413332403433403635
423837433A3A433A3941393941393A40393A41393B443C3D453E3F474142464243474244
4743454543454A474A5650516159596A62617369677B6F6C827570897A75907F7996847D
9C8880A28C84A79087AC938A
A88D839E837994786E8A6C637F615773544B67473E59382F4A281F4221183D1E15381C14
381C1541231A492A214F2F264E2F274D30284D322B4C332E49302B472F2A47302D473330
4936344A39374C3B394C3C3A4B3D3B4A3C3B473938453634423433413434403535403537
403738413A3A433C3D4942424F47464D45454D45454D46464A4546474346454246454346
4442464343474B494C565254615A5B6963627269677A6F6C827571897B7690807A97847E
9C8981A28C84A79087AC948A
A88D839E837994786F8A6E6480625974574E694A425C3E354F3128482A2343261F41251E
43261F472A224C2F2750322A4F312A4E332C4E352F4E37334F3B374F3C394E3C3B51403F
5445435547465447465247464F44444B3F3E473A3A4436364135354036364036383E3539
3D35393E373A403A3C443D3F4842434A45474B47494A4649464448454248434147424146
4040464142474A4A4F595658625D5E6863637068677A706D8276738A7C7891817C97867F
9D8A82A28D85A89188AD948A
A88D839F847A9579708B6F6681655C765A516B4F4660433C55393150342D4D312A4A2F28
4A2E274C302950332B51342C50332C4F342E4E36314E39354F3C3951413F534645554948
564C4C564D4E554D4E524A4B4D4444483D3E443938413636403636403638423A3C433D40
423D423E393F3B373C3D393D413D41434044444145444246434147424147414147414148
3D3F4741434A4D4D525755585C595B625E5E6E66657B716F8479758C7E7A92837E998781
9E8B84A38E86A89189AD948B
A88E849F847B967B728C716883675F795D556E534B6449425A3F39563C36543A34523731
52373053373053373053373051362F4F36304E36324D38354D3B384E3E3D4F4141504344
4F45454F45464E44454B4143483E3F45393A4236363F34353E33353F353740383B423C40
4541454844484743484340453E3C413D3B413E3D433F3E45403F4641424941434A3F4249
3D424A44484F4D4F555454595A5A5E67656675706F7E7674877C798E817D9586819A8983
A08D86A49088A9928AAD958B
A98E84A0857C977C738E736B846A627B6059725750684E475F453F5D433D5A413B583E38
583D37573C36563A345338325036304E35314D36324C37344C38364B3A394B3B3B4B3D3D
4A3E3F493D3F473C3D453A3B4237394034363D32343C30333B31333B32353D34383E383C
413C4044404447444849474B4A484D48474C46454B46464C45474E43464E3F444C3D444C
3F464E474D5450545A585C606164676D6D6E7B7675837B798B807D9285819789849D8C86
A18F88A69189AA938BAE958C
A98F85A1867D987E758F756D876D657E645D755B546C524C6349436047415E46405D443F
5B423C5A3F3A573C365339335036314E35314C35324B3633493634483736473737463737
4537374336374134363F33343D30323B2E31392D30372C2F372D30372E333830353A3338
3C373B3F3A3F423E4444424847464C48484F48495046485043474F41464E3E454D3D444D
4148514B525A565B626064696A6B6F7473747F7979887F7D908683968A869B8D88A08F8A
A4918BA7938BAB948CAE968C
A98F85A1887E998077917870897068806760785F596F5751664E49644D49634C48614A45
5E47435B443F573F3B533B375037334D35324B3532493432473432453333433333413232
3F31313D2F303B2E2F392C2E372A2D35292C33272B32272B32282D33292F342C31352F35
37323839363C3B3A413E3E4540414841434A42444D40454D3E454E3D454E3B454E3B4651
434D575058605B6169666A707273777D7C7E888383918988978D8B9B908C9F928DA3938D
A6948DA9958DAC968DAF968D
AA9086A289809B8179937A728B736B836B647B635D735C566B545069534F67514E66504C
634D496049455C454258413E523C394E37354B3432473331453130422F2F3F2E2E3D2D2E
3A2C2D382A2B36282A3426293124282F23272E22272D22272D23292E252B2E282E2F2A31
312E3534323936353D3839413A3C443B3F483C404A3C424B3C434D3C444E3B4550404A55
4B555E575F686369707074797E7F838A898B9591919C96959F9694A19693A49792A69791
A99790AB978FAD978EAF978E
AA9187A38A819C837B957C758D766F866F687E676276605B6E59556D58556C5753695552
66514F624D4A5E49465B4441563F3D513A374A3533463231422F2E3F2C2C3B2A2A382829
3526273324263022252E20232C1E222A1E22291D22281E24281F2528212829232B2B262E
2D2A322F2E3631313A33343E353841363B45373D47383F4A39414C39434F3C475345505B
515B655F676F6E747A7C7F848A8B8E989697A5A3A3A9A4A3A79F9CA79D99A99B97AA9B95
AB9A93AD9991AE9890B0988E
AB9187A48B829E857D977F7890797289726D826C677A6460725D5A715C596F5B586C5956
695653665351624F4D5C4847564241503C3B4936364331313F2D2D3B2A2A372727342325
3020222D1E202A1C1E281A1D25181C24171C23171D23181F231B22231D2524202826232C
2827302A2B342C2E382E313C303540323844343C47343F4B36414E3A4652414D594C5863
5A646E697179787E84878A8E959699A3A1A2AEAAAAAEA9A8AEA6A3ADA39FADA09BAE9E98
AE9D96AF9B93B09A91B1988F
AB9288A58C849F877F99827A937C768C777186716C7F6B6777646176636074615E715E5C
6E5C5A6A58576452515E4C4B5645454D3C3D463536412F303C2B2C3726283322242F1E20
2B1A1C28171A2415182113171F12171D12181C12191C131B1C161E1E1922201C2621202A
23242E262732282C372B303B2D333F2E3643303A47313E4B35424F3A485644525F525F6B
626D76727A8281878E909499A0A1A4AFADAFB8B4B4B5B0AEB3ABA9B2A8A4B1A4A0B1A29C
B19F98B19D95B19B92B19990
AC9289A68E85A189819B847D968079907B768A767284716E7E6B697C6A68786866756463
71605F6C5B5B6756566050505747494C3D3F4535373E2F3139292B3323252E1E202A191C
2516182112161E10141B0F14190D14170C14160C15160E1817111C1915201B19241D1C27
1F202C222531242935272E3A29323F2B36432D3A47313E4C3544523E4D5B4B5A675B6974
6D77817E858D8D92989EA0A4AFAFB1BFBFBFC2C0BFBCB6B5B9B1AEB7ACA8B5A8A3B4A59F
B3A29BB39F97B29C93B29A90
AD938AA88F86A38B839E878099837D947F7A8F7B778977748473718272717E6F6E7A6B6A
756666706161695B5C625455584A4D4E414445383B3C2E313526292F2024291B1E24161A
1F12171B0E14170B121409111208101007110F0912100B16110E1913121D151521181A26
1B1E2B1E2330212835232D3A26313F2A36452D3C4A3241503A4A5946566455647166737E
78828B889097999EA3AAACAFB9B9BAC4C2C2C3C0BFC1BBB9BDB5B2BBB0ACB8ABA6B7A7A1
B5A49DB4A099B39D94B29A91
AD948AA99088A48D85A08A839C878197847F93817D8F7E7B8A7A788879788476767F7272
7A6D6E7467696E6162665A5C5E515453474B473B403B303532262B2B1D2325171D1E1118
190D15150A121107100E050E0B030E09030F0805110A07140C0B180F0F1C111321141826
171D2B1A22301E2735212C3B2432412937472F3E4E37475742536251616F62707C737F89
848D96949BA2A6AAAFB8BABCC6C5C6CCCBCAC9C5C4C5BFBDC1B9B6BEB3AFBBAEA9B9AAA4
B7A59FB6A29AB49E95B39B91
AE948BAA9289A68F87A28C869F8A849B88839886829584829384849082838B7E7E85797A
8175767B6F7074696A6D616464595C594F544D444A40373E332931281E2621161F1A1019
130A140E06110A030E07010D04000D02000D02020F040513070A180A0E1D0D1221101726
141D2B1822311C2838212E3E2635452D3C4D3445553F50604F5F6E5F6E7B707D89818C96
939BA3A4AAB0B6B9BDC5C7C8D4D5D6D6D6D6CECBC9C9C3C0C5BCB9C1B6B2BEB0ABBBABA5
B9A7A0B7A39BB59F96B39B91
AE958BAB938AA89189A48F88A18D879E8C879C8B879A8A88988B8A958A899186868C8182
867C7D8076787A707373696C6B616562595E574E544A42493C343D302932231C2618121D
100B170A051107020F03010E00000F000111010414020717040A1A070F1E0B14240E1929
111E2E1623351D2B3C2333442A3A4C3343553E50604C5E6D5C6D7A6E7C88808B96919BA4
A3ABB1B5BABEC5C8CAD3D4D5DBDBDBD8D6D5D2CECCCDC6C3C8BEBBC4B8B3C0B2ADBDADA7
BAA8A1B8A49CB69F97B39B92
AF958CAC948BA9928BA6918AA4908AA28F8BA08F8B9E8F8D9D908E9B9090988E90948A8B
8E8586897F8282797C7B7376746B706A626760585E544D544841493B353E2D2934211E2A
191522120F1D0C0B1A08081805081805091B050C1E060E200711230915270C192B0F1E30
1524361B2B3D213244293A4C3344553E50614C5E6E5C6D7B6D7C897F8C97919CA5A3ABB3
B6BBC0C8CACED6D7D9E1E2E3E4E4E3DCD9D8D5D0CECFC8C5CAC0BCC6B9B5C2B3AEBEAEA8
BBA9A2B9A49CB6A097B49B92
AF968CAD958CAB948CA8938CA6938DA5928EA3938FA29391A19593A29797A096979B9293
968D8E91888A8C8386867E817D7579726B706760665B555C504A52453F4839353F2F2C38
2625321F202E191B2A1417271116271117281018290F1A2C101C2F121F3214233618283B
1D2F412435482C3D503547584052634D5F6F5D6E7B6D7C897F8C97919CA5A3ACB3B6BCC2
C9CCD0D9DADDE5E6E7EDEEEEE8E8E8DFDBDAD7D1CFD1C9C5CCC1BDC7BAB5C3B4AEBFAFA8
BCA9A2B9A59CB7A097B49B92
B0968DAE968DAC958DAA958EA9958FA79590A69692A69794A69997A69B9BA69D9EA49C9D
9E96989A9194948C8F8D8689847D817A737870696F6660675C575F504D5645444F3D3C48
37364331323F2A2D3B262A39222737212737202939212B3C222E3F2532432735472A3A4C
303F52374759405161495A6A55657462717F727F8C828E99939DA6A4ADB4B6BDC2C9CDD1
DADDDEE8E9EAF4F6F6F3F4F4E8E6E5DFDBD9D8D1CED2C9C5CDC1BDC8BBB5C4B4AEC0AFA8
BDAAA2BAA59CB7A097B49C92
B0978DAE978EAD968EAC968FAB9791AA9792A99994A99A97A99C9AAA9F9EABA2A2AAA1A3
A79FA1A29B9D9C9597948E918D878B8580847B767C716C736762695C596254525C4D4C56
46465240414E3B3D4B383B49353948333A49343B4B353E4D3741513945553C4959404E5E
4654644E5C6B5664735F6D7B6A788477848F87919C97A0A9A7AEB6B9BEC3CBCED1DCDEDF
EAEBECF7F9FAF9FAFAEFEEEDE7E3E2DFD9D7D8D0CDD2C8C4CDC1BCC8BAB5C4B4AEC0AFA8
BDA9A2BAA59CB7A097B49C92
B0978DAF978EAE978FAD9890AC9892AC9994AC9B96AC9D99AD9F9DAEA3A1B0A7A6B0AAAA
AFA9ABAAA4A6A59FA19F999C9892968F8A8E8681867D797F7470786A687164626B5D5C66
58576153525D4E4F5B4B4D5A484C59484D5A494F5D4B515F4D5463505866545D6B596371
606A7868727E6E798576818D818B968D96A09BA3ABABB1B7BCC0C5CDCFD2DBDCDEE9E9EA
F8F9F9FCFDFDF3F3F2ECE9E8E4DFDDDDD6D3D7CECAD1C6C2CCBFBAC8B9B3C4B3ADC0AEA7
BDA9A1BAA49CB7A097B49B92
B1978EB0988FAF9890AE9991AE9A93AE9B95AE9C97AE9F9BAFA19EB1A5A3B3AAA9B8B1B2
BAB5B6B5B0B2AFAAACA9A4A6A29DA09C979A948F948D888E8581877C7A8175737B6F6D75
6A697166656E62636C60626B60616C5F616C60636E626570656874686C786E727D737883
797F8A808690878D968F959D999FA6A6AAB0B4B7BCC2C4C8D0D1D4DFDEDFEDEBECF9F8F7
FDFDFCF6F6F5EFEDEBE8E4E2E2DBD8DBD3CFD5CBC7D0C4BFCCBEB8C7B8B1C3B2ABC0ADA6
BDA8A0BAA49BB79F96B49B91
B1988EB0988FB09990AF9992AF9A94AF9C96AF9E98B0A09BB1A39FB3A7A4B6ABAAB9B1B1
BEB9B9C0BBBDBBB6B8B4AFB1AEA9ABA8A3A6A29DA19C989C9692978F8C9289868D838188
7F7D847C7A827A798077777E76757D76757E76767F7878817B7B847F808883858E8A8D96
93959D989AA19D9FA6A6A8ADB2B2B7BCBDC0C8C8CAD5D4D5E2E0E1EDEBEBF7F6F6FEFFFF
FBFCFCF2F0EFEBE7E5E4DEDBDED6D3D9CFCAD3C8C3CFC1BCCABBB5C6B6AFC3B1A9BFACA4
BCA79FB9A39AB79F96B49B91
B1988EB1988FB09990B09A92B09B94B09C96B19E98B2A19CB3A39FB5A7A4B7ABA9BAB1AF
BEB7B6C3BEBFC4C0C2C0BABCB9B4B6B3AEB0AEAAADABA6A9A6A1A5A19CA09C989D989499
949096918D938E8B918C89908B888F8C898F8C8A908E8C92908E9493919799979C9E9CA1
A4A1A4ABA8ABB2B0B3BBB9BBC4C2C3CCCACBD7D5D5E3E0DFEDEBEAF8F6F5FFFFFFFDFEFE
F4F3F1EDE9E7E6E0DDE0D8D5DBD1CDD5CAC5D1C4BECCBEB8C8B8B2C5B3ACC1AFA7BEAAA2
BBA69EB9A299B69E95B49B91
B1988EB1988FB19990B19A92B19B94B19D96B29E98B2A19BB4A39EB6A7A3B8ABA7BBAFAD
BEB5B3C2BABAC6C1C2C7C3C4C4BFC0BFBABCBAB5B7B7B1B4B4AFB3B0ACB0AEA8ACACA7AA
AAA5A8A7A2A5A49FA3A29DA1A19CA0A09B9FA19BA0A39DA2A59FA3A7A2A5A9A4A6ADA7A8
B1ACACB4AFB0BBB6B7C3BFBFCCC8C8D8D3D3E3DFDEEDE9E8F7F3F2FEFCFCFDFDFCF5F3F1
EEE9E7E7E1DEE1D9D5DCD2CDD7CBC6D2C5BFCEBFB9CABAB3C6B5AEC3B1A9C0ACA4BDA8A0
BBA59CB8A198B69E94B49A90
B1988EB1988FB19990B19A92B19B93B29D95B29E97B3A09AB4A39DB6A6A1B8A9A5BAADAA
BDB2AFC1B7B6C5BDBDCAC5C6CBC7C9C8C2C4C4BEC0C1BBBEBFBABCBEB8BBBCB6B9BAB4B7
B8B1B4B8B1B4B7B0B3B5AEB1B4ACAFB4ACAFB5ADAFB6AEAFB7AEAFB9B1B1BBB2B2BEB5B4
C1B8B7C5BDBCCDC5C3D5CDCBDDD6D4E7E0DEEEE9E7F6F1EFFDFAF9FBFAF9F4F1EFEDE7E5
E6DFDCE0D8D4DBD1CCD6CAC5D2C5BFCEBFB9CABAB4C7B6AFC4B1AAC1ADA6BEAAA2BCA69E
BAA39AB7A097B59D93B39A90
B1988EB1988FB19990B19A91B29B93B29C94B39E96B39F99B4A19BB6A49EB8A7A2BAABA6
BCAFABBFB3B0C3B8B6C7BFBECDC7C7D2CDCFD0CACBCAC4C5C6BFC1C6BFC2C8C1C4CAC3C4
C9C2C3C6BFC0C4BCBEC6BDBEC8BEBEC6BBBBC3B9B8C3B8B7C4B9B7C5B9B7C5BAB7C8BDB9
CABFBCD0C4C1D6CBC8DDD3D0E5DCD9EDE4E1F2EBE8F8F3F2F6F3F2EFEAE8E9E3DFE4DBD7
DED4D0D9CEC9D5C8C2D1C3BDCDBEB7CAB9B2C7B5AEC4B1AAC1ADA6BFAAA2BCA79EBAA49B
B8A198B79F95B59C92B39A8F
B1988DB1988EB1998FB29A90B29A92B29B93B39D95B39E97B4A099B5A29BB7A49EB9A7A2
BBABA6BDAEAAC0B3AFC4B8B5C8BEBCCDC5C3D2CBCBD3CCCCD0C9C9CFC7C7CFC6C7CFC6C7
CFC5C6CFC5C5D0C5C4CFC3C1CCBFBDCBBEBBCBBEBACABDB8C9BBB7C9BCB6CCBFBACEC1BC
D1C4BFD6CAC5DCD1CDE3D8D5E8DEDBECE4E2F1ECEAF1ECE9E9E2DFE4DBD7DFD4D0DACEC9
D6C9C3D2C3BDCEBFB8CBBAB4C8B6AFC5B3ABC3AFA8C0ACA4BEA9A1BCA79EBAA49BB9A299
B79F96B69D94B49B91B3998F
B1978DB1988EB2988FB29990B29A91B29B92B29B93B39D94B49E96B5A098B6A19AB7A49D
B9A6A0BBA9A3BDADA7C0B0ACC3B5B1C7BAB6CBBFBCD1C6C3D7CDCBD8CECCD4C9C7D2C6C4
D4C7C6D4C7C6D2C4C2D0C1BECEBFBCCEBFBCCFC0BBCFC0BAD0C1BBD0C1BBD1C2BCD2C4BE
D4C7C2D7CCC7DBD1CDE1D8D5E7E0DDEAE3E0E6DEDAE1D6D2DCD0CBD8CAC5D4C5BFD0C1BA
CDBDB6CAB9B2C7B5AEC5B2AAC3AFA7C1ACA4BFAAA1BDA79FBBA59CBAA39AB8A198B79F96
B69D94B59C92B49A90B3998E
B1988EB1988EB2988EB2988FB2998FB29990B29A91B39B92B39C93B49D94B49E96B5A098
B7A19AB8A39CB9A69FBBA8A2BEABA5C0AFA9C3B2ADC6B6B1C9BAB5CCBDB8CFC1BBD2C4BE
D1C3BDCFC1BCD0C1BDCFC0BDCDBDBACBBBB7CABAB5CBBAB4CBBBB4CCBCB5CDBCB6CDBDB6
CFC0B9D6C8C3DBCFCBDCD1CBD9CCC7D6C9C3D4C6BFD1C1BBCEBDB7CBBAB3C9B6AFC6B3AB
C4B0A8C2AEA6C0ABA3BFA9A1BDA79EBCA59CBAA39AB9A299B8A097B79F96B69E94B59D93
B49B91B49A90B3998FB2988E
B1978DB1988DB2988EB2988EB2988EB2988EB2998FB2998FB29A90B39A91B39B91B39B92
B49C93B59D94B69E96B6A097B8A199B9A39BBAA59DBCA79FBDA8A1BFAAA2C0ACA4C1ADA5
C1ADA5C1ADA5C2AEA6C2AFA7C5B1A9C7B4ABC7B4ACC8B5ADC8B5AEC9B6AEC9B7AFCAB8B1
CBBAB3CAB8B1C7B4ADC6B3ABC5B2AAC4B0A8C3AEA6C1ACA4C0AAA2BEA8A0BDA79EBCA59C
BBA49BBAA299B9A198B8A097B79F96B79E95B69D94B59D93B59C92B49B91B49A90B39A90
B3998FB3998FB2988EB2988D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?ooo`BaUh`4/IJ<2;6FR`B`UH/7/9F:1;2DRPR_U8T7[i>81:jC
R0R^TXL8[Y661:fAQ@N]T8D4[I242:f?Q0B]Sh<7[Hn42:f@Q0B]T8D8[Hn41jb?Q0R/SX@8[8n51:f@
QP>]THH4[I671:fBR0B^TXP8[Y>90jjDRPB_UH`4/9J=1;2HS`BaVI04/9N>1k2FS1N`UX/4/9J<2;6F
S0RaUh`4/IN=5Oooo`005?ooo`BaUh`4/IJ<2;6FR`B`UH/7/9F:1;2DRPR_U8T7[i>81:jCR0R^TXL8
[Y661:fAQ@N]T8D4[I242:f?Q0B]Sh<7[Hn42:f@Q0B]T8D8[Hn41jb?Q0R/SX@8[8n51:f@QP>]THH4
[I671:fBR0B^TXP8[Y>90jjDRPB_UH`4/9J=1;2HS`BaVI04/9N>1k2FS1N`UX/4/9J<2;6FS0RaUh`4
/IN=5Oooo`005?ooo`BaUh`4/IJ<2;6FR`B`UH/7/9F:1;2DRPR_U8T7[i>81:jCR0R^TXL8[Y661:fA
Q@N]T8D4[I242:f?Q0B]Sh<7[Hn42:f@Q0B]T8D8[Hn41jb?Q0R/SX@8[8n51:f@QP>]THH4[I671:fB
R0B^TXP8[Y>90jjDRPB_UH`4/9J=1;2HS`BaVI04/9N>1k2FS1N`UX/4/9J<2;6FS0RaUh`4/IN=5Ooo
o`005?ooo`BaUX`4/IF;1;2ERPB`U8T7[i>81:jBQ`B^THH4[I661:f@Q@B/Sh@3[8n31:b>PPB[SH44
Zhb12:Z;O`BYRWh3ZHYm1:V9O0BYR7`4ZHQk1:R7N`BYQgX4ZHQk2jV8O0BXR7d4Z8Ql1:R7N`nWQW/4
YhIl1:N8OPBXRGl3Z8Z01:V;P@BYS884ZXf31:Z>Q0B[ShH3Zi681:fCRPB^UXd4[iVA1;2JTPB_Uhh4
[YF<4jjDRPN_U8X4[iF:1;2ER`R`UX/4/IJ<1;6GS1Goool001Coool4/IJ<1;6ER`B`UHX4/9B91jnC
R0B^TXL4[Y661:fAQPB]T8D4[8n40jb?P`B/SX84Zhf11:^<P@RZRgl4ZHYn0jV:O@BYRG`4ZHQl1:V8
N`BXQg/4ZHMj1:V8N`^YR7`4Z8Qm1:R8O0BXQg/?YhIk1:N6O0BWR7h4Z8Uo0jR:P0BYRh44ZHb21:Z=
P`BZSX@4Zhn60j^AR0B]ThX4[YJ=1:nIT@B`VY84[iN>1:jES1>^U8X7[iB:1:nERPB`UH/8/9J;1;6F
S0BaUh`Eoooo000Doooo1;6FS0BaUH/4/9F:1;2DR@N_ThP4[Y:71:jAQPB]THH4[I251:b?Q0>/Sh<4
[8j21:^=P@B[S848ZX]o1:V:OP>YRWd4ZHUl1:V8O0BYR7/4Z8Mk1:V7NPBYR7/;ZHQl1:R8O@BXR7`4
Z8Mk3jN6N`BWQW`4YhQn1:R9O`>XRX04ZH^11:V<PPBZSH<4ZXj41:^?QP>[THP4[I>:1:jFS@B_VI44
/9ZB1:nGSPB^UH`C[YB:1jnDRPB_UHX4/9F;2;2FR`BaUX`4/IN<5Oooo`005?ooo`BaUX`4/IF;1;2E
RPB`U8T7[i>81:jBQ`B^THH4[I661:f@Q@B/Sh@3[8n31:b>PPB[SH44Zhb12:Z;O`BYRWh3ZHYm1:V9
O0BYR7`4ZHQk1:R7N`BYQgX4ZHQk2jV8O0BXR7d4Z8Ql1:R7N`nWQW/4YhIl1:N8OPBXRGl3Z8Z01:V;
P@BYS884ZXf31:Z>Q0B[ShH3Zi681:fCRPB^UXd4[iVA1;2JTPB_Uhh4[YF<4jjDRPN_U8X4[iF:1;2E
R`R`UX/4/IJ<1;6GS1Goool001Coool4/IJ<1;2ER`B_U8T4[i>81:jBQ`>]THH4[I251:b?P`B[SH84
Zhb11:Z;O`>YRWh4ZHUm1:R8O0BWQg/4YhIj1:J5N0BUQ7L3YH=e1:B2M0BTPG<4Y81b1:AoLPBTOg44
Y7mb0jB0L`BTP7@4Y85d1:B1M@BTP7D;Xh1e1:=oM@BSP7H4Y89h1:F3NPBUQG/3YXIl1:J6O@BVQgd4
YXQn1:J:P0BWS883ZHj51:ZAR0B/U8`4[YRA1:jHT0B]UH`4[9>:0jbBR@b/TXP4[I:81:fCR0>^ThT4
[YB91:nDRPB_UHX4/9F;1;2FR`BaUX`Eoooo000Doooo1;6FS0B`UH/4[iB91:nCR0B^TXL3[I661:f@
Q@B/Sh<4Zhf21:^<P@BZRgl3ZHYn1:V9O@BXR7`4YhMk1:N6NPBVQGP4YHAg0jF3M@BTPW@4Y85c1:B0
LPBTOg84Y7ma1:AoLP>TP7<4Y81d1:B1M0BTPGD4Y81e2j>0M@BSOgD4Xh1f1:B2N0BUPgX4YHEk0jJ6
O0BVQWd4YXMm1:J8OPBVRX04Yhb20jV>Q@BZTHP4[9B<1:jHT@B^V904[IF<1:bCRP>/TXT<[9:81:fB
R0B]ThP3[Y>91:jDR@B_U8X4[iF:1;2ER`B`UX/4/IJ<5Oooo`005?ooo`BaUX`4/9F;1:nDR@B_ThP4
[Y:70jfAQPB]T8D4[8n31:^=PPB[S844ZX]o0jV:OPBYRGd4Z8Ql1:N7N`BWQWX4YXEh1:F4M`>UPgD4
Y89d1:B1L`BTP784Y7mb1:AoL@BTOg83Y81c1:B0M0BTPG@4Y85e1:B0M@^SP7D4Xgme1:>0MPBTPWP4
YH=j1:F5N`>VQW`4YXIm1:J7O@BVR7h4YXZ01:N<PP>YSXD4ZY681:bDS0B^V944[YR@1:fES0B/ThX3
[9:93:bBR0B]TXP4[I>80jjCR@B^U8T4[iB:1:nERPB`UH/4/9J;1;6FS1Goool001Coool4/IJ<1;2E
R`B_U8T4[i>81:jBQ`>]THH4[I251:b?P`B[SH84Zhb11:Z;O`>YRWh4ZHUm1:R8O0BWQg/4YhIj1:J5
N0BUQ7L3YH=e1:B2M0BTPG<4Y81b1:AoLPBTOg44Y7mb0jB0L`BTP7@4Y85d1:B1M@BTP7D;Xh1e1:=o
M@BSP7H4Y89h1:F3NPBUQG/3YXIl1:J6O@BVQgd4YXQn1:J:P0BWS883ZHj51:ZAR0B/U8`4[YRA1:jH
T0B]UH`4[9>:0jbBR@b/TXP4[I:81:fCR0>^ThT4[YB91:nDRPB_UHX4/9F;1;2FR`BaUX`Eoooo000D
oooo1;6FR`B`U8X4[i>81:jBQ`B]T8D3[8n41:^>PPBZS844ZH]o1:R:O@BWR7`3YXIj1:J5N0BUPgH4
Y89e1:>0L`BROg44XGe_0j5lKPBPNV`4WgU[19mhJ@ROMfP4X7QZ0j1iJ`BPNF`8X7Y]1:1jKPBPNg03
XGab1:9mLPBQOG<4XGid1:9nM0BROWD4Xgmf0j>0M`BSPGP4Xh=i1:>4N`BTQWd4YHUo0jJ;PPBXSXD4
ZI691:^DS0B[Th/4ZY:91:ZAQ`^ZT8H4Zi261:^AQPB/THL3[9:71:fBR0B^ThT4[YB91:nERPB`UH/4
/IJ<5Oooo`005?ooo`BaUX/4/9B:1:nCR0B^TXL4[I250jb?Q0B[SX84ZXb11:V;O`BXRWd4YhQl0jJ6
NPBVQGP4YH=f1:B2M@BSP7<4XWma1:5mK`>QO6h4X7Y/19miJ`BON6T8WgMX1:1hJP>PNF/4X7U/2:1j
K@BPNVh4X7]`0j5lLPBROG84XGec1:5nM0BROW@4XWie1:=oMP>SP7L4Xh5h1:>3N@BSQ7/4Y8Im1:F9
O`>VRh84Z8j51:VAR@B[U8`4Zi>;1:ZBR@BZTHL;ZY261:^@QPB[THH4[9670jbBQ`B]TXP4[Y>91:jD
R@B_UHX4/9F;1;6FS1Goool001Coool4/IJ;1;2DRPB_ThP4[Y:71:f@Q@>/Sh@4Zhj21:Z<P@BYRgl4
Z8Ym1:N8O0>VQWX4YXEh1:F3MPBTPWD4Xh1c1:9oL@BQOFl3XGa^1:1jK0BONF/4WgQY29mgJ0BPN6X3
X7U[1:1iK0RPNVd4X7Y^1:1kL0>QO784XWeb1:5mL`BQOW@4XWid1:9nM@BSOgH3Xh1g1:>1N0BSPgT4
XhAk1:B6O@BURGl3YX^21:R>Q@BYTHT4ZiB<1:^CR`BZTXT4ZY672jZ@QPB[T8H4Zi661:bAQ`>/TXL4
[I:81:jCR@B^U8T4[iF:1;2ER`BaUX`Eoooo000Doooo1;6FR`B`U8X4[i>81:jBQ`B]T8D3[8n41:^>
PPBZS844ZH]o1:R:O@BWR7`3YXIj1:J5N0BUPgH4Y89e1:>0L`BROg44XGe_0j5lKPBPNV`4WgU[19mh
J@ROMfP4X7QZ0j1iJ`BPNF`8X7Y]1:1jKPBPNg03XGab1:9mLPBQOG<4XGid1:9nM0BROWD4Xgmf0j>0
M`BSPGP4Xh=i1:>4N`BTQWd4YHUo0jJ;PPBXSXD4ZI691:^DS0B[Th/4ZY:91:ZAQ`^ZT8H4Zi261:^A
QPB/THL3[9:71:fBR0B^ThT4[YB91:nERPB`UH/4/IJ<5Oooo`005?ooo`B`UH/4[iB91:jBQ`B]THH4
[8n30jZ=P@BYRgl4Z8Um1:N8N`BVQWT4YHAg0jB2M@BSP7<4XGia1:1mK`BONf`4WWUZ19egJ0>LMFH4
Vg=S19]aH@BJL608VVmO19]aH@>KLV84Vg9T19]cI@BKM6L4W7AX19aeJP>LMV/4WGM/19ehK@BMNFh4
WWY`19mkL0BONg43Wgeb1:1nM0BPOWD4X85g1:63N@BRQG/3XhMn1:B:P@BWSXH4Z9691:R?Q`BWSXD4
Yhf40jN=P`BXSH<4Z8j31:V>Q0BYSh@4ZXn50j^@QPB/THH4[I:71:jCR0B_U8T4/9F;1;6FS1Goool0
01Coool4/9F;1:nDR@B^TXL4[I661:b?P`>ZSH44ZH]o1:R9O@BWR7/4YXIi1:F4M`>TPWD4Xh1c1:5n
L@BPOFl4Wg]/19iiJPBMMfP3W7EV19]cH`BKLF44VW1P29Y_G`BKLF43Vg9R19]bI0BKLfD4VgAW19ad
J0BLMFX3W7I[19egK0BMN6d4WGU^19ijL0BONg04Wg]a0immLPBPOW@4X7ie1:21M`BQPgT4XXEk0j>7
OPBTRX44Yhj61:RAR@BXShL4Yhj51:N=Q0>WSH<4Z8f31:R>P`BYSX@4ZHn41:Z?Q@>[T8H4[9661:fB
Q`B^ThP4[iB91;2ER`BaUX`Eoooo000Doooo1;2ER`B_U8T4[Y:71:fAQPB/Sh<3ZXf11:V;O`BXRGd4
YhQk1:J6N@BUQ7L3Y89e1:>0L`BQOW44X7e_19mkK0BNNFX4WGMX0iaeIPBKLf<4Vg5Q19Y`H0RJKel4
Vg5Q0i]bHPBKLV@4Vg=U19]dI`BLM6P4W7EZ0iafJ`BMMf`4WGQ]19eiKPBNNW04Wg]`19mkL@>OOG84
X7id1:1nM@BPPGL4XH=i1::5N`>SQgh4Y8Z11:N>QPBXTHT4Z8n71:N>Q@BWSH@3Yhf31:R=P`BXSX<4
ZHj41:V?Q0BZShD3Zi261:bAQPB]TXL4[Y>81:nDR@B`UH/4/IJ<5Oooo`005?ooo`B`UH/4[iB91:jB
Q`B]THH4[8n30jZ=P@BYRgl4Z8Um1:N8N`BVQWT4YHAg0jB2M@BSP7<4XGia1:1mK`BONf`4WWUZ19eg
J0>LMFH4Vg=S19]aH@BJL608VVmO19]aH@>KLV84Vg9T19]cI@BKM6L4W7AX19aeJP>LMV/4WGM/19eh
K@BMNFh4WWY`19mkL0BONg43Wgeb1:1nM0BPOWD4X85g1:63N@BRQG/3XhMn1:B:P@BWSXH4Z9691:R?
Q`BWSXD4Yhf40jN=P`BXSH<4Z8j31:V>Q0BYSh@4ZXn50j^@QPB/THH4[I:71:jCR0B_U8T4/9F;1;6F
S1Goool001Coool4/9F:1:nCR0B]THH4[8n41:Z=P@>YRgl4Z8Um1:J7NPBUQGP4Y89e1::0L`>QOW04
X7a^19iiJ`BMMfT4W7EV19YcH`BIL603V6iN19M[F`BEJEP4UFMF19EVE@BEIeH4UVUI0iM[G0BGK5d4
UfeN19M]H0BGKV44UfiR0iM_H`BHL6@4V75V19UcJ0BIM6T4VGAZ19YeJ`>JMf`4VWQ]19]jK`BLNg04
WGec19j0MP>OPgT4XHIm1:B;P`BUSHD4Y8^21:B:P@BTRX07YHZ01:J;P0BWS844Z8b21:V=P`>ZSh@4
Zi251:bAQPB]TXL4[Y>91:nERPB`UX/Eoooo000Doooo1;2ERPB_ThP4[I661:b?Q0BZSH43ZH]o1:R9
O@BVQgX4YHEh1:B2M@BRP7<3XGi`1:1lKPBNNF/4WGMY19aeIPBJLf<4VG1P0iQ^GPBGJe/4UFUH19EW
EPBEIUD4UFMF19IYF@>GJe`4UfaM19M]GPBGKF04UfiQ19M^HP>GKf<4V71T19QaIPBILfP4VGAY19Ud
JPBJMF/3VWM/19YhK@BKNVl4W7]`19emL`BNP7H3Wh=i1:66O@BTRh<4YHf51:B;PPBTRX44Y8Z01jF:
P0BVRh04Yhb11:R<PPBYSH<3ZXn41:^@Q@B/THH4[I:71:jCR@B_UHX4/9J;5Oooo`005?ooo`B`UHX4
[i>81:fAQPB/Sh@4ZXf10jV;O`BXRGd4YXMj1:F5N0BTPWD4XX1c0j5nL0BPO6h4WWU[19egJ@BLMFH4
VW=S19U`H0>HKUh4Uf]K19EYF0BEIeH4UFIE19EWEPBFJET3Uf]L19M/G@BGKEh4UfeP19M^H@BGKV83
UfmS19Q`I0BHLFH4VG=X19UdJ@BIM6X4VWE[0iYgK0BJN6d4VgY_19akL0BMOG<4WX1f0in3N@BQQWd4
Y8^31:F=Q@BTRh84Y8Z11:B:P0NURX04YX^01:N<P@BXS884ZHf30jZ?Q0B[T8D4[9661:fBQ`B^ThT4
[iF:1;2FRaGoool001Coool4/9F:1:jBQ`B]T8D4Zhj21:V;O`>XRGd4YXIj1:B4M`BSPG@4XGma1:1l
K`>NNV`4WGMY19]eIPBILV<4V6mO19I/G0BEJUT3TfMF199TDPB@H4h4SUe;18iKB0B@GT/4TV9B0i=T
E@BCIUH4TfIH19=WF@BCIeX4TfMK1i=XG0BCJ5d4TfUN19=[H0BDK644U6iR0iE_I0BELFH4UWAX19Mf
JPBHN6`4VWY_0ianM0BNPWP4X8Im1:27OPRQQW`4XHIk0j:6O0BSQg`4Y8Qm1:F9OPBVRh04Yhb10jR=
PPBZSX@4Zhn51:bAQPB]TXP4[iB:1;2FRaGoool001Coool4/9F:1:jBQ`B]T8D4Zhj21:V;O`>XRGd4
YXIj1:B4M`BSPG@4XGma1:1lK`>NNV`4WGMY19]eIPBILV<4V6mO19I/G0BEJUT3TfMF199TDPB@H4h4
SUe;18iKB0B@GT/4TV9B0i=TE@BCIUH4TfIH19=WF@BCIeX4TfMK1i=XG0BCJ5d4TfUN19=[H0BDK644
U6iR0iE_I0BELFH4UWAX19MfJPBHN6`4VWY_0ianM0BNPWP4X8Im1:27OPRQQW`4XHIk0j:6O0BSQg`4
Y8Qm1:F9OPBVRh04Yhb10jR=PPBZSX@4Zhn51:bAQPB]TXP4[iB:1;2FRaGoool001Coool4/9F:1:jB
Q`B]T8D4Zhj21:V;O`>XRGd4YXIj1:B4M`BSPG@4XGma1:1lK`>NNV`4WGMY19]eIPBILV<4V6mO19I/
G0BEJUT3TfMF199TDPB@H4h4SUe;18iKB0B@GT/4TV9B0i=TE@BCIUH4TfIH19=WF@BCIeX4TfMK1i=X
G0BCJ5d4TfUN19=[H0BDK644U6iR0iE_I0BELFH4UWAX19MfJPBHN6`4VWY_0ianM0BNPWP4X8Im1:27
OPRQQW`4XHIk0j:6O0BSQg`4Y8Qm1:F9OPBVRh04Yhb10jR=PPBZSX@4Zhn51:bAQPB]TXP4[iB:1;2F
RaGoool001Coool4/9F:1:jBQ`B]T8D4Zhj21:V;O`>XRGd4YXIj1:B4M`BSPG@4XGma1:1lK`>NNV`4
WGMY19]eIPBILV<4V6mO19I/G0BEJUT3TfMF199TDPB@H4h4SUe;18iKB0B@GT/4TV9B0i=TE@BCIUH4
TfIH19=WF@BCIeX4TfMK1i=XG0BCJ5d4TfUN19=[H0BDK644U6iR0iE_I0BELFH4UWAX19MfJPBHN6`4
VWY_0ianM0BNPWP4X8Im1:27OPRQQW`4XHIk0j:6O0BSQg`4Y8Qm1:F9OPBVRh04Yhb10jR=PPBZSX@4
Zhn51:bAQPB]TXP4[iB:1;2FRaGoool001Coool4/9B:1:jBQ`B/Sh<4ZXb01:R9O@>VQgX4Y8Ag1:>1
M0BQOW44Wg]^19eiJP>KMVL4VW=T19Q`H0BFKEd4U6YI19=VE@BAHe83Sf1>18eLB@B:F4D4QU4m18UD
@0B>FdP4See<0hmOC`B?H544Sf1B18iPDP^>H5<4SUmC18eOE0B=H5@4SF5F18eSF0B>IEX3SfQL18mZ
GPB@KF44TW1T19AcI`BFMFX3V7U^19YmLPBLP7H4W85f29f1MPBNPWL3Wh=h1:24N@BQQGX4XhMl1:B8
O@BURWl3Yh^11:R=PPBZSh@4Zi661:fBR0B^U8T4/9F;5Oooo`005?ooo`B`U8X4[Y:71:b?P`BZS804
Z8Um0jJ7NPBTQ7L4Xh5d1:5nL@BONfh4WGUZ0i]fI`BJLf@4V71P19I]G@BDJUT4TfIE195SDP>?H4h4
SEa918YHA@B6DCd4REA018iKB0B?GD`3Sem?18mPD@B?H584SV1B2hiPD`B>Ge<4SEmD18ePE0B=HEH4
SF=H18iUFP>?J5`4SfYN191]H@BBL6@4U7=W19IeJP>HNFh4VWeb19b0MPBLPGH8WH5f19j2M`>OPgP4
X8Ai1:65NPBSQg`4Y8Qm1:F:O`>WRh44Z8f21:Z?Q0B[THH4[I:81:jDR@B`UH/Eoooo000Doooo1;2D
RPB^TXL4[8n31:Z<P0BXRGd3YXMj1:B4M`BSPG@4XGia19mkKPBMNFX3VgIW19YcI0BHL604UVeM19AZ
F@BCIUD4TF=B0hmPCPB=G4T4RUQ518IA?@B9E404SU]818mMC0>?Gdl4Sf1A18mPDPB>H58;SV1C18iO
D`B=Ge@4SF1D18eQEPB=HeP4SVEJ0hmXG0B?JUh4T6eQ199`I0BDLfL4UWEZ0iQiKPBJOG84W81f19b1
MPRMPGH4WX9g0in3N0BPQ7T4XHEj1:>7O0BTR7d4YHYo0jN;P@BXSH84ZXn41:^AQPB]TXP4[YB91;2E
RaGoool001Coool4/9B:1:jBQ`B/Sh<4ZXb01:R9O@>VQgX4Y8Ag1:>1M0BQOW44Wg]^19eiJP>KMVL4
VW=T19Q`H0BFKEd4U6YI19=VE@BAHe83Sf1>18eLB@B:F4D4QU4m18UD@0B>FdP4See<0hmOC`B?H544
Sf1B18iPDP^>H5<4SUmC18eOE0B=H5@4SF5F18eSF0B>IEX3SfQL18mZGPB@KF44TW1T19AcI`BFMFX3
V7U^19YmLPBLP7H4W85f29f1MPBNPWL3Wh=h1:24N@BQQGX4XhMl1:B8O@BURWl3Yh^11:R=PPBZSh@4
Zi661:fBR0B^U8T4/9F;5Oooo`005?ooo`B_U8T4[I661:^=PPBYRWl4YhMk0jF4N0BSPG@4XGia19mk
K@BMN6X4VWEV0iQaHPBFKUl4U6]K19=WE`BAI5<4Sf5?18eMBP>;FDH4R5E118I@?0B4CCT4ReE118aH
A@B<FDP3ReY918]JBPR:FT/4RUY<18UJC@>9FD`4R5M;18QFBPB7ETX4QeM<18MJCPB8GE83RF5E18US
E`B;Ie/4SFYN18m]H@BAL6@3Tg9W19EeJ@BGN6d4V7U]19UjK`BJO704Vgea0iaoL`BMP7D4Wh9g1:24
N@BRQW/4Y8Qm0jF:O`BWS844ZHj31:Z@Q@B/TXL4[Y>91;2ERaGoool001Coool4[iB91:fAQPB[SH84
ZHYo1:N7N`>UQ7P4Xh5d1:5nL@BONfd4WGQZ19YeIP>HLF84UViO19A[F`BCIeL4TFAC18mQC`B=GDX3
ReU618QE@@B6D3`4Q4di18]E@@B<F4D4S5U80h]JB@B;FTX8RUY;18YJC0B9FTd3REU<18QGB`B8ETX4
QeI:18MGC0B7FTh4R5eB0hUQE@B9HeL4RfMK18eZGPB?KF44TG1T0i=bI`BEMFT4UgQ]19QiK@BINVl4
VWa`19]mL@>LOg<4WH1e19n2M`BPQ7T4XXIk1:B8O@>URWl4Yhb11:V>P`BZT8D4[9:71:jCR@B`UH/E
oooo000Doooo1:nDR@B]THH4Zhf21:V:O`BWQg/3YHAh1:>1M0BQOW44Wg]]19ehJPBJMFH3V75R19I^
G`BDJe/4TfMG195TD`B?HDl4SEe:0h]IAPB8ED44QU0l18A=>@B;ED44S5Q518aIB0>;FTT4ReY:28YJ
B`B:FT`4REY=0hUIC0B8Ed/4R5I:18MFBPB7Ed`4QeY>18QMDP>9HED4RF=G18]WF`B=JUh4SfeQ195`
I0>CLVL4UGEY19MhK@BHNFd4VGY_19YlL0BKOG43W7mc19f0M@BOPWL4X8Ai1::6N`BTR7d3YHYo1:N<
P@BYSX<4ZY251:bBQ`B^ThT4/9F;5Oooo`005?ooo`B_U8T4[I661:^=PPBYRWl4YhMk0jF4N0BSPG@4
XGia19mkK@BMN6X4VWEV0iQaHPBFKUl4U6]K19=WE`BAI5<4Sf5?18eMBP>;FDH4R5E118I@?0B4CCT4
ReE118aHA@B<FDP3ReY918]JBPR:FT/4RUY<18UJC@>9FD`4R5M;18QFBPB7ETX4QeM<18MJCPB8GE83
RF5E18USE`B;Ie/4SFYN18m]H@BAL6@3Tg9W19EeJ@BGN6d4V7U]19UjK`BJO704Vgea0iaoL`BMP7D4
Wh9g1:24N@BRQW/4Y8Qm0jF:O`BWS844ZHj31:Z@Q@B/TXL4[Y>91;2ERaGoool001Coool4[iB91:f@
Q@BZSH44Z8Um1:J6N@>SPWH4XGmb19mlKPBLN6X4VWEV19QaHP>FKEh4TfYJ195VE@B?HU44SEm=18]K
B0B9Ed@3Qe<o18E?>PB2BcD4RU<l191JA@B;ET<4REE30hQD@`B7E4<4QUA418EDA@B5DdD4Q5=50hAB
A@B3D4@4PTm4189@A0B2DDH4PU=8189FB`>3FDd4QEeA18IPE0B8I5P4RfMK18i[G`>?KF44TFmS199a
I0BCLF@4UGAW19IfJPBGN6`3VG]_19]mL@BLOg<4WX5f1:24N0BRQW/3Y8Qm1:J:O`BXS884ZXn41:bA
QPB^ThP4/9F;5Oooo`005?ooo`B_U8T4[I251:Z=P@BXRGd4YXIi0j>2MPBQOg84Wga^19ahJPBJMFH4
V75R0iI]GPBCJUX4TFIE18mRD@B=Gdd4Re]818UGA0>7Dcl4QDlj189;=@B:Dc`4T5Y518]F@`B9ED<3
R5A318MD@`B6E4@4QEA518ECA@B4DdD3Q59518=@A0B2Cd@4PU14189AAPB2DdP4PUI;0h=IC@B5GE44
QV1D18QTF0B;Ie/4SV]O0hm]H@BAKf<4TW5T19=aI0BEM6L4UWIZ19MhK0>INfl4Vgea19aoL`BNPGH4
X8Ah1::6N`>TR7d4YXYo1:R<PPBZSh@4[9661:jCR0B`UH/Eoooo000Doooo1:nDR@B]T8D4ZXf11:R9
O@BVQWT3Xh9f1:5oLPBOO6h4W7QZ19YeIPBHLF83UVeN19=ZFPBAIUD4Sf9A18eOC@B;FdP4REM40hMC
?`B5CcX4PT/e18YC?0B@FTD4ReI318UE@`>8E4<4QeA318IDA0B5E4D4QE=518ACA@>4DTD4Pe14189?
A0B2D4@4PU56189CB0B2ET/3PeU=18EMD@B6H5@4R6AH18]WF`B>Jel3SfeQ195_H`BBLF@4Tg5T19Ed
I`BFMVX4UgQ/0iUkK`BKOG44W7mc19j1MPBPQ7P4XXIk0jB8O@BVRWl4Z8b21:Z?Q0B/THH4[Y>81;2E
RaGoool001Coool4[iB91:f@Q@BZSH44Z8Um1:J6N@>SPWH4XGmb19mlKPBLN6X4VWEV19QaHP>FKEh4
TfYJ195VE@B?HU44SEm=18]KB0B9Ed@3Qe<o18E?>PB2BcD4RU<l191JA@B;ET<4REE30hQD@`B7E4<4
QUA418EDA@B5DdD4Q5=50hABA@B3D4@4PTm4189@A0B2DDH4PU=8189FB`>3FDd4QEeA18IPE0B8I5P4
RfMK18i[G`>?KF44TFmS199aI0BCLF@4UGAW19IfJPBGN6`3VG]_19]mL@BLOg<4WX5f1:24N0BRQW/3
Y8Qm1:J:O`BXS884ZXn41:bAQPB^ThP4/9F;5Oooo`005?ooo`B_ThT4[9241:Z<P0BWR7`4Y8Eh0j:1
M0BOOFl4WGU[19YeI`BHLF84UFeN0i=YF@B@IED4SV5@18aMB`B9FDL4QeE218EA?@>3CCP4OdH`18I=
=`B>Ed44ReA018QB?`B6DCh3Q4lm18=>?@B2CSd4PDhn181>?`B0CCl3Od/o17m9?PAnB3d4OTTn17i:
@0AnC484OU150giCB0B0Ed/4PU]?18AOD`B7HeH4RFII0h]XF`B=JE`4SFUK18m[G@B@KV04TW5T19Ad
I`>FMVX4V7U]19YlL0BLOg<4WX5f1:24N@>RQW/4Y8Un1:N;P0BYSX<4Zi251:fCR0B_UHXEoooo000D
oooo1:nCR@B/T8@4ZXb01:N8O0BTQGP3XX5d19mmK`BMNF/4VWEW19QaHPBEKEh3TfUI191UE@B>HE04
S5e;18UIA`B7ED84QE4m0h==>0AoAS04QTdg18iG@@B;E404R58o18IA?P>4Ccd4Pdhm189>?@B1CSh4
P4ho181=?`=oBcl4OdTn17i8?@AnBCh4OTY017i<@PAnD4D3OU=8181GB`B2Fdl4Q5mC18MSEPB9IUT3
RfQK18eYG0B=JE/4Sf]M191^H0BBLF@4U7AW0iIfJPBHNFd4VWa`19aoL`BNPGH4X8Ai0j:6N`BTRGh4
Yh^01:V>P`B[T8D4[I>81:nERQGoool001Coool4[i>91:b@Q0BZS804YhQl1:B5N0>RPG@4Wge_19ei
J`BJMFL4V75R19E]GP>CJET4T6EE18iQD0B<GD/4REU718ME@PB5DCd3Pddh17m6<0B6CCL4SUM118]D
@0B8DSl4QU4n0hA??@B3CSd4PThm185>?PB0CSl4P4do0gm;?`AoBCh4OTPm17i9?PAnBT04OTa217i@
A@=nDdP4P5M;189KC`B4Ge<4Qf=F18UVF@>;J5/4SFUL18eYF`B?Jed4T6iP199aI0BDM6L3UWIZ19Qi
K@BJO704W7mc19j1MPBPQ7T3XXIk1:B9OPBWRh04ZHj31:^@Q@B]ThP4[iF:5Oooo`005?ooo`B_ThT4
[9241:Z<P0BWR7`4Y8Eh0j:1M0BOOFl4WGU[19YeI`BHLF84UFeN0i=YF@B@IED4SV5@18aMB`B9FDL4
QeE218EA?@>3CCP4OdH`18I==`B>Ed44ReA018QB?`B6DCh3Q4lm18=>?@B2CSd4PDhn181>?`B0CCl3
Od/o17m9?PAnB3d4OTTn17i:@0AnC484OU150giCB0B0Ed/4PU]?18AOD`B7HeH4RFII0h]XF`B=JE`4
SFUK18m[G@B@KV04TW5T19AdI`>FMVX4V7U]19YlL0BLOg<4WX5f1:24N@>RQW/4Y8Un1:N;P0BYSX<4
Zi251:fCR0B_UHXEoooo000Doooo1:nCR0B/Sh@4ZH]o1:J7N`BSPgH3X7ia19ijK@BKMVP4V79S19E^
G`BCJUX3T6EE18eQD0B;GD/4R5Q618ED@@B3Cc/4P4/f0gm6<@B4Bc@4RU4k18Q@>PB6CcX4Q4hj189<
>@>0BSL4OTPg17e8=`AlB3P4O4Pi17]7>@=kAcX4NdPl17Y;?PAjC3l4NTi227U?@`=jCdD4Ne=817eH
B`B0G4l4PemC18EREP>8IEP4RFII18YWF@B;IUL4S6MH18i/GPB@Kf83TW9V19EfJ@BGNFd4VGa`19ao
L`BNPWL3XHEj1:>8O@BVRX04Z8f21:Z@Q@B]TXP4[iF:5Oooo`005?ooo`B_ThP4[8n41:V;O`BVQg/4
Xh=f0j1nL@BNNVd4VgIX19QbH`BEKUl4TfYJ0i1UE@B=HE04Ree;18QHAPB5E444Pdlk181;=P=oAS44
Q4/d18YA>`B8D3X4QTlj18A>>PB2C3T3P4Xg17i8=`AmB3L4O4Ph17a8>@AkAcT3NdLj17]8?0AjBch4
NT`o17Y>@PQiCd<3NTm517]CB0AmF4/4P5a?18=OD`B5HUH3R6EH18UVF@B:IeT4RfIG18aWF0B>K5h4
T6mR0i9bIPBEMVT4UgU]19UlL0BLOg<4WX9g0j65NPBSR7d4YXZ01:R=PPBZT8D4[I:81:nERQGoool0
01Coool4[i>81:b?Q0BYRgl4YXMk1:>3MP>POW44WWY]19]fJ0BHLV<4UFiO19=ZFP>@IED4SF5@18]M
B`B8F4H4QEA118=?>`B0BcH3OdHa18A;=0B:DC/4R50j18I?>PB4CSX4PT`i0h1:=`AnB3L4ODPg17a8
>0AlB3T4NdLi0g]7>PAkB3`4NT/n17Y<?`AjCT88NDm30gY?A@AkDdP4OEQ;181LC`B3Ge<4QF9F0hQU
F0B9IUT4RVMI18]VE`B<IeP4SVaN191_HP>BLVH4UGIY19MiK@BIO704W7mc19j2M`>QQGX4XhQm1:J:
P0BXSH84ZY251:fBR0B_UHXEoooo000Doooo1:jCR0B[SX<4Z8Yn1:F5N@BRPG@3Wga_19ahJPBILfD4
UVmP19=[F`B@IUH3SF5A18YMB`B7F4H4Q5=0185>>`AoBSD4O4D_0gTo:@AnA2`4PdXc18=;=@B2BcH4
P4Xf17i8=0=kAC84ND<b17Q3<`Ag@c@4MT<d17M4=P=gAST4Md/m17M?@PAgE4H4MeI817ICAPMeD4@4
Me9617UEB@AlF4`4Oea?189PDP>4HUD4QVAF18MTEPB8I5H4RFEF18YWF0B<Jed3SfiQ195bIPBDMVX4
UgU]19YmL@BMP7D3Wh=h1::6N`BURGh4Yhb11:Z?Q0B/TXL4[iB:5Oooo`005?ooo`B^ThP4Zhj31:R:
OPBUQGT4XX5d0imlK`BLN6X4VG=U19I_H0BCJe/4T6IF0heQD@B:GD/4QeQ618AC@0B1CS/4OdXe17a5
;`=i?bT4OT@/18=:<`B3BcD4PT/f181:=PAnB3@3NdDb17U3<PAh@c<4Md<d17I3=0AgA3H3MdHi17M;
?@AgCd84MeA617MFB0AfDdH7ME1417MBAPAiEDT4O5Q<17mLC`B2H583Q69E18ITEPB7I5H4R6AF18UU
EPB:IeP4S6]M0hm^H@BALVH4U7IZ19MiK@BJOG44WH1e0in3N0BRQW/4YHUn1:N<P@BZSh@4[9:71:nD
RQGoool001Coool4[Y>81:^>P`BXRWh4YHEi1::1M0>OO6l4W7QZ19UcI@BFKf04Tf]K191VEP>=HE44
RUe;18MHAPB4Dd04PDhk17m:=@AlABl3NClY17i4;0B3BS<4Pd/e189;=PB0BSH4OTPd0g]5<PAi@c84
N4<c17M3=0Af@c@4Md@f0gM6>@AgBcd4Mdm217MDAPAgETP4MU=61gE@A0AgDTH4NEE917aHC0AoG4l4
PV1B0hARE@B6I5H4QfAF18QTEPB9IEH4RVMH18a[G@>?KV44TG9V19AfJPBGNFd4VWea19f0M@>OPgP4
XXIk1:F9OPBWS844ZXn41:bBQ`B_U8XEoooo000Doooo1:jCR0B[SX<4Z8Yn1:F5N@BRPG@3Wga_19ah
JPBILfD4UVmP19=[F`B@IUH3SF5A18YMB`B7F4H4Q5=0185>>`AoBSD4O4D_0gTo:@AnA2`4PdXc18=;
=@B2BcH4P4Xf17i8=0=kAC84ND<b17Q3<`Ag@c@4MT<d17M4=P=gAST4Md/m17M?@PAgE4H4MeI817IC
APMeD4@4Me9617UEB@AlF4`4Oea?189PDP>4HUD4QVAF18MTEPB8I5H4RFEF18YWF0B<Jed3SfiQ195b
IPBDMVX4UgU]19YmL@BMP7D3Wh=h1::6N`BURGh4Yhb11:Z?Q0B/TXL4[iB:5Oooo`005?ooo`B^TXL4
Zhj21:N9O@BTQ7L4XGmb0iejK@BJMVP4Ug5R19A/G@B@IeL4SF9B0hYNC0B7FDL4Q5=1185>>`AnBCD4
NT@_17Ln:0=l@BT4PdTa1858<PAoB3<4OTPd17a7=0AjA343Md4^17@n;@Ac?Rl4LSh`170n<@AcAcT3
MTm117MDAPAhF4`4N5M;17EDA`AcETP4LUM:0g5DA`AbDD@4ME9617QFB@AlFTd4OeeA0h5QD`B3HU@8
Q69D18EQDPB6HU<4R6IH0h]ZG@B>KV84TG=W19EgJ`BHNfl4Vgic0ij2M`BQQGX4Y8Qm1:J;P@BYSX@4
[9671:nDRQGoool001Coool4[Y:71:^>PPBWRGd4Y8Ag1:5oLP>MNVd4VWIX19MaHPBDK5d4T6MG18eR
DP>:GT`4QeU718AC@@B1CS/4OTTe17Y4;`Ag?RP3O44Y18=9<@B1B384OdPc17i8=0AlAc@4NT@a0gM1
;PAd?Rd4Lch_178n<0A`?S44LdLi0gI?@@AgE4H4N5Q<17QGB`AeE4L4LeI8179GBP=aE4L4LU5417EB
APAhETT4O5Y=17mMD@>1HE<4Pf9D28ARE0B5HE84QV9C18QVF0>;JUd4SViR195cI`BEMf/4V7]_19]n
L`>NPWL4XHEj1:B8O@BVRh44ZHj41:bAQ`B_U8XEoooo000Doooo1:jBQ`B[SX84YhUm1:B4M`BQOg83
WGY]19YfJ0BGLF84U6aM191WE`B=HU83RUi<18MIA`B4Dd44PDhk17i9=@AjA2l4MchX0ga1:@B3BC44
PDPb17m8<`AnB3@4O4Ld17Y4<@=g@Bh4M3h]17<n;`Ab?S04L3ha17=7>@=fCd44MeA617QHC0AhEd/4
MEA717=FB0AbEdX3LEA7179AA0AeDTH4N5I917aJC@AoGE43PF5C18=RE0R4HU@4QF5B18IRD`B8IUP3
RfYM18i^HPBALfL4UGM[19QkK`BKOW<3WX9g1:65NPBTR7d4YX^11:V>Q0B/THL4[iB:5Oooo`005?oo
o`B^TXL4Zhj21:N9O@BTQ7L4XGmb0iejK@BJMVP4Ug5R19A/G@B@IeL4SF9B0hYNC0B7FDL4Q5=1185>
>`AnBCD4NT@_17Ln:0=l@BT4PdTa1858<PAoB3<4OTPd17a7=0AjA343Md4^17@n;@Ac?Rl4LSh`170n
<@AcAcT3MTm117MDAPAhF4`4N5M;17EDA`AcETP4LUM:0g5DA`AbDD@4ME9617QFB@AlFTd4OeeA0h5Q
D`B3HU@8Q69D18EQDPB6HU<4R6IH0h]ZG@B>KV84TG=W19EgJ`BHNfl4Vgic0ij2M`BQQGX4Y8Qm1:J;
P@BYSX@4[9671:nDRQGoool001Coool4[Y:71:Z=P@BVQg`4Xh9f19mnL@>LNF/4V7=U19E^G`BAJEX4
SVAD18]OCP>7FTP4Q5A2185??0AmBCD4ND@_17Ho:@Ac>R@3NT4Y1817<0AnAc44ODHa17]5<PAiA344
Md8`0g@o;PAa?Rh4KS`]1713=0AfD484NEI80gMFB@AfEdX8MEI817EJC@AfFTh4M5U=0g9EB@A_DdH4
LE9517EDB0AiF4`4O5a?0giNDPB0H5<4P61B185ODPB1H584PV5D18=RE@>7IUT4Rf]O18m`I0BBMFT4
UWU]19UmL@>LP7D4X8Ai1:>7O0BVRh04ZHj31:bAQPB_U8XEoooo000Doooo1:jBQ`BZSH44YXMl1:>2
MPBOOW43W7U[19QcI@BEKUl4TFUJ18iTE0B;Gdh3QeY818AD@PB1Cc`4ODTe17U4;`Af?bT4LcXT0gY1
:@B0Ac04OTLa17e6<@AkAC84ND@a17M2<0=d?bh4LCh^16hl;@A`@c@4MU1217UFB0=gETT4MUM:27EF
B0AeFTd4MUY>17AIC@=bEDT4Ke=6175BA@AeE4P4NEQ<17aLC`=nGU84P61C181PDPB1Ge84PF1B189Q
E0B3HUD3QfII18][G`B?L6@4TWEY19IiK@BIOG43W81e1:24N@BSQg`4YX^01:V>P`B/THH4[iB:5Ooo
o`005?ooo`B^TXL4ZXf11:J7O0BSPWH4Wgia0iaiJ`BHLfD4UFiO195YFPB>I5@4Rem>0hMJB0B4E484
PDll17e9=@AiA2l4MSlY17<j90=j@BT4P4L`17i7<@AmAS44NdDb17U4<@Ag@S03M3l^174n;PA^?2d4
L4<d17I@@PAiETP3MeI917IGBPQeETP4MEY=17IJCPAdFDd3LUE916mCAPAaDTD4MEA817UHC0AlG4l3
OUiB181PD`B0H584PEmB185PDPB2HE@4Pf9E0hMVF@B;Jel4Sg1T199eJ@BFNFd4VGea0ib0M@BPQ7T4
XhMl1:J;P0BYSX<4[9661:nDRQGoool001Coool4[Y:71:Z=P@BVQg`4Xh9f19mnL@>LNF/4V7=U19E^
G`BAJEX4SVAD18]OCP>7FTP4Q5A2185??0AmBCD4ND@_17Ho:@Ac>R@3NT4Y1817<0AnAc44ODHa17]5
<PAiA344Md8`0g@o;PAa?Rh4KS`]1713=0AfD484NEI80gMFB@AfEdX8MEI817EJC@AfFTh4M5U=0g9E
B@A_DdH4LE9517EDB0AiF4`4O5a?0giNDPB0H5<4P61B185ODPB1H584PV5D18=RE@>7IUT4Rf]O18m`
I0BBMFT4UWU]19UmL@>LP7D4X8Ai1:>7O0BVRh04ZHj31:bAQPB_U8XEoooo000Doooo1:fBQ`BZS844
YXMk1::2M@BNO6l3VWIY19IaH`BCK5d4SfIG18aQD0B8FdX3QEI4185A?PAmBcL4ND@`17Dn:0Ab>B<4
LcTR0ga2:`AmABh4O4D`17Y5<@AiAC84MT<a17A1<0=a@S04LD<c1797=`AfC3`4MTdm17A=?@=cCSl4
LThn175=?@A`CCh4L4i0175?@@AcDT@3MEI917IIC0AcEDX4LU9717EEB@AiFDd3Nee@17aND@AmGU48
OUi@17mND0B0Ge03Pf9E18MXG0B<KV84T7=W19AgK0BHNg03Vgmd19j3N0BRQg`4YHYo1:R=P`B[THH4
[YB95Oooo`005?ooo`B]TXL4ZXb11:J7N`BRPWD4WWa_0iYfJ@BFLF<4TfaM18mVE`B<HE04R5]:0hEF
A0B1DCh4OD/g17U4<0Ae?RP4LSTS17<i8P=l@R/4ODD^17a5<0AjAC44NDDb17I3<@Ad@C03LD8`1753
<`AbAcL4MT`l17I=?@AdCCd3Ldho179>?PAaCCd4L4dn171>@0AaCd44Le940gEFB@AfFD`4LeE:179B
A`AeEDT4NEU=0g]MD0AlGU44OEiA27iND0AoGU04P5m@0h=RE@B7J5`4S6iR191cI`BDMf`4V7]`0i]o
M0BNPgP4XXMl1:F:O`BXSH<4Zi661:jDRAGoool001Coool4[I:71:Z<P@BVQg/4XX9e19ilK`>JMVT4
UW5S19=/G@B?IUL4S65@18QKBP>5ET@4PE4n17e;=`AiA304MChX178i8`Ac>B83O48[17e5;PAlAC04
NTDa17U5<PAf@c44M44`0g52<0Aa@c<4LTLg17I<?0AfCCd4M4dm0g=>?`AbCSh4LDdm171=?PA`CT04
LDm117=BA0=eETT4MUU<17=EBPAbDTL4MEE917UIC@=kGE04O5iA17eND@QnGU04Oei@181OD0>3HUD4
QfQL18a^HPB@LfL4U7M/19QkL0>KOg@4WX=h1::7O0BURWl4Z8f31:^AQPB^U8TEoooo000Doooo1:fB
Q`BZS844YXMk1::2M@BNO6l3VWIY19IaH`BCK5d4SfIG18aQD0B8FdX3QEI4185A?PAmBcL4ND@`17Dn
:0Ab>B<4LcTR0ga2:`AmABh4O4D`17Y5<@AiAC84MT<a17A1<0=a@S04LD<c1797=`AfC3`4MTdm17A=
?@=cCSl4LThn175=?@A`CCh4L4i0175?@@AcDT@3MEI917IIC0AcEDX4LU9717EEB@AiFDd3Nee@17aN
D@AmGU48OUi@17mND0B0Ge03Pf9E18MXG0B<KV84T7=W19AgK0BHNg03Vgmd19j3N0BRQg`4YHYo1:R=
P`B[THH4[YB95Oooo`005?ooo`B]THH4ZHb01:F6NPBPP7<4W7Y]0iQdIPBDKV04T6UJ18eSD`B9GTd4
QEQ70h9C@@AoCCX4NdLc17I0:`A^=Ql4Jc0I17Hk8`>0Ac04O4D`17U3;`Ag@c04MD<a17A3<@Ab@c83
LdLg17I?@0AiEdL4NUQ817EB@`AbCSl3L4`l16i8>@A]AcT4K4Li16a7>0A]B3T4KTdn0g1?@@AcDTH4
MEE917=DB0AdE4T4MeQ<0gQJCPAiFdh4NU]?17YLC`AkGE04O5e?17mOD@>2HUD4QVMJ18Y/H0B?LFD4
TgIZ19IjK`>JOW<4WH9g1:66N`BTRGl4Z8f21:^@QPB^U8TEoooo000Doooo1:fAQPBYS804YHIj1:20
L`BLNVd3V7AV19A^H0B@JEX4SF=C18UNC@B5F4L3PU=117m=>PAkAc<4MT0[16hf7`A[<1T4MS/S0h17
<0AlAC04ND<_17M3<0Ae@c44M4<a1793<P=cAcL4MTm017UGA`AjF4P4ME93179>?`=`C3`4KTPi16e7
>@A/AcT4K4Lh16e8>@A^CCh3L4m117=BAPAeEDT4LeA817ADB@AgF4`3N5Y>17UKCPAjFdl4NUa?17]M
D0AlGDl4OemA0h9RE@B6IeX4RVaP18maI@BCMVX4UWY_0iYnL`BMPWL4XHIk1:B9O`BXSH84Zi261:jD
RAGoool001Coool4[I661:V<P0BUQWX4X81c19ajK@>HM6H4U6iP191YFPB=He<4REi=18EHA`>2Dd44
Oddj17]7<`Af@2/4KSHO16/`6@Af>b<3P4L`17a5<0Ai@bl4Md<`17E3<@Ad@c44LT<b0g=7=`AfCd04
NEM717YHB0AeDT<4LTho0g1<?0A^B3T4KDLi16a7>@A/AcP4KDPi16i=?P=`Cd44Le9617EEB@AcE4P4
M5A917MHC0=hFTh4NE]>17YKC`AjG4l4Nee@17aMC`AoGe43PV9E18IWFPB:K604Sg5U19=fJPBFNVl3
VWic19f2M`BQQW/4Y8Uo1:R=PPB[T8H4[YB95Oooo`005?ooo`B]THH4Z8]o1:B5N@BOOW84VgQ[0iIb
I0BBK5d4SVIG18YPD0B6FTX4PeE30gm??@AlBSL4ND@`17Dn:@A`>284MC`U17i6;`=nAc44NT@`17M3
<0Ad@c44LT<b1752<PA`@c<3L4Hf175;?0AcCd44LU53175B@PA`DD83KU1116e>?`A/CSh4Jdhn16]@
@0A[D444K4m10fi>@@A`DD@4LeA617EGBPAfF4`4MEQ<1gIIC@AgFTh4N5Y>17QKCPAiFTh4MUM:0gaM
D0B4IeT4RF]O18e`I@BAMFX4UGU^0iUmLPBLPGL4X8Ej1:B9OPBWSH84Zi261:jDRAGoool001Coool4
[I661:R;O`BTQGT4Wgib19]hJ`>FLV@4TVaM18iVE`B:H504QUY:18=E@`=oCcd4O4Xg17U4<0Ae?RT4
L3PR17Dl9@AnARl3OTLa17Y4<0Ag@c04M4<a1793<PAa@S84L4<c0g16=PAaBc`4Ldm1179A@`AaDT84
L5520fi@@@A]CSl4K4hn16]>?PA[D404Je1116a?@@=^CT44L55417=DAPAeEdX4MUQ<17EHC0MfFDd4
MeY>17QJCPAhFdh4NEY>17IGBP=lGE04Q6MI18U[G`B=L6D4TGEZ19EiKP>IOG84W85g1:25NPBTRGh4
Yhf21:^@QPB^U8TEoooo000Doooo1:fAQPBXRgl4Y8Ei19mnLPBKN6/3UW9T199/G@B>IUL4RV1@18IJ
BPB3ED<3Odlm17a:=`AiA304MChY170h8PAe?2D4OTH_0gi7<@AjA304Md<`17A3<@Ab@c84LD8b1713
<`=`ASH4LD/l17=?@@AbDD<4LE92171A@P=^D444KDho16a>?PA[CSh4Je1016]@@@A/Cd43KTi1171A
A0AcE4H4MEM:17IHC0AeF4`7MUU=17MJCPAhFTh4N5]>17UJCPAfEdX3O5e@18AWF@B9Jel4SG1U195e
JPBENFh3VGeb19b1M`BPQGX4Y8Un1:N=PPB[T8H4[YB95Oooo`005?ooo`B]THH4Z8]o1:B5N@BOOW84
VgQ[0iIbI0BBK5d4SVIG18YPD0B6FTX4PeE30gm??@AlBSL4ND@`17Dn:@A`>284MC`U17i6;`=nAc44
NT@`17M3<0Ad@c44LT<b1752<PA`@c<3L4Hf175;?0AcCd44LU53175B@PA`DD83KU1116e>?`A/CSh4
Jdhn16]@@0A[D444K4m10fi>@@A`DD@4LeA617EGBPAfF4`4MEQ<1gIIC@AgFTh4N5Y>17QKCPAiFTh4
MUM:0gaMD0B4IeT4RF]O18e`I@BAMFX4UGU^0iUmLPBLPGL4X8Ej1:B9OPBWSH84Zi261:jDRAGoool0
01Coool4[I661:R:O`BSPgL4WWe`19UfJ@>EL684T6YK18aSE0B7GDd4PeM6181A?`=mC3T4NTHc17Q2
;PAg@2/4ODD^18I==@B2Bc@3NTD`17I3;`Ac@c44LD<b1713<PA^A3<4KDDe0fe6=`A^B3T4KDTj16e;
?0A/C3d4Jd/m0fY;?0AYBC`4IdTk16M:>`AVBS`4Id`n16M=?`=YD484K5E6171JC0AeGe84Mf5D17IN
DP=dFTh8M5U>17EJCPAfFTh4MUY?17MKD0=mHED4PVII18Q/H0B<L6@4T7AY19AiKP>HOG84W85f19n5
NPBSRGh4Yhb21:Z@Q@B^U8TEoooo000Doooo1:fAQPBXRWl4Xh=g19imL0BIMVT3UG1R191ZF`B<He@4
Qee=18=GAPB0DCl3OD`i17Y6<`Ah@Rh4Md0[17e5;PB6CCD4PT/d0gY5<0Af@bl4Ld<a1753<PA`@c84
KT@c16e5=@=]ASL4KTPi16e9>PA]Bc`4K4`m16];?@=ZBc`4JDTl16M9>`AWBS/4ITXl16M<?PAWCCl3
JE1216aEAPA`FT`4MEmB17MQE0AfGU83M5Y>27AICPAeFTh4MUY>17IJC`AgFe03OF5E189VF@B8K604
S71T191dJ@BDNFh3V7eb19b1MPBOQGX4XhUn1:N<PPBZT8D4[YB95Oooo`005?ooo`B]THH4Z8Yo1:>3
M`BNOG04VGIY0iE`HPB@JU/4S6=D18MMC@B3EdH4P54o0ge<>@AjAS<4N48^17M0:`AmABh4QTde189;
=0=jAC04MT<_17=3<@Aa@c84L4<b16i4<`A]ACD3KDHg16i8>@A]BCX4KD/l16a<?@A[Bcd3JT/l16U9
?0AWBC/4IdXk16I:?0AWC3h4Iddo0fU@@PA/EDH4L5Y<17EODPAgHE@4MUiB0gAJCPQdFDh4MEY>17IJ
CPAfFTl4Me]@0geQE@B2IUT4R6aP18a`I0B@M6T4U7U^0iQmLPBLPGH4WhEj1:>9OPBWS884ZY251:jD
RAGoool001Coool4[I661:R:O`BSPgL4WWe`19UfJ@>EL684T6YK18aSE0B7GDd4PeM6181A?`=mC3T4
NTHc17Q2;PAg@2/4ODD^18I==@B2Bc@3NTD`17I3;`Ac@c44LD<b1713<PA^A3<4KDDe0fe6=`A^B3T4
KDTj16e;?0A/C3d4Jd/m0fY;?0AYBC`4IdTk16M:>`AVBS`4Id`n16M=?`=YD484K5E6171JC0AeGe84
Mf5D17INDP=dFTh8M5U>17EJCPAfFTh4MUY?17MKD0=mHED4PVII18Q/H0B<L6@4T7AY19AiKP>HOG84
W85f19n5NPBSRGh4Yhb21:Z@Q@B^U8TEoooo000Doooo1:b@Q@BWRGh4XX9f19ekK`BGMFL3TViP18iW
F0B9H544QEY:181C@PAmCC/3NDLe17I2;`Ae?bT4MCdU17Po9`Ai@R`4Md<^0gA1;@Aa@2h4Kd4`16e2
<@A/@c<4Jd8c16Y3=0=ZA3H4JD@e16Q4=@AXASL4IdLi16I7>@=UASP4I4Hh16=6>0ARACL4HTHh1697
>PASBCd3IDa016Q@@`A/EDP4KeU<175KC`AcG503LU]@279HCPAcF4h8M5Y?17AJD0=mHUL4PVML18I[
G`B;Kf@4SgAY19=hK@>GO784Vh1f19n4NPBRR7h4YXb21:Z@Q@B^ThTEoooo000Doooo1:b@Q@BWRGh4
XX9f19ekK`BGMFL3TViP18iWF0B9H544QEY:181C@PAmCC/3NDLe17I2;`Ae?bT4MCdU17Po9`Ai@R`4
Md<^0gA1;@Aa@2h4Kd4`16e2<@A/@c<4Jd8c16Y3=0=ZA3H4JD@e16Q4=@AXASL4IdLi16I7>@=UASP4
I4Hh16=6>0ARACL4HTHh1697>PASBCd3IDa016Q@@`A/EDP4KeU<175KC`AcG503LU]@279HCPAcF4h8
M5Y?17AJD0=mHUL4PVML18I[G`B;Kf@4SgAY19=hK@>GO784Vh1f19n4NPBRR7h4YXb21:Z@Q@B^ThTE
oooo000Doooo1:b@Q@BWRGh4XX9f19ekK`BGMFL3TViP18iWF0B9H544QEY:181C@PAmCC/3NDLe17I2
;`Ae?bT4MCdU17Po9`Ai@R`4Md<^0gA1;@Aa@2h4Kd4`16e2<@A/@c<4Jd8c16Y3=0=ZA3H4JD@e16Q4
=@AXASL4IdLi16I7>@=UASP4I4Hh16=6>0ARACL4HTHh1697>PASBCd3IDa016Q@@`A/EDP4KeU<175K
C`AcG503LU]@279HCPAcF4h8M5Y?17AJD0=mHUL4PVML18I[G`B;Kf@4SgAY19=hK@>GO784Vh1f19n4
NPBRR7h4YXb21:Z@Q@B^ThTEoooo000Doooo1:b@Q@BWRGh4XX9f19ekK`BGMFL3TViP18iWF0B9H544
QEY:181C@PAmCC/3NDLe17I2;`Ae?bT4MCdU17Po9`Ai@R`4Md<^0gA1;@Aa@2h4Kd4`16e2<@A/@c<4
Jd8c16Y3=0=ZA3H4JD@e16Q4=@AXASL4IdLi16I7>@=UASP4I4Hh16=6>0ARACL4HTHh1697>PASBCd3
IDa016Q@@`A/EDP4KeU<175KC`AcG503LU]@279HCPAcF4h8M5Y?17AJD0=mHUL4PVML18I[G`B;Kf@4
SgAY19=hK@>GO784Vh1f19n4NPBRR7h4YXb21:Z@Q@B^ThTEoooo000Doooo1:b@Q@BVR7d4XH5e19]j
K@BFLfD3T6]N18]TEPB6GDh4PEI617e??`AiBCL3MD<`178m:PA`>B@4KcHP16lg8@A_=b84KSXV0fhl
:PA]?B`4Jch^16To;`AX?c04Icla16I0<P=V@C<4IT8d16E2<`AT@C@4Hd8d1691=0=Q@C@4H48d15m2
=@QN@SH4GT@h1657>`=SBSl4ITm416UCB0A/Ed/4KUU>16mJC`=_F4l8KeM>175IC`AcFU08M5]A0gaQ
E@B0IEP4QFYN18Y_I0B>M6T4TWQ]0iIlL@BJP7H4WXAj1::8OPBVS844ZY251:jCRAGoool001Coool4
[9251:J8O@BQPGD4VgY]19IcI@>@Jeh4RfAF18IMCPB1ETH4ODlo17U9=`=e@c04LSdZ170i90A_=R04
KcLQ16lg8PA^>RH3KS`Z16dm;0A[?Rh4JCl_16Po<0AW?c44IT0b0fI1<`AV@S@4ID8c16A1=0AS@S@4
HT4d0f51=0AP@S@4Gd8e25i2=PANA3P4HDLk0f=:?`AVCd@4JE=816aGB`A^FDh4KeY?0fmHC`Q_Edh4
LEU?17=JD0QdFe43O65E181UF0B5JUh4RVmT18idJ@BBN6d3UWaa19Z0MPBNQ7X4XXQn1:J<P@BZT8D4
[Y>95Oooo`005?ooo`B/T8D4YXQm1:61M@BKNVd4UW=U0i1[GPB;I5H4QUe>185FAPAmCcl4NDTg0gE3
<0Ab?BX4L3TT16lf80A_=b44KcLR16hj9P=^?2X4KCd/16/n;PAY?bl4J3l`16Lo<@AV@383IT4c16I2
=0AU@S<4I44d16=2=0AR@C@3HD4d1612=0AO@SD8GT8f15i4>0AQAc/3HdXo16I?A0AYDdP4K5M;16iI
CPA_FTl3KeQ?26mGCPAaFDl4LeY@27AKD@=lHED4P6EH18EZGPB:Kf@4SWAY199hK@>FO744VX1f19j4
NPBRR7h4YXb11:Z@Q@B^ThTEoooo000Doooo1:b@Q@BVR7d4XH5e19]jK@BFLfD3T6]N18]TEPB6GDh4
PEI617e??`AiBCL3MD<`178m:PA`>B@4KcHP16lg8@A_=b84KSXV0fhl:PA]?B`4Jch^16To;`AX?c04
Icla16I0<P=V@C<4IT8d16E2<`AT@C@4Hd8d1691=0=Q@C@4H48d15m2=@QN@SH4GT@h1657>`=SBSl4
ITm416UCB0A/Ed/4KUU>16mJC`=_F4l8KeM>175IC`AcFU08M5]A0gaQE@B0IEP4QFYN18Y_I0B>M6T4
TWQ]0iIlL@BJP7H4WXAj1::8OPBVS844ZY251:jCRAGoool001Coool4Zhn41:F8O0BOP7@4VWQ/19A`
H`>>JE/4R65C18=JB`AnDT84ND/j17E4<`=a?R/4KCPT16/b7@AY<1X4J30L16Pb7`AY=R<3JSPV16Pi
:@AV>RX4I3/[16<k;0AR>bd4HSd^0f4n<0AQ?c44H3ha15ln<@AO?c84GSlb0ee0<`AL?c<4Fcld15]0
=0AK@CH4G4<i15e5>`=PBCh4HTe316IAB0AYED`4K5Q?16aID0=[Edh4K5I>16eGC`A`FE04LU]A17EM
D`AgGU<3O61D17mSE`B5JEh4RFmT18edJ@BAN6d3UGab19V0MPBMQ7X4XHQm1:F<P@BYShD4[I>95Ooo
o`005?ooo`B[Sh@4YHQl19n0M0BJN6`4U71S0hiYF`B8HE<4PeY;17iB@PAiBcX4MD@c0g4n:`A]>2@4
Jc8M16T`6PAX<1`4J38O16Tf8`=Z>2H4J3TY16Hj:PAT>b/4Hc//168k;@AR?Bh3HCh`164o<@AP?S44
Gcha15lo<PAN?c83GD0c15`o<`AK?c@4Fd0d15]1=PAL@cT4GDDk0f19?PARCD<4IU5816UEC0A/F4l4
K5U@0f]GCPA/ETh4KEM?171ID0AbFe44MEeC17MND`=lH5@4Of=G18EYGPB9Kf@4SGAY195hK@>EO784
VH1f19f4NPBQR7d4YHb11:V?Q@B]ThTEoooo000Doooo1:^?Q0BUR7`4Wh1d19YhK0BDL6<3SVUK18QQ
D`B3FT/4OU9217U;>PAeA3<3LCh[16dh90A[<Qd4JC0J16P`70AX<Ql4JCHS0fXh9PAX>BT4ISXZ16@k
:`AS>b`4HS/]168m;P=Q?S04HCla160n<@AO?S44Gclb15ho<P=M@3<4G3lc15/o=0AK@3@4Fd4f15a3
>@AMAC/3H4Tn169=@`AVDDP4JEE<16aHC`A/FE03JeM>16aFCPA]Edl4L5U@179KD@AeGE<4MeiC0gaP
E0AoHeL4QFUN18U_I0B=M6T4TGQ]0iElLPBIP7H4WHAj1:68O@BUS844ZHn51:fCRAGoool001Coool4
Zhn41:F8O0BOP7@4VWQ/19A`H`>>JE/4R65C18=JB`AnDT84ND/j17E4<`=a?R/4KCPT16/b7@AY<1X4
J30L16Pb7`AY=R<3JSPV16Pi:@AV>RX4I3/[16<k;0AR>bd4HSd^0f4n<0AQ?c44H3ha15ln<@AO?c84
GSlb0ee0<`AL?c<4Fcld15]0=0AK@CH4G4<i15e5>`=PBCh4HTe316IAB0AYED`4K5Q?16aID0=[Edh4
K5I>16eGC`A`FE04LU]A17EMD`AgGU<3O61D17mSE`B5JEh4RFmT18edJ@BAN6d3UGab19V0MPBMQ7X4
XHQm1:F<P@BYShD4[I>95Oooo`005?ooo`B[Sh@4YHMk19ioL`BHMfX4TViQ0h]VF@B5GU04P5I717Y>
?`AeAcH4L3l^0f/h9@AX<Ah4IB`G168Y5@AQ:AH4HRlL16@c8P=T=B@4HSLV164f9`AP=bP4GSLX15dg
:@AM>2X3G3T/15`j;PQK?2l8FS/_0eTk<0AH>c04Ec/`15Hk<0AF?C<4Ed0f15U3>P=LAch4Gd]2169>
APAUDT/;IeE=16UEC@AZETh4KEQ@175KDPAfGeH4OVAJ0hAYG@B2IU/4Q6UN18U`IPB=M6X4TGQ^0iAl
LPBHP7H4WH=j1:67O@BURh44ZHn51:fCRAGoool001Coool4Zhn41:F7N`BNOg<4V7MZ199^H@>;IUT4
QEi@181FA`AjCSl4MDLf170o;P=[>2D4J34N16D/5`AR:AD4HBTF168_70AT<b83I3DT168g9PAQ=RL4
H3LX15hg:0AM=bT4GCPZ0e`i;0AL>Rh8Fc`_25Xk;`=I>c04F3/`15Lk<0AF>c04ESdc15M0=PAI@cX3
G4Ln15m;@PARCTH4IE9;2fMEC@AYEDd4JUI>16eHD0AaFe84MUmF17iTFP>4JEd4PVIK18AYGPB9L6H4
SGAZ195hKP>DO784V81f19f3NPBQQgd4YH^11:V?Q@B]ThTEoooo000Doooo1:^?Q0BUQg/4WWmc19Qg
JPBBKV43RfII18END0B0ETL4NTho17E7=PA`?bh3JcPU16Pa7PAU;1L4HRTE164Y5PAR;a`4I3<R0f@e
90AR=bH4HCHW160g:0AN=bP4GCLY15dh:P=L>B`4G3X^25/l;`QJ>bl3FC/`15Pk<0AG>c04ES/`15Hm
<`AG@3H4FD<j0ea7?PAOBd84HTi616EBB`]WEDd4JEE=16YFCPA]F504LE]B17IOEPAnI5X3Q6UM189V
F`B4JEh4RG1V18edJPBAN6h3U7ab19R0MPBMPgX4XHMm1:F;P@BYShD4[I>95Oooo`005?ooo`B[Sh@4
Y8Ik19emLPBFMFT4SfaO0hUTEPB2Fdd4O5=417I:>`A`@S84JSXY0fDb80AQ:AH4GB<?15/P3PAK9A@4
GBdL15ha80=N<b84GC<S15`b8`AK<R<4FC4S15Pb90AG<RD3Ec<W15Lf:PAG>2d4EcT^15Li;@ME=b`4
E3H/158f;0AB=bd4DST`15<l<`AE@3L3Ed<k15Y8@@ANCDD4H518165@B@ARD4T3He5916EABPAWDd`4
JeI>16mID@AdGED4Nf=J0h=[HPB;MF/4SGE/18YbJ0B<M6/4T7Q^0i=kLPBHOgH4W8=j1:27O@BTRh44
ZHn51:fCRAGoool001Coool4Zhn41:B6N`BMOG84UWEY18m/G`>9I5H4PU]=17aCA0AfBS/4L48b16Xj
:@=U<R04HBTF15dS3`AK80h4FbDD15d]70AN<B03GS<R15dc8`AL<R<4Fc8S15Ta8`AH<R@4Ec8U0eLc
9`AG=RX4EcP]15Li;PAG>Bd7ECL/15@f;0AB=R`4DSL]158i<0AC?3<4ED0g0eM3>`AJB444GTe5161@
B0AQD4T4HU190f=AB@AUDDX4Ie=<16]FCPA_FE44M5eE17]SFP>3Jf84RgE[18eeK0B:LVP4S7A[191h
KP>CNg84V7mf19b3NPBPQgd4Y8^11:V?Q@B]ThTEoooo000Doooo1:^?Q0BTQW/4WGeb19IeJ@B?K5l3
RFAF189KC@AlDd@4MTXk1712<PAZ>RT3IC8P164Y5PAM8`l4Fb0>15/U50AM;A`4GS4P0ehc8PAM<b<4
G38S15/b8`AI<B<4F38T15Lb9@=G<bL4EcHZ15Lh;@AG>Bh4EcT]1eDg;0AD=R`4DSH/158g;@AB>C04
Dc`c15E0=`=G@c/4FTQ115i=A@APD4P4HE19169@B@=SDDT4IE5:16MCC0A[ETh4KeUA17AME@AkHeX3
Pf]R18]eJ`B=MF`4RW9X18adJ`B@N6h3Tg]b19QoMPBLPgX4X8Mm1:B;P@BYShD4[I>95Oooo`005?oo
o`B[Sh@4Y8Ik19emLPBFMFT4SfaO0hUTEPB2Fdd4O5=417I:>`A`@S84JSXY0fDb80AQ:AH4GB<?15/P
3PAK9A@4GBdL15ha80=N<b84GC<S15`b8`AK<R<4FC4S15Pb90AG<RD3Ec<W15Lf:PAG>2d4EcT^15Li
;@ME=b`4E3H/158f;0AB=bd4DST`15<l<`AE@3L3Ed<k15Y8@@ANCDD4H518165@B@ARD4T3He5916EA
BPAWDd`4JeI>16mID@AdGED4Nf=J0h=[HPB;MF/4SGE/18YbJ0B<M6/4T7Q^0i=kLPBHOgH4W8=j1:27
O@BTRh44ZHn51:fCRAGoool001Coool4ZXj31:>5NPBLO744U7=W18eZGP>6HE@4OeQ:17Q?@@AaASL4
Jcd]16Dd8`=O;1X4FR@A15HP3PAE8A04EbLF15T[6`AJ;Qh3FBlP15P_80AG;R04ERdO15@/7`AC;1l4
DR`P0e8^8PAB<2D4DS8X15<d:PAB=B/4DSH/0e4f;0A@=B/4CcD[14he;@A>=bl4CcXb154m=P=D@S`4
F4M115Y:A0AKBdD4G4a515a<AP=NCDL4H4i816=@BPAWDdd4JeI@16mKE0AeGeL3O6IM189]I0B5KfH4
Qg5X18YdJPB>Mfh3TW]b19MoMPBKPgX4WhMm1:B;P@BXShD4[I>95Oooo`005?ooo`BZSX<4XhEj19al
L@BDLfL4SFYN0hIQE0AoF4X4N4m11756=`A[?Bd4IC@S0el/6PAJ9144ER0>15DQ40AG9aH4FB/K15X^
7P=I;b04F2lP15L^80AF;Al4E2`O15</7`AB;203DRhR158`9@AB<RP4Dc@Z158e:`AB=R`3DCH/150e
:`A?=B/4CSD]14hg;`A?>S84DCdf0eA2?0AHAd44FTY415];A@ALC4D4G4a60ei=A`APCTP4He1:16MC
C@A[EU04Ke]D17EOE`=lIUd4PVeT18E_IPB7LFP4RWAZ18igKP>BNg84Ugmf19^3NPBOQgd4Y8^11:R?
Q@B]ThTEoooo000Doooo1:Z>P`BSQGX4W7aa19AcI`B=JUh3QV5D17mHBPAhCd44LDHg16/m;@AU=2<3
Gb`J15XT4@AF80h4EB4@15LW5PAI:a/4FRhN0eT_80AH;b04EbhP15H]7`AD;1l4Db`O158/80=B;R84
DS0U158b:0AC=2X4DSD[158f;0=A=R`4D3D[14le:`A>=Bd4CSL_14lj<PAA?CH3E48l15Q7@@AJBT@4
Fd]515a<A@ALC4H3GTe7161>B0ASD4X4Ie==16]FD0A_Fe@4MEmG0gaVG@B2KF@4QFmV18MaJ0B:M6X4
SWM^0i9kLPBGOgH4Vh=j19n7O@BTRh44Z8n51:fCRAGoool001Coool4ZXj31:>5NPBLO744U7=W18eZ
GP>6HE@4OeQ:17Q?@@AaASL4Jcd]16Dd8`=O;1X4FR@A15HP3PAE8A04EbLF15T[6`AJ;Qh3FBlP15P_
80AG;R04ERdO15@/7`AC;1l4DR`P0e8^8PAB<2D4DS8X15<d:PAB=B/4DSH/0e4f;0A@=B/4CcD[14he
;@A>=bl4CcXb154m=P=D@S`4F4M115Y:A0AKBdD4G4a515a<AP=NCDL4H4i816=@BPAWDdd4JeI@16mK
E0AeGeL3O6IM189]I0B5KfH4Qg5X18YdJPB>Mfh3TW]b19MoMPBKPgX4WhMm1:B;P@BXShD4[I>95Ooo
o`005?ooo`BZSX<4XXAi19YkL0BCLVH4RfQL0h=ODPAlEDP4M4/m16e2<`AV>2T4GRlN0ePU4`AB7P`4
CQd;14dP3`AA9AD4E2TJ15D[70=E:ad4E2/M158Z70AA:1/4CbLJ14dV6PA<9Q/3C2PM14`Z80A=;B<4
CRlV14ha9`A><RT3CC<Z14`b:PA;<RX4Bc</14/f;`A=>C84Ccdf0e51>PAC@cd4E4@o15E6@0AFAT44
EdM20eU9@`AKBdD4GTe8165@BPAUE4h4JeQA171LE@=fHEX4NVEM17mXH0B4KVD4R79Z18afKP>ANg84
UWmf19Z3NPBOQgh4Y8^11:R?Q@B]ThTEoooo000Doooo1:Z>P`BRQ7T4VW]`19=bIPB;J5`3PemB17aE
B0AdBcd4KD8c16Hh:@AN;ah3F2DC158N30A>7@/4CB0?154U5@AD:AX4EB/L0eD[7@AD:ad4DRXL154X
6`A?9aX4CBHJ14`V6`=<:1d4C2XP14d]8`A>;bH4CS4W14hb:@==<bX4C38Z14/b:PA;<b`4BcH_14di
<PA??CH3DD4j15=3?@ADA3l4EDI015I6@@AGAd83FDU315];A@ANCDP4HE1:16EDCPA[F544L5aE0gIQ
FPAjIEd4OfQP18A^I@B8LVX4S7I^0i5kLPBFOgH4VX=j19n7OPBTRh44Z8n51:fCRAGoool001Coool4
ZXj31::4N@BJNg04Tg9V18]XG0>3Ge84O5E817A;?@A]@S<4ISPY15h_7P=H9A<4DQh<14hM2`A=80l4
DBDE15@Y6PAE:a`3EB/M15@[7@AB:Q`4DBPK14lW6PA=9QX4C2HK0d`X7@A<:R04CBdS14h_9PA><BL4
CS8Y0ddc:PA<<RX4Bc8Z14/c;0A;=Rl4CCTb14lm=P=A@CX4Dd<m15A4?`AEAT04ETI115M7@P=IBD<4
Fd]515i=B0AQD4X4IEA>16]HD@A`G5D3MV5J17YUG@AoJ604Q6iU18QbJPB<MVh3TG]b19IoMPBJPgX4
WhMn1:B;P@BXShD4[I>95Oooo`005?ooo`BZSX<4XXAi19YkL0BCLVH4RfQL0h=ODPAlEDP4M4/m16e2
<`AV>2T4GRlN0ePU4`AB7P`4CQd;14dP3`AA9AD4E2TJ15D[70=E:ad4E2/M158Z70AA:1/4CbLJ14dV
6PA<9Q/3C2PM14`Z80A=;B<4CRlV14ha9`A><RT3CC<Z14`b:PA;<RX4Bc</14/f;`A=>C84Ccdf0e51
>PAC@cd4E4@o15E6@0AFAT44EdM20eU9@`AKBdD4GTe8165@BPAUE4h4JeQA171LE@=fHEX4NVEM17mX
H0B4KVD4R79Z18afKP>ANg84UWmf19Z3NPBOQgh4Y8^11:R?Q@B]ThTEoooo000Doooo1:V=P`BQQ7T4
VGY_195`I0B9IUX3P5a?17QBA@A`B3X4J3h`160d9@AH:AX3D1h=14LF1@A250@4A1T;14/R4`A?9aP7
D2PJ14lW6PA>9aT4C2DH14XT5`A88QL4AR8G0dHS6@A79Qd4B2TP14T/8`A:;RD4BRlW0dXa:@A9<BT4
B38Z14Pb:`A8=2h4BCLa14/j=0==?3L4CChj14ho>`A>@3/4Cd4m1553?`=CAD44ETQ415U;A`ALCTT4
HE1<16ECCPAYETl3Ke]D17EOE`AkIEd4PFaT18IaJ@B;MVh3T7Yb19AnMPBIPgX4WXMn1:>;PPBXShD4
[I>95Oooo`005?ooo`BYSH<4XHAi19UjK`BAL6@4RFIJ0h1LC`AhDTD4L4Pj16Pn<0AP=2D4F2TJ0e0N
3@A75PD4@Q@414@I2`A;8Q<4CbLH1e0X6PA?9aX4CRLI14`U60A:91L4B28G14HR5`=68aT4AbHM14PY
80A9;2<4BRhU14X_9`=:<BT4BC4Y14Pb:PA8<R/4B3@^14Tg<@A;>S@3CC`g14dn>PA>?c/4CT0k14m1
?@AA@cl3DdE115I8A0AIBdL4G4i9165@C0AUDdh4JEI?0fmKE0AeGeL4NfEM185/I0B6LFT4RgI^0i1j
LPBDOWH4VH=j19j7OPBSRh84Z8n51:fCRAGoool001Coool4ZHf31:64N@BINVl4TG1T18UVFP>0G4l4
N5951718>PAX?S04H3@U15PY6P=@7Pd4AaH5148D10A46@/4Bb8C14lW60M@:1X4CbLJ14hW6@A<9AP4
BR@G14PR5`A68QL3AR<I14LV7@A8:B04BB`S14X^9@A:;bL3BS4Y14Ta:@A8<RX4B38[14Pd;PA9=c44
BcXd0ddl=`A=?SX4CSlk14i0>`A?@Cd4DD<o0e=5@@AFB4@4FD]715a>B@AQD4`4IE=>16UFC`=_Fe@4
MEmG17]UG@B1K6@4QW5Y18]fKP>@NW84U7if19V3NPBNQgh4Xh^21:R?Q@B]ThTEoooo000Doooo1:V=
P`BQQ7T4VGY_195`I0B9IUX3P5a?17QBA@A`B3X4J3h`160d9@AH:AX3D1h=14LF1@A250@4A1T;14/R
4`A?9aP7D2PJ14lW6PA>9aT4C2DH14XT5`A88QL4AR8G0dHS6@A79Qd4B2TP14T/8`A:;RD4BRlW0dXa
:@A9<BT4B38Z14Pb:`A8=2h4BCLa14/j=0==?3L4CChj14ho>`A>@3/4Cd4m1553?`=CAD44ETQ415U;
A`ALCTT4HE1<16ECCPAYETl3Ke]D17EOE`AkIEd4PFaT18IaJ@B;MVh3T7Yb19AnMPBIPgX4WXMn1:>;
PPBXShD4[I>95Oooo`005?ooo`BYSH84X8=h19QiKPB?Kf<4QVAH0geJC@AeCd84K4@g16<i;0AK;b44
DR@F0dTJ2`A04PD4?A<6140H2`A67a84Bb@G1ddV6@A<9QT4BR@H14LS5`A58AL4@b0F1d4O5PA181P4
@b@K14DX7`A7:b<4B2hV0dP_:0A7;bP4ABlY14@`:PA5<R`4AC@^14Hf<@=7>3@4AcTe14Lj=PA8>SL4
BC`h14/n>P==@Cd4D4A015A7A0AHBTL4Fde915m@B`ASDdd3JEMA171LEPAhIUl4OV]T18=`J@B9MFh3
SWYb19=nMPBHPWX4WXMn1:>;PPBXShD4[I>95Oooo`005?ooo`BYSH84X8=h19QiKPB?Kf<4QVAH0geJ
C@AeCd84K4@g16<i;0AK;b44DR@F0dTJ2`A04PD4?A<6140H2`A67a84Bb@G1ddV6@A<9QT4BR@H14LS
5`A58AL4@b0F1d4O5PA181P4@b@K14DX7`A7:b<4B2hV0dP_:0A7;bP4ABlY14@`:PA5<R`4AC@^14Hf
<@=7>3@4AcTe14Lj=PA8>SL4BC`h14/n>P==@Cd4D4A015A7A0AHBTL4Fde915m@B`ASDdd3JEMA171L
EPAhIUl4OV]T18=`J@B9MFh3SWYb19=nMPBHPWX4WXMn1:>;PPBXShD4[I>95Oooo`005?ooo`BYSH84
X8=h19QiKPB?Kf<4QVAH0geJC@AeCd84K4@g16<i;0AK;b44DR@F0dTJ2`A04PD4?A<6140H2`A67a84
Bb@G1ddV6@A<9QT4BR@H14LS5`A58AL4@b0F1d4O5PA181P4@b@K14DX7`A7:b<4B2hV0dP_:0A7;bP4
ABlY14@`:PA5<R`4AC@^14Hf<@=7>3@4AcTe14Lj=PA8>SL4BC`h14/n>P==@Cd4D4A015A7A0AHBTL4
Fde915m@B`ASDdd3JEMA171LEPAhIUl4OV]T18=`J@B9MFh3SWYb19=nMPBHPWX4WXMn1:>;PPBXShD4
[I>95Oooo`005?ooo`BYSH84X89h19MhK@B=KF84Q69G0g]GB`AaC404Id0d15he:0AE:Qd4C20B0dDH
2`A05P/4?QH;140J3PA78AD4BR@H14XU60=;9QX4BRDJ14LS60A381D4?a`B13/I40@i6A03>Q/C13dN
5PA08AX4@RDM14DZ8PA6;BL3ARlY14D_:PA3<2X4@S0Z148a:`A2<Rh4@S<_0d4d<0A0=344@CDb148g
=0A3>3H4AS/i0dTn?0A<@Sl4CdA215=7A@AFBdP4FTe:15e?B`=RDTl4JeYF17AUH0AkJfD4PG1Z18Me
KP>=NG84TWif19R2NPBMQgh4XX^21:N?QPB/ThTEoooo000Doooo1:V=PPBPPWP4UgQ]18e]HPB4HUL3
NeM;175<@0AW@3@4GSDX15DZ7@A<8183AAP;140F2`@n5P/4@1X>14LQ5@A:91P4BRDH0d/V6PA:9AX4
Ab<H14<P5@@o7184>aT@13TI40<j6a<4?AhF140Q6PA29Ad4ABXR14H]9`=6;bT4ABlZ14<`:PA2<2X4
@S4[148b;PA2<bl3@C@`140d<@A1=C84@SLd14<h=PA6>cT3BChl14a2?`A?A484DdM515I;B0AJCDX4
GDm;0f9BC`A[FUH4M6EP17][I@B1L6X4QgE^0heiLPBBOWH4V89j19f7OPBRRh84Yhn61:bCRAGoool0
01Coool4ZHf21:22N0BGN6d4SFeR18ARE`=kEd/4LDa016M0=0AN=BP4EBXM14`P4P=560/4@1H;13hF
2`A06Ph4Ab4E14XT60A:9AP3BbHJ14XU6PA78aP4@b0E13lL4P@k6A04>AT@0cXK4`@m7QH4@24J148U
7@A5:R84ARdW0dH_:@A5;bX4@c0Z148`:PA2<B/4@S8^148c;`=1=304@3@a144e<PA2=c@4@cPf14Hk
>@=9?S`4C48o14m4@PACAdD4ET]815Y=BPAMCd/3HU9?16]JEPAdIF04Nf]U185`JPB7MFh3SGUb199n
MPBHPWX4WHMn1::;PPBWShH4[9>95Oooo`005?ooo`BYSH84X89h19MhK@B=KF84Q69G0g]GB`AaC404
Id0d15he:0AE:Qd4C20B0dDH2`A05P/4?QH;140J3PA78AD4BR@H14XU60=;9QX4BRDJ14LS60A381D4
?a`B13/I40@i6A03>Q/C13dN5PA08AX4@RDM14DZ8PA6;BL3ARlY14D_:PA3<2X4@S0Z148a:`A2<Rh4
@S<_0d4d<0A0=344@CDb148g=0A3>3H4AS/i0dTn?0A<@Sl4CdA215=7A@AFBdP4FTe:15e?B`=RDTl4
JeYF17AUH0AkJfD4PG1Z18MeKP>=NG84TWif19R2NPBMQgh4XX^21:N?QPB/ThTEoooo000Doooo1:R=
PPBOPWL4UWM/18a/H@B2HEH3N5E:16e9?@AS?C44F30T14hU60A66Pd3?a@813LA1`@g4`X4?Q/@14LS
5`A99AX4BRHK0dXW70A99a`4AbHL14@T6`A08AT4?1hG13PL5@<h7AD4?20H13hR6`A19Ah4A2XT14D_
:@=5<B/4A34[148`:`A1<2/4?c4/13h`;@@n<Bh3?S8`13db<0@l<C04?38`13hd<PA1>3H3AC/i14Pn
?@A;@D04CDE31558APAEBdT4FDi<0f5ED`AZGEX4LVIR17U[IPAoL6X4QWE_0haiL`BAOWL4Uh9k19f7
OPBRRh84Yhn61:bCRAGoool001Coool4Z8f219n2M`BFMf`4S6aQ189QEP=hEDX4KDTm16<m<@AH<2@4
CRDH14HJ3@<o50P4=a4713LC2P@n6a04Ab<G14TU6PA:9Q/3BRLL14TW70A79Q`4A2@K140Q6@@l7QL4
>1`E0cPM5@@l81P4?R8K144U7PA4:R@4ABlY0dDa:`A4<B/4@S0[144`:`@o<B`4?S0]13ha;P<n<S04
?C8`13`a<0@l<S04?S@b144h=P=5>cT4B3hm14]1@0A=AD<4DDQ615E;B@AICT`3HEEC16YMFPAbIV84
NF]V17m`JPB6MFl3S7Uc195nM`BGPW/4WHMn1::;PPBWShH4[9>95Oooo`005?ooo`BXSH84Wh9g19Ig
K0B<K644PV5F0gQEBPA]BCd4Hcda15P`90A>9AP4AQX=0clD20@g4@L4=a<:13hK40A78aL4BBDJ14XV
6`=:9a`4BBLL14LV70A491/4@24I13`N5`@h71D3>1dE13`P60@n8Q/4@BDN14@Z90A5;bT3AC4[14@a
:`A2<2/4@C0[13la;0@n<2d4?S4^0chb<0@m<S04?34`13`b<0@n=384@CPf0dDk>@A8?Sd4Bd5014e5
@`AAB4H4ED]915U>C0=QEE<4JUeJ179VHPAiJfH4Og1Z18IeK`><NG<4TGig19N2N`BMQgh4XX^21:N?
QPB/ThTEoooo000Doooo1:R=PPBOPWL4UWM/18a/H@B2HEH3N5E:16e9?@AS?C44F30T14hU60A66Pd3
?a@813LA1`@g4`X4?Q/@14LS5`A99AX4BRHK0dXW70A99a`4AbHL14@T6`A08AT4?1hG13PL5@<h7AD4
?20H13hR6`A19Ah4A2XT14D_:@=5<B/4A34[148`:`A1<2/4?c4/13h`;@@n<Bh3?S8`13db<0@l<C04
?38`13hd<PA1>3H3AC/i14Pn?@A;@D04CDE31558APAEBdT4FDi<0f5ED`AZGEX4LVIR17U[IPAoL6X4
QWE_0haiL`BAOWL4Uh9k19f7OPBRRh84Yhn61:bCRAGoool001Coool4Z8b219j1M`BEMf`4Rf]Q181P
E@=fE4T4JTLk15hi;PAB:al4AahB13lE2@<j4PL4>1@:13`J40A27aD4BBHK14XX7@A::1h3BBPO14TX
80A8:B44B2XS14T/9@A6:b@4A2TR0d@Z8`A4;2H4ARlY14Xe;PA:=S04Ac@_0dDc;`A3<Rh4@C4]13l`
;@@n;bd4>bd/13X^;@<h;R`4=B`[13@[:`@f;Rd4>C4a13de=0=1>3L4AC`k14Q0?`A;@d84CDE514m7
A`ACBd/3G5AC16MOG@A`IfD4Mf]X17i`J`B4MFl3RgUc195nM`BGPg/4W8Mo1::;PPBWShH4[9>95Ooo
o`005?ooo`BXS884WX5g19EgK0B;Jf44P61E0gIDB@AZAc/4GST^158[7`A77Q84?aD90cXB1`@h50X4
?1X@148O5@A99Q/4BRPM14XX7P=9:1l4BBPP14PY8@A8:R<4BB`U14H[90A4:B83A2XS14@/9PA6;bT4
BSD^14Xf<0A7=2l3AC<_14<b;PA1<Bd4?c0]13h_;@@k;B`4>Rh]0cP^;0@e;2/4=2/[13H^;@@i<C44
?CDd0d4h=`A5?3/4B40o14]3@PA=ADD4CdM715=;B`=LE5<4IemM171WI@AgJfP4OW1[18AeK`>;NG<4
TGig19N3N`BLQgl4XX^21:N?QPB/ThTEoooo000Doooo1:R<PPBNPGL4UGM/18][H@B0H5D3MUA916Y7
>`AN>Bh4DR/O14LN4P@o5@T3>Q8713PD2P@l6Q04@QlE14TV6`A::1d4BRPN0dTX7`A9:204B2TQ14PZ
8`A9;2D4AR/T14@Y8P=4:R<4A2`V14H_:@A:=Bh4BSH`14Ld;`=5<bl4@c8^144a;@@o<2d4?Rl]13/]
;0@j;Rd3>2h/13D/:`@d:b/4=Rh]13Ta<@@m=C@3@CPg14Dl>`A8@3l4Bd=214e5A@A?AdL4Dd];0eaD
D`AWGed4L6MU17M[J0AnL6/4Q7E_0h]iL`BAOWL4Uh=k19b7O`BRRh84Yhn61:bCRAGoool001Coool4
Z8b219j1M`BEMf`4Rf]Q181PE@=fE4T4JTLk15hi;PAB:al4AahB13lE2@<j4PL4>1@:13`J40A27aD4
BBHK14XX7@A::1h3BBPO14TX80A8:B44B2XS14T/9@A6:b@4A2TR0d@Z8`A4;2H4ARlY14Xe;PA:=S04
Ac@_0dDc;`A3<Rh4@C4]13l`;@@n;bd4>bd/13X^;@<h;R`4=B`[13@[:`@f;Rd4>C4a13de=0=1>3L4
AC`k14Q0?`A;@d84CDE514m7A`ACBd/3G5AC16MOG@A`IfD4Mf]X17i`J`B4MFl3RgUc195nM`BGPg/4
W8Mo1::;PPBWShH4[9>95Oooo`005?ooo`BXS844WX5g19AfK0B:Jf44OemE0gACB0AWACX4FSH[14/T
6P@i40D4<`X00c@@1P@f5@`4?1/C14<R6@A::Ah4BbTP14XZ8@=::R84B2XR14P[90A9;RP4BS0Z14dc
;@AB>C83E3/d15<k=0AA>cD4CS/f14/i=0A8=S83AC@`14<b;`A1<Bl4@38`140c<PA0=C@4?SHf0cLa
<P@a;2h4<b`^23H_<@@j<S<3?SHg14<k>`A6?cl4B49314Y4A@A:ADH4CDU:0eMAD@ASG5/4KFIT17EZ
I`AlKf/4PgE`0hYjM0B@OWP4UX=l19b7O`BRRh<4Yhn61:bCRQGoool001Coool4Z8b119j1M`BDMV`4
RV]Q17mOE@=dDdP4IdDj15Xf:`A;91X4>A0513<:00<d40H4=QD<13`K4`A38QT4BRTN14/Y80A::R43
BRXR14PZ8PA8:b@4BBhX14X`:PA=<bd4DSTb0e@k=0AC>c@4DC/e14hk=PA;>C@4B3Hb0dDd<0A3<Rl4
@C4_140b<0A0<c84@3Dd13hf=P<g<C84<B`^13</;PPf;c44>S8c0chf=`A3>c/4ASlo14Q2@`A:A4D4
BTE614e9BP=GDE44HeaK16eVI0AeJVL4O6m[18=eL0>:NW@4T7ih19J3O0BLQgl4XX^31:N?QPB/ThXE
oooo000Doooo1:R<P@BNPGL4U7I/18Y[H@AoGeD3M5=816M5>PAJ=R/4Bb@J13T@1@@c2P03=10613HE
30@l6a<4@b8I14XY7PA;:B04BRXQ0dXZ8PA8:R84B2/T14T^:0A:<2X4CC<]158i<P=D>c@4Dc/d154k
=@A>>cH4BcTd14Pf<P=5=304@c8_144a;`A0<S04@3<b140e=0@n=SH3=c4b134/;P@c;2h8=Rla13Xb
<`<n=SL4@c/k14Ho?`A8@T<4BTA514Y5APA=BDX3Ee5A16=LF`A]IV@4MFYW17a_J`B3MG03RWYd191n
N0BFPg`4W8Mo1::;P`BWShH4[9>:5Oooo`005?ooo`BXS844WX5g19AfK0B:Jf44OemE0gACB0AWACX4
FSH[14/T6P@i40D4<`X00c@@1P@f5@`4?1/C14<R6@A::Ah4BbTP14XZ8@=::R84B2XR14P[90A9;RP4
BS0Z14dc;@AB>C83E3/d15<k=0AA>cD4CS/f14/i=0A8=S83AC@`14<b;`A1<Bl4@38`140c<PA0=C@4
?SHf0cLa<P@a;2h4<b`^23H_<@@j<S<3?SHg14<k>`A6?cl4B49314Y4A@A:ADH4CDU:0eMAD@ASG5/4
KFIT17EZI`AlKf/4PgE`0hYjM0B@OWP4UX=l19b7O`BRRh<4Yhn61:bCRQGoool001Coool4Z8f219j2
N0BDMfd4RFaR17mPEP=cDdT4ITDk15Le:`A47Q@4=a88138?1`<]30D4<18;13XK4`A59A/4CB`R14`/
8`A<;2D3BR/T14T[9@A9;BL4BC0[14Xc;`A<=S84CcPd0e0l=`AB?SX4D3hj14hm>PA;>cP4B3Pe0dDe
<`A3<c44@C<b140d<`A0=SD4@SPg14<j>P=3>ST4@CTi144i>PA0>CX4@CTk14@l?@=5?Sl4Ad5214I2
@`A7@T@4Ad=514E3A@A:AdX3EU1A165IF@AZHV44LfUW17]_K0B2MG03RGYe191oN@BFQ7d4W8R01::<
Q0BWT8L4[9>:5Oooo`005?ooo`BXSH84WX9h19AgK@B9K684Of1F0g=CB@AVAC/4EcD[14@N50@g4PP4
<Pl70bd<1@@`4P/4>Q/C14DU6`A=;284C2`S14`/9@=::b@4BB/U14T]9`A9<2/4BS<_14`f<PA?>3@3
D3`g158n>PA@?SX4CSdj14/k>0A8>3D3ACDc14<c<@A1<c84@3@c140f=@A2>3L4@cXj0d<j>@A1>CT4
@CTj140i>PA1>C/4A3`m0dDn?`A7@D84AT9314M2A0A7@dD4AD=514Y7BP=FD544HEUI16YRH@AcJFL4
Nfm/189eL0>9NWD4T7mi19J4O@BLR804XXb41:N@Q`B/ThXEoooo000Doooo1:R=PPBNPWP4U7M]18U/
HPAoH5H3Le=916I5>`AG=B/4A1hD13LB20@b3`L3;@`5130B2`@j6a<4ABDK14d/8PA<;2<4C2`U0dX[
90A9:bD4BBdW14T`:`A:<bl4C3Hb14lh=0=@?3L4DShj150n>PA>?CX4Bc/h14Ph=@=5=C<4@c<a144c
<PA0=3<4@3He148h=`A3>SX3@cXi144i>@A1>CX4@3Tj144i>`A4?3d3ACho14M1@PA6@T<4Ad9414M3
A@A5@dD4BTM:0eI@D@AQFET4JV9Q17=YI`AkKf`4PWE`0hUjM@B@OgT4UXAm19b8P0BRS8@4Yi271:bC
RQGoool001Coool4Z8f219j2N0BDMfd4RFaR17mPEP=cDdT4ITDk15Le:`A47Q@4=a88138?1`<]30D4
<18;13XK4`A59A/4CB`R14`/8`A<;2D3BR/T14T[9@A9;BL4BC0[14Xc;`A<=S84CcPd0e0l=`AB?SX4
D3hj14hm>PA;>cP4B3Pe0dDe<`A3<c44@C<b140d<`A0=SD4@SPg14<j>P=3>ST4@CTi144i>PA0>CX4
@CTk14@l?@=5?Sl4Ad5214I2@`A7@T@4Ad=514E3A@A:AdX3EU1A165IF@AZHV44LfUW17]_K0B2MG03
RGYe191oN@BFQ7d4W8R01::<Q0BWT8L4[9>:5Oooo`005?ooo`BXSH<4WX=i19AhKPB:K6<4Of5G0g=D
B`AWAch4FCP_14XX7`A28AP4?AhE0cPL50@h71D4@B<J14TZ8@A?;bH4CRlW14d`:0==<R/4C3<^14T`
:`A7;bX4Ac0]14Lc<0A9=S@3BSTg14`k>@A<?3X4Bcdk14Xl>`A7>CP3ACHd148d<`A1=3@4@3De140e
=`A0=cP4@CXj0d<l?@A9@T84CdM624e5A@A=ATH3BTE614M3APA5@TH4AD=614A2APA3@dL4BdU<0eIB
E0AQFU/4JF=R179YI`AjKf`4PWEa0hUkMPB@P7X4UhAn19b9P@BRS8@4Yi271:bDRQGoool001Coool4
Z8f319j3N@BDN6h4RVaS17mQE`=cE4/4IdLn15Th;`A::1l4@R4H13dN5@<h71@4>1`E144S6PA9:R44
CblV14h_9`A=<2P3CC8[14`c;PA9<2/4AblZ14L`;@A7<c04BCHd0dXi=`A<>cT4C3`j14/m>`A:?3/4
AcTh0dDf=0A2=3<4@C@d140e=@A0=CL4@3Lh144j>P=3?3d4BD9214m7APQ=ADD4CDI60dY5APA7@dH4
AD9614E3APA4@TH4@d=714]9C0=FDU@4HEYK16USHPAbJFL4NVm/189eL@>9NgH4T81j19N4OPBLRH44
XXb41:N@Q`B/U8XEoooo000Doooo1:R=P`BNPgT4U7Q^18Y/H`AoHEL3LeA;16M7?PAI>2l4BRPO148Q
60@m7QD3>1`D13PL5@A18aX4BBXQ14l_9PA>;bL4CC0X0ddb:`A<<bh4BC0[14L_:PA7<2d4Ac<`14Tf
=0=:>CL4C3/i14`l>PA;?C/4BS`k14Li>0=5=S@4@S@c144d=0A0=CD4@3Dg140g>0A1>SX3@c`m14U2
@PA?AdH8CDE514e6AP=:ADH4Ad=614E2APA5@dH4A49614=3A`A;BD`3EU9D165JF`AYHf84LVUW17Y_
K0B2MG43RG]f1920NPBGQ7h4W8V11::<Q0BWT8L4[9B:5Oooo`005?ooo`BXSH<4WX=i19AhK`B:KV@4
P69I0gAGCPAYBT84G3he14la:0A8:R<4@bHO0d4U7PA39Ql4AbXR14`_9`A@<RX4Cc4Z14hc;0=>=Bl4
CSLc14lk=`A??3T4CS`k1550?`ADAD<3EDM615A7APABAdH4CdA414/o?PA7>SX3A3Hf144e=@A0=SH4
@3Hh13he>@@m=CT4?SLj0d0j?0A4?Cl4B49314Y5A`A;AdT4BTI90dI4B0A5@TP4@d571491APA0@4H4
@D9714Y:C`=IEUP4HUeN16QSH`A`J6L4NW1]189fL`>:O7P4TH5l19N6O`BMRX84XXf51:RAR0B]U8XE
oooo000Doooo1:R=P`BNPgT4U7Q_18Y^I0B0HUT3M5M>16U:@PAL?SD4Cc4X14PZ8`A39Ql3@BDN14<V
7`A7:R84C2lW150b:PA?<BX4CS</0dhe;`A>=c<4Cc/g14ll>@A>?3/4DD0o15A5@`=EAdH4E4M61597
APA?A4@4Bcln14Lj>P=4=SH4@CDe140f=PA0=SP4?SDi13de>@@n=cX3@3Xl14@m?`A8@T<4BTE714]7
B@A:ATT3ATA814E2B0A3@DL4@T561410APA1@TL4BTY?0eUFF0ARGEh4J6=S171XI`AjL6d4PWIc0hYl
N0BAPG`4UhIo19f:PPBRSHD4Z9681:fDRQGoool001Coool4Z8f319j3N@BDN6l4RViT181RF@=dEdh4
JDY215`n=@A?<BP4B2XS14<V7`=19Ah4@bHO14LZ8PA<;bL4D38Z14la:PA><b`3CSD_14hg<`A?>cL4
Cc`i14hl>`AA@3l4E4E30eE7APADAdH4DTM614m4A0A;?ch4AcXj0d@f=PA1=CD4@3Hf140f>0@n=CT4
?CDi13hg>P=0>S`4A3do14Q2@`A:ADL4BdM914Y6B@=6A4P4AD9814=1A`A2@DH4@4161452A`A:BTl3
FEIH169MGPAXHf<4L6QW17Y`K@B2MW<3RWah1961O0BGQWl4WHZ21::=Q@BXTHP4[IB:5Oooo`005?oo
o`BXSH<4WX=i19AhK`B:KV@4P69I0gAGCPAYBT84G3he14la:0A8:R<4@bHO0d4U7PA39Ql4AbXR14`_
9`A@<RX4Cc4Z14hc;0=>=Bl4CSLc14lk=`A??3T4CS`k1550?`ADAD<3EDM615A7APABAdH4CdA414/o
?PA7>SX3A3Hf144e=@A0=SH4@3Hh13he>@@m=CT4?SLj0d0j?0A4?Cl4B49314Y5A`A;AdT4BTI90dI4
B0A5@TP4@d571491APA0@4H4@D9714Y:C`=IEUP4HUeN16QSH`A`J6L4NW1]189fL`>:O7P4TH5l19N6
O`BMRX84XXf51:RAR0B]U8XEoooo000Doooo1:R=P`BOQ7X4UGU`18]_IPB1IE`3MUYA16]?APAP@c`4
ECTa150d;@A=<BX3BRlX14X^9`A<<2T4D3<[154d;0A@<b`4Cc@^0dhf<@A>>CD4Cc`i1551?`ACATD4
EDU815I<C0=FCDh4EDe>159:B`A=A4@4B3dn14@i>0=1=SH4@3Hf140f>0A2>S`4@ce0148m@P@n>Cl3
>cLl13di?@A1?D44@d1414A1A@A4@TH3@d571491A`A1@DL4@D5813doA`A1@dX4CDeB0eMEF0ALFE/4
HUiN16iVI@AkLFl4Q7Ue0hanNPBBPgh4VHN119j;Q0BSSXH4Z9691:fDRaGoool001Coool4Z8f319n4
NPBENG04RfmV185UG0=fFU44Jdm61613?0AE>C44D3@]14da:P=:;bP4BRhW14``:@A@<b/4DC@/150c
;0A?=2h3CSHa14hi=@A??3T4DD4o15=6A@AEBDP4ETa<0eI=CPAECDh4DTY;14e4A0A8?Ch4A3Th0d4f
=PA0=SH4@3Hh148j?0A3?D04@Se213hi?`<k=c`4?CTm144m@@A3@4@4A45514A2AP=3@DL4@T571451
A`A1@DP4?Cm71453BPA=CE83EeEH15aIF`ARGUh4KVIU17]aK`B4NGD3S7ij19:3OPBIQh44WX^41:>>
QPBXTHT4[IB;5Oooo`005?ooo`BXSH<4WhAj19EiL0B;KfH4PFEL0gIJD@A[CdH4H4<l15Di<@A@=2d4
CC4Z0dX_:0A:;RL4C30Y150c:`AA=2`4D3</14ld;P=>=S44CSTe14ll>@AA@Cl4DdI515E9B0AFC4`3
ETe>15E=CPABBT/4CDA414Pm?PA4>CP3@CHf140f=PA0=SP4@SXl14<m@0A2?D84?STo0c/g?0@m>Cd4
@Ce114=0A0A4@DD4A4960d=1A`A2@DL4@D571451B0@m?dL4@D=:14e=DP=GEEP4G5UK169NGPA^IVD4
Ng5_18AiM@><OWX4TX=n19V7P@BNRh@4Xhj61:RAR@B]U8/Eoooo000Doooo1:R=P`BOQ7X4UGU`18]_
IPB1IE`3MUYA16]?APAP@c`4ECTa150d;@A=<BX3BRlX14X^9`A<<2T4D3<[154d;0A@<b`4Cc@^0dhf
<@A>>CD4Cc`i1551?`ACATD4EDU815I<C0=FCDh4EDe>159:B`A=A4@4B3dn14@i>0=1=SH4@3Hf140f
>0A2>S`4@ce0148m@P@n>Cl3>cLl13di?@A1?D44@d1414A1A@A4@TH3@d571491A`A1@DL4@D5813do
A`A1@dX4CDeB0eMEF0ALFE/4HUiN16iVI@AkLFl4Q7Ue0hanNPBBPgh4VHN119j;Q0BSSXH4Z9691:fD
RaGoool001Coool4Z8j419n4N`BFNg84S75X18=WG`=iGED4KU=;16A9@PAJ?cT4ES`f15@j=0=B=c44
DSL`35<g<0AA=Rl4CcH`0dhf<PA=>3D4CC/h14hn?@A?@D44D4=414m5A@=?ADH4CTA514]1@`A8?Sl4
ACTj148f=P<o=3D4?S<e13le=`A0>3/4@Sa014E1A@A8A4P3Ad=814=0A@@n?444?C]113hm@`@o?TD3
@3m61452B@A1@dX4?d9913e2BPA4B4l4CDmE0eADF@AJFUh4IfEV17E`K`AnMW@4Qgai0hj1O@BEQX44
VXV31:2=QPBTT8P4ZI::1:fERaGoool001Coool4Z8j419n4N`BFNg84S75X18=WG`=iGED4KU=;16A9
@PAJ?cT4ES`f15@j=0=B=c44DSL`35<g<0AA=Rl4CcH`0dhf<PA=>3D4CC/h14hn?@A?@D44D4=414m5
A@=?ADH4CTA514]1@`A8?Sl4ACTj148f=P<o=3D4?S<e13le=`A0>3/4@Sa014E1A@A8A4P3Ad=814=0
A@@n?444?C]113hm@`@o?TD3@3m61452B@A1@dX4?d9913e2BPA4B4l4CDmE0eADF@AJFUh4IfEV17E`
K`AnMW@4Qgai0hj1O@BEQX44VXV31:2=QPBTT8P4ZI::1:fERaGoool001Coool4Z8j419n4N`BFNg84
S75X18=WG`=iGED4KU=;16A9@PAJ?cT4ES`f15@j=0=B=c44DSL`35<g<0AA=Rl4CcH`0dhf<PA=>3D4
CC/h14hn?@A?@D44D4=414m5A@=?ADH4CTA514]1@`A8?Sl4ACTj148f=P<o=3D4?S<e13le=`A0>3/4
@Sa014E1A@A8A4P3Ad=814=0A@@n?444?C]113hm@`@o?TD3@3m61452B@A1@dX4?d9913e2BPA4B4l4
CDmE0eADF@AJFUh4IfEV17E`K`AnMW@4Qgai0hj1O@BEQX44VXV31:2=QPBTT8P4ZI::1:fERaGoool0
01Coool4Z8j419n4N`BFNg84S75X18=WG`=iGED4KU=;16A9@PAJ?cT4ES`f15@j=0=B=c44DSL`35<g
<0AA=Rl4CcH`0dhf<PA=>3D4CC/h14hn?@A?@D44D4=414m5A@=?ADH4CTA514]1@`A8?Sl4ACTj148f
=P<o=3D4?S<e13le=`A0>3/4@Sa014E1A@A8A4P3Ad=814=0A@@n?444?C]113hm@`@o?TD3@3m61452
B@A1@dX4?d9913e2BPA4B4l4CDmE0eADF@AJFUh4IfEV17E`K`AnMW@4Qgai0hj1O@BEQX44VXV31:2=
QPBTT8P4ZI::1:fERaGoool001Coool4ZHj41:25O0BGO7<4SW=[18AZHP=kH5T4LUM@16Q>A`AOACl4
GD<m15Y1>`=H?SP4F3dg15Ll=PAF>S@4DcPb150f<0A>=C43CCHb14`g=0A<>3H4BcXi14/k>`A;?Cd4
BSho0dTm?`A7?3d4ACXk148g>@A0=3H4?C8d0c``<`@k<C<4>c8e13dd>0@n>3`4@Ca014A0A0=7A4P4
BDM;14Y8C@A8Ad`4ATE;14I6C0=5Adh4@dI>13m4C0@mA4`4?dI>14M=E0A@E5X3F5aP165TI`A]KFh4
NgIe18=kN@B;P7d3TXF119N9Q0BMS8H4XHn81:JAR@BZTh/4[YF<5Oooo`005?ooo`BYSX@4X8El19Ml
L`B>Lf/4Q6YR0g]PF@AbEe04J4i715m5?`AM@cd4FT4k0ePn>0AH?CL4Ec`f15Hj=0AC>384D3H`14he
<@===S84C3Ld14`h=PA;>ST4Bc/k14/m?@A:?Sl3BCdo14Ll?@A5>S/4@SLi140d=P@m<S@3?30c13/a
<`@k<SD4?C@h13hh?0A1?404A4140dM4B0A9Ad/4BTQ=14Q7C0A6AD/4ATI<0dE7CPA3ATh4?dA<13e4
C0@oATh4AdeD151DFP=HG604HFAW16e]KPAkMWD4Pg]i18^0O@>BQH44UhV419f<QPBQShP4YY691:ZC
R`B^UH`Eoooo000Doooo1:V>Q0BPQG`4Ugac18icJ`B4JV83Nf1I179GD0AXCTL4GdDo15e3?@AJ@C/3
F3hh15Pm=`AG?3H4ESXd15<h<PA@=S04CSDa0ddf<PA<=c@4C3Pf14/j>@A;>c/4Bcdm14Xn?`=9?Cl4
Ac`m14Dj>`A2=cT4@3@f13db=0<l<3<4>c4c13/b=@@m=3P4?SPl144l@0A4@4@3AdA814U7B`A:B4d4
B4M<14I5B`A6AT`3ADM>14=6CP@oA4`4?DA<13m6CPA7CE@4D5AJ0eQLH0AQI6L4KFe^17]fM@B3NgT4
Rh1m0i:5P@BGRH@4WHb61:6?R0BVTHT4ZY>;1:jES1Goool001Coool4ZHj41:25O0BGO7<4SW=[18AZ
HP=kH5T4LUM@16Q>A`AOACl4GD<m15Y1>`=H?SP4F3dg15Ll=PAF>S@4DcPb150f<0A>=C43CCHb14`g
=0A<>3H4BcXi14/k>`A;?Cd4BSho0dTm?`A7?3d4ACXk148g>@A0=3H4?C8d0c``<`@k<C<4>c8e13dd
>0@n>3`4@Ca014A0A0=7A4P4BDM;14Y8C@A8Ad`4ATE;14I6C0=5Adh4@dI>13m4C0@mA4`4?dI>14M=
E0A@E5X3F5aP165TI`A]KFh4NgIe18=kN@B;P7d3TXF119N9Q0BMS8H4XHn81:JAR@BZTh/4[YF<5Ooo
o`005?ooo`BYShD4XHIm19QnM@B?MFd4QfeU0giTG@AeFe@4K59<16=9@`APAd44GTI00ee4?`AK@S`4
FSlj15Ll=PAC>C<4D3Ha14he<@=<=C84BcHc14Tf=0A8=cH4AcLg14Hg=`A5=cL3@cHg144d=P@o<c@4
?C0b13/^<@@i;C03=b`_13L]<0@g;S<4>30e13Xc>0@l=c/4?cXo0d8nA0A4@TP4AdI<14Q8C`A8BE04
ATQ@0d=7C`A1ATh4?TE=13e4C@A1B544Be9J15IKHP=PI6T4JV]_17AcM0AoNGT4R7mm1926P`>FRXH4
Vhf81:2?RPBTTH/4Yi>;1:^DS0B^UX`Eoooo000Doooo1:V?Q@BQQWd4V7ie18meK@B7KFD3OVAM17EK
E0A/DT`4HdU31617@@ANAT03GD@o15]2?0AJ?cX4Ec`f15<i<`A@=S44CSDa0d`e<PA;=S<4BCHd14Pg
=PA7=cL4ASLg14Dg=`=3=SL4@C@f13lc=0@m<384>bha13T]<0<g;2l4=bd`13L^<`@h<3D4>S<h13`g
>`@o>Sl3@Si414A2B0A7AT`4B4Q?14Q9D0A6B503@dM?1456CP@nADd4?DA=1458D@A;DUX4EU]R0f1T
J@AZJfl4M7=d17miN@B8Ogd4T8J30iJ:QPBKSHP4X8n:1:BAR`BWTh/4ZiB<1:jFS1Goool001Coool4
ZHn51:66O@BHOWD4SgE]18M]I@=nI5d4ME]D16aBC0ASBD<4H4M115i6@0=MA3l4Fd8l15Xo>PAG?3H4
DcTc150f<@A>=C43C3Db14/f<`A9=S@4B3Lf14Lg=`A6=cL4ACLg0d<f=`A1=3H4?c<d13d`<P@k;S44
>Bd`0cL/;`@g;C04=bhc13P`=@@j<cP4?3Lk13lj?`=2?T@4A49814M6C0A8B4l4B4U@14I8D0=3Adl4
@DI>13i5C@@mA4d4@DQA14]BFPAFFf83H6AY16Y[K`AdLg@4OgUi18QoO@B@QX<3UXZ619^=R0BPShX4
Y96;1:NCR`B[U8`4[YJ<5Oooo`005?ooo`BYShD4XHQn19V0M`BAN704RG1X0h1WH0AhGeT4KeMA16I>
B@ATCDT4Hda80f5:A@ANAd<4Fd@o15Lo>`AC>cL4D3Lc14de<P=;=C84BC@b14Ld<PA5<c<4@c<c144b
<P@o<C43?Bl`13/^;`@i;2h4=bX]13DY;0@c9b/3<RL[138X;@@c:Bl4=2`a13D_=@@g<SP4>CHl0c/j
@@@n?TD4@4581453BPA2A4d4@4E=0ci5CP@mADh4>dE>13]6D@A3CEL4D5QP15]QJ@=VJW04LW=g17el
OPB8Ph<4THV819N=R`>KT8`4Wi:=1:>CS@BVU8d4ZIF=1:bFS@B_UXdEoooo000Doooo1:V?Q@BQR7h4
VH1g195hL0B9L6P3P6MP17QOF@A_Ee44ITi916A=B@ASC4P3HDY515i7@`AKA3l4Eclk15<k=`A@=c<4
CCDb0d/e<PA9=384Ac@b14Dc<`A3<c<4@C8b13la<@<m;c04>bh_13T/;P@g:Rd4=BT/13<W:`<b9b/4
<RP]13<Y;`@d;344=Ble13Lb>0@i=S`3>cY113hnA@A0@DP4@D=:1494C@A0ADd3?TE>13e5CP@kADh4
>dIA14==E`A@F604Ff5Y0fIZL0AbLgL4OGan18R3P`BARHP4Uhf;0i^@S0BOTXd4Xi>=1:JDS@BYUHd4
[9J=1:nFSAGoool001Coool4ZHn51:68OPBIP7L4TGQ`18U`J0>0If04N5mI16mGD@AVCTT4I4e916=<
B0=QBTD4GTM315]4?`AG?c/4Dc/g150g<`A==C83BcDb14Td<PA7=384AC<c14<c<`A1<S84?c4a0cd_
<0@k;Rl4>B`^13LZ;@@e:B`4<bL[0c8W:`@b:2d4<bT_13@/<@@e;cD4=c8h13Tf?0<k>T44?Si51411
B0A1@dX4@TA=1415C@<nADh4?DE>13]5CP@kAU44@deG151HH0AKHFT3IVY`179cM`AmO7h4R8>31969
R0BGSH/3Vi2<19nBS@BSThd4YYB=1:VES@B/UXd4[iJ=5Oooo`005?ooo`BYShD4XHQn19V0M`BAN704
RG1X0h1WH0AhGeT4KeMA16I>B@ATCDT4Hda80f5:A@ANAd<4Fd@o15Lo>`AC>cL4D3Lc14de<P=;=C84
BC@b14Ld<PA5<c<4@c<c144b<P@o<C43?Bl`13/^;`@i;2h4=bX]13DY;0@c9b/3<RL[138X;@@c:Bl4
=2`a13D_=@@g<SP4>CHl0c/j@@@n?TD4@4581453BPA2A4d4@4E=0ci5CP@mADh4>dE>13]6D@A3CEL4
D5QP15]QJ@=VJW04LW=g17elOPB8Ph<4THV819N=R`>KT8`4Wi:=1:>CS@BVU8d4ZIF=1:bFS@B_UXdE
oooo000Doooo1:Z@QPBRRH04Vh5i19=jLPB;Lf/3Pf]T17]SG@AcG5H4JeA@16UCC`AWDDh3IU1<16==
B@APBDD4G4E215Q1?PAB?3T4CSLe0d/d<PA7<c44AC4`148_;`@o;Rh4?Bd^13X/;@<h:R/4=RPZ13@V
:@@a92P4;b<W12hR9`<]8RL4;B<Y12hU:`@^:2h4;bXa134^=@@d<ST3=SDm13Pi@@@j?4@4>cm813a0
BP@l@T/3?4==13a4CP@kAE04@4YE14]EGPAGGfP4HfU`0g1dN@AnOh<4RXV;19FAT@BLUYD4WiJD0j6F
T`BTUi84YYNA1:VGT0B[Uhl4[IN>1:nGSQGoool001Coool4ZY261::9P0BKPGT4TgYb18]cJ`>3Jf@4
Nf=M17=LEPA[E504JE=?16MACP=VD4`4Hde91619A@ALAD84F44n158l>@A>=cD3Bc@b14Lc<@A5<C04
@Rl_13l^;P@m;Bh4>R`]0cPZ:`@f:2X4=2HY134T:0@_8bL4;R8W0bdR9`@]8bT4;RD[12hX;P@_:S44
<Bhe13@b>@<f=Cd4>3U113XlA0@k?dP4?41:13a2B`<l@dd4?4A>13]5D0A0BUD4BeEN15MOJ0ASJG03
L7Ai17ioP`B:RH/4UI6A19bFU@BOUY@3XIJC1:BGTPBVUi44ZIN@1:^GS`B]Uhh4[iN>5Oooo`005?oo
o`BZT8H4XXV019^1N@BCNW84Rg=[0h=[I0AkHed4LeaF16]DD0AYDdl4Ie5>0fI@C0ASCDT4H4U515a5
@PAH@Ch4DS`i14hg=@=;=384Ac<a14Da<0A2;bl4?bh^13d];P@j;2d3>2X[13HX:P@d9RT4<B@X12lS
9`@^8RL3;B8W12dS:@@^9B/4;RP^12lZ<@@a;SD4=38i0cHe?@@h>D44>Sa413/oB0@l@4X4?49;0ca3
C@@lA4h4>dE@141:E@A;EEh4EemX16=YL0=`M7T4OWn318Z9R`BETI44W9JE19nFU0>QUY<4Y9NB1:JG
T@BYUi04ZiN?1:fGSPB_UhhEoooo000Doooo1:Z@QPBRRH04Vh5i19=jLPB;Lf/3Pf]T17]SG@AcG5H4
JeA@16UCC`AWDDh3IU1<16==B@APBDD4G4E215Q1?PAB?3T4CSLe0d/d<PA7<c44AC4`148_;`@o;Rh4
?Bd^13X/;@<h:R/4=RPZ13@V:@@a92P4;b<W12hR9`<]8RL4;B<Y12hU:`@^:2h4;bXa134^=@@d<ST3
=SDm13Pi@@@j?4@4>cm813a0BP@l@T/3?4==13a4CP@kAE04@4YE14]EGPAGGfP4HfU`0g1dN@AnOh<4
RXV;19FAT@BLUYD4WiJD0j6FT`BTUi84YYNA1:VGT0B[Uhl4[IN>1:nGSQGoool001Coool4ZY671:>:
P@BLPg/4UGae18efK`>6KfP4OVMR17IPF`A^FED4KEQE16aGD`=YEE84IU5?169=BPANBDH4FdA115Ho
?@AA>SL3BSDc14Hb<@A2;bh4?b`/13/Z:P@h:2T4=BHW0c<T9P@`8RD4;R0S12`N8P@Z7R84:AdR0bPN
90@X7bD4:24X12TS:`@[9Rh4;BXb12l^=P<a<CX4<c@n13Dh@@@f>dD4=ce713PoBP<i@D`4>D=?13a7
D`A5D5/4DE]U15mWK`A^M7X3O7n418Z;SPBHUYL4YJ>S1:VTX`BWWi`3YifI1:VKU`BZViD4ZiZC1:fI
T@B^V904/9R>5Oooo`005?ooo`BZTHL4XhZ119b3N`BEO7D4SGI_0hI_J0AnIf84MV1K16iIE@A]F5D4
K5MC0fUEDPAVDDl4HTe:15i9APAKA444ESlm154j=`=:=C<4AS8a148_;P@o;2`4>bXZ13PX:@@e9RL3
<b@V130R9@@^82<4;1hR12XN8P@Y7B83:1hT12PO9@@X8BP4:B<[12/V;P@]:S84;bhf0c4a>P@c=3h4
=CQ113HkA@@g?DL4>3m:0cU1C0@i@dl4?4MC14E@F`AAFfD4GfM_16idNP=lOh@4RX^>19RFU`BUXj<4
ZJBS1:NOW0>WWIT4ZI^G1:ZKU@B[VY<4[IVA1:jHT0B`V8hEoooo000Doooo1:ZAQ`BSRX44W8=k19El
M@B=MVl3QVmX17iWHPAfH5/4KUUE16eHE@A/Ee<3JEEB16IAC`ARCDX4GTU615]4@@AF?cd4DCXg0dXe
<`A6<S44@Rl^13l/;0@k:RX4>2PY13DV9`<c92H4<28U12hP8`@/7R84:QhR12TM8P<X7R@4:1lU12PQ
:0@Y8b/4:bH^12dZ<P@_;SH3<C4j13<d?P@e>444=S]513LmA`@h?dX3>D5<13U3C`@lAe<4AE1K155K
I@AOIfl4KWAj0gaoQ0B:Rhh4V9JG1:FSX`BYY:<4YinL0jNMV@BYViL4ZY^E1:^JT`B]VI44[YR@1;2H
SQGoool001Coool4ZY671:>:P@BLPg/4UGae18efK`>6KfP4OVMR17IPF`A^FED4KEQE16aGD`=YEE84
IU5?169=BPANBDH4FdA115Ho?@AA>SL3BSDc14Hb<@A2;bh4?b`/13/Z:P@h:2T4=BHW0c<T9P@`8RD4
;R0S12`N8P@Z7R84:AdR0bPN90@X7bD4:24X12TS:`@[9Rh4;BXb12l^=P<a<CX4<c@n13Dh@@@f>dD4
=ce713PoBP<i@D`4>D=?13a7D`A5D5/4DE]U15mWK`A^M7X3O7n418Z;SPBHUYL4YJ>S1:VTX`BWWi`3
YifI1:VKU`BZViD4ZiZC1:fIT@B^V904/9R>5Oooo`005?ooo`B[THL4Y8^219j5O@BGOgP4T7Ub0hUb
K@B2K6L4NVAP179MFPAaG5T4Ke]H0faIEPAYEU<4IU=A169?C@ALB4L4ET91150l>`=9=SH4@c4a13l]
;@@k:RX4=bLW13@S9@@`8283;AhP12XL7P@X6Qd49APL12@G70@S5ad38aPO12<K8P@S7BD4920X12HS
;0@X9c04:R/d0b`^>0@^<C`4<3E0138hA0@d?4L4=3m;0cI1CP@jAU84@DeI14aHH`AJI6h4JG5i17Qn
Q0>7RXh4UIJI1:>QXPB^ZZX4[ZVX1:jVX`>]Xil4[J2K1:jNV0B^WIH4[i^C1;2JT@BaV8lEoooo000D
oooo1:^AQ`BTRh84WXEm19MoN0B@NG83RG9]189/I`AjI604LUeJ175LF@A_FeP3K5UF16UFD`AVDe44
HTm=15a8A`AF@T44D3`k0dTf=PA3<C44?bd]13/Z:P@g9bL4=2<U130P8P<]7R04:Q`N12PJ7@@U61`4
91LL12<G7@<S61l48a/R12<M9@@T82P49R</12PW<0@Z:c@3;2hh12ha?0@`=D04<SQ413@lA`@d?d/3
=T5>13Y6DPA1CET4C5QS15YTKPAYLGT4N7j40hN:SPBEUYT4Xj6R1:jZZPB^ZJP4[ZJS0jfSW`B]X9/4
[YjH1:jMUPB_Vi<4/9ZA1;6HSaGoool001Coool4Zi671:B;PPBNQGd4Ugmh191iLP>9LVd4PVaW17YT
H0AbGEX4LEaI16mKF0=/FEH4JEIC16ICD@ARCdd4G4Q715I2@@A@?3/3BCHf14<a<@@o;Bd4>bXZ13LW
9`@d8bD4<20R0bdN80@Z71h4:1XM12DH70@T5a`48aLM0b<H7`@S6b848adU12@P:0@V8b`4:2L`12X[
=0</;SP4;S4l130e@0@b>4@4=3a713@oB`<f@Dh4>TIB145=F@A<F6<4FVA^16UaN@AhOX@3QhZ>19FF
V@BSXJ84[ZZZ1:jYZ0B^YZ<3[J>O1:fPV`B^WYP4[YfF1:nKT`B`VY44/IR?5Oooo`005?ooo`B[THL4
Y8^219j5O@BGOgP4T7Ub0hUbK@B2K6L4NVAP179MFPAaG5T4Ke]H0faIEPAYEU<4IU=A169?C@ALB4L4
ET91150l>`=9=SH4@c4a13l];@@k:RX4=bLW13@S9@@`8283;AhP12XL7P@X6Qd49APL12@G70@S5ad3
8aPO12<K8P@S7BD4920X12HS;0@X9c04:R/d0b`^>0@^<C`4<3E0138hA0@d?4L4=3m;0cI1CP@jAU84
@DeI14aHH`AJI6h4JG5i17QnQ0>7RXh4UIJI1:>QXPB^ZZX4[ZVX1:jVX`>]Xil4[J2K1:jNV0B^WIH4
[i^C1;2JT@BaV8lEoooo000Doooo1:^BR0BUS8@4WhMo19V2NPBCO7H3S7Ma18IaK0AoJfL4MfAQ17IS
H0AdHEh3LEiL16iLFPAZF5L4I59A15i<B`AFADD4CC`m0dHe=PA1;c04?2//13LV:0@c8R@4;ahP12/J
70<X5aX491DH124C5`@O4QL47A8H11`B6@<L4a/471HN11hI8P@P72H48B0Z12<T;P@V9c83:2`g12/`
>`@]<cl4;SI3130jA`@a?T/3=D9?13Y8EPA4DUl4DUm[169]MPAbNX84PHN>0i2DV@BPXJ@4[jf_1;Rd
]0Be/:h4/j^Y0k:XY0BaY:04/J:L1;6OV0BaWID4/I^B1;6IT1Goool001Coool4Zi:81:F<Q0BOQgl4
VH9j19=lMP><Mg44QW5/17m[I`AgI644MV=P17AQGP=aGU`4KUaJ16YHE`ATDU44GTa;15I5A@A=?3d3
ASDf144_<0@l:b`4=bHX13<R90@_7R04:aXL0bPG6P@T5AP48A<G11lB5`@M4QP4718I0a`C6`@L5Qh4
7QTR120L9P@Q82X48b@^12HW<P<X;3L4:c0k12dc?`@^=T<4<3Y7134nB`<e@Tl4>TQF14ABG`ABGf/4
HVef179jPPB1Qhh3T9BI1:2QY0B_[Jl4^;Bd1;F`[PBcZjT3/ZRT1;6TX0BaXY`4/InH1;6MU@BaVi84
/IV@5Oooo`005?ooo`B[TXP4YHb419n7O`BIPWX4Tgaf0hagL@B6LF`4Of]W17MTH@AfHf04M65N0g5N
G0A^G5X4JUQG16ABD@ANC4/4ETE514dl?@=6=CH4@Bl`13`[;0@g9RP4<b8T12lN80@[6Q`3:1LJ12@E
60@Q4aL47a8G11dB60@L4QT371<K11`F7P@N6B8481`V124P:P@S92h49RLb0bP/=`@[<3/4;C<o12hf
@`@`>TL4<Ci;0cE2C`@jB5H4A59O159OJ`ARKGH4LWZ21867SP>@U9T4X:6T1:n][`Bh];@4]K2^1;>[
Z@>bZ:@4/JBP1;6RW0BaWiP4/IfE1;6KTPBaVI0Eoooo000Doooo1:bBR@BVSXD4XHV119^4O@BFP7T3
T7]f18YfLPB4LFh4OV]Y17aZJ0AhJ6H3MFAS175PG`A/Fe/4IeIF161@D0AGAdT4C3do0dDe=`@n;c44
>BT[13<S9@@^7R04:QTL12DF60<Q4QH47Q0D11/?50@I3A@45``D11H<5@<F3QP45a4L11TE80@K6B@4
7A`W11lP;0@R9C4392Te12L^>P@Y<Sl4:cI312djA`@a?T`3=DAB13i=F`A;FVL4FfUd16egP@AnQHd4
SI:H0ijPY0B_[k44_kno1<;0_`Bl][D4^K6^0kN/Z0BeZ:<4]:FO1;>RV`BcWiL4/YbC1;:JT1Goool0
01Coool4[9:91:J>Q@BQRH44VhAm19J0N@>@NgH4RWIb18AaKPAnJfT4O6YX17QXIP=eI6<4LF1O16aK
F`AWEUH4H51@15M7B@A<?Cl3ACDg13h_<@@i:B/4<b<U12hN80@Z6A`49AHH0b4B5P@N41@46`lD11T=
50@G31@45P`E0aH>60@G4A`46ADP11/I90@M72L47b0/128U<@<T:CD49bhj12Tb?`@[=T<4;CY7134n
C0<eA584?TeK14]JI`AKJG@4KGN117j5S@B=TYP3WZ2T1:n_/@Bo_kl4`/2o1;bf]@Bi/Jh3]jbX1;FX
X`BdYIl4/j:K1;>OU`BbW9<4/YZ@5Oooo`005?ooo`B/TXT4YXj51:69P@BKQ7d4UX1i0i1kMPB:MW84
Q75^17i[J@AlJVP4N6QV0gETH`AaH5l4K5]K16MFEPAPD504EdM914`m?`=5=CL4?Rla13TY:`@c8bD4
;QhP12XI70@U5QP38A8F11h@50@K3a@46@dD11L<50@F31D35PhH11LA70@I5B046aTT11dL9`@O82`4
8RDa0b@Y=@@W;SX4:C8o12/f@`@]>TL4<Ci<0cE4DP@nCE/4BeYW15]YM0A]Mh44OXF=18fBV0>NX:@4
[jna1;no_`C2`;l4_;Je1;Va[P>g[:P4]JRS1;BUW`BcXY/4/inG1;:LT`BbVY0Eoooo000Doooo1:bB
R@BVSXD4XHV119^4O@BFP7T3T7]f18YfLPB4LFh4OV]Y17aZJ0AhJ6H3MFAS175PG`A/Fe/4IeIF161@
D0AGAdT4C3do0dDe=`@n;c44>BT[13<S9@@^7R04:QTL12DF60<Q4QH47Q0D11/?50@I3A@45``D11H<
5@<F3QP45a4L11TE80@K6B@47A`W11lP;0@R9C4392Te12L^>P@Y<Sl4:cI312djA`@a?T`3=DAB13i=
F`A;FVL4FfUd16egP@AnQHd4SI:H0ijPY0B_[k44_kno1<;0_`Bl][D4^K6^0kN/Z0BeZ:<4]:FO1;>R
V`BcWiL4/YbC1;:JT1Goool001Coool4[I>:1:R?QPBSRh<4WXN019V3O@>DOgX4Sg]g18UgM0B4Lg44
PW9a17i_KP=jJfX4MFIV171QH@AYFe`4HUAE15Q:C@A>@D@3ACPk13`^<@@e9RT4;b0T12TK7P@T5QX4
7a8G0a/>50@G2a8450TA118840@@1a443`TB0a0;5P@A3QT44a8M11DE8@@H6RH46ah[11hS<0<Q:3D4
8bdj12Ha?`@Z=TD4;Ca:1391D0<jBUT4AUIT15ETL@AVLgh4N8:;18R@U`BIWZ<3ZZb_1;Vi^PC4`/84
`l2o1<6k^@Bm]K83^k2/1;R[YPBgYj44]JBM1;BPV@BcWI@4/YZA5Oooo`005?ooo`B]ThX4Z8n61:>;
P`BNQh04VH=m0iAoNPB?NgL4RGMd18AcL@B2LW44OVm^0gY[JPAeIVH4L65Q16UKG0ARE5D4F4Y=14i1
A0=5>3/4?2ha13DV:@@_82@4:A/N12@F6P@O4QL36`hD11L;4P@D2A444PP@11074@@?2A8340/F114>
6@@C4Qd45ADQ11PJ9P@K7R/47R<`0b4X=@@S;CX49S4o12XfA@@]?4X4<T5@0cY:F@A6EV@4EFAa16Ic
OPAhPX/4R92G19VNX`>Z[:l4^KVj1<C2`PC3`;l4`K^i1;fe/P>k/:`4^:^V1;NWX@BeY9d4]:2I1;>M
U0BbVY4Eoooo000Doooo1:fCRPBXShH4Xh^319j7P0BIPgd3U7mj18mkM`B9Mg@4Q7=a189bL@AnKfh3
NV]Z17EVIPA`HF44JE]L169DE@AHBTd4CT540dDh>`@l;S44=BHY12lP90@Y6ah491HJ11lB5`<K3Q@4
5`/B11@94@@B210440LA10l94P<@2aH44@hI11<B7@@E5B4461XV11/N:`@N8c038BPe12<]>P@V<Cl4
:SI512dlBP@b@E03>TYI14IFI0AEI744IW=n17R2R`B8T9L4VIjS0jZ/[`Bi^KX4a<;21<?0_`C1^kT4
_KFb0k^`[0BhZjH4]jNQ1;FTW@BdX9T4/ifD1;:JTAGoool001Coool4[I>:1:R?QPBSRh<4WXN019V3
O@>DOgX4Sg]g18UgM0B4Lg44PW9a17i_KP=jJfX4MFIV171QH@AYFe`4HUAE15Q:C@A>@D@3ACPk13`^
<@@e9RT4;b0T12TK7P@T5QX47a8G0a/>50@G2a8450TA118840@@1a443`TB0a0;5P@A3QT44a8M11DE
8@@H6RH46ah[11hS<0<Q:3D48bdj12Ha?`@Z=TD4;Ca:1391D0<jBUT4AUIT15ETL@AVLgh4N8:;18R@
U`BIWZ<3ZZb_1;Vi^PC4`/84`l2o1<6k^@Bm]K83^k2/1;R[YPBgYj44]JBM1;BPV@BcWI@4/YZA5Ooo
o`005?ooo`B]U8X4ZI281:B=Q@BPRX<4W8N10iN4O`BCPGd4Sgik18YjN0B8NGP4Q7If0gmbLPAjKFh4
M6MY16iQHPAVFU`4GU5D15=7B`=7>d04>c0e138V:`@[7B<49ALM11hA60@I3AD35@XB114740@>1@h4
2`<>10T33`@81A432PLD10`;60@?3a`44A<Q11@H9P@G7B/46R8`0ahW=@@Q;3/4939112TgA`@_?Th4
=dMG0d9CHPAAHFl4HW1l17=oR@B4SIH4U9^R1:JZ[`>h^[`4a/G61<c;bPC9aL@4aKnm1<6i]P>n/jl4
^jjY1;VZY0BgYIl4]Z:J1;BNU@BcVi4Eoooo000Doooo1:fDRPBYT8P4Y8f51:2:P`BLQh43UhAo19>1
O@B?OW/4RWYh18QiN0B4MWH3Og9b17Y]KPAdIfT4KV5R16IJG0ANDE@4DdM;0dLk@0@k<3D4<RH[12/M
8`@U5ad47Q4H11T=5@<E2Q844@L@10h53P@;0`h42@<?10P54@<:1a@430/H10l?70@A4b4451PV11LM
:`@J8S037RLe124/>`@T<T44:CM712lnCP@gAeL3@U=R155QK`ARL7`4Lgn918B=UPBDVj84YZZ_0kRj
_0C6aLH4c<_:1<W5a0C5_kd4`KVf0kjc[`Bk[ZT4^JZT1;NUW`BfXYX4]9jE1;>KTAGoool001Coool4
[IB:1:V@R0BTSHD4X8Z319b7P@>GQ7l4Th5m18mnN`B:NWP4R7Uh18AfMP=oLW84NVe^17AWJ@A^HF84
IUYL15iAE0ACAd/3Ac]013/`=@@b9R/4:adS12DG7@@N4AP46@dE0aD:4P@A1a043PD>10/33P@90`l4
20DA0`X750@<2aP43`lL114C8@@D62H45ad[11XR<0<N9cD48B`k12@b@@@Y=dL4;ci>13M7E`=2Df84
DF5_169`O0AcOhT4Q8fF19BKXPBVZZl3^;Zl1<K5aPC<blX4bLG41<Fo_@C1^KH3_[>_1;^^Z@BiZZ@4
]jFO1;JRVPBdWYD4/i^A5Oooo`005?ooo`B]U8X4ZI281:B=Q@BPRX<4W8N10iN4O`BCPGd4Sgik18Yj
N0B8NGP4Q7If0gmbLPAjKFh4M6MY16iQHPAVFU`4GU5D15=7B`=7>d04>c0e138V:`@[7B<49ALM11hA
60@I3AD35@XB114740@>1@h42`<>10T33`@81A432PLD10`;60@?3a`44A<Q11@H9P@G7B/46R8`0ahW
=@@Q;3/4939112TgA`@_?Th4=dMG0d9CHPAAHFl4HW1l17=oR@B4SIH4U9^R1:JZ[`>h^[`4a/G61<c;
bPC9aL@4aKnm1<6i]P>n/jl4^jjY1;VZY0BgYIl4]Z:J1;BNU@BcVi4Eoooo000Doooo1:jDR`BZTXT4
YXn71::<QPBORX@3VhR319R6PPBEQ884ThB41922P`B;OWh3QGUj185eMPAkKg04M6UZ16eQI0ATFE`4
FDmD0de4BPA0=ch4<bTa12PN9P@Q5Ql46Q0I11<:50<>1Q442P<>10L13@@400d40P0=10823`<41A<4
1`XH10X>7@@=4R4441LV11@M:`@H8S4372Ph124^?P@V=DD4;Ca=13A5E@@oD603Cem^15m^N`A`OHT4
PHbF19>KX`BTZ[04][Vm0lG7b0CDeMH4e]KF1<k;b@C9`l04aKbi0l6f/PBn/:/4^j^U1;VWX0BgXi/4
]InF1;>KTAGoool001Coool4[YB;1:ZBR@BVShL4XXb619n:Q0>KR8<4V8J219F4PPBCQ8@4T8:318]n
OP>5NGX4PGEf17]_L0AdJFX4KF5T16AIG0AICe@3CDA:140g?P@c:C44:1hV124F7`@J41T44`XD0`h6
4@@:0`h41`4=10@03@@200d40P8?0`@54`@72QP42PhM10dB8@@@5bH451d[11PR<@<L:3P48Bhn12He
A@@]?4d4=4EE13m@H0=?Gfh4Gfik171mR@B1S9H4Ti^S1:BZ/0Bf^Kd3aLO81=CEePCFe]H4c/_91<W3
`0C5_;T3`KJb1;j`Z`BkZjD4^JNP1;NSV`BeWiH4/i^A5Oooo`005?ooo`B^U8/4ZY:91:J?Q`BRS8H4
WhZ40i^8P`BHQX84UHB219>4Q0B@PX<4Rgin0hEiNPB1MGH4Nfm`17AYJPA]HF@4I5UL15U?E0==A4X4
@3Ln13<Y<@@X7RH48AHO11X@6@@C2Q@33PHA10X33P@70@d4100=10803@@20Pl310DC10L:60@:3Qd4
3A8Q110G9P@D7B/4628a0a`X>0@Q;Sh49SE512dlC@@dAED4?e1P0dmOKPAOKW/4L7f9186<UPBCVj<4
Y:Z`1;Ji_@?5alP4e=GF1=KFePC>blT4bL?01<Fl^@?1][84_[2[1;^[Y@BiYj04]j>K1;FOUPBcVi4E
oooo000Doooo1:jDR`BZTXT4YXn71::<QPBORX@3VhR319R6PPBEQ884ThB41922P`B;OWh3QGUj185e
MPAkKg04M6UZ16eQI0ATFE`4FDmD0de4BPA0=ch4<bTa12PN9P@Q5Ql46Q0I11<:50<>1Q442P<>10L1
3@@400d40P0=10823`<41A<41`XH10X>7@@=4R4441LV11@M:`@H8S4372Ph124^?P@V=DD4;Ca=13A5
E@@oD603Cem^15m^N`A`OHT4PHbF19>KX`BTZ[04][Vm0lG7b0CDeMH4e]KF1<k;b@C9`l04aKbi0l6f
/PBn/:/4^j^U1;VWX0BgXi/4]InF1;>KTAGoool001Coool4[YF;1:^CRPBXTHT4Y8n81:6=Q`>NS8L4
W8^719Z:R0BHRhX4UHZ91966QP><PH84QWam181fN0AjL7<4LfU/16]QI@ARFEh3EdiD14Y2B@@l=3d4
<2Tb12<L9P@H4Qd440/G0`X54@@70Pl40`4>10003`@00A440@@D0`875`@42QX41`lN10/D90@>6BT4
4Ah^11HS=@<M:c`48c=412XjC0@c@eD4?U1P14aNK@=LKGX4KWb8182;UPBAVj@4Xj^a1;Fj_PC5b<X3
dmCE1=_Kf`CHe]D4d/k<1<g6``C8_[/3a;Rc1<2b[@Bm[JL4^ZRQ1;RTW0BfWiL4/i^B5Oooo`005?oo
o`B^UH/4Zi>:1:RAR@BTShP4XHf70ij<Q`BLRhL4VXZ819R;RPBERXT4THJ60hb1PPB6O7d4P7Ih17Y`
L`AcJF`4Jf5U169IGP=GCU@4BT9913`d?@@`:C848a`V11PB7@@@2aL32PDA10L23`@30@h4000?1001
4@@111@30PLG10@:6P@73ah42a@T10hI:@@A7Rh45R<e0ad[?0@S<d@4:SY<13=3E@@nD604C5i]0ea]
NPA^O8P4P8^F196KY0BSZk44]KZn1<G8bP?Ce=D4fm_K1=SFe@CBc/`4cLK31<Rn^`?4^;<4`;:]1;f]
Y`BjZ:44^:BL1;JOU`BcVi8Eoooo000Doooo1:jER`B[ThX4Z9691:B?R0BQSHL3WXb719b;Q`BJRXP4
V8^:19F:R@BAQXH3S86218IlO@B0MWP4NW1c17=YK0A[HFD4HUUN0eM>E0A:@TT4?3@m130Y<P@S72H4
618M110;5`<:1A441`8?10<13P@000l4004A104450<21aL410XJ10L?7P@;52@43QTY114N;P@F8cD3
7B/l12<cA0@Z>T`4<d=E13i@H0A<GVd3G6ej16ilR0B0RiH4TI^T1:>[/@Be^[h4aLS:0m?De@CKfm/4
f=KE1=;>c0C=a/<4b;jk0lBh/`C0/Zd4_JfW1;ZXX@BhY9`4]YnG1;>KTQGoool001Coool4[YF;1:^C
RPBXTHT4Y8n81:6=Q`>NS8L4W8^719Z:R0BHRhX4UHZ91966QP><PH84QWam181fN0AjL7<4LfU/16]Q
I@ARFEh3EdiD14Y2B@@l=3d4<2Tb12<L9P@H4Qd440/G0`X54@@70Pl40`4>10003`@00A440@@D0`87
5`@42QX41`lN10/D90@>6BT44Ah^11HS=@<M:c`48c=412XjC0@c@eD4?U1P14aNK@=LKGX4KWb8182;
UPBAVj@4Xj^a1;Fj_PC5b<X3dmCE1=_Kf`CHe]D4d/k<1<g6``C8_[/3a;Rc1<2b[@Bm[JL4^ZRQ1;RT
W0BfWiL4/i^B5Oooo`005?ooo`B_UH`4[9B;1:VBR`BVTHX4Y92:0j:?R`BPSh/4WXn=19f@SPBKT904
V8j@0iB:R`B>QHH4RGn2189iO0AkLgH4M6]`16YRI`=PF5h4E4eD14Q1B@@k=Ch4;BTd124N:P@I5B83
4PlM10`;6P@821P41@PH10D96`@531h31PhP10LA8`@95BL431T[10lN<0@E93H46b/m0b4bA0@Y>T`4
<dAE13i@H@A<GVh4G6ek0felR@AoS9L4TIbU1:>[/`Bf^l04b<[>1=KGf@?Qh^<4i>CS1=cIf0CEd<h4
clS51<[0_0?6^KD4`[>^1;j^Z0BkZJ84^JBL1;JPU`BdVi8Eoooo000Doooo1:nES0B/U8/4ZI:;1:JA
RPBTT8X3XXn;1:2?R`BNShd4WI2>19^@T0BHSY03U8Z;18j5QPB9Oh84PWUl17]cMPAdJg04JV9W0f1H
GPADCE@4B45913/e?P@]:C@48AhZ11TE8P<B3ad430/J10P860@521P41@TK10D<7P<63R041a4S10TE
9`@<6B/43ah`11DT=P@K:cd38C9412TjC0@cA5D4?U1Q14aNKPALKG/3KGb917n<U`BAW:D4Xj^c1;Jk
`0C8b/h4e]OI0n7Rh`CTi><4g=WH1=G@cPC?b<D4b/2l0lJi]@C2/jh4_ZjX1;^YXPBiY9`4]Z2G1;BK
TQGoool001Coool4[iF<1:bDR`BYTX/4YY6:1:B@RP>RSh/4X8n;19j?S@BMT8h4Vi2@19R>T0>DRX/4
SXF618UoPPB2NG`4Ng=f17A[L0AZHVL3H5QN15A=E0A8@DT4>cDn12dY=0@Q7RX46ADR0a8?7@@<2aX4
20PH10D860@52A/41@`N0`H>80@74B<42ADW10`I:`@?7S045B@f11/[?@<Q<T@4:CY<13=4E@@nD644
C5i^15a]N`=]O8T4OhbG196LY@BSZk<4][_01<S:cPCFemT3hN;S1>CTh`CLfMP4eM3>1<o8a@C:`;`3
a[Ve1<:c[PBn[ZP4^jVR1;VTW0BfX9L4]9^B5Oooo`005?ooo`B_UX`4[IF<1:^DS0BXTh`4YY>=0jFB
SPBSThl4XY>A1:6ET`BRUiL4X9JG0i^BT`BFSHh4THR:18b3QPB6OX44OGEi179[L0=WH6H4FeEL151:
DPA5?dP4>CDo12l/>0@V9C837b0^11TK:P@D5bL44AHW114G:0@@62T33aX/110L;`@B7c8452<f11PX
>`@M;d4493E80b`mD0@eAeP4@59S14eOK`AMKW/4KGb90gn<U`BAW:D4Xjbc1;Jl`PC9c=04fM[M1>GV
i`?]k^h4j>SX1=oKfPCGdLl4dLW51<c1_@?7^[D4`kB^1;n_Z0BlZJ84^JFL1;NPU`BdVi8Eoooo000D
oooo1:nFS0B]UH`4ZiB<1:RCS0BVThd3YI:>1:>CS`BRTi44XIFC1::GU`BPUYL3Vi:C19J=SPBAR8X4
S8>618InP@AmMGT4LV]`0fMPIPAKEE`4D4YB14DoB0@i=Cl4;b`h12HU<P<O82h46A/Z11@G9`@A5RL4
4ALX110H:@<?6R`441`_118O<P@D8cH462Pk11d_@@@T=DP3;3e@13E7F0A0DV<4CEm_15e^N`A]O8T3
OhbG196LY@BS[;<4][c21<W<d0CIf]d4iNKW0ng^kPCXj>P4gm_J1=OAc`CAbLD4c<6m0lNj]@C3]:h4
_jnX1;bYXPBiYI`4]j2G1;BKTQGoool001Coool4[iJ<1:fES0B[U8`4Z9><1:JCS@>UTXh4Xi>?1::C
T@BQUI<4XYNG1:2FU`>KTY<4UXf>1968RPB<PhH4QWj117eeN@AbJg03If1V15]EG0A@BU84ACm813Te
?`@_;3P49RDb0alP;P@I6bX451LW114F9`@A5bP441PY0`lJ;0@@72l44Qlb11@S=P@H:3/47Bm112@e
B0</?E04=DMH141BH`A=Gfl4GFik16elR@=oS9L4TIbU1:>//`Bf_<84bLc@1=WJg@CUi^L3kNk^1>SX
j0COfmX4em7?1=79a@C<`Kd3akZe1<>d[PBo[jP4_:VR1;VUW0BgX9L4]9^B5Oooo`005?ooo`B_UX`4
[IF<1:^DS0BXTh`4YY>=0jFBSPBSThl4XY>A1:6ET`BRUiL4X9JG0i^BT`BFSHh4THR:18b3QPB6OX44
OGEi179[L0=WH6H4FeEL151:DPA5?dP4>CDo12l/>0@V9C837b0^11TK:P@D5bL44AHW114G:0@@62T3
3aX/110L;`@B7c8452<f11PX>`@M;d4493E80b`mD0@eAeP4@59S14eOK`AMKW/4KGb90gn<U`BAW:D4
Xjbc1;Jl`PC9c=04fM[M1>GVi`?]k^h4j>SX1=oKfPCGdLl4dLW51<c1_@?7^[D4`kB^1;n_Z0BlZJ84
^JFL1;NPU`BdVi8Eoooo000Doooo1;2FS@B^UXd4[9F=1:ZESPBYUHl3YiF@1:JFTPBVUi@4YYVG1:JK
V`BVWIh3Y9bM19jFV0BJTI@4U8b?18f6R@B4OH44NW=h0g1YK`AVH6L4G5MO151=EPA5A4l4?Ca813Lf
@`<a<Sl4:Rdk12HZ>@@R9cL48BLg120Y>@<Q:c`48Rho12Db@`@W=DL4:SY<130oDP@gAeT3@55Q14UJ
JPAEIG@4HW5o179oS0B2SYT3TifV1:B]]0Bf_L84bLgA1=[MgPCXjNX4m?Kf0o?dm0CXi^D4gm_I1=SA
cPCBbLD4cL6m0lRk]@C4]:h4`:nX1;fZXPBjYI`4]j2G1;BLTQGoool001Coool4/9J=1:jFS@B/UHd4
ZYF>1:VES`>WUI04YYJB1:JGU0BVVIL4YY^K1:JMWP>TW9d4WYJH19ZAU0BDS8l4SHJ918AmP@AjLgP3
L6U_16IPI`ALEel4D4eF14E4C`@m?4P4=cI30c4b?`@Z;C/49RXi128W=`@Q9cL482Ti0b4[?0@R;Sl4
9C9312LeA`@Z>T`4<3mB13M7F@=0DF44BEYZ15EUM0ARLGl4LWn<18:>V@>CWJH4Y:fd1;Jm`PC9cM44
f]gN1>SYjPCdm_H3loCd1>SVi@COfmT4f=7>1=;9a@C=`Kd3b;^e1<Bd[PC0[jP4_JZR1;ZUW0BgX9L4
]9bB5Oooo`005?ooo`B`UXd4[YJ=1:bES@BZUHh4ZIF?0jNET0BVUY84YYND1:JIU`BVVi/4YYfN0jBL
W@BNUYP4VY6D19B<S`B=QXT4Q7f117YcN0=`JFl4IV1W15aGG`A@CEH4ADA?13dlB0@g=T<3<C8o12X]
>`@V:ST48RLg124W=`@P:CT38B/l128^?`@U<T<49cE712XjC0@`?e84=dMI0d1AH@A9FVX4EFEd169a
O`AbOh`4PXjI0i>MYPBT[K@4][g21<W=d@CJgMh4j>WZ1?CfmP?cm?@4j>KU1=oKf@CHdLh4d/W51<g1
_@?8^kD4a;B^1<2_Z0BmZZ84^ZFL1;NPU`BdW98Eoooo000Doooo1;2FS@B^UXd4[9F=1:ZESPBYUHl3
YiF@1:JFTPBVUi@4YYVG1:JKV`BVWIh3Y9bM19jFV0BJTI@4U8b?18f6R@B4OH44NW=h0g1YK`AVH6L4
G5MO151=EPA5A4l4?Ca813Lf@`<a<Sl4:Rdk12HZ>@@R9cL48BLg120Y>@<Q:c`48Rho12Db@`@W=DL4
:SY<130oDP@gAeT3@55Q14UJJPAEIG@4HW5o179oS0B2SYT3TifV1:B]]0Bf_L84bLgA1=[MgPCXjNX4
m?Kf0o?dm0CXi^D4gm_I1=SAcPCBbLD4cL6m0lRk]@C4]:h4`:nX1;fZXPBjYI`4]j2G1;BLTQGoool0
01Coool4/9N=1:jGSPB]UXh4[9J?1:^GT@>ZUi84ZIVD1:VJU`BYW9X4ZYnN1:^RXP>ZXJ<4YinQ1::K
W@BLUIL4U8jA18f7R`B5P8@3NgIl175/L`AWHVT4G5UR15ABG0A=C5H4ATIB0d11CP@k?D/4>3]913Di
B0@c>TT4=3];0cDnC@@g@E44>DEE13a9F@A0CUh4AUAT14iLJ`=FI7<4Gfek16YhQ0AgQ8l4Qi6L19NP
Z@>W[[H4^Kk31<_>d@CLg]l4j^_/1?OinPCin_X3knk]1>OShPCOfML4f=3=1=;8a0C=`K`3b;Ze1<Bd
[PC0[jP4_JVR1;ZUW0BgX9L4]9bB5Oooo`005?ooo`B`Uhd4[YN>1:fFSPB/UXl4ZiNA0jZGTPBYVI@4
ZIZG1:VLVPBZWih4Zj:R0jZQX`BWWj44XY^M19bEU`BDSY44SHN;18F0Q0=kMW`4LFac16MRJ@ALFF84
E59L14e<EPA6AU83@45>13/mB`@h>dT4=CU813<jB@@d>d/3=Ci=13M1D@@iAED4?4UI141>GPA6E6@4
CUa[0eITL`AOKG/4JWR417N4S`B7TI`4Uj2Y0jN^]PBi_/<4blkA1=cNg`CZjn`4moWj1?WjnP?_k^d4
in?R1=oIe`CHd<d4d/S41<g1_0?8^[D4a;B^1<2_Z0BmZJ84^ZFL1;NPU`BdW98Eoooo000Doooo1;2G
S@B^Uhh4[IJ>1:bFS`B[Ui43ZYNB1:VIU0BYVYL4ZIbJ1:ZOWPB[XZ83ZZ6S1:NOX@BRVid4W9FG19B>
T@B=Qh/4QH240g]fO0AaK7<4If9Y15aIHPADDU`4CDaF14I6DP=0@Dh4>ce;13PkB@@e>DP4<cY913@k
B`<e?Td4=d5A13U5E@@lBET4@4iN14IDI0A>G6/3EVAc15m]N`AZN8@4MhB?18NAW0BGX:T3Yjjf1;Vn
``C;c]44g=kO1>[[k0CgnOX4nO[j0no^k@CWhn84gmWG1=S@c@CBb<@4cL6l0lRj]@C4]:h4`:nX1;fY
XPBjYI`4]j2G1;BLTQGoool001Coool4/9N=1:jGSPB]UXh4[9J?1:^GT@>ZUi84ZIVD1:VJU`BYW9X4
ZYnN1:^RXP>ZXJ<4YinQ1::KW@BLUIL4U8jA18f7R`B5P8@3NgIl175/L`AWHVT4G5UR15ABG0A=C5H4
ATIB0d11CP@k?D/4>3]913DiB0@c>TT4=3];0cDnC@@g@E44>DEE13a9F@A0CUh4AUAT14iLJ`=FI7<4
Gfek16YhQ0AgQ8l4Qi6L19NPZ@>W[[H4^Kk31<_>d@CLg]l4j^_/1?OinPCin_X3knk]1>OShPCOfML4
f=3=1=;8a0C=`K`3b;Ze1<Bd[PC0[jP4_JVR1;ZUW0BgX9L4]9bB5Oooo`005?ooo`B`Uhd4[iN>1:jG
S`B]V904[9RB0jbIU0B/ViH4[9fI1:fOW@B^Xj44/:NV0k2ZZPB_ZJ/4ZZBV1:FOX@BOVI`4V9:F18n:
SP>6PHH4OGUo17A`N0AZJ744I69[15eLIPAHEf43De9M14i?F`A;CEX4B4aI14Q=FPA9Ced3Be5O14eD
H`A@F6H4E5e[15USL@APJWP4J79n0fiiQ@AfPHd4PH^F18fFX0BKXj/4Zk6g0kc0a@C=cm84fmcN1>WY
jPChnOT4o?gm1??clP?/jNP4i=oM1=gFd`CGc/X4dLK21<bo^P?8^K<4a;>]1<2^Y`BmZJ44^ZBL1;NP
U`BdVi8Eoooo000Doooo1;2GS@B_Uhh4[YN?1:fHT0B/V983[9VD1:bKUPB/WIT4[InM1:jSX@B`YjH3
/:ZZ1:nYZ`BZY:H4YInQ19nIW0BHTYH4ShZ>0hJ1QPAmNGl4M71h16YXL@ATHV/4GEaV15QGH@=CDUd4
CTmK14]=FPA8C5T4B4eJ14U?G@=;DEl4CEAS151HIPADGF/4FF=a161ZN0AXLWh3KWV517J1S@B1RiH4
SIJP19^SZ`B[/KL3_<351<g?dPCKg=h4jNWZ1?Sin@CloOd4lo?b0ncYj0CTgmd4gMKC1=O>bPCAa/84
c;nj0lRi/`C4/jd4`:jW1;fYX@BjY9`4]j2G1;BKTQGoool001Coool4/9N=1:nGSPB^Uhl4[IR@1:bH
TP>/VI@4[9^F1:bMV@B]Wid4[Z>Q1;2WYP>`ZZX4[jV[1:ZTYPBUWj44WiVL19RBUPB?RXh3QX6617ei
O`AdL7P4JVQa16ARJ`AMG6H4F5MQ0e=BG@A>Ce/4BdeJ14Q<F@A8CEX4BDmM0d]AG`A=E6<4D5QV15AM
J`AIHg44H6Yh16QbOP=^NHD4MX6=186;UPB=UZ04Vj>[1:^a]`>l`<D4cLoB1=_LgPCYjNX4n?Wi1?cm
o@Cclo83k>WX1>COg@CMe]<4elk:1=76`PC<_kX3b;Vc1<Bc[@C0[ZL4_JVQ1;ZTW0BgX9L4]9^B5Ooo
o`005?ooo`B`Uhd4[iN>1:jGS`B]V904[9RB0jbIU0B/ViH4[9fI1:fOW@B^Xj44/:NV0k2ZZPB_ZJ/4
ZZBV1:FOX@BOVI`4V9:F18n:SP>6PHH4OGUo17A`N0AZJ744I69[15eLIPAHEf43De9M14i?F`A;CEX4
B4aI14Q=FPA9Ced3Be5O14eDH`A@F6H4E5e[15USL@APJWP4J79n0fiiQ@AfPHd4PH^F18fFX0BKXj/4
Zk6g0kc0a@C=cm84fmcN1>WYjPChnOT4o?gm1??clP?/jNP4i=oM1=gFd`CGc/X4dLK21<bo^P?8^K<4
a;>]1<2^Y`BmZJ44^ZBL1;NPU`BdVi8Eoooo000Doooo1;6GSPB`V8l4[iR@1:jIT@B^VY<3[Y^E1:jL
U`B^Wi/4[j6N1;6UX`BcZZT3^;6b1;Ze]PBe/;84[jZ/1:VTYPBRWJ04W9NJ0iB?U0B=R8h4QH6717aj
P@AeLg/4Kfee16YYL@=VIFh4HV=/161RJ`APHF`4Gf5/161SKP=RIG04IFQd16Q/N0A^LWd4LgR317Uo
RPB0QY03QhfF18nEW@BIWjH4YZZ`1;Bg_0C2a<P3d=7D1=oNg`C]jn`4nOSg1?gmo0Cfm_D4kng[0nST
hPCRfmP4fm??1=G;a`C@a;l4c;jh0lNh/@C3/Z/4`:fV1;fXX0BjY9/4]inF1;BKTAGoool001Coool4
/IN>1;2HS`B_V904[YVA1:jJT`>^ViD4[YbG1:jOV`B_XIh4/JFS1;>ZZ@>h/K84^[Ff1;F`/PB_ZZ`4
ZJBV1::MX0BLUiX3U8nD18f8SPB5PHL4O7Z117EcN`A_KGD4JVUa0fIUKPARHf`4H69[161QK0AOHF`4
H6=^0f9UL0AUJ7@4J6ah16ibO@AcN8<4NGn:1826T0>7SIH4SiFM19VOYPBVZ[04];Nl1<;4b0?@dM@4
gmkO1>g[k0Cin?L4oOgl1?Kfm@C_kN/3j>CR1>;Kf0CKdll4eL_71=34_`C<_[P3akRa1<>bZ`C0[JH4
_JRP1;ZTV`BgWiH4]9^A5Oooo`005?ooo`BaUhh4/9R?1:nHT0B^VI44[YZC0jjKU@B^W9L4[YnK1:nQ
WPBaYJ<4/jZY0kRa/PBj]KH4]K2b1:nZ[0BYY:H4XYfP19bGVP>DSi@4SHR>18F1Q`AlNX44MG=k16m]
M@AZJG43IVE^169SK0APHV/4H65/15mQK0APHfh3HVE`16EXM0AXK7P4KW9m17=hP`AiOhX4P8J@0hN=
UPB?UId4VInV1:JZ/0Bd]k`4`/C80m3Ae0COg]l4kN_/1?Whm`CmoO`4m_Ke1>o]j`?Xi>84h]_H1=_C
c`CEblL4d<Bo1<bn^0?7^;44`k:[1<2]YPBmZ:04^ZBK1;NOUPBdVi4Eoooo000Doooo1;6HSPB`V8l4
/9V@1:nITPB_VY@3[ibF1:nNV0B`X9/4/J>O1;>WY0BfZjX3^K6a1;ji^@C0^kd4^kJh1;B_/@B^ZJ/4
Z:>V0j:MX@BLV9`4UY:G18n<TPB9QXd4Ph6817mmQ0=lNX84NWV017MgOPAfMGd4MWEn17IfO`=hN844
Ng^417n0R0B3QHh4RXfF19>EW@BHVZ43WInV1:JX[@Bb/[L4_;g01<S8bPCEe=D3h^3Q1>g[j`Cgm_H4
o_oo1?_lo0Cbl>l4jnOU0nCNf`CNe]<4fLo:1=?8``C?`K`4b[^e0lJf[`C3/JT4_jbT1;bWW`BiXiX4
]inF1;BKTAGoool001Coool4/IR>1;2HS`B`VI04[iVB1:nJU0>_W9H4[ijH1;2PV`BaXil4/jNT1;J[
ZP>i/K44_[Vi1<2k_@Bk][P4]:na1:jYZ`BXXjH3XYfQ19bHW0BFTYL4ShbB18V6S@B3PHP4Ogf40gaj
PPAjNH04MgMn17IeO@AfMGh4MWIo0gQhP@AkNh@4Oh2818>5SPB:SIH4TiFM19RJX@>MWjH4YZR]1;:b
]`Bl_L04b<S:1=GDe@?Rh>44kN_[1?OfmPCnool4nocl1?;`k`C[inD3i=kK1=kFd`CIclX4dlS31<o1
_0C:^kD3a[J_1<>aZ@Bo[:@4_:NO1;VSVPBgWiH4]9^A5Oooo`005?ooo`BaV8h4/9R?1;2IT0B_VI84
[iZD0jnLUPB_WYP4/:2K1;6SW`BcYj@4]Z^Z0kVa/@Bn^KT4`;^m1;^f^0Bd[k44[ZV[1:RSYP>RWJ44
W9RL19JBU`B?S984RHJ=18>1R0AoOH@3O7Z217YiP0AgMgh4MWEm17IeOPAfMWl3N7R117]kQ0AoP8P4
PhF>18Z=UPBCUId4V9ZQ0ifOYPBVZ:d4/[:g1;bm`0C8b<X4eMCE0n;Ph@C]jn/4moKf1?koo`Cko?`4
l_3_1>_Wi@?Tg]/4g]KC1=W?bPCCb<<4cl6l1<Zk]@?6]Zl4`k6Y1;n/Y0BlYil4^J>J1;NOUPBdVi4E
oooo000Doooo1;6HSPB`V8l4/9V@1:nITPB_VY@3[ibF1:nNV0B`X9/4/J>O1;>WY0BfZjX3^K6a1;ji
^@C0^kd4^kJh1;B_/@B^ZJ/4Z:>V0j:MX@BLV9`4UY:G18n<TPB9QXd4Ph6817mmQ0=lNX84NWV017Mg
OPAfMGd4MWEn17IfO`=hN844Ng^417n0R0B3QHh4RXfF19>EW@BHVZ43WInV1:JX[@Bb/[L4_;g01<S8
bPCEe=D3h^3Q1>g[j`Cgm_H4o_oo1?_lo0Cbl>l4jnOU0nCNf`CNe]<4fLo:1=?8``C?`K`4b[^e0lJf
[`C3/JT4_jbT1;bWW`BiXiX4]inF1;BKTAGoool001Coool4/IR>1;6HS`B`VI04/9ZB1;2KU0>`W9H4
/IjH1;:QW0BcXil4]JNT1;N[Z@>j/Jl4_[Nf1<>n_`C4`<84`;Zl1;Vd]PBc[[03[ZZ]1:^VZ@BVXJD4
XIbP19bHW@BHU9T4U92F0i6=T`B>Ri44S8V@18^8S`B<RHl4S8Z@0hj<TPB@SY@4Ti6G19VGW0BNW:44
Y:6T1:^XZ`>b/;<4^kVk1<C2``C<b//4emGE1>?Pg`?]jnX4n?Ke1?ooo`Cmo_h4m??a1>gYi`CVh=d3
h=SE1=_Ac@CEb/D4dLBn1<bn^0C8^;83aK>/1<6_Y`BnZZ84^jJN1;VRV@BfWYD4]9^A5Oooo`005?oo
o`BaV8h4/IR?1;2IT0B`VY84/9^D0k2LUPBaWYP4/Z6L1;>SW`BeYj@4]j^Y0kZa[`Bn]kH4`kjo1<C0
`PC0^[`4^KBf1;>^/0>^ZZd4ZjJY1:JQY@BQW:04W9RM19RDV@BDT9H3THfC18j;T@B<RI04RhR?18b9
S`B<RY03SXbB192>U0BCTIL4VINL19jLX@BTXJ@4ZjR[0k:`/`Bk^K/4a<;31<c:b`CGeMD4hn3O0ng[
jPChm_D4oooo1?gnoPCdlo44kNWW1>KPg@?Pf=D4fm7=1=G:a@CAa;h4c;jh1<Rh/P?5/j`4`JnW1;jZ
XPBkYYh4^J:I1;JNU@BdVi4Eoooo000Doooo1;6HSPBaV8l4/9V@1;2JTPB`Vi@3/9bF1;6NV0BbXI`4
/j>O1;FWY0BgZjT3^[6_1;jg]PC3_[l4a<321<2j_0Bi];H4/jj`0jjZ[@B[YZT4YZ6U1:6LX0BLV9d4
V9BI19B@UP>ASI<4SX^A18b9T0B;R8l4S8V?18b:T0>>S984T8jD19>AU`BIUi`4WYbQ1:BQY0B[Z:/3
/[2c1;^i^`C4`/<4c<[;1=OEe@CSh=l3kN_Z1?Sfm@Coool4oOkn1?Ccl@C]jNL4i^3M0n3He@CKdLd4
eL[51=74_PC<_[P4b;Rb0lFc[0C1[jL4_ZZR1;^VWPBiXYT4]YjE1;BKTAGoool001Coool4/IR>1;6H
S`B`VI04/9ZB1;2KU0>`W9H4/IjH1;:QW0BcXil4]JNT1;N[Z@>j/Jl4_[Nf1<>n_`C4`<84`;Zl1;Vd
]PBc[[03[ZZ]1:^VZ@BVXJD4XIbP19bHW@BHU9T4U92F0i6=T`B>Ri44S8V@18^8S`B<RHl4S8Z@0hj<
TPB@SY@4Ti6G19VGW0BNW:44Y:6T1:^XZ`>b/;<4^kVk1<C2``C<b//4emGE1>?Pg`?]jnX4n?Ke1?oo
o`Cmo_h4m??a1>gYi`CVh=d3h=SE1=_Ac@CEb/D4dLBn1<bn^0C8^;83aK>/1<6_Y`BnZZ84^jJN1;VR
V@BfWYD4]9^A5Oooo`005?ooo`BaV8h4/IR?1;6IT0BaVY84/I^D0k6MUPBbWYP4/Z6K1;BSWPBfYj<4
^:^W0k^_[@Bn]K<4`[Zj1<K1`PC7`l@4a;o01;nj_0>j]KL4]k6d1;B_/`B`[;04[ZR/1:bWZPBZYJP3
Yj:U1:BOX`BRWJ44XIbP1:2KW`BQVj03XifR1:FOX`BWXZD4ZJBV1:fWZ0Ba[:`4]:n`0k^f]`C3_kl4
c<S81=SCd`CSgmh4kNWX0oOclPCno?`4oOgl1?Gcl@C^jNL4in7N1>7Ie@?Ld/d4el_61=;5_`C>_kT4
b[Zc1<Je[P?3/JT4`:bT1;fXX0BkYI`4^:6H1;JNU0BdVY0Eoooo000Doooo1;6HSPBaV8l4/IV@1;6J
TPBaVi@3/IfF1;:NV0BbXI/4]:>N1;JWX`BhZjL3^jn]1;je/`C2^[X4a/721<O3a0C4_l04_kZl0kZe
]`Bg/K@4]:nc1;2//0B^Z:`4[:NZ1:ZUZ0>WXZD4Y9nS1::MX@BQW:04X9^O1:6KX0>SWJ84YInS1:NR
Y@BYY:H4[JNX1;6/[0Bd[k03^kJg1<>o_`C<b<P4f=?C1>?OgPC]jNP3mo?b1?klo0CmoO`4mO?a1>kY
i`CWhMh4hMWE0mcBc@CGblH4d/Fo1<jo^@C:^[<4a[F^0l>aZ@C0[:@4_JRP1;^UW0BhXIP4]YjD1;BJ
T1Goool001Coool4/IR>1;6HS`BaVI04/IZB1;6KU0>aWIH4/YjH1;:QV`BdXih4]ZNS1;R[Y`>k[jd4
_[Fc1<:j^PC6`L84al?41<Bo`0Bo^[`3^[Fg1;Na]0Bd[k<4/:b`1:jX[0B/YjX4ZZFX0jNRY@BTWj<4
XYfQ1:6LX0BPVil4XI^P0j>MXPBUWj<4Yj:U1:VTYPB]YjP4/Jb/1;B_/0>k][L4`kno1<c8b0CHdm<4
hmoN1>gYj0?glo84o_cl1?gmo0Celo44k^WW1>OQgPCQfMD3g=;=1=O;aPCBaKl4c[ni1<Zj/`C6]Jh3
`k6Y1<2/Y0BmZ:04^jFL1;RQV0BfWY@4]9Z@5Oooo`005?ooo`BaV8h4/IR?1;6IT0BaVY84/I^D0k6M
UPBbWYP4/Z6K1;BSWPBfYj<4^:^W0k^_[@Bn]K<4`[Zj1<K1`PC7`l@4a;o01;nj_0>j]KL4]k6d1;B_
/`B`[;04[ZR/1:bWZPBZYJP3Yj:U1:BOX`BRWJ44XIbP1:2KW`BQVj03XifR1:FOX`BWXZD4ZJBV1:fW
Z0Ba[:`4]:n`0k^f]`C3_kl4c<S81=SCd`CSgmh4kNWX0oOclPCno?`4oOgl1?Gcl@C^jNL4in7N1>7I
e@?Ld/d4el_61=;5_`C>_kT4b[Zc1<Je[P?3/JT4`:bT1;fXX0BkYI`4^:6H1;JNU0BdVY0Eoooo000D
oooo1;6HSPBaV8l4/IV@1;6JTPBaVi<3/YfE1;:NU`BcX9X4]:>M1;JVX@BhZJD3^ZfZ1;fb[`C1]kH4
aKfm1<[5aPC;alT4b<;40lBn`0C1^kh4_kZl1;jh^`Bl][T4^[Bg1kRa]0Bg/;<4]Jja2;B/[`Be[Jl3
]Zj_1;N^[`Bi/K44^k:b1;je]0C1^;L4aKfl0lg5``CEcL/4gMKD1>OPgPC^jNL4m_7_0ogjn@Ckn_T4
m?7_1>gWi@CVgm`4h=SD1=_Ac0?Fb/D4d/Fo1<jo^@C:^[@4akJ_1<BaZP?1[JH4_ZZR1;bVWPBjXiX4
]j2G1;FMT`BcVY0Eoooo000Doooo1;6HSPBaV8l4/IV@1;6JTPBaVi<3/YfE1;:NU`BcX9X4]:>M1;JV
X@BhZJD3^ZfZ1;fb[`C1]kH4aKfm1<[5aPC;alT4b<;40lBn`0C1^kh4_kZl1;jh^`Bl][T4^[Bg1kRa
]0Bg/;<4]Jja2;B/[`Be[Jl3]Zj_1;N^[`Bi/K44^k:b1;je]0C1^;L4aKfl0lg5``CEcL/4gMKD1>OP
gPC^jNL4m_7_0ogjn@Ckn_T4m?7_1>gWi@CVgm`4h=SD1=_Ac0?Fb/D4d/Fo1<jo^@C:^[@4akJ_1<Ba
ZP?1[JH4_ZZR1;bVWPBjXiX4]j2G1;FMT`BcVY0Eoooo000Doooo1;6HSPBaV8l4/IV@1;6JTPBaVi<3
/YfE1;:NU`BcX9X4]:>M1;JVX@BhZJD3^ZfZ1;fb[`C1]kH4aKfm1<[5aPC;alT4b<;40lBn`0C1^kh4
_kZl1;jh^`Bl][T4^[Bg1kRa]0Bg/;<4]Jja2;B/[`Be[Jl3]Zj_1;N^[`Bi/K44^k:b1;je]0C1^;L4
aKfl0lg5``CEcL/4gMKD1>OPgPC^jNL4m_7_0ogjn@Ckn_T4m?7_1>gWi@CVgm`4h=SD1=_Ac0?Fb/D4
d/Fo1<jo^@C:^[@4akJ_1<BaZP?1[JH4_ZZR1;bVWPBjXiX4]j2G1;FMT`BcVY0Eoooo000Doooo1;6H
SPBaV8l4/IV@1;6JTPBaVi<3/YfE1;:NU`BcX9X4]:>M1;JVX@BhZJD3^ZfZ1;fb[`C1]kH4aKfm1<[5
aPC;alT4b<;40lBn`0C1^kh4_kZl1;jh^`Bl][T4^[Bg1kRa]0Bg/;<4]Jja2;B/[`Be[Jl3]Zj_1;N^
[`Bi/K44^k:b1;je]0C1^;L4aKfl0lg5``CEcL/4gMKD1>OPgPC^jNL4m_7_0ogjn@Ckn_T4m?7_1>gW
i@CVgm`4h=SD1=_Ac0?Fb/D4d/Fo1<jo^@C:^[@4akJ_1<BaZP?1[JH4_ZZR1;bVWPBjXiX4]j2G1;FM
T`BcVY0Eoooo000Doooo1;6HSPBaV8l4/IV@1;6JT@BbVi<3/YbD1;>NUPBcWiT4]:6K1;JTWPBhYj83
^Z^V1;b_Z`Bo/k04`kRf1<No_PC=alL4d/g?0m3:b`C:a<D4a[o11<Jo`PC8`L@4b/?41<W2``?6_l04
a;bn1<Jm_PC8_[h4a[^k1<>i^0?3^;L4a;Vg1<Fi]`C5^[L4b;fi1<Zo_0C@a<43e/_81=gCd0CUg=T4
kNCQ1?;[j0Chlo83m_?b1>oZj0CYhml4i=_G1=kDd0CIc/T4eLS20m73_@C=_[L4b[Vb1<Ne[PC4/JX4
`JfV0knZXPBlYih4^ZBK1;RQV0BgWiD4]IbB1;>JSaGoool001Coool4/IR>1;6HS`BaVI04/IZA1;:K
T`>bW9@4/ijF1;>OV@BdXI/4]ZBN1;RWXP>jZjH4_:n[1;nc/0C3^;H4aknn1<g7a`CBcLl3d<[;1<[4
a@C6_l44a[o21<S1a0C:`l@4bL;30lJo`0C4_;h4a[fn1<Rn_PC6^k/4`kVh0l>h]`C4^KL4aKVg1<Fj
]`C8_KT4b[nl1=34`@?FblP4gM?@1>GLf@C]i>44l^_X1?SclP?flo84kn[X1>WSg`CTfmL4g]C@1=W>
b@CEb<83dL>m1<fn]`C:^K84akF^1<BaZPC1[JH3_jZR1;bWWPBjY9/4^:6H1;NOU@BeW984/iZ?5Ooo
o`005?ooo`BaV8h4/IR?1;6IT0BaVY44/Y^C0k:LU0BcWYH4/inI1;BQV`BfY9h4^:NR0kZ[YPBl[j/4
_k>`1<>h]PC7_kh4cLO71=;=c`?@b//4b/C51<Jo`@C6_l84b<741<[3a0C9`/<3a[o01<Bl_PC6_Kh4
b;jn1<Jk^`C3^KP3`kRg1<Bi]`C5^KL4aKZg1<Rm^@C:_k`4d<C10mK;b0CMdm04iMcI1>gTh@CbjnP4
n??b0oKclPC_j^P4jN?O1>CKe`CNe=04fLk91=G8`P?A`kd4cKjg1<Zi/PC7]Jh4a;6Z1<6]YP>oZZ84
_:NN1;ZTV`BhXIP4]inE1;FLTPBcVXlEoooo000Doooo1;6HSPBaV8l4/IV@1;6JT@BbVi<3/YbD1;>N
UPBcWiT4]:6K1;JTWPBhYj83^Z^V1;b_Z`Bo/k04`kRf1<No_PC=alL4d/g?0m3:b`C:a<D4a[o11<Jo
`PC8`L@4b/?41<W2``?6_l04a;bn1<Jm_PC8_[h4a[^k1<>i^0?3^;L4a;Vg1<Fi]`C5^[L4b;fi1<Zo
_0C@a<43e/_81=gCd0CUg=T4kNCQ1?;[j0Chlo83m_?b1>oZj0CYhml4i=_G1=kDd0CIc/T4eLS20m73
_@C=_[L4b[Vb1<Ne[PC4/JX4`JfV0knZXPBlYih4^ZBK1;RQV0BgWiD4]IbB1;>JSaGoool001Coool4
/IR=1;6HSPBaVHl4/YZ@1;:JTP>bVi<4/ifE1;>NU`BdX9T4]J:K1;NTWP>iYj84^j^V1;f^ZPC0/jl4
a;Re1<Rn_0C=aL<3d/_;1=?<c0C@bLT4clO72<o6a`C?aLH3clG51=35a0C?`l44c;nm1<^n^`C;_[X3
b[fh1<Vk]`C9_;H4c;nj1<k1_0CAa;l4e/[50mcAc@CSf=D4j=kK1>cThPCak>X4lNcY0nWRg`CTfmL4
gmC@1=[>b@CFbL<4d/>m1<jo^0?;^[@4b;J_1<FcZ`C3[jP4`:bT1;jYX@>lYih4^ZBK1;VRV@BgWiH4
]YfD1;BKT@BcVHlEoooo000Doooo1;6HS@BaV8h4/IV?1;:JT0BbVY83/Y^C1;>MU@BcWYL4]:2I1;FR
V`BgY9h3^JNR1;^[YPBm[ZX4`;>_1<Bh]@C8_[`4cLG30m;;b`CCc<`4d<W91<o7a`S?a/L4clG60lo5
a@C@aL@4cl?11<bo_@C;_[/4bkjj0lZm^0C9^kL4bKbf1<bo^PC>`K`4dLBo1=K:a@?LdLd4hmSE1>SN
f`C/i>84lNcZ1?7/j@?Yh]l4i=_G1=oDd0CJc/T4e/W31=;3_@C>_kP3bkZd1<Rf[`C5/j/4`jnX1<2/
Y0BnZJ43_:NN1;ZTV`BiXYT4]inF1;JMU0BdVi44/iV?5Oooo`005?ooo`BaV8d4/IR>1;6IS`BbVY04
/YZB0k:KT`BcWID4/ijG1;BPV@BeXY/4]jBN0kVWXPBkZjH4_JjZ1<2c[`C4^;D4b;jl1<g5``?Bbl/4
dlc<1=39b@C?alL8clK71<o5aP??aLD4d<G41<o3`@C<_kd4bkjk1<^n^P?:_KP4bK^g1<Vl]PC<_kX4
c/6l1=74_`CFb/D3g=7=1>?He@CXg]/4k>CR1?7/jPCak>T3jN;O1>CKe`COe=04f/k91=K9``CB`kd4
c[nh0l^j]0C8]Zl4aK>[1<>_Z0C0[:@4_ZVQ0kbWWPBjY9/4^J:I1;NOUPBfWI@4]9^A1;>ISaGoool0
01Coool4/IN=1;6HSPBbV8l4/YV@1;:JT@>bVi84/Y^C1;>MU0BdWYH4]J2H1;JQVP>gY9d4^JJP1;^Y
X`Bm[JL4`;2/1<>e/@C7^[H3bknl1=76``CGcL/4f<k<1=C9a`CBa/@7e<O61=;4`PC@`Kh8c[nl1<o0
^`??`;X8d<6k1=72_0CBa;h4e<O21=O<a`?KdLd4hMSE1>OPg@CZhn04i]kJ1>7FdP?Ld</4f<[51=C5
_`C@`KX4cKff1<Zi/PC7]Jh3aK:Z1<>_Y`C1[:@4_jZQ1;fWW`BkYI`3^Z>J1;RQV0BgWiH4]YfD1;FL
TPBdVY04/iV>5Oooo`005?ooo`BaUhd4/IR>1;:HS`BbVI04/YZA0k:KTPBbVi<4/ifD1;BNUPBeX9P4
]Z6J0kNTW@BiYZ04^jVS1;f]Y`C0/:`4`kFa1<Nj]P?;_k`4dLK31=O=b`CHc/`4e<W71=;6a0ODalH4
d/C21=31_PS>_k`4cl2k0lo0^PS@`K/4dL:l1=;4_PCDal84elc70m_Ac@CQf=D4in3M1>[Sh0CVg]X4
hMKB0mc@b`CHb/D4e<Fo1=31^PC=_KH4b[Vb1<Ne[P?5/ZX4`jnW1<6/Y0BoZZ44_JNO1;^UW0>jXiX4
^:6H1;NOUPBfWI@4]IbB1;BJT0BcVHhEoooo000Doooo1;6GS@BaV8h4/YR?1;:IT0BbVY43/Y^B1;:K
T`BcWI@4]9jF1;FPV0BfXIX3]jBM1;VVX0BkZJ<4_JfW1<2`[0C3]K44akZf0l^o_0CAa/<4elg;1=S>
c0CDbLL4d/K41mC7aPCBa<84d<6n2<jo_0C?`;/3cl2j2=31^`CA`[`4d/Bn1=C7`PCGc<L3fm7=1>7H
e@CWh=d4j^?P1>KNfPCQe]83g=3;1=S:a@CDaKl4d<6j1<fm]PC:^K84akF^0lFbZPC3[jL4`JbT1;nZ
X@BmYil4^jFL0kZSVPBhXIP4]inF1;JMU0BeW984]9Z@1;>ISQGoool001Coool4/IN=1;6HSPBbV8l4
/YV@1;:JT@>bVi84/Y^C1;>MU0BdWYH4]J2H1;JQVP>gY9d4^JJP1;^YX`Bm[JL4`;2/1<>e/@C7^[H3
bknl1=76``CGcL/4f<k<1=C9a`CBa/@7e<O61=;4`PC@`Kh8c[nl1<o0^`??`;X8d<6k1=72_0CBa;h4
e<O21=O<a`?KdLd4hMSE1>OPg@CZhn04i]kJ1>7FdP?Ld</4f<[51=C5_`C@`KX4cKff1<Zi/PC7]Jh3
aK:Z1<>_Y`C1[:@4_jZQ1;fWW`BkYI`3^Z>J1;RQV0BgWiH4]YfD1;FLTPBdVY04/iV>5Oooo`005?oo
o`RaV8h4/YR>1;:HS`BbVHl3/YV@1;:JT@BcVi84/ibC1;BMU0BdWYH3]J2H1;NQVPBhXi`4^JJO1;^X
XPBnZjD4`:nY0l>b[@C6][44bKZe1<bm^0C?`K/4d/Bn1=73_@??`K`4d<6m1<o0_@C=_KX4bk^g1<Zj
]@?;^[@4bk^d1<bl]@C=_;H4cKff1<o0^@CFb<<3flo;1=cAb`CIc<L4e/W31=C6_`CA`K/3c[fg1<^j
/`C9]Zl4a[>[1<B`Z0C2[ZH4`:^S0knYX@BmYih4_:FL1;ZSVPBiXYT4^:2G0kNOUPBfWY@4]IfC1;BK
T@BdVY04/iV?1;:HSQGoool001Coool8/IR>1;:HSPBbV8l4/YV?0k:IT0BbVY44/i^B1;>LT`BdWI@4
]9jF0kFPV0BgXIX4^:>L1;VVW`BkZ:84_Z^U1<2_Z@?3/Zd4a[Ja1<Vj]@C<_KP4cl6k1=;4_PCA`kd3
cl6l1=31_@C?`;d4cKfj1<^k]`C:^[D3bkZd1<^k]0C<_;D4cKbf1<fm]PC?`;T4e/S30m_?b`CLdL/4
fLc71=K9``CDa[l4dL6k0ljm]`C;^[<4bKJ_1<JcZ`C4/:P4`ZjV1<2[X`>oZJ44_JNN1;bUW0BjXiX4
^J:I1;RPU`>gWiH4]YjD1;FMT`BdVi44]9Z@1;>IS`BbV8hEoooo000Doooo2;6HSPBbV8h4/YR?1;:I
S`>bVI04/YZA1;>KTPBcW9<4]9fD1;BNUP>eX9P4]j6J1;RSW0BiYYl4^jRR1;j[Y@C0[jT3`k:]1<Jf
/@C9^[D4c;fh1<o1^`CBa;h4dL>m0lo1_0C@`Kd4cl2m1<fm^PC;^kL4b[Ze0l^j]0C;^k@4c;be1<fl
]PC=_KH4cl2i1=K8``?Kcl/4g=7;1=W<a`CFbL<4e<Jo1=71^`?>_KL4bkZc1<Vf[`C6/j/4a;2X1<:^
YPC0Zj<3_jVQ1;fWWPBlYI`4^Z>J1;VRV@BhX9L3]inF1;JNU0BeWI<4]9^A1;BJT0BcVHl4/YR>5Ooo
o`005?ooo`RaV8h4/YR>1;:HS`BbVHl3/YV@1;:JT@BcVi84/ibC1;BMU0BdWYH3]J2H1;NQVPBhXi`4
^JJO1;^XXPBnZjD4`:nY0l>b[@C6][44bKZe1<bm^0C?`K/4d/Bn1=73_@??`K`4d<6m1<o0_@C=_KX4
bk^g1<Zj]@?;^[@4bk^d1<bl]@C=_;H4cKff1<o0^@CFb<<3flo;1=cAb`CIc<L4e/W31=C6_`CA`K/3
c[fg1<^j/`C9]Zl4a[>[1<B`Z0C2[ZH4`:^S0knYX@BmYih4_:FL1;ZSVPBiXYT4^:2G0kNOUPBfWY@4
]IfC1;BKT@BdVY04/iV?1;:HSQGoool001Coool4/IN=1;6HS@nbV8h8/YV?1;:JT0BcVY44/i^A0k>K
TPBdW9<4]IfD1;JNUPBfX9L4^:6I1;VSV`>jYId4_:NO1;fXX@BoZZ84`:bT2l6]Y@C2[ZH4`ZnW1<Fa
Z@C7]:/4akB/0lRe[@C8]Jh4bKJ^1<Vg[`C:^;44bkZc1<Zh/@?7]:d4a[>[1<FbZPC4/:P4`jjV1<6/
Y0?0ZZ84_ZRP1;fWWPBlYI`4^jBK1;ZRV@BiXIP3^:2G1;NOUPBgWYD4]YfD1;FMT`BeW983]9^A1;BJ
T0BcVY08/iV?1;:HSPBbV8dEoooo000Doooo1;6GS@BaV8d?/YR>2;:IS`BbVY04/iZA1;>KT@>cVi84
]9bC1;FMU0BfWYH4]Z2G1;RQV@BiXi/3^ZFM1;bWW`BmZ:44_jZR1<2/Y0_1[JD4`ZjV1<:_Y`C5/JT4
akB[1<Nd[0?8]Jd4b;F^1<Vf[PC9]jl4b[Ra1<^j/`C:^;43akB]1<JcZ`C5/ZX4a;2X1<>^YPC1[:@3
`:ZR1;jXX0BmYih4_:FL1;^TV`BjXYT4^J6H0kRPU`BgWiH4]ijE1;JMU0BeWI<4]IbB0kBKT@BdVY04
/iZ@2;>IS`BbV8h4/YR=5Oooo`005?ooo`BaUhd4/IR=3k:HSPRbVHl4/YZ@1;>JT@BcVi43/i^B1;BL
T`BeWI@4]YjF1;JPU`BhXIT4^J>K0kZUW@BlYil4_JRQ1;nZXPC0[:@;`JfU1<:^YPC2[jL4aK6Y1<Nd
Z`C7]:`3b;F]1<Re[PC9]Zh4bKN_1<Zh/@C;^[<4b[Ra0lNd[@C6/j/4aK:Z1<B`Z0C3[ZH4`JbT0l2Z
XPBnZ:04_JNN1;bUW0BkY9/4^Z:I1;VQV0>hX9L4]inF1;NNU@BfWI@4]IfC1;FLTP>dVi44]9Z@1;>J
T0RcVHl4/YR>1;:HSAGoool001Coool4/IN=1;6HS@nbV8h8/YV?1;:JT0BcVY44/i^A0k>KTPBdW9<4
]IfD1;JNUPBfX9L4^:6I1;VSV`>jYId4_:NO1;fXX@BoZZ84`:bT2l6]Y@C2[ZH4`ZnW1<FaZ@C7]:/4
akB/0lRe[@C8]Jh4bKJ^1<Vg[`C:^;44bkZc1<Zh/@?7]:d4a[>[1<FbZPC4/:P4`jjV1<6/Y0?0ZZ84
_ZRP1;fWWPBlYI`4^jBK1;ZRV@BiXIP3^:2G1;NOUPBgWYD4]YfD1;FMT`BeW983]9^A1;BJT0BcVY08
/iV?1;:HSPBbV8dEoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo002Ioooo0`0008Coool009coool00`000?ooooooo`21oooo001koooo1@00
00;oool200001?ooo`800004oooo100000;oool300000oooo`<00003oooo0P0007koool007goool0
1@000?ooooooooooo`000002oooo00@0003oooooool00002oooo00@0003oooooool00002oooo00@0
003oooooool00005oooo00@0003oooooool00023oooo001moooo00<0003oooooool00oooo`030000
oooooooo00Coool010000?ooooooo`0000;oool00`000?ooooooo`0400000_ooo`040000oooooooo
0000Poooo`00OOooo`030000oooooooo00Coool010000?ooooooooooo`800004oooo0`0000?oool2
00001?ooo`@00022oooo001moooo00D0003oooooooooool000000_ooo`050000oooooooooooo0000
00Ooool00`000?ooooooo`2=oooo001loooo0P0000Coool200001?ooo`<00004oooo0P0008ooool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(158) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
C2A693C2A693C1A692C1A592C1A592C1A591C0A591C0A491C0A490C0A490C0A38FBFA38F
BFA38FBFA28EBFA28EBEA18DBEA18DBEA18DBEA18CBEA08CBEA08CBDA08CBDA08CBEA08C
BDA08CBDA08BBDA08BBDA08BBE9F8BBD9F8BBD9F8BBD9F8BBD9F8ABD9E8BBD9F8BBD9F8B
BD9F8CBEA08CBEA08DBEA08DBEA08DBEA08DBEA18DBEA18EBEA18EBFA28FBFA390BFA391
BFA390BFA390BFA390BFA390BFA390BFA390C0A490C0A490C0A491C0A491C1A591C1A592
C1A592C1A693C2A693C2A693
C2A693C1A592C1A491C0A490C0A390BFA38FBFA28EBEA28DBEA18DBEA08CBDA08BBD9F8A
BC9E8ABC9E89BB9D88BB9C87BA9B86BA9B85BA9A85B99A84B99984B99983B99983B99984
B99984B99883B99882B99883B99883B99883B99782B89781B89681B89681B89682B89682
B89884B99885B99985BA9986BA9A86BA9A86BA9A86BA9B87BB9C89BB9D8ABC9E8CBCA08F
BCA08FBC9F8CBC9F8BBC9F8BBC9F8BBDA08CBDA08CBEA08DBEA18DBEA28EBFA28FBFA390
C0A490C1A591C1A592C2A693
C1A693C1A592C0A490BFA38FBFA28EBEA18DBDA08CBD9F8ABC9E89BB9D88BB9C87BA9B86
B99A84B99983B89882B79781B69680B6957EB5947DB5937CB4927BB4927BB4917AB4917B
B4917AB4917AB4917AB4917BB4917BB5917BB4917BB4917CB4917CB5907CB5907CB6917D
B6937FB79480B79480B6937FB6937FB5937FB59480B69581B79683B79884B89987BA9C8A
BA9D8AB99B87B99A86B99A86BA9B87BA9C87BB9C88BB9D89BC9E8ABD9F8BBDA08CBEA18D
BFA28FC0A390C1A591C1A692
C1A692C0A591BFA390BEA28EBDA18CBD9F8BBC9E89BB9D88BA9C86B99A85B89983B79781
B6967FB5947EB4937CB3927AB39079B28F77B18D75B08C74AF8B72AF8A71AF8A71AF8A72
AF8A72AF8A72AF8A72B08A72B08A73B08B74B18C76B38D78B38E7AB38F7AB48E7AB48E79
B48D79B48E7AB48D7AB48D79B38E79B38E7AB28F7AB3907BB3917DB4927EB49380B59481
B59581B59581B69581B69681B79782B79883B89984B99A85BA9B86BB9C88BC9E89BD9F8B
BEA18DBFA28EC0A490C1A592
C1A592C0A490BFA38FBDA18DBC9F8BBB9D89BA9C87B99A85B89983B79781B5957FB4937D
B3927AB29078B18E76B08C74AF8A72AE896FAC876DAB856BAA8369AA8268A98267AA8268
AA8368AA8369AB836AAB836BAB846CAC856EAD866FAD8771AE8873AE8974AF8A75B08A75
B08A75B08974B08A74B18974B08873B08974AF8974AF8A74AF8A75B08C77B18E79B18F7A
B18F7AB28F7AB2907AB3917BB3927CB4937EB5957FB79681B89883B99A85BA9B87BB9D89
BD9F8BBEA18DBFA38FC1A592
C1A592BFA38FBEA18DBD9F8BBB9D89BA9B86B89A84B79882B6967FB4947DB3927AB29078
B08D75AF8B73AE8970AC876DAB856BA98268A88065A67E62A57B5FA4795DA3785CA4795D
A57B5FA57C61A67C62A67D63A77D65A77E66A87E67A87F68A98069AA826CAA836DAB836D
AB836DAB836CAB836CAB836CAB836CAB826BAB826BAA836DAA846DAB856FAC8873AD8974
AD8972AE8973AE8A73AF8B75B08D76B18F78B3917BB4927DB5957FB79782B89984BA9B86
BC9D89BDA08CBFA28EC0A591
C0A591BFA28FBDA08CBC9E89BA9C87B89984B79781B5957FB4937CB29079B08E76AF8C73
AD8970AC876DAA846AA98267A77F64A57C60A3795DA276599F73559D6F519C6D4E9E6F51
A07357A1755AA1765BA2765CA2775DA2775EA3775EA3785FA37860A47861A47862A57962
A57A62A57A62A57A63A57B63A67B62A67B62A57B62A57B63A67D65A77E67A78069A8816A
A9816AA9826BAA846CAC866EAD8870AE8A73B08D76B28F79B3927CB5947EB79781B99984
BB9B87BC9E8ABEA18EC0A491
C0A491BEA28EBD9F8BBB9C88B99A85B79782B5957FB3927BB29078B08D75AE8A72AC886F
AA856BA88268A77F64A57C61A3795DA176599F73559D6F519A6B4B9564439564449A6B4C
9C6E509D6F539D70559D70559D70559D70569E6F559E6F559E6E559E6E559E6E559E6E56
9E6F579E70589F71589F72599F7359A0735AA0745AA1745BA1765CA2775DA3785EA3795F
A47A60A57B62A67E64A88067A9836AAB856DAD8871AF8B74B18E78B3917BB5957FB79883
B99B86BC9E8ABEA18DC0A490
C0A490BEA18DBC9E89BA9B86B89883B6967FB3937CB19078AF8D75AD8A71AB876EA9846A
A78166A57E63A37B5FA1775B9F74569D70529B6D4E996949966443946140956343986849
99694B996A4D996A4D996A4E99694D99694E99694F98674E98664C98644B98624A976249
97644B98664D98684E986950996B519A6C519B6D529B6D529C6D529C6D519C6D519E6F53
9F7156A07459A2775CA47A60A67D64A88168AA846CAC8870AF8B74B18F78B3927CB69680
B89984BB9D88BDA08CC0A390
C0A490BDA18CBB9D89B99A85B69781B4947DB29179B08D76AD8A72AB876EA9846AA78066
A47D62A2795DA076599E72549B6F50996B4B97674695634293603C9866429B6A49976646
966546956446956345946346946346946246946146936046935E44925D43925C42925C42
925C43915D44925F4593614693634894644996654A97664A98664A986548976345986446
9A684B9C6C4F9E7054A07459A2785DA47C62A78067A9846BAC8870AF8C75B29079B4947E
B79782BA9B87BD9F8BBFA38F
C0A390BDA08CBA9C87B89983B59680B3927BB08E77AE8B73AB876EA9846AA68066A47C61
A1795D9F75589C71539A6D4F98694A95654593613F905B3895613E9B6948976644956342
936141915F3F905E3E905D3E8F5D3F8F5C3F8F5B3F8F5A3F8E583E8E553C8D543B8D543B
8D543C8D553C8D583E8D593F8E5C418F5E42905F43926043936042935E3F925B3A925B3A
95604097644699694B9C6E519E7257A1775CA47B62A78067AA846CAD8971B08D76B3917B
B69680B99A85BC9E8ABFA38F
BFA38FBC9F8BBA9C87B79882B4947EB19079AE8C74AC8870A9856BA68167A47D62A1795D
9E75589C7153996D4E96684994644391603E8F5C3994603D97644295624093613F915F3E
8F5D3C8D5A398C58378B57378A56388A56388A55398A553A8A573C8A583D89583D89593D
89573D88543A88533987543A88573B8A593D8B5A3D8D5B3E8E5C3E8F5B3C8F58388E5532
8F5634925D3C95624397674A9A6C509D7256A0775DA47C63A78168AA866EAE8B74B1907A
B5957FB89984BB9E89BFA28F
BFA38FBC9F8AB99B86B69781B3927CB08E77AD8A72AA866DA78268A47E63A1795E9E7559
9B7154996C4E966849936343905F3D8D5A378955308A5631905C38905D3A8F5D3A8D5B3A
8B5937895634865232855132855133845133845234855437865A3D865E42876145876246
855D4183573C8354388352378453378555388756388857398A583A8B58388B56358B5331
8B52308D5534905B3B93614396674A996D519D7358A1785EA57E65A8836BAC8971B08E77
B3937DB79883BB9D89BEA28E
BFA28FBB9E8AB89A84B5957FB1907AAE8C74AB886FA8836AA57F65A27B609F765A9C7255
996D4F9568499263438F5F3D8C5A378854308B56328E5A368D5A378C59378B5938895837
875534855231824E2E804C2D804C2E7E4C2E7F5436845E4186634789684E88664C866145
8362458161457E5A3E7D52367E4F3380513483523685543787563888563688543387512F
874D2A874E2B8A54338E5B3C91614496684B9A6E539E755AA27B61A68168AA866FAE8C75
B2927CB69782BA9C88BEA28E
BEA28EBB9D89B79883B4947EB09079AD8B73A9866DA68168A37C629F785C9C7357996E51
96694B9264458F5F3E8B5A3888553285512D86532F8A58358A5835895836885735865635
855534825231804F2F7C4B2B7C503184604386644885654A85674C85654985664A86684C
87674D856449815E427B563A794F337C4E327E5033815134835335845334855231844F2E
844D2B834C2B844E2E8854348D5B3D926346966A4F9B7157A0785EA47E66A8846DAD8A73
B1907AB59681BA9C87BEA18D
BEA28EBA9D88B69883B3937DAF8E77AB8971A7846BA47F65A07A5F9D75599A7053966B4D
9366478F61408B5B39875431834F2B844F2C85522F875633875734865736855736845636
82553580553580563680583881583982593B815B3C815C3D815C3E815B3C805B3D805A3D
815A3C835C3E866043845E427D563B784C317A4B2F7D4E317F5032815132815030814D2D
814B29804926804A27824D2D8856388E5F4293674B986E539D755BA27C63A7826AAB8972
B08F79B59580B99B86BEA18D
BEA28EBA9C88B69781B1927BAD8C75A9876EA58168A27C629E775C9A7256976D5094684A
9063448D5E3D895735814D297C461F834F2A895734865634845534835434825535815636
815738825B3D846245886A4D86684A8260437F5D3F7E593B7D56387C55377C55367C5233
7C52337D54367F573981573A81573B7B5034774A2E7A4C2F7C4D307D4E2F7E4D2D7D4C2B
7D4A297E48267F4927814D2C8553348A5B3E906447966B509B7359A07A61A58169AA8770
AF8E77B4947FB99A86BDA18D
BEA18DB99C87B59680B0907AAC8A73A8846CA37F669F7A5F9B7459986F52946A4C916546
8E60408C5C3B89573486522F85522E8757348859378456358254358054367F55377E5537
7E573A7E583B7E5B3E8060447F62457E61447D60437C5F427C5E407B5D3E7B5C3E7B5D3E
7B5C3C7B58397C56387E56387F56387F55387A5033774B2F794C2F7A4C2E7B4C2D7B4A2B
7B48287A462577411E79452382513187593B8E614593694E9971579E785FA37F67A9866F
AE8D76B3937EB89A85BDA08D
BDA18DB89B86B4957FAF8F78AA8971A6836BA17D649D775D997156956C4F9166498E6142
8B5D3D8A5A388B593792603D9765428D5E3B8457358055347E55357D54367C54377B5639
7B583B7B583C7A573A79583A795A3D795B3E785A3D785A3D77593C77583B76583A765739
765739765638765738785A3B7B5C3E7E5E417D5B3F795437774E30784C2F784B2D784A2B
7849297847277947277847277E4E2F85573A8B5F4391674C976F559C765DA27E66A7856E
AD8C75B2937DB79985BDA08C
BDA18DB89A85B3947EAE8D77A98770A481689F7A619A745A966E5292684B8E63458A5D3E
8859388656348755308956328858368456357F52327C51327A5234785336775438775439
77563A77563A755337745134745336745538735538735538735638725538715335715234
715234715234725335735436765538775739785638775337764F34754C30764A2D76492C
77482A7747287746267747297D4E30835538895D418F654A956D539B755CA17C64A6846D
AC8B75B1927CB79984BDA08C
BDA08CB79985B2937DAC8C75A7856EA27F669C785E977157936B4F8E64478A5E40865939
835433814F2D7F4D2A7E4C297C4B287A4B2A784C2E774D2F754E31744F33735034725135
725237725237725236704F326F4E316F4F326F4F336E4F336E50336E50346D50346D4E32
6D4D326E4E336F4F34705236725338745438745338745136734E33734B30734A2E754A2D
76492C77492B784829754525794A2A805335875C3F8D6449936C5299745B9F7B63A5836C
AB8A74B1917CB69884BCA08C
BCA08CB69984B1927CAB8B74A5836C9F7C649A755C946E548F674B8A6043855A3C815334
7D4E2D7B482678452276442274442374462573472871482A70492C6E4A2D6E4B2F6D4C30
6D4E326D4F336C4E326B4C2F6A4A2E6A4B2F6A4D316A4D326A4D326A4D336A4D32694D32
6A4D326A4D326B4D336C4E346E503770523971533A715138704D33704B31714B2F734A2E
754A2D784B2D7B4C2D7746267646277E5033855A3E8C6348926B5198735A9E7A63A4826B
AA8973B0917BB69884BC9F8C
BC9F8CB69883B0917BA98973A3826A9D7A62977359916B508B6448865C3F8055377C4E2E
774726734120703D1B6D3C1A6D3F1E6E42236D43256B44266A442769452968452A67462A
67472C67492E674A2F66492E65482C65472B65482C66482D65492E65492E65482D64482E
65492F664A30674C32684C32694D346B4F376C4F376C4E356C4C336D4B316E492F70492E
734A2F784D318153348352337B4B2C7B4E31845A3F8A6248906A519672599C7962A3816A
A98973AF907BB59883BC9F8C
BC9F8BB59783AE907AA88871A180689B785F9470568E684D87604481583B7B5032754828
703F1E6B3716673312663516663A1C653E1F663F21653F22643F22633F22623F23623F24
61402561412761432962452B61452B61442A61432961432961432961432960432960442A
60442B60452C61472E624831644B33654B33664A3267493167472F68462D6A462D6D472D
70482D754B307B503482563A875C40865C41855C418962488F69509571599B7861A1806A
A88872AE907BB59783BC9F8B
BB9F8BB49782AD8F79A686709F7E6798765D916D548A654A835C417C5337754B2D6F4223
693A1A64341461331460341661371961391C603A1E5F3B1F5F3A1E5D391D5C391D5B391D
5B391E5B3A205B3C225C3D245C3F265C40285D42295D42295D42295D42295C41295C4129
5C41295C422B5D452E5F473060483160462F60452E61442D62432C63432B65432B68432B
6B452C6F472E744A30784E337C52377F563B825A408760478D684F936F58997761A07F69
A78772AE8F7AB49783BB9F8B
BB9F8BB49681AC8E78A5856F9E7C6596745B8E6B528762477F583D774F33704528683B1C
6034135B31115830115831135933165A35185A351A5A361A593519583418563217553216
54321854321954341B55361E563920573B22583D24593E26593F28593F27593F27593F28
59402959412B59422C5A422C59412B5A402A5A3F295A3F285C3F285E3F28604028624128
65422968442A6D462D71482E73492E774D337E563D845E468A664E916E579876609F7E69
A68771AD8F7AB49783BB9F8B
BB9E8AB39681AB8D77A4846E9C7B6494725A8C684F835F457B553A734B2F6A4124603517
562B0B4E26074B260A4E2B0F522E13543015553116553116543115533014512F144F2D13
4D2C134D2D144E2F174F321951341B52371F543922553C24563E26563E27563E27553D27
553D27553D27553D28543C27533B26523A24533A24543B25563B25573D26593E275C3E27
5F3E27623F27653F266941276D432873482D79533A805C4487644D8E6D5696755F9D7E68
A48671AC8E7AB39683BB9F8B
BA9E8AB29581AB8C77A2836D9A7A6392705889664D805C427751376E472C653D215C3316
50280C48230845230946250C4C2A114E2D13502F14502F144F2F144E2D144B2B13492A12
472911462710462710482A124B2E164E321B503720523A23533B25533C26523B25523B25
513A244F39244F38244D37224B35204B34204C341F4D341F4F3621513822543923563A24
593B245B3B235D3C24603C23663F276D472E7550397D5A4384634D8C6C5694745F9C7D68
A38571AB8E7AB39682BA9F8B
BA9E8AB29580AA8C77A1826C997862906E5786644C7C5940734E3469432960391E583218
522D1449270E44240B44250D4829104A2B124C2D144D2E154C2D14492A1145260D41230A
3E21093E220B41240D43260F4629134A2F194E351F503924513B26513C27503C254F3A24
4D38234B362248342046321E45301C45301B45301C47311C4A331E4D34204E3621513722
5338225538225737225937215F3C2568442D714F3879584281614C8A6A5592735F9A7C68
A28571AA8D7AB29682BA9E8B
BA9E8AB29580A98B76A1826C9878628E6D5684624A79563E6E4A31643F245A3419532E13
4A280F42230C40230C41250E462912482B144A2D164C2F184C301A4B2F19482D16432914
3D25103B240D3D250F412711432813482E184C36214F3A26503D28503D294F3C284D3A26
4A372248342046321F44301D412D1A3F2A183F2A18412C19452F1B48311D49321E4B341F
4D35214F36215237235639255C3D2964442F6D4D397657427F604C87695590725E987B68
A18471A98D7AB29682BA9E8B
BA9E8AB29580A98B77A0826C9778628D6D5682614A76543C6A462D5D381F542F154E2B11
4C2B13472913432711422711452A15472D17492E194A301B4C331F4F3622513925513924
4D352149331F46331F4835224C3A264D3B274E3B284F3D2A4F3E2C4F3E2C4E3C2A4C3927
48342244301E412E1C3C2A183826143826143A28163C29173F2B18432E1B46301D48311F
4932204A32204B34214F3825573E2C604432694D397256427C5F4B8568558E725E977B68
A08471A98D7AB19682BA9E8B
BA9D8AB29581A98C77A0826D9779638D6E5782614A75533B654229522C1246210846260E
472A13462A15422915412814442B17462E1A482F1C49311D4B34214F3A27523D2B57422F
5C47345B483557443154433051412F4F3E2D4F3D2C4F3E2C4F3E2D503F2E503F2E4F3E2D
4E3E2E4A3B2A4334253B2C1D3828193828183726163826153C2817402C1A442F1E453120
45311F45301F453120483322503A285A412F654A386F5441795E4B8368558C715E967B68
9F8471A88D7AB19683B99E8B
BA9E8BB29682AA8D79A18470987A658E705A83644D75553E6240275331184627103D200B
3E240F412814432B17432B18442D1A462F1D48301F4831204A35234D3A29503F2F544334
5645365747385648395446375144345042324F40304F3F2F4F4030504132504233504232
51423251413051402F4F3D2D483828453324443223433122443222453323453223443121
433121412E1F412E1F4532224B3524553C2A6048366C5241765D4B8167558B715F957B68
9E8471A78D7AB09683B99E8B
BAA08CB39784AB8F7BA286729A7D6890735E8668537A5C466E503960432C553A244A321D
452E19462E1A462F1C442D1B452F1D4732204937264B3A2A4A38284A37274B3B2B4D3F30
4E42354F44375044374F43364E43364F44364F42334F40314F4131504233504235504134
4F41334F41325142335848385A49395544345240304F3D2E4A3A2B463628443426443325
4131234030214030214433244A3627523B2B5D4635695140745C4B7F67558A715F947B69
9E8472A78D7BB09683B99E8C
BBA08CB39885AC907DA488749C806C9377638A6E59816550785C466A4F3A5D4530543D2A
5039254B36234734224431204431204734244938294D3D2F50433652463953473C564C41
5A51475B5349595248575046544C4151473C4F44374E41344E41344F43365044384F4237
4C3E344B3D324D3F325041335243355345375143364D3F32483B2F45372C433429413226
3F30233E2F233F31244536294A392B4E3A2B594334665040725C4C7E6756897261947B6A
9E8573A78E7CB09684B99F8C
BBA08DB49986AD927FA68B779E8370977C688F7460876D59806653755C496A523F604937
574230513C2B4B38274533234432224634254838294B3D304E4337524A3F5751475A554C
5B58505C5A525B595257554D534D434F473C4D43374C42344C42354F443752483C554B41
5349404D4239483C32483B314A3D324B3E334B3E32483C3046392E44362B43352A423329
3F30263E3025413429423429443528473426523D2E644F40725D4D7E6858897362947D6C
9E8674A78E7DB09785B99F8C
BCA18EB59B88AF9582A88E7BA187749A816E937A678D7461866F5C7D6755735E4C6A5442
614C3B5844344F3D2D483627453325453426473729493B2E4B3F334E453A504A40524D45
534F47535048524F47504C444E483F4C43394A40354A3F334A3F334C41364F453A53493F
574E445A4F46574C434F443B483D3345393044393044382F43382E44382F44382E41362C
40342B40352B41362C3F342B41362C4B3D30564538655244725F507F6A5B8A7565957E6E
9E8776A88F7EB19785B99F8D
BCA18FB69C89B09684AA917EA48B799E857398806E927B698D7664866F5E7C6656715D4C
6854445E4B3C53413349382A43332543332544352746382A483B2F493E334B41374C443B
4C463E4C473E4B453D4A433B484138473E35463C32463B31463C31483D334B40354E4339
51473D544B41574D43594E45574D4353483F4F443B4D42394B4139473D35433A31413830
423930443A32443C33443E344740374F453A594B3F675649746255816E5F8C7868968171
A08979A99180B19887BAA08D
BDA28FB79D8BB29986AD9482A78F7DA28A789C857497816F927C6B8A7463826D5D786555
6D5A4B6250415645374A3A2D43332641322542332643352944372B45392F463B31463C32
463D34453E35443D34433B3342393041382E41362D41362C42362D43382F453A31483D33
4B40374E433A51463E534941554B42554B43534A424F463F4B423B473F37443C34423A32
443C344740384B433C4E473F504940554B415C4E4369594D78675A8472648F7B6D988474
A18B7BAA9382B29988BAA08E
BDA390B99F8CB49B89AF9785AA9381A58E7DA18A7A9C86769782728F7C6D8775667E6C5E
736255655649594A3E4D3E3344352940312440312541322641332841342941352B40362C
40362C3F352C3E352B3D342B3C332A3B31283B30273B30273C31283D32293F342C42372F
443A32473E354A40394C433C4D453E4D453E4C443E4A433C47413A443F38423D37423D37
45403A4B46404F4A44544E4758524A5D554D655A507063577D6F6388786B9280729B8779
A38E7FAB9584B39B89BBA18F
BEA491BAA08EB69D8BB19A88AD9685A99383A58F80A18C7D9D897B9582748D7C6E847467
7A6A5E6E5E5360524754473D483C324133293F30253E30243E2F243D2F233C2F243B3026
3A2F26392F25382E25372D24362C23352B22352A22352A22362B23372D25392F273B312A
3E342D413831433B34453D36473F3947403A47403B46403A46403A453F39443F3946413C
4C4843524D4857524D5D5853645F586B645D716A617B716785786D8E7F739685789E8C7D
A69182AD9787B49C8BBBA28F
BFA492BBA290B79F8EB49D8CB09A8AAD9788A99485A59283A18F829A897C9282768A7B6F
7F716672655A65594F594D434E423745372D3E30263C2E233A2D22392B20372A1F36291E
34291F33281F32271E30261D2F251C2F241C2F241C2F251D2F251E312720332922352C25
382F293B322D3D35303F3832403A35423C37423D38433E39433E3A423F3A45413D4B4743
514E4A585651605D5868645F706C6578726C827C7589827A8E837994877B9B8B7FA29082
A99586AF9989B69E8DBCA290
BFA593BCA391B9A190B6A08FB39E8EB09C8DAD9A8BAA9789A694879F8E8297887C8F8075
84776D796D646C61595D544B50473F463B333E322A3A2D24372A2035281E33261B312419
2F22182D21172B1F162A1E15281D14281D14281D15291E172A20192B221B2D251E2F2822
322B26342E2937312C3934303B37333D39353F3B383F3D3A403F3C44423E4947444F4E4B
58575461605C6A686372706B7A7772827E7889837D908981958B829B8E83A09185A69487
AC9889B19C8CB79F8FBDA391
C0A693BDA593BBA493B9A393B7A292B4A192B2A092B09F92AD9D90A5968A9D8F8495887E
8C807780756C726860635A53544C45463E383C322B372B2334281F31241A2E21172B1E13
291B1027190E25180E23160D21160D21160E201610211711221913241C1727201A29231F
2C27222F2A26332E2A35312E3734313936343B39373C3C3A3F3F3D4343424A4B4A545553
5E5F5C69686672716E7B797684827E8E8B87948F8A98918A9C938AA0948AA5968BAA998C
AF9B8DB39E8FB8A190BDA492
C0A694BFA695BDA695BBA696BAA597B8A598B7A699B5A69AB4A59AAD9F95A4988E9B8F87
90867D847A73776E6768615B58514C48413C3C342E352B2430261E2D2118291C1326190F
23150B2013091E12091C11091B100A1A0F09190F0A1A110C1B14101D1714201B17231E1B
27221F2A26232E2A28312F2C3432313636343839373B3C3B3F41404648485053525B5E5D
6769687273717C7C7A87868392908D9D9C99A19F9BA19B94A39A92A69A91AA9B90AD9D90
B19F90B6A191BAA392BEA593
C1A795C0A796BFA898BEA899BDA99BBCAA9DBCAB9FBBACA1BBAEA4B5A9A1ABA199A29890
988E878C837D7D76716E68635E58544D48453E3A35332C262D231D281E1724191120150D
1D1109190E07160C05150B05130A05120905110A06120C09140F0B16120F1A16131D1A18
211F1D2523222928272C2D2C303130343635383A3B3D40404347484C5151575B5C636768
7072737B7D7D86878691918F9A9A97A09F9BA5A29DA7A19BA9A098ABA096AEA095B1A194
B4A294B8A393BBA493BFA594
C1A896C1A998C0AA9AC0AB9CC0AD9FC0AEA2C0B1A5C1B3A9C1B5ACBCB2AAB4ABA4A9A19B
9E9792938C87857F7A77716D68635F57535045413E35312E2B2421251B162015101B100B
160C071309051007030D05010B05010A05020905030B07060D0A09100E0D141211181717
1C1C1C202121252626292B2C2D3132323638393C3E4145474A4F51555B5D6267696E7374
797D7E8588899194939D9F9DA7A7A5AAA9A6ACA9A5ADA8A2AFA69EB0A59CB2A499B4A498
B7A497BAA596BCA595BFA694
C2A896C2AA99C2AC9CC2AE9FC3B0A2C3B2A6C4B6ABC6BAB0C9BFB8C7BEB8BDB5AFB2ABA6
A8A29D9D9792908A86817C79726E6C625F5E514F4E3E3C3C2F2B2A241E1C1D1512170F0C
1109060C05030902000701000500000200000101010303030707070A0C0D0E1011131516
181B1C1D2121222628282D2F2E3336353B3E3D4346484E51545B5E61676A6E74767B8082
878C8D9397989FA3A2A9ACABB3B7B7B7B9B7B4B2AEB4AEA8B4ACA4B5AAA0B6A89DB8A79B
B9A799BBA797BEA796C0A795
C2A997C3AB9AC3AD9DC4B0A1C5B3A5C6B6AAC8BAAFCBBFB6CEC5BECEC7C1C5BFBABBB5B0
B0ABA7A5A19D9895928B88857E7B78706D6C605E5E4F4D4D3E3C3C2F2D2D211E1E171313
0E0B0A08040405010102000100000100010300030500050702070A060B0E0B11140F1619
141B1E19212521282C28303530383D3A4247454E52525B5F60686C6E75797C8285898F91
969B9DA2A7A8AEB2B2B6BABABABDBDBCBDBBBBB8B4B9B4AEB9B0A9B9AEA4B9ACA1BAAA9E
BCA99BBDA899BFA897C0A795
C3A997C4AC9BC5AF9FC6B2A3C7B5A8C9B9ADCBBDB3CEC2B9D1C8C1D4CDC9D0CBC7C6C1BD
BBB7B4B1ADAAA5A29F9795938A88877C7B7A6E6C6C5F5D5D4F4E4E3F3E3F303031242324
1B181A1211130C0B0E08080C06090D050A0F050B11050C12050E140711170B151C0F1B20
1621271D282E242F352D383E384348444F54515C61606A6E6F777B7E85888C92959A9FA2
A7ACAEB4B8B9BEC2C3C5CACAC6C9C9C3C3C1C0BDB9BEB8B2BDB4ADBDB1A8BDAFA4BDADA0
BEAB9DBFAA9AC0A998C1A896
C3AA98C4AD9CC6B0A0C7B3A5C9B7AACBBBAFCEC0B5D1C5BCD4CCC4D9D3CED9D4D0D0CCC8
C6C2BFBCB8B5B2AFADA6A4A29795948987867A78786A69695C5A5B4E4C4D424041363537
2C2D2F2325291C1F23161A1F14191F13191F1019200F1A210F1B23101D2513202818262E
1E2C3425333B2E3B4338454C445157525E64606B706F797E7F878C8E95999CA3A6AAB0B3
B9BEC0C5C9CBCDD2D4D2D8D9CFD3D3C9C9C6C5C2BDC3BCB6C1B8B0C0B4AABFB1A6BFAFA2
BFAD9FC0AB9CC0A999C1A896
C3AA98C5AD9CC7B1A1C8B4A6CAB8ABCDBDB1D0C2B7D3C8BED7CEC7DCD6D0E0DCD8DBD8D6
D1CECBC7C4C2BCBAB8B0AFADA2A1A09493938786867978786C6C6D5F6061525456484A4D
404245393B3F32353A2B3035272D32252C31242C33232D34232F3625323A28353E2C3942
313F4839474F4250574D5A6058646A657076747E82828B9091999C9FA6A9AEB4B6BCC2C3
C9CED0D4D9DBDCE3E5DBE1E2D3D5D4CDCCC9C9C5C0C6BFB8C4BAB2C2B6ACC2B3A7C1B0A3
C1AEA0C1AC9CC1AA99C2A897
C4AA98C5AE9DC7B1A1C9B5A6CBB9ACCEBEB2D1C3B8D5C9C0D9D0C8DED7D1E3DFDBE3E0DD
DBD9D7D2D0CEC7C6C4BABAB8AFAFAEA4A3A39797978989897B7B7C6F6F706465675B5D5F
5355584B4E5246494D41454A3D42483A41473942483A434A3A454C3C484F3E4B53435058
49565E505D6559666C636F756D787E7A8489889195969EA2A4ABAEB2B8BAC1C6C7CED3D4
D8DEDFE2EAECE3EBEDDCDFDFD5D6D4D0CECACCC7C1C9C1B9C6BCB3C5B8ADC3B4A8C3B1A4
C2AFA0C2AC9DC2AA9AC2A997
C4AA98C6AE9DC8B1A1CAB5A6CCBAACCFBEB2D2C4B9D6CAC0DAD0C8DFD8D2E5E2DDE9E9E5
E6E5E3DDDCDBD3D3D1C9C8C7BDBDBCB1B1B0A6A5A59A999A8D8E8F82838478797B707173
696A6C6263655C5E61575B5F53585C52575C52585E52595F535B62555E655962695E686F
656E756C767C737D837B848A858E928F989C9CA3A7A9B0B2B8BDBFC5CACBD0D4D6DADEE0
E5ECEEE8EFF1E2E6E6DCDDDCD6D5D2D2CEC9CEC7C1CBC1B9C8BDB3C6B8AEC5B5A9C4B2A4
C3AFA1C3AD9DC2AB9AC2A997
C4AA98C6AE9DC8B1A1CAB5A6CCBAACCFBEB2D2C4B8D6C9BFDBD0C8E0D8D1E6E1DCEFEEEB
F2F3F1EAEAE9E0E0DFD5D6D5CBCBCBC1C1C1B8B7B8ADADAEA2A2A398989A8D8E90858687
7E8080787A7B7375776F72746E71746C6F736B6F736B70756D727770757A747A7F7A8085
7F868B868D928D9397949B9E9EA4A6A8ADB0B4B8BAC0C4C6CBCFD1D6DADBE2E5E6EAEFEF
EBF0F1E7EBEBE1E3E2DCDBD9D7D4CFD3CDC7CFC7BFCCC1B9C9BDB3C7B9ADC6B5A9C5B2A4
C4AFA1C3AD9DC3AB9AC2A997
C4AA98C6AE9CC8B1A1CAB5A6CCB9ABCFBEB1D2C3B7D6C8BEDACFC6DFD6CFE5DFD9ECE9E5
F4F5F3F7F8F8EEEFEFE3E3E3D9D9D8D0D0CFC8C8C7C0C0C0B7B7B8AEAEAFA5A5A69D9D9E
9797989292938E8F8F8A8B8C86888985868884858884868985888B888B8E8B909393979B
9B9FA3A0A4A7A6A8ABAEB0B2B7BABAC0C2C3C8CBCBD3D5D5DDE0E0E5E8E9ECF0F2F0F7FA
EDF3F5E6E8E8E0E0DEDBD9D5D7D2CCD3CBC4CFC6BDCCC1B7CABCB1C8B8ACC7B5A8C5B2A4
C4AFA0C4AD9DC3AB9AC3A997
C4AA98C6AD9CC8B1A0CAB4A5CCB8AACFBCAFD2C1B5D5C7BBD9CDC3DED4CBE3DBD4E9E4DF
F0EEEAF8F9F8FAFBFBF2F2F1E7E7E6DDDDDCD6D6D5D1D0D0CAC9C9C3C2C1BCBBBAB4B4B4
AEAEAEAAA8A9A5A4A5A2A1A19F9E9F9D9D9E9C9C9D9C9C9E9D9D9F9E9FA0A2A3A4A7A7A8
ADACACB5B5B4BCBCBCC4C4C3CBCBCAD1D1D1D9DAD9E1E2E1E9EBEBF1F4F5F5FBFEF2F8FB
EBEDEDE4E4E2DFDCD9DAD5D0D6CFC8D2C9C1CFC4BBCDBFB5CABBB0C8B8ABC7B5A7C6B2A3
C5AFA0C4AD9CC3AB99C3A997
C4AA98C6AD9BC7B09FC9B3A3CCB7A8CEBBADD1BFB2D4C4B8D8CABFDCD0C6E1D7CFE6DED8
ECE7E2F2EFECF9FAF9FBFCFBF4F4F3EBEBEAE3E2E2DDDDDDD9D9D9D4D4D4CFCECDCCC9C9
C8C5C5C3C0C0BEBBBABAB7B7B7B4B4B4B2B2B3B0B0B3B0B0B4B1B1B5B2B1B5B2B0B7B4B1
BBB9B5BFBCBAC4C2C0CCCAC7D3D2D0DDDCDAE5E5E4ECEDECF3F5F4F8FDFEF5FAFCEEF1F0
E8E7E5E2DFDBDDD8D2D9D1CBD5CBC3D1C6BDCFC2B7CCBDB2CABAADC8B6A9C7B4A5C6B1A2
C5AF9FC4AD9CC3AB99C3A996
C4A997C5AC9AC7AF9EC9B2A2CBB5A6CDB9AACFBDAFD2C1B4D5C6BAD9CBC1DDD1C8E2D8D0
E7DFD8EDE7E2F3F0ECFAFBFAFCFDFDF5F5F4EDEDECE8E7E7E5E4E4E2E1E1DFDDDDDAD7D7
D7D3D3D6D1D1D3CFCED0CBCACCC8C6CBC6C4CAC5C3C8C3C1C8C3C0C9C3C1C9C3C0CAC4C0
CDC7C3D2CCC8D9D3CFDFDAD6E6E2DFEDEBE8F2F1EFF6F7F6FAFEFEF8FCFDF0F2F1E9E9E6
E4E0DCDFD9D3DAD2CBD6CDC4D3C7BED0C3B8CEBFB3CBBBAFCAB8ABC8B5A7C7B2A4C6B0A0
C5AE9EC4AC9BC3AA99C3A996
C3A997C5AB9AC6AE9DC8B0A0CAB3A3CCB6A7CEBAABD0BDB0D3C2B5D6C6BAD9CBC0DDD1C7
E2D7CEE7DED7ECE6E0F2EEEAFBF9F8FFFFFFFBFAFAF1F0EFEBE9E8EAE7E7EAE8E8EBE8E7
E9E5E4E5E1E0E1DCDBE2DCDAE2DCD9DFD7D3DAD2CED7CFCBD7CFCAD6CEC9D6CEC7D6CEC8
D8D0CADDD5CFE3DBD5E8E2DDEEE9E5F4EFECF7F5F2F8FAF9F6F8F8EFEFEDEAE7E3E4DFDA
DFD8D1DBD2CAD7CCC3D4C7BDD1C3B8CEBFB3CCBBAFCAB8ABC9B6A7C7B3A4C6B1A1C5AF9F
C4AD9CC4AB9AC3AA98C3A896
C3A996C4AA98C6AD9BC7AF9EC8B1A1CAB4A4CCB6A7CEB9ABD0BDAFD2C0B3D5C5B8D9C9BE
DCCEC4E0D4CAE5DAD2EAE1DAEFE9E3F5F1EDFBF9F6FBF9F7F5F2F0F2EDEBEFEBEAEFEAE9
EDE8E6EDE7E4EDE5E2EAE1DCE7DDD7E4DAD4E3D8D1E0D6CDDDD2C9DCD1C8DDD3CBDED4CC
E0D6CFE4DBD4E9E1DBEEE8E3F2EDE9F4F0EEF8F7F6F5F4F2EDEAE6E7E2DDE2DBD4DED5CD
DACFC6D7CAC0D4C6BBD1C1B6CEBEB1CCBBAECBB8AAC9B5A7C8B3A4C7B1A1C6AF9FC5AD9D
C4AC9BC4AB99C3A997C3A895
C3A895C4A997C5AB99C6AD9BC7AF9EC8B1A0CAB3A2CBB5A5CDB8A8CFBAACD1BEB0D3C1B4
D6C5B8D9C9BDDCCEC3E0D3C9E4D9D0E9DFD7EEE5DEF5EEE8F9F4EFFAF4EFF4EDE8F0E8E3
F0E8E4F0E7E3EEE3DEEBDFD9E7DCD5E7DBD4E7DAD2E6D9D0E5D9CFE4D8CEE3D7CEE3D8CF
E4DBD2E5DFD7E9E2DCEDE8E3F3F0EDF4F2EEEFEAE5E8E1DBE3DAD3DFD4CBDBCFC5D8CABF
D5C6BAD2C2B6CFBEB1CDBBAECCB8AACAB6A7C9B4A5C8B2A2C6B0A0C6AF9EC5AD9CC4AC9B
C4AB99C3AA98C3A996C2A895
C3A896C3A997C4AA98C5AB99C5AC9AC6AD9CC7AF9EC8B0A0C9B2A2CBB4A4CCB6A7CEB9A9
D0BBACD2BEB0D4C1B4D6C5B8D9C8BCDCCCC1E0D1C6E3D6CBE6D9CFE8DCD2ECE1D6EDE2D9
EBE0D6EADED5EADED6E9DDD5E6D9D1E2D5CCE0D3C9E0D2C7E0D1C6E0D2C7E0D2C7DFD1C6
E0D3C9E5DBD2EBE3DBEAE2DAE6DCD4E3D8CFE0D3CADCCEC4D9CABED6C5B9D3C2B5D1BFB1
CFBCAECDB9ABCBB7A8CAB5A5C9B3A3C8B1A1C7B09FC6AE9EC5AD9CC5AC9BC4AB9AC4AA98
C3AA97C3A996C3A896C2A895
C2A895C3A895C3A896C3A996C4AA97C4AA98C5AB99C5AC9AC6AD9BC6AE9CC7AF9DC8B09F
C9B1A0CAB2A2CBB4A4CCB6A6CEB8A8CFBAAAD1BCADD3BEAFD4C0B1D5C2B3D7C3B5D7C4B5
D7C4B5D7C4B5D7C5B6D8C6B8DBC9BADCCABCDCCBBDDCCBBEDCCBBEDCCBBEDDCCBFDDCDC1
DDCDC2DAC9BDD7C5B8D5C4B6D4C2B4D2BFB1D1BDAFCFBBACCDB8A9CCB6A7CBB4A5C9B3A3
C8B1A1C7B09FC7AF9EC6AE9DC5AD9CC5AC9AC4AB9AC4AB99C4AA98C3AA97C3A997C3A996
C3A896C3A895C2A895C2A794
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?ooo`S2YY<4`JJB2<6UTP?1YI44`:FA1<2TT@S0Y904`:>?1knS
S`RoXXh<_Z6=0kjQS0RnX8`8_J2<1;jPS0BmX8`;_J2;1;jOR`^mWh/4_In:1;fNR`RmWh/4_In<1;jP
S0nnX8d4_Z6=1kjQSPBoXXl4_j>@1;nSTANoXi08`:B@1l2TT@C1YI48`JFB1<6VT`S2YY<Eoooo000D
oooo2<:VT`C1YY88`JFB0l6UT@C0YI44`:BA2<2TT0C0Xhl7_j>?2;nRSPbnXHd3_Z6<2;jPS0RmX8`4
_Z2<1;fPS0^mX8/4_Yn;2kfOR`BmWhX4_Ij;2;fOR`BmWh`4_Z2<3kjPS@BnXHd7_Z6>1;nRS`BoXi04
_j>A5knST0S0Y907`:BA1<6UT@S1YI84`JJC2<:VTaGoool001Coool8`ZJC1<6VTPS1YI83`JFA1<2U
T@C0Y948`:B@1<2SS`NoXhl8_j:>3;jQS@>nXH`8_Z2<2;fPS0BnX8`4_J2<2kfPR`BnWh/;_In;1;fO
RPBmWX/8_In;1;fOS0BnX8`?_Z2=1;jQS@NnXHh4_j:?1;nST0BoXi4G_j>@2<2TT0O0Y944`JFA2<6U
TPC1YY<8`ZJC5Oooo`005?ooo`C2YY<4`JFB1<6TT@C0Y904`:>@0knSS`BoXXh4_Z:=1;jQS@BnX8`4
_J2;0kfORPBlWXX4_9j91;^MR0BkW8L4^Y^61;ZKQ@>jVXD4^IZ41;VIQ0RiVH<8^IV40kVHP`BiV88<
^IR31;VGPP>hUh48^9J12;RFPPBhV8@4^IR50kVIQ@BjVHH<^YZ61;ZKQ`>kW8T4^if:1;bNS0RlX8l4
_9n<2kbOR`RmX8`4_Z2=1;jQS@>nXXh4_j:?1;nST0C0Y904`JFA1<6UTPC2YY<Eoooo000Doooo1<:V
T`C1YI84`JBA1<2TT0C0Xi03_j>?1;nRSPBnXXd4_Z6=1;jPS0BmX8/3_In:1;bNRPBlWXT4^if81;^L
Q`BjVhH4^Y^50kZJQ@BiVX@4^IV42;VIP`RiVH@3^IR31;VHPPbiV8<4^IN20kRGP@RhUX48^9J21;RH
Q0BiV8D3^IV51;ZIQPbjVXH4^Y^70k^LR@BkWHX4_9j<2;bPS`BlWh`;_9n;2;fPS0BnX8d4_Z6=0kjR
SPBoXXl4_j>@1<2TT0C1YI44`JFB1<:VTaGoool001Coool4`ZJC1<6UTPC1Y944`:B@1<2ST0>oXhl4
_j:>1;jRS@BnXHd4_Z2<1;fPR`>mWhX4_9j:1;bNR@BkWHP4^ib71;ZKQPBjVhD3^YZ51;VJQ0BiVH@8
^IV32;VIQ0>iV8<4^IR23;VHP`BiUh83^9N12;RFP@RhUX84^9R41;VHQ@>iVHD4^YV63;ZJQPBjVhL3
^ib91;^MRPBlWX`8_:2?1;bOS0^lWh/8_J2<1;jPS@BnXHd3_Z:>1;nRS`BoXi04`:B@1<6UT@C1YI84
`ZJC5Oooo`005?ooo`C2YY<4`JFB1<6TT@C0Y904`:>@0knSS`BoXXh4_Z:=1;jQS@BnX8`4_J2;0kfO
RPBlWXX4_9j91;^MR0BkW8L4^Y^61;ZKQ@>jVXD4^IZ41;VIQ0RiVH<8^IV40kVHP`BiV88<^IR31;VG
PP>hUh48^9J12;RFPPBhV8@4^IR50kVIQ@BjVHH<^YZ61;ZKQ`>kW8T4^if:1;bNS0RlX8l4_9n<2kbO
R`RmX8`4_Z2=1;jQS@>nXXh4_j:?1;nST0C0Y904`JFA1<6UTPC2YY<Eoooo000Doooo1<6VT`C1YI84
`:B@1;nSS`BoXXh3_Z6=1;fPS0BmWhX4_9j91;^MR0BkW8L3^Y^61;VJQ0BiVH<4^9R21;NGP@BfUX04
]YEn0kFDO@BeTg`8]99k1;BANPBdTG/;]95j2;BAN`BeTG/4]95k1kBAO0ReT7`4]Y5m1;JCO`NgU808
]Y=o1;FCO`BeU804]YF10kNFP`BgV8@4^9V71;ZLRPBjWHX4^I^71kVJQPBjVhL4^Yb71;^LR0BkWHT4
_9j:0kfOR`BmX8`4_Z6=1;nRS`C0Xi04`JFA1<6VTQGoool001Coool4`JJC1<6UTPC0Y904_j>?1;nR
SP>nXHd4_J2<1;fORPBlWXT4^if81;^LQ`>jVhH4^IZ41;VIP`BhV884]iN11;JFP0BfUGh3]IAm1;FC
O0RdTW/4]95j1;BAN`^dTGX8]95k1;FAN`BdTG/7]95l2;F@O0BfTGd4]Y=o1kNDP0RfTgl4]I=o1;FD
P0BfUH43]iJ31;NHQ0BhVHL4^Yb:1;ZMRPBiVhL7^IZ61;ZKQ`BjW8L4^ib81;^MR@BlWXX3_In;1;fP
S0BnXHd4_j:?1<2ST0C1YI44`JJB5Oooo`005?ooo`C1YY<4`JFB1<2TT0BoXhl4_j:>0kjQS@BmX8`4
_In:1;bNR@BkWHP4^ib70kZKQPBiVX@4^IV31;RHPPBgUh44]YJ01;JEOP>eU7d4]I=l2;BBN`BdTGX4
]95k2kBANPRdTG/4]I5k1;BAN`NdTG`8]I1l1;JAO@BfTgl7]iB02;JCO`BeTgl4]IB01;JEP@>gUX<4
]iR41;RIQ`BjW8X4^Yf:1;VKQ`NiVXH4^Y^71;ZLQ`BkW8P4^if91;bNRP>mWh/4_J2<1;jQS@BoXXl4
`:>@1<6UT@C1YY8Eoooo000Doooo1<6VT`C1YI84`:B@1;nSS`BoXXh3_Z6=1;fPS0BmWhX4_9j91;^M
R0BkW8L3^Y^61;VJQ0BiVH<4^9R21;NGP@BfUX04]YEn0kFDO@BeTg`8]99k1;BANPBdTG/;]95j2;BA
N`BeTG/4]95k1kBAO0ReT7`4]Y5m1;JCO`NgU808]Y=o1;FCO`BeU804]YF10kNFP`BgV8@4^9V71;ZL
RPBjWHX4^I^71kVJQPBjVhL4^Yb71;^LR0BkWHT4_9j:0kfOR`BmX8`4_Z6=1;nRS`C0Xi04`JFA1<6V
TQGoool001Coool4`JJB1<2UT@BoXi04_Z:>1;fQS0>mWh/4_9j91;^MR0BjW8H4^IZ51;RIP`>gUh44
]YIo1;FDOPBdTg`4/i9j1;>@N@BbSgL3/Hee1;2<M0B_Rg88[hYa3jn:LPB`RW84/8Yc1;2;M0BaS7H3
/heh1;>>NPBcSgX4]8ij1;B>N@BdSGT4]8ij0kB=NPBdSGT4/hii1;>>NPBbSgX4/i1k0k>AO@BdTWh4
]9>01;FDP@ReUH44]YF10kJFP@BgUh84]iR31;RIQ0BiVXD4^Y^60k^LR0BlWXT4_In;1;jQS@BoXXh4
`:B@1<6UTQGoool001Coool4`JJB1<2UT@BoXi04_Z:>1;fQS0>mWh/4_9j91;^MR0BjW8H4^IZ51;RI
P`>gUh44]YIo1;FDOPBdTg`4/i9j1;>@N@BbSgL3/Hee1;2<M0B_Rg88[hYa3jn:LPB`RW84/8Yc1;2;
M0BaS7H3/heh1;>>NPBcSgX4]8ij1;B>N@BdSGT4]8ij0kB=NPBdSGT4/hii1;>>NPBbSgX4/i1k0k>A
O@BdTWh4]9>01;FDP@ReUH44]YF10kJFP@BgUh84]iR31;RIQ0BiVXD4^Y^60k^LR0BlWXT4_In;1;jQ
S@BoXXh4`:B@1<6UTQGoool001Coool4`JJB1<2UT@BoXi04_Z:>1;fQS0>mWh/4_9j91;^MR0BjW8H4
^IZ51;RIP`>gUh44]YIo1;FDOPBdTg`4/i9j1;>@N@BbSgL3/Hee1;2<M0B_Rg88[hYa3jn:LPB`RW84
/8Yc1;2;M0BaS7H3/heh1;>>NPBcSgX4]8ij1;B>N@BdSGT4]8ij0kB=NPBdSGT4/hii1;>>NPBbSgX4
/i1k0k>AO@BdTWh4]9>01;FDP@ReUH44]YF10kJFP@BgUh84]iR31;RIQ0BiVXD4^Y^60k^LR0BlWXT4
_In;1;jQS@BoXXh4`:B@1<6UTQGoool001Coool4`JJB1<2UT@BoXi04_Z:>1;fQS0>mWh/4_9j91;^M
R0BjW8H4^IZ51;RIP`>gUh44]YIo1;FDOPBdTg`4/i9j1;>@N@BbSgL3/Hee1;2<M0B_Rg88[hYa3jn:
LPB`RW84/8Yc1;2;M0BaS7H3/heh1;>>NPBcSgX4]8ij1;B>N@BdSGT4]8ij0kB=NPBdSGT4/hii1;>>
NPBbSgX4/i1k0k>AO@BdTWh4]9>01;FDP@ReUH44]YF10kJFP@BgUh84]iR31;RIQ0BiVXD4^Y^60k^L
R0BlWXT4_In;1;jQS@BoXXh4`:B@1<6UTQGoool001Coool4`JFB1<2TT0BoXhl4_J6=1;bOR`>kWHT4
^Yb71;VJQ@BhVH<4]iN11;FEO`>dTgd4/i9j1;:@N0BaSWH4/8ad1:n:LPB^RFl3[8M]1:^5J`BZPfT4
ZX9X1:V2I`BZPVP4ZX=X0jZ3J@B[PfX4Zh=[1:^4K0B/QFh4[HI_0jf7L@B^R7<4[XUd1:n:M@R`RWD4
/8Ud0k2:M0BaRG@4/8Qc1;29M0B_RG@4[hYd0jn:M@B`S7L4/Hii2;6?NPBbSgX4/Y1j0k>AN`BcTW`4
]9=n1;FEO`BgUX44^9R30kVJQ@BjVhL4^if91;fOR`BnXHd4_j>?1<6UTQGoool001Coool4`JFB1<2T
T0BoXhl4_J6=1;bOR`>kWHT4^Yb71;VJQ@BhVH<4]iN11;FEO`>dTgd4/i9j1;:@N0BaSWH4/8ad1:n:
LPB^RFl3[8M]1:^5J`BZPfT4ZX9X1:V2I`BZPVP4ZX=X0jZ3J@B[PfX4Zh=[1:^4K0B/QFh4[HI_0jf7
L@B^R7<4[XUd1:n:M@R`RWD4/8Ud0k2:M0BaRG@4/8Qc1;29M0B_RG@4[hYd0jn:M@B`S7L4/Hii2;6?
NPBbSgX4/Y1j0k>AN`BcTW`4]9=n1;FEO`BgUX44^9R30kVJQ@BjVhL4^if91;fOR`BnXHd4_j>?1<6U
TQGoool001Coool4`JFB1<2TT0BoXhl4_J6=1;bOR`>kWHT4^Yb71;VJQ@BhVH<4]iN11;FEO`>dTgd4
/i9j1;:@N0BaSWH4/8ad1:n:LPB^RFl3[8M]1:^5J`BZPfT4ZX9X1:V2I`BZPVP4ZX=X0jZ3J@B[PfX4
Zh=[1:^4K0B/QFh4[HI_0jf7L@B^R7<4[XUd1:n:M@R`RWD4/8Ud0k2:M0BaRG@4/8Qc1;29M0B_RG@4
[hYd0jn:M@B`S7L4/Hii2;6?NPBbSgX4/Y1j0k>AN`BcTW`4]9=n1;FEO`BgUX44^9R30kVJQ@BjVhL4
^if91;fOR`BnXHd4_j>?1<6UTQGoool001Coool4`JFB1<2TT0BoXhl4_J6=1;bOR`>kWHT4^Yb71;VJ
Q@BhVH<4]iN11;FEO`>dTgd4/i9j1;:@N0BaSWH4/8ad1:n:LPB^RFl3[8M]1:^5J`BZPfT4ZX9X1:V2
I`BZPVP4ZX=X0jZ3J@B[PfX4Zh=[1:^4K0B/QFh4[HI_0jf7L@B^R7<4[XUd1:n:M@R`RWD4/8Ud0k2:
M0BaRG@4/8Qc1;29M0B_RG@4[hYd0jn:M@B`S7L4/Hii2;6?NPBbSgX4/Y1j0k>AN`BcTW`4]9=n1;FE
O`BgUX44^9R30kVJQ@BjVhL4^if91;fOR`BnXHd4_j>?1<6UTQGoool001Coool4`JFB1;nSS`BnXHd4
_In;1;^MR@>jVhH4^9Z41;NHPPBfUWl4]9Am1;>BNP>bT7P4/8ee1:n;L`B^RG04[8M]1:^5J`BYPVP3
Z81U1:InHPBUNel4Y7UM1:=hG0BTNEd4YG]O0jElH@BVO684YWeS1:MmI@BWOVH4Z7iW0jQoJ0BYP6T4
ZX9/1:Z3K@R[Pfd?Zh=/2:^2J`BZPfd3ZXA]1:^5K`B/R7<4[HUd1:f9LPB^RG<4[XYc0jn;M@B`SGH4
/Hmh1;>AN`BdTWd4]IEo0kNGPPBhVH@4^Y^61;bMR@BmX8`4_j:>1<2UTAGoool001Coool4`JFB1;nS
S`BnXHd4_In;1;^MR@>jVhH4^9Z41;NHPPBfUWl4]9Am1;>BNP>bT7P4/8ee1:n;L`B^RG04[8M]1:^5
J`BYPVP3Z81U1:InHPBUNel4Y7UM1:=hG0BTNEd4YG]O0jElH@BVO684YWeS1:MmI@BWOVH4Z7iW0jQo
J0BYP6T4ZX9/1:Z3K@R[Pfd?Zh=/2:^2J`BZPfd3ZXA]1:^5K`B/R7<4[HUd1:f9LPB^RG<4[XYc0jn;
M@B`SGH4/Hmh1;>AN`BdTWd4]IEo0kNGPPBhVH@4^Y^61;bMR@BmX8`4_j:>1<2UTAGoool001Coool4
`JFB1;nSS`BnXHd4_In;1;^MR@>jVhH4^9Z41;NHPPBfUWl4]9Am1;>BNP>bT7P4/8ee1:n;L`B^RG04
[8M]1:^5J`BYPVP3Z81U1:InHPBUNel4Y7UM1:=hG0BTNEd4YG]O0jElH@BVO684YWeS1:MmI@BWOVH4
Z7iW0jQoJ0BYP6T4ZX9/1:Z3K@R[Pfd?Zh=/2:^2J`BZPfd3ZXA]1:^5K`B/R7<4[HUd1:f9LPB^RG<4
[XYc0jn;M@B`SGH4/Hmh1;>AN`BdTWd4]IEo0kNGPPBhVH@4^Y^61;bMR@BmX8`4_j:>1<2UTAGoool0
01Coool4`:FA1;nRS`BmX8`4_9j91;ZLQ`>hVH@4]iN11;FEO`BdTg`4/Y1i1;2>MP>_S7<4[HU`1:b7
K@BZQ6X4ZH9W1:MoI0BUO603XgUM1:9fF@BOLeD4WFmA19a]CPBNKe44X7=G0j5eFPBQMU/4XWIL1:9g
G@BRMeh4XgMN0j=hG`BSN604Y7QQ1:AhHPBUNF88YGYR0jEjH`BUNf<8YW]R1:EkHPBUNf<3YWeU1:Mn
I`BWP6T4Z85Z1:V1JPBYPV/4ZXA/0jb6KPB]R704[XYc1;2=MPBbSgT4/i9l0kFDOPBgUh44^IV41;^K
Q`BlWXX4_Z6>1<2TTAGoool001Coool4`:FA1;nRS`BmX8`4_9j91;ZLQ`>hVH@4]iN11;FEO`BdTg`4
/Y1i1;2>MP>_S7<4[HU`1:b7K@BZQ6X4ZH9W1:MoI0BUO603XgUM1:9fF@BOLeD4WFmA19a]CPBNKe44
X7=G0j5eFPBQMU/4XWIL1:9gG@BRMeh4XgMN0j=hG`BSN604Y7QQ1:AhHPBUNF88YGYR0jEjH`BUNf<8
YW]R1:EkHPBUNf<3YWeU1:MnI`BWP6T4Z85Z1:V1JPBYPV/4ZXA/0jb6KPB]R704[XYc1;2=MPBbSgT4
/i9l0kFDOPBgUh44^IV41;^KQ`BlWXX4_Z6>1<2TTAGoool001Coool4`:FA1;nRS`BmX8`4_9j91;ZL
Q`>hVH@4]iN11;FEO`BdTg`4/Y1i1;2>MP>_S7<4[HU`1:b7K@BZQ6X4ZH9W1:MoI0BUO603XgUM1:9f
F@BOLeD4WFmA19a]CPBNKe44X7=G0j5eFPBQMU/4XWIL1:9gG@BRMeh4XgMN0j=hG`BSN604Y7QQ1:Ah
HPBUNF88YGYR0jEjH`BUNf<8YW]R1:EkHPBUNf<3YWeU1:MnI`BWP6T4Z85Z1:V1JPBYPV/4ZXA/0jb6
KPB]R704[XYc1;2=MPBbSgT4/i9l0kFDOPBgUh44^IV41;^KQ`BlWXX4_Z6>1<2TTAGoool001Coool4
`:FA1;nRS`BmX8`4_9j91;ZLQ`>hVH@4]iN11;FEO`BdTg`4/Y1i1;2>MP>_S7<4[HU`1:b7K@BZQ6X4
ZH9W1:MoI0BUO603XgUM1:9fF@BOLeD4WFmA19a]CPBNKe44X7=G0j5eFPBQMU/4XWIL1:9gG@BRMeh4
XgMN0j=hG`BSN604Y7QQ1:AhHPBUNF88YGYR0jEjH`BUNf<8YW]R1:EkHPBUNf<3YWeU1:MnI`BWP6T4
Z85Z1:V1JPBYPV/4ZXA/0jb6KPB]R704[XYc1;2=MPBbSgT4/i9l0kFDOPBgUh44^IV41;^KQ`BlWXX4
_Z6>1<2TTAGoool001Coool4`:BA1;jRSPBmWh/4^ib81;VJQ@>gUh84]IEo1;>BN`BbT7P4/8ee1:j:
LP>/R6l4ZXE[1:R2J0BWOf@4YGaQ1:=iG@BQMUT3Wg=E19e_D@BJJd/4UFA319ETA0BJJd`4W6i@0ie_
D`bML5D4WG1F1ii_E@bNKUD4WViF19i_E`BNL5P3Wg5H19mbF@BOLeT4X7=J1:1dFPBQM5/3XGIL1:9g
G@BSN5h4XgUO1:AjH0BUNf84YWiT0jR0I`BYPfX4ZhE]1:f8L@B_Rg@4/Hih0k>AN`BeUGl4]iR31;VK
QPBlWXX4_Z6=1<2TT1Goool001Coool4`:BA1;jRSPBmWh/4^ib81;VJQ@>gUh84]IEo1;>BN`BbT7P4
/8ee1:j:LP>/R6l4ZXE[1:R2J0BWOf@4YGaQ1:=iG@BQMUT3Wg=E19e_D@BJJd/4UFA319ETA0BJJd`4
W6i@0ie_D`bML5D4WG1F1ii_E@bNKUD4WViF19i_E`BNL5P3Wg5H19mbF@BOLeT4X7=J1:1dFPBQM5/3
XGIL1:9gG@BSN5h4XgUO1:AjH0BUNf84YWiT0jR0I`BYPfX4ZhE]1:f8L@B_Rg@4/Hih0k>AN`BeUGl4
]iR31;VKQPBlWXX4_Z6=1<2TT1Goool001Coool4`:BA1;jRSPBmWh/4^ib81;VJQ@>gUh84]IEo1;>B
N`BbT7P4/8ee1:j:LP>/R6l4ZXE[1:R2J0BWOf@4YGaQ1:=iG@BQMUT3Wg=E19e_D@BJJd/4UFA319ET
A0BJJd`4W6i@0ie_D`bML5D4WG1F1ii_E@bNKUD4WViF19i_E`BNL5P3Wg5H19mbF@BOLeT4X7=J1:1d
FPBQM5/3XGIL1:9gG@BSN5h4XgUO1:AjH0BUNf84YWiT0jR0I`BYPfX4ZhE]1:f8L@B_Rg@4/Hih0k>A
N`BeUGl4]iR31;VKQPBlWXX4_Z6=1<2TT1Goool001Coool4`:BA1;jRSPBmWh/4^ib81;VJQ@>gUh84
]IEo1;>BN`BbT7P4/8ee1:j:LP>/R6l4ZXE[1:R2J0BWOf@4YGaQ1:=iG@BQMUT3Wg=E19e_D@BJJd/4
UFA319ETA0BJJd`4W6i@0ie_D`bML5D4WG1F1ii_E@bNKUD4WViF19i_E`BNL5P3Wg5H19mbF@BOLeT4
X7=J1:1dFPBQM5/3XGIL1:9gG@BSN5h4XgUO1:AjH0BUNf84YWiT0jR0I`BYPfX4ZhE]1:f8L@B_Rg@4
/Hih0k>AN`BeUGl4]iR31;VKQPBlWXX4_Z6=1<2TT1Goool001Coool4`:B@1;jQS@BlWXT4^Y^61;RH
P`>fUWl4/i=l1;6@N0B_SGD4[HYa1:^7KP>YQ6X4Yh5V1:EnH`BSNel4XGMK19mdEPBML583Vfe>19UY
B@BFI4<4U65019ES@`BHJ4T4VFU;1iUZC@BIJTh4VFU=19UYCPBIJDl3V6M>19QVC0BHI4/4V69:19MR
B@BGI4/4V6I=0iQXCPBHJE04VF]A19Y/D@RKKE83W6eB29a]D@BNKe<4Wg5F1:1dF@BRMe`3Y7YP1:Im
I0BXPFP4ZXA/1:b8L0B_Rg@3/Hmh1;>BO0BfUX04^9V41;^MR0BmX8`4`:>@5Oooo`005?ooo`C0Y904
_Z6=1;bNR@BjVhH4^9R30kJFO`BcTg`4/I1h1:n=M@B]RW44ZhM^0jV4JPBWPFH4YGiS1:=kG`BQMe/4
WgAF19e`DP>KKDh4VFU919IT@`BDHD04UF=319QXB@BIJD/7VFY=19UZCPBIJDd4VFU>19UYC`>HIdh4
V6I<19QTB`BHHTX4Uf9919MTB`BHITd3V6Q>19QYD0BIJe44VVaA29]]DP>LKE88W6eA19i_D`BOLEH4
X7AI1:9gG0>TNV04YWeT1:R1J0BZQ6`4[8Q`1:n;M0>aSgP4/i9l1;JFP0BhVH@4^if81;fPS0C0Xi0E
oooo000Doooo1<2TT0BnXHd4_9j91;ZKQPBhV8<3]YIo1;>CO0BaT7P4[hee1:f:L@B[Qfh3ZHAZ1:N1
IPBUOV<4Xg]O1:5gF`BOM5H4WG1B0i]]CPBIJDT4UVA319AQ@0BEHd<4V6Q919UYB`NIJTd4VFY>19UY
C@BIJDh4VFU?0iQWCPBHIT`4V6A;19QRBPBGHTT4UfA;19QVC@>HJ4h4V6U@19U[D@BJK548VfeB0ia]
DPRLKE44WVmC19maEPBPM5T4XWML0jAjH0BVOF@4Z85X1:Z4K0B/R704[h]d0k6?N0BcTW`4]YJ01;RI
Q0BkWHP4_J2<1<2ST1Goool001Coool4`:B@1;jQS@BlWXT4^Y^61;RHP`>fUWl4/i=l1;6@N0B_SGD4
[HYa1:^7KP>YQ6X4Yh5V1:EnH`BSNel4XGMK19mdEPBML583Vfe>19UYB@BFI4<4U65019ES@`BHJ4T4
VFU;1iUZC@BIJTh4VFU=19UYCPBIJDl3V6M>19QVC0BHI4/4V69:19MRB@BGI4/4V6I=0iQXCPBHJE04
VF]A19Y/D@RKKE83W6eB29a]D@BNKe<4Wg5F1:1dF@BRMe`3Y7YP1:ImI0BXPFP4ZXA/1:b8L0B_Rg@3
/Hmh1;>BO0BfUX04^9V41;^MR0BmX8`4`:>@5Oooo`005?ooo`C0Y904_J6<1;^MR@BiVXD4]YN10kBD
O@BbTGT4/8ef1:f:LPB[Qfh4ZHAZ0jN0IPBTOF84XWUM1:1fF@BNLU@4Vfm@19U[B`>GIdH4UF=219=P
?0BHIT84VfY919MVAPBFIDH3UFA619ESA@RDHdH4U69619AQAP>CH4H4Tei4199M@`RBG484TUa3195M
A0>BGdD4Tf5619=SB0BDI4T4UVE:19MVBP>HITX4V6E819MSA@BHI4H4VVQ;19a/C`BNL5@3X7AI1:9h
G@BTO684Yh1W1:V4J`B/R703[hae1;:@N@BdU7h4]iN21;ZKQ`BmWh/4_j>?5Oooo`005?ooo`C0Y904
_J6<1;^MR@BiVXD4]YN10kBDO@BbTGT4/8ef1:f:LPB[Qfh4ZHAZ0jN0IPBTOF84XWUM1:1fF@BNLU@4
Vfm@19U[B`>GIdH4UF=219=P?0BHIT84VfY919MVAPBFIDH3UFA619ESA@RDHdH4U69619AQAP>CH4H4
Tei4199M@`RBG484TUa3195MA0>BGdD4Tf5619=SB0BDI4T4UVE:19MVBP>HITX4V6E819MSA@BHI4H4
VVQ;19a/C`BNL5@3X7AI1:9hG@BTO684Yh1W1:V4J`B/R703[hae1;:@N@BdU7h4]iN21;ZKQ`BmWh/4
_j>?5Oooo`005?ooo`C0Y904_J6<1;^MR@BiVXD4]YN10kBDO@BbTGT4/8ef1:f:LPB[Qfh4ZHAZ0jN0
IPBTOF84XWUM1:1fF@BNLU@4Vfm@19U[B`>GIdH4UF=219=P?0BHIT84VfY919MVAPBFIDH3UFA619ES
A@RDHdH4U69619AQAP>CH4H4Tei4199M@`RBG484TUa3195MA0>BGdD4Tf5619=SB0BDI4T4UVE:19MV
BP>HITX4V6E819MSA@BHI4H4VVQ;19a/C`BNL5@3X7AI1:9hG@BTO684Yh1W1:V4J`B/R703[hae1;:@
N@BdU7h4]iN21;ZKQ`BmWh/4_j>?5Oooo`005?ooo`C0Y904_J6<1;^MR@BiVXD4]YN10kBDO@BbTGT4
/8ef1:f:LPB[Qfh4ZHAZ0jN0IPBTOF84XWUM1:1fF@BNLU@4Vfm@19U[B`>GIdH4UF=219=P?0BHIT84
VfY919MVAPBFIDH3UFA619ESA@RDHdH4U69619AQAP>CH4H4Tei4199M@`RBG484TUa3195MA0>BGdD4
Tf5619=SB0BDI4T4UVE:19MVBP>HITX4V6E819MSA@BHI4H4VVQ;19a/C`BNL5@3X7AI1:9hG@BTO684
Yh1W1:V4J`B/R703[hae1;:@N@BdU7h4]iN21;ZKQ`BmWh/4_j>?5Oooo`005?ooo`C0Xi04_J2<1;ZL
Q`BhVH<4]IJ00k>BN`B`SWL4[X]c1:^7KPBYQ6X4YX1V0jAlH@BQNEd4WgEH19aaD`BJKDl4V6U:19EU
A@>CHCl4T5/h19EQ?PBKJDP4UfI419ES@PBCHD43TElo191N?PB@GCh4Sedo18mL?`B?Fcl3SeXo18iH
?PB>EC`8SE@k18eD?0B=EC`3SEPn18eI?`B>G444Sei2191O@`BBH4<3Tf1219=N?`RBFcX4UF1019MT
APBIJD/3W6iA19ibE`BQMe`4Y7]R1:N0I`BZQ6`3[HUa1;2=MPBcTG/4]YJ01;VJQ@BlWXX4_j>?5Ooo
o`005?ooo`C0Xi04_J2<1;ZLQ`BhVH<4]IJ00k>BN`B`SWL4[X]c1:^7KPBYQ6X4YX1V0jAlH@BQNEd4
WgEH19aaD`BJKDl4V6U:19EUA@>CHCl4T5/h19EQ?PBKJDP4UfI419ES@PBCHD43TElo191N?PB@GCh4
Sedo18mL?`B?Fcl3SeXo18iH?PB>EC`8SE@k18eD?0B=EC`3SEPn18eI?`B>G444Sei2191O@`BBH4<3
Tf1219=N?`RBFcX4UF1019MTAPBIJD/3W6iA19ibE`BQMe`4Y7]R1:N0I`BZQ6`3[HUa1;2=MPBcTG/4
]YJ01;VJQ@BlWXX4_j>?5Oooo`005?ooo`C0Xi04_J2<1;ZLQ`BhVH<4]IJ00k>BN`B`SWL4[X]c1:^7
KPBYQ6X4YX1V0jAlH@BQNEd4WgEH19aaD`BJKDl4V6U:19EUA@>CHCl4T5/h19EQ?PBKJDP4UfI419ES
@PBCHD43TElo191N?PB@GCh4Sedo18mL?`B?Fcl3SeXo18iH?PB>EC`8SE@k18eD?0B=EC`3SEPn18eI
?`B>G444Sei2191O@`BBH4<3Tf1219=N?`RBFcX4UF1019MTAPBIJD/3W6iA19ibE`BQMe`4Y7]R1:N0
I`BZQ6`3[HUa1;2=MPBcTG/4]YJ01;VJQ@BlWXX4_j>?5Oooo`005?ooo`C0Xi04_J2<1;ZLQ`BhVH<4
]IJ00k>BN`B`SWL4[X]c1:^7KPBYQ6X4YX1V0jAlH@BQNEd4WgEH19aaD`BJKDl4V6U:19EUA@>CHCl4
T5/h19EQ?PBKJDP4UfI419ES@PBCHD43TElo191N?PB@GCh4Sedo18mL?`B?Fcl3SeXo18iH?PB>EC`8
SE@k18eD?0B=EC`3SEPn18eI?`B>G444Sei2191O@`BBH4<3Tf1219=N?`RBFcX4UF1019MTAPBIJD/3
W6iA19ibE`BQMe`4Y7]R1:N0I`BZQ6`3[HUa1;2=MPBcTG/4]YJ01;VJQ@BlWXX4_j>?5Oooo`005?oo
o`BoXhl4_9n;1;ZLQ`BgV884]9An0k6@N@B^S7@4[8Q`1:V5J`BVPFL4Y7eR0j5iG@BNMEP4W75C19U]
CPBFJ4T4U6A3195P?P>?G3T4U60m19MT@PBEHT04Tf4o195O?PB?GC`3SEXi18aH=`B;EcL8RUHh18YE
>@>:ECX4RULl18YH?@B9F3d4RETm18UG?@B8E3X3R5<i18MD>PB8Ec/4RUTm18]J?@B=Fch3SU`n18mK
?0B?F3P4SUDb18mF=0BBGC`4UF930iMWBPBJK504WG9F1:1gG@BTO6<4Yh5X0jZ6KPB^Rg@4/I1j1;FE
O`BhVH@4^ij91;nRSaGoool001Coool4_j>?1;bOR`BjW8L4]iR21;BDOP>aT7T4[Xad1:b8L0BYQF/4
YX5W1:AmHP>QNEd4WWEH19aaD`BIKDh4UVQ919AT@`BAH3h3Se`i19AP?@BGI484UF9019=Q?`BAGch4
Sedl0heJ>@B<F3L4ReLg28YF>0B:ECT3RUDj18YG?0B:F3d4REPm18UI?@B9Ecd4R5@j0hQC>@B7E3X4
R5Lk18YI?@B;FSd4SE/n0hiL?PB?Fc`4SePh18iE<PB?ES@4TUdl19ER@`>GIdX4VVa@19ebEPBPMed4
Y7aS1:N1J0>ZQVh4[X]d1;6@NPBeUGl4^9V41;^NR@BoXXlEoooo000Doooo1;nSS`BlWh/4^Yb71;NH
PPBdU7h3/I1i1:j<M0B/R704ZHE[1:J1I`BTOF83XGUM19ieF0BLLE<4VFe>19IXB@BDI4<4TF0n0hmL
>@BDH3d4UfA219ER@0BCHCl4TEln18mM?0>=FST4S5Pg18]G=`R:ESP4RUDi0hYE>PB:Ec`4RUPm18UH
?@B9FCd4RELm18QD>P>8DcT4Qe@j18QG>`B:FCd4ReXm18eK?P>>G3h4Se/l18mH>0B>EC84SeHd199M
?0BEHT<3UfM:19Y/D0BMLUH4X7MM1:AlH`BWPFP3ZXI^1:j;M0BaT7X4]IEo1;RIQ0BkWXT4_j:?5Ooo
o`005?ooo`BoXhl4_9n:1;VKQPBfUh44/i9l0k2>M`B]RW84ZXI]1:N2J0BTOV<4XGUN0iieF@BKLE@4
VFa>19IXB@BCHd<4T5lm18eJ=`>9EC04RUHa191L>0B@GCX4Sedj18eK>PB;FCL3REHd18IB<PB5DC84
QE4c18AA<`B4DS@3QE@g18IJ?@B6GT84Qf5518MRAPB5GD44PeLl0h=D>0B3DSL4Q5<g18EE>0B7ESP4
R5Li0hYH>PB;F3P4ReHe18]C<@B;DS04SEDd191K>`>CHD<4UVM:19U]D@BMLeP4XGQN1:EnI@>XPf/4
[8Ua1;2>M`BcTgd4]iR31;^MR@BnXXhEoooo000Doooo1;nSS`BlWhX4^I^61;JGP@BcTW`3/8ig1:f:
LPBZQVd4Yh9X1:AnH`BQNEh3WWEI19]aE0BIK4h4UVQ919=S@`B@Gcd4SEXg0hUE<0B:ES44T5`h191M
>PB?GCX4SE/j18]I=`>9ES@4QU8b18EA<PB5DC<4Q54c18AB=0>5E3L4QUXm18IN@PB7HDD4Qf9618EM
@@B3Ec`3Pe@h18=B=`B4DcL4QEDh18MF>0B8EcT3RUPj18]H>0B;ESD4Re<a18]B<0B=EC@4T5/k0i=Q
@`BFIdX4VFeA19ecF0BQN5h4YGiU0jR3J`B/RG44/8ig1;>CO@BgV8<4^if91;jRSQGoool001Coool4
_j>?1;bORPBiVhH4]YN11;>BO0>`SWL4[HYb1:Z6K@BWPVP4Y7iS1:5iGP>NMET4Vg5D19U/CPBFJ4T4
Tf=3191O?@B=FSL3RED`18YF<@B@G3P4T5dj18mM>PB=FcX4ReTg0hUF=0B6DS84QE4b18EA<`B4DC<4
Q58d0hED=`B6FSd4QUi218MQA@B7HTH4QEe118=G?0>3E3P4Pe8g18AC=`B5ECP4QeHh18QG>@>:F3X4
RePh18]F=@B;Dc44Re8`18eE=0B@Fc/3Tf5319IWBPBIKE44WG=H1:5hGPBUOVD3Z8=[1:b9L@B`SWL4
/i=m1;NHP`BkWHT4_Z:>5Oooo`005?ooo`BoXhl4_9n:1;VKQPBfUh44/i9l0k2>M`B]RW84ZXI]1:N2
J0BTOV<4XGUN0iieF@BKLE@4VFa>19IXB@BCHd<4T5lm18eJ=`>9EC04RUHa191L>0B@GCX4Sedj18eK
>PB;FCL3REHd18IB<PB5DC84QE4c18AA<`B4DS@3QE@g18IJ?@B6GT84Qf5518MRAPB5GD44PeLl0h=D
>0B3DSL4Q5<g18EE>0B7ESP4R5Li0hYH>PB;F3P4ReHe18]C<@B;DS04SEDd191K>`>CHD<4UVM:19U]
D@BMLeP4XGQN1:EnI@>XPf/4[8Ua1;2>M`BcTgd4]iR31;^MR@BnXXhEoooo000Doooo1;nRS`BkWXX4
^9Z41;FEO`BaT7X3[Xad1:^8K`BXPfX4YGmU1:9kH0BOMUX3W79E19U]C`BEJ4T4TV=318mO?@B<FSL4
R5@`0h]F<PB>FSH4SEXg18aI=`B;FCP4REPg18ME=0>5DS44PTh^181<;@B0C2h4OT`^17mD=P>4GT44
QV=718UXCPB8IT`4QV5518=RA@B1HDD3OUXn17eB=PAnCc<4P54d18=B=PB5E3L3QeHh18QF=PB8E3<4
Qe4_18M=:PB7CR/4RU@c0hiK?0BAHD@4UVQ;19Y^D`BNMEX4XW]Q0jJ1J0BZQVl4[Xae1;:BO0BfUh84
^Yb81;jRSQGoool001Coool4_j:?1;^NRPBhVX@4]IEo1;6@NP>^S7@4ZhQ_1:R3JPBUOfD4XW]P19mf
FP>LLUD4VFe?19EXB@BBHd<4Selm18aJ=`B8E303ReHb18iJ=PB=FSL4S5Tg18]I>0B9F3L4QeDd0hEB
<@B2CRh4P4`]181<;PAnC2h4Oe@f0hAN@@B6HdL4RFQ>18QVC0B6HDD4Pf95185QA@=nFSh4OE8f17i?
<`B0DC@4Pe8f18ED=`>7ESP4R5Hf18QD<`B7DBl4QddZ18M>:`B:E3<3SU/l195QA0BFJ4/4VViC19ie
FPBRNf43YX5X1:Z6K`B^S7D4/Y9l1;JGPPBjW8P4_Z:>5Oooo`005?ooo`BoXXl4^ij:1;RJQ0BeUGl4
/I1j0jj<M0B[R6l4Z8=Z1:EoI@BRNf04WgIJ0iabE@BIKDl4UFQ9199S@`B?Gcd4S5Xg18QD<0>;ES84
SUXf18eJ=`B<FCL4ReTh18UH=`B7EC@3QE8a189>;PB0C2d4P4`^17i<;PAoE3H3Q5i118ISA`B9J4h4
R6I<18IQA@B3HTD4PF550giJ?PAmDSH4OTlc181A=0B3DSH4QE@g0hMF>0B8ESH4R5@c18MA;`B7CBX4
Qdh[18YD<`>>Fc`4TF5419IXB`BJKU<4WWEJ1:9kH@>VPFP4ZXI_1:j<M@BbTW`4]YN21;ZLR0BnXXhE
oooo000Doooo1;nRS`BkWXX4^9Z41;FEO`BaT7X3[Xad1:^8K`BXPfX4YGmU1:9kH0BOMUX3W79E19U]
C`BEJ4T4TV=318mO?@B<FSL4R5@`0h]F<PB>FSH4SEXg18aI=`B;FCP4REPg18ME=0>5DS44PTh^181<
;@B0C2h4OT`^17mD=P>4GT44QV=718UXCPB8IT`4QV5518=RA@B1HDD3OUXn17eB=PAnCc<4P54d18=B
=PB5E3L3QeHh18QF=PB8E3<4Qe4_18M=:PB7CR/4RU@c0hiK?0BAHD@4UVQ;19Y^D`BNMEX4XW]Q0jJ1
J0BZQVl4[Xae1;:BO0BfUh84^Yb81;jRSQGoool001Coool4_Z:>1;^MR@BgV8<4]9An1;2@N@>]Rg<4
ZHI]1:J1J0BSO684WgQL19acE`>IKU44UVU;199TA@B?Gch4ReXh18QE<PB5DBd3QU<_28YH=@B9F3H4
R5Le18IF=@B5EC@3PU8a181?;`AlBb/4O50a18AP@`B6I4P3QFE:18EWC0B5IDT4QFI:18IXC0B7Idd4
QFA90h5N@PAkESX4NDlc17a><PAnD3<4PE4d0h=C=@B4Dc@4QE8a18A?;PB4CB/4Pd`[18A>;P>8E3@4
SE/m199SAPBFJTl4Vg5G1:1hGP>TOVH4Z8A]1:f:L`BaT7X4]IJ11;ZLQ`BnXHdEoooo000Doooo1;jR
SPBkWHT4]iR31;BDOPB`T7T3[H]c1:V6K@BVPFP4XgaR19mhG0BLLeL3VFiA19IYB`BBI4D4Seln18]J
>0B8EC84QE4]0hIC;`R:F3D4REPf18QG=@B6ESD4QEDd0h9B<@B0Cbl4O4/[17a@<@B4H4<4QVA80hEU
BPB5Id`4QFE918EVBPB6J4`4QfM=18ETB@>1GT84NeHj17U?<`AlCS84OU0c185A=0>3DcD4Q5<d18EB
<@B4Cbh4Q4d[18=<:`B4CRh3R5@d18eK?@BBHdH4UVY?19]aE`BPN5h3Y7iV1:R4K@B]RW<4/I1j1;FF
P@BjW8L4_Z6=5Oooo`005?ooo`BnXXh4^if91;NHP`BdU7h4/91i0jf;L`BYQVd4YX5X1:=lHPBON5`4
W7=G0iU^D@BFJD/4TVA518mO?PB;FSP4R5Db18EA;@>6Dbl8RUPe18UH=PB8EcD4QUHe18EE=0>2DS44
P4l_17a;:`AlD344Q61318ITB0>5IDX4QFM<18EUB@B5ITX4QVQ<18MWC@B5I4T3PEi217]F>PAiCc<4
O4hb17i@<`B1DC@3Pe<e18AC=0B5DS44Q4l^18A=:`B3C2/4Q4h^0hQD=0B=Fcd4TV=619IZC`BKLEL4
X7QN0jAnIPBXQ6d4[HYc1;6@NPBeUX44^Yb71;jQSAGoool001Coool4_Z:>1;^MR@BgV8<4]9An1;2@
N@>]Rg<4ZHI]1:J1J0BSO684WgQL19acE`>IKU44UVU;199TA@B?Gch4ReXh18QE<PB5DBd3QU<_28YH
=@B9F3H4R5Le18IF=@B5EC@3PU8a181?;`AlBb/4O50a18AP@`B6I4P3QFE:18EWC0B5IDT4QFI:18IX
C0B7Idd4QFA90h5N@PAkESX4NDlc17a><PAnD3<4PE4d0h=C=@B4Dc@4QE8a18A?;PB4CB/4Pd`[18A>
;P>8E3@4SE/m199SAPBFJTl4Vg5G1:1hGP>TOVH4Z8A]1:f:L`BaT7X4]IJ11;ZLQ`BnXHdEoooo000D
oooo1;jRSPBjWHP4]YR31;>CO@B_SWL3ZhUa1:N4J`BTOfD4X7YO19eeF@BJL5<3UV]=19=VA`B?HD04
Re/i18MD<@B3Cb/4Q4l/0hEB;`B7ES<4QeLd18IG=PB5EcH4Q5Hf189E=@>0ECD4P5Hf181H>0B1F3T4
PUTk185K?0>1G3d4PE`n185K?0B0Fcd4P5Xm185J?0B3G3h3QV1318AN@PAmES/4N4`a17Y;;`AmCS43
Oe0b185A<PB1D304PDd]185;:@B0BBH4P4XW0h9=;@B8ESP4SUm219=WB`BHKU<4WGEK0j9lH`BWPVX4
ZhUb1;2?N@BeUH04^I^61;jQSAGoool001Coool4_Z:>1;ZMR0BfV8<4/i=m1:n>M`>[RG44YhA[1:Ao
I@BPNUl4WGEI19Y`D`>FJdd4TfI718mQ@0B;FcT4Qe@a18=?:`B4Cb`3QE8_18MF<`B7Ec@4QULf18EG
=PB4ESH4PUDe0h1E=@B0ESH4P5Ph185H>@B2FC/4PE/l0h5L?@B1G3h4PE/l181K?@B0FSd4PEXl18=L
?P>6H4<4Q5i217eF>`AhC344NT/_17e><@=oD384PE4b185@<0B1CBd4PD/Y18199PB0BRL3PTd]18QF
>0B>Gd84TfM;19Q^D`BMME/3XWaS1:N2JPB[RG84/8mi1;FEP0BiVhH4_Z6=5Oooo`005?ooo`BnXXh4
^Yf81;JHP`BcTgd4[hig0j^9L@BWQ6/4Y7mU1:1jG`BMMET4VW1C0iI[C@BCITL4Sf5018]K>@B7E344
Pdl[18A?;0>5DRl4QeHc18MG=0B6EcH4QELf18AF=PB2ECD3P5De181F=PB0F3P4PEPi189I>`B1Fc`3
PE`m185L?PB1Fc`4P5/m181J?@B1FS`4Pe`n0hIP@`B4GT84OEHk17Q<<@AjBbl4ODha0gm@<PB1DC84
PE0`185=;@B1BbT4P4TV181:9`>2CBd4R5Hh18iO@PBCId/4V6iC19eeF`>RO6<4Yh9Z1:^9LPB`SgT4
]IF01;VKQPBnXHdEoooo000Doooo1;jRSPBjWHP4]YR31;>CO@B_SWL3ZhUa1:N4J`BTOfD4X7YO19ee
F@BJL5<3UV]=19=VA`B?HD04Re/i18MD<@B3Cb/4Q4l/0hEB;`B7ES<4QeLd18IG=PB5EcH4Q5Hf189E
=@>0ECD4P5Hf181H>0B1F3T4PUTk185K?0>1G3d4PE`n185K?0B0Fcd4P5Xm185J?0B3G3h3QV1318AN
@PAmES/4N4`a17Y;;`AmCS43Oe0b185A<PB1D304PDd]185;:@B0BBH4P4XW0h9=;@B8ESP4SUm219=W
B`BHKU<4WGEK0j9lH`BWPVX4ZhUb1;2?N@BeUH04^I^61;jQSAGoool001Coool4_Z:>1;ZLR0BfUh44
/I9k1:f<M@>YQfh4YH5X1:9lHPBNMe`4VW9F19M]D0>DJ4X4T6=418eN?@B9EcD4PDdY17a67`B3CbX3
RELd18IF=0B4EC@4Pe@d189E=@B1ESH4PELh0h9K?@B4HTD4R6Y=18IXBPB2H4<4Oedo0giI>`AmESP4
O5Dg17aE=PQlDS<4OE@f0gmG>@B1EcX4PELk17]@=0AgBRh4NT`_0ga=<0AmCRl4OTd]17e<:`AmBRT4
OTPV17m99`>1CB`4QE<d18YK?PB@I4L4UV]@19]cF@>PNV44YH5Y1:Z7L0B_SWL4]9Ao1;VJQPBmXHdE
oooo000Doooo1;jRSPBjW8P4]YN11;6BN`B]S7D3ZHM^1:F1J0BRO684WWML19YbEPBGKE03U6Q:191S
A0B=GSd4RELe185=:@AlAQl4PdlZ0hUG=0B6ES@4Q5Dd18=D=0B2ECD4PEHf185G>0>2Fcd4Q69518QZ
C@B6J4X4PV1317mM?`=nFC/4OEHh17aE=`AlECH8O58c17eD=P=oEcT4PELj185G>`AkD3@4MdX^17Y<
;`=lCC04ODh_17i=;@AmC2/4ODXY17i89PAoBBL3PDd/18EC=0B:Fch4T6A719I[D0BKLeT3X7YQ1:F1
J@BZQg04[hig1;BDO`BiVXH4_J6=5Oooo`005?ooo`BnXXh4^Yb81;JGP@BaTW/4[Hae0jV7KPBUPFP4
XWaR19igG0BJLUH4Ufe@0iAXBPB@Hd@4SEhm18UG=@B1CBT4O4HO18=?:P>9Ec@4QUHd18AE=0B3E3@4
PUDe185F=PB1EcP3PU/m18ARA@B8JTd4QVQ:189P@`AoGCl3OUTk17eF>0AlECL4O5Df27aB<`AmE3H3
OeLi185G>PB1Ec/4Ne0d17M:;PAjC2l3O4d`17e>;`AnCBd4OD`[17e::@AnB2H4OdTW0h5=;0B5Dc@4
RU/n191TA`BFJe04Vg=I0j1jH@BUPFT4ZXM`1:n>M`BdU7l4^IZ61;fQSAGoool001Coool4_Z6=1;VL
Q`BeUX04/91j1:b:L`>XQ6`4XgmV19mjG`BKM5T4V6mB19AZC0>AIDH4SV1018aL>`B9Ec@4QU8_18EB
;PB7Ec@3R5Tg18AF=@B2E3D4P5@f17mE=`AnECL4OULj0giH>`AnFch4P61417mRA@AnHD@4OF130gaO
@PAlGT04Nedn17]L?PAkGCh4Ne`l17]H>@=lESP4OUHh17mF>0AoECP4NU0c17M;;`=iC2l4NT`^17]<
;@AkBR/4NdPX17Y69@Ag@Ah3NDDS189A<@B7FC/4SV5519=YCPBILEL3WWQO1:=oI`BYQVl4[Xef1;>C
OPBhVXD4_J2=5Oooo`005?ooo`BnXHd4^Ib71;FFP0B`T7X4[8Yc0jR4K0BSOfH4WgYO19]dF@BHKe84
U6Y<0i5UAPB>H404S5`k18UG=0B6DRl4QE8^18MG=0>8FCL4Q5He189D=@B0E3H4OeDg17iE=`AnEcX3
OUPk17iK?PB0H4@4Of9517iQA0AmH4<3O5m217aN@0AkGCh4Ne`n17]M?PAkG3`4NePi0gaF>0AnESP4
OeHh17mE>0AjD3<4Md/_0gU<;`AjC2h4Nd`]17]::`AkB2P4NTHU17M17P=iAB<4PU4a18MI>`B>HDD4
TfU>19UaE`>NN5l4XgmW1:V6K`B^SGH4/i=n1;RJQ@BmX8dEoooo000Doooo1;jQS@BiW8L4]IJ01;2@
NPB/RW<3Z8A/1:=oIPBONUl4VgAI19Q_DPBDJT`3TFE618iP@0B<G3/4RELd18IB;`B5DRh4QeLd0hQI
=`B4ESD4PU@e181D=PAoECL4OUDg17iG>P=nF3/4OU/n181PA0AoHTD4OV5417eP@`=lGd84O5i017]M
?PAkG3h4Nedn17]L?0AkF3T3O5Hh17iF>0AoESP4OeDh17Y@<`AgBbl3ND`_17Y<;PAkC2d4NdX[17]8
:0AjARD4Md4N0gU58`B2DC44QeTk18iQA@BCJDh4VG5G0iihG`BSOfL4ZHI_1:j=MPBcTgh4^9Z51;fP
SAGoool001Coool4_Z6=1;VLQ`BeUX04/91j1:b:L`>XQ6`4XgmV19mjG`BKM5T4V6mB19AZC0>AIDH4
SV1018aL>`B9Ec@4QU8_18EB;PB7Ec@3R5Tg18AF=@B2E3D4P5@f17mE=`AnECL4OULj0giH>`AnFch4
P61417mRA@AnHD@4OF130gaO@PAlGT04Nedn17]L?PAkGCh4Ne`l17]H>@=lESP4OUHh17mF>0AoECP4
NU0c17M;;`=iC2l4NT`^17]<;@AkBR/4NdPX17Y69@Ag@Ah3NDDS189A<@B7FC/4SV5519=YCPBILEL3
WWQO1:=oI`BYQVl4[Xef1;>COPBhVXD4_J2=5Oooo`005?ooo`BmXHd4^9^61;BEO`B_SgP4ZXUa0jJ3
J`BQOF@4WGMM19UaEPBEK4l4TFI90hiQ@PB;GCd4RUXh18]I=`BBH3d4UfE218eN>`>4EcD4P5Dd17iE
=@AmE3H4O5@g17]F>@AkF3/3NePl17YG>PAiF3X4NEXm17UK?PMhFSd4MeTl17MH>`AfF3X8MULi17IF
>0=fEcP4N5Xk17]L?PAnGT44OE/o17UD=`=gCS04N4`_17Q;;@AhBR/4N4TY17Q79`AiAbL3N4LW17i>
;`B5EcX4Rem3195WC0BGKeD3W7IM1:9nIPBWQFh4[Hae1;:CO@BgVHD4_J2<5Oooo`005?ooo`BmXHd4
^9^61;BEO`B_SgP4ZXUa0jJ3J`BQOF@4WGMM19UaEPBEK4l4TFI90hiQ@PB;GCd4RUXh18]I=`BBH3d4
UfE218eN>`>4EcD4P5Dd17iE=@AmE3H4O5@g17]F>@AkF3/3NePl17YG>PAiF3X4NEXm17UK?PMhFSd4
MeTl17MH>`AfF3X8MULi17IF>0=fEcP4N5Xk17]L?PAnGT44OE/o17UD=`=gCS04N4`_17Q;;@AhBR/4
N4TY17Q79`AiAbL3N4LW17i>;`B5EcX4Rem3195WC0BGKeD3W7IM1:9nIPBWQFh4[Hae1;:CO@BgVHD4
_J2<5Oooo`005?ooo`BmXHd4^9^61;BEO`B_SgP4ZXUa0jJ3J`BQOF@4WGMM19UaEPBEK4l4TFI90hiQ
@PB;GCd4RUXh18]I=`BBH3d4UfE218eN>`>4EcD4P5Dd17iE=@AmE3H4O5@g17]F>@AkF3/3NePl17YG
>PAiF3X4NEXm17UK?PMhFSd4MeTl17MH>`AfF3X8MULi17IF>0=fEcP4N5Xk17]L?PAnGT44OE/o17UD
=`=gCS04N4`_17Q;;@AhBR/4N4TY17Q79`AiAbL3N4LW17i>;`B5EcX4Rem3195WC0BGKeD3W7IM1:9n
IPBWQFh4[Hae1;:CO@BgVHD4_J2<5Oooo`005?ooo`BmXHd4^9^61;BEO`B_SgP4ZXUa0jJ3J`BQOF@4
WGMM19UaEPBEK4l4TFI90hiQ@PB;GCd4RUXh18]I=`BBH3d4UfE218eN>`>4EcD4P5Dd17iE=@AmE3H4
O5@g17]F>@AkF3/3NePl17YG>PAiF3X4NEXm17UK?PMhFSd4MeTl17MH>`AfF3X8MULi17IF>0=fEcP4
N5Xk17]L?PAnGT44OE/o17UD=`=gCS04N4`_17Q;;@AhBR/4N4TY17Q79`AiAbL3N4LW17i>;`B5EcX4
Rem3195WC0BGKeD3W7IM1:9nIPBWQFh4[Hae1;:CO@BgVHD4_J2<5Oooo`005?ooo`BmXHd4^9Z51;>D
OPB^SGL4ZHM`0jB1J0BONV44VWAJ19I^DPBBJ4/4SV=50hYM?PB8FCP4QUHd18ME<0B9ES84R5Pf18AF
=@=oDS84O54b17YB=0AhDcH4Me@h17MD>@MgESX4ME<g17AA=0AdDcH4M5Dh1g=E>0AcESP4LUDh175C
=@aaDS@3LU<e17=D=PAfECP4MeLi17QF>0AgDcL3MTld17E<<0AfBRd4MTT/17M8:PAgAbP4MdHV0gM7
:@AmCS04PeDh18UM@@B?IDX4UFeC0i]eG0BQO6@4YXA]1:b;M@BaTW`4]iV41;fPS1Goool001Coool4
_J6=1;RJQ@BcU7h4[Xeg1:V7L0>TPFP4WgYQ19YdFPBFKU84TVQ;18iSA@>:GCh4R5Th18IF=0B7EC04
REHb18QH=PB4ESD3Oe8b17aA<PAjDS@4N5<f17MD>0AgE3T7MeHj17EC=`AdDC@4M5<f17AE>0McECP4
LeHh179E>0AaDcD<LE8d0g9C=@AcE3H4MUDh17MG>@AhESP4Me<g0gI?=0AeC304MTX]17I9;0AgB2X4
MdLX17M69P=gAbT4ODh`18=E>0B9GD44SfE:19E]D`>KME`4XGaT1:J4K@B/RgD4/I9l1;NIQ0BmX8`E
oooo000Doooo1;fQS@BhVXD4/iAn1:j=M`BYQg03Y85X19mjH@BJM5X4UViB199XB`B>HdD3RUdn18QI
>0B6ES@4QeD`18UF<PB8F3H4Q5He0gmB<PAlDC84NU8d17QC=PAgE3P4Me@i1gMF>PAeDcL4M54d17AC
=PAdECP7LeDh17=F>0AbECP4LE<e375B=0=bDcD4Le@f17IE>0AgEcT4N5Hh17MC=`=fCc@4MD``17I:
;@AfBB`4MdPZ17M7:0AgARH3MdLY17e><0B3ECP4REe118mUBPBEKE<3VgEL1:5lI0BVQ6d4[8]e1;6B
O0BgVH@4_J2<5Oooo`005?ooo`BmXHd4^9Z51;>DOPB^SGL4ZHM`0jB1J0BONV44VWAJ19I^DPBBJ4/4
SV=50hYM?PB8FCP4QUHd18ME<0B9ES84R5Pf18AF=@=oDS84O54b17YB=0AhDcH4Me@h17MD>@MgESX4
ME<g17AA=0AdDcH4M5Dh1g=E>0AcESP4LUDh175C=@aaDS@3LU<e17=D=PAfECP4MeLi17QF>0AgDcL3
MTld17E<<0AfBRd4MTT/17M8:PAgAbP4MdHV0gM7:@AmCS04PeDh18UM@@B?IDX4UFeC0i]eG0BQO6@4
YXA]1:b;M@BaTW`4]iV41;fPS1Goool001Coool4_J2<1;NIQ@BbTgd4[8ae1:N5KP>ROfH4W7QN19Ma
E`BCJdl4SVA718YN@0>6FCT4Pe@c185?;@AoCBX4OT`Y17a;:0AjBbX3N4`^17M=;`AeCS44M4lc17=@
=0AbDCD7LU8g179B=PA`Cc84Kdha16m?<PA_Cc<3KTlc16i@<`A^D3@4KE0d16e><PA]CC84KThc0fm?
=0A`DSH4LU<h17AD>0AdDcP4M54f0g=><`AcBc04LdX^17E:;@AfBB`4MdT[17Q8:@=eABD4NDXZ181C
=@B7G3l4SFA919=/DP>IM5/4Wg]S1:F3K0B[RW@4/I5l1;JHQ0BlX8`Eoooo000Doooo1;fPS0BgVHD4
/Y=m1:b<M@BWQFh3XWmV19ahGPBGLEL4Tf]?18iTA`B:GT03QUTi18=D<`B1Cbd4OddZ17i<:@AlBbP4
NT/Z0gQ<;PAgCBl4MDha17A?<`AcD3@4LU4e1g9B=`AbDSH4L4lb16m><@A_Cc84Kdlc0fi?<`A^D3<4
KU0d16e@=0A]CS84KDdb16i><`=_Cc@4L58f179C>0AdE3P4M5<h17AA=P=cCS<4Ld/`17=:;PAeBRd4
MTT/17M9:`AhB2T3MDDU17U::PB0DcD4Qe`o18eTB@BCK583VGAK19mkH`BUPf`4ZhYd1;6AO0BfV8@4
_:2<5Oooo`005?ooo`BmX8`4]iV51;:CO@B/S7D4YhE^0j9oIPBLN5h4Ug5G19=[C`B>I4L4RUi00hII
>@B3E3<4PDl]17m=:PAnC2T4O4/X17Y;:P=hC2h4Mdd_17E><@AdCc<4Le0d179A=@MbDSL4LU8f171?
<PA_CS44Kdlb16m?<`=^Cc<4KU0c16i@=0A]D3@4KDhb16e=<PA^CS<3Kdld171B=PAbDcP4M5@h17AC
>0AdDCH3Ldhc17=;<0AcBRh4MDX]17I9;0AgBB/4N4PY0gE59@AiBRX4P5<e18ML?`B=I4T4TfaB0iUd
F`BONf<4YH=/1:^:M0BaTG`4]YR41;bPS1Goool001Coool4_J2<1;NIQ@BbTgd4[8ae1:N5KP>ROfH4
W7QN19MaE`BCJdl4SVA718YN@0>6FCT4Pe@c185?;@AoCBX4OT`Y17a;:0AjBbX3N4`^17M=;`AeCS44
M4lc17=@=0AbDCD7LU8g179B=PA`Cc84Kdha16m?<PA_Cc<3KTlc16i@<`A^D3@4KE0d16e><PA]CC84
KThc0fm?=0A`DSH4LU<h17AD>0AdDcP4M54f0g=><`AcBc04LdX^17E:;@AfBB`4MdT[17Q8:@=eABD4
NDXZ181C=@B7G3l4SFA919=/DP>IM5/4Wg]S1:F3K0B[RW@4/I5l1;JHQ0BlX8`Eoooo000Doooo1;bP
S0BfVH@4/I9l1:^;M0BUPf`3WgaT19YeG0BDKU@4SfM;18YP@`B5FS`3PE<d17e>;@AkB2H4N4DR17I4
8PAdA2<4M4HU0g=7:0AaB2X4L4T/16i:;@A^Bbl4KD``16e><P=]Cc<4K4hb16]<;`AZBRh4JT/_16Y=
<@MZCC84JTdc16Y=<PAYCC88JTdb0f]=<`A/CS@4KU0g171B>@AaDcX4LE4h0g1=<`A`Bc44LD/_17=:
;PAeBRd4N4/]17]<;@=gARH4MTHW17i@<`B5FSh4S6=8199[D@>HLeX4WWYS1:B2J`BZRG<4/95k1;JH
Q0BlWh`Eoooo000Doooo1;bPS0BfVH@4/I9l1:^;M0BUPf`3WgaT19YeG0BDKU@4SfM;18YP@`B5FS`3
PE<d17e>;@AkB2H4N4DR17I48PAdA2<4M4HU0g=7:0AaB2X4L4T/16i:;@A^Bbl4KD``16e><P=]Cc<4
K4hb16]<;`AZBRh4JT/_16Y=<@MZCC84JTdc16Y=<PAYCC88JTdb0f]=<`A/CS@4KU0g171B>@AaDcX4
LE4h0g1=<`A`Bc44LD/_17=:;PAeBRd4N4/]17]<;@=gARH4MTHW17i@<`B5FSh4S6=8199[D@>HLeX4
WWYS1:B2J`BZRG<4/95k1;JHQ0BlWh`Eoooo000Doooo1;bPS0BfVH@4/I9l1:^;M0BUPf`3WgaT19Ye
G0BDKU@4SfM;18YP@`B5FS`3PE<d17e>;@AkB2H4N4DR17I48PAdA2<4M4HU0g=7:0AaB2X4L4T/16i:
;@A^Bbl4KD``16e><P=]Cc<4K4hb16]<;`AZBRh4JT/_16Y=<@MZCC84JTdc16Y=<PAYCC88JTdb0f]=
<`A/CS@4KU0g171B>@AaDcX4LE4h0g1=<`A`Bc44LD/_17=:;PAeBRd4N4/]17]<;@=gARH4MTHW17i@
<`B5FSh4S6=8199[D@>HLeX4WWYS1:B2J`BZRG<4/95k1;JHQ0BlWh`Eoooo000Doooo1;bPS0BfVH@4
/I9l1:^;M0BUPf`3WgaT19YeG0BDKU@4SfM;18YP@`B5FS`3PE<d17e>;@AkB2H4N4DR17I48PAdA2<4
M4HU0g=7:0AaB2X4L4T/16i:;@A^Bbl4KD``16e><P=]Cc<4K4hb16]<;`AZBRh4JT/_16Y=<@MZCC84
JTdc16Y=<PAYCC88JTdb0f]=<`A/CS@4KU0g171B>@AaDcX4LE4h0g1=<`A`Bc44LD/_17=:;PAeBRd4
N4/]17]<;@=gARH4MTHW17i@<`B5FSh4S6=8199[D@>HLeX4WWYS1:B2J`BZRG<4/95k1;JHQ0BlWh`E
oooo000Doooo1;bOS0BfV8<4/95k1:V9L`BSPVX3WGYR19McF@BAJe04RfA818IL?`B0ECL3O4h^17M7
9PAc@B04L3dK16dl6PA]?ah4KT8S0fe39@A[A2H4JT@W16U5:@AXABX4IdHZ16M7;0=WBBh4IdX_16I9
;PAUB2`4IDL[16E8;0=VB2d8IDT^16E8;@ATB2h4IDT_16I:<0=WC384J4`b16U==0A[CcL4K4lg16a>
=@=/C3<4KD/a16i9;`A`BBh4LdX_17Q=<@B1Dc@3Pe8c17];;0AkCS44Q5Xo18YRB0B@JU43UW9I19ai
HPBSPFX4ZHUc1:n@N`BeV8<4_9n<5Oooo`005?ooo`BlWh`4]YR31;2AN`BYRG<4Xh9Z0iejHPBGLeT4
TF]@18]TB0B6G3l4P5Dg0ga>;PAgAbH4Ld4P170m6`A]?1X4KClN16i28`=]@bD4Jd@V16Y49`AYABT4
J4DZ16M6:PAWAb`3IdT^16M:;`AVBBh4IDP/16E7:`AUB2`3ITP]26E9;PAUB2d4I4P^16E9;`AVBS03
Id`b16Q<<PAYCC@4Jdlg16a?=`A/CSD3K4`c16e;<@A^BBl4L4T^17=:;`AhCC44PE<d0h=B<`AkBb`4
Ndha18AJ?`B:HTP4T6YA0iIbF@BLNF84Xh5Z1:V9L`B_T7/4]IR31;bOS1Goool001Coool4_9n<1;JH
P`B`TG/4ZHUc1:>2JP>MNV84Ug=I195[D0B;I4P4QU`o181E=`=lCRh4MdLV17=180A`?A/4KC`J16do
7PA^@R<3KD<U16]49PAZA2L4JDDY16Q5:PAWARX4IdL/0fM9;PAWBRl4ITT^16E8;0AUAb/4IDP/0fI8
;@QUBBh4IDP]16A8;PAUBBl4ITX`0fM<<PAXC384JDdd16]?=`A/CcL4K4he0fa<<`A]Bc44KTT_1719
;PAcBRl4N4da185C=0>3DS<4Nd//17]><@B4FSl4RV98191ZD@>FLUT4W7UR1:>1JPBYRG<4[i1k1;FH
P`BlWh`Eoooo000Doooo1;bOR`BeUh<4[Y1j1:R8L@BQP6P3VgQO19A`EPB>J4d4Qf14185H>`AkD383
MDPX170o7PA[=aH4Ic<B16He5PAV>Q`4IChO0fHo8@AU?b84I3lR16<o8PAR?b<4HSlT16509@=Q@BL4
HD<Y1695:`AQAB/4HD@Z3f53:@AP@bT4H4@Z1614:`APAB`3HDL^1698<@ATBc<4ID/c16I:<PAWBC43
IdL_16Q6;@AZARd4KDL]1718;@AeBc04Ne0d0h9F>PB7G404QUa118EL@@B9HTP4SfU@0iEaF@BKN644
XH1Z1:R8LPB^T7/4]IN31;bORaGoool001Coool4_9n;1;FGP`B^T7X4Z8Qa1:60J0>KN5l4U71F18iX
C@B7H4@4PEPk17]@<P=eB2P4L3lN16/g5PAW<a84ISDF16Hj70AU?Ql3ISlQ16Do8PAT?b84HclR168o
8`AR?b@4HD0U0f519`AQ@bT4HTD[1655:`AQA2X?HD<Y1613:@APA2X4H4@[1615;0=QAbh4HTPa16A;
<`AUBc<4ITXb16M9<@=WAbl4J4H]16Y6;@A]Abd4L4P]17E;<0AkD3@3PUHj18ML@0B6G444QEa118UR
B0B?JE03UG5I19]hH@BQP6X4Z8Qb1:j@N`BeUh<4_9n;5Oooo`005?ooo`BlWh/4]IN31:j@NPBXR744
XH1X0i]hG`BDL5H4SVQ=18MPA0B1F3/4Ne0b0gE8:0A`?ah4JcLF16Lc4PAV=AH4ISXL16Dn7`=V?b44
IClR16@o8PAS?b84HSlS168o90AQ@2D3HD4W1653:@ARAB/4HDD[1654:PmQ@bT4H4<Y1614:PAPA2/4
H4D/0f57;PARB344I4/c16E;<`AVBS84IdTa0fM7;`AXARd4JTH]16e7;@A`B2d4MD/`17]@=0>2ESX4
Qea018IL@@B5G444RF9818mYD0>ELET4VgQQ1:60JPBXR784[Y1k1;FGP`BlWh/Eoooo000Doooo1;bO
R`BeUh<4[Y1j1:R8L@BQP6P3VgQO19A`EPB>J4d4Qf14185H>`AkD383MDPX170o7PA[=aH4Ic<B16He
5PAV>Q`4IChO0fHo8@AU?b84I3lR16<o8PAR?b<4HSlT16509@=Q@BL4HD<Y1695:`AQAB/4HD@Z3f53
:@AP@bT4H4@Z1614:`APAB`3HDL^1698<@ATBc<4ID/c16I:<PAWBC43IdL_16Q6;@AZARd4KDL]1718
;@AeBc04Ne0d0h9F>PB7G404QUa118EL@@B9HTP4SfU@0iEaF@BKN644XH1Z1:R8LPB^T7/4]IN31;bO
RaGoool001Coool4^in;1;BGPPB]SgT4YXI`19mnI`>HMUd4TFeD18YUBPB3G444O5<g17E;;@=_@R<4
JCXJ16@d50AQ<a@4H3@F164g6@AQ>A`3H3XN15lk7`AO>Qh4GCTM15`i7@AK>Ad4FcTN0e/j80AK?284
G3dT15`o9PAL@2P?GD8Y35a1:@AL@R/3GDD^15m7<0APB344H4H_1615;PAQA2d3HT</16=3:`AU@b/4
J4<[16]5;0A_Abh4M4X`0gQ><`AlDSL4OeHk189J@0B7H4L4SFQ?0i=_F0BIMf44X7mY1:N7LPB^SgX4
]9N31;^ORaGoool001Coool4^in;1;BGPPB]SgT4YXI`19mnI`>HMUd4TFeD18YUBPB3G444O5<g17E;
;@=_@R<4JCXJ16@d50AQ<a@4H3@F164g6@AQ>A`3H3XN15lk7`AO>Qh4GCTM15`i7@AK>Ad4FcTN0e/j
80AK?284G3dT15`o9PAL@2P?GD8Y35a1:@AL@R/3GDD^15m7<0APB344H4H_1615;PAQA2d3HT</16=3
:`AU@b/4J4<[16]5;0A_Abh4M4X`0gQ><`AlDSL4OeHk189J@0B7H4L4SFQ?0i=_F0BIMf44X7mY1:N7
LPB^SgX4]9N31;^ORaGoool001Coool4^in;1;BGPPB]SgT4YXI`19mnI`>HMUd4TFeD18YUBPB3G444
O5<g17E;;@=_@R<4JCXJ16@d50AQ<a@4H3@F164g6@AQ>A`3H3XN15lk7`AO>Qh4GCTM15`i7@AK>Ad4
FcTN0e/j80AK?284G3dT15`o9PAL@2P?GD8Y35a1:@AL@R/3GDD^15m7<0APB344H4H_1615;PAQA2d3
HT</16=3:`AU@b/4J4<[16]5;0A_Abh4M4X`0gQ><`AlDSL4OeHk189J@0B7H4L4SFQ?0i=_F0BIMf44
X7mY1:N7LPB^SgX4]9N31;^ORaGoool001Coool4^in;1;BGPPB]SgT4YXI`19mnI`>HMUd4TFeD18YU
BPB3G444O5<g17E;;@=_@R<4JCXJ16@d50AQ<a@4H3@F164g6@AQ>A`3H3XN15lk7`AO>Qh4GCTM15`i
7@AK>Ad4FcTN0e/j80AK?284G3dT15`o9PAL@2P?GD8Y35a1:@AL@R/3GDD^15m7<0APB344H4H_1615
;PAQA2d3HT</16=3:`AU@b/4J4<[16]5;0A_Abh4M4X`0gQ><`AlDSL4OeHk189J@0B7H4L4SFQ?0i=_
F0BIMf44X7mY1:N7LPB^SgX4]9N31;^ORaGoool001Coool4^in;1;BFP@B/SWP4YHE_19ilI@>FM5/4
SV]B18MRA`AoF3d4Mdlc1715:0=X>a`4H3@C15/a4@AH<144F34C15Tc5PAJ=AP3FSDJ15Xf6PAI=AT4
F3@H15Hb5`AE<QH4E38H0e@b6@AD=1/4ECHN15Hi80AG>b84F3dT0eTn9PAI?bP8FClW15To:0AI@2T4
FD4[0eU2;0AJ@R`4FD4[15Y0:PAJ?bT4FSlX0e`o:0AN?bP4H40X1691:0AU@RT4J4@Z16e6;@=aB2h4
LdT^17M=<`AnESd4Q5i618YVCP>AKUL4V7IP19mnJ@BVQg44[Hmj1;BGP`BkWh/Eoooo000Doooo1;^O
R`BdUX44[8ih1:F5K`BNO6D3UWAK18i[DPB7HTL4OePm17M?<`A`ABP3J3/L160d4`AK<A44F30A15Pa
4`AI<aH4FSDH0eXe6PAJ=QX4FCDI15Pd60AF<QL4EC8F15@b60=D<QT4E3@K15Df7PAF>B04Ec/R15Pm
90=I?RH4FClX25To9`AI?bP4FD0Y15U1:`=I@R`4FT8/15U1:`AJ@2X4FSlY15Xo:0=L?bP4GSlX1610
:0AR@BP4ID8Y16Q4:PA]ARd3LDP^17=9;PAgCC<4OUHm18ANAPB:ITh3TFiG19QfH0BOOVT4YXMa1:f?
NPBdUh<4^in;5Oooo`005?ooo`BkWh/4]9J11:b>N0BUQFl4WWaU0iIdF`B>Je84Qf9717mH?@AgCc<4
L4DX0fPk70AP=1<4Fc4A15P`4@AH<A<4FC<F15Xe60=J=AX4FSHJ15Te6@AH=1P4ES8G15Db5PAD<QP3
E38I15@d6`AE=Qh4ESTP15Lk8PAH?B@3FChV15To:0QI?bL4FClX15U0:@AI@B/3FD8/15Y2;0AI@B/4
FT0Z15Xo:@AJ?bP3G3lX15ho:0AP@2P4HT4X16E2:@AXA2X4KDH]0g58;PAcBBh4Mddc17iF?@B4GTH4
RVI>0i5^E`BHMV04WgiY1:J7L@B]SgX4]9N31;^ORaGoool001Coool4^in;1;BFP@B/SWP4YHE_19il
I@>FM5/4SV]B18MRA`AoF3d4Mdlc1715:0=X>a`4H3@C15/a4@AH<144F34C15Tc5PAJ=AP3FSDJ15Xf
6PAI=AT4F3@H15Hb5`AE<QH4E38H0e@b6@AD=1/4ECHN15Hi80AG>b84F3dT0eTn9PAI?bP8FClW15To
:0AI@2T4FD4[0eU2;0AJ@R`4FD4[15Y0:PAJ?bT4FSlX0e`o:0AN?bP4H40X1691:0AU@RT4J4@Z16e6
;@=aB2h4LdT^17M=<`AnESd4Q5i618YVCP>AKUL4V7IP19mnJ@BVQg44[Hmj1;BGP`BkWh/Eoooo000D
oooo1;^NRPBcUX44Zheg1:B4KPBLNf@3U79J18aXC`B3GdD4NeDj17=;;`AZ@B@3H3DG15H[2`A>9PL4
BbH:14h[3`AB;Q<4E30E1eDa5PAD<AD4Dc0D154_50A?;A<4CB`C0dd]50A>;aL4Cc8I154d6`AB=al4
E3TR0eDl90AF?RH8EShW35Dm9`=E?BP4E3`W15<k9PAB>R@4DcXT15@k9@=F>bD4EcdV15Tn9`AL?RL4
GchW168o9`AU?bH3JD4W16e3:0AcB2d4NE<j181LA0B7I4d3SVeF19IeG`BMOVP4Y8Ia1:b>NPBcUX<4
^in;5Oooo`005?ooo`BkWXX4/iJ11:^=M`BTQ6h4W7]T0iAbFPB<J4l4Pem517]E>PAcBbl4JT4T0f0e
5`AF:`/4CRH714/V2PA>:`l4DRhC15@`5@ME<AH4E34E15<`50AA;a@4CbdC14d/4`==;A@4CRlG14lb
6@AA=1/4DSLO15@i8P=E?2@4EShV25Hn9`aE?BL3ECdX15@l9`AC>bH4DSXT15<j90AD>bD3ES/U15Lm
9PAI?RL4G3hW15ln9`AR?bL4IClV0fU19`A]@bP4LdP]17UC>PB0G4@4QfA=0hi]EPBFMEl4WGiX1:B6
L@B/SWX4/iJ31;^ORaGoool001Coool4^ij:1;>FP@B[SGL4Y8A^19akI0>DLUX4S6Q?18=OA@AkECX4
Ld/_16Y190=P=AL4ER/;14hV1`A;9PX4CR/?158^4`AD<1D7EC4F15@a5@AC<1@4DBlD14l]4`A=;1<3
CBdD14h_5`A?<QT4DC@K158g7`AD>B83EC`T15Hn9PQF?RL<ECdW0eDm:0AD?2L4Dc/V158j90AC>R@4
E3/U0eHk9@AG?BH4FChW15`n9`AO?RL4HSlW16Do9P=Y@BL4KD<X17=8;@AiDcX4P5a418MTC@>>KEH4
UWEO19enJ0BTQW44[8ij1;>FP`BkWh/Eoooo000Doooo1;^NRPBcUX44Zheg1:B4KPBLNf@3U79J18aX
C`B3GdD4NeDj17=;;`AZ@B@3H3DG15H[2`A>9PL4BbH:14h[3`AB;Q<4E30E1eDa5PAD<AD4Dc0D154_
50A?;A<4CB`C0dd]50A>;aL4Cc8I154d6`AB=al4E3TR0eDl90AF?RH8EShW35Dm9`=E?BP4E3`W15<k
9PAB>R@4DcXT15@k9@=F>bD4EcdV15Tn9`AL?RL4GchW168o9`AU?bH3JD4W16e3:0AcB2d4NE<j181L
A0B7I4d3SVeF19IeG`BMOVP4Y8Ia1:b>NPBcUX<4^in;5Oooo`005?ooo`BjWXX4/YF11:^<M`BRPfd4
VWYS0i9`F0B9ITd4P5a217MA=`A^Ab`4ICdQ0e`c5PA@:0`4B2<814DS2@A69@`4C2XA14h]4`M@;a@4
CblD14h]50A;:a<4BBXB14LY4@M69a04B2XB14/^5PA><Q/4D3LP0e8j8`AC>bD4Dc`V258k9@AA>R@4
CcTT0dlh90A==b84BcDP14/d80A<=1l4CC@O0dlf8@AA>284E3TS15Hj90AI>b@4Fc/S15dl90=P?2<4
ISlW16e7;PAeD3T4OEY318ASC@><K5H4U7AO19amJ0BSQG44Zhij1;>FPPBjWh/Eoooo000Doooo1;ZN
RPBbUH44Zhag1::3K@BJNV<3TW1H18UVC@B0G484Me4g16i7;0AU?B43G3<F150X30A88`P4AB<914HU
30A<:Q44CRdC1e0_50A?;a@4CRdD14/[4`A9:Q84AbTA1dHW40A8:Q84BbhF14hb6`A@=b03DSXS15<k
9@AC?2H8DS/U154j90A?>B@3CcPT14dg8PA;=B04Bc@P14`d7`A==1l3CcHQ154h8PAD>B<4ESXT15Tk
90AK>b<4GC`T0f0l8`AV?bL4KDL^17E@>@AmFT<4Q6==0ha/EPBDM5l4W7eX1:>5L@B[SWX4/iJ21;ZO
RaGoool001Coool4^Yj:1;:EP@B[S7L4XX=]19YjH`>BL5P4RFI=181L@PAgDCL4KTL/16Dm8@=L<aH4
D2P<14PS20A58`T4ARD<14`Z4@A>;A<7D2lD14l_50A>;A@4Bb/C14TZ4PA7:A47ARL@14PZ4PA;;QH4
CS8K150g80=B>R<4Dc/U15<l9PQB>bD4DCXT14li90=?>2@4CCLR14/e80A;=204C3@O14dd7`=?=R44
DCPR15@i8`AF>R@4FC/T15/k8`AM?2@3H3`S16Ho9`A]Abh4ME0i17eJ@`B4Hdd3S6aF19AdG`BLOFP4
XhEa1:^>NPBcUX84^Yn;5Oooo`005?ooo`BjWXX4/YF01:Z<M`BQPV`4VGQR0i1^E`B6I4`4O5U017=>
=0AY@bT4H3TN0ePb60AB;A@4BBL>14@T2`A49@d4B2T@14X[4P=<;A@4CBhE14`]50A9:Q44ABH=144S
2P@n8@T3?R8;144T3@A39Pl4ARTC14X_6@A>=Al3D3TT154k9PAA?2L4D3`U14lj90A=>2<4BcHR0dPd
80A6<Qh4AC0L14D`6`A5<1`4Ac4L0dXc7PA==204CSHQ154g8PAC>284ECPR15Lg8P=I=b44Gc`U16Q4
;@AaCcP4NEQ2185QC0>:JUD4TW=O19YlJ0BRQG44ZXej1;:FPPBjWX/Eoooo000Doooo1;ZNRPBbUH04
ZXag1:62K0BIN683T6iG18ITC0AlFD04Ldhd16U3:@AP>Ah3F38H158]50A99`h4A2@;14@U3@A8:A04
BR/B0d`]50A=;QD4C2dD14TZ4@A59Pd4@B<:13hQ2@<n8P/4@B@=14<V3`A6:A<4BRlI14he7`=@>B@4
DC/V154l9`A@?2D4CcXT14dh8`A;=R83B3@P14Hb7PA5<1`4AC0K14D`70A7<A`3BS<N14dd80A>=R44
DCLR15<h8PAE>284EcLR0eTg8@AO?2D4J4@]175?>0AiF484PF5<0hYZE@BBLel4VWaX1::5L@BZSGX4
/YJ21;ZNRaGoool001Coool4^Yj:1;:EP0BZS7L4XH9/19UhHP>@KUL4QVA<17aI@0AcCS@4JD<Y160i
7P=H<QP4DRdD14TW3PA490/4A2D=14PY40A::a83C2dD14d^5@A<;A@4BBXA14DV3@A18`X4?R490chR
2`A190d4@bH?14HY4`A:;aT4CSDO0e0i90AA>bH4DC`W150l9@A?>R@4CCPS14/f8P=8=204AS8N14D`
70A5<1/4AC0L14La70=:<ah4CC@P14hf8@AA=b84DcPR15Dh8PAG=b83FCLQ15ll9@AXA2d4LDlh17UH
@PB1HD`3RVYE199cG`BJO6P4XXEa1:Z=NPBbUX84^Yj;5Oooo`005?ooo`BjWXX4/YF01:Z<M`BQPV`4
VGQR0i1^E`B6I4`4O5U017=>=0AY@bT4H3TN0ePb60AB;A@4BBL>14@T2`A49@d4B2T@14X[4P=<;A@4
CBhE14`]50A9:Q44ABH=144S2P@n8@T3?R8;144T3@A39Pl4ARTC14X_6@A>=Al3D3TT154k9PAA?2L4
D3`U14lj90A=>2<4BcHR0dPd80A6<Qh4AC0L14D`6`A5<1`4Ac4L0dXc7PA==204CSHQ154g8PAC>284
ECPR15Lg8P=I=b44Gc`U16Q4;@AaCcP4NEQ2185QC0>:JUD4TW=O19YlJ0BRQG44ZXej1;:FPPBjWX/E
oooo000Doooo1;ZNRPBbUH04ZH]f1:62K0BHN683SVeF18ARBPAiESh4KTXa16@o90AJ=1T3DbhC14XX
3`A28``4@2<<144U3PA6:A84B2/D0dX]5PA<;aP4C30J14/_6@A8;AH4@bTD13dU40<k90d4?BD?144W
4@A3:1<4B2hH14`f8@=?>RH4D3dX150m:@A??2P4CCXV14Xg8PA8=203AS8O14@`7@A1;AX8?bXH144/
6@=5;a/4B34M14Tb7PA;=1l4CCDQ14lf8@AB=b<3ESTU15`m:@ATA2l4KDdi17IG@PAoH4`3QfUE191b
GPBHNfP4XHAa1:V=NPBbUX84^Yj;5Oooo`005?ooo`BjWXX4/YF01:V;MPBQPV`4V7QR0hi]EPB4HTX4
NEHn16i:<@AT?b@4FS@I0e<^4`A::0l4@R<<140S30A19@h4ARTB14P[50=:;AH4C2lH14``6PA;;aT4
B2dF14<Y50@m9A03>b@=13dU3`A19a44@bPC14P^60A<=R43CcXV150m:0A@?BT4Cc`X14dj9PA:=b84
B3@P0dHb7`A4<1d4@BdJ23lZ60A1;1T3ABlK14Pa7@A9<Qh4Bc@O14de8@A?=R44DSLS0eHi9@AL?BT4
I4@_16e=>@AfEd84Of1<0hMYE@B@LUh4V7]X1:64L@BYSGX4/YJ21;ZNRaGoool001Coool4^Yj:1;:E
P0BYRgH4XH9/19QhHP>>KEH4Q69:17UF?PA^BS44I3lT15Xd6@=C;Q<4BRP?148S30A08``4@BD>14HY
4PA8:a@3BRdF14`_60A<<1X4BblI14P]5PA3:A@4?BD@0c/T3@@m9@l4@BLA14<X4`A8;QP4C3HQ0dlj
9PA@?BP4D3dY14ll:0A=>RH4BSLR14Pd80=6<Ql4A30M144]6PPo:QP4@B`I0dD_6`A8<Ad4BC8N14/d
7`A==B44CcHQ158g8`=F>BD4G3dY16A4;`A]CCT4MUM217mPC0>7JED4T79N19QkJ0BQQ744ZHej1;:F
PPBjWX/Eoooo000Doooo1;ZNRPBbUH04ZH]f1:62K0BHN683SVeF18ARBPAiESh4KTXa16@o90AJ=1T3
DbhC14XX3`A28``4@2<<144U3PA6:A84B2/D0dX]5PA<;aP4C30J14/_6@A8;AH4@bTD13dU40<k90d4
?BD?144W4@A3:1<4B2hH14`f8@=?>RH4D3dX150m:@A??2P4CCXV14Xg8PA8=203AS8O14@`7@A1;AX8
?bXH144/6@=5;a/4B34M14Tb7PA;=1l4CCDQ14lf8@AB=b<3ESTU15`m:@ATA2l4KDdi17IG@PAoH4`3
QfUE191bGPBHNfP4XHAa1:V=NPBbUX84^Yj;5Oooo`005?ooo`BjWXX4/YF01:V;M`BPPV`4UgQR0he]
EPB2HDX4MU@l16Y6;@AM>1l4E2lE0dh[4@A<:a<4AbTC14<W4@A29a44ABXE14L]5`=9;QT4BS0K14`c
7`A?=R84DCTU154i90A==B43BC<O14Hc7`A8=B84C3XV14dk9`A>>bP3CcdZ24ln;0A>?2X4C3TW14Pd
8PA4<1h3@BhL13`Z60Ph9Q@4>RPF13`Y5`<o:aP4@bhK14H`7@A8<Al4BC8P14Xb80A;=243CcPU15Ln
;0APA384JDdi179F@PAlGd/3QFQE18ibGPBGNfP4X8Aa1:V=NPBaUX84^Yj;5Oooo`005?ooo`BjWXX4
/YF01:V;M`BPPV`4UgQR0he]EPB2HDX4MU@l16Y6;@AM>1l4E2lE0dh[4@A<:a<4AbTC14<W4@A29a44
ABXE14L]5`=9;QT4BS0K14`c7`A?=R84DCTU154i90A==B43BC<O14Hc7`A8=B84C3XV14dk9`A>>bP3
CcdZ24ln;0A>?2X4C3TW14Pd8PA4<1h3@BhL13`Z60Ph9Q@4>RPF13`Y5`<o:aP4@bhK14H`7@A8<Al4
BC8P14Xb80A;=243CcPU15Ln;0APA384JDdi179F@PAlGd/3QFQE18ibGPBGNfP4X8Aa1:V=NPBaUX84
^Yj;5Oooo`005?ooo`BjWXX4/YF01:V;M`BPPV`4UgQR0he]EPB2HDX4MU@l16Y6;@AM>1l4E2lE0dh[
4@A<:a<4AbTC14<W4@A29a44ABXE14L]5`=9;QT4BS0K14`c7`A?=R84DCTU154i90A==B43BC<O14Hc
7`A8=B84C3XV14dk9`A>>bP3CcdZ24ln;0A>?2X4C3TW14Pd8PA4<1h3@BhL13`Z60Ph9Q@4>RPF13`Y
5`<o:aP4@bhK14H`7@A8<Al4BC8P14Xb80A;=243CcPU15Ln;0APA384JDdi179F@PAlGd/3QFQE18ib
GPBGNfP4X8Aa1:V=NPBaUX84^Yj;5Oooo`005?ooo`BjWXX4/YF01:V;M`BPPV`4UgQR0he]EPB2HDX4
MU@l16Y6;@AM>1l4E2lE0dh[4@A<:a<4AbTC14<W4@A29a44ABXE14L]5`=9;QT4BS0K14`c7`A?=R84
DCTU154i90A==B43BC<O14Hc7`A8=B84C3XV14dk9`A>>bP3CcdZ24ln;0A>?2X4C3TW14Pd8PA4<1h3
@BhL13`Z60Ph9Q@4>RPF13`Y5`<o:aP4@bhK14H`7@A8<Al4BC8P14Xb80A;=243CcPU15Ln;0APA384
JDdi179F@PAlGd/3QFQE18ibGPBGNfP4X8Aa1:V=NPBaUX84^Yj;5Oooo`005?ooo`BjWHX4/YF11:V<
M`BPPVd4UgUS0he^E`B2HDX4ME<k16E2:@AB;184AR480dHV3PA7:Q<4ARXE148Y5@A1:1@4A2/G14H^
6P=8;a`4BC4M14/d8@A?>RL4DSd[15M2;`ALAc@3FdPe15M4<@AD@c04DD4_14ln;@A??B`3Cch/14ln
;@Q@?bh4Cch]14hn;PA:>bX3@c@U13//7@@h:1T4>2PH13LV5P@h9QD3?2PG140/6PA4;ah4AC4P14Da
7`A5<1l4AC4P0dPc8PA@>RP4FT4_16E:>0A_E444NEi;0h=XE@B<LEh4UW]X19n4L@BXSGX4/IJ31;VN
RaGoool001Coool4^Yf:1;:EP@BYS7L4X89]19MiH`>=KUL4PV5:17EC>`AU@RT4DR`B14HQ20=69Ph4
AbXC14HZ5@A2:AD4@BPD14@[5`A6;QX3B2lL14Ta7@A;=244CcXW158m:`AG@Rl4G4Ld0e]8=@AGA344
E4<`1551;`A??Rd4Ccd/0dln;0A??Rd8D3l^14ln;@A>?Rh4BS/Z0d<d9@@k;1d4>2PI13PX60@g9QH4
>2HE0c`X5`A0;1X4A2lN14Da80A5<Al4AC0O14Da80=8<b84D3XX15Y1;`AUBSP4KeA117UNB`>3J5D4
S75N19IkJ0BOQ744Z8ej1;6FP`BiWX/Eoooo000Doooo1;ZMRPBbUH44ZHag1:22K@BGNF<3SFiG189Q
BPAeDc/4ID8Y158/4PA68@P3ARH>14LZ4`A6:QD4@RTE144X50A4:aL4ARhJ0dP_70A9<Ad4Bc@Q14lj
9`AB?B/4Ed8_15a7=0=KB3D4Ed@a15A3<0AA@Bl4Cch]14lm;0=??R`4Cch]250o;PA??Rd4CSh^14Xk
:P=3=2D4>b`M13PX6@@h:1P4=bHF13PV5@<l:1L4@2`J14@_7PA5<B04AC4O14D`7`A5<B03B3<R150j
:0AJ@Bl4IDXh16mD@@AiGT/3PfQE18aaGPBFNfP4WhAa1:R=NPBaUX<4^Ij;5Oooo`005?ooo`BjWHX4
/YF11:V<M`BPPVd4UgUS0he^E`B2HDX4ME<k16E2:@AB;184AR480dHV3PA7:Q<4ARXE148Y5@A1:1@4
A2/G14H^6P=8;a`4BC4M14/d8@A?>RL4DSd[15M2;`ALAc@3FdPe15M4<@AD@c04DD4_14ln;@A??B`3
Cch/14ln;@Q@?bh4Cch]14hn;PA:>bX3@c@U13//7@@h:1T4>2PH13LV5P@h9QD3?2PG140/6PA4;ah4
AC4P14Da7`A5<1l4AC4P0dPc8PA@>RP4FT4_16E:>0A_E444NEi;0h=XE@B<LEh4UW]X19n4L@BXSGX4
/IJ31;VNRaGoool001Coool4^Yj;1;:FPPBZSGT4XHA`19QjI@>>L5X4PfA=17EE?PAR@2L4Dc4H14HW
40<m80/4?R@?144X50A3:aL4@b/H14@]6PA6;ad3B30O14Pa80A:=B<4CCXY150o;`AD@c@4ETDf0eM7
>0AFB3T4E4Hg1554=0A@@S84Cd0`0dlo;`A?@304D44b1512<`A@@S84DD8b1551<0=A@2l4Ccd]14Ph
:0A5<b@4A38S14<a8P=4<R84AC<S14Db8`A4<B44@c4Q244^7`=5<R84BcDT15Dl:PAPB3H4K59117IM
B`>1IeD4Rg5O19EkJ0BNQ744Yhej1;2FP`BiWX/Eoooo000Doooo1;ZNR`BbUX84ZXei1:64L0BHNVD3
SW1J18=TC@AeECh4HT0W15<a60A69a03?B0;13hT3`A1:1@4@b/G14<[60A4;AX4ARlM0dP`7`A8<B04
BSDS14dj:@A@?bl4E4<d15I5=P=GAcP4ETPi15A6=`AAA3@4D48b14m0<0=??bl4Cd0`1511<PA@@S<4
D48b1552<PAA@C03DD0_14lm;@A8>2P4AC<T14@b8`A3<B83A38R14Dc8`A5<R<4A34Q14<a8@Q1;Ql3
AC8R14/e90AE?2X4H4Pf16aB@@AfGD/3PFME18]aG`BENfP4WXAa1:N=NPB`UX<4^Ij;5Oooo`005?oo
o`BjWX/4/YJ21:Z=N@BQQ704V7YU0hi`FPB3I4d4MEDn16909`AC<AP4ARL@0cdP2`@n90l4@BPD14<[
5`A3:aP4A2dJ14H_7@=8<1l4B34P14Xe8`A=>RT4D3l_15A3=0AFACH3EdLh15I8>@ADASL4DD@d1512
<PA?@303Ccl_14m0<0A@@C84D48c1512<PAA@S84DD4`0e50;`A??Bd4B3PX14Dc90A4<R<4@c4R0d@b
8PA5<b<4AC8S14@a8@A3<B48@BhO0dDb8PA;=B@4EC`Z1618=PA/DT44MUe;0h5WE@B;LEl4UG]X19j4
L@BWSGX4/9J31;VNRaGoool001Coool4^Yj;1;:FPPBZSGT4XHA`19QjI@>>L5X4PfA=17EE?PAR@2L4
Dc4H14HW40<m80/4?R@?144X50A3:aL4@b/H14@]6PA6;ad3B30O14Pa80A:=B<4CCXY150o;`AD@c@4
ETDf0eM7>0AFB3T4E4Hg1554=0A@@S84Cd0`0dlo;`A?@304D44b1512<`A@@S84DD8b1551<0=A@2l4
Ccd]14Ph:0A5<b@4A38S14<a8P=4<R84AC<S14Db8`A4<B44@c4Q244^7`=5<R84BcDT15Dl:PAPB3H4
K59117IMB`>1IeD4Rg5O19EkJ0BNQ744Yhej1;2FP`BiWX/Eoooo000Doooo1;ZPS0BcUh@4Zhmk1::6
LPBJOFP3T7=N18IXD`AjG4H4KU0i1613;0AE>R@3BS8M14D^6@A6;QX4ARlL14@]6`A5;ad4Ac8P0dTg
9PA;>RX4BSPX14Xg9`A;>b/4CCl`14i2=@=?A3L4D4@g14m3=PA>@cH4Cd@f14m2<`=?@344Cd4a1512
<`A@@SD4D44d14m1<`A?@C83DD8c15Q8>0AJBCT4ED@d1590<0A??Bh3BSX[14Hf:0A4=2H4A3<U144a
8`Q0<243A3<T14Xf9`AB>b/4GDHe16UA@0AdG4/3OfME18YaG`BDNfT4WXAb1:N=N`B`UX<4^Ij<5Ooo
o`005?ooo`BjX8`4/iN41:^?N`BRQW84VWeX0i1cGPB6J5<4NUa616i@>@AP@b`4ECXT0dXb7@A5;QT4
ARhJ14H_70A4;A/4ABlM14Lb80=9=bH4BcXZ14Xh:0A:=bL4Bc/[14do<0A>@SD3Cd@g1514=`A?@cH4
CT<f14m4=PA?@S<3Cd0a14m1<@A@@S<4D48e1511=0A?@C<4Cd4b0e52<`AHB3P4FTTi15E4=0AB@304
Ccd^0dXj:`A6=RP4A3@V14@c9@A1<B<8@30Q0d@c90A:=RL4DS/[15e6=@AYDD04M5a;0gmWE@B:LEl4
U7]Y19j4LPBWSG/4/9J31;VNS1Goool001Coool4^Z2<1;>GQ0B[Sg/4XXIb19YmJ0>@Leh4QVQC17YL
APA^D3T4H4</15Dj90=:<Qd4ABhI14H^6PA6;a`4A2dK14D_7@A7<R03BCLV14/j:PA:>2P4BSLW14/k
:`A=?c04CT8e0dm4=`A@A3L4Cd<f14i3=PA?A3H4Cd8c0dm0<@A?@C44D48c1512=@A@@C@4Cd4c14m1
<P=A@S<4F4Ph15Y9>@AEA3@4DT0`14lm;P=:>R/4ASHX14@d9PA4<bD4@C4S240`8@=4<b@4BSHW158k
:`AMASD4JE5017ALB`=oIeD4RW5O19AkJ@BNQ784Yhek1;2FP`BiWX`Eoooo000Doooo1;^PS0BcV8D4
[91m1:B8M0BLP6`3TgMS18Y^F@B1IE04N5a616Y?>PAMAC03E3dZ150i9@A;=R<4Ac@R24@a80A7=2@3
BCPY14dm;`A@@cH4DTHi15=7?0AFC444FU570e]CB@AIDTP4Ee1615A<@@AAAc`4Cd@g1di1=0A?@cH4
D4@h14m2=`A<?S@4Bcdb0ddo<PA@@C<4DT<e15=5=`AA@cH4CClb0dPk;`A5=b`4@c@Y144b9P@o<2<4
?RlS13la90=5=RT4BST[14hj:`AI@c@4IU10179LC0=nIeH4RG9Q19AkJPBNQG<4Yhil1;2FQ0BiWh`E
oooo000Doooo1;^PS0BcV8D4[91m1:B8M0BLP6`3TgMS18Y^F@B1IE04N5a616Y?>PAMAC03E3dZ150i
9@A;=R<4Ac@R24@a80A7=2@3BCPY14dm;`A@@cH4DTHi15=7?0AFC444FU570e]CB@AIDTP4Ee1615A<
@@AAAc`4Cd@g1di1=0A?@cH4D4@h14m2=`A<?S@4Bcdb0ddo<PA@@C<4DT<e15=5=`AA@cH4CClb0dPk
;`A5=b`4@c@Y144b9P@o<2<4?RlS13la90=5=RT4BST[14hj:`AI@c@4IU10179LC0=nIeH4RG9Q19Ak
JPBNQG<4Yhil1;2FQ0BiWh`Eoooo000Doooo1;^PS0BcV8D4[91m1:B8M0BLP6`3TgMS18Y^F@B1IE04
N5a616Y?>PAMAC03E3dZ150i9@A;=R<4Ac@R24@a80A7=2@3BCPY14dm;`A@@cH4DTHi15=7?0AFC444
FU570e]CB@AIDTP4Ee1615A<@@AAAc`4Cd@g1di1=0A?@cH4D4@h14m2=`A<?S@4Bcdb0ddo<PA@@C<4
DT<e15=5=`AA@cH4CClb0dPk;`A5=b`4@c@Y144b9P@o<2<4?RlS13la90=5=RT4BST[14hj:`AI@c@4
IU10179LC0=nIeH4RG9Q19AkJPBNQG<4Yhil1;2FQ0BiWh`Eoooo000Doooo1;^PS0BcV8D4[91m1:B8
M0BLP6`3TgMS18Y^F@B1IE04N5a616Y?>PAMAC03E3dZ150i9@A;=R<4Ac@R24@a80A7=2@3BCPY14dm
;`A@@cH4DTHi15=7?0AFC444FU570e]CB@AIDTP4Ee1615A<@@AAAc`4Cd@g1di1=0A?@cH4D4@h14m2
=`A<?S@4Bcdb0ddo<PA@@C<4DT<e15=5=`AA@cH4CClb0dPk;`A5=b`4@c@Y144b9P@o<2<4?RlS13la
90=5=RT4BST[14hj:`AI@c@4IU10179LC0=nIeH4RG9Q19AkJPBNQG<4Yhil1;2FQ0BiWh`Eoooo000D
oooo1;^PS@BdVHH4[I9o1:J;M`BNPg03UgaX18mdH0B7KET4P6IC17ELB@AZDSl3H4Tg15M2<0AA?2/4
BcPW14Dc8`A4<R84AS@U0dPh:@A;?C04CT<g159:?`AGDDL4FUE<15]HD0=LFU84FeUB15MEC@ACCD<4
CdLl14e3=`=<@S@4C48e14m4=`ABB3`4ED]115=9@0A=@ST3B3`b14Pk<@A:?C84Bchc14/n<PA8?303
AST^14@f:`A3=BX4@S<Y13l`9P@n<2D4@C@Y0d8d:@A4=BP4Ac@V158m;PATCd04LUe=0giXF0B9Lf84
U7e/19j6M0BWSWd4/9N51;VOS1Goool001Coool4^j2=1;BIQPB]TWl4YX]g19j3L0>GO6P4SgAP18M]
F@B0IU<4MEa916YB?`=PBCL4Ed8`154l:`A;>2L4AC<S14@b8PA6=2D3B3PY14/m<0A>@cL4DTXo15MA
A`AJED`4FeQ@0eaJDPAKFE84EeE=15==@`A?Ac`4CD<g0da2=0A<@SD4Cd@g1598?0AEBd44DdU014e2
>@=8?384B3/a14Xm<PA;?S<4Bchb14Pl<0=6>Bh4A3H[14<e:PA2<bT4?c0V13h`9@A1=2T3@S@Y14@e
:0A7=2H4DSd^16A?@0AbGDd3OVQH18UcHPBDOF`4WXId1:N>O@B`UhD4^In<5Oooo`005?ooo`BkX8d4
]9V61:fBO`BVRgL4WX=`0iMlJ0B?M604QfeI181VD`AeG4T4JU8o0f19=`AG@S04DC`[14/h9`A5<b<4
A38R14Hd9@=8>2T4Bcd`14i3=`ABBSl4Ee5715YEC0AKF503G5YB15]IDPAGEDd4Dde314m7?0A=@cL3
C48d14a2=@A?A3L4DTPl15E;@@ACBD04CD8i0dPl<PA8>c44BSdb14/n<`A;?S84B3``0dHi;PA4=R/4
@cDZ148c:@@o<2H4?S0U144d:@=2=2T4A3DX14Ld9PAB?Bh4I4m0179MC@=nJ5P4RG=R19AmK0BNQW@4
Yhim1;2GQ@BiWh`Eoooo000Doooo1;^PS@BdVHH4[I9o1:J;M`BNPg03UgaX18mdH0B7KET4P6IC17EL
B@AZDSl3H4Tg15M2<0AA?2/4BcPW14Dc8`A4<R84AS@U0dPh:@A;?C04CT<g159:?`AGDDL4FUE<15]H
D0=LFU84FeUB15MEC@ACCD<4CdLl14e3=`=<@S@4C48e14m4=`ABB3`4ED]115=9@0A=@ST3B3`b14Pk
<@A:?C84Bchc14/n<PA8?303AST^14@f:`A3=BX4@S<Y13l`9P@n<2D4@C@Y0d8d:@A4=BP4Ac@V158m
;PATCd04LUe=0giXF0B9Lf84U7e/19j6M0BWSWd4/9N51;VOS1Goool001Coool4_:6>1;FKR0B_UH84
Z8ik1:67M0>JPFh4TgYW18edH@B6Ke`4OFME17=NC0=ZE484HD`k15Q4=0A??Bd4B3HW14Dc9@A5=2H3
AcLY14Tk;PA;?c<4CTDj151:@0ABCDD4Ddm70e=@B0ABCdL4D4a414i8?`A<@cT4BT0e1dXo<`A<@CH4
CdDj15=9?`AGCT@4FTm60eM<@`A?A3/4B3dc14Di<0A4>C04A3P_0d<h;PA4>2l4A3P^144f;0A0=2/4
@3D[144f;0<o=2/4@CH/14/m<0AFACP4IE94179OD0=oJU/4RWEU19EnKPBNQgH4Z8mn1;6GQ@BiWhdE
oooo000Doooo1;bQSPBeVhP4[iF21:R>N`BQQg@3VX5^19=jI`B=M644QVmL17eWE@AcGT`3JUA2165<
>`AHA3@4Ccd]14Pf9`A5<bD4AC@V0dLg:@A9>bh4Bclc14i5>PA@BT04DTe515=?A`=CD4P4DTm7151<
A0A>B3l4C4<i14Y0=@M:?c<4C44f14m5>PACBCl4Edi415Y?AP=GC4<4Cd@k14Pm<`A5>C04A3T`14@h
;`=3>2h4A3P_14@h;PA1=R`4@3@[140e:`A1=R`3?c@[144f;0A;?C04ETDh16EBA0AbGe03OfYK18Ye
I@BEOVh4WXMf1:R?OPBaUhD4^In=5Oooo`005?ooo`BlXHh4]I^81:nEPPBXSW/4XHMd0iZ1KPBCNVL4
SGAQ18I_G0AmIeD4Lei<0fYD@PAQC3/4F4@d14lm;@A8=RL4AC<U14Dd9P=7=bT4BC/^14/o<`A>ACX4
D4Y0159=A@ACCdL3De18159?A`A@C4@4CTPo14a3>@A:@3D7BSlc14a1=PA?ACX4DdTo15M>A0AJCdH3
Eda314m4>`A8?C<4ACT`14@i<0A4>2l3@cP^14@h;`A4>2h4@CH/140d:`A0=B/4@CH/0cld:`A1=R`4
Bcd`15I5>0AUDT@4LUm@0gmZF`B:MFD4UGi^19j7MPBXSgh4/IN51;VOSAGoool001Coool4_:6>1;FK
R0B_UH84Z8ik1:67M0>JPFh4TgYW18edH@B6Ke`4OFME17=NC0=ZE484HD`k15Q4=0A??Bd4B3HW14Dc
9@A5=2H3AcLY14Tk;PA;?c<4CTDj151:@0ABCDD4Ddm70e=@B0ABCdL4D4a414i8?`A<@cT4BT0e1dXo
<`A<@CH4CdDj15=9?`AGCT@4FTm60eM<@`A?A3/4B3dc14Di<0A4>C04A3P_0d<h;PA4>2l4A3P^144f
;0A0=2/4@3D[144f;0<o=2/4@CH/14/m<0AFACP4IE94179OD0=oJU/4RWEU19EnKPBNQgH4Z8mn1;6G
Q@BiWhdEoooo000Doooo1;bQS`BfW8T4/9J41:ZAOPBTRgT3WXEc19R0KPBBNfT4SGIT18I_GPAlIUH3
LEe<16QDA0ANBc`4Dd4c14Th:PQ3<bD3A3DW14Hh:PA8>bl4BChc14]1=`A<A3/4C4Hn0da7?PA;ACd4
BT<k14Q1>0A7?SD4AS`b0dHk<@A6?344B3dc14]0=@A>@cT4DDLm15A;@@=GCD<4FDi515M=@`ACB3l4
Cd@k14e2>@=;@CT4Acde14<j<@A1>304@ST`14@j<PA4?3<3A3hd14M0=`A?ACX4FD/o16MFB@AdHUD3
PFiO18ahJ0BFPG44X8Ui1:VAP0BaV8L4^Z2=5Oooo`005?ooo`BlXHl4]Yb91;2FQ0BZTGh4Y8]i0ij5
L`BHP6h4TW]Y18efI0B6Keh4O6IF0g5MC0AXE4@4GT/l15=1<`A9>2X8@c<U0d@e9`A6>2X4B3/_14Tn
<`A;@CL4C4@k14a6?P=<Ach4BdDm14Y3>`A8@CP4Ache14Hl<P=6>c44AS`a14Pm<`A;@3D4CT<i1557
?@ADBd43Ede315U>A@AGCD<4DdPo14m4>`A=@ST3Bd4i14Lm=@A3>S44@CP`148i<0A4>S84A3`c0d@n
=0A7@3L4CdDj15U;?`AWETT4M69E0h5^G`B<N6P4UX5a1:29N@BYTH04/IR71;ZPSAGoool001Coool4
_:6?1;JLR@B`UX@4ZY5n1:B;N@>NQG<4V81^199kJ@B=MV@4QVmN17aVEP=aGD`4J5A415i;?0AC@C<4
BCPZ24<c9@=4=BL4ASPZ14Pk;`A9?S<4Bd4g14a4>`A<ASh3C4Ln14]5?@A:@c/4B44h14Ln=@A6?383
AS/a14Hl<@A8?C<4Bd0e14i3>@AAAcd4E4]10eM=@`AICTD4Ede315=8?`A?A3/4CD8i0d]1>@A7?CD4
@cXa144h<0A2>C04A3Xb14@l<`=4?S@4Ad0g14m5>PAIBcl4IeI917ARE@>1KUl4S7QX19J1L@BPRGT4
ZI601;6HQ`BjX8dEoooo000Doooo1;bQS`BfW8T4/9J41:ZAOPBTRgT3WXEc19R0KPBBNfT4SGIT18I_
GPAlIUH3LEe<16QDA0ANBc`4Dd4c14Th:PQ3<bD3A3DW14Hh:PA8>bl4BChc14]1=`A<A3/4C4Hn0da7
?PA;ACd4BT<k14Q1>0A7?SD4AS`b0dHk<@A6?344B3dc14]0=@A>@cT4DDLm15A;@@=GCD<4FDi515M=
@`ACB3l4Cd@k14e2>@=;@CT4Acde14<j<@A1>304@ST`14@j<PA4?3<3A3hd14M0=`A?ACX4FD/o16MF
B@AdHUD3PFiO18ahJ0BFPG44X8Ui1:VAP0BaV8L4^Z2=5Oooo`005?ooo`BmXXl4]if;1;:IQPB]U884
Yhmm0j::N0BLQG@4Uh5_199lJ`B:M6<4PVeM0gQUE@A]FT/4HU1115I5=`A:>Rd4@c<V144b9@=2<bH4
@cDY14@g:`A5>Bl4AS/a14Hl<PA6?C@3AChe14@m=0A3>c<4@ST`144h;PA1=Rd3@CH/148f;@A3>2l4
ACXa14Pm<`A;@3L4CT<j0e56?PACBD44ED]215E;@`ACBT84CdHo0d]2>`A7?cL4A3`d148j<PA4?3@4
Ad0h14]3?0=>Acl4D4U015E;@@ALCT<4JEU=17QWFP>4LV@4Sg]]19R4M0BQRg/4ZY>21;:IR0BjX8hE
oooo000Doooo1;fRS`BgWH/4/YV61:fDPPBWSgd3XXYh19b5M0BGPFl4TWa[18YdH`B2KEd3N6EE16eJ
B`ARD444ETDg14Xj;@A3<bH4@C8U0d8c9PA3=BT4A3L[14Di;`A6>c44AS`b14Hm=0=5?SD4A3dd14<k
<`A2>C04@CP^144f;@=1=R`4@SH]14<h;`A5>S44B3dc14]0=`A>@cX3DDHn15=9@@AEBd84ED]315=:
@PA?ASl3Bd8k14Lo=`A4?3@4@SXb14@l=0A7@3P4Bd<l0di7?`A@BD04ED]115a>@`AYFDd4N6MJ0hAb
I0B?Nfd4V8Ad1:6;N`BZTh84/YV81;ZPSQGoool001Coool4_J:?1;NMR`BbVHH4[IB21:N?O@>RRWP4
W8Ed19N1K`BBO6/4RWAS189]G@=hIED4KEY;169@@@AFACL4BSX]14<c9PA1<RD3@S<V14<e:@A4=b/4
ACT_14Hk<@A6?384ASdd0dDn=@A4?C@4@c/c148i<0A1>2h4@CH]0d4f;0A2=Rd4@cP_14Dj<@A8?C<4
Bd0g14i3>P=AASh4DdU115E;@PAEBd<4DdY214m6?`=;@S/4Aclg14@l=0A2>S84A3`d14M0>0A;@c`3
CTLo1519@0AEBd44G4i316UIC@AhIeX3Q79T18mkK@BHQ7@4XH]k1:ZCPPBbVHP4^Z2>5Oooo`005?oo
o`BmXi04^In<1;BKR@B_UhD4ZY>10jF>O@BQRWX4W8If19N2LPB?O6d4QgEV0gi/GPAcHUD4IEI915U:
?PA=?S<4A3DY140a90=0<BD4@C8V144c:0A1=2T4@CD[240f;0<o=B`4?SD[13dd:`@l<bX4>c4X1c/`
9`@l<BP4?C8Y13ld;0A2=bl4A3Xb14Ln=@=:@3T4C4<l24e5?PA<A3h4BT<l0dM1>PA4?cP8@Sdg14E0
>PA;AT04CdY40eA>A`AHDTX4GEE=16EJD0A`HeL4OFmS0hQhJ`BBP784VhMi1:>>O`B[UH@4/i^91;^Q
SaGoool001Coool4_J>@1;VOS0BdVhT4[iN51:ZCP@>USWd4XHYj19b6MPBGPW84Sga]18MeIP=nK5h4
Lf9E16EFB@AIBSh4CChc14@e:@A0<B@3@34U144b9PA1<bP4@C@Y144e:`Q0=R`3?cD/13he:`@m=2/4
?3<Z13/a:0Lk<2L4?34X13db:@@o=2`4@SL_14@j<PA7?SD3BT0i14a3?0Q=ACh4C4@n14Y3?0=7@CX4
A3lh248m=`A5@3X4BdI014m:A0=DCTL4F59:15eEC@AUFU04L6=G17e_H`>8N6/4TX1b19^7N@BSSWl4
ZiF41;>KR@BkXHlEoooo000Doooo1;fST0BiWh`4]9^91:nGQ@BZTh43YHim1:6:NPBLQWH4Uh9b18ml
K@B7MFH3OVaN17=RE@AUETT4FDXn14dn<`A4=BT4@34T0d0a9@A1<RH4@C<X144d:@A1=B/8@3H/0cle
;0@n=B/4?C@[13`c:P@k<BP7>c0W13`a:0@m<RT4?c@/148g;`A4>S84Ache0dY0>@A<@c`8CDDn14a4
?PA:@c`3Ad4j14@o>0Q2?CL4AD0j14]6@0A?BT@3E4i715QBBPAMEDd4IEY@171SE`AmKf<3R7Q[19:0
LPBKQgT4Xhio1:^EQ0BcVhT4^j6?5Oooo`005?ooo`BmXi04^In<1;BKR@B_UhD4ZY>10jF>O@BQRWX4
W8If19N2LPB?O6d4QgEV0gi/GPAcHUD4IEI915U:?PA=?S<4A3DY140a90=0<BD4@C8V144c:0A1=2T4
@CD[240f;0<o=B`4?SD[13dd:`@l<bX4>c4X1c/`9`@l<BP4?C8Y13ld;0A2=bl4A3Xb14Ln=@=:@3T4
C4<l24e5?PA<A3h4BT<l0dM1>PA4?cP8@Sdg14E0>PA;AT04CdY40eA>A`AHDTX4GEE=16EJD0A`HeL4
OFmS0hQhJ`BBP784VhMi1:>>O`B[UH@4/i^91;^QSaGoool001Coool4_ZBA1;ZPSPBfWH/4/IZ81:fF
Q@>YTh<4YHn01:6<O@BMRG/4UH9d18elKP>4M6L4NVYN16iND`APDTL4E4Lm14Pl<PA1<bT3?c0U13h`
90@n;b@4?BlS13`_90@k<2H4>RlV0cT_9@@h;RD4=bdT13H/8`@e:b87=BXR13H[8`@g;BD4>BlW13/a
:P@n=2d4@CPa0d<k=0A5?CH4Acli14M0>PA7@3/7AT0j14Do>@A4?cT4AT4l14a8@`ABCDP4Ee9=0eeH
D`ATGeP4JfAM175ZH@AkLFL4QGQ]0hioL`BFQGP4WXam1:JAPPB]UhL4]9b;1;^RSaGoool001Coool4
_ZBA1;ZPSPBfWH/4/IZ81:fFQ@>YTh<4YHn01:6<O@BMRG/4UH9d18elKP>4M6L4NVYN16iND`APDTL4
E4Lm14Pl<PA1<bT3?c0U13h`90@n;b@4?BlS13`_90@k<2H4>RlV0cT_9@@h;RD4=bdT13H/8`@e:b87
=BXR13H[8`@g;BD4>BlW13/a:P@n=2d4@CPa0d<k=0A5?CH4Acli14M0>PA7@3/7AT0j14Do>@A4?cT4
AT4l14a8@`ABCDP4Ee9=0eeHD`ATGeP4JfAM175ZH@AkLFL4QGQ]0hioL`BFQGP4WXam1:JAPPB]UhL4
]9b;1;^RSaGoool001Coool4_ZBA1;ZPSPBfWH/4/IZ81:fFQ@>YTh<4YHn01:6<O@BMRG/4UH9d18el
KP>4M6L4NVYN16iND`APDTL4E4Lm14Pl<PA1<bT3?c0U13h`90@n;b@4?BlS13`_90@k<2H4>RlV0cT_
9@@h;RD4=bdT13H/8`@e:b87=BXR13H[8`@g;BD4>BlW13/a:P@n=2d4@CPa0d<k=0A5?CH4Acli14M0
>PA7@3/7AT0j14Do>@A4?cT4AT4l14a8@`ABCDP4Ee9=0eeHD`ATGeP4JfAM175ZH@AkLFL4QGQ]0hio
L`BFQGP4WXam1:JAPPB]UhL4]9b;1;^RSaGoool001Coool4_ZBA1;ZPSPBfWH/4/IZ81:fFQ@>YTh<4
YHn01:6<O@BMRG/4UH9d18elKP>4M6L4NVYN16iND`APDTL4E4Lm14Pl<PA1<bT3?c0U13h`90@n;b@4
?BlS13`_90@k<2H4>RlV0cT_9@@h;RD4=bdT13H/8`@e:b87=BXR13H[8`@g;BD4>BlW13/a:P@n=2d4
@CPa0d<k=0A5?CH4Acli14M0>PA7@3/7AT0j14Do>@A4?cT4AT4l14a8@`ABCDP4Ee9=0eeHD`ATGeP4
JfAM175ZH@AkLFL4QGQ]0hioL`BFQGP4WXam1:JAPPB]UhL4]9b;1;^RSaGoool001Coool4_jBB1;^R
T0BgWhh4]9f<1;2JRP>]UhP4ZIB51:FBP`BQSh84VXUl19:2MP>:Nfl4Og5V179UFPAUFDl4FDe314i2
=`A5=bd3?S0V13`^8`@j;B84>B/P13LZ7`@f:Ah4=2TO0c<X7`@b9ah4<2HM12lU70P_91`3;bDM12lU
7P@a9b04<bTR13D/9@@h;bT4>c8]0cde<0@o>384@3Xe148l=`A2?CP4@chi0d<n>PA2?cX4AD4m14]7
@`AACTX4F5IA161MF0=XI5l4L6aU17QbK0B2O7D4RH9j18j3N@>DQg/4Vh]o1::@PPBYUHH4[iV91;JN
S@BlXY0Eoooo000Doooo1;nTTPBkXY04]in>1;BMS0B`VXX3[IN81:VDQ@BUTX<4XHn219Z9O0BBPWH3
RW]_17maIPAbIEX4IEU?15U=@`A>@SL4ACL]0ch`9P@l;R<4>RdR13T[80@g:Ql4=RTN13@Y7`<c:1l4
<RLN130V7@@_9A`8;b@L0blU7@@_9Ah4<BLP13<Y8P@e;2D4>2lY13/b;@<m=C04?cPb140j=@A2?3L4
@Sdh14<n>@=3?SX4@Slj14E1?@A;Ad<4DDi:15QFD@APGEP3J6AO171/I@AhLV`4PWae18V2NPB>PgT3
U8Mk19^;O`BRT884ZIF61:nIR@BfWXd4_::@5Oooo`005?ooo`BoY984^j:@1;NOSPBdWH`4/9Z:0jfG
R0BYU8D4YI:31:6?PPBJRG`4TX9f0hYkK`AoLFH4LVEJ16EIC`AICD<4CT8g14Dg;@<n<2H4?2hS13X]
8P@i:b04=bXO13HY7P@d:Al3<bPO138W7P@`9Qd4;bDL22lT70<_9Ad4;bDN134W80@c:B84=B`U13P_
:@@k<Rd3?CD`13lh<PA0>SD4@S`g148m>0A3?ST3@chj148o>PA5@Cd4BdM3155>BPAHEU44H5eH0fQT
G`A`K6D4N79/189lM@B9PWX4SX=i0iB7N`BKRgl4XY221:VEQPB_VHT4]Yj=1;bRT1Goool001Coool4
_jBB1;^RT0BgWhh4]9f<1;2JRP>]UhP4ZIB51:FBP`BQSh84VXUl19:2MP>:Nfl4Og5V179UFPAUFDl4
FDe314i2=`A5=bd3?S0V13`^8`@j;B84>B/P13LZ7`@f:Ah4=2TO0c<X7`@b9ah4<2HM12lU70P_91`3
;bDM12lU7P@a9b04<bTR13D/9@@h;bT4>c8]0cde<0@o>384@3Xe148l=`A2?CP4@chi0d<n>PA2?cX4
AD4m14]7@`AACTX4F5IA161MF0=XI5l4L6aU17QbK0B2O7D4RH9j18j3N@>DQg/4Vh]o1::@PPBYUHH4
[iV91;JNS@BlXY0Eoooo000Doooo1;nUT`BlXi44^J6@1;JPS`BcWXh3/9b=1:fJR`BZUhT4YYB719n>
PPBGR7`3Sh1e18AgK@AiKF@4K65I15eDB`A@Acl4AS/c0chb:P@j;B@4=bXP13DX7P@c9Q/4<B@I12lR
60<]8AL4:alF12XN5@PX7A@4:1dE0bTN5`@Z81T4:b8K12dU7P@_:284<R/V13@^:@<g<B`4>C@`13/g
<`@m>CD4?c/h13lm>P=0?c`4A48n14U7A0A?CT/4F5MD165PG0AZJ6<3LW1[17YgLPB2OWP4RH=m1929
P@BERh83Vhj31:2AQ@BVU8L4[9R91;6LS0BgWhl4_J>A5Oooo`005?ooo`BoYI<4_:>A1;VQT0BfX8l4
/ij>0k2LS@B]VX/4ZYN91:JDQ`BOSX84UhQl0hn0M@B4Mfd4NFeT16aQF@AME4/4D4Lo14Hk<`<n<RX4
>RdT13LZ80@e:1h4<bHK134T6@@_8QP3;B4G12/O5P@Z7QD8:1dD12PM5@<Y7QL4:R0I12/R6`@]9Ah4
;bPR138[9P@d;RT3=c4/13Td<0@k=c<4?CTe13lk>0@o?CX3@3ll14A2?PA9Ad@4Cdi;15QGE0AQH5`4
JVQS0g9`J`AjMg84PWih18V3O@B@RH44UH^20i^>P`BPTHD4YYB71:bHR@BaW8`4]in?1;fSTAGoool0
01Coool4_jFC1;bST@BiXI04]Z2?1;>NSP>`W8d4[IZ;1:ZGR@BVU8L4Whj219N8O0>?P7D4Q7M]17U]
I0A/HET4GEA;1517?`A6>c<3?S8Z13X]90@g:R04=BPN13<V6`@a91T4;b8H0bdQ5`@[7aH4:QhE22PM
50@X7AD3:AhG12XP6@@[8Q/4;BDN12lX8P@b:bH4=2hY0cLa;0@i=304>cLc13di=@@o>cP4?cdj0d0o
?0A4@Sh4BDM414m>B`AHEe@4HF1L16YXH`=bL6/4NWMb189nN0B9Pgd4T8V119F;PP>KSX<4X9651:JD
Q`B/V8T4/Ib<1;NOS`BmXi4Eoooo000Doooo1;nUT`BlXi44^J6@1;JPS`BcWXh3/9b=1:fJR`BZUhT4
YYB719n>PPBGR7`3Sh1e18AgK@AiKF@4K65I15eDB`A@Acl4AS/c0chb:P@j;B@4=bXP13DX7P@c9Q/4
<B@I12lR60<]8AL4:alF12XN5@PX7A@4:1dE0bTN5`@Z81T4:b8K12dU7P@_:284<R/V13@^:@<g<B`4
>C@`13/g<`@m>CD4?c/h13lm>P=0?c`4A48n14U7A0A?CT/4F5MD165PG0AZJ6<3LW1[17YgLPB2OWP4
RH=m1929P@BERh83Vhj31:2AQ@BVU8L4[9R91;6LS0BgWhl4_J>A5Oooo`005?ooo`C0YY<4_JFC1;^T
T`BiXi<4]j:B0kBQTPBbX984/9nB1:fMT0BUUXX4WHn40iF8OPB<P7L4P7E/179XH0ASFU<4E4a514Hn
>0<l<R/4=b/S13@X7`@a91X4;R4G12/N4`@Y6a039aT>12DH3P@S5Pd48AH=124F3P@P5Q038ALA128I
4`@T71L49b0J12TS7`@/9b84;bXV0c<^:P@e<Bh4=c@a13Tf=0@k>CL4?3`j0clo?@A3@d84BT]:15AE
D`ANGe`4JFQV179aKP=kNGH4Q89n18j;Q`BDShX4V96:19bCRP>PU8X4YIJ;1:ZIS0B_Vhd4/ij?1;RQ
T0BmY98Eoooo000Doooo1<2VT`BmYI<4^jBC1;VST`BgXY83]:6B1;:PTPB`Wi84[If@1:FFRPBMSh@3
UHQn18b0M`B0MF`4LVQP16=JD`ADC4D4AShh0c`b:`@g:b<4=2PO134T6P@^8AL4:ahC12TK40<W6@h4
9AP>12<F3@@Q5Pd48AH>120F40<Q5a448QTC12@L5`@W81X4:B<O12`W8P@_:RH3<bhZ13Da;P@g=344
>CHd13/i=`@l?3X3?clm14=3@PA:BdX4E5EC15iOG0AYJ6H4LW5^0g]iMPB4PWh4SX^719B?RPBHTHX4
W9>:0j2DRPBUUX/4ZYV<1:nKS@BcWXl4^:6@1;fTTQGoool001Coool4`:JC1;fUT`BkY9<4^J>C1;NR
TP>dXI84/Z2B1;2OTPB]WI04YIJ:19f?Q0>ER7h4S81g181eK0AbJ604HeYC15A<A@A6?SP3?38[13L[
8`@d:1l4<B@J12hQ5`@[7Q<4:A/@0bLI3P@U60h48aH=124F3@@Q5Ph481H@0b4G4@@R6A<491`G12LP
6P@Y8al4;2LR12lZ9P<c;RX4=C4^13Ld<@@i=S@4>cTg13`l>P<o?cd4@d=214Y;BPADEE<4GUmL16UX
IPAbLFh3NgUf18B2OPB>RhL4U8n:19RARPBLThX3X9B:1:FFR`BZVH`4[i^=1;>NS`BhXI04_JBB5Ooo
o`005?ooo`C0YY@4_jJE1;fVU@BkYYH4^ZFG0kRUV0BgYYT4]JJJ1;BUVPB]WiD4Y9R>0i^?Q`B@QWd4
Q7Yc17M^I`AXHE/4F55<14Q1?0<l=2h4=B/T130V7P@]8AP4:A`C12HI3`@S5@/381<911hB2@@L4@T4
6a0:11X?2@@I3`X36Q4<11/D40@M5a@481/G12<N6`@W8Ql4:RHS0bhZ:0@a;b`4=38a13Hf=0@h>CL4
>c`k0cm1@0A6B4P4D5=B15]NG@AWJFP4LW=a17alNP>7QX<4TY2=19fLV@BQWi/4XI^D1:>JTP>VVY44
ZY^@1:fMT0BaWi04]Z6A1;ZSTPBnYI<Eoooo000Doooo1<2VU0BoYYD4_JJE1;^VUPBjYIL3^:FH1;NV
V@BeYYX4]:FJ1:fOU@BTV8h3Vhn71926O@B4NW<4MfiW16QQF`AHDD`4B44l0c`d;P@e:b@4<2HN12dQ
60@Y71<49QT?12<E2`<P4`T47Q8911`A2@@K40X46Pl911T?2P<J4@`46a@@11dG50@P6aL48ahK12LR
7`@Z9R<3;RXX134_;0@d<S44=SHd13Pi=`@k?3/3?d5014I8B0A@De84FeiM16MYJ0AbLg44O7aj0hN6
P`BBT8d4WIbI1:6OV`BQVi@4XiZB0jJJT@BZVi04[If@1;6OT0BfXI44^Z>B1;jUTaGoool001Coool4
`:JD1;nVU@BmYYD4^jJF1;ZUU`>hYIP4]jJI1;FVVPBdYIX4[InE1:BHSP>KShL4T8Im18AjL`AgKVL4
J65K15QAC0A8@C`3?3@^13D[90@`9Qh4;B4H12TL4`@V6@l48aD;0b0C2@@N4PT4714911/@2P@J3`T4
6@l:0aXA30@K51047ALD120K5`@S7Q/49b8O12XV8`<^:RP4<Bl/13@b<@@f=S@4>3Tg13/l>`<o@D04
ATQ8151CDPAKGUd4IfUX179cL@AlO7X3QhJ319:@S@BMW9T4XInK1:6KU0BSVY83YYZA1:ZKT0B]WI04
/In@1;JQT@BjXi84_ZFC5Oooo`005?ooo`C0YY@4_jJE1;fVU@BkYYH4^ZFG0kRUV0BgYYT4]JJJ1;BU
VPB]WiD4Y9R>0i^?Q`B@QWd4Q7Yc17M^I`AXHE/4F55<14Q1?0<l=2h4=B/T130V7P@]8AP4:A`C12HI
3`@S5@/381<911hB2@@L4@T46a0:11X?2@@I3`X36Q4<11/D40@M5a@481/G12<N6`@W8Ql4:RHS0bhZ
:0@a;b`4=38a13Hf=0@h>CL4>c`k0cm1@0A6B4P4D5=B15]NG@AWJFP4LW=a17alNP>7QX<4TY2=19fL
V@BQWi/4XI^D1:>JTP>VVY44ZY^@1:fMT0BaWi04]Z6A1;ZSTPBnYI<Eoooo000Doooo1<6WU@C0YiH4
_jRH1;jXV@BmZI/3_:ZM1;b[W`Bk[:44^jjT1;FYX@B[XIT3XYR@19R>Q`B<Pgd4OGIa16iXH`ANF5@4
CDQ50chj=@@c;2H4;B<M12PN5`@T6A4481D=11dA2@<I3PL45P`511D;1@@C2PD44PT5114:1P<B30T4
50l;11HB3`@J5Q<47AXH124O7@@U8b83:BPW12`];0@`<C04=3He13Pj>`@m@403@dM814aAD@AGFe`4
HfMX171bL`AkOGd4QXN60i6AS`BJVYL4X9nK1:FRW@BWXI/4ZJ2H0j^PUPB^X9D4/J6D1;BRU0BhXi<4
^jBC1;nUU1Goool001Coool4`JNE1<2WUPBoZ9P4_ZRI1;fYV`>lZYd4_:^O1;^/X@Bk[Z@4]JVQ1:^Q
V@>RV904V8j718b3O@AmMW44KVQS15iHE0A=B4D3?SXe13</9P@]8ad4:1hG12@I4@@P5@d47A490aT>
1`@F30D45@/511<:1@@B2@D44@X60a8<2@@D3`/45Q8?11XF4`@M6QP48AlM12DS8P<Y:2L4;2d/130a
<0@d=SD4>3Xk13e0@0=3AdP4C55A15MKG0ASIfP4L79c17]mO@B6QhH3TI6?19ZJU`BPWi/4YJ:M1:NQ
V`BYX9P3Zj2F1:jPU@BaXI@4]::D1;RST`BkY9<4_jFD5Oooo`005?ooo`C1YiD4`:NF1;nXV0BnZ9T4
_JVK0kbZW@BlZil4^jbQ1;^^Y0BeZJ44Zj6I0j:HT0BHSXL4S8=m17efL@A^J6<4GUQD14e8A@<n>SD4
<b`V12dS7@@X7QL491TA120E3@@M4@T36@h711H<1@@E2`D44`X511891@@A2PH34P`911@?2`@F4Pl4
6QHC11dJ60@Q7ad49B<R0bTX9`@/;B`4<34`13@f=@@h>S/4?D100d=7B0A<DE44Ee]L16=WJ0A`LW<4
Ngem18J7QP>ATHl4VYZG1:2OV`BUXYd4Yj6K1:VPV0>[X9H4[Z2E1;6QU0BdXY@4^:>C1;^TT`BoYI@E
oooo000Doooo1<6WU@C0YiH4_jRH1;jXV@BmZI/3_:ZM1;b[W`Bk[:44^jjT1;FYX@B[XIT3XYR@19R>
Q`B<Pgd4OGIa16iXH`ANF5@4CDQ50chj=@@c;2H4;B<M12PN5`@T6A4481D=11dA2@<I3PL45P`511D;
1@@C2PD44PT5114:1P<B30T450l;11HB3`@J5Q<47AXH124O7@@U8b83:BPW12`];0@`<C04=3He13Pj
>`@m@403@dM814aAD@AGFe`4HfMX171bL`AkOGd4QXN60i6AS`BJVYL4X9nK1:FRW@BWXI/4ZJ2H0j^P
UPB^X9D4/J6D1;BRU0BhXi<4^jBC1;nUU1Goool001Coool4`JRF1<6YV0C0ZYX4`:^L1<2]W`?0[Z84
`;6U1<6cZ@C1]J`4_;:Z1;B[Y0>YXI/4WYNB19><Q`B5OgX4Mg5]16QSG`AGDe03AD4n13Da;P@[9244
9A/F120E40@K40/45P`70a<91@@@1`<43@D110/50@@:1@842@D30`/71P@=2PT440h=11@B4@@H5aL4
71`L120Q8@<U9RH4:B//12da<P@b=SP4>C`n1455A`=:Ce44EE]M169WJ@A^Lg@4NGen18F8R@BAU9<3
WInM1:NWY@BZZJH4[:VU1:fXXPB_YYh3/:FL1;:TV@BdY9P4]jBG1;ZUUPBlYID4_jJD5Oooo`005?oo
o`C1Z9H4`JVH1<2ZVPC0Zi`4`:fO0l2^XPC0/JD4`K>Y1<6e[0Bl/ZX4]:^T0jVQV`BNUi84Thb718Eo
NPAgLFd4J6=O15MCD0=5@Ch4=C4^12/T8@@U6aH481D@11/@2`@F30L34`T511070`@=1@442`D110X5
0P@91@<32`L610d:2@@@3Pd4518A11PG5`@L71`4824Q0bDV9P@Y:b`4;C4b138f>0@i?3h4@DE70dY?
D@AEFed4HVMY16icM0AiOGh4QHR9196DT`>MWid4YjNU1:ZYYPB/ZJD4[JRR1:nVWP>`YI`4/ZBI1;BT
V0BgY9L4^ZFF1;bUU@BoYY@Eoooo000Doooo1<6XUPC1ZIP4`:ZJ1<2[W0C0[Il3`:jR1<2aY@C1/jT4
`KF/1;bbZPBdZj@3ZJ6K19jGTPBCS8L4QGmj17MaK@AXHel4Ee=@0dE1?P@e<Bh4:b@Q12DK5P@P5A04
6a0;11H<1`<C2@D440L310d50@@;1@442PD210T50`<;1`H43@X9110>3@@D4Q4461LG11`L70@P8B43
9BHV12T[;0@]<C84<SHh13Tl?PA1ADL3BTmA15EKG@ARIfT4KW=d17UmOPB5R8T4TIBC0ifOW@BWYjD4
ZZVV1:bYY@B]Z:84[jJN0k2UW0BbY9T4]:BH1;NTU`BjYIH4_:FE1;nVU1Goool001Coool4`JRF1<6Y
V0C0ZYX4`:^L1<2]W`?0[Z84`;6U1<6cZ@C1]J`4_;:Z1;B[Y0>YXI/4WYNB19><Q`B5OgX4Mg5]16QS
G`AGDe03AD4n13Da;P@[92449A/F120E40@K40/45P`70a<91@@@1`<43@D110/50@@:1@842@D30`/7
1P@=2PT440h=11@B4@@H5aL471`L120Q8@<U9RH4:B//12da<P@b=SP4>C`n1455A`=:Ce44EE]M169W
J@A^Lg@4NGen18F8R@BAU9<3WInM1:NWY@BZZJH4[:VU1:fXXPB_YYh3/:FL1;:TV@BdY9P4]jBG1;ZU
UPBlYID4_jJD5Oooo`005?ooo`C2Z9H4`ZZI1<:/W0C2[Yl4`k2R0l>bYPC4]Z/4a[Z`1<Vo^0C7_[P4
_KF_0k:[YPBXXYd4WINB192:QPB1O7T4LVi/169OGP=ACdh4?S`l12l[:P@T7Q`47ADB11L?30@A2@H3
30D310T200@70@041@00108000@10@430`<310L71`@:30d43Q0A11<E5P@H6a`47B4Q0b8V:0@X;Bl4
;S<f13Dk?P@m@dH4B4iA0eAKGPAQIfX4KWAf17^0PPB7S8d4TiNH19nSXP>Y[:/4/kNg1;Ni]`Bd/Zh4
]:jX1;B/Y0>eZZ04]ZRM1;RWV`BiYiT4^jNG1;jWUPC0YiDEoooo000Doooo1<:XUPC2ZYT4`ZbL1<:^
W`C3/:83`k:V1<BfZ`C6^[04bKnh1<Nn^0Bm]Jl3/Z^V1:RRW@BMUi84T8Z6185lN@AbKV`4HUmN0e5?
CP@n?3`4;b/Z12@N70@M5A845`l<11491P<<1@<42@8010L100@500040P0010410@<30`<41`L710X<
3@@>41444aDF11PK70@M8B438RHX12P];`@^<cH4=C/n13e3APA8CU43E5]N165WJPA^M7H4Nh2218N<
S@BCUiP4Wj>R0jV/Z`Bc]kL4]kVg1;Bb[PBd[ZP4]:bT0kFZX0BfZ9d4^:NK1;VWV@BkYiL4_ZNF1<2W
UAGoool001Coool4`ZRF1<:ZV@C2[9`4`ZjO1<>`XP?3/ZH4a;J[1<Jj/0C9_kP4akjh1;fe[`>bZjH4
Z::M19fGTPB@RXH4PGai179^K0ARGeh3DDm>13hl?0@_:bX491hL11dE4P@G3``44@T60``50`@90P04
1`4010D000@200040@410`<30`@71`L42P`=10h@4@@C5AH461/L11dQ8@<R9RP4:2d_12hc=P@e>ch4
?D=614Q>D@=DFeh4HFMZ16idMPAkP884Qhb=19>GV0BOXj83ZJb[1;>g]`Bg^KL4];:^1;B^Z0Bd[:@3
]JZP1;JXW@BhYi/4^JNI1;^WU`BnYiH4`:NE5Oooo`005?ooo`C2Z9H4`ZZI1<:/W0C2[Yl4`k2R0l>b
YPC4]Z/4a[Z`1<Vo^0C7_[P4_KF_0k:[YPBXXYd4WINB192:QPB1O7T4LVi/169OGP=ACdh4?S`l12l[
:P@T7Q`47ADB11L?30@A2@H330D310T200@70@041@00108000@10@430`<310L71`@:30d43Q0A11<E
5P@H6a`47B4Q0b8V:0@X;Bl4;S<f13Dk?P@m@dH4B4iA0eAKGPAQIfX4KWAf17^0PPB7S8d4TiNH19nS
XP>Y[:/4/kNg1;Ni]`Bd/Zh4]:jX1;B/Y0>eZZ04]ZRM1;RWV`BiYiT4^jNG1;jWUPC0YiDEoooo000D
oooo1<:YU`C3ZiX4`jfM1<B`X@C5/jD3a[JZ1<Rj[`C;_kH4c/Fn1<k7`@C5_kX3^kF`1;2[Y`BUXId4
V9FB18^8Q@AnNgP4L6e/0f1NGPA?CDd4?S`l12l];@@Q7Qh45a<C10h;2P<810@41@4110800@@00044
004310031@<01@L40PL:10H;3P@;4A@43aHI11@K7P@I8BD38BP/12P`=@@`>3d4>T9714E>DPABFel3
H6Q/16ieN@AlPXD4RHnA19JKW@BRYjP4[[:b0kJj^PBj_Kd4_;fk1;^h]0Bi]:h4^K2Y0kV^Y0Bi[:44
^ZZN1;bYV`BmZ9T4_jRG1<2WUAGoool001Coool4`ZVG1<>[VPC3[Id4a;2Q1<FcY@?6]ZX4b;Z_1<^o
]PC>aKh4c/O11<Fo^P>k]K04/:^W1:FQW@BHUI84RhR517ikN0A`KF`3H5iN14m=C@@n?3`4;bd]124N
7P@G4a<43P/:0`P410@50@440P0110000@@00@<400<50`051`@21`X41P/>10/A50@?5QT451/N11TQ
9@<Q:2`4:30e130h?@@j@TL4ADiB159KG`=PJ6`4KWEi17b2Q@B9Si44UY^M1::WZ0B^/[83][Zj1;Zm
_@Bl_K/4^kRd1;Vd[PBi/:T3^JjT1;V/X@BjZYh4_:VK1;fXV@BoZ9L4`:NE5Oooo`005?ooo`C2ZIL4
`j^J1<>]W@C4/:44aK>U0lJfZPC8^Zl4bknf1<k5_PC>al44aKnj0k^e/0B`ZjL4YJ6M19RETPB;R8D4
OW]h171]K0=PGUh4Cde=13hl?0@_;Bd48AhN11LC4`@>2`X320@410D10@@20044000110010`@00`D3
00D710872P@62`h42a4D10lF6@@D6ah46B4U0b4X;0@X<3D4<3Pm13Y2A`A5CU84DU]O0f1XK0A^MGT4
O8:518V?T@BFVid4XZNX1:jb/P>f^[X4^[fm1;bm^`Bk^;@4^KB^1;V`Z@>i[Z@4^JbQ1;ZZWPBlZI/4
_JRI1;nXU`C0YiDEoooo000Doooo1<:YU`C3ZiX4`jfM1<B`X@C5/jD3a[JZ1<Rj[`C;_kH4c/Fn1<k7
`@C5_kX3^kF`1;2[Y`BUXId4V9FB18^8Q@AnNgP4L6e/0f1NGPA?CDd4?S`l12l];@@Q7Qh45a<C10h;
2P<810@41@4110800@@00044004310031@<01@L40PL:10H;3P@;4A@43aHI11@K7P@I8BD38BP/12P`
=@@`>3d4>T9714E>DPABFel3H6Q/16ieN@AlPXD4RHnA19JKW@BRYjP4[[:b0kJj^PBj_Kd4_;fk1;^h
]0Bi]:h4^K2Y0kV^Y0Bi[:44^ZZN1;bYV`BmZ9T4_jRG1<2WUAGoool001Coool4`jVG1<B/V`C5[il4
a[:S1<NeZ0?9^Jd4bkfc1<k2^@CAb<44e<g91=3;a`?6`Kd4^kNd1;6]ZPBUXYl4UiFC18Z8Q`AlNgX3
KVa/15mMG@A?CTh4?cho130`<@@T8b@46aPJ0a8A4`@<2`h420P<10H93@@52Pl41@/A0`D<4P@53Q@4
1a4G10/E70@?6b045R4W11dX;P<T;cD4;CPn13Q3B0A4Ce@4DEaQ161ZKP=_Mg/4OXF818bBU@BJWj84
Yjb^1;Bh^@Bn`/<3aL[:1<K9b@C3`l44`;fi1;jh/PBm]:d3_K6X1;f_Y0Bm[J04_Z^M1;nZVPC0ZIP4
`JRF5Oooo`005?ooo`C3ZIL4a:bK1<F_W`C6/Z<4akFX0lVi[@C;_K<4c/:i1=78`@CDcLT4d<_70lK1
_@Bk]k@4/JfZ1:FRW`BGUI<4RXR717akNP=^K6`4GeeM14m>CP@o?Sl4<30a12@S90@K61X34Q4C10`;
3P@820`41PT=10D:3`@52a431@`B10D>50@74AL42aDL10lK80@F8BL47BP^0b@_=@@]>3h4>4=814A?
E0AAG644H6Y^0fmgN`AnQHP4S9:E19ZOXPBW[:h4];Ri1;k2``?5b/X4a/W91<?3`@C0_KT4_[Rb1;fd
[@>m/JP4_JnT1;f]X0BnZid4_jZJ1<2YV0C1Z9HEoooo000Doooo1<>YU`C4[9/4aJnO1<JbX`C7]JP3
bKV]1<^m/`C>`[T4dLS11=C=b@C@blL3a/6m1;^g]0Ba[JX4YJ:O19NET`B:R8L4O7]j0fi/K0AOGEd4
Cdi>13ln?`@`<34492<T11/H6P<B4A<430/>10P830@62@d41@X?10D;4@<531841@hD10LA5`@;5A`4
3a/P11HQ9`@M:2h392le12dh?P@h@dP4A4mD155LH@APJVh3KgMk17j5R0B<TYD4VYnR1:N/[PBd^;T4
_/;30lG:bPC6bLT4`l?11<2m^@Bn^;84_KB]0kfaZ0Bm[j@4_JfP1;j[W@BoZYX4`:VH1<6XUQGoool0
01Coool4`jZH1<B]W0C6/:04ak>U1<VgZP?;^jl4c/2e1=75_0CDc<@4fM?>1=WDd0?@c<P4a/:o1;bh
]@Bb[jd4YZBR19NEU0B9QhH3NWQh16YYJ@ALFU/4CTa=1490@@@f=CL4;2d_0b<U:@@L7b<45QXO11@I
7`@C6Al441TP0`lJ8@@?6b<441dU11<P:0@H9Rh47R`d12Dc>`<^>d<4>4E<14AAE`ABGV@4H6]`16mi
OP=oQh`4SYFI19bSYPBZ/;<4^Kk01<G9b`C=d]@3d]SI1<oCd`C9bLH4aL:m1<>l]PC1^;03`;BZ1;na
YPBo[j84_jfO1<2[W0C0ZIT4`JRF5Oooo`005?ooo`C3ZYP4a:fL1<J`X0C7/jD4bKNZ0l^k[`C>`;D4
dLFl1=C<a0CIdlh4fMC@0m3<b0C6`[l4_;Re1;:_[@BVY:84UiFD18V7QP=jN7P4JVUY15aJF`A>C4d4
@T1113He=`@/;Bl38bDY11`O8`@F6Ql451TO11<I7`@@6B033aXQ10lK8`@@7BD44b0X11PV;P@N;3@4
9C<k0bhk@`@hAD`4A55G159NI0APJg04KgUn0gn7S0B>UIT4W:>V1:Z`/`Bi_/04aLW;1<gBe0?Bf=T4
cm?C1<W9aPC5`[d4`kbf1<6h/0?0]:X4_k6V1;n_XPBo[Il4`:^L1<2YV@C1Z9HEoooo000Doooo1<>Z
V0C4[I`4a[2P1<NcY@C9]jX3bk^_1<k0]@CAaK`4e<c41=WCcPCIe=03d<c81<K2_`Bl^;D4/Zn]1:JT
XPBGUI@4RHN60gYhN0AZJFT4G5YK14i<C@A2@444=SDg12`];`<S9BT471lS11HJ7`@D6Al44aTO110I
80<?6R443a/S110M9@@C82P462H^11h/=0@U<c/3;S]313Q5C0A4DEL4DUiT161[L0A_NGh3OhN<18jE
V@BLXjH4Z[2c1;Vn`0C5bL/4cM;D0m;Hf@C?dm<4bLW61<G2_@C3_;H4`KR`0l2dZPBo/JH4_jnR1;n]
W`C0Zi`4`:VI1<6XUQGoool001Coool4`jZH1<B]W0C6/:04ak>U1<VgZP?;^jl4c/2e1=75_0CDc<@4
fM?>1=WDd0?@c<P4a/:o1;bh]@Bb[jd4YZBR19NEU0B9QhH3NWQh16YYJ@ALFU/4CTa=1490@@@f=CL4
;2d_0b<U:@@L7b<45QXO11@I7`@C6Al441TP0`lJ8@@?6b<441dU11<P:0@H9Rh47R`d12Dc>`<^>d<4
>4E<14AAE`ABGV@4H6]`16miOP=oQh`4SYFI19bSYPBZ/;<4^Kk01<G9b`C=d]@3d]SI1<oCd`C9bLH4
aL:m1<>l]PC1^;03`;BZ1;naYPBo[j84_jfO1<2[W0C0ZIT4`JRF5Oooo`005?ooo`C3ZYP4aJfL1<Na
X@C8]:H4b[R[0lfm/@C@`[L4dlRn1=O>a`CLe]04h=cH0m_HePCAc//4alC21;bj^0B`[jd4XZ6P19BC
T`>7QXH4NGQh16a/K@AOH644DUAF14Q:C@A0@TD3>C/o138e>P@[<3D49bdb12D/<@@T;3<38bdd12<_
=P@U<SX4:3Dn12`i@P@a?dP4>DM?0d9@E`A=FV04F6AZ16E`MPAdOX84PX^@0i6IW0BOYZT4[[Bf1;c2
``C9c]04e=WK1=cSi@?KhN84dmGD1<g<b@C9aL04a[nh1<Bj/P?2]Z`4`[>W1<6`X`C1[Z04`JbL1<6Z
V@C2Z9LEoooo000Doooo1<>ZV0C5[I`4ak6Q1<RdYPC:^:/3cKfa1=32]`CCb;h4elk71=cFd0CPg=P3
fmSF1=7>b`C7a<84_;Zh1;2_[@BRXJ04U9>C0hN6QPAiN7P4K6a]15mPH@ABE5H4B4Y=1412A@<i>cl4
<SDj12/`=@@W;C849B`a12@/<`<S;C@48blf12Db>P@X=Ch4;3U2134oB0@iAdl3@U1G14eJH0AHI6X4
IG1f17AnPPB2Ri03TIVL19nVZ@B^];H4_<;31<W>d0CDfM/4g>?U0m_QhPCCeM@4cLc91<W5`0C6_kP4
a;Zb0l:f[0C2/jL4`K2S1<6^X0C1[9`4`JZI1<:XUaGoool001Coool4`jZH1<F]W0C7/J44b;BV1<Zh
Z`?=_K44d<:g1=?8_PCGc/L4g=K@1>3Lf0?Kf=H4dLk;1<O4`PBl^[P4/:n]1::QX0BDTi<3QhJ617Uh
N0A/K6d4Gf1Q159DEPA8BTd4@4950cTk?`@b=CX4:c0e12L]<P@U;34492`c0b<]=0@S;cH49C8j12Pe
?P@/>D84<Cm813U7C`=2D5L4CEYP15QTJPAUL7H4M7j218:;T0>AVI`4WjJY1:jd]PBl`/<4bLk@1=CI
f`CLhnD3fn7R1=?Ee0C=c<T4bLG01<Jo^0C4^[83`[J/1<:cY`C1/:<4`JjP1<6/W0C1ZYT4`ZRG5Ooo
o`005?ooo`C3ZYP4aJfL1<NaX@C8]:H4b[R[0lfm/@C@`[L4dlRn1=O>a`CLe]04h=cH0m_HePCAc//4
alC21;bj^0B`[jd4XZ6P19BCT`>7QXH4NGQh16a/K@AOH644DUAF14Q:C@A0@TD3>C/o138e>P@[<3D4
9bdb12D/<@@T;3<38bdd12<_=P@U<SX4:3Dn12`i@P@a?dP4>DM?0d9@E`A=FV04F6AZ16E`MPAdOX84
PX^@0i6IW0BOYZT4[[Bf1;c2``C9c]04e=WK1=cSi@?KhN84dmGD1<g<b@C9aL04a[nh1<Bj/P?2]Z`4
`[>W1<6`X`C1[Z04`JbL1<6ZV@C2Z9LEoooo000Doooo1<BZV0C5[Yd4ak6Q1<VeYPC;^J`3c[jb1=73
^0CEbL04fM381=kGd@CSgm/3hn3M1=_Ie`CBd<h4alK41;Zj^0B_[jh4Y:>S0iNGU`B9RHT4Ng]l16m_
L0ATIFL4FeeO15=EF0=;CU84ATU=1455BP@m@TP4>T5713U2B0<j@dX4>TE<13a8C`@nBe<4@e1H14UF
GPA@GFD3FFI/16=_M@A]N7h4NXB918RAU@BFWZ83Y:^^1;:h^PC1a/L4c]?D1=SNg`CRj^`4hn_]0mcO
g`CEe]@4d<k:1<c7`@C9`KT4a[bc0lFh[@C3]:P4`k6T1<:_X0C2[9d4`ZZJ1<:YUaGoool001Coool4
a:ZH1<F^W@C7/J44bKFV1<^i[0?>_[84dL>h1=G9`0CId<P4g]OA1>?Of`?Sh=d4fmWG1=;@cPC7a/@4
^[Zh1:n_[PBTXj<3UiNG18V9R@AkNg`4Kfm`16AUI`AKGEl4DeEH0d]>DPA6BDd4@DE:13e2B0@j@DL4
>D980cY3BP@jAD`4?4Q?13i;D`A3D5P4BEIN151MI@=IIV`4Hfme16ehOPAjQ8T4R96E19JNXP>TZjh4
/[Rj1<76a`C>dm@4f=kO1>;Zk0CSjnd3g=oO1=GFe0C@c/X4c<O11<W1^@C6_;<3aKR]1<>dZ0C3/J@4
`ZnP1<:/W@C2ZYX4`ZVG5Oooo`005?ooo`C4ZYP4aJjM1<NaX@C9]JH4bkV/0ljn/PCA`kP4eLW01=W@
b0CNem44hmoK0n?Pg@CKfML4d]3>1<O6a0Bj^[P4[jn^1:BSX`>GUiL4RHV917]kO0A_Kg04I6EW15]M
G`ACEEP3BdiB14I9C@A1ADX4?D9813Y1A`@i@TP3>T=:13Y5C0@lB4l4?T]C14=@F0A9EUh4D5eU0eUV
K0ASKgD4KGQn17Z4R@B8TID4UYjR0jB[[PBb^;X4`LK71<kCe0CHg]l4h^[/1>?[k@?Lgml4eMKD1=3>
bPC<al44bL6i1<Jl/`?5^:d4`kBX1<>aY0C2[j04`ZbM1<:ZVPC2ZILEoooo000Doooo1<BZV0C5[Yd4
ak6Q1<VeYPC;^J`3c[jb1=73^0CEbL04fM381=kGd@CSgm/3hn3M1=_Ie`CBd<h4alK41;Zj^0B_[jh4
Y:>S0iNGU`B9RHT4Ng]l16m_L0ATIFL4FeeO15=EF0=;CU84ATU=1455BP@m@TP4>T5713U2B0<j@dX4
>TE<13a8C`@nBe<4@e1H14UFGPA@GFD3FFI/16=_M@A]N7h4NXB918RAU@BFWZ83Y:^^1;:h^PC1a/L4
c]?D1=SNg`CRj^`4hn_]0mcOg`CEe]@4d<k:1<c7`@C9`KT4a[bc0lFh[@C3]:P4`k6T1<:_X0C2[9d4
`ZZJ1<:YUaGoool001Coool4a:ZH1<J^W@C8/J44b[FV1<bj[0??_[84d/Bi1=K:`0CJd<P4gmSB1>GR
g@?YjND4i^GS1=gLf`CCdm44bLS71;fm_0Ba/K03YZFU19ZIVPB=SXl4PX>417QiN`A`LG<4JFY/0f9S
I@ALGV44Ee]O15=HG0ABEe`4DUQN0e9IG`ACFf84EEiU15URJ@ANJ6l4IFie16afO0=cOH<4NhB:18F>
TPB?V9`4W:>W1:V`/P>h_Kl4aL[;1=3DePCJg^04iNc^1>S_l@CRi^H3g=gL1=KEdPCBc/T4c/O11<_1
^@C8_K<3a[R^1<FeZ@C4/Z@4`jnQ1<>]W@C2ZiX4`ZVG5Oooo`005?ooo`C4ZYP4aZjM1<RaX@C:]JH4
c;Z/0lnn/PCBa;T4e/[01=[@b0COf=84iN;M0nWYi@CViN<4gMcK1=?Cd@C9b<L4_Kfl1;6a/0>VYJD4
VYVJ18f>S`B2Ph@4N7Uk171aL`AYJV`3HV=U15aNH@AGFel4DeQL159GG0ABF5h3DUUO15=KHPAEGVD4
FF9Y15iXK`AUKWD4K7Il0g=mP`AkQ8X4QHjB18nHW0BLXjL4ZK2b0kRm_`C5b//4d=CF1=[Nh0CUk>h4
j>oa1>;ViP?LgM`4e]GB1=;>b@C>al44bl6i1<Rm/`?6^:h4aKFY1<BbY0C3[j44`jfM1<:[VPC2ZILE
oooo000Doooo1<BZV0C6[Yd4b;6Q1<ZeYPC<^Z`3ckjb1=;4^@CFb/04f]381=oHdPCUh]d3jNWU1>KU
h`CMg=/4dm?A1<W8a`Bm_K`4/K6`0jJUY@BJVIX4SHj?18:3Q0AhNG/4L75c16UZK0=RHfD4G5iQ15MK
G`ACF5`4DUML159HGP=BFEl4De]R15ENI@AIHVT4GVQ_16E^M@A/MW`3Lgf317^4RPB5SY84SiRL19bS
Y`BY/;83^;fo1<G:b`C@e=H4f]kP1>G/kPCXko44h^KV0mcMg0CFeM84d/k91<k7`@C;`KT4b;fc0lJh
[PC5]JT4a;:T1<>_X@C3[Id4`Z^J1<:YUaGoool001Coool4a:ZH1<J^W@C8/J44b[FV1<bj[0??_[84
d/Bi1=K:`0CJd<P4gmSB1>GRg@?YjND4i^GS1=gLf`CCdm44bLS71;fm_0Ba/K03YZFU19ZIVPB=SXl4
PX>417QiN`A`LG<4JFY/0f9SI@ALGV44Ee]O15=HG0ABEe`4DUQN0e9IG`ACFf84EEiU15URJ@ANJ6l4
IFie16afO0=cOH<4NhB:18F>TPB?V9`4W:>W1:V`/P>h_Kl4aL[;1=3DePCJg^04iNc^1>S_l@CRi^H3
g=gL1=KEdPCBc/T4c/O11<_1^@C8_K<3a[R^1<FeZ@C4/Z@4`jnQ1<>]W@C2ZiX4`ZVG5Oooo`005?oo
o`C4ZYP4aZjM1<RaX@C:]JH4c;Z/0lnn/PCBa;P4e/Vo1=_@b0CPf=44i^7L0no^j`Cblo44j^[Y1>3P
g`CEe]D4bl_;1<71`@>h]kP4[Jf^1::RX`BHV9X4SHj@18F6Q`AnP803N7Yk17=eM`A_LW@4KW5d16a_
L`A[Kg<3Jg1e16ebM`A`MGX4M7Yo17Z0Q@AoQX/4QXfB0hfCU`BDVih4WZBV1:R]/0Bd^;X4`<C60l_?
d@CFf]/4h^GV1>[_k`C[l?44in_[1>7ShP?LfmT4emC?1=?=a`C?akl4c<6i1<Vm/`?7^Jd4a[FY1<Fb
Y0C4[j44`jfM1<>[VPC2ZILEoooo000Doooo1<BZV0C6[Yd4b;6Q1<ZeYPC<^Z`3ckjb1=;4^0CFbKl4
fm381>3Hd@CVhM`3knk[1?;cl@CZj^T4h>3O1=GFe@C;bl/4`L710kRg^0B][Jh4XZ:S19RHVPB=SY04
QHJ717j0P0=hNW/4LgEg16mbM0A^LG@4K6mc16]_L`=[L7D4KG9g171eNPAdNWl4NX2517n6R`B6SI83
SI>G19BKWPBNY:H4Z:f`1;Bh^PC0a<H3bloA1=KJf`CRiNH4j^o_1>_`l@CWjn/4hN?R0mcKf@CGe<l4
dlg71<o7_`C<`KT4bKfc0lNi[@C6]JT4aK:T1<B_X@C3[Id4`j^J1<:YUaGoool001Coool4a:ZH1<J^
W@C8/J44b[FV1<bj[0??_[84d/Bh1=K9_`CKd<P4h=SA1>KQg0?_k^/4l_?a1>[Zj@CPh=l4eMKE1<_;
b`C1`L43^;Nh1:f][PBRXZ<4V9RJ18f>T0B5QXL4OX200gQjN`AcMGL4Kg9d16iaM0A/Kg<4Jfmc0f]`
M@A]LWL4L7Ej17AjO`AjP8D4OhJ;18J=TP>=TiL4U9^N19jTYPBX[K04];Rj1<34aP?;cm44e][K1>;U
iPCZknl4jo3a1>O[j`CQhn83g=_I1=ODc`CCcLL4clNo1<c1^@C9_K<3akV]1<JeZ@C5/Z@4a:nQ1<>]
W@C3ZiX4`ZVG5Oooo`005?ooo`C4ZYP4aZjL1<RaX@C:]JH4c;V[0lnn/@CB`kL4e/Rn1=[?aPCOe/l4
iMoI0ncYi@CdmO<4moSh1>k_k`CShn<4fMWH1=3@c`?8b<L4`<301;Ng^0B^[Zl4YJFV19fMWPBGUiP3
TY:C18j?S`B:Rh`4QXR918F6R0B4QHP3Q8J918F8R`B8Rhh4Ri2C19>GV`BKWj<4X:BW0jJXZ`B^/;84
]kZj1<32``C8bl/4dmGE0mgPh0CUj>T4k?3b1?3gnPC]loD4i^SX1>3PgP?KfMD4em;<1=?;a0C?a[d4
c<6g1<Zl/@?8^:`4akFX1<FbY0C4[j04a:fM1<>[VPC3ZILEoooo000Doooo1<BZV0C6[Y`4b;6Q1<Ze
YPC<^J/3ckja1=;3]`CFb;h4f/o61=oFc`CUgmT3k>WU1?Cel`Cgn?P4k^o_1>?Sh`CIfMP4d=3?0lS8
a`C0`<04]kNh1:j^[`BUYJH4WIfN19NGV0>BTY<4SXn?18Z;S0B6R8T4QHJ818B5R0>4QXT4QHR;18R;
SPB;T9<4TiNK19^OX`BPY:L3YZR[1:j`/PBg^[X4`<;31<S;b`CCeMD3gN3P1>GXj@C/l?84l?Oj1>gc
m@CVj>P4h>3N0m_Ie@CGd/`4dl_41<o6_@C<`KL4b[ba0lRh[0C7]JP4aK:T1<B_X0C4[Id4`j^J1<>Y
UaGoool001Coool4a:ZH1<J^W0C8/J44b[FV1<biZ`??_[44d/>g1=K8_PCJclH4gmK?1>GOf@?/jND4
m?Gc1?Ohn0C^knl4hn?S1=WIf0C@d<l3b<S71<30`0Bg]kP4[Zj_1:FUYPBMWIh4UiNH0i:BT`B>Shl4
RX^<18J8R@B5QXP4Q8F80hB6R@B5R8/4R8^>18^@T`BCUi/4VinS1:2TY`>VZ:/4[[2b1;Nj^PC0`/<4
b<_;1=?Ee@?Mh>04iNSY1>c`lPC`moX4kO?e1>KXj0CPh=h3fmWE1=OBc0CCbl@4clJm1<c1]`C:_;43
b;R/1<NeZ0C5/Z@4a:nP1<B]W@C3ZiX4`jVG5Oooo`005?ooo`C4ZYP4aZjL1<RaX@C:]JH4c;V[0lnn
/@CB`kL4e/Rn1=[?aPCOe/l4iMoI0ncYi@CdmO<4moSh1>k_k`CShn<4fMWH1=3@c`?8b<L4`<301;Ng
^0B^[Zl4YJFV19fMWPBGUiP3TY:C18j?S`B:Rh`4QXR918F6R0B4QHP3Q8J918F8R`B8Rhh4Ri2C19>G
V`BKWj<4X:BW0jJXZ`B^/;84]kZj1<32``C8bl/4dmGE0mgPh0CUj>T4k?3b1?3gnPC]loD4i^SX1>3P
gP?KfMD4em;<1=?;a0C?a[d4c<6g1<Zl/@?8^:`4akFX1<FbY0C4[j04a:fM1<>[VPC3ZILEoooo000D
oooo1<BZV0C6[I`4b;6P1<ZdY@C<^:X3ckb_1=;1]@CEak/4fLg31=kDb`CSfm@3jNCO1?3^jPChnOP4
n__k1?;bl@CWinH4gMgL0mKFe@CAd=04b/W91<?2`@Bl^kX4];Bd1:j^[P>ZZ:T4YJBU1::QX@BOWYl4
WIfN19bLW@>LW9h4WIfO19jOX0BRXj@4YjNX1:f/[0Be]K@3_;bl1<C4``C;blX4dM7A1=WJf@CQh^43
jN_[1?7dm@Cenoh4l_Sk1>_]k@CTi>84gmcI0m[Ed0CFclP4d/W11<o4^`C=_kD4b[^`0lRhZ`C7]JL4
a[:S1<F_X0C4[I`4`j^I1<>YUaGoool001Coool4a:ZH1<J]W0C8/J04b[BU1<bhZP??_:l4d/6e1=G7
^`CIcL<4g]C;1>?Ke0?Yi=l4l>kZ1?Sin0Cjno/4l_;a1>OWiPCMgM`3e]KE1=7@d0C:bLT4`l;11;bk
^PBd];@4[Zj^0jZXZ@BUY:D4XZ6Q19nNW`BMWIh4W9bM0ibLWPBMWIl4WYnP1::SY0BWYjP4[Jb/1;Fe
]0>l_;`4a<C31<_;bPCAdM44fM[I1>7Rh@?Yjn/4lOCe1?GkoPCbn?/4jng]1>CThPCOg=T3f]G@1=K?
b0CBbL44clBk1<fo]@C:^k03b;R[1<NeY`C6/Z<4aJnP1<B]W0C3ZiT4`jVG5Oooo`005?ooo`C4ZYP4
aZfL1<RaX0C:]:D4c;RZ0lnl[`CB`KD4eLNk1=W=``CNe</4hm_D0nWTg`C`k^X4n?Wh1?[kn`Cbl_44
inOV1=gMg0?Fe]D4dM3@1<[9b@C3`/44_;^j1;Bd]0B^[Zh3ZZRY1:FTY@BRXJ44WijO19fMWPBLW9d3
W9bN19fMW`BNWj04XZ>T1:NWZ0B][:`4]KFd0kbl_0C4a<<4bl_:1=7Ad@CIf]T4hN;Q0nW[j`Cam?D4
mO_n1?;hn`C[kNd4i>CR1=oLf@?JeM04e/o81=;9`@C?a;/4cKne1<Zk/0?8^:/4akFW1<JbX`C5[j04
a:fL1<>[V@C3ZILEoooo000Doooo1<BZV0C6[I`4b;6P1<ZdY@C<^:X3ckb_1=;1]@CEak/4fLg31=kD
b`CSfm@3jNCO1?3^jPChnOP4n__k1?;bl@CWinH4gMgL0mKFe@CAd=04b/W91<?2`@Bl^kX4];Bd1:j^
[P>ZZ:T4YJBU1::QX@BOWYl4WIfN19bLW@>LW9h4WIfO19jOX0BRXj@4YjNX1:f/[0Be]K@3_;bl1<C4
``C;blX4dM7A1=WJf@CQh^43jN_[1?7dm@Cenoh4l_Sk1>_]k@CTi>84gmcI0m[Ed0CFclP4d/W11<o4
^`C=_kD4b[^`0lRhZ`C7]JL4a[:S1<F_X0C4[I`4`j^I1<>YUaGoool001Coool4a:ZH1<J]V`C7/9l4
bK>S1<bgZ0?>^jd4dKnb1=C4^0CHb[l4g=361>7Gc`?Vg]P4k>OR1?;_k0Cin_T4nock1?Cdl`C[jnX3
hn;R1=gMg@CIfMT4e=CD1<o>c@C<bLT4b<G50l?0`0Bn^kX4^[Ng1;Nd]0Bd/[87/k2`1;Ba/@Be/[44
]K:`1;Nd/@Bk^KD4_kbj0lC2`0C<b/L4dm;@1=gLfPCUiN@4k>g/0o?em0ChoOh4mO[l1>kal0CXinD4
h]oK1=gHdP?IdL/4eL_31=76_@C?`[L4c;fb1<Zj[@?8]ZT4akBU1<JaXPC5[il4a:fL1<>[V@C3ZIHE
oooo000Doooo1<BZV0C6[I/4ak2O1<VcX`C<]jP3c[^]1=6o/PCDa;P4f<Zo1=c@aPCQell3i]kH1>cW
hPCbkn`4nO[i1?_ln`Cdm?<4jn_Z0n?RhPCMgMd4fMWI1=CDe0C?c/d4c<W91<S5a@?3`<04_[^j1;Zg
]`Bg];@4];:b1k>`/0Bd/K44]K:a1;Fb/0Bg];44^kVe1;nl^P?4`/04c<[71=?Bd0CMg=X4iNGT1>c]
k0?cmO@4n?gn1?Gjo0C^lO04j>OU1>;Of`CMf=83fM7;1=G;``CAa[d4cl:g1<bm/PC:^Zd3b;JY1<Nd
Y@C6/J84aJnO1<B]W0C3ZiT4`jVF5Oooo`005?ooo`C4ZYP4aZfK1<N`W`C9/j<4c;NX0ljk[@CA_k84
e<Bh1=S:_`CLd<H4hMO?0nKNf0C/in84l^o/1?Wjn@Cko?/4m?Cc1>_[jP?Sh^84gMgM1=WIf@CDe=@4
clk=1<c9b@C8aLD3`l301;jk^PBj]kL4]kBd1;Bb/PNc/;04];6a1;Fb/@Be/[04]kBa1;^i]@Bo_;X3
a<;01<c:a`CCd]04gMcJ1>GUi0C/kN`3loGd1?SmoPCen_`4k_7`1>SWi@CRgm/4gMSB0mWAb`CEbl<4
dLJm1<o2]`C<_K84b[Z]0lRfZ@C7]:D4a[6R1<F_W`C4[I`4`j^I1<>YUQGoool001Coool4a:ZH1<J]
V`C7/9l4bK>S1<bgZ0?>^jd4dKnb1=C4^0CHb[l4g=361>7Gc`?Vg]P4k>OR1?;_k0Cin_T4nock1?Cd
l`C[jnX3hn;R1=gMg@CIfMT4e=CD1<o>c@C<bLT4b<G50l?0`0Bn^kX4^[Ng1;Nd]0Bd/[87/k2`1;Ba
/@Be/[44]K:`1;Nd/@Bk^KD4_kbj0lC2`0C<b/L4dm;@1=gLfPCUiN@4k>g/0o?em0ChoOh4mO[l1>ka
l0CXinD4h]oK1=gHdP?IdL/4eL_31=76_@C?`[L4c;fb1<Zj[@?8]ZT4akBU1<JaXPC5[il4a:fL1<>[
V@C3ZIHEoooo000Doooo1<BYU`C5[9X4ajnN1<VbXPC;]JH3cKVZ1<nm[`CB`K@4eLJj1=W;`@CMdLP3
h]S@1>OOf0C]in84lo3/1?[knPCloOd4mOGd0ng]k0CXinL4iNCT1>;Qh@COgMd4f]OG1=OCd`?FdM44
dlo>1=3;bPC<b<H4blK41<[5``?8`l44b<?01<W3`@C9`l04b/C01<g7``CBc<P3fM??1=oJePCVh]l4
kN_X1?;ak`CfmoH3n_kn1?Slo@C`l_44jNWV1>CPg0COfM<4f];;0mK=a0CCakh4d<>h1<jo/`C;^jl4
b[R[0lReY`C7/Z@4a[2P1<F^WPC4[9/4`jZI1<>YUQGoool001Coool4a:VG1<F/VPC7[ih4bK:R1<^e
YP?=^JX4ckf_1=;1]0CEa[X4fL_11=gAb0?Rf=04imoH1>gWhPCcl>`4n__j1?cmo@CemO@3kNg/1>SW
i`CUi>@4h^7Q1=oMg@CJemL4em?C0mKAd@CCclh4d<_:1<c8aPC;a/@4b/G30lS3`@C8`l04bL?11<W3
`0C:a<04cLO31=;<b0?Idll4gm[F1>KRg`C]jnP4l_7_1?KgmP?jo_h4n?cm1?3bl@CYjNH4i>3L1=oI
d`CJd//3e/g41=?7_PC@`kP4c[nc1<^k[`C:^:/3b;FW1<NbY0C6/:04aJjN1<B/V`C3ZYT4`jVF5Ooo
o`005?ooo`C4ZIL4aJbJ1<N_WPC9/Z84bkFV0lfiZPC?_Jl4d/6d1=G6^PCIbl44gM780n;Hd0CWgmP4
kNOR1??`k0CjnoX4o?gm1?Gem0?]kN`4j>OW1>GTi0CRhN44gmgM1=[Ge`CGdm<3e]7A1=??cPC@blX4
c<S61<_6a0C:aL<3b<?11<S3`0C9`l44bL?01<[4`0C=al<4d/c80mWCc`COf]H4i^;O1>g[j0CblNl4
m_Of0o[noPCho?d4l?;a1>WYiPCTh=`4gmWC1=[Bb`?FcL@4dlNn1=33^0C>_k<4bk^_1<ZhZ`?8]JL4
ak:T1<J`X0C5[Yh4a:bK1<>ZV@C3ZIHEoooo000Doooo1<BYU`C5[9X4ajnN1<VbXPC;]JH3cKVZ1<nm
[`CB`K@4eLJj1=W;`@CMdLP3h]S@1>OOf0C]in84lo3/1?[knPCloOd4mOGd0ng]k0CXinL4iNCT1>;Q
h@COgMd4f]OG1=OCd`?FdM44dlo>1=3;bPC<b<H4blK41<[5``?8`l44b<?01<W3`@C9`l04b/C01<g7
``CBc<P3fM??1=oJePCVh]l4kN_X1?;ak`CfmoH3n_kn1?Slo@C`l_44jNWV1>CPg0COfM<4f];;0mK=
a0CCakh4d<>h1<jo/`C;^jl4b[R[0lReY`C7/Z@4a[2P1<F^WPC4[9/4`jZI1<>YUQGoool001Coool4
`jVG1<F[VPC6[Yd4b;2P1<ZcX`?<]ZL4c[Z[1=2m/0CC`[D4e/Jj1=W;`0?MdLL4h]O>1>ONe`C/i^04
l^kZ1?_in0Coool3no[j1?7`k`C[jNP4j^OW1>[Xj0C[j>L4jNGT0nGQh0CQg=/4h]cJ1>;Lf@COem<4
f];>0mO?b`CGclX4e/k91=K>a`CFc/P4f=3:1=gEc`?SfmD4j>;M1>kYi@Cdkn`4moGb1?Sjn@?fn?P4
kno]1>[Wh`CTgmX4gmSA1=_BbPCGc<<3e<Nm1=73^0C>_k<4c;^_1<ZhZ`C9]ZL3ak>T1<JaX@C5[il4
a:fL1<B[VPC3ZYP4`jRF5Oooo`005?ooo`C3ZIL4aJ^J1<J^W@C8/:04b[>S0lbfY`C>^Z/4d;f`1=?2
]@CFa[X4fL_00mgAa`CRelh4imkG1>cVh0Cbk^X4noWh1?ooo`?kn_X4lO3_1>_Yj0CZinL4j^SX1>_X
i`CYiN@3iN7P1>7Lf`CRg=X4h]cI1=oGd`CJd/h3elo;1=O?bPCFc/T4e/k71=K>b0CHd<X4gMG?0n?K
e@CXh]d4k^WU1?C_k0CgmO84n?[i0oKhn0C_knd4j^OS1>COfPCOf=44fm;:1=O<``?Dakd4dL>h1<jo
/`C<^jl4b[R[1<VfY`?7/j@4a[6Q1<F_W`C4[I`4a:^J1<>ZV0C3Z9HEoooo000Doooo1<>YU`C5ZiX4
aZjM1<R`X0C:/j<3c;JW1<jjZ`C@_K04dl:e1=K6^PCIbl03gM771>;GcPCWg]L4k>KP1?;^jPCknOP4
oooo0o_jnPCal>l4jnWX1>[Wi`CZj>P4jnSW1>WUi0?UhN04hMcK1>;LfPCRg=T4gmOC1=[BcP?Gcl/4
elo:1=K>b@CFc/L4e/k81=S@bPCMeLl3hm_E1>SRg@C^jND4m>o/1?OelPChn_T3m_Sh1>o_k@CZin<4
i=oJ1=oHd@CKd/X4elc30mC7_@CA`kP4c[nc1<bk[`C:^:/4bKJW0lNcY0C6/J44aJnO1<B]W0C4ZiX4
`jZH1<>XUQGoool001Coool4`jVG1<F[VPC6[Yd4b;2P1<ZcX`?<]ZL4c[Z[1=2m/0CC`[D4e/Jj1=W;
`0?MdLL4h]O>1>ONe`C/i^04l^kZ1?_in0Coool3no[j1?7`k`C[jNP4j^OW1>[Xj0C[j>L4jNGT0nGQ
h0CQg=/4h]cJ1>;Lf@COem<4f];>0mO?b`CGclX4e/k91=K>a`CFc/P4f=3:1=gEc`?SfmD4j>;M1>kY
i@Cdkn`4moGb1?Sjn@?fn?P4kno]1>[Wh`CTgmX4gmSA1=_BbPCGc<<3e<Nm1=73^0C>_k<4c;^_1<Zh
Z`C9]ZL3ak>T1<JaX@C5[il4a:fL1<B[VPC3ZYP4`jRF5Oooo`005?ooo`C3ZIH4a:ZH1<J]V`C7[ih4
b;6Q0lZdY0C<]ZL4c[V[1=2m[`CB`;<4eLFh0mW9_PCLc/@4h=C:1>GJdPCZhMX4knWS1?Gak@?knOH4
noWg1?Gbl0CbkN/4kn_Z1>oZj@C]j>H3kNOT1>gUhPCZhM`4imgG1>CJe0CSf=43h=K=1=gBb@CLdLP4
gM?;1=kDc0CPe/l4i=_D0nWQf`C^j><4l^gY1?C`kPChmoH4mOCb0ngZiPCWh]d4h]_D1=kEc@CJclH4
el[01=C6^`?A`KH4c[ja1<bk[PC;^:X4bKFW1<RcY0?7/J44aZnO1<F]W@C4[9/4a:^I1<>YU`C3Z9DE
oooo000Doooo1<>YUPC4ZYP4aZfK1<N_WPC8/J43b[BT1<bfY`C>^J/4d;f_1=;0/`CEaKP3fLVn1=c>
a0CPe<X4iM[B1>[QfPC_jN<4mO7]0o_imPCknOL4mO;`1?;]j`C_jnX4kn[Y1>gXiP?]in@4kNGR1>[Q
g0CWgML4i=[D1>?Hd@?Pe/d4gM;91=cAb0CMdl/4g]C<1>3Fc`CTfm@3jN7K1>kXh`CbkNT4m?3^1?Sg
mPCem?83kN[V1>ORg@CRfm@4g]G=1=[?aPCGb/04e<Jk0m71]PC>_[44c;^^1<^hZPC9]JL4b;>T0lNa
X@C6[il4aJfM1<B/V`C4ZiT4`jVG1<>XUAGoool001Coool4`jVF1<BZV0C6[I/4ajnN1<RaX@?:]:@4
c;JW1<jiZ`C@_Jl4d/2c1=G5^0?IbKh4g<k41>3DbPCUf]84j^7J1>oYh`CelNd3noWf1?_im`Cel_04
l^g[1>o[jPC_j^T4kNSV0ngWi0C]iN84j^7L1>OMe`CTf]@4hmSA0n3Fc@CMd/T4g=781=gCb`CNe<`4
h=K?1>CKe0?YhM/4k^SS1?;]j@Cdl>h4n?Of1?GdlP?]j^H4in;M1>;Ke0CNeLd4f/o61=O:`0CDa[/3
dL6f1<jn/@C<^jh4bkRZ1<VeY`C8/j@3ak6Q1<J_W`C5[Id4a:bK1<B[V@C3ZIL4`jRE5Oooo`005?oo
o`C3Z9D4a:VG1<F[V@C6[I/4ajnN0lRaX0C:/j84bkFU1<fhZ0C?^Z`4dKj`0m?1]0CFaKP4fLVm1=c>
``CPdlT4i=W@1>WOe`?^iMh4mNkX1?Wdk`Cjm>l4m>gX1?3Xh`C`j>@3l>OS1>kSgPC[gmT4imcE1>OK
e0CWf]83i]W@1>GIc`CTf<h4hmO>1>?Hc`CTfm84iMoG0nWRg0C]j><4lo3]1?CbkPC_j^D4j>7K0n?J
d`COe</4flo51=S:_`CEa[X4d/:f1<nn/@?=^jh4c;RZ1<ZfY`C9]:D4b;:R1<J`X0?6[ih4aJfL1<B/
V`C4ZiT4`jZH1<>YUPC2Z9DEoooo000Doooo1<>XU@C4ZIL4aJ^I1<J]V`C7[ih3b;6P1<ZcXPC;]JD4
cKRX1<nj[0CA_[03dl6d1=K5^0CIbKd4g<k31>3Cb@CTfM04jMoG0nkUgPCek^P4nOC_1?[dk`CdkNP4
l>SS1?3Xi0?`in<4k^?N1>_Of@CWg=D4im_D1>OJdP?VfM04iMW?1>CHcPCSelh4hmS?1>CKdPCUgmL3
jN;L1>gXh`Ccl>d4m?;^1>oZi@CXhM/3hm[C1=oDb`CKclD4f<Zo1=G6^PCB`[H4ckja0lfk[PC<^:X4
b[JW1<VdY@C8/Z84a[2P0lJ_WPC5[I`4a:bK1<B[V@C3ZYP4`jVF1<:XUAGoool001Coool4`jRE1<BY
U`C5ZiT4aZfK1<N_WP?8/J04b[>R1<^eY@C=^:P4ckZ/1=6n/0?C`K@4e/Fh1=W9_@CLc/<4h=?91>CI
d0CYgmL3k^GN1?G^j0Cim>l4n_C_1?C]j0C`j><4l>ST0o3Wh`C^hmh4jmoI1>OLe@CWfm@4im[B0nKI
d0CUfLl4i=S>1>?GcPCSf<l4i=_B1>GOe`?Yh]`4kNSS1??`k@Cdl^h4kn[U1>SQf`?Sf]<4gmC;1=_?
a@CHb[l4eLJj1=;2]PC?_[43cK^^1<bhZPC:]ZL4bKBU1<RbXPC6/:03aZnN1<F]W0C4[9/4a:^I1<>Z
V0C3ZIH4`ZRE5Oooo`005?ooo`C3Z9D4a:VG1<F[V@C6[I/4ajnN0lRaX0C:/j84bkFU1<fhZ0C?^Z`4
dKj`0m?1]0CFaKP4fLVm1=c>``CPdlT4i=W@1>WOe`?^iMh4mNkX1?Wdk`Cjm>l4m>gX1?3Xh`C`j>@3
l>OS1>kSgPC[gmT4imcE1>OKe0CWf]83i]W@1>GIc`CTf<h4hmO>1>?Hc`CTfm84iMoG0nWRg0C]j><4
lo3]1?CbkPC_j^D4j>7K0n?Jd`COe</4flo51=S:_`CEa[X4d/:f1<nn/@?=^jh4c;RZ1<ZfY`C9]:D4
b;:R1<J`X0?6[ih4aJfL1<B/V`C4ZiT4`jZH1<>YUPC2Z9DEoooo000Doooo1<>XUPC3ZIL4a:ZH1<F[
V@C5[9X3aZfL1<N_WPC8/:04bK:R1<^dY0C<]ZL3c[VY1=2k[0CB_[04e<6d1=K5^0CIb;`4g<c10n3A
aPCSe//4i]W?1>SLdPC/hMH4kN;I1>_PeP?Zg]D4j]kF1>WMe@CVfM44h]G<1>3Cb@?Pd/L4h=762>3B
a`COdLH4h=?91>GKdP?[hm/4j^;J1>KLe0CSf<l4h=?:1=c>a0?Ib[h4e/Fi1=?2]@CA_k44ckb^1<fi
Z`C;]jP3b[FU1<VcX`C8/J44ak2O1<J^WPC5[I`3aJbK1<B[VPC4ZYP4`jZG1<>YUPC3Z9H4`ZRE5Ooo
o`005?ooo`C3Z9H4`jVG1<BZV0C5ZiT4aJbJ0lJ]W0C7[ih4b;2P1<VbXPC;]:@4c;JW0ljiZ@C@^j`4
d[j`1=C1]0CFaKP4fLRl1=c<`@?PdLH4hmK;1>KIc`CXg=84k>7F1>gRf@C[h=H3j]kE1>[NePCYgMD4
i]WA1>;Ec0CPdlT3h=;71>3AaPSPd/L4gm761>3Cb@CUfm83jn?K1>[RfPCVg=@4hmS?1>3CbPCLc/@3
fLZn1=K5^@CC`[D4dKna1<nl[PC=^J/4bkNX0lZeY@C9/j<4b;6Q1<N`W`C6[Yh4aJfL0lF/V`C4ZiX4
a:ZH1<>ZU`C3ZIH4`jRF1<:XUAGoool001Coool4`jRF1<>YU`C4ZYP4aJ^I1<F/VP?6[I`4ajnN1<R`
X0C9/Z84bkBT1<bfY`?>^JT4d;^/1=:n/0CD`K@4e/Fh1=W8_0CLc<43h=761>?Fb`CVfLl4j=cB1>cQ
ePC]h]T4jn3F0n[Ne@CZg]H4jMgE1>KId@CReL`4h=?90n3Ba`CPdLH8h=;71=oAaPCPdlT4iM_B0n_S
f`CZh]X4i]cD1>?Hc`CPdlX4g<k40mW:_PCFaKT4dl:e1=6o/@C?_:h4cKV[1<^gZ0?:]JD4bK>S1<Ra
X@C7/9l4aZjN1<F]W0?5[9/4a:^J1<BZV0C3ZYL4`jVF1<>XUPC2Z9DEoooo000Doooo1<>XUPC3ZIL4
a:ZH1<F[V@C5[9X3aZfL1<N_WPC8/:04bK:R1<^dY0C<]ZL3c[VY1=2k[0CB_[04e<6d1=K5^0CIb;`4
g<c10n3AaPCSe//4i]W?1>SLdPC/hMH4kN;I1>_PeP?Zg]D4j]kF1>WMe@CVfM44h]G<1>3Cb@?Pd/L4
h=762>3Ba`COdLH4h=?91>GKdP?[hm/4j^;J1>KLe0CSf<l4h=?:1=c>a0?Ib[h4e/Fi1=?2]@CA_k44
ckb^1<fiZ`C;]jP3b[FU1<VcX`C8/J44ak2O1<J^WPC5[I`3aJbK1<B[VPC4ZYP4`jZG1<>YUPC3Z9H4
`ZRE5Oooo`005?ooo`C2Z9D4`jRE1<>XUPC3ZIH4a:ZG0lBZV0C5ZiT4aJbJ1<J]V`C6[Y`4ajnM0lR`
W`C9/J04b[:R1<^dY0C<]ZH4c[RX1<njZP?A_:d4dkj_1=C0/@CE`[<4el>e2mO4]@CGaKH4f<Jh1=_9
^PCLb[`4g<^m2mc;_PCMc;l4gLg11=g=`PCJbKd3elFh1=G4]PCD`[@4d[na1=6m[`C?^j`3cKRY1<bf
Y`C;]:D4bK>S1<RaX@C7/9l4ajnN0lJ^W@C5[I`4aJbJ1<B[VPC4ZiT4a:ZH0l>ZU`C3ZIL4`jVF1<>X
UPC3Z9D4`ZRE1<:WU1Goool001Coool4`ZRE1<>XU@C3Z9H4`jVF1<BZU`?4ZYP4aJ^I1<F/VPC6[I/4
aZjL1<N_W@?8/9l4bK6P1<ZbXPC;]:@4c;JV1<jhZ0C?^ZX3dKb]1=>n[`CD`;44eL:c1=O3]@_Ga;D4
elFf1=S6^0CKbKX4g<Zl1=c;_@_Lbkh4gLbo1=g=`@CMcL84f/Vm0mO5^0CEa;H4e<:d1=:o/@CA_Jl4
ck^/0lfhZ@C<]ZL4bkBU1<VcX`C8/J44ak2O1<N_WP?6[Yd4aJfL1<F/VPC4ZiX4a:^I1<BZV0?3ZYL4
`jVG1<>YUPC3Z9H4`jRE1<:XU@C2Yi@Eoooo000Doooo1<:XU@C3Z9D4`jRF1<>YUPC4ZYL3a:ZH1<F[
V@C5[9X4aZfK1<J^W0C7[id3b;2O1<VaX0C:/Z84bkBT1<bfYPC>^:P4ckZZ0m6l[@CC_Zl4e<2a1=G2
/`CG`kD;elBe1=O5]PCHa[P4flVj1=c:_0CLbkd;g<^n1=g<_`CMcL44gLg21=[9_@?GaKP4eLBf1=C2
]0CB_k44dKf_1<nk[0?=^:T4c;JW1<^dY@C9/j<4b;6Q1<N`W`C7[ih3aZjM1<F]W0C5[9X4a:^J1<B[
V@C4ZYP3`jZG1<>YU`C3ZIH4`jRF1<>XU@C2Z9D4`ZND5Oooo`005?ooo`C2Z9D4`jRE1<>XUPC3ZIH4
a:ZG0lBZV0C5ZiT4aJbJ1<J]V`C6[Y`4ajnM0lR`W`C9/J04b[:R1<^dY0C<]ZH4c[RX1<njZP?A_:d4
dkj_1=C0/@CE`[<4el>e2mO4]@CGaKH4f<Jh1=_9^PCLb[`4g<^m2mc;_PCMc;l4gLg11=g=`PCJbKd3
elFh1=G4]PCD`[@4d[na1=6m[`C?^j`3cKRY1<bfY`C;]:D4bK>S1<RaX@C7/9l4ajnN0lJ^W@C5[I`4
aJbJ1<B[VPC4ZiT4a:ZH0l>ZU`C3ZIL4`jVF1<>XUPC3Z9D4`ZRE1<:WU1Goool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool009Woool30000Q?oo
o`00W?ooo`030000oooooooo087oool007_oool500000_ooo`800004oooo0P0000Coool400000_oo
o`<00003oooo0`0000?oool20000O_ooo`00OOooo`050000oooooooooooo000000;oool010000?oo
ooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`0000Goool010000?ooooooo`00
08?oool007goool00`000?ooooooo`04oooo00@0003oooooool00002oooo00@0003oooooool00002
oooo00<0003oooooool0100000;oool010000?ooooooo`0008?oool007goool00`000?ooooooo`02
oooo0P0000Coool200001?ooo`<00003oooo0P0000Coool40000P_ooo`00OOooo`030000oooooooo
00;oool00`000?ooooooo`02oooo00@0003oooooool00005oooo00<0003oooooool0SOooo`00O?oo
o`800004oooo0`0000?oool200001Oooo`80002?oooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(180) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
A3918BA3918AA3918AA3918AA2908AA2908AA2908AA2908AA2908AA29089A19089A19089
A18F89A18F89A18F89A18F89A08F88A08F88A08F88A08F88A08F89A08F89A08F8AA0908B
9F8F89A08E88A08E87A08E88A08D87A08D87A08D87A08D87A08E87A08D87A18D87A08D87
A18E87A08D87A18D87A08C86A08C86A08C85A08B85A08B85A08B849F8A839F8A839E8982
9D877F9E89829F8A839F8B84A08C85A08C86A08C86A18D86A18D87A18E87A18E88A28F88
A28F89A29089A3908AA3918A
A3918BA3918AA2908AA2908AA29089A18F89A18F89A18F89A08F88A08E88A08E889F8E88
9F8E879F8D879E8D879E8D869E8C869D8C869D8C869D8C869C8C869C8C879C8D889C8E8A
9C8C879C8B859C8A849C8A849D8A849D8A849D8A849D89839C89839D89839D89839D8983
9D89839D89839E88829D87819D87809C867F9C857E9C847E9C847D9B837C9B827B9A827A
9981799A827B9B847C9C857E9C867F9D88809D88819E89829F8A839F8B84A08C85A08D86
A18D87A18E88A28F89A3908A
A3918BA2918AA2908AA18F89A18F89A08F89A08E889F8E889F8D879E8D879E8C869D8C86
9D8C869C8C859C8B859B8B859B8A849A8A849A8983998983998983988984988A85988B87
9889839888829887819987819987819A86809A87819A87829A87829B87819B86819C8681
9C86819C86809C857F9B837D9A817B998079987F78977E77977D76977C74967B73967A71
967B73967C74977E75987F779981799A827A9A837C9B847D9C867F9D87809E89829F8A83
A08C85A18D86A18E88A29089
A3918AA2908AA1908AA18F89A08F889F8E889F8E879E8D879D8D879D8C869C8C859C8B85
9B8A849A8A84998983998982988882978781968781968680958680948681948682948783
94858094847F95847E95837D96837D97847E98857F9A86819A87829A87829B86819B857F
9B837E9B827C9A817B997F79987D77967B74957A7394787194776F93756D92736A907067
92736A93756C93776E947971957B73967D75987F779981799A827B9B847D9C867F9D8881
9E8A83A08C85A18D87A28F89
A2918AA2908AA1908AA08F899F8E889E8D879E8D879D8C869C8C859B8B859A8A849A8983
99898298888297878196868095857F94857F93847E92837D91827D90827D90827D90837F
90827C90817A91807A92807A92807A93807B94817C95827D96837E97847F98847F98837D
98817B988079987E77977C7596787294766F92756D91726A906F678F6E658D6C628C6A5F
8D6C628E6F6590716891736A92766D93786F957A72967C74977F769981799A837B9C857E
9D88809F8A83A08C86A28F88
A2918AA1908AA08F899F8E889E8D879E8D869D8C869C8B859B8A849A8A83998983988882
97878196868095857F94847E93837D91827C90817B8F807A8D7E798C7D788B7D788B7E79
8B7D788C7D778D7C768E7C768F7C768F7D77907D77917D78927E79937F7A94807A947F79
947D76947B7493797293776F92746C9070688F6E668D6C638B69608A665D89655B886459
89665B8A685E8C6B618D6D638E706690736992766C93786F957B72977E759880789A837B
9C867E9E8981A08B85A18E88
A2908AA18F89A08F889F8E879E8D879D8C869B8B859A8A84998983988882978781968680
95857F94847E92837D91827C90817B8E7F7A8D7E788B7C77897B75877873857670857671
8778738879738979738A79728B79738B78738C78738D79738D79738E79738F78738F7872
8F77708F756E8F736C8E71698D6E668C6B628A675D88645B876258855F54835C51845D52
855F5486625688645989675D8B6B608D6E648E716790746B92776F947B72967E76988179
9B847C9D87809F8B84A18E87
A2908AA18F899F8E889E8D879D8C869C8B859A8A8499898398888297878195868094857F
93847E91827C90817B8F807A8D7F798C7D778A7C75887A7486777182736D7D6F6A81736D
83746F85757086757086756F87746E88746F88746E89736D89736D89726D8A716B8A706A
896F69896D67896B64896A6287675E86645B856158845E53825B5080584C7F54477F5549
80584B825B4E835E5285615687655A89695E8B6C628D706690746A92776E947B73977F77
99837B9C867F9E8A83A18D87
A2908AA08F899F8E879D8C869C8B859B8A8499898398888296878195868094847F92837D
91827C8F817B8E7F798C7E788B7C76897B7588797386777184756F82736E7A6C687F716B
81726C82726C82726C83716B83706A84706A84706B856F6A856E68856C66856964846762
84666084665F83655D83635B826158825E55805B517F574C7D53477B4F42794A3C7A4D3F
7C50427D53467F574B815B4F835F5486635888675D8B6C628D706690746B927870957D74
9881799B857D9E8982A08D86
A2908AA08F899E8E889D8C869B8A849A898398888297878195868093847F92837D90827C
8F807B8D7F798B7D788A7C76887A7487797385777184756F83756D82746D80736C7E706A
7E6F697F6F697F6E687F6E67806D67806C66806C66816B66816A6480686281656080625E
7F605B7F5E597E5D567E5C547C5A517C574E7B544B7B5146794D4177493B744233754334
774739794C3E7B50437D55487F594D825E5285635888675D8A6C628D716790766D947A72
977F779A837C9D8881A08D86
A1908AA08F889E8D879C8C869A8A8499898397878295868094857F92837E90827C8E807B
8D7F798B7D78897C76877A7486787284777082756F80726B81736D82756F7F726C7D6F69
7C6E677C6C667C6B647C6A637C69627C69627C68627D68627E66617D635E7D605C7D5D59
7C5A567B58537A575279554F78544C775148764F45754C4175483C724335703D2D6F3A2A
713F2F74443576493B794E417B53477E594D815E5284635888685E8B6E648E736A92786F
957D7499827A9C8780A08C85
A190899F8E889D8D879C8B859A8A8498888296878194857F92847E90827C8E817B8D7F79
8B7D78897C76877A7485787283767081746E7F736C8376707F736D7E716B7C706A7B6E67
7A6C65796A6378686178665F78655E78655E78655F79655F7A67617A66607A645D79615A
795D5877575276534E74514B724F48724D44714A4071483C7144386F40326E3B2B6B3524
6C36246F3C2C71423374483A774D407A53477E594D815F5485655A896A608C706790766D
947B739881799C867F9F8C85
A190899F8E889D8D869B8B8599898397878295868093847F91837D8F817B8D7F7A8B7E78
897C76877A7585787382767180746E7E726C7B706A756A64796E677A6E68796D67786C66
786B6476696175655E74635C74625B73625B74635C75645D776861786A63786A63786861
77645C745B5472544E704F486E4B446D49406C463C6C44386C42356C3E306B392A693524
6831206A35246C3B2B6F413373473A764E417A54487E5B4F82615686675D8A6D648E736B
937971977F789B857E9F8B84
A190899F8E889C8C869A8A8498888396868194857F91837E8F827C8D807B8B7E79897C77
877B7585797382777180746F7E726D7B6F6A7B706A766C67766C67776C67766B66766C66
756A6474676172645C6F5F596F5F596F5F596D625B746A63776C667A716A7A6F68786861
76686073635B6F5B536A4F4869484168453D684339684136693F33693D2F683829663423
642E1C642E1C6734236A3A2B6E413372483B764F437B564B7F5D5284645A886B618D7168
91786F967E769A857D9F8B84
A18F899E8E879C8C86998A8497888395868192847F90827D8E817B8C7F7A897D78877B76
8579748377728075707E736D7B706B796F6A716965736B66746B66746C66746A65746B65
746B6573696371655E6D60596B6059736C65736D66746F68757069766E67787069796E66
7A6C657767607360596A544D64484163423B634037643E33653D31663B2E663829643323
622E1D612B1A612E1E643324683B2D6D4336724B3E7752477C5A4F81615786685E8B6F66
90766D957D759A847C9E8A84
A18F899E8D879B8C86998A8496878294858091837E8F817C8C807A8A7E79887C77867A75
8478738176717F746F7B716B786D68786E6A6D6662706964716A66726C67726B66726C66
726C67736C66716B64726A626D635C70655D71665F71675F72696173685F74675F74645B
75635A77625878635A745C546950485F413A5F3C33603A30623A2F633A2D633728623223
602D1C5F29175D2A185E2C1D623426693D306E463A744E4379564B7F5E5484665C896D64
8E746C947C7499837B9E8A83
A08F899E8D879B8B8598898395878192857F90827D8D807B8B7E7A887D78867B76847974
8277738076717E746E796F69716761726A657069656F6966706965706965706A65706C67
726E69736F6A75736D77766F73716A706B646F69626F665E6F655E70645C70635B705F56
715C54705A51725C5272574E6F534A64473F5B3A325D382F5E382D60382B6135275F3223
5E2D1D5D29175C28175C2B1A5E2F2164392B6A4235704B3F7653487C5B51826359876B62
8D736A937B7298827B9E8A83
A08F899D8D879A8B8597888394868191847F8E817C8B7F7B897D79867B77847A75827873
8077727F76717F75707F7571776F6A706B67706B686E6A666D69666D69676D6A676E6C68
6F6E6A6F6D686E6B666F6E686F6E676E6D666E6C656F6C646F6C64706A6270696070675E
6F645A6F5E546E5B516F574D6E5248694C425F3F365A372E5C372C5E372B5F35275E3122
5C2D1D5B28185723115322115A2C1D603427673E326D473B7450457A594E806157866960
8C716992797197817A9D8982
A08F899D8D879A8A8596888393868190847F8D817C8A7E7A877C78847A76827874807672
7E75717E7570807873877E79857C7676706C6F6A676C69666B6A666B69676B69676B6C69
6D6E6A6D6D696A67636A67616A68626A69626B68626B68626B68626C67606C665E6C635B
6B60586A5D54695B5069594E6A574C695348644A405D3F355B392E5C372B5D35285C3224
5B2E1E5A2A1A5A29185021115528195D3224643B2E6A4438714D4277564C7E5F5584685E
8A70679178709781799D8982
A08F899C8C87998A849587829285808F827E8B807B887D79857B778278757F76727D7471
7B736F7A726E7B746E7B736E78726E716C6A6B6865686765686765676866676967686A68
696C6A696B6867656165625C65635D66645F67655F67655F68666069665F68635C685F58
675D55665A5264574E64544A645147624D4260473C5D41375B3B315B382D5B35295B3124
5A2E205A2B1C5929184D1F11522518592E2160382B6742366E4B4075544A7C5D5382665D
896F6690776F9680799D8982
A08F899C8C86988A849587829184808D827D8A7F7B867C788279767F77737C747179726F
77706D756E6B736D6A716B676E67646A6462666362656362646462636563636664636766
64696765686664656262605C615E5962605B63615C64615C64625D65635D65615B645D57
645A5364585062544D605249604E465F4B425D463D5B40365A3C3259382E5A362A5A3226
5A2F225B2D1E5C2B1B4B1D0E4E2112562B1D5D3528653F336C493E7352487A5B5281645B
886E658F766F967F789C8881
9F8F899C8C8698898494868290847F8C817D887E7A847B778078757C757279726F756F6C
726C6A6F6A676C67646A646266615F645F5D615F5E605E5E5F5F5E5F60605E62615F6362
5F65636065636063605E5F5B5D5B575E5D585F5F5A60605B61605C62615C625F5A625D57
6159536056505E524C5D4F485B4B455B49425B463E594139583D3457392F58362B583327
5930235B2F205F2F1E4E2010491C0E52271A5B3226623D316A473C715046785A507F635A
866C648E766E957F779C8881
9F8E889B8C869789849386818F837F8B807C867D79827A777E767479737175706D716C6A
6D696769656465615F625E5C5E5B5A5D5B5A5C5B5A5B5B5A5A5B5B5A5C5C5A5D5D5A5E5E
5A5F5F5A605F5B605E5A5D5B595A565A5A565B5B575C5C585E5D595F5D595F5C575E5954
5D56515C544E5A514A594D4657494256464056433D564038553D3455393055362B563328
5731255B30226233235D2C1B4E20114D2215593124613B3068453A6F4F4576584F7E6259
856B638D756D947E779C8881
9F8E889B8C869789849286818E837E897F7C857C798079767B757376716F716D6C6C6968
676564635F5F5E59595B5657575555555757555757555757555757555757545858545959
555A5A555A5A555B5A565A595558565658555758555858555A5A565B59565B59545A5551
58524E574F4B554D4853494452464052443D51403A523E36523A3251372E52342A523127
542F23562D215A2F225C2F215B2E1F572C205931255F3A2F6643396D4D4374574D7C6058
846A628C746C937E769B8781
9F8E889B8B869688849285818D827E887F7C837B797E787579747273706E6D6B6A686766
6262635D5D5E5858595353545151525052535053545053545053545053544F53544F5354
4F54544F5454505454505353505453525554545755555856575956585856585754575450
55504D524D49514A475048434E443F4D403B4C3D374D3B344D38314D352D4D32294E2F26
4E2C23502A20522B1F52281A51251753291D5730245D382D6341376B4B4272554C7A5F57
8269618B736C937D769B8780
9F8E889A8B869688849185818C827E877F7B827B787C7775767371706E6E6A6969636464
5B5F5F555A5B4F54554A4E50494C4F494D4F4A4E504A4F514B4F514B4F504A4F4F494E4F
494E4F494D4F494E4F4A4D4E4B4E4E4D50504F5352525554545756565755565553545250
524F4C504B484D48454B444049403C483C38483A3447373148352E48332B483027482D24
482A2149271D4B271C4B2317491E114C2216522C2159352B603F3668494070544B795E56
81686089726B927D769B8780
9F8E899A8B869688849185818C827F867E7C817B787B76757472716E6D6D6768695F6264
55595A4A5153424B4F3F474B40474B42494C444A4D454B4E464C4E464C4E464C4D444B4D
434A4C42484B43484B44494A454A4A484D4D4B504F4E535251565453575553545251514F
4F4C4A4C484649444246403D443C3942383542363242342F42322D42312A422E27422B23
43271F42241B432218431D12441B0F461C104E281D5532295D3D3465473F6E524A775C55
7F676088726A917C759A8780
9F8E899A8C869689849186828B827F867F7C807B797976757371716C6D6D6568695D6366
53595C454E523B464C343F463842483C454A3F484B41494C424A4D424A4D414A4D3F494B
3E474A3C44473C42453D42443F4446434849484D4D4B51514F54535055545053524E4F4E
4C4A4848454345413F413C3A3E38353D34323C322E3C302C3D2F2A3D2D273D2B253D2922
3D251E3C21193C20173B19103C180E40190E48241B512F26593A3262453D6B5049745B54
7E665F87716A907C759A8680
9F8F899A8C879689859186828C8380867F7D807B797976757171716A6C6D6267695C6468
565D6247505538454B2E3C44323F453743483A454A3E484D3F494D3E484B3D4649394346
364145343F44353E43373E423A3F423E4445444A4C4950514D54544F55554F53524D4F4D
494948454442413E3D3C3A3839353337312F372F2D362D2A382C28392A26382823382620
38231D372019371D1633160F34130B39150C4321194C2D255638305F433C694F47725A53
7C655E867069907B74998680
9F8F899B8C87968A859187838C848186807E807C7A787776707171676B6C5F6568596164
515A5F404C5333424A293A432E3D4533414838444A3B484D404C51414D51404C503C494D
364449304045303E42333E42363D413A404342494B4850514C55564F56574F54544C4F4F
484948434241403E3D3C3938373332332E2D322B2A31292732292634282434262133241F
32221C331F19331D173018122F130C34120B3E1F17482A2351362F5C413B664D46705852
7A645D846F698F7B7499867F
9F8F899B8D88978B869388858D8583888280817D7C7978786F717264696B5B6367565E62
535C6044505733434C2639432B3D4630414935444B39484F3E4D534452584854594A555A
4451553C4B5037474C38484D3C494D3E484C434C4E4851544C56584F57594F55564C4F50
484949403F403D3C3C373636312F302D2B2A2D29282C26252D252330252231242131221E
2F201B2E1D192C1A1628151128120D2E110C391D174328224D342E58403A634B456E5751
78635D836F688E7A7499867F
A08F899C8D88988C88948A868F88858A858383807F7B7A7A7072736065674F575C4E595E
4E585E424F5731434D233843283C462E404933444C37474F3C4C5342525947565C4E5B60
515D624D5A5F465458415055404E52414C50444E514852554C565950585B515859505455
4F5252484949414244393A3B3031332E2C2E2A28292723242923232C23213024212F231F
2D201C2B1C182718141F110E1F0D09270E09331A153E252049312C543E38604A446B5650
77625C826E688D7A7498857F
A0908A9D8F8A9A8E8A968C89928B888D8886888584808080747677656B6D505C61445259
4351583B4B542F424D223844273C472C404A31444E35454F394A523F505844565E495A61
4A5A6249596146575E435359415056424F544450544853574C575B50595D525A5C525758
515554504F4E504D4C4E49483F3E3E3A3636363233302C2C302A2A3028273126242F2321
2C211E2A1D1A2215131B0F0C1807051F08052C161238221E452F2B513C375D4844695550
75615C816D688C797498857F
A1918C9E908C9B908C988F8C958E8B928D8B8D8B8A89898985888972787B606C704F5E64
46565D3B4D562F434E223845263C472B404B314751364B55384B553A4D553E515941555D
42576041555E40545C3F51593E4F574251584552574854594C585C50595D525A5E52575A
5053554E5050504F4E56514F514C4B4A4443443D3C3C3636373131332C2B312928302624
2D22202B1F1C211614190E0E1508071A050326120F331F1C402D294D3A365A474367544F
73615C806D688C797397857F
A1928C9F928D9D928E9B928E99928F9692909492919292929094947D83866A74795A676D
4D5D643D515A2E4551213A47243B472A404B2F4650364C573D535D405660435963465D67
4B616A4A606A485F68465B6444575F44555C45555B48555B4C585D505A5F525B6052585D
4E52564B4D504B4C4D4C4B4B4B48484A46464541413D393A383334352E2F322A2B302626
2E23222A1F1E1E1616160F10150B0A1403021F0E0C2D1C1A3C2B284A393658464365534F
72605C7F6D688B797397857F
A2928DA1938E9F94909E94919D96939B97959A9897999A9A9A9D9E8A8F91777F83657176
53636A41545E314753223C49223A47273E4A2D434E32495439505B3F5862455E6848616C
4A646F4B65704A646F47606A455A6343565E44565C46565C4A585D4F5A5F535E61576063
565C604E5156484A4E444549444446434143413E3F3C393A383435352F30332B2C322829
3025252A1F1F1F1718120D0F1008090E0000140505281918382927483835564643645350
71605C7E6D688B797497857F
A3938DA29590A19692A19894A09997A09B9AA09E9DA0A1A0A1A4A592989A81898D6E797F
5C6B72485B64344B57253E4C213A48253C4929414C2F4551344B5639515C3D5661405A65
425C68435D68435C68425A6642586242555D43555C45555B48555B4C575D505A5F555D61
5A5F635B5D6157575B4C4E514344483E3E423C3B3E39373A373436363133362F30342C2D
342A2A2A22221E181A100E120B080B0F0607120708251818362827463836554643635350
71605C7E6D688A797497857F
A3948EA39691A49894A49B97A49D9AA4A09EA5A3A2A6A6A6A8AAAB9B9FA08B9195768186
6371784E606A394F5C27414F203948213A47263D492B414D2F4551334A55374E593A525D
3B54603D55613D56623D55603E545F3E525C40525A42525A44535A47545A4B555A4F575C
54595D565A5D58595C5757595352544C4B4D474446423F41403C3E3B3638383234362F30
362E2E2D2527221D1F1716190E0F120E0A0D11090B23191A342929453837544745635451
70615D7E6D698A7A74978580
A4948FA59792A69A96A69D9AA7A09EA9A4A2AAA7A6ACABABADAFAF9FA3A491979A7E888D
69777F54656F3E54602A43521F39481F3745233A47273E4A2B414D2E4551314854344B56
354D59374E5A384F5B384F5B394F5A3A4E583B4E583D4E57404E56424F56465057495257
4D5358505458525457525356525154504E514C4A4C464446423E403E3A3B3B3637393233
362F302F292B2722251F1C1F161518110E12110B0D211819342A2B453A39554847635653
71625F7E6E6A8B7A75978680
A5958FA69894A89C98A9A09CABA4A1ADA8A6AEACABB1B0B0B3B5B5A5A9AB979DA1858F94
717F86596C76435A662F4857203B4A1C3544203745243A47273D492A3F4B2C434F2E4551
304752314854324955334A56344A56354A54364A54384A533A4A533D4A52404B53434D53
464E54494E544B4E534C4E534B4D514A4A4E48474A444346403F413D3B3D3B383A3A3537
363133302C2E29272A2221251C1B1F16151A161316231C1E362E2F473D3D564B4A655855
7264617F6F6C8B7B76978680
A59590A79A95A99E9AACA29FAEA7A4B0ABA9B3B0AFB5B5B5B9BABBABAEB09CA3A68C969B
79868E63747E4D626E38515F2742521D37471E3644213745243946263B47283D4929404C
2B414E2C43502D44502E44512F455130455131455033454F35454F37464F3A464F3C474F
40484F43495044494F46494E46484D45474B444449434246413F42403C3F3E3A3C3D383A
3A35373430332E2B2F29272B2423271F1F241F1E222924273B34364B4242594E4D675A58
73666380716D8C7C77988781
A69690A99B96ABA09BAEA5A1B1AAA7B4AFADB7B4B3BAB9B9BDBFC0B0B4B6A2A8AC929CA1
808D956B7C855469753F57652E4857213C4B1D36441F3643213744223844243845253A46
263C49273E4B273F4C283F4C29404C2B404D2C414C2D414B2F404B31404A34414B37424B
3A434C3D454C3E454C40454B41444A414449414247414145403F433F3D403F3C3F3F3B3D
3B373A383538333135302E322C2B2F28282D2A292D363235423C3E5047485D5352695E5C
75686681736F8D7D78988782
A69791AA9C97ADA19DB0A7A3B4ADAAB8B2B0BBB8B7BFBDBDC2C3C3B4B8BAA7ADB098A1A6
87949B74838D5D727D465F6D324E5E2541521E38481D35441E35431F3543203642203642
213744223845223947233A47233A47243A47263B47283B47293C472B3C472E3D47313F48
3440483741493941493B41493C42493E42483F42473F40463F4044403F43413F42403D41
3F3C3F3C3A3D39383B3535393232362F2F342E2C313C393C494345554D4E6157566C615F
786B688375718E7E7A998882
A79791AB9D98AFA39FB3A9A5B7AFACBBB6B4C0BDBBC5C4C3C9C9CABBBEC0AEB3B69FA7AC
909BA27C8B946679845067753955652846571E394A1B34441B33421C33411C32401C323F
1C323F1D323F1D33411D34411D34421E35421F36432135422236422537432839442B3A45
2F3B45323D46353F47373F47393F473B3F473C40463D40463D40453E3F44404045403F44
403F433E3D423C3B4039393F36373D36373C37353A4440434F4A4B5A5353655C5B706563
7A6E6B8577738F807B998883
A79792AC9E99B0A4A0B5ABA7B9B2AFBEB9B7C4C0BFC9C8C7CFD0D0C3C6C8B5BABDA6AEB3
96A1A883929A6E808B586F7C415C6C2E4C5D1F3D4E1A344519324218313F182F3D182E3C
182E3B172E3C172F3D18303E18303F18303E19303E1A303E1C303E1E3240213440253541
2937422C3944303B45333C46353E46383E463A3F463C40463D40463F4147414348424348
4343484343474142474040453E3F443F40454544494C494C5650526058596A6060736967
7D716E87797590817C9A8984
A89892AD9F9AB1A5A1B7ADA9BCB4B1C1BCB9C7C4C2CECCCCD5D6D6CBCED0BCC2C5AEB5BA
9FA9AF8C9AA37789946177844C65753754652544561A3749173142152F3F142D3D142C3B
132B3A122B3A112A3A112B3A122C3C112B3B122B3B132B3B142C3A172D3B1A2F3D1F323F
2333402736412B38432E3A44323C46353E473940483C41493F434941444B43464C44474C
45474D47484D46474D44464B4244493F40454B494D5450535C5758655E5E6E6564776C6B
807471897B7792827E9A8A84
A89892AD9F9AB3A6A2B8AEAABEB6B3C4BEBCCBC7C5D2D0CFDADADAD3D5D7C6CBCEB6BEC3
A7B1B896A3AB82929D6D818D5A717F466070304E5F1F3E51173446142E40122B3C10293A
0E28390D27380C27380B26380B27390B27390A26380B27380E2738112838142B3A192E3C
1D313E2133402635422B38442F3B46333E483840493E444C41464E444950484B52494C52
494C534A4D534B4D534A4D524B4C5148484C5251545B575A635D5F6B6364736A697B706E
8377748B7D7993847F9B8A85
A99893AEA09BB4A7A3B9AFABC0B7B4C6C0BDCDC9C7D5D3D2DFE0E0DEDFE1D0D3D6C1C7CB
B1BBC0A2AEB58F9DA67A8C98687D8A546D7C415D6E2C4A5D1E3D50143246112C3F0E293C
0B26390824370723360623360624370424370322350422340624350A26370E2839132A3A
182E3D1D313F2335422938442F3C4834404B39434D404750464C544A4F564D51584F5359
51545A52555B52555B51545A52555B57575C5C5A5D625E60696364706869776E6D7E7472
8679778D7F7B9485819C8B86
A99993AEA09BB4A8A3BAB0ACC1B8B5C8C1BECFCAC9D7D5D4E1E1E0E5E7E8DADDDFCAD0D4
BBC3C8ABB7BE9AA8B18697A2768995647A88546C7C405B6D2F4D5F224054173549112E42
0A283C0624380422360322360323370223380123370022360122350524360927390F2A3B
132D3E19303F2034432739472E3E4B36434F3D4853454D574B525A50555D54585F575A61
595C625B5D635B5E635A5D6256585E5E5E626462656965676F696A756E6D7C7271827775
897C798F817D9686829D8C86
A99993AFA09BB5A8A3BBB0ACC2B8B5C9C1BFD0CBC9D8D5D4E1E0DFEAEBEBE5E7E9D6DADD
C7CED2B8C2C7A8B4BB94A4AD8495A0748894647A88546C7B445E6E3551632946591F3D4F
173548102F430B2A3F08283D08293E06293F05283F03273D03263B04263C08293D0D2C3F
133042193445203747293D4B3243503B4A55434F5A4C555E525962585E655D6167606369
63656B65676D66686D64676C63646868666A6C696B706C6D756F6F7A7272807675857A78
8B7F7C91837F9788839D8C87
A99993AFA09BB5A8A3BBB0ACC2B8B5C9C1BED0CBC8D9D5D3E2E0DFECECEBEEEFF0E1E4E6
D3D7DBC4CBD0B6BFC6A5B1B993A2AB83949F738693637886546B7A475F6F3D5566334D5E
294658213F521A3A4E15354A1435491234490F32480C30460B2F450B2E440E3045133347
1836491F3A4C263E4F2F4453384A5843515D4B5761535D665B616A61666D666A706A6D72
6D6F757071777172776F7176707074716F727470727772737B74747F7776847A78897D7B
8E817E9385819889849E8D87
A99993AFA09BB5A8A3BBB0ABC2B8B4C9C1BDD0CAC7D8D4D2E1DEDDEBEAE9F3F4F4EDEFF0
DEE1E4D0D5D9C1C9CEB1BBC2A1AEB6919FA983949E748692667B885A707F4F6676465E6E
3E5768355062304C5E2946592543562341542140541E3E521C3D511D3D511F3E52234053
2743552D4758344C5B3D515F4556624F5C6757616B5F676F656B736B6F7670737874767B
77787D7A7B807C7D817B7B8079787B7976797B76787D7778807978847B7A887D7B8C807D
9083809587829A8A859E8E88
A99892AFA09AB5A7A2BBAFAAC1B7B3C8BFBCCFC8C5D7D2CFE0DCDAE9E7E6F3F3F2F5F5F6
E9EBECDBDFE2CDD3D7BDC5CBAFBAC0A2AEB695A3AC8595A07788946C7E8A617582586D7B
506675475F6F435B6B3D5667395364355063334F61324E60304D5F304D5F324E5F365061
3A52633F5665455A684D5E6B54626E5B6771636C756B717971757C76797F7C7D827F8084
818286848589848488818083807D80807C7D817B7C837C7C857D7C887E7D8B807E8F8380
9385829788849B8B869F8E88
A99892AE9F9AB4A6A1BAAEA9C0B5B1C7BDBACEC6C3D5CFCDDED9D7E7E4E2F1F1EFFAFBFA
F3F4F5E6E9EBDADEE1CCD2D6BEC6CBB0BAC0A5AFB798A4AD8A98A27F8F997585906C7D89
6576835D707D566B785166754D63724A6070485E6F465D6E455C6D465C6D475D6D4C606F
5063715566745A6A76606D7865707A6A737C70777F777C827D808682848885858986868A
89898D8A8A8D88878A87848686828486808186808087807F89807F8C82808E8381928582
9587839889859C8C87A08F89
A89892AE9E99B3A5A0B9ACA7BFB3AFC5BBB7CCC3C0D3CCC9DBD5D3E4E0DEEDEBEAFAF9F9
FEFEFEF4F5F6E6E9EBD9DDE0CCD2D5C0C7CCB6BEC4ABB4BB9FA9B195A0A889969F808E97
79879172818C6B7C8667788364758160717E5D6F7C5C6E7B5B6C7A5C6D7A5E6E7B63717D
65737F6A76816F7983747C85787F867D828882858B87898E8B8B908E8E92929093929193
8E8C8F8E8C8F8D8A8C8B87898B85868A84848B83838C83828D83828F8482918583948784
9789859A8B869D8D88A08F89
A89791AD9D98B2A49EB8AAA5BDB1ADC3B8B4C9C0BCD0C8C5D7D1CEDFDAD8E8E5E3F2F0EF
FDFCFCFFFFFFF5F5F6E7E8EADADCDFCFD3D6C6CBCEBDC3C8B3BABFAAB1B79FA7AF969FA7
8F99A089939B838F977E8A9279858F75828C727F8A717D886F7C876F7C86707D8776808A
7C858E808790838890878B918C8E938F909491919594939798969998979A98979A98979A
969497939092918D8E908A8B8F89898F87878F8685908685918684928784948884968985
998A869B8C879E8E88A08F89
A89791AC9C97B1A29DB6A8A3BBAEAAC0B5B1C6BCB8CCC3C0D3CBC8DAD4D1E2DDDBEAE7E5
F3F1F0FDFCFCFFFEFEF5F4F4E7E7E9DBDCDED2D5D7CCCFD2C5C8CBBDC0C3B5B8BCABB0B5
A4A9AF9DA3A9989EA4939AA08E969D8B929A888F97858D95848B94828992838A91858B92
898D9490939896979B98989C9B9A9D9C9A9D9D9B9D9E9C9EA09EA0A2A0A2A09FA29E9C9E
9A9698979294958F90948D8D938B8B928A89928987938886948886958986968986988A86
9A8B879C8D889F8E89A1908A
A79690AB9B95B0A09BB4A6A1B9ABA7BEB1ADC3B7B3C8BEBACEC5C2D5CDCADBD5D2E3DDDB
EAE6E4F2EFEEFCFAF9FDFBFBF3F1F1E8E7E8DDDDDED7D7D9D2D2D5CCCDCFC5C5C8BFBFC2
BABABEB4B5B8AEAFB2A8AAAEA3A6AA9EA1A79B9EA3989BA1979AA095989D929599929498
95969A99989C9B9A9D9E9C9FA29FA1A5A1A4A6A3A4A7A4A5A8A5A6A9A6A8A4A2A4A09D9E
9D98999A9495989191978F8E968D8C958C8A958B89968A88968A87978B87998B879A8C87
9C8D889D8E889F8F89A1908A
A7968FAA9A94AE9F99B2A39EB6A8A3BAADA8BFB3AEC4B8B4C9BFBBCEC5C2D4CCC9DAD3D0
E1DBD9E8E3E1F0ECEAF9F7F6FAF7F7F0EEEDE6E4E4DFDDDEDAD9DAD7D6D7D2D0D2CBC9CB
C6C4C6C3C0C3C0BDBFBBB9BBB5B4B6B1B0B2AEACB0AAA9ACA8A7AAA6A4A8A5A3A5A2A0A3
A5A2A4A9A4A5ACA6A7AEA8A9B0AAAAB2ACACB2ACADAFABACAFABADACA9AAA7A3A3A39D9D
9F99999D95959B93929A908F998F8D988D8B988D8A988C89998C889A8C889B8C889C8D88
9D8E899F8E89A08F8AA2908A
A6958FA99993AD9C97B0A09BB3A59FB7A9A4BBAEA9BFB2AEC3B8B3C8BDB9CDC3BFD2C9C6
D8CFCCDED6D4E4DEDCEBE6E4F4F0EFF7F3F2F1EDEDE6E2E1DEDADADBD7D7D9D6D7D8D3D4
D4CFD0D0CBCBCBC5C6C9C4C4C8C2C2C3BDBDBDB6B7B7B2B3B5AFB0B2ADAEB1ABABADA8A8
AFA9A9B1AAAAB4ACABB6AEADB7AFAFB8B0B0B8B1B0B2AEAFB0ACADACA6A6A8A1A1A49D9C
A199989F96949D93919C918F9B908D9B8F8C9B8E8B9B8D8A9B8D899C8D899C8D899D8E89
9E8E899F8F89A1908AA2908A
A6948EA89791AB9A94AE9E98B0A19BB3A59FB6A8A3BAACA7BDB0ACC1B5B0C5B9B5C9BEBA
CEC4C0D2C9C6D8CFCCDDD6D3E3DCDAE9E3E0EFE9E7EDE7E6E5DEDDDFD8D7DAD5D4D8D2D2
D6CFCFD5CECDD3CAC9CFC6C4CBC2C0C8BFBDC4BBB8C0B7B5BAB2B0B8B0AEB7AFAEB5AEAD
B5AEACB7AFADBAB1B0BCB3B1BCB4B3BAB2B3BBB4B5B5AFAFAFA8A7ABA3A2A89F9DA59B99
A29896A096939F94919E928F9D918D9D908C9D8F8B9D8F8A9D8E8A9D8E8A9E8E899F8F89
9F8F8AA08F8AA1908AA2918A
A5938DA7958FA99892AB9B95AD9D97AFA09AB2A39DB4A6A0B7A9A4BAACA7BDB0ABC0B3AF
C3B7B3C7BBB7CBC0BCCFC5C1D3CAC6D8CFCBDCD3D0E3DBD7E5DCD9E3DAD7DDD4D1D6CDCC
D6CCCBD5CBCAD2C8C6CFC4C1CBC0BEC9BEBCC7BBB9C5B9B6C2B7B4C0B5B2BCB3B0BBB2AF
BAB2B0B9B2B0BBB3B1BBB3B2BFB8B8BEB7B6B7AFAEB2A8A7ADA3A1AA9F9DA79C99A59996
A39794A29591A09390A0928E9F918D9F908C9E908B9E8F8B9F8F8A9F8F8A9F8F8AA08F8A
A0908AA1908AA2908AA3918B
A5938DA6948EA79690A89791AA9993AB9B95AD9D97AF9F99B0A19BB2A39EB4A6A0B6A8A3
B9ABA6BBAEA9BEB0ACC1B4AFC3B7B2C6BAB6C9BDB9CCC1BCCEC3BED0C4BFD2C7C2D0C6C1
CDC3BECDC2BECCC1BFCCC1BDC9BDBAC3B8B5C1B5B3BFB3B0BDB2AEBDB1ADBBAFACB8AEAA
B8ADAAB9AFADBFB6B3BBB2AFB7ADAAB4A9A7B1A5A2ADA19EAA9E9AA89B97A69995A59793
A39591A2948FA2938EA1928DA1918CA0918CA0908BA0908BA0908BA0908AA1908AA1908A
A1908AA2908AA2918AA3918B
A4928CA5938CA5948DA6948EA7958FA79690A89791A99892AA9993AB9A94AC9B96AD9D97
AE9E98AF9F9AB1A19BB2A29DB3A49FB5A6A0B6A7A2B8A9A3B9AAA4B9ABA5BAABA6BAABA6
B9ABA5B9ABA5B9ABA6BAACA7BDAFA8BCAEA8BCAEA9BBADA9BAACA8BAACA8B9ACA8B9ACA8
B8ABA7B2A5A1B0A39EAFA19DAD9F9BAC9D99AA9B97A89995A79893A69691A59590A4948F
A3938EA3938DA2928DA2928CA2918CA2918BA2918BA2918BA2918BA2918BA2918BA2918B
A2918BA3918BA3918BA3918B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?ooo`BSTH/<Xi6:4j:@RPBRT8T7XI294:6?R@nPShP8X8n91:2?
RPBPT8/4Whn90j2>R0BPSXL4X8j83j2=Q`BPSXL4X8f71:6=Q`BPSHL4XHj71:2=Q`>QSHL8X8b61:2<
Q@RPRhD3X8^429n:P`BNRH84WHMo19j9PPBORX<3Wh^41:2<Q@RPS8H4XHf61:6=Q`>QSXL4XHj81::?
R0BRShT4XY291:>@RPBSTHXEoooo000Doooo1:>AR`bSTHXCXY2:1::@R@NQT8T@XHn93j2?R0RPShT4
X8n:1:2@R`BOShT3X8j81:2>Q`BPSXP?X8f71:2>Q`BPSHL4XHf71:2=Q`BQSXL4X8f70j6=Q`RPS8H4
X8b52:2;Q@>PRh@8WhZ319j9PPBMQgl4WXV219n:P`>ORh@4X8b52:2<QPBQSHH4XHf70j6>Q`BQSXP4
XXn81::?R@BRT8T4Xi2:1:>ARQGoool001Coool4Xi6;3:>ARQ>RT8X4XY291j6@RA2QShT?X8n82:2?
R@BPShX4X92;19n?R@>PSXP4X8j71:2>R0nPSHL4X8j71:2=Q`BQSHL4X8f71:6>Q`BPSHL3XHf72:2<
QPBPS8D8X8^50j2;Q0RORX<4WXV219f7O`BNRH84WhZ30in;Q0BPS8D8X8b61:6=QPBQSHL3XHj71:6>
R0BRShP4XXn91::@R@BST8X4Xi6:5Oooo`005?ooo`BSTH/4Xi6:2::@RPBRT8T;XHn91:2?R0RPSXP3
Whj819n>Q`BOSHL4WXf719j=QPBNS8H;WHb619b<QPBLS8L4W8f819b>RPBLS8L3W8^529b:Q0bMRX@3
WHV319b9PaBMRH<3WXR219f7P@BMQh04W8Io19b5OPBLQ7h3W8Am19^3O0BKPW/4VX9j19V1N@BJPW/4
VhAl0ib5OPBLQWl4WHR019f8P@BNRH84WhZ30in;Q0BPS8D4X8f61:6=Q`BQSXP4XXn91:>@RQGoool0
01Coool4Xi6;1:>ARPRRT8X4XY292j6?R@BPShP8X8j80in>R0BOSXL4Whf719j=Q`BNSHH4WXb62if<
QPBLS8H4W8b719b=R0BLSXX4W8b70ib;Q@RLRX@<WHZ40if9P`BLRH<DWHV30ij8PPBMQh44WHN019b6
O`BLQGh4W8An0ib4O@BKPg`4Vh9k19Z2NPBIPGT4VX9k19^4O0>LQGh4W8Io19f8P0BMR844WXV219n:
P`>ORh@4X8b51:2=QPBQSHL4XHj81::?R@BST8XEoooo000Doooo1:>AR`BSTHX8XY2:1::@R@^QShT4
X8n82:2>R0>OSXP4Whj719n=Q`BNSHL4WXf619j<QP^MS8H4W8b619b<Q`BLSHP4W8j:19b<Q`>LRhD8
W8Z439f:Q0>MRH<4W8V359f9P`>NR884WHN119f7P0BLQWl4W8En19b4OP>LQ7d4Vh=l19^2N`BJPWX4
VH5i19Z2N`BKQ7`3W8En19b6O`BMR804WHR119j9PPBORX<3Wh^41:2<Q@BPSHH4XHf71:6>R0BRShT4
Xi2:5Oooo`005?ooo`BSTH/4Xi6:2::@RPBRT8T;XHn91:2?R0RPSXP3Whj819n>Q`BOSHL4WXf719j=
QPBNS8H;WHb619b<QPBLS8L4W8f819b>RPBLS8L3W8^529b:Q0bMRX@3WHV319b9PaBMRH<3WXR219f7
P@BMQh04W8Io19b5OPBLQ7h3W8Am19^3O0BKPW/4VX9j19V1N@BJPW/4VhAl0ib5OPBLQWl4WHR019f8
P@BNRH84WhZ30in;Q0BPS8D4X8f61:6=Q`BQSXP4XXn91:>@RQGoool001Coool4Xi6;1::ARPBRT8X8
XHn90j2?R@BPSXP4Whj819n=Q`BNSHL4WXb61if<QPBLS8D4W8^519^;Q@BKRX@4VXZ40iZ9P`RIRH<4
V8V419R:Q@BHRhL4V8V30iR8PPBHQh48VHN119Z6P0BJQh47VXN219^7P@BKQX48W8J119b6P0>LQGl4
Vh=m19Z1N`BIP7T4V7mh19MnM`>GOGH4Ugad19IkL`BFNW44UW]c19IlM0BGOWD3V7mg19V1N@BJPWX4
VX=l19^4O@BLQWl3WHN019j9PPBORX<4X8b51:6=QPBQSXP4XY295Oooo`005?ooo`BSTH/4XY6:1::@
RPRQShT3X8n91:2>R0BOSXP4Whf719j=Q`BNS8H7WHb619b<Q@BLRhD4Vh^519^:Q0BJRX@3VXV329V9
P`BHRH@4V8Z519R;Q`BHRH<3V8R219R7P@RIQh44VXJ019Z7P@NJQh84VhN119^6P@RLQX44W8J00ib5
O`BKPgd4VX5k19V0N@BHOgP4Ugig0iMmMPBGO7@4UW]c19IjL@BFNg<4UWad19MnM@>HOgL4VH5i19Z2
NPBJPg`4VhAm19b6O`>MQh04WXV219n:P`BPS8D4XHf61:6>R0BRT8TEoooo000Doooo1:>AR`BRTHX4
XY2:2:6?R@>PShT4X8j819n>R0BOSHL4WXf719j<QPNMS8H4W8b519b;Q@BKRhD4VhZ419Z:Q0>JRH<8
VHV319R9Q0BHRXD4V8^719R9P`>HR884V8N129V7P@BJQX04VXN11iZ7PPBKQh44VhJ129b6P@BLQX03
W8Eo19^3O@BJPG/4VH1i19QoN0BGOWL3Ugef19MlM0BFNg<4UWYa19IkL`BFO7@4Ugie0iQoM`BIPGT4
VX9j19Z3O0BKQ7d4W8Io0if7P0BNRH84WhZ31:2<Q@BQSHH4XHj81::@RAGoool001Coool4Xi6;1::A
RPBRT8X8XHn90j2?R@BPSXP4Whj819n=Q`BNSHL4WXb61if<QPBLS8D4W8^519^;Q@BKRX@4VXZ40iZ9
P`RIRH<4V8V419R:Q@BHRhL4V8V30iR8PPBHQh48VHN119Z6P0BJQh47VXN219^7P@BKQX48W8J119b6
P0>LQGl4Vh=m19Z1N`BIP7T4V7mh19MnM`>GOGH4Ugad19IkL`BFNW44UW]c19IlM0BGOWD3V7mg19V1
N@BJPWX4VX=l19^4O@BLQWl3WHN019j9PPBORX<4X8b51:6=QPBQSXP4XY295Oooo`005?ooo`BSTHX4
XY2:1:6@RPBQShT4X8n80in>R0BOSXL4WXf719f=Q`BMS8H4W8b50ib;Q@BKRX@4VXZ419V9P`BIRH84
V8R219N7P@>FQh44UXJ019F6P0BDQX44U8J219B7P`BDQH03U8Ao19F4OPBEPgd4UX=m19N4OPBHQGl3
VXJ129Z7PPBKQX44VhEo19^3OPBKPW`3VX5k19UoN@BHOGL4UW]d19EjL`BDN743U7M_19=eK@BBLfX4
T71W199cJPBCMF`4TgM^0iAiL@BENg<4UWee19QoM`BIPGT4VX9k0i^4O@BLQWl4WHR119j:P`BPS8D4
XHf71::?RAGoool001Coool4Xi6:1::@RPBQT8X4XHn91:2?R0>OSXP4Whj719j=Q`BMSHL4WHb619b<
Q@>LRhD4VhZ419Z:Q0BIRH<4VHV219R8PPBGQh43UXN119J6P0BEQX04U8J119B6PPBDQh<4U8F00iB4
O`BEQ7h4UH=m19J3O@BGQ7h4V8Eo0iZ6P@RJQh84VhJ119^5O`BKPgh4Vh9l0iZ1N`BIOgT4V7eg19Ik
M0BENW<4U7Qa0iAgK`BCMFd4TW=Z191`I`BBLfX4TgE/19=gKP>DNG44UG]c19ImM@BHOgL4VH5i19Z2
N`>KQ7d4W8Io19f8P@BNRX<4X8b51:6=Q`BRShTEoooo000Doooo1:>ARPBRT8X4XI2:1:6?R@BPShP3
Whj819n>Q`BNSHL4WHf719f<QPBLS8D3W8^519^:Q0BJRX@4VHV319V9PPBHR884UhN10iJ7P@BFQX04
UHJ019B6P@BDQX84U8N319B5P0>DQ7l4UHAn19F3O@BFPgd4UhAn19R5O`>JQX48VXN219^6P@BKQGl4
Vh=n19^2O0>JPG/4VGmi19QmM`BFNg@4UGYc19AhL@>DMfl4TgE]199cJPB@L6L4TW=Z19=eK0BCMfh3
U7Ua19EkL`BFOGD4V7mg19V1N@BJPW/3VhAm19b6O`BMR844WXZ31:2<Q@BQSHL4XXn95Oooo`005?oo
o`BSTHX4XY2:1:6@RPBQShT4X8n80in>R0BOSXL4WXf719f=Q`BMS8H4W8b50ib;Q@BKRX@4VXZ419V9
P`BIRH84V8R219N7P@>FQh44UXJ019F6P0BDQX44U8J219B7P`BDQH03U8Ao19F4OPBEPgd4UX=m19N4
OPBHQGl3VXJ129Z7PPBKQX44VhEo19^3OPBKPW`3VX5k19UoN@BHOGL4UW]d19EjL`BDN743U7M_19=e
K@BBLfX4T71W199cJPBCMF`4TgM^0iAiL@BENg<4UWee19QoM`BIPGT4VX9k0i^4O@BLQWl4WHR119j:
P`BPS8D4XHf71::?RAGoool001Coool4XY6:1::@RPBQT8X4X8n919n>R0NNSHL4WHb619b<Q@BKRhD4
VXZ40iZ9P`BIRH84V8R219N7P@BFQX04UHEo19B5O`>CQ7h4TX=m1962O@R@PWd4T8=o1922O0>@PGX4
TH1j29:0NPBCP7/4U85l0iF2O@BFPgh4UhAo19R4O`BHPgd4V85k19R0N@>HOWL4Ugae19IhLPBDMVl4
TWE]195bJP>@KfL4SfiU18e/HPB<JUl4SFaR18i_I@B@LFP3TG=Z199fK@BCN6l4UGYb19IlM0BGOgH3
VH5i19Z3N`BLQGh4WHR019n:P`BPS8H4XXn85Oooo`005?ooo`BRTHX4XY2:1:6@RPBPShT4Whj81ij=
Q`BMS8H4W8b519^;Q@BJRX@3VXV319V9PPBHR884UhN119J6P0BEQGl4U8Eo0i>4OPBBPgd4TH9m2922
O@B@Pgl4T89l0i21NPBAP7X8TX1j19>0N`BDPG`3UH9m19J3OPBGQ7l4V8Ao19R3O@BHPG/4V81i0iQn
M`BGO7D4UWQb19AfK`BBMFd4TG9Z0i1_I`B?KVD4SFaR18aZG`B=K684SVmU191aJ0>ALfX4TWI]19=h
K`BENW84UWad19MoMP>IPGT4VX=k19b5OPBMR804WhZ31:2<QPBRShPEoooo000Doooo1::ARPBRT8X4
XI2:1:2?R@BOSXP7WXf719f<QPBLS8D4Vh^519Z:Q0>JRH<4VHV219R8PPBGQh44UXJ019F5O`BDQGl3
ThAn19:3O@BAPWd8T89m1923O`B@PW`3T85j1960NPRBP7X4Th1k19B1O0>EPWd4UX=n19N4O`BHQ7l4
V8=m19R1N`BHP7T3V7ig19MlM@BFN784U7I_199eK@BALVX3T6mW18m^I@B=K684S6YO18e/HPB>KfD4
T75X0i5cJPBBMVd4TgQ_19EjLPBFO7@4Ugmf0iV1N@BJPg/4W8En19f8P0BORX<4X8b61::?R1Goool0
01Coool4XY6:1::@RPBQT8X4X8n919n>R0NNSHL4WHb619b<Q@BKRhD4VXZ40iZ9P`BIRH84V8R219N7
P@BFQX04UHEo19B5O`>CQ7h4TX=m1962O@R@PWd4T8=o1922O0>@PGX4TH1j29:0NPBCP7/4U85l0iF2
O@BFPgh4UhAo19R4O`BHPgd4V85k19R0N@>HOWL4Ugae19IhLPBDMVl4TWE]195bJP>@KfL4SfiU18e/
HPB<JUl4SFaR18i_I@B@LFP3TG=Z199fK@BCN6l4UGYb19IlM0BGOgH3VH5i19Z3N`BLQGh4WHR019n:
P`BPS8H4XXn85Oooo`005?ooo`BRTHX4XI2:1:2?R@BOSXP4WXf70ij=QPBMS8H4W8^519^:Q0BJRX<4
VHV30iR8PPBGQh44UXJ019F5O`BDQ7h4Th=m1962O0>@PG/4Sh1j18enN@B<OGP4Rgeh18]nN@B;OGP3
S7eg18elMPB>O7H4Sgaf18mmM`B@OGL3TGeh199nN@BCOgX4U81j19AoN@BDOGH4U7]d0i=iLPBCMfl4
TWA/191`J0B?KVH4SFaS0h]YH0B:IUd4RFEK18QTF@B9IU/4RVQN18a[H@>=KF<4SW1V191cJ@BBMV`4
TgQ_19EkLP>GOWD4V81h19Z3N`BLQWh4WXV11:2;Q@BQSXPEoooo000Doooo1::ARPBQT8X4X8n919n>
R0BNSHL3WXf619f<QPBLRhD4VhZ419Z:P`BIRH<3V8R219N7P@BFQX04UHEo19B4OPBCPgd4TH9l0i21
N`B?P7X4SGii18amN0B;OGP4Rgii18]mN0><OGL4SGaf18ilMPB?O7H4Sgeg191mM`>AOGP4TWii19=o
NPBDP7X4U7mi19AmMPBDNg@3TgUb19=gK`BBM6`4T71X18m^IPB=K6<3RfUP18YVG@B9IE/4R6AI18UV
F`B:J5h4S6]Q0he]H`B>L6H4T7=Y199fK0BCN6l4UG]b0iMnM@BHP7P4VX=k19b6OPBNRH44X8^51:6>
R1Goool001Coool4XY6:1:6@RPBPShT4Whj819j=Q`>NSHH4WHb619b;Q@BKRX@4VXZ319V9P`>HR884
UhN119J6P0BEQGl4U8An19>3O@BAPW`3T85k18n0NPB=OWT4S7eh18]mN0B;OWT4Rgeh0hamM`B=O7H4
SWaf18mlMPB?OGL4T7eg0i5mN0BBOWT4Tgmj19B0NPBDOgT4U7ef19AkM0>CNG84TgM_199dK0B@L6P4
SfiV18e/H`>;JF04RVIM18UUF`B8I5T4RFIK18YXGPB<Jf43SFeS18i`IPB@LfT4TWI/19=hK`BENg83
Ugie19R0N0BJPg/4W8In19j9P@BPRhD4XHj85Oooo`005?ooo`BRT8X4XHn91:2?R0BOSXL4WXf70if<
QPBKRhD4VXZ419V9P`BHR884UhN10iJ6P0BEQGl4U8An19:3O@BAPW`4T85k18ioNP>=OWP4Rgag18Uk
M@B7N7<4QGI`18EfL@B7N7<3R7Uc18UiL`B:NG84RgUc18]hL`B<N7<7SGUc18iiL`B?N7<4SgQb18mg
L0B?MFh3Sg=/18iaJ@B=KVH4S6]R18YWG@B8I5/3Qf9H18EOE0B3G544Q5eB18EOE0B6HUH4R6AI0hUW
G@B;Jf04SFiT18iaI`B@M6/4TWM_0iAkLPBFOWH4V85i19^4O0BMQh04Wh^41:6>QaGoool001Coool4
XY2:1:6?R@BPShP4Whj719j=Q`>MS8H4Vh^519Z:Q0BIRH<4V8R219N7P@>FQX04UHEo19B4OPBBPgd4
TH9l1921N`B>OgX3SGih18]lM`B9NgD4QgQc18EfL0B5MW44QgQc0hQiL`B9NG<4RWUb18]iL`B;N7<4
S7Qc1heiL`B>NG<4SgQc18mhLPB?Mg04SgE^0hmcK0B>LFT4SFiV18a[HPB:Ied4R6AK0hMRF0B5Ge@4
PeaA18AMDPB5Ge@4QV9F18QTF@>9Ied4Rf]P18e^I0B>LFL4T7A[199gK`>DNg84UWif19R1N@BKQ7`4
WHN019n;Q0BQSXLEoooo000Doooo1::@RPBQShT4X8n819n>Q`BNSHL3WHb619^;Q@BJRX@4VHV319R8
PPBGQh43UXJ019F5O`BDQ7h4TX=m1962O0B@PG/4SWmj0henN0B;O7L4RG]e18MhL`B5MW04QGIa18Mh
L`>8NG<4RGUc18YiLPB;NG<4RgQc18ahL`N=NG<4SWUc18mhL`B?N784SgM`18meKP>?Lf`4SW5Y18e^
IPB<Jf84RVMM18QTF`>7HUP4QEmD18=LD@B4GE84QEmD18IREPB8I5T3RFMM18][H0B=KV@4SW5W191d
J`BBMfl3U7]b19InMPBHPGT4VhAl19f7P0BORh@4XHj75Oooo`005?ooo`BRT8X4XHn91:2?R0BOSXL4
WXf70if<QPBKRhD4VXZ419V9P`BHR884UhN10iJ6P0BEQGl4U8An19:3O@BAPW`4T85k18ioNP>=OWP4
Rgag18UkM@B7N7<4QGI`18EfL@B7N7<3R7Uc18UiL`B:NG84RgUc18]hL`B<N7<7SGUc18iiL`B?N7<4
SgQb18mgL0B?MFh3Sg=/18iaJ@B=KVH4S6]R18YWG@B8I5/3Qf9H18EOE0B3G544Q5eB18EOE0B6HUH4
R6AI0hUWG@B;Jf04SFiT18iaI`B@M6/4TWM_0iAkLPBFOWH4V85i19^4O0BMQh04Wh^41:6>QaGoool0
01Coool4XY2:1:6?R@BOSXP4WXf719f<QP>LRhD4VXZ419V9P`BHR884UhN119F6P0>DQGl4ThAn1962
O0B@PG/4Sh1j18eoN@B<OGL3RWae18QjM0B6Mg44PW=]17e_JPB1Lfd4PgA_0hEeL0B6MG04QWE_18Md
KPB8M6l4R7A^1hUcK@B9LVd4RW5[18Y`JPB9KfT4RFeW0hU[I0B9JV84QfMN18ITF`B5HEP4Q5iC0h9K
D0B0F4`4OeA717mEB@B0F4/4PU]>18=NDP>5HEH4QfEJ18UYGPB;K684SG1V191dJP>BMfh4U7]c19Mo
M`BIPg/4W8Io19j:P`BQSHLEoooo000Doooo1::@RPBQShT4Whj819j=Q`BMS8H3W8^519Z:Q0BIRH<4
V8R219N7P@BEQX03U8Eo19>4OPBAPW`4T85k18n0NPB=OgT4S7eg0hYlM@B8NW@4QWMa189cK@AmKfX4
PG=]18=dK`>5MG04QWE`18IeK`B7M6h4R7A_18QdKPN9Lfd4RG9]18YaJ`B:L6X4RFmY18U]I`>9Jf@4
RFYR18MWGPB6I5/4QF5H18AND`>2Fe04P5Q<17mDA`AoEDT4P5Q;189KCPB3GU83QF5F18MUFPB9JEh4
RfaR18e`IPB@M6X3TWM^19AkL`BGOgL4VH=k19b6O`BNRX<4XHf75Oooo`005?ooo`BRT8X4XHn919n>
R0BNSHL4WHb60ib;Q@BJRX@4VHV319R8PPBGQh44UHJ00iB5O`BCQ7h4TH9l1921N`B?P7X4SGmi18am
M`>:O7D4R7Yd18IgL@B2Lfd4OFmZ185cK@B3M6l3QGE`18IeL0B6MFl4QgA^18QdK`B8M6h7RG=]18Ub
K@B:LF/4RW1Z18U_J@B9KFL3RF]T18UZHPB7Ieh4QVAK18EQF0B4GU<3PU]@181HC0AoE4L4OeE9181H
B`B2Fdh4PeiB0hEQEPB7IEX4RFUN18]/HPB=L6H4T7AZ0i9gKPBDNg<4Ugmg19V3N`BLQWl4WXZ31:6=
QaGoool001Coool4XY2:1:6?R@BOSXP4WXf719f<QP>LRhD4VXZ419V9P`BHR884UhN119F6P0>DQGl4
ThAn1962O0B@PG/4Sh1j18eoN@B<OGL3RWae18QjM0B6Mg44PW=]17e_JPB1Lfd4PgA_0hEeL0B6MG04
QWE_18MdKPB8M6l4R7A^1hUcK@B9LVd4RW5[18Y`JPB9KfT4RFeW0hU[I0B9JV84QfMN18ITF`B5HEP4
Q5iC0h9KD0B0F4`4OeA717mEB@B0F4/4PU]>18=NDP>5HEH4QfEJ18UYGPB;K684SG1V191dJP>BMfh4
U7]c19MoM`BIPg/4W8Io19j:P`BQSHLEoooo000Doooo1::@RPBPShT4Whj719f<QPBLRhD3VhZ419V9
P`BHR884UXN119F6P0BDQ7l3TX=m1962O0B?PG/4SWmi18anN0B;O7H4RG]e0hQiL`B6Mg44Q7E_189c
KPAjK6P4Og5[185bK0N2LV`4Pg5[18=`JPB4L6X4Q71[0hE_JPB5KVP4QFaV18EYI0B4If84Q6IP18AV
G`>3IEd4Pf=K189QF0B2GUD4P5]A17mGC0=mDdL4Ndm217U:?0AjCCl4O51217eCAPAoEd/3PE]?18=O
E0B6HeP4R6MM18]/HPB=L6H3T7A[199hL0BEOG@4V85i19^5O@BNRH84X8f65Oooo`005?ooo`BRT8X4
X8n919n>Q`BMS8H4W8^50i^:Q0BIRH<4V8R219J7P@BEQX04U8Ao0i:3O@BAPW`4Sh5k18ioN@B<OWP4
Rgaf18UkM@>8NG<4QWMa18AeK`B2Lfh4NVaX17maJ`B1LV`7PW9/18=aJ`B3L6X4Q71Z18A`J`>5KfX4
QFiX18E/IPB5JF@4Q6MR18AVH0B4IUl3PfEM18=SF`B2HEP4PUiE181KD@AoEd`3OE=717]?@PAiBS`4
NTdo17a@@PAmDdH4OeM;0h5KC`B3Ge@4QV=H18QWG@B;K684SG1V0i1dJ`BBN704UGed19R1N@BKQGd4
WXV21:2=QQGoool001Coool4XY2:1:2?R@BOSXL4WHb619b;Q@>KRX@4VHV319R8PPBFQh44UHJ019B4
O`>BPgd4TH9l18n1N`B>OgT4S7ih18]lMPB9NgD3R7Uc18IgL@B4MFl4PW=^17Y/J0AoLF/4PG9/1h9b
K0B3LF/4Pg1Z18A`JPB4L6/3QFmZ18E^J0B5K6H4QFUT18AWHPB4IV04Q6IO0h=UG@B3He/4PV5H189N
E@B0Fe44OeM<0geCA`AkCd84NDXl17Y=?`AlD484OE=617mGB`>1Fdl4PemD18ISF0B8Ied4RfaR18e`
IP>@M6/4TWQ`19EmM0BHPGT4VhEm19j9PPBPSHHEoooo000Doooo1::@RPBPShT4Whj719f<QPBLRhD3
VhZ419V9P`BHR884UXN119F6P0BDQ7l3TX=m1962O0B?PG/4SWmi18anN0B;O7H4RG]e0hQiL`B6Mg44
Q7E_189cKPAjK6P4Og5[185bK0N2LV`4Pg5[18=`JPB4L6X4Q71[0hE_JPB5KVP4QFaV18EYI0B4If84
Q6IP18AVG`>3IEd4Pf=K189QF0B2GUD4P5]A17mGC0=mDdL4Ndm217U:?0AjCCl4O51217eCAPAoEd/3
PE]?18=OE0B6HeP4R6MM18]/HPB=L6H3T7A[199hL0BEOG@4V85i19^5O@BNRH84X8f65Oooo`005?oo
o`BRT8X4X8n919j>R0BMS8H4VhZ40iZ9P`BHR884UhN119F6P0BCQ7l4TX=m0i22O0B?P7/4SGmi18]m
N0B:O7H4R7Yd18MiL`>5Mg44Q7E_18=eK@B2M6d4P7=/17i`JPAnKfT3OfmY17m^J0AoKVL4P6eW281/
IP>1JfH4PFYT181XHPB1IF04P69N17mPF`AoGUT3OUeF17iLE0AlFU44O5M>17]DB`AkDDH3NDe117M9
>`Ad@S<4MD<d17M7>@AiC3h4Ne130geEB0AoFDd4PUiB18ESF0B8Ied4RVaR0heaI`B@MVd4U7Yb19Mo
M`BJPg`4WHR11:2=QQGoool001Coool4XY2:1:2?R@BNSXP4WHb619^:Q0>JRH<4V8R219N7P@BEQX04
ThAo19:3O@>@PW`4Sh1k18eoN@B;OGP4RWaf18QjM0B7NG<3QGMa18AeK`B3MFd4PWA]181cK0AnL6X4
OVmY0gm_J@AoKVP4OfiW181]I`R0K6H3PF]V185ZI0B0J684PFEP181RGPAoH5/4OeiI0giMEPAnG5@4
O5YA17aGCPAkE4/4Ne560gU=@@AgBC/4M48c17E3=0AgAcT4ND`n17]@@`=mEDP4OeU=189NDPB5HeP4
R6MM18Y/HP>=LFL4T7I]19AjLPBGOgL4VX=l19f8P@BPSHHEoooo000Doooo1::@RPBPShT4WXj819f<
QPBKRX@3VXV319R8PPBGQh44UHJ019>4O`BBPgd3T89l18n0N`B=OgT4Rgeh18YlMPB8NW@4QgUc0hEg
L@B4MFl4PgE]189dK@B0Lf`4OW1Z17i_J@=oKfT4OfiX17m^I`B0KFL8P6aV0h5[IPB1JV@4P6QR185U
H0B0HUh4Of1K17mNF@=nGEH4OUaD17aJD@AlEdh4NeA;17]AAP=iCD44MdTk17A2<`Ae@c@4MdLi17U<
?PAkD4<3OEE817mIC@B2GU84QF=H18QWG@B:K683SG5W191fK@BDNW84Ugmg19Z3O0BMR844X8f65Ooo
o`005?ooo`BRT8X4X8n919j>R0BMS8H4VhZ40iZ9P`BHR884UhN119F6P0BCQ7l4TX=m0i22O0B?P7/4
SGmi18]mN0B:O7H4R7Yd18MiL`>5Mg44Q7E_18=eK@B2M6d4P7=/17i`JPAnKfT3OfmY17m^J0AoKVL4
P6eW281/IP>1JfH4PFYT181XHPB1IF04P69N17mPF`AoGUT3OUeF17iLE0AlFU44O5M>17]DB`AkDDH3
NDe117M9>`Ad@S<4MD<d17M7>@AiC3h4Ne130geEB0AoFDd4PUiB18ESF0B8Ied4RVaR0heaI`B@MVd4
U7Yb19MoM`BJPg`4WHR11:2=QQGoool001Coool4XI2:1:2?R0BNSHL4W8b619Z:Q0>IRH<4UhN219F6
P0BDQGl4TX=n1922O0>>P7/4SGmi18]mN0B9O7H4QgYd18IhLPB4Mg03PWE_181bJ`B1Lfd4PWE_17mb
K0AmKfT4O6iW0ga/IPAlJf@4O6YS27aYHPAlJ683OFQR17iVH@AmHeh4OF1L17eMF@AlFUH4NeQC0gYG
DPAiEDl4N5A<17MAB0AfCdD4MDa10gE8?0Ab@cD4L3d]16lj:PAa?bl4M4@e17I9>`=iCT44Ne=717iI
C@B1GU84Q6=H18QXGP>;KV@4SW=Z199hK`BEOG@4VH9j19b7P0BPS8DEoooo000Doooo1:6@RPBPShP4
WXf719b<QPBJRX@3VHV319N7PPBEQX04U8Eo19:3OPB@PW`3SX1k18eoN@B;OGP4RGaf18MjM0B6N784
Q7M`0h9eK`B0LV/4PG=]189eK`AoLV`4OFmY17a^I`=lK6H4O6]T17aZH`QlJF84O6QR0geXHPAnIV44
OF=N17ePG0AmGET4O5YF17]HD`=jEe84NEE?17QDC0AgDDP4MTm517E<@@=eB3`4LT<e170m;@A_>RX4
LCl_17A4=@AfBC/3NDi117]CA`AnFDd4PEiB18ASF0B8J5h3RfiT18icJPBBN6l4UGed19V2NPBLQh04
X8b55Oooo`005?ooo`BQT8X4X8n819j=Q`BLS8H4VXZ40iV9P`BGQh84UHJ019B5O`BBPgh4T89l0hj0
N`B=OgT4Rgeh18UlMPB7NW@4QWQb18AgL0>2MFl4P79[185cK@B2MFl4Og9/17e_J@AlKVL3O6aV17a[
I0AlJV<8O6UR17aXHP=mJ684OVIQ17eSGPAmH5`4OEeI17aJEPAkF5<3NUMB17UEC`AhE4`4Me5817I?
A@AeC443MDPl1793=@A`?Bd4KcXZ174o;`AdA3D4MTTk0gU>@@AkDdL4OUU=185NDPB4HeP4R6QN0h]^
I0B>LfX4TWQ_19EmM0BIPWX4W8N01:2<QAGoool001Coool4XI2:1:2?R0BNSHL4W8b619Z:Q0>IRH<4
UhN219F6P0BDQGl4TX=n1922O0>>P7/4SGmi18]mN0B9O7H4QgYd18IhLPB4Mg03PWE_181bJ`B1Lfd4
PWE_17mbK0AmKfT4O6iW0ga/IPAlJf@4O6YS27aYHPAlJ683OFQR17iVH@AmHeh4OF1L17eMF@AlFUH4
NeQC0gYGDPAiEDl4N5A<17MAB0AfCdD4MDa10gE8?0Ab@cD4L3d]16lj:PAa?bl4M4@e17I9>`=iCT44
Ne=717iIC@B1GU84Q6=H18QXGP>;KV@4SW=Z199hK`BEOG@4VH9j19b7P0BPS8DEoooo000Doooo1:6@
R@BOSXP4WHf719b;Q@BJRX@3V8R219J7P@BDQGl4TXAn1922O0B>PG/3SGmi18]mN0B9O7H4QgYd18Eh
LPB3MW04PGA^0gmcK0B3MW04Og=]17iaJ`AlL6X4NfiW17Y/I@=iJV<4N6QQ17QVG`QhIEh4N6EO0gUU
G`AjIf44NVIP17YTG@AiHEX4NEeH17MGDP=fDdh4M55;179?B0AbCD@4LDY01758?0=aA3P4Kd0b16hk
:`A[=B@4K3HT16ll;0Aa@S<3M4Pj17M=@0AjDdL4OUU=185OE0B5IEX3RFYP18a`I`B@MVd4U7]c19R1
N@BLQWl4Whb55Oooo`005?ooo`BQT8T4Whj819f=Q`BLRhD4VXZ40iR8PPBFQh44U8Eo19:4OPB@PW`4
SX5k0heoN@B;OGP4RGaf18MjM0B5N784PgI`185dKP=oLf`4PgI`17mcK@AnLF/4O71Z17]^I`AjK6D3
NFYS17QXH@AhIUl8N6EN17QUG`=iIEl4NVMQ17YVH0AjI5d4NF5J17UMF0AgEe83MU=>17AAB`AbCdP4
LTe4175:@0AaB3`3LD@h16m0<PA^>b/4JcDT16`f90A_?2`4LD8c0gA8>PAgCD04NU=717iIC@B1Ge@4
QFEJ0hUZH0B<L6L4T7I]19AkL`BHPGT4W8Io19n<QAGoool001Coool4XI2919n>R0BMSHL4W8^519Z:
Q0>HR884UXN119B5O`BBQ7h4T89l18j1N`>=OgT4Rgeh18UlMPB7NW@4QGQb18=fL0B1M6h3Og=/18=f
L0AoLfd4OW5[17a`JPAkKVL4NVaU0gUZH`AhJ644N6IO27QUGPAhIEl3NFEO17YWH@AjIV04NVAM17UQ
FPAiGEP4MeMB0gICCPAdDD/4LTm8179=A0AaBT04LDPl0g54>0A_@384KS/[16/e90A/=R@4Kc`/1752
<`=dB3X4Mde017YCA`AnFDd4PEmD18EUFP>9JV04S71W191fK@BDNg<4V85i19b6O`BOS8DEoooo000D
oooo1:6@R@BOSXP4WHf619^;Q@BIRH<3UhN219F6P0BCQ7l4TH=m18n1N`B=OgX3Rgih18UlMPB7NWD4
QGQc189fL@B0M6h4OW9/0g]`JPAeJV@4NFiW17Y^J0AiKFL4N6aV17Q[I0=fJF44MFEN17ASG0AdHU/4
Lf9K17ASG0=eI5d4MfQQ27QZH`AhJ644MfAL17AKE0=bE4h4L4m816i;A0A]BD04K4Hl16a4>0=/@SD4
K3h`16/i:PAY=B@4J34P16Xe90A/>b/3Kd4c17=7>PAfCT44NUA817iKC`B2HEH3QVMM18Y]I0B>Lf/4
TgUa19MoN0BKQGh4Wh^45Oooo`005?ooo`BQT8T4Whj819f=QPBKRhD4VHV30iN7PPBEQX04ThAo1963
O@B?PG/4SGmj0h]nN0B9O7H4QgYe18EhL`B2MW44P7A^17ibK0=kL6X4MFYT17U^I`AjKVP4NFeW17Q/
IPAhJf@3MVUQ17EUGPAdHe`4M69K17=RF`AdHe`3MFAM17MXH@QhJV<4N6QQ17MTG0AdFe@3LUA>171?
B0A^Bd@4KDU016a6?0A/A3P3K48e16`n<0A[>BX4JCDT16Pa80AZ=B@4K3/[0fm1<`AcAcX4MTi117YD
B0AnFdl4PV5F0hIWG@B:KF@4SW=[19=iL@BGOgP4VhEn19n;Q1Goool001Coool4XI2919n>R0BMSHH4
Vh^519V9P`>GQh84UHJ019>4O`BAPgd4Sh5k18eoNP>;OWP4RGaf18MjM@B5N7<4PWIa181dKPAnLV`3
Ng1Z17EZI0AiKVL4NViX17U]I`AhK6H4N6]T0gIYH@AeIEh4M6=L17ARF`AcHU/4M6=L0gETG@AgJ648
N6YS17QXH@AgI5`4M5]D0g9DCPA`CdP4KT]416e9@0A/AS`4K4@h0fa2=@A/?S04JcTZ16Te90AX<B04
JSDT16`k:`=_@C<4LdLj17I>@@AjE4P4OU]?189QEP>6Ied4RVeT18icJ`BCNG44Ugmh19^5OPBORh@E
oooo000Doooo1:6@R@BOSXP4WHf619^;Q@BIRH<3UhN219F6P0BCQ7l4TH=m18n1N`B=OgX3Rgih18Ul
MPB7NWD4QGQc189fL@B0M6h4OW9/0g]`JPAeJV@4NFiW17Y^J0AiKFL4N6aV17Q[I0=fJF44MFEN17AS
G0AdHU/4Lf9K17ASG0=eI5d4MfQQ27QZH`AhJ644MfAL17AKE0=bE4h4L4m816i;A0A]BD04K4Hl16a4
>0=/@SD4K3h`16/i:PAY=B@4J34P16Xe90A/>b/3Kd4c17=7>PAfCT44NUA817iKC`B2HEH3QVMM18Y]
I0B>Lf/4TgUa19MoN0BKQGh4Wh^45Oooo`005?ooo`BQT8T4Whj819b<QPBJRX@4V8R30iJ6P@BDQGl4
TH=n18n2O0B=P7/4Rgii0hUlM`B7NgD4QGUc189gL@B0M6l4OW9]17]_JP=kL6X8MVaW17M/I`AfJfH4
MVaV17EZI0=dIf44LVAL36mOF@A]HU/3M6YS17M/IPAjLFX4NVmX17QXH@AfJ604Lf=K0fmKD`AZCdP4
JDQ116Q5?@AX@cT4J44f0fTo<`AY?Bl4J3PY16Hd8`QT;Q`4Ic@S0fXj:`A^@C<4LTPk17I?@`AkET/4
OeeB0hATFPB8Jf44SG5X195hK`BFOWH4VXEm19n;Q1Goool001Coool4XI2919n>R0BLS8H4VXZ419R8
P`>FQX44U8Eo1963OPB?PW`4SH1k18]nN@>9O7L4Qg]e18EiL`B2Mg44P7A_17ibK@AkKfX3Ng1Z27I/
I`AgK6L4MV]V17I/IPAeJV@3M6MQ179TG0a_GeT4KF9K0gAZH`AgK6H4NW5Z17Y_J0AhJ644MVQP17=S
F`=_Fe<4JTm816U8@@AXACd4J4<i16Q1=P=Y?c<4JCd_16Ph:@AV=2<8I2hL16Ld8`=Z>R/4KT4c1798
>`AfCd<4NeI;17mMDP>4I5X4R6]Q18eaJ0BAN6l4UWif19Z5O@BORh@Eoooo000Doooo1:6@R@BOSXP4
W8b619Z:Q0BHR8<3UXJ119B5O`BAPgh4Sh9l18f0N`B;OWT3RGag18MkM@B5NG<4PWMa181dK`AnLVd4
NfmZ0g]`JPQfK6L4MfaW17I[IPAfK6H4MFYT0gAWH@AbI5`<KemI16eRF`=dJV<4MfaV17YaJPAjKfP4
N6QQ17IXH0AcHe/3Ke]C16Y?B0AYB444J4Dm16Q3>@AX@CH3JClc16Tm;`AX>2T4IS@S26@^70AW=2<3
JSX[16i1<`AbB3/4MTm317]FB`AoGE83Q6AJ18Q[H@B=LFP4TGQ_19InMPBJQGd4Wh^45Oooo`005?oo
o`BQT8T4Whj819b<QPBJRX@4V8R30iJ6P@BDQGl4TH=n18n2O0B=P7/4Rgii0hUlM`B7NgD4QGUc189g
L@B0M6l4OW9]17]_JP=kL6X8MVaW17M/I`AfJfH4MVaV17EZI0=dIf44LVAL36mOF@A]HU/3M6YS17M/
IPAjLFX4NVmX17QXH@AfJ604Lf=K0fmKD`AZCdP4JDQ116Q5?@AX@cT4J44f0fTo<`AY?Bl4J3PY16Hd
8`QT;Q`4Ic@S0fXj:`A^@C<4LTPk17I?@`AkET/4OeeB0hATFPB8Jf44SG5X195hK`BFOWH4VXEm19n;
Q1Goool001Coool4XHn919j>Q`BLS8H4VHZ419N8P`>EQX44TXAo1922O@B>PG/4S7mj18UmN0>7NgH4
QGUd18=gLPB0MG04OW=]17]`J`AiKfX3LFUU17=[IPAdJfH4M6aV17AZI@QdJfD3LfUS175UGPA]H5T4
Jf1I17=/I@AcKFH3M6mX17E`J@AfKVL4N71Y17U^IPAjK6D4MfMP0g=PF@AZE4d4I4Q116=2>`AS@3L4
I3hc0fDm<@AV>bh4ISPY16@c8`AR;Qd4HB/J164^7P=T<b@4J3/]16e3=PAbBch4Me9717aJC`>1HEL4
QVQN18]_IPB@MVd4UGee19Z4O0BNRX@Eoooo000Doooo1:6?R@BNSXL4W8b619V:Q0BGR8<3UHJ119:4
O`B@PWd4SX5k18aoNPB9OGP3Qg]f18EiM0B3Mg84P7E`17icK@AkL6/4NFmZ0g5YI@AcJfH4M6]V17A/
IPAdJVD8M6]U0g=YH`AaIEh4KF1I16]PF@AcK6D4LfeV0gA_J0AeL6T4MViW17Q`J@AiKVH4NVaU17MW
H0=cH5T4JUA=16A8@@AS@S/4Hd0g16@n<`=U?C44IS/^16Hh:@AT<b<4HRhM164[6PAQ;Qh3I3<T16Pk
;@A]@cH4LT/n17MBA`AlFTl3PF5G18IXGPB;KfH4T7I]19EmM@BJQ7`4WXZ45Oooo`005?ooo`BQShT4
WXj719b<QPBIRX@4UhR30iF6P@BBQ7l4T89m18j1N`B<OgX4RGeh0hMkMPB5NG@4PgMb181eL0AnLfd4
Ng1[17U_JP=aJFD4Lf]V17A[IPAdK6H4M6YU27A[I@=cJF<4LFEN16ePF@A[H5T4LfaU17=]IP=dKfP4
MG1Y17I^I`AhL6T4NFiV17Y/I@AgIf03Lf1I16YDC@ATB444Hd8k16=0=`AT?S<3ICda16Hk;PAV>2T4
I3<S168^7@AQ:aX4HBhN0f@c90AX>bd4KD<f179;?PAgDTL4O5Y?0h5QE`B6J5h4RfmV191fK@BEOGD4
VXAl19j:Q1Goool001Coool4XHn919j>Q`BLS8H4VHZ419N8P`>EQX44TXAo1922O@B>PG/4S7mj18Um
N0>7NgH4QGUd18=gLPB0MG04OW=]17]`J`AiKfX3LFUU17=[IPAdJfH4M6aV17AZI@QdJfD3LfUS175U
GPA]H5T4Jf1I17=/I@AcKFH3M6mX17E`J@AfKVL4N71Y17U^IPAjK6D4MfMP0g=PF@AZE4d4I4Q116=2
>`AS@3L4I3hc0fDm<@AV>bh4ISPY16@c8`AR;Qd4HB/J164^7P=T<b@4J3/]16e3=PAbBch4Me9717aJ
C`>1HEL4QVQN18]_IPB@MVd4UGee19Z4O0BNRX@Eoooo000Doooo1:6?R@BNSHL4Vhb619V:Q0BFQh83
U8F01963OPB?PG`4S81j18YnN@B8O7L3QWYe18AhL`B1MW44OgA_17]aJ`AhKFP4N6iZ0feVHPA`JF@4
LFYV179/I`AbJfH4LVaV179/I`=cK6H4LF]T179ZHPA]He`4L6EM175VG`=aIel4LVUQ17=XG`AdIel4
M6AK17ESFPAgHUP3N6=J17ALE0AYD4P4Gd4j15ll<`AP>S03HSX_16<j;@AS=bP4HS8S160]70AO:AL4
GBXH0eh/7@AR=2H4JCd`16i6>PAdCT<4NEI;0gmNE0B4IU`4RFeT18idK0BDO7@4VH=k19j:PaGoool0
01Coool4XHn919j=Q`BKS8H4VHZ419J7PP>DQH04TH=n18n1O0B<P7X4RWii18QlM`>6NWD4Q7Qc185f
L@AoM6l4Ng5[17Q]J0AhKVX3KFIR171YI0AaJVH4LVaW179[IPAbK6H4LVaW0g=/IPAaJf@4LVYR16eS
G0A`IEd4LFIO0g5WG`AbJF44LfQO17AWG`AdI5/4MF=J17MRF0=hHeX4M5aD16U@B0AO@CX4Gc`c160j
<0=R>Rl4HcX]16<g:0AR<R<4H2dL15lY5`AM:QP3GR`M168d9PAY?C04KTHj17A>@`AiET/3OeiD18AV
G0B9KF@4SWA/19AlM0BIPg/4WXZ35Oooo`005?ooo`BQShT4WXf719^<QPBIRX@4UXN20iB5P0BAPgh4
Sh5l18b0NPB:OWT4R7ag0hIjM@B4N7<4PGIa17mdK`AkLF/4N6eX17Q^JP=]IV84L6UT175ZIPAbK6L4
LV]V179/IPAbK6L3LfaV175[I0AbJV84KF=L171UG@AaIUl3LFMO179YH@AcJ5l4M6MO17ATF`AeHeX4
Mf9H0gQSFPAdG5@4JE1815m1>PAO?3<4H3X`0f8j;`AS>Rd4HcLX168b8`AP;A`4GbTG15dZ60=N;1d4
HS@V16Tm<0A^ASX4M4i317UFB`=oGU@4Q6IL18U]I0B>M6`4U7ad19V3N`BNRX<Eoooo000Doooo1:6?
R@BNSHL4Vhb619V:Q0BFQh83U8F01963OPB?PG`4S81j18YnN@B8O7L3QWYe18AhL`B1MW44OgA_17]a
J`AhKFP4N6iZ0feVHPA`JF@4LFYV179/I`AbJfH4LVaV179/I`=cK6H4LF]T179ZHPA]He`4L6EM175V
G`=aIel4LVUQ17=XG`AdIel4M6AK17ESFPAgHUP3N6=J17ALE0AYD4P4Gd4j15ll<`AP>S03HSX_16<j
;@AS=bP4HS8S160]70AO:AL4GBXH0eh/7@AR=2H4JCd`16i6>PAdCT<4NEI;0gmNE0B4IU`4RFeT18id
K0BDO7@4VH=k19j:PaGoool001Coool4X8n919j=Q`BKRhD4V8V319F7P@>BQGl4T89m18f0N`B;OWX4
R7eh18IkMP>4NG@4PWMc181fL@AnM6h4NFmY175WH@AbJVD3L6UU16mYIPQ`JFD4L6YU171/I`AbKVT3
LfmZ17EcK@AgMVl4Lg5Z171[I0A_JF83KfIN16mUGPA`I5`4L6=K171OEPAaG5@4L5YA0g9LDPAbEdh4
Ke=:16A7?`AK>S84GCP_0ehh;@AP>2/4HCDW15lb8`AN;Ad4GBTG15`X5`=L:aX4GRlQ16@i:`AZ@SD4
L4/o17ICB0=lFe44PV=I18M[HPB=LfX4Tg]b19R2N`BNRX<Eoooo000Doooo1:2?R@BNSHL4Vh^519R9
P`BEQh43TXEo1922O@B=P7/4Rgij18QmN0B6NgH3Q7Ud189gL`B0MW44OWA^17U_J@AaIf44LVYU0g1Y
I@A_JFH8L6UU171ZI@A`K6L4LViY0g=_JPAeLfd4MgI_17=aJPA`Jf@4KfUR0fmVGPA_IEh4L6AL171S
F`A`GeH4LEaD171JD@=bG584LUM>16mCBPATAcl4FcXb15dh;`=N>2d4H3P[164e9`AO<R<4GRdM15dY
5`AL:1L3G2/J15h_8@AT>B/4JT8e171;?`AfDdP3O5]A189SF@B7Jf84SG=Z19=kLPBHPW/4WXZ35Ooo
o`005?ooo`BPShT4WXf719^;Q@BHRH<4UHN10i:5O`B@PWd4SH1k18]nNPB8OGP4QW]f0hAiM0B2Mg<4
P7Ia17idKPAiKfT4LFMQ179ZI@=`JFD4KfUV271YI@A`JVD4L6aW179^J@=cKfX4MG=]17MfK`AcLFX4
L6]T16mYHP=_IUh4KfEN171TG0A`He/4L5mF175LE0A`FU43LUaB179GCPA_DdX4I4Lo15/j<PAM>2l3
GSP]160h:`AQ=BL4Gc8S15h]7@AM:AL4G2PG0e`[6PAN;b44I3T[16Y2=@A`Bcl4MU=80gaKD@B2HeT4
Qf]R18ecJPBCNg84V89k19j:PaGoool001Coool4X8n919f=Q`BJRhD4UhR319B6P@>AQ7l4SX5l18]o
N`B9OGT4QW]g18AjM@>2N7<4P7Mb17mfL@AoMG04OgEa17M_JPA`JfL3L6]X16iZIPA]JFH4KFUW16eZ
I`A^K6P4KfiZ0fm]J0A^JfH4KfiX16m^I`A^KFH4KVaU1fm/I0A`JV84L6UP171WGPA_I5X4KeiD0fiK
D@A_Edd4KU9816U<@PAO?cH4FSL^0e`g;0AN=b/4GcDW15ha8PAL;Ad4FbPH15LS4@=C8Q44FR`M160d
9`AW?S84KDLk17A@A@=jFDh4P65G18IYH0B<LFT4TWUa19N1NPBMRH8Eoooo000Doooo1:2?R@BMSHL4
VX^519N8P`BDQX43THAo18j1O0B;Og/4RGei18IkM`B4NWD3PWQc181gLPAoMW44OgE`17meL@AgKfX4
L6]W0g1[J0A^JVH4KFUV16eYI`A]JVL4KVaX16m^JP=_KFP4KV]V16m^J0A_KVL4KVeV16i/I@M_K6@4
L6YR171YH0A`Ieh4KfAJ16mNE0=^Fe44KeM=16iBB0AYC484Gclf15Xg;P=L=b`4GSL[15le9`AN<B84
G2dM15/X60AG8a43Db8A15X/7@AP=2L4Ichb16e7>`AdD4D3NUU>181QE`B6JF04S75Y199iL@BGPGX4
WHV25Oooo`005?ooo`BPShT4WHf719Z;Q@BGR8<4U8J10i64O`B>PG`4Rgmk18UmN@B6NgL4Q7Ye0h9h
L`B0Mg84OgIa17meL0AoMG44MfmZ171[I`=`JfP4KVYV16eYIPA]JFL4KFYW16i/J0A_KVX3KfeX16i[
IPA_KVP4KfiW16i]IPA^K6D7KfaT171ZHPA`JF04L6MN16mTFPA_GU@3KU]A16mGC@A^DTP4JDa215lo
=PAJ=bh3G3L/15hg:`AO=BL4GS4R15`]7@AK:1P4Eb<A0e<R4@AJ;1d4H3@W16Ln<PA]Ac/4M5150gYI
CPB0HEL4QVUP18aaJ@BBNG44Uh5j19f9PQGoool001Coool4X8n919f=Q`BJRhD4UhR319B6P@>AQ7l4
SX5l18]oN`B9OGT4QW]g18AjM@>2N7<4P7Mb17mfL@AoMG04OgEa17M_JPA`JfL3L6]X16iZIPA]JFH4
KFUW16eZI`A^K6P4KfiZ0fm]J0A^JfH4KfiX16m^I`A^KFH4KVaU1fm/I0A`JV84L6UP171WGPA_I5X4
KeiD0fiKD@A_Edd4KU9816U<@PAO?cH4FSL^0e`g;0AN=b/4GcDW15ha8PAL;Ad4FbPH15LS4@=C8Q44
FR`M160d9`AW?S84KDLk17A@A@=jFDh4P65G18IYH0B<LFT4TWUa19N1NPBMRH8Eoooo000Doooo1:2?
R@BMSHL4VXZ519J8P`BCQX43T8Ao18f1O0B:OWX4Qgah18AjMPB2N7@3P7Ib17ieL@AnMG04P7Qc18Mn
N@B5O7H4MW1/0fmZI`A/JFH4JfYV26]YI`A[K6T4KFiZ0fe]J@AZIf<4JVMQ16YXHPAZJF8;JfQR16aW
H0A/IUh4K6=K16]PF0AZGE@3JE]@16UICPAZEd`4JE=816A:@0AM?cD3FcT^15`g:`AM=BP4G38T15/^
7PAJ:QX4FRTH0e0Q4@AE:1T4GC8T16@k;PAZA3P4LDe20gMFC0AnGeD4Q6QN18Y`I`BAN704Uh5i19f9
PQGoool001Coool4X8n919f=Q`BJRXD4UXR319>6P@>@Q7l4SH5l18YnNPB7O7P4Q7Yf189hM0>0MW84
OWEa17ieL0B0N7<4Qgii18ElMPAfL6`3KfYW16aYIPA[JVH8JfUW16]/J@A]KVX3KFeY16YWH`AZIf44
JVQR16YYHP][J684K6MP16aVGPA/He/4Jf1H16YME0=YFe04JEU>16YGC0AYDdP4I4Y015do=@=K>Bh4
G3L[15de:0AL<R@4FbhN15XZ6PAJ:AP3D24A15DX6@AM<R@4I3/^16Y4>0AaCD83MeI<17iOE@B4J5h4
RW1W195hL0BGPGT4WHV25Oooo`005?ooo`BPShT4WHf719Z:Q@BFR8<4ThJ10i24O`B=PG`4RWij18Ml
N0B4NWH4PWQd0h1fLPAnMG44OWE`181hL`B7OWT4QGaf17I`K0=_JVL4K6UV16]ZIPQ[JFL4JfaY16e^
JP=]KFT4JVMS16YWH@AZJ684JVUR2f]XHPA/If04K6IN16aSF`A[H5P4JUeD0fUKD0AYFDh4JUM<16UC
B0ATBT04GCle0e/i;PAL=b/4GCDX15`b90AK;Qh4FRXJ15XY60=@8A44EBPI15db90AT>bh4JT@h175=
@P=gET`4OUmE18AXGPB:L6L4TGQ`19N1N@BMRH8Eoooo000Doooo1:2?R@BMSHL4VXZ519J8P`BCQX43
T8Ao18f1O0B:OWX4Qgah18AjMPB2N7@3P7Ib17ieL@AnMG04P7Qc18MnN@B5O7H4MW1/0fmZI`A/JFH4
JfYV26]YI`A[K6T4KFiZ0fe]J@AZIf<4JVMQ16YXHPAZJF8;JfQR16aWH0A/IUh4K6=K16]PF0AZGE@3
JE]@16UICPAZEd`4JE=816A:@0AM?cD3FcT^15`g:`AM=BP4G38T15/^7PAJ:QX4FRTH0e0Q4@AE:1T4
GC8T16@k;PAZA3P4LDe20gMFC0AnGeD4Q6QN18Y`I`BAN704Uh5i19f9PQGoool001Coool4X8n919b<
Q`BIRX@4UHN219:5P0>?PWh4Rh1k18QmN@B5NgL4PWQe17mfLP=mM744Ng=_17YbKPAkM6h4Ng=^17Qb
KPAaK6X3JfQU26QWI@AWJ6H4IfUW16QZJ0AYK6X3JF]X16MUH@AUHU`4IF=M16ITG`MWIEl4J6IP16UV
G`AXHe`4J5mH16MME@AVFU83I5M>16ADBPATDDL4HTe21617?0AM@CL3Fc/a15/h;@AK=BT4Fc4T15X^
80AJ:a`4FBTH0ddO4@AB9AP4FBhQ160h:`AW@SH4KT]00gEDBPAlGE<4PVIM18U_IPB@Mfl4UX1i19f9
PQGoool001Coool4X8n919b<Q`BIRX@4UHN219:5P0>?PWh4Rh1k18QmN@B5NgL4PWQe17mfLP=mM744
Ng=_17YbKPAkM6h4Ng=^17QbKPAaK6X3JfQU26QWI@AWJ6H4IfUW16QZJ0AYK6X3JF]X16MUH@AUHU`4
IF=M16ITG`MWIEl4J6IP16UVG`AXHe`4J5mH16MME@AVFU83I5M>16ADBPATDDL4HTe21617?0AM@CL3
Fc/a15/h;@AK=BT4Fc4T15X^80AJ:a`4FBTH0ddO4@AB9AP4FBhQ160h:`AW@SH4KT]00gEDBPAlGE<4
PVIM18U_IPB@Mfl4UX1i19f9PQGoool001Coool4X8n919b<Q`BIRX@4UHN219:5P0>?PWh4Rh1k18Qm
N@B5NgL4PWQe17mfLP=mM744Ng=_17YbKPAkM6h4Ng=^17QbKPAaK6X3JfQU26QWI@AWJ6H4IfUW16QZ
J0AYK6X3JF]X16MUH@AUHU`4IF=M16ITG`MWIEl4J6IP16UVG`AXHe`4J5mH16MME@AVFU83I5M>16AD
BPATDDL4HTe21617?0AM@CL3Fc/a15/h;@AK=BT4Fc4T15X^80AJ:a`4FBTH0ddO4@AB9AP4FBhQ160h
:`AW@SH4KT]00gEDBPAlGE<4PVIM18U_IPB@Mfl4UX1i19f9PQGoool001Coool4X8n919b<Q`BIRX@4
UHN219:5P0>?PWh4Rh1k18QmN@B5NgL4PWQe17mfLP=mM744Ng=_17YbKPAkM6h4Ng=^17QbKPAaK6X3
JfQU26QWI@AWJ6H4IfUW16QZJ0AYK6X3JF]X16MUH@AUHU`4IF=M16ITG`MWIEl4J6IP16UVG`AXHe`4
J5mH16MME@AVFU83I5M>16ADBPATDDL4HTe21617?0AM@CL3Fc/a15/h;@AK=BT4Fc4T15X^80AJ:a`4
FBTH0ddO4@AB9AP4FBhQ160h:`AW@SH4KT]00gEDBPAlGE<4PVIM18U_IPB@Mfl4UX1i19f9PQGoool0
01Coool4X8n919b<QPBHRX@4UHN21964P0>=PWd4RWmk18IlN0B2NGH4OgMc17adL@=iLVl4Mg1]17E^
J`AcKFX4LF]W16iWI0AZI683IV=R16ESHPATI684HfES16=VI0ASIfH4I6UW0fEXIPATIF84HV1L165N
F@ARH5/4Hf5L0fAQG0ATHUd4IF=M16EQF`ATGEL4I5YC16AHD0=RE4d4H599161>APAOBd84GDHm15]0
=P=J?384FCP^15Xf:PAJ<RH4FRlR15/]7PAL:a/3Bad>14hQ4PAF:ad4GCDX16Do<`A/BCh3Le9817YK
DPB1I5/4R6iU18mfK`BFOgP4W8R15Oooo`005?ooo`BPShT4W8b619R:Q0BEQh84THB00hf2O@B:Og/4
QWah189iMPAoMg<4O7Aa0gUbK`AgL6d4MFi[17=]JPAaJfL4KVMT16YTHP=VHf84IF=R16ATHPASIF<4
HfIT16=WIPATJFL3IFQV16AUHPARH5`4HEiI169PF`ASHE`3I65L16ARG@AUHed4IF5K16AME`ATFU<4
I5Q@0f9DC@APDTT4H4i615m;@PAMASd4Fd0f0eXl<PAI>2h4FSHZ15Xb9PAJ;b84FbdN15`[6`=;7@h4
CR4B15H[7@AM=BP4IClc16a9?P=cDTP4NU]B185TF`B8KVD4SgI_19IoN0BLR84Eoooo000Doooo1:2?
R@BLS8H4V8Z419F7PPBAQ803SH9m18YoN`B6O7P4PWUf17mgL`AlM743NG9_17M`K@AeKV/4LfeZ175[
I`A^If@4JVAR0fISHPAUHf84I6AR16=UH`ASIV@4HfMV16AYI`=UJ6H4I6ER169PG0AQGUT4HV1K16=Q
G0=THE`4I69M16ESG@AUHE/4I5eG16AJD`ATF503HUA=161BB@APCTH4Gd]215e6?@AK@3H3FS`b15Th
;PAJ=RX4FS8V15X_8PAK;Ah4G2/K0d/M3PA>8A84ER/M15de:0AU?c<4K4Tn0g=BB0AjFe84PFAK18Q^
I@B?MVl4UWmh19b8PAGoool001Coool4X8n919b<QPBHRX@4UHN21964P0>=PWd4RWmk18IlN0B2NGH4
OgMc17adL@=iLVl4Mg1]17E^J`AcKFX4LF]W16iWI0AZI683IV=R16ESHPATI684HfES16=VI0ASIfH4
I6UW0fEXIPATIF84HV1L165NF@ARH5/4Hf5L0fAQG0ATHUd4IF=M16EQF`ATGEL4I5YC16AHD0=RE4d4
H599161>APAOBd84GDHm15]0=P=J?384FCP^15Xf:PAJ<RH4FRlR15/]7PAL:a/3Bad>14hQ4PAF:ad4
GCDX16Do<`A/BCh3Le9817YKDPB1I5/4R6iU18mfK`BFOgP4W8R15Oooo`005?ooo`BOShT4W8b619R9
Q0BDQX84T8Ao0hb1O@B8OWX4Q7]g181hM@AlMG84NG9_0gE_K0AbK6X4KfYW16aWI0AZI684IV5O16AO
G@=QGeh4H5iN15mOGPAOH604GV9Q15mSHPAOIF<3H6ES161SH0ANGe/4GE]G15iMF0AOGeX3H61K165P
G0ARHE`4HUmJ169ME`AQFE<4H5I@0eiBC0AMCdP4Fd]515]9@PAKASh4FD4i0ePm=0AG>Bl4F3H[15Pc
9`AI<2<4FblP15l_7P=>8104BA`>158W6PAK<RH4HSda16Y7?0=aD4H4N5Y@17mSFPB6K6@4SWI^19Eo
M`BLR84Eoooo000Doooo19n?R@BLS8H4V8V419B6PPB@Q7l3S85m18QnNPB4NgL4P7Qe17aeLPAiLVl3
MFm/179/JPA_JVL4K6MT16YTHPAVHEl4I5mM0f5OGPAPGUh4GemN15mPH0ANHV44Gf=R15mUH`=PIF<4
H6=P15iOF`AMFeL4GUeH15mOFP=PH5/4HF1L169QG0ARGeX4HUeG165ID`APEU03GU9<15e?B0AKBdD4
FdU215]6?PAI@CT3F3dd15Li;`AH=R/4F3<W15T`8`AK;b04GblN0dhP40A970h4DRLJ15/b9PAR?C44
JTLl0g5@APAhFU04Of=J18I/I0B>MVh4UGmg19b8PAGoool001Coool4Whn919b<QPBHRH@4U8J21924
O`><PGd4R7ij18AkM`B0N7D4O7Eb17UbK`=eKf`4LVaZ16mZI`A/If@4JVAR16IQG`ATGed3HEmN161N
GPAOGeh4Gf1P15iRH@AOHf84GfES0f1UH`APHf04GUmK15eKE`ANGEP4GemJ0f1PF`AQH5`4HV5L169O
FPARGEL4HEUC161FD0=NDT`4GDm815];A@AKBD84FdHn15U1>@=H?C@4EcT_15Pf:`AH<bL4FC0S15/_
80AO;ah3CR0@14TL3PAB9aX4Fc8V168m<@AZAc`3LE1617QJD0AoHeX4QVaT18ifKPBEOgL4W8R15Ooo
o`005?ooo`BOShT4W8b619R9Q0BDQX84T8Ao0hb1O@B8OWX4Q7]g181hM@AlMG84NG9_0gE_K0AbK6X4
KfYW16aWI0AZI684IV5O16AOG@=QGeh4H5iN15mOGPAOH604GV9Q15mSHPAOIF<3H6ES161SH0ANGe/4
GE]G15iMF0AOGeX3H61K165PG0ARHE`4HUmJ169ME`AQFE<4H5I@0eiBC0AMCdP4Fd]515]9@PAKASh4
FD4i0ePm=0AG>Bl4F3H[15Pc9`AI<2<4FblP15l_7P=>8104BA`>158W6PAK<RH4HSda16Y7?0=aD4H4
N5Y@17mSFPB6K6@4SWI^19EoM`BLR84Eoooo000Doooo19n>R0BKS8H4UhV419>6P@B?Pgl3Rh1l18Im
N@B2NWL4OWId17UcL@AeL6d3LFaZ16eYI`AYIF@4IF5O169NG0ANFeX4GE]J0eaKFPAKFeX4FU]K15YL
G0AJGEd4FUiN15YOG`=JH5l4Ff1N15YMF`AIFUH4FUYF15]KE`=LG5P4GUeI15mMF@AOG5L4GUUD15eF
D@ALE4h3FU5:15U=APAGBD84ETI015I3?@AF@3P3ECdd15Di<0AE=R/4ES<X15La9@AK<284HS<S0ed/
6`A>8144CB8E15Ta90AQ>c04J4Dj0fm?A@AfF4l4OV9I18E[H`B=MFd4U7ig19b8PAGoool001Coool4
Whj819^<QPBGRH@4ThJ118n3O`>;P7`4QWei189jM`AnMW@4NG=a17E`K@=aK6X4KFUW16UUI0AUHEl4
HUiL15iKFPAMFeX3G5]J15]KFPAJFe/4FUaL15YMG@AJGUh4FUmO0eYPG`AKH5h4FUeK15UJEPAJFUH4
Fe]G0eaLF0ANGET4GeeI15mLE`ANFE@4GEIA15aDCP=JDDX4FDe615M9@PAFAT04ET<m15I0>0=E?C@4
ECT`15Df:`AF<bP4Ec4U15/`8PAR<b<3GB`K14hP4@A=8QD4FC4T164k<0AXACX3Kdm517IHC`AnHUT4
QF]S18eeK@BDOWL4W8R15Oooo`005?ooo`BOSXP4Vhb619N9Q0BCQX44Sh=o0h^0O0B6OGT4PWYg17if
M0AiLg44MG1]0g5/JPA]JFL4JFET16EQG`ARGU`4GU]J15eKFP=LFeX4Fe]J15YKF`AJG5`4FUeM15YN
GPAJGel3FV1O15]PGPAJGE/4FEYF15YJEPAKFeL3G5aH15iMF@AOGET4GeaG15iIE0AMEU44G5A>0eYA
BPAICDH4EdU215I6@0AF@cd4ET0h0eDm=0AE>C04ECH[15Hc:0AG<BD4Fc0R168c8`=M;1/4CR0A14dR
5@AI<B@4HC/`16Q5>P=_CdD4MUQ?17iRF@B5Jf<4SGE]19AnM`BLR84Eoooo000Doooo19n>R0BKS8H4
UhV419:6P@B>Pgh3RGml18ElN@B0NGH4NgEc17IaK`AaKF`3K6UX16MUI0ASGel4GUUI15]FE`AGEEDC
EEMG15AHF0ADFET7EEYJ15EKFPAFFUT4EEQF15IHE@AGF5D3F5QE15YJEPAKFEH4FeUD15YED@AHDTh4
Edm;0eE=B0ACBD@4DTI01594?@AA@3X4DShf0e8j<PAA=bh4DS@Z158a9`AD;b<4ERdQ15X_8P=L;b44
FbhO15L/80AI<BD4GcX_16I3>@=]CD<4M5M=17aPF0B4JV84S7A/19=nMPBKQh4Eoooo000Doooo19n>
R0BKS8H4UhV419:6P@B>Pgh3RGml18ElN@B0NGH4NgEc17IaK`AaKF`3K6UX16MUI0ASGel4GUUI15]F
E`AGEEDCEEMG15AHF0ADFET7EEYJ15EKFPAFFUT4EEQF15IHE@AGF5D3F5QE15YJEPAKFEH4FeUD15YE
D@AHDTh4Edm;0eE=B0ACBD@4DTI01594?@AA@3X4DShf0e8j<PAA=bh4DS@Z158a9`AD;b<4ERdQ15X_
8P=L;b44FbhO15L/80AI<BD4GcX_16I3>@=]CD<4M5M=17aPF0B4JV84S7A/19=nMPBKQh4Eoooo000D
oooo19n>R0BKS8H4UhV419:6P@B>Pgh3RGml18ElN@B0NGH4NgEc17IaK`AaKF`3K6UX16MUI0ASGel4
GUUI15]FE`AGEEDCEEMG15AHF0ADFET7EEYJ15EKFPAFFUT4EEQF15IHE@AGF5D3F5QE15YJEPAKFEH4
FeUD15YED@AHDTh4Edm;0eE=B0ACBD@4DTI01594?@AA@3X4DShf0e8j<PAA=bh4DS@Z158a9`AD;b<4
ERdQ15X_8P=L;b44FbhO15L/80AI<BD4GcX_16I3>@=]CD<4M5M=17aPF0B4JV84S7A/19=nMPBKQh4E
oooo000Doooo19n>R0BKS8H4UhV419:6P@B>Pgh3RGml18ElN@B0NGH4NgEc17IaK`AaKF`3K6UX16MU
I0ASGel4GUUI15]FE`AGEEDCEEMG15AHF0ADFET7EEYJ15EKFPAFFUT4EEQF15IHE@AGF5D3F5QE15YJ
EPAKFEH4FeUD15YED@AHDTh4Edm;0eE=B0ACBD@4DTI01594?@AA@3X4DShf0e8j<PAA=bh4DS@Z158a
9`AD;b<4ERdQ15X_8P=L;b44FbhO15L/80AI<BD4GcX_16I3>@=]CD<4M5M=17aPF0B4JV84S7A/19=n
MPBKQh4Eoooo000Doooo19n>R0BKRhH4UXR419:5P@B=PWh3R7ml18=kN@AnN7D4NGAb17=`KPA]JfX3
J6MV169RH`AMGEh4F5QI15=CE0AADE84D59C3e1CE0Q?De@7CeAD151DE0A@De<4D5AC159EE0ADEeD3
EEQF15MIEPAHF5H4F5MD15MDD0AED4d4DTe90e5:A`A@B4<4CT@o14e0>`A<?CL4CC/d0ddh<@A==Bd4
CC8Y14h_9PA>;2<4D2XP158[7`=B:1X4DBDG15<Y7@AG<2@4GCP]16=1=`=[Bd84LUE<17YOE`B2JF44
Rg=/19=mMPBKQh0Eoooo000Doooo19n>R0BKRhH4UXR419:5P@B=PWh3R7ml18=kN@AnN7D4NGAb17=`
KPA]JfX3J6MV169RH`AMGEh4F5QI15=CE0AADE84D59C3e1CE0Q?De@7CeAD151DE0A@De<4D5AC159E
E0ADEeD3EEQF15MIEPAHF5H4F5MD15MDD0AED4d4DTe90e5:A`A@B4<4CT@o14e0>`A<?CL4CC/d0ddh
<@A==Bd4CC8Y14h_9PA>;2<4D2XP158[7`=B:1X4DBDG15<Y7@AG<2@4GCP]16=1=`=[Bd84LUE<17YO
E`B2JF44Rg=/19=mMPBKQh0Eoooo000Doooo19n>R0BKRhH4UXR419:5P@B=PWh3R7ml18=kN@AnN7D4
NGAb17=`KPA]JfX3J6MV169RH`AMGEh4F5QI15=CE0AADE84D59C3e1CE0Q?De@7CeAD151DE0A@De<4
D5AC159EE0ADEeD3EEQF15MIEPAHF5H4F5MD15MDD0AED4d4DTe90e5:A`A@B4<4CT@o14e0>`A<?CL4
CC/d0ddh<@A==Bd4CC8Y14h_9PA>;2<4D2XP158[7`=B:1X4DBDG15<Y7@AG<2@4GCP]16=1=`=[Bd84
LUE<17YOE`B2JF44Rg=/19=mMPBKQh0Eoooo000Doooo19n>R0BKRhH4UXR419:5P@B=PWh3R7ml18=k
N@AnN7D4NGAb17=`KPA]JfX3J6MV169RH`AMGEh4F5QI15=CE0AADE84D59C3e1CE0Q?De@7CeAD151D
E0A@De<4D5AC159EE0ADEeD3EEQF15MIEPAHF5H4F5MD15MDD0AED4d4DTe90e5:A`A@B4<4CT@o14e0
>`A<?CL4CC/d0ddh<@A==Bd4CC8Y14h_9PA>;2<4D2XP158[7`=B:1X4DBDG15<Y7@AG<2@4GCP]16=1
=`=[Bd84LUE<17YOE`B2JF44Rg=/19=mMPBKQh0Eoooo000Doooo19n>R0BJRhH4UXR41965P@B<PWh3
Qgmk189kN0AlMgD4MW=a171^KPAZJFT3HfAT15]OG`AEFU/4CeAE14Y>D0A9C4l4BDe?0dY>D0A:Ce44
BdmA14]?D0A:Cdl8BDi?0dU=C`A9CTl4BTe>14]>CPA=D504Ce=B0e9EE0ADEeH4EUME15IED`ADDU04
DTm<151;B0==B4D4BdA014U0?0A8?3P4B3Xd14Lg<@=8=Bh4B3<[14P`9`A8;B@4B2XQ14TW7@A;9a`3
Bb<G14TN4@A<8QH4DR`Q15Te:`AP?cH3J4U0171DB`AiGUH4PFQP18UbJ`BBOGH4VhN05Oooo`005?oo
o`BOSXP4VX^619J8Q0BAQH44S89n0hMoN`B2NgP4O7Me17IcL@A`KVh4JVUY0f=TI0AKGel4EEYK14mD
E@A:CU04BDa?14U=C`=:CU04BTmA14]?D@A;Ce04BTm?24U>C`=9CDl4BDi?14Y=CPA;CTh4CE1@14mC
DP=BEE@4E5MF15IGE@AFEE<4E59@159?C0A@BdP3CDQ514]4@0A9@3`4B3`h14Pj=0A7=c43B3D^14Pc
:`A8<2L4B2dT14PZ8@A99ad4BbLL0d/S5`A97Q44C28F158/8@AI=B/4H3lf0fQ9@0A`E4/4NEiF185X
H0B9LV/4TWef19^7P1Goool001Coool4Whj819Z;QPBFR8@4THF118b2OP>7Og/4PW]h17agM@AfLg44
L6i^16YYJ@=SI6@4FemO15EJF`A?E5D4BTi@14U<C`A9CDl3BTi@14Y?D@A;Ce44Bdm@14Y?C`Q9CTl3
BDe?14U>C`A:CDh4Bdi>14e@D0A?De83DUED15AGEPAFEeD4EUEC15ABD0ABCd`4D4]80de8A@A;A404
BD0l14Pl>0A8>S@4AcLa0dPe;PA8<b/4B30W14P]90A8:R44BBLM14/W70=;8aL4BAhA14`R5PAB;244
FCD[160o=P=XBD04L5A;17UNEPB1J604RG9[199mMPBKQh0Eoooo000Doooo19n>R0BJRhH4UXR41965
P@B<PWh3Qgmk189kN0AlMgD4MW=a171^KPAZJFT3HfAT15]OG`AEFU/4CeAE14Y>D0A9C4l4BDe?0dY>
D0A:Ce44BdmA14]?D0A:Cdl8BDi?0dU=C`A9CTl4BTe>14]>CPA=D504Ce=B0e9EE0ADEeH4EUME15IE
D`ADDU04DTm<151;B0==B4D4BdA014U0?0A8?3P4B3Xd14Lg<@=8=Bh4B3<[14P`9`A8;B@4B2XQ14TW
7@A;9a`3Bb<G14TN4@A<8QH4DR`Q15Te:`AP?cH3J4U0171DB`AiGUH4PFQP18UbJ`BBOGH4VhN05Ooo
o`005?ooo`BOSXT4VX^619J8Q0BAQH44S89o0hInO0B1NgP4NgIe17AbL@A^KFd4IfQY0emRI0AEFEX4
BU5C149;C`@oAd/4@4M;1499C0=4BTd4AD]>24I<CPA6C4d4A4]=14=:C0=2B4/4@dQ;14A9BPA5BTX4
B4e=14]@C`=>De84DEID15=GE@ACE584DE5?14m<BPA<B4H3BDA214I0?@A4?3T4@SPe148f<PA2=2l3
@S8]148a:PA2;RL4@R/S14<W7`A291/4@b8H0d<M4PA46`l4AQ`@14hX7@AE<RT4GCdd0fE7?`A^DTX4
MeaE17mWH0B8LVX4TGae19Z7P1Goool001Coool4Whj919Z;QPBFR8@4THF118b2O`>6OW`4PG]h17]f
M@AdLW44KVe]16MXJ@=OHV@4EEUJ14YAD`A2Bdl4?dM;1417B`A2BD`3A4Y=14E;CPQ6C4h4ATa=14A;
C@A3BT`3@TQ;14=8B`A4BDX4ADY:14Q=C@A;D4l3CU=B155FE0ACEeD4DeAB155AC`A?C4X4C4Q60dU4
@PA6@3d4A3`i148h=@A2=S84@S@_0d8b;@A2<BX4@RhW148[8`A39al4@R@K14<R60=37A84A1/?14HL
40A>:1d4EC8Y15dm=0=UAcl4KU9:17MLE@AoIf04R79Z195lM@BJQh0Eoooo000Doooo19n>R@BJRhH4
UXR41965P@B<PWl3QWil185kN0AkMWD4M79a16i]K@AWJ6T3Gf9T15EIFPA:DE<4@T]?13m7B`A0Ad/4
@TU<0dA:C@A5Bdh8ATa>14I<C@A4Bdd4@dY<0d98B`A3B4/4A4U:14E:BPA8CDd4Be1?0diCDPAAEU@4
DeME15=DDPAADDl4Cda:14a8AP=9A484AT0m14@l>@A2>3D4@SHb148d;`=2<Rd4@S4Z148^9`A2:b<4
@bLO148T6`A38QP3@adB14@K3`A67104CRPM15Db:@AM?C@3IDLo16iBBPAgG5D4OfMP18QbJPBAO7D4
VXN05Oooo`005?ooo`BOSXT4VX^619J8Q0BAQH44S89o0hInO0B1NgP4NgIe17AbL@A^KFd4IfQY0emR
I0AEFEX4BU5C149;C`@oAd/4@4M;1499C0=4BTd4AD]>24I<CPA6C4d4A4]=14=:C0=2B4/4@dQ;14A9
BPA5BTX4B4e=14]@C`=>De84DEID15=GE@ACE584DE5?14m<BPA<B4H3BDA214I0?@A4?3T4@SPe148f
<PA2=2l3@S8]148a:PA2;RL4@R/S14<W7`A291/4@b8H0d<M4PA46`l4AQ`@14hX7@AE<RT4GCdd0fE7
?`A^DTX4MeaE17mWH0B8LVX4TGae19Z7P1Goool001Coool4Whj919Z<QPBFRH@4THJ218^2O`>6Og`4
P7]i17UfM@AcLG44K6e]16EXJ@=MHfH4DeUL14E>DP@kAT`4=3m613Q2B0@lADX3?dQ;1459C0Q2BTd4
@DY=13m9B`@nAdX3?4A713a2A@@m@T@4?dA614=8B@A8CDd3Be5A14mDD`A@EE@4D5=B14i?CPA<BTP4
B4E30dE1?`A1?3X4?SPe13dd<P@l<Rh4?30/0cd_:P@m;BL4?B/U13dY8P@m9Ah4?24I13`P5`<k6A04
?1P>140I3PA891/4DBlV15Tj<P=RACd4Je1917AKE0AnIUl4Qg5Z191lM@BJQX0Eoooo000Doooo19n>
R@BJS8H4UXV41966PPB;PWl3QWml181kN@AiMWD4Lg5a16a]K@AUJ6T3GF=V15=IG0A5CU84>dI<13@o
AP@h@TP4?4E:0cm8B`A1BD`8@TY=145:C@@oBD/4?TM:0ca4A`@l@TD4?D9413m4APA3B4T4B4e=0d]A
D@A?E5<4D5ED151CDPA>Cdh4C4Y814Q5@`=5@Cl4@C`j13hh=@@m=384?38^13``;0<m;bX4?BdW13d[
9@@m:B84?BDN13`Q6@@l81L3>aT@13`H3PA06@h4B2@K154_9PAI>S83HTDm16]@B@AdFe@4OVIO18Ma
JPB@O7D4VXJ05Oooo`005?ooo`BOSXT4VXb619J9Q0BAQX84Rh9o0hIoO0B0NgT4NGIe17=aL@A/KFd4
IFQY0eeSIPACFE`4ADiB13]6C0@d?dH4>49813a5BP<oB4/4@DU<249:C@A1BTd4?dU;13i7BP<lA4L4
?49513e2A0@oA4H4@dQ914Q=C@=;DE44CeAC151EE0A@De84CTm>14a:B0A8AD<3AD4o144l>P@n>3D4
?C@b13`b;P@l<2`3?BlZ13d]9`@m:bD4?BTR13dU7P@l8AT4?20G0c/I40@l60h4@1T>14PT6`AA;bH4
FCXb0f95?@A[D4T4M5]D17iVG`B7LFX4T7ae19Z6P1Goool001Coool4Whn919Z<Q`BFRHD4THJ218b3
P0>6Ogd4P7]i17UfM@AaLG44JVa]169WJ@=LI6P4EUeR14M@E@@hAD/4;Sa4138oA@@g@dP3>TE:13i8
C@@oBDd4?TQ;13e6B@@i@dH4=T550c@oA0@e?T<4=ci213Xo@P@nA4D4A4Y<0dU@D@A=E5@4CeEE14mC
DPA=Cdd4BDU814E4@P=1?Sd4?3Xh13Te<`@g<Bl4=bl]13H]:P<h;2P4>BXV13PX8`@h9R04>2<M13LP
6@@g7AH3<aH?13@C2`@i5@`4@b4I14`]9@AF>303Gd<l16U?A`AbFU<4O6EN18I`J@B@Ng@4VHJ05Ooo
o`005?ooo`BOShT4VXb719J9Q@BAQX84S8>00hIoO@B0NgT4NGIe175aL@AZK6d4HVMY0eaTJ0AFGF84
Ae1E13Q5B`@^?4@4<Sm513M3B0<jADX4?TQ=13m9C@@nB4/4?DI913U3AP@f@DD3=3m413Dn@`@g?T84
>Sm213i4A@A4BT`3BE1A14eDE0A?EED4Ce=B14e?C@A9BDP4ADA20d4n?@@l>SP4>CDc13La;`@g;bd4
=RdZ0cP/:0@i:RH4>2PS13PV80@h8ad4=b0I13LM5P<c5Pl4=1<;13TE30A38AT4C2dU15Hh<0=O@c`4
JDm7179JD`AlIEh4QW1Y191kM0BIQX0Eoooo000Doooo19n?R@BJS8L4UXV51966PPB<Ph03QWmm181k
N@AiMWD4LG5a16Y/K@ARIfT3G6AX15IMHPA7D5D4>4E;12hlA0@b?dD4=d=80cY5BP@nB4d4?dU=13i8
B`@mATT4>D=613I1A@<d?d@4=Ci313Ln@P@j?d84?TA514A:C0=9D544CEAD14mEE@A?De84CDm=14U9
B0A5A483@Chm13`j>0@i=C<4=c4_13L_;@@f;BX3>2`X13TZ9P@h:2<4>2HP13PS7@@g81T4=adF0c<F
3`@d4`/4>AD<14<Q6@A<;BD4ESP`0em3?0AYCdL4LUYC17aUGPB6L6T4T7]d19V6P1Goool001Coool4
Whn919Z<Q`BFRHD4THJ218b3P0>6Ogd4P7]i17UfM@AaLG44JVa]169WJ@=LI6P4EUeR14M@E@@hAD/4
;Sa4138oA@@g@dP3>TE:13i8C@@oBDd4?TQ;13e6B@@i@dH4=T550c@oA0@e?T<4=ci213Xo@P@nA4D4
A4Y<0dU@D@A=E5@4CeEE14mCDPA=Cdd4BDU814E4@P=1?Sd4?3Xh13Te<`@g<Bl4=bl]13H]:P<h;2P4
>BXV13PX8`@h9R04>2<M13LP6@@g7AH3<aH?13@C2`@i5@`4@b4I14`]9@AF>303Gd<l16U?A`AbFU<4
O6EN18I`J@B@Ng@4VHJ05Oooo`005?ooo`BOShT4Vhb719J:Q@BAQh<4S8B10hJ0OPB0O7X4N7Mf171a
L@AWJf`4GfEX0eUQI0AAFUl4@4aC13=2BP@Y>T<4;Se513=1B0<hA4X4>dQ=141<D@A1CE44@4a@13a9
C@@fA4T3<415130n@P@c?T84=Se113Y0@`A2BD/3B51A14aEEPA?EUL4CeAD14a?C`A8BDP4@d910d0n
?@@l>CP4=c<b13<^;@@b:bX4<BTW0c8Y9P@d:2@4=2HQ13<T7`@b8Q`4<alI13<M5`<`6184;a<<13@B
2`@n7aL4B2XS154f;`=L@C/4ITe6171HDPAjI5d4Q6mY18mkM0BIQWlEoooo000Doooo19n?R@BKS8L4
UXZ51967P`B<Q843QX1n181lNPAhMgH4L75a16M[K0AOIFP3FF5T155JG`A0C5<4<d9:12Tj@`@^?DD4
<d580cQ4BP@kB4d4@4aA145=D@A0C504?4U=13I4B@<`@4D4<3i213<n@P@f?D44>T131499B`=8D544
C5EF14mFE`A?E5@4C4m?14Q9B0A3@T43@3hm13`i>0@g<c84<bh]138[:P@a:BL3<RTV13@X90@d9R44
<b@O138R70@c7aT4<adG0c0H4P@_4``4=18;13hO5`A8:R<4DCH_0ea1>`AVCDH4L5QB17YTG@B4KfT4
Sg]d19V6OaGoool001Coool4Whn919^<Q`BFRXD4THN318b4P@>6P7h4P7aj17QgMPA`LG44If]/15mU
J0=IHF@4DEYO141<D`@c@TX4:CY312hmA@@c@DP3>4A:13]8C@A0C544@DeA141<D0@lBDd4=TA90c10
A@@`?T84<ci213Hm@@@j@4<4@TU;0dQ@D@A<EEH4CeIG14mDE0A<Cdl4B4U814=2@@=0?Sd4?3Th13Lc
<P@c;Rd4<R/Z134Y9`<b:BH4=2PT13@V8@@c91l4<R8L13<O6@@c7AL3<1PB12lC30@d4P/4?QlG14PZ
8`AA=Rl3G44k16I=APA`F584NVAM18A_J@B?Ng@4VHIo5Oooo`005?ooo`BOShT4Vhb719J:Q@BAQh<4
S8B10hJ0OPB0O7X4N7Mf171aL@AWJf`4GfEX0eUQI0AAFUl4@4aC13=2BP@Y>T<4;Se513=1B0<hA4X4
>dQ=141<D@A1CE44@4a@13a9C@@fA4T3<415130n@P@c?T84=Se113Y0@`A2BD/3B51A14aEEPA?EUL4
CeAD14a?C`A8BDP4@d910d0n?@@l>CP4=c<b13<^;@@b:bX4<BTW0c8Y9P@d:2@4=2HQ13<T7`@b8Q`4
<alI13<M5`<`6184;a<<13@B2`@n7aL4B2XS154f;`=L@C/4ITe6171HDPAjI5d4Q6mY18mkM0BIQWlE
oooo000Doooo19n?R@BKSHP4Uh^619>8Q@B=QH<3R8:0185mO0AiN7P4Kg5b16AYJ`AKHfL3EUiR15=L
H0A4D5L4<d=<12Hi@`@[?DH4<4590cE4B`@iB4l4?TeC14ABF0A8E5T4BUEJ14AAE@<lBe04=dM<13Q8
C@@lBDd4?TQ<14=<CP=8DE@4C5IH14mGF@A?EEH4C4m@14Q9B@A0?d03?C`l13Lf=P@a;c04;B/Z12dY
:0@/9RD3;BDS130U8P@a9244<B8N12lP6`@^7AT4;1XF0bPE4@@X4Pd4;Q4<13TM5`A3:284CC@^0eQ0
>PASBdD4KUMA17QSG@B3KfP4SWYd19V6OaGoool001Coool4Whn919^=R0BGRhH4ThR518f5P`>8PX04
PGel17UhN0A_LG84I6U[15]SI`=FGV84DeaP14A@E`@c@d`49SU312/mAP@`@DT3=DA;13U8C`@nCE<4
A59H14QDF@A:EEX4A55E0ca;D0@gAd`4>4Q=13a9C@@nB4`4@da>0dQAE0A<EUP4CeMI14mEEPA<Ce04
B4U9140o@0<m?3`4=cHf134_<0@]:bX4;BTX12`V9@<]9B<4<2DR134T8@@a8Qh4;b0K12hM6@@/6QH3
:1DA12PB3@@^4@`4>AdG14<X8PA==2h3F40j16=;A@A^Ee44N6=M18=_J0B>NW@4VHIo5Oooo`005?oo
o`BOShT4Vhf819N;QPBCR8D4SHF30hR2P0B1OG`4NGQh16maLPATJF/4Ff=W0eINHPACG604A51G13=3
C0@V>D<4:ce61311B@<eA4/4>DQ?13i=D`A4DUP4B5AI14YEFPA4DED3?4]@13M7C0@hB4d4?4U=13i8
C0A3C4h3B55D14aFF0A?EeT4CeEF14a?D0A8BDT4@3m00cdl?0@g=SH4<Bl`12d[:P@]:BP4;2HU0bdU
8`@`9B84<B@Q134R7P@_81/4;QdI12`J5P<X5A44:18=12hA30@i7AL4@bPR14dd;P=H@3X4Hd]516iG
D@AhHed4PfmX18ijM0BIQWlEoooo000Doooo19n?R@BKSHP4Uh^619>8Q@B=QH<3R8:0185mO0AiN7P4
Kg5b16AYJ`AKHfL3EUiR15=LH0A4D5L4<d=<12Hi@`@[?DH4<4590cE4B`@iB4l4?TeC14ABF0A8E5T4
BUEJ14AAE@<lBe04=dM<13Q8C@@lBDd4?TQ<14=<CP=8DE@4C5IH14mGF@A?EEH4C4m@14Q9B@A0?d03
?C`l13Lf=P@a;c04;B/Z12dY:0@/9RD3;BDS130U8P@a9244<B8N12lP6`@^7AT4;1XF0bPE4@@X4Pd4
;Q4<13TM5`A3:284CC@^0eQ0>PASBdD4KUMA17QSG@B3KfP4SWYd19V6OaGoool001Coool4X8n919b=
R0BHS8P4U8Z618n8Q@>:QH<4Ph1o17]jNPA`LW<4H6EW14mGG0=>FEh4CUQN149?E`@a@dd48cQ312Pl
AP@^@4T3<dA<13M7C`@lC5<4@U9I14MFG0A>Ff04DEeR0deJG`A6E5P4@E1E141>DPA1C504A4iA0dQB
E@A<EUT4D5QK155HF@A@E5D4Ce9B14Q9B@=1@T@4>CXk130a<`@^;2h4:RPY12LS90<Y8b<4;2<Q130T
8@@_8al4;B0L12/L60@W61@37a4>11l=2@@W3PT4<aXE13hU80A9<B`3E3hh161:A0A[EU04Mf9L189^
J0B=NW@4V8Eo5Oooo`005?ooo`BPShT4W8f819R<R0BDRXH4ShR50hZ5P`B3P7l4NgYj171bL`APIFL4
CeML0diIGPA>F5h4@TmG1353C@@S>4<4:3a612i0B@<cA4`4=dM?13a<D`A2DUT4AeIL14iKH0AAGF83
CEYO14IDF0A1D5D4@4iB145<D0A4CU43B59E14aFF@A@F5/4DEQI151DE@A?DU84B4U90d52A0@i>S/4
<34c12h/;P@Z:2T49b<T0bTS8`@/8b44<2@Q12lS7`@]81`4:a`H12LH50<O4@h47`d912L>2@@c6QD4
?RDP14Ta;0=D?SP4H4Y416]FD0AgHU`4PViX18ejM0BHQGlEoooo000Doooo1:2?R@BLSHP4V8b819B:
QPB?R8D3RXF318>0O`AkNWX4L79c161UI`A?Ee`3CUUN14iHGPA2CeL4<D==12<h@`@X?4H4;T190c=4
C0@gAdl4?4aC149BF@A7EU`4CU]P155MHP==FUl4AUAH145@E@A0CU84@Da@14A>D@=8DUD4C5II151H
F`AAF5T4D5AE14mBDPA8BDT3@D9413Tj>`@`<C<4;R`^12XX:@@W8b@3:B<S12`S8@@`9244;b<O12dP
70@[71P49aPD0alA3P@O3@T49`h913<J5@@n9B04BC4/0e@n>0APBT@4JeI@17MRG0B2KVP4SGYd19R5
OaGoool001Coool4X8n919b=R0BHS8P4U8Z618n8Q@>:QH<4Ph1o17]jNPA`LW<4H6EW14mGG0=>FEh4
CUQN149?E`@a@dd48cQ312PlAP@^@4T3<dA<13M7C`@lC5<4@U9I14MFG0A>Ff04DEeR0deJG`A6E5P4
@E1E141>DPA1C504A4iA0dQBE@A<EUT4D5QK155HF@A@E5D4Ce9B14Q9B@=1@T@4>CXk130a<`@^;2h4
:RPY12LS90<Y8b<4;2<Q130T8@@_8al4;B0L12/L60@W61@37a4>11l=2@@W3PT4<aXE13hU80A9<B`3
E3hh161:A0A[EU04Mf9L189^J0B=NW@4V8Eo5Oooo`005?ooo`BPT8X4WHn:19Z>RPBFS8T4TX^80hf8
QPB8QH@4P82017AfM`AUJfd4D5aQ0dABF@A3DEP4>d]D12m2C@@R>4@49ca712a0BP<aA4h4=DE?13U:
DP@oD5P4A5IN14UJH@A:FV83BEUQ14IGGPA3DeT4@E1F149?E0A4D5@3B5=G14aGF`A@FEd4DUYL159G
F0AAEE@4D4m>0e1=C0A>BDP4?chn13Xf=P@f<S<4<2`/0c0Z:P@`:2L4<BHT12lS8@@/8Ah4:QdJ128E
4`<K3``460L511l81@@/5Q84>28N14D_:`=A?3L4GDQ416UED0AeHE`4PFeX18aiM0BHQGlEoooo000D
oooo1:2@RPBMShX4VXj:19J<R@BBRhP3SHR618R5Q0B0P804M7Ig16E[K@A@G643A59I14=AF0@kBe@4
;d9=128hA0@W?4L4;41:0c54CP@eADl4>DYB13m@F0A4EUh4BEYQ14YJHP=9FF44AUMN14=CF@A1D5H4
@TmD14A@E0=8DeL4C5MK151IG@ABFU`4DUMH155EE0A@Cdh3D4e<14i9B0@o?Sh4>SHf13Hb<`@`;2`3
<2XZ130X9`@a9R@4;b<Q12`Q7P@Z7AX48QDC0a/?30@H1`D47`P512`F4P@h8Qh4ABl[0e4l=`AMB4@4
JEE@17EQG0B1KFP4S7Ud19R5OaGoool001Coool4X92:19f?RPBJSXX4UXb919:;R0>=R8H4R8F41820
P0AdMWL4IF]]151LH@=4DUT4@e5H13];E0@_@Td48SQ412LlA`@/@4X3<DA>13E5C`@iBU84?e1H14AF
GPA9FV44BUYR0dUIH@A6Eeh4@e=I145@EPA2Ce@4A51D0dQCE`A<Ee/4D5UM159JG0ABEeP4DEED151?
CP=@CD`4CTU813ln?P@j=SH4=S8c130/;0<`:RX4<2PW134V90@_8b44;24N12XM6P@R5A<36`l<11P7
1@@O20D4;1HB13PR7PA5;b/3DC`g15e8A0AYEE04MF5L185]J0B<NG@4V8Eo5Oooo`005?ooo`BPT8X4
WHn:19Z>RPBFS8T4TX^80hf8QPB8QH@4P82017AfM`AUJfd4D5aQ0dABF@A3DEP4>d]D12m2C@@R>4@4
9ca712a0BP<aA4h4=DE?13U:DP@oD5P4A5IN14UJH@A:FV83BEUQ14IGGPA3DeT4@E1F149?E0A4D5@3
B5=G14aGF`A@FEd4DUYL159GF0AAEE@4D4m>0e1=C0A>BDP4?chn13Xf=P@f<S<4<2`/0c0Z:P@`:2L4
<BHT12lS8@@/8Ah4:QdJ128E4`<K3``460L511l81@@/5Q84>28N14D_:`=A?3L4GDQ416UED0AeHE`4
PFeX18aiM0BHQGlEoooo000Doooo1:6AS0BNT8`4Vi2<19R?S0BESX/3TXf;18f;RPB9RHT4QHR9179h
N`APK703CeiT14IFG@@kCEH4;d=>128hA@@V?4L4:d1;0c57D@@fBeD4>4]E13Y=E@@nDET4@EEM149G
H0=1EEh4@5AL13mAF@@nCeL4@U5H14EBE`=8E5T4C5QL151IG@ABFUh4DUMJ151CE@A>D503D4m>15IA
C`AAC4/4BTA314@m?0@l=SH3=c4a13</:`@a:BP4<2HT12dR80@[7a`48AHD0aT>3P@E20L46PD312HB
3`@c7a`4@2dY0ddj=PAJAd<4IeA?17=QG0B0KFP4S7Uc19N5OaGoool001Coool4XI6<19j@S0BKT8`4
V8n<19F>R`>BSH/4SH^:18V9R@B5R8T4LWQk161/L0=?GV@4AUIM13]=EP@_@dh48SQ512HlA`@[@4/3
<DMA13I;E@@hBeD4>TeE13iAF@A1EEd4@UMP0d5EGPA0E5`4?e5I13i?E`A2DEP4AE9G0dQDF@A<F5`4
D5UM159JGPABEeX4D5=E14i@D0=@Cdh4EU5?155<B`A:A4<4A3dl13`f=P<g<C44<b`[134Y:0@`9R@4
;B8P12/O70@Q5Q@36@h>11D81`@J1@<49Q8?13<O70A0;BT3CCXf15Y7@`AWE4l4Lf5L181]J0B<NG<4
UhEo5Oooo`005?ooo`BQTH`4WY2<19^@S0BHSh`4UHj;0i:=R`B=RhX4RHV918F8R@AbN7/4H6a`0dmN
I0A6EUd4>deF12m3CP@R>4D49Sa712]0B`<aAe44=T]E13Q;E@@jCED4?U5I145EG@A2Ef03@EEN141D
G0@oDET4?TmG149AF0A5DUL3B5AI14aHG0A@FEd4DUYN159GFPA@DeD4CU1@0e1?CPAFDDl4DDa;14Y4
@`A4?C`4?3Hf0cLa<@@c;2/4<BTX130V90@]8R04:alL124F50<I3Ph45@P711X50`@V4Pl4<alL140]
:@==>SH4FTM316MDC`AcHE`4P6eX18aiL`BGQGlEoooo000Doooo1:6BS0BOTXd4WI:>19^BSPBITXl3
UY:@19BBT@BBTY84T9BD17f3QPAZM7T3FVM]14eMI0@mDEX4;TEA124jA`@T>dL4:T1;0bm6D0@fC5L4
?E=M141FH0A3FF<4AUeW14]QJP=:H6X4B5mX14IKI0A4Eel4A5EL14EEF`=8EE/4C5QM151JG`ABFf04
DUQM14iBEPA;CE03Bda=14a;B`A;B4P4BTI614E1@@@m>CX3>3<d13D^;`@b:R/4<2HV12hS8P@Z7ah4
7QHF0aH?40@E2`X450<211l>30@]71X4?2/X0dXi=PAHAT<4IE=?179PG0AoKFP4RgUc19N5OaGoool0
01Coool4XI:<19nBS@BMTXh4Vi:>19VBS`>FTY04U9:A19:BTPB@U9@4OH>616YdN@=JIfd4CEeT13eA
FP@^AE448CY712@kA`@Z@4/3;dI@13I<E`@mDed4@5IP14=IH`A6GFL4Bf5Z0dYPJPA8GfP4AU]T14AG
G`A4EE`4AEEK0dQEF`A<F5d4D5YO159KH0ABF5d4CU9F14]=D0=;C4d4C4];14]8B0A:ATH4AD5113di
>P<h<c@4=Bh_138Z:`@`9RH4;R<R12XO7P@N5QH35Pl@11D;2P@D0`847`h<12dL6P@l:bP3BSTf15Q6
@`AUDdl4LV1L17m]J0B;NG<4UhEo5Oooo`005?ooo`BQTX`4Wi:=19fBSPBKTXh4VI:?0iJBT0BDTY44
TY:B192DU0AmPhH4JWAi0eYWK@A=GF@4?E5J12i5D@@Q>TL493]712Y0B`<_AU04=TaG13eCG@A0EV04
@eUS14IMI`A;HFX3BV1Z14QOJ0A6Ff@4A5MO14AEG0A5EE/3B5EK14aHG@A@FUl4DU]P159HG@A>DUH4
Bde@0d]<C@A<Bd/4BdQ814Y6APA5@D44?CTj0cPc=0@e;Rl4<RX[130V9P@^8b84:QlN11hF5P<F3a04
5@/:11@30P@O3P`4;A`J13`[:0=:>CH4F4I316ECC`AbH5`4OfeX18]iL`BGQGlEoooo000Doooo1:6B
S0BOTXd4WI:>19^BSPBITXl3UY:@19BBT@BBTY84T9BD17f3QPAZM7T3FVM]14eMI0@mDEX4;TEA124j
A`@T>dL4:T1;0bm6D0@fC5L4?E=M141FH0A3FF<4AUeW14]QJP=:H6X4B5mX14IKI0A4Eel4A5EL14EE
F`=8EE/4C5QM151JG`ABFf04DUQM14iBEPA;CE03Bda=14a;B`A;B4P4BTI614E1@@@m>CX3>3<d13D^
;`@b:R/4<2HV12hS8P@Z7ah47QHF0aH?40@E2`X450<211l>30@]71X4?2/X0dXi=PAHAT<4IE=?179P
G0AoKFP4RgUc19N5OaGoool001Coool4XY:=1:6CSPBOU904WYBA19fFT`>KUiD4VYRG19VJVPBJWIh4
RXnA17MoP`=ULGH4Df=Z145DGP@aAe<48Sa9128jA`@W?TX3;D=>1399E0@iD5/4?eQR14ENJ0A8HF`4
BVA_0d]UL0A:I6l4Af1Z14EJH`A3EUh4A5IL0dIFG0A:F5d4CeYO15=NH@AGH6<4EUaP14iAEP=8BTh4
A4E914A4APA3@D<4@Cho13`i>P<h=3D4=Bl`13<[;0@b:2T4<2DU12XO7`@O5aP34Pd?11082@@>0004
50D512PI60@h:BL3B3Pe15I6@`ATDe04LF1L17i]J0B;NG@4UhEo5Oooo`005?ooo`BRTXd4XI>>19nD
T0BNU944WIJC0i^GU@BJV9L4VIZJ19ZMWPB:Si44Mgn30fEaMPACHfX4@EAN1357D`@R?4T48SY712Ln
BP<]@dh4<TUD13U@F`@oF684AEiX14QQK0A:I6l3BfE`14YTK`A7H6X4AEYS14=FGPA4EU`3AUIL14YH
G@A?FUl4DeiQ15MPH`AFG604CU5F0dQ:CPA4ADT4A4A614=1@`A1?Sl4?3Tj0cPd=@@e;c04<b//138X
:@@`9BD4:QlO11lG60<B3@l440P910h000@D1@D4:1TH13PY9`=8>3D4ETI316ACD0AaH5`4OVeX18]i
M0BGQGlEoooo000Doooo1::BS@BQThh4WiB@19jDT@BMUY<3ViNE19ZHU`BIVYX4VYfN18Z?T@AgOh<3
IG5f15=SJPA1E5h4<DMC128lB@@R>TL49ci:0be3CP@bBE@4>E1K13mHHPA5GVP4B65/14YTK`=;IG04
BVA_14MPJPA5FV<4@eIN14AFG0=6EU`4BUQM14mJG`ACGV44Ef1S15ILH0A>DEH3B4Y>14A5B@A4A4H4
@d53144n?`@l>CX3>3@e13D_<0@c:b`4<RPY130U9@@Z7al47aLH0a8=3`@@20T43P0011@51@@X6AP4
>2TW0dPh=@AFAT<4I5=@175PG0AnKFP4RgUd19N5OaGoool001Coool4XY:=1:6CSPBOU904WYBA19fF
T`>KUiD4VYRG19VJVPBJWIh4RXnA17MoP`=ULGH4Df=Z145DGP@aAe<48Sa9128jA`@W?TX3;D=>1399
E0@iD5/4?eQR14ENJ0A8HF`4BVA_0d]UL0A:I6l4Af1Z14EJH`A3EUh4A5IL0dIFG0A:F5d4CeYO15=N
H@AGH6<4EUaP14iAEP=8BTh4A4E914A4APA3@D<4@Cho13`i>P<h=3D4=Bl`13<[;0@b:2T4<2DU12XO
7`@O5aP34Pd?11082@@>000450D512PI60@h:BL3B3Pe15I6@`ATDe04LF1L17i]J0B;NG@4UhEo5Ooo
o`005?ooo`BSThd4XYF@1:6FTPBQV9@4X9VG0j2KVPBPWYd4X:6P1:6TY@BBV9X4PHV=0fiiO`ALJg84
B5]T13A;E`@U?T`48CY812DlB@<Y@D`4;dEA13A;EP@iDE`4?EIQ141JI@A2G6P3@eeX14=LJ0A2FVH4
@UQR149EG@A3EE`3AEEK14QEF`A<Eed4D5YO15EMH@AJGf<4FeeQ0eMGF`A<CU44@dA813hn@P@l>ch4
>CLj0cLd=P@f<C<4=Rl`13@/;@@d:RX4:R8R11hH6P<@3Q842`P;10l61`@B1`P49APH13HX9`=6>3H4
EDI316=CD0AaH5`4OVeX18YiM0BGQGlEoooo000Doooo1:>CS@BRUI04XIJB1:6HU0BPVIL3X9^J1:2N
W@BPXJ04XJBU19:HVPB1RHd3KWUo15a[LPA8Ff@4=4]G12DnC0@Q>TP49Ca90bU1C0@_AE44=4]F13UA
G0@mEV44@5YU149LJ0=3GFP4@eaX149JIPA2F684@UEM14=EG0=5EE/4B5EK14aGG@A@FUl4EEeQ15YO
H`AKGF43EeMK14a>D@A3A4P4?Si213`k?P@i=cX3=c@f13Ha<`@f;c04=2`]13@Z:P@Z8R847QPJ0a0>
4P@;20/43`H7118720@U61P4=RPW0dHh=PAEAT<4He=@175PG0AnKFP4RWUd19N5OaGoool001Coool4
Xi>=1::ET0BQUY84XIRD1:2IU`>PViX4X9jM1:2QX0BQY:D4TYRJ1869S@=^NGl4G6]b14QKI0@dBeL4
9Ci<124jB0@U?4T3:D5<12m5D@@dBeH4>E5L13eFH@A0FVD4@UaX0d=MJ0A3G6P4@UYV149HHPA2EEd4
@eEL0dEEF`A8EE/4C5MM151JG`AEGF44FUmS15]MH@=GEe/4C4iA14=4B0@n?T84?3/n13Tg>P<g=3H4
=S4c13H_<0@d;2d4=2XZ12XR8P@N61X340hB10/82`@?1PL44PL812DH60@f:2L3ASPf15E6@`ASDe04
LF1L17i]J0B:NG@4UhEo5Oooo`005?ooo`BSThd4XYF@1:6FTPBQV9@4X9VG0j2KVPBPWYd4X:6P1:6T
Y@BBV9X4PHV=0fiiO`ALJg84B5]T13A;E`@U?T`48CY812DlB@<Y@D`4;dEA13A;EP@iDE`4?EIQ141J
I@A2G6P3@eeX14=LJ0A2FVH4@UQR149EG@A3EE`3AEEK14QEF`A<Eed4D5YO15EMH@AJGf<4FeeQ0eMG
F`A<CU44@dA813hn@P@l>ch4>CLj0cLd=P@f<C<4=Rl`13@/;@@d:RX4:R8R11hH6P<@3Q842`P;10l6
1`@B1`P49APH13HX9`=6>3H4EDI316=CD0AaH5`4OVeX18YiM0BGQGlEoooo000Doooo1:>DSPBSUY44
Y9RD1:BKU`BTWIX3Y:2N1:FSXPBVYZH4Z:Z[19^OX0B;TID3MX6616=aN0A>H6X4>DmL12M1C`@P>DP4
8CY70bHmB@@[@Dd4;dEA13=:E@@gCUT4>U9M13]DH0<mEF44?EIR13eEH0@nE5l4?U9L141BFP=2DUX4
A5=J14MDFPA;EEX4CeML15AIG@AFFUd3F5UL15MGF@ACDU@4C4]=14M4APA2?d43@3`n13/f>0@h<S@4
=Rl`13H^;P@]9BL48QdO0aLF6@@>3a843PX=11492`@S6AX4=2TY0dDh=`ADAdD4HeAA171QG@AnKFT4
RWYd19N5P1Goool001Coool4XiB>1:>FT@BTV9@4Y9^G1:BMVP>TX9h4YJ>R1:JVYPBXZZ/4VinP18^A
U@=fPHH4Hg5h14iPJP@iCe`49d5?120iB0@Q>TL39Se912]1C@@_AE44<dYE13M>F@@jDUd4>eAP0ceE
H@@mEV84?EEP13iDG`@nDU`4@59J0d9BFPA4DeX4AeAJ14]EFPA?Ee`4E5UM15IJG@=HFE`4EeMI15=B
E0A<Bdd4AdA6148o@@=0?3h4>cHh13Pb=0@f;c04=Rh^12dU9`@R7Al35aHI10h?4P@>2Pd44@T;12<I
6P@d:BT3ACPg15A7A@ASE544L65M17i]J@B:NW@4UhF05Oooo`005?ooo`BSU8h4XiJA1:BHU0BTViL4
Y9fJ0jBPWPBUXj84YZJV1:RZZ`BKWj04Ri6E0gJ1QPASLGP4CV1Z13U?G0@W@Dl483U8124jA`<V?DT4
:d5=12m5D@@cBUD4=diI13YBG@@kE603?EEQ13eFHP@mEF04?UAO13iBG0A0DUX3@U9J14ACFPA7E5X4
BeEJ14mGG0ADFEd4EUYM0eQIG0AGEeT4De9D14a;C@A7A4H4@Sm10d0l?P@k=SP4>38d13H_<0@f;Rh4
;BDW128M7`<G5QT43PlB10h:3@@A2@/48aTJ13@Y:@=5>3L4E4M516=DD@A`HEd4OVeY18YjM0BGQH0E
oooo000Doooo1:>DSPBSUY44Y9RD1:BKU`BTWIX3Y:2N1:FSXPBVYZH4Z:Z[19^OX0B;TID3MX6616=a
N0A>H6X4>DmL12M1C`@P>DP48CY70bHmB@@[@Dd4;dEA13=:E@@gCUT4>U9M13]DH0<mEF44?EIR13eE
H0@nE5l4?U9L141BFP=2DUX4A5=J14MDFPA;EEX4CeML15AIG@AFFUd3F5UL15MGF@ACDU@4C4]=14M4
APA2?d43@3`n13/f>0@h<S@4=Rl`13H^;P@]9BL48QdO0aLF6@@>3a843PX=11492`@S6AX4=2TY0dDh
=`ADAdD4HeAA171QG@AnKFT4RWYd19N5P1Goool001Coool4Y9B?1:FGTPBVVYH4YYfJ1:NPWP>YY:84
ZZNV1:b[Z`B][jl4Wj>T196GVP=nR8d4JGMo15AUK`@nE604:T=B11liB0@O=dD38cY712LnBP@[@Dd4
;TEA1358E0@dBeH4=DeI0cM>FPPhCe/4>DmJ13Y>F0@kCUP3?DiG141>EPA2CeH4AU1G14UBE`A=DeP4
D5AH0e9DE`ABDeH4DU5D151>D@A<BT`4ATA60d8n@0@n>S/4>cHg13Tb<`@f;c04;bT[12LR9@<O71l4
5QDH114>4P@A2`d48API13@Z:`=5>ST4EDQ716=FD`AaHUl4OViZ18]jM@BGQX0Eoooo000Doooo1:BD
S`BUUi84YYZF1:JMVPBWX9h3ZJBR1:ZWYPB/Zj/4[Jn_19nSY0BAUiX3OXR=16UgO`ADIFl4?UAP12Y3
DP@O>DP47cM50b<jA`@W?TX4:d5=12i5D@@aB5@4=4]F13E=F@<gCUX8>4mK13U?FP@jCUP4>diH0ce>
E`A0CUH4@TmF14I@E`A9DUL4CE=H151DF0=BE5L4DU=F159AE0A@CU44C4Y<14I4AP=2?T04?SXk13/f
=`@i<S<4=Rl`12lY:`@W8RD37a`O11HE60@A3Q844@/=124H6@@d:R/3ACXi15E8A`ASEU<4LF9O17i^
JPB;NWD4UhJ05Oooo`005?ooo`BTU8l4YINB1:JJUPBVWIX4Yj2N0jVTXPBZYjH4[:^[1:f_[`BOXj@4
TINJ0gj8S@AYMgl4E6E_13iDH0@Z@e847cU811lgA@<S>TL49ci:12]1C@@^AE44<DQD13A;EP@eCET3
=diJ23Q?F`@iCeX4>TiH13]>F0<mCUL4@4iF149?EPA6D5L4BE9G14eCF0A@E5P3DUAG159CEPABDE@4
D4iA14a:C0A6A4H3@Si013hj>`@k=SL4>C8c13H_<0@_:B/49b8U0alL7`@F5AP44@hB114;3@@Q61T4
=2X[0dDj>@AEB4L4HeIC175RG`AnKVX4RgYe19N6P1Goool001Coool4YIF?1:JHU0BXW9P4ZJ2L1:^T
X@>]Z:H4[Zb[1;6`/0Bc]KD4YJV[19NMX@>5Si@4LGn615U/MPA3FVH4;dQG120kBP@L=D@383M512@j
A`@W?DT4:Sm;12a3C`@^AE44<4MB0c58E0@bBED4<dYF13A:EP@eBU@4=TYD0cQ:D`@jBU<4?DYB141;
D`A3CE<4ATiD14U>E0=;CU<4C4iC14]=D@A:BTh4B4M:14A3AP=0?d44?C/m13/h>P@j=CL4=S4c130/
;P@Y9bX38R4U11`K7`@F5AX45Q<F12<L7P@f;Rl3Acdm15I;BPAUF5D4LVAQ17m_K0B;NgH4UhJ05Ooo
o`005?ooo`BUUHl4YYRD1:RLV0BYX9`4ZjBQ0jfXYPB^[:/4/K2`1;>e]@BUZJ/4UifQ0hF?U0AaOhH4
FFaf14=JIP@_B5L483]:11`eA0<P=dD493Y712LmB@@Z?d/4;4=?12i5D@@`Ae83<DQD1399E@@cBUH4
=4YF13E:E0@fBU@3>4YC13Y:D`@mBU84@4]C14==D`A6CU@4BDiD0d]>D`A<CU<4BdeA14Y:CPA8AdX4
A4=60d0o@@@m>cd4>cPj13Xe=`@f<C<4<2`^12TW:P<R8BD471/O11HE6P@F4aH48a`N13H^;`=7?Cd4
ET]:16EHE@AbI644Ofm/18]kMPBGQX0Eoooo000Doooo1:FES`BVV9@4Z9bH1:VPW0B[Y:43[JRV1:j/
Z`Ba/;04/kFe1:FYZ`BGWJ43QHnD175oQPAIK7H4@eYV12m8E`@P>dX473E40b0gA@@T>TL49ce912Xo
B`@/@dl4;TEA1317DP<aB5@4<TUE13=:EP@dBUH4=DYD13I:E0<hBU<4>TYC13e:DPA0Be<4@deC14I>
E0A9CU@3BdiC14a>D`A;CE44BTY>14Q7BPA4@dH3@3m113dk?@@k>3X4>SDg13Ha<`@`;2h4:BLZ0b8Q
9@@L6al45QDJ11HC5P@S71h4=Rh_0dLm?@AFBdX4IEQE179TH@AoKf`4Rg]f19N6P1Goool001Coool4
YIF?1:JHU0BXW9P4ZJ2L1:^TX@>]Z:H4[Zb[1;6`/0Bc]KD4YJV[19NMX@>5Si@4LGn615U/MPA3FVH4
;dQG120kBP@L=D@383M512@jA`@W?DT4:Sm;12a3C`@^AE44<4MB0c58E0@bBED4<dYF13A:EP@eBU@4
=TYD0cQ:D`@jBU<4?DYB141;D`A3CE<4ATiD14U>E0=;CU<4C4iC14]=D@A:BTh4B4M:14A3AP=0?d44
?C/m13/h>P@j=CL4=S4c130/;P@Y9bX38R4U11`K7`@F5AX45Q<F12<L7P@f;Rl3Acdm15I;BPAUF5D4
LVAQ17m_K0B;NgH4UhJ05Oooo`005?ooo`BUUI04YiZE1:VNVPB/XYl4[ZNT0k2[Z@Bc/:l4]KFe1;Vj
^`B[[[04W:>V0hbFV`AiQXh4HgAn14eRKP@hDEl49d9B11dgA`<N=T@48CM512@iAP@V>dL4:3e912U0
C0@[@Dh3;4=@12e4D0@^A544;dEA1315D@@aAE03<dE?13E5C`@gATl4>TI?13a7C`A0B4l4@dU@0dA9
C`A6BDh4ATQ=14E7B`A4A4T4@d960d4o@PA0?3l4?SXl13dh>P@j=CL4=30c12h[;`<Y9b/492<W11lO
90@O7R84:B@W13/d=P=;@T84FDi=16MJF0AcIV<4P75]18alM`BHQh4Eoooo000Doooo1:FET0BWVYD4
ZIjJ1:bRW`B^Yj@3/:^Y1;>`[`Be]KD4^KZk1:^^/0BLXjH3S9JK17V6SPASM7h4CF9^13QAG`@W@U84
7CM70ahfA0@Q=dD493U612HkA`@X?DT4:D1<12]1CP</@e04;DA@12i4D@@_AE44<4EA1355D0<cADl4
=DE?13M6C`@jATl4?4M?1418C`A3BE03A4U?14I9CPA6B4d4ADM;14A4B@A3@TH3@Cm2140l?`@n>S`4
?CPj13Xe=`@d<3<4;R/_0bTW:`@T8bL47alT11lN8P@Y92L4>c@f0d]2@PAICTd4IeYH17=VH`B0LFd4
S7ag19R7PAGoool001Coool4YIF@1:NJU@BYWYX4[::O1:jWY0>`ZjT4/k2_1;Fe]@Bi^[/4Zjj`19bS
YP><UY/4NHJ>16=dOPA=HVh4>55O12M2DP@M=dL37SI4124gA@@T>DH49S]712PmB@@Y@4`4:d5>0ba3
D0@]A504;TAA12m5D@@`AE44<DE@0c=5C`@eADl4=dI?13Y6C`@lAdl4@4Q?14=9D0=4BDl4ATU>14I8
C@A5Ad/4A4A914=2AP=1?d84@3`o13hj?0@m>3X4>SDg13@`<`@^:bl3:BL[12@S9`@O7b@47ahR12TT
9`@k=3H3Bd9215U>C@AWFUP4LfIS181aK@B<O7L4V8N15Oooo`005?ooo`BUUI04YiZE1:VNVPB/XYl4
[ZNT0k2[Z@Bc/:l4]KFe1;Vj^`B[[[04W:>V0hbFV`AiQXh4HgAn14eRKP@hDEl49d9B11dgA`<N=T@4
8CM512@iAP@V>dL4:3e912U0C0@[@Dh3;4=@12e4D0@^A544;dEA1315D@@aAE03<dE?13E5C`@gATl4
>TI?13a7C`A0B4l4@dU@0dA9C`A6BDh4ATQ=14E7B`A4A4T4@d960d4o@PA0?3l4?SXl13dh>P@j=CL4
=30c12h[;`<Y9b/492<W11lO90@O7R84:B@W13/d=P=;@T84FDi=16MJF0AcIV<4P75]18alM`BHQh4E
oooo000Doooo1:JFT0BYViH4Zj2K1:jUX@BaZZL3]:n]1;Nd/`Bj^KT4_Ko01;2d]PBRZ:`3TYbQ182=
U@A[O8D4E6Ue13mGI@@^B5L48Ca;0adfA0@O=T<48CM4128hA0@T>4D49CY612HlB@<W?T/49cm<12Po
C0@Y@4`4:d1=12a1C0<]@D/4;d1;1350BP@d@D/4=d9;13Y3C0@mAD`3?TE<1415B`A1A4X4@DA91452
A`A1@DD3@3m313lm@0@o?3l4?c/m13/g>P@h=CP4<c4e0c0^<P@/:bl4:2P]12XY;@@f<SD4@S`n0e17
B0AMDe84JEiL17EXIPB1Lfl4SGeh19R7PQGoool001Coool4YYJ@1:VKUPB[X9/4[ZFQ1;6ZY`>d[jd4
]kBc1;Zi^@Bm_l04/;Bf1::X[0>BW:44P8fE16]lQ@ADJGD4?eMU12i8E`@Q?4/37CI411lf@`@Q=d@4
8SQ412@hA@@U>TH49Sa90bLnB`@W?d`4:3m<12U0C0@[@4d4;45<0be1B`@_@4/4<D1:13A1B`@g@T/4
>T=<13e5C0<nAD`4@4E;1454BPA1A4T4@D971451A@=0?d<4?ce013ll?`@o>cd4>cLj13Pe>0@c<CD3
<2hb12`[;`@X:2d4:RT]13Hb=@A2?3h3D4M815eCDPAYGU`4MFQV185cK`B=OGP4V8N25Oooo`005?oo
o`BVUY04ZI^F1:^PV`B^YJ44/JZW0kB_[@Bg];<4^[Vi1;fo`0B`];H4XZR/0i:LX@B0SID4Jgb515AY
M@@oEfD4;TQG124lB`<M=T@47cI3124gA0@R>4@493Q512DjAP@V?4T39ci;12LoC0@X?d`4:D1<12]0
C@@/@D`3;D5;12m0B`@a@4X4=45;13M2B`@j@d`4?DE<0ci5C0A0AD/4@DA:1454B@A1@TL4@D550d0o
@`@o?D04?c`o13lk?@@k=cX4>3Dh13<a=@<`;S84;2/_12PX;@@Z:Bd4=S8e148l?P=@AdP4GE=B16UN
G0AeJ6H4PG=_18emN0BHQh8Eoooo000Doooo1:JFT0BYViH4Zj2K1:jUX@BaZZL3]:n]1;Nd/`Bj^KT4
_Ko01;2d]PBRZ:`3TYbQ182=U@A[O8D4E6Ue13mGI@@^B5L48Ca;0adfA0@O=T<48CM4128hA0@T>4D4
9CY612HlB@<W?T/49cm<12PoC0@Y@4`4:d1=12a1C0<]@D/4;d1;1350BP@d@D/4=d9;13Y3C0@mAD`3
?TE<1415B`A1A4X4@DA91452A`A1@DD3@3m313lm@0@o?3l4?c/m13/g>P@h=CP4<c4e0c0^<P@/:bl4
:2P]12XY;@@f<SD4@S`n0e17B0AMDe84JEiL17EXIPB1Lfl4SGeh19R7PQGoool001Coool4YYNA1:ZL
U`B]XId4/:NS1;B]ZP>h/[04^kRg1;nm_@C2`l<4];Rj1:N]/0>HXJH4QiBK17B3S@AMLWd4AUm]139>
GP@U@E837SQ811deA0@N=D<47cE3220f@P@Q=d@38SQ5128iA`PS>TL493Y712HkA`<X>dL4:Ca712/l
A`@^?DL4<Cm813A0B0@g@DT3>D5913]1B@@l@TT4?T9813m2A`@o@4H3?d14140o@`A1?d84@3e113ll
?`@l>Sd4>CPk0cDe>@@b<SH4;bld12h/<@@l>C`4BD=50eE=CPAQEeH4K65O17Q[J0B3MG44SWij19V8
PQGoool001Coool4YYNA1:ZLU`B]XId4/:NS1;B]ZP>h/[04^kRg1;nm_@C2`l<4];Rj1:N]/0>HXJH4
QiBK17B3S@AMLWd4AUm]139>GP@U@E837SQ811deA0@N=D<47cE3220f@P@Q=d@38SQ5128iA`PS>TL4
93Y712HkA`<X>dL4:Ca712/lA`@^?DL4<Cm813A0B0@g@DT3>D5913]1B@@l@TT4?T9813m2A`@o@4H3
?d14140o@`A1?d84@3e113ll?`@l>Sd4>CPk0cDe>@@b<SH4;bld12h/<@@l>C`4BD=50eE=CPAQEeH4
K65O17Q[J0B3MG44SWij19V8PQGoool001Coool4YYNA1:ZLU`B]XId4/:NS1;B]ZP>h/[04^kRg1;nm
_@C2`l<4];Rj1:N]/0>HXJH4QiBK17B3S@AMLWd4AUm]139>GP@U@E837SQ811deA0@N=D<47cE3220f
@P@Q=d@38SQ5128iA`PS>TL493Y712HkA`<X>dL4:Ca712/lA`@^?DL4<Cm813A0B0@g@DT3>D5913]1
B@@l@TT4?T9813m2A`@o@4H3?d14140o@`A1?d84@3e113ll?`@l>Sd4>CPk0cDe>@@b<SH4;bld12h/
<@@l>C`4BD=50eE=CPAQEeH4K65O17Q[J0B3MG44SWij19V8PQGoool001Coool4YYNA1:ZLU`B]XId4
/:NS1;B]ZP>h/[04^kRg1;nm_@C2`l<4];Rj1:N]/0>HXJH4QiBK17B3S@AMLWd4AUm]139>GP@U@E83
7SQ811deA0@N=D<47cE3220f@P@Q=d@38SQ5128iA`PS>TL493Y712HkA`<X>dL4:Ca712/lA`@^?DL4
<Cm813A0B0@g@DT3>D5913]1B@@l@TT4?T9813m2A`@o@4H3?d14140o@`A1?d84@3e113ll?`@l>Sd4
>CPk0cDe>@@b<SH4;bld12h/<@@l>C`4BD=50eE=CPAQEeH4K65O17Q[J0B3MG44SWij19V8PQGoool0
01Coool4YiNA1:^MV0B_Xil4/jVU1;N_[0>k][@4`;fk1<G4``C9bLX4^kk01:jc]P>OYj`4T9^R17b;
U0AVNH@4D6Me13UEI@@XAUL37SU:11/dA0@K<d8473=111`b@0PL<Sl37C8o11dc@@@M=4447CA211he
@P@O=T<38CE2128f@P@U=d<4:3U412/jA@@_>dD4<Se60cDoA`@g?dL4>Cm713/oA`@l@4H4?D160ce0
A@@n?d@4@415140oA0A0?d<4?Se213`k@0<i>Cl4=SLm13Hg?0@g=CX4A41314m:B`=JDe<4IEaK171U
H`AjKV/4QGMc18n0N`BIR8<Eoooo000Doooo1:NGT@B[WIP4[j>O1;>YY@Bg[j`3^kJd1<2m^`C5a<<4
bLW:1;^n`0B^/kH3WjN/192KXPAlRi@4IWV4151WM@@iEFD4:4IG0ahiBP@K=4@46c=211`c@@@L<T08
738o0adb?`@M<d447CA111dd@P@N=D847cI30b4e@P@R=T849CM312PiA0@[>TD4;c]5138mAP<e?dL4
=cm713ToA`@k?dL4?41613e0AP<m@4D4?Sm41410A@A0?d@4@3m313hm@P@l>d03>CTo13Hg?@@f=c`4
=cDj14A0@`A?BT/3FU=C16ELF`A`IF<4NVi[18EgL`B?P7/4VHR35Oooo`005?ooo`BWUi44ZifH1:nS
W`BcZJD4]jn/0k^f]0C0_K/4aLC31<W9bPBk_/04[[>f0inW[0B@Vj84O8^D16IiQ0A@IgD4>EEU12Q6
E`<N>DX46cA411/c@P@L<d44739021`b?`<M<Sl47C=111dd@@@M=4847SE211lf@`<Q=D848SI212Dg
@`@X>D@4:cY512lkA@@b?DH3=Cm713LoA`@i?dL4>cm713a0AP@m@4H3?D1513hoA0A0@4D4@3m4140o
@`@n?D84?3]00cTi?`@f=cd4=SLl13Le>PA4@4<4CdY;0eYCD`AUG5/4L6ES17Y^J`B5Mg<4Sh1k19V8
PaGoool001Coool4YiNB1:bNV@B`Y:04]J^W1;Vb[`>n^KL4a<2o1<W8a`C?d=04`lK81;Fj_@>V[[<4
UZ6X18>BVPA^P8/4F6ml145LK0@^C5d37ce>11XdA@@I<T84634o11P_?@@H;S`462hk0aL^?0@G;cd4
630n11P`?`@H<3h46C0n0aX`?P@L<3h47S90124d@0@U=D44:CM212`iA0<`>dD4<ca613DnAP@h?TH4
>Sm613a0AP<m@4H4?d571453B0A2@dP4@d=814=3A`A1@TL3@41513hoA0@o@4D4ADA914a9C0AFD583
H5QI16YPH0AcJFL4OG5^18MiM@B@PG`4VXV45Oooo`005?ooo`BWUi84[9jI1;2TX0BeZjL4^K:_0kji
]`C4`;l4bLS71<o@d0C3a/P4]KZm0jJ^/`BFXJP4Pi:J16j0R`AHKg`4@Ea/12i<G@<O?Dh46SA511Tb
@P@H<Cl462lm11P^?0@H;S/35bhl11L_?@@H<3h4630o11P`?P@I<3h36S0n11``?P@N<T048CA012De
@@@Y=d84;3U40c0kA@@c?4H4=Ci613PnAP@j?dH4?4160ce0AP@o@DL4@D=81493B0A3@dP4@d=71452
A`=0@4D4?Sm413m0A@A5A4T4C4U<15I@DP=PF5T4JV1P17=YI`AmLFh4QgUe1921O0BJRH@Eoooo000D
oooo1:NGTPB/WYT4/:BP1;F[Y`Bi/Zl3_[Vg1<C0_`C9b<L4cm3@1<?6b0Be^[d3YZjc19JQZ0B3TYX4
KX2;15Q_O0A1G6`4;TaM0almCP@J=4D46C9211Pa?`@H;cd462hl11P^>`<G;S`45blm11P`?P@H<3l4
630n11T`?P<J<3h4730n11hb@0@Q=4049CE112Tg@P@/>D@3<3]513<lAP@e?TH4>3i613XoAP@l@4H3
?D1613m1A`A1@dP4@T=814=3B0A3@dL4@D970d10A@@n?d@4?d1514E4B@A<BD`4EU1B0f1HF@AZH604
LfUW17eaKPB7NGD4T85l19Z9Q1Goool001Coool4YiNB1:bNV@B`Y:04]J^W1;Vb[`>n^KL4a<2o1<W8
a`C?d=04`lK81;Fj_@>V[[<4UZ6X18>BVPA^P8/4F6ml145LK0@^C5d37ce>11XdA@@I<T84634o11P_
?@@H;S`462hk0aL^?0@G;cd4630n11P`?`@H<3h46C0n0aX`?P@L<3h47S90124d@0@U=D44:CM212`i
A0<`>dD4<ca613DnAP@h?TH4>Sm613a0AP<m@4H4?d571453B0A2@dP4@d=814=3A`A1@TL3@41513ho
A0@o@4D4ADA914a9C0AFD583H5QI16YPH0AcJFL4OG5^18MiM@B@PG`4VXV45Oooo`005?ooo`BXV984
[InJ1;6UX@Bg[JT4_;Ba0l6l^@C7a<84c/c<1=GFePC;c]04_<;50jje^PBOZJl4S9ZS17N9U0AQMh@4
C6Ee13MDI@<UA5H46SM911La@P@E;cl452dm11@/>`@C:cX34R/j114Z>P@A:cX44R`l114[>`@B:c/3
4b/k11@/>P@G;C/46Rlm11lb?`@S<d049cI10b/h@`@^>T@4<Sa613DnA`@i@4P4?4590cm3B@A1A4/4
@dI<14A7C0A5Add4AdQ=14I7C@=4AT/4@TA913m0A@A;BDd4E51C15aGF0=UGUh4KVET17M/J`B0M744
RG]g19:2OPBJRX@Eoooo000Doooo1:RHTPB]WiX4/JFQ1;N]Z@Bl];43`Kbi1<O4`PC>c<`4eMKF1<_>
d0Bl`/D3[[Fj19nY[`B<VZ<4MhVD165gQ0A<IGD4=eAU0bE4EP@J=dT45c5211D_?`@D;Cd452`k11<[
>P<B:cX44BXj114[>P@B;3`44B/k118[>`<C:c/452`j11L]>`@J;cd47c8o12<c@0@W=T43:cQ312hj
A0@b?4H4=Ci713U0B0@l@DT3?d=91454B`A3AT`4A4M<14E7C@A7B4d4ATM=0dA6B`A2A4T4?d1514]9
C@ADD5<4G5MH0fENGPA^IF@4Mfa[181dL@B9NgL4TX9n19Z:Q1Goool001Coool4Z9RB1:fOVPBaYJ44
]jfY1;bd/@?1_;T4alC21<k<c0CEe]H4blk@1;c2a@>^]KX4WjV_18bJX`AgRI@4HGN414aUM@@gE6D3
9DAF11XgB@@G<D845Blo11@]?@@D;3/44b/j0a8[>P@A:SX44B/j118/?0@A:c/44R/k0a<[>`@D;3X4
5bdk11X_?@@O<Sl48c=012Lf@@<[>4<4;SY4138lAP@e?TL4>D1813a1B@<o@dT4@DA;14=6C0A4Ad`4
ADM=14M8C@A6Add3A4I;1494B@@o@4D4BdU=15A@D`ALEeP3IEiN16iUI0AgK6/4P7Aa18UkM`BBPWh4
VXZ45Oooo`005?ooo`BXV984[InJ1;6UX@Bg[JT4_;Ba0l6l^@C7a<84c/c<1=GFePC;c]04_<;50jje
^PBOZJl4S9ZS17N9U0AQMh@4C6Ee13MDI@<UA5H46SM911La@P@E;cl452dm11@/>`@C:cX34R/j114Z
>P@A:cX44R`l114[>`@B:c/34b/k11@/>P@G;C/46Rlm11lb?`@S<d049cI10b/h@`@^>T@4<Sa613Dn
A`@i@4P4?4590cm3B@A1A4/4@dI<14A7C0A5Add4AdQ=14I7C@=4AT/4@TA913m0A@A;BDd4E51C15aG
F0=UGUh4KVET17M/J`B0M744RG]g19:2OPBJRX@Eoooo000Doooo1:RHTPB]WiX4/jJR1;R^ZPBn][<3
a;jl1<_7a@CBd<l4f][J1=?Ee`C6blh3][k31:Na^0BFXj/4PY:M16f1S@AJLGl4AV1`0c1>G`@O?U44
5cA611@^@0@B:c`442Tj10hX>@<=9cP432Lh10/V>0P;9cT42RHh0`/W>0@>9cP44BPh11@[>P@I;S`4
7C4n124c@0<V=D84:cQ412lkAP@c?TP4>41913i4C0=1ATh4A4U@14Q;DPA9C584BDaC14Y=D`A;CE<3
BTeB14]<D@A8B4`4DU5D15]GFPASGEl3Jf=T17=ZJ@AkL6h4PgMd18]mN@BCQ7l4VhZ55Oooo`005?oo
o`BXV984[InJ1;>VXPBh[ZX4_[Jc0lBn_0C;alD4d]3?1=[JfPCCeML4a/_>0kJn``BW/KP4UZ>[18:B
W@A]PHd4FW5o14IPL0<`CUl47ciA11LdAP@D;T044R/l110Y>P@>:3T33BLh10`W>0@;9SP82bLi10XV
>0<;9cP43RLh114X>0@D:cX46Bhl11da?P@Q<d039SE212/hA0@_>dH4<ci813Q0B@@nA4`3@DI>14A9
D0A8Be84BDaB14U<D`A:CE<4BdeC0dY=DPA;C544B4Q<159AE0AKEeX4HeeO0f]SI0AcJVT4Ng1^18=g
M0B;OGT4ThAo19^:QAGoool001Coool4Z9RB1:fOVPBcYZ84^:jZ1;jf/`?4_[`4blO51=;@c`CJf]X4
dmGG1<K;cP>f_/<4Yk6h19JSZ`B2TYd4KH6=15YaO`A6H703<4iO11lnD@@G=4H452i0118[?0@@:CX4
3RPi0`dW>0@<9cP42bHh20/W>@@:9SP32bLh10hW>0@A:3P452/j11T^?0@M<Ch48C=00bHe@P@[>4@4
;c]613<nB0@h@4T4?TA<0d56CPA4BE04B4]B14U<DPA9C5<4BTeC14]=D`=:CE84BdaA14Q8C0ABDE@4
FeMJ16=MG`=[Hf@4LfYY17]`KPB3Mg@4Rgei19>4O`BKRXDEoooo000Doooo1:RHTPB]WiX4/jJR1;R^
ZPBn][<3a;jl1<_7a@CBd<l4f][J1=?Ee`C6blh3][k31:Na^0BFXj/4PY:M16f1S@AJLGl4AV1`0c1>
G`@O?U445cA611@^@0@B:c`442Tj10hX>@<=9cP432Lh10/V>0P;9cT42RHh0`/W>0@>9cP44BPh11@[
>P@I;S`47C4n124c@0<V=D84:cQ412lkAP@c?TP4>41913i4C0=1ATh4A4U@14Q;DPA9C584BDaC14Y=
D`A;CE<3BTeB14]<D@A8B4`4DU5D15]GFPASGEl3Jf=T17=ZJ@AkL6h4PgMd18]mN@BCQ7l4VhZ55Ooo
o`005?ooo`BYV9<4[Z2K1;BWX`Bi[j/4`;Nd0lK0_@C=bLL4eM?B1=oPh0CNgn44d=?F0l77b`Ba^l04
XZje18nMYPAjS9P4J7f:15A]O0=1GFh4;4YM11hmD0@D<TH44B`o10hY?0@;9ST322@g10LS=P@68cH4
1R@g10@T=`@38SD3128d10HT=@@:9SL43RPi11<Z>P@H;Sd47C4o0b<e@P@Y>4@4;ca813A0B`@i@dd4
@4M@0dI<E0A:CeH4CE5H14mCF@AAE5X8DUEK0e5DFPABEE/4EeML15aJG@ARGV04JF=T0g1XJ@AgKVd4
OWAb18IiM`B=Og/4U8F119b;QQGoool001Coool4ZIRC1:jPV`BdYj<4^Jn[1<2g]0?6`;d4cLW71=GC
dPCOh>04g]oQ1=3CeP?1al/4/K_01::^]@B?WJH4NXbH16QmRPADKG`3@Ee^12a:G@@N?E045396114/
?`@>:C`42bHi0`PT=`@78cH41R<f10HT=`@493L40b8e0`@R=0@693D42RHg10hX>@@C:SX462hm11da
?`<S=D84:CQ412llB0@d@4/4>D==1417D0=6C5@4BTmF14eAF0A?DeT4DEAJ259EF`=AE5X4DUEK15MG
G0ALFUd4HUiP16USI0=`J6T4Mfi]17idLPB6NGL4SGmk19B5P@BLRhHEoooo000Doooo1:VHT`B^X9/4
]:NS1;V_Z`C0]k@3a/2m1<g9a`CEdm84gn3P1=kOh@C@dmH3`LO;1;6k`0BR[[D4SifV17Z<V0AXOHX4
E6el0d5MKP@/BUd47Se@11@bAP@A;3l43RTl10/V>@<893L41b<f10HS=P@693L412@g10<R=@<48S@4
1R@e10XV=`@>:3T44bXj11P^?@@M<Cl38cE212ThA0@_?4P4=41;13U3C@A0Ae03ATaD14Y?EPA=DEP4
Ce=I155DFPQBEE/3DEAJ159EF`AGEe`4G5YM169NH0AYHf@3L6QY17M^K@AnM784QWUg18eoN`BDQH44
W8^65Oooo`005?ooo`BYV9<4[Z2K1;BWX`Bi[j/4`;Nd0lK0_@C=bLL4eM?B1=oPh0CNgn44d=?F0l77
b`Ba^l04XZje18nMYPAjS9P4J7f:15A]O0=1GFh4;4YM11hmD0@D<TH44B`o10hY?0@;9ST322@g10LS
=P@68cH41R@g10@T=`@38SD3128d10HT=@@:9SL43RPi11<Z>P@H;Sd47C4o0b<e@P@Y>4@4;ca813A0
B`@i@dd4@4M@0dI<E0A:CeH4CE5H14mCF@AAE5X8DUEK0e5DFPABEE/4EeML15aJG@ARGV04JF=T0g1X
J@AgKVd4OWAb18IiM`B=Og/4U8F119b;QQGoool001Coool4ZIVC1:jPV`BdZ:<4^[2/1<6h]@?8`Kh4
cl[91=OEe0CQhN04iNOX1=[Mg`?:d=@4^l?81:^g_PBJZ;44QYNR17J9U@ATNXP3E6al141KK@@_CEl4
8T1D11LeB@@A;T842RPl0`HT>0@48SH40b8f10<S=`@28cP40B<g0`0R=P@18SD41B@f10TW>@@?:S/4
4bdn11T`?`<P=4<49cU712hnB`@f@dl4?DQC14E=E`=;DUX4D5EM15AHG`AGFV44FEaR15]MH`AKGV<3
FUeR15IHGPANGV84I69U16UUI`A_JFX3MFi]17abL@B2MgD4RGai18n1O@BFQX84WHb65Oooo`005?oo
o`BYVI<4[Z2K1;BXX`Bj/:`4`KRe0lS1_PC?b/T4emGD1>7Qh0CUinP4f]gO0l[@e0Bk`lP4ZkNn19ZX
/@B6Uj84MXVE16AjR0=DK7`4@5]]12m=G`@R@5@45cE9114^@P@::3`31R@h10@R=P@38SH40b<g108S
>0@18cL3028f104R=@@593H42BLi10lZ>`@C;Ch46C0o0b0d@`@W>DL4;Si;13I3C`@mB5<4ADeG0d]B
FPA@EEd4E5QO15MJH@AIG684FeeS15]NH`=JGF84EUQN15iNHPATHVD4JFEW16mYJP=eKVd4O79a189g
M@B9O7T4Sh5m19J6PPBMS8HEoooo000Doooo1:VIT`B^X9/4]:RS1;Z`[0C1^;D3b<6n1<o:b@CGeM@4
hN7P1>GWj0CJgMl3b]3D1;_3b0B[]kh4VZRa18JGXPAfRID4I7Z80eA/O0A0Ffd4;deO1290E0@G=DT4
4Bi210XX?0<693P4128f10<R=P@38cL40R<h104S=`<08SH40B8e10DT=P@99cT43bXk11<]?P@I<3l3
83A312LiA`@^?T/4=T=?13e8D`A5CEL3Be9J151EG@ADF5l4EeYQ15ULHPAKGF<4FeiS0eYMHPAFF5h4
GUiR16ARI@AYIFL4KfUZ0gE^K@AlLW44PWMe18UlN@B?PGd4UXJ219f<QQGoool001Coool4ZIVC1:jP
V`BdZ:<4^[2/1<6h]@?8`Kh4cl[91=OEe0CQhN04iNOX1=[Mg`?:d=@4^l?81:^g_PBJZ;44QYNR17J9
U@ATNXP3E6al141KK@@_CEl48T1D11LeB@@A;T842RPl0`HT>0@48SH40b8f10<S=`@28cP40B<g0`0R
=P@18SD41B@f10TW>@@?:S/44bdn11T`?`<P=4<49cU712hnB`@f@dl4?DQC14E=E`=;DUX4D5EM15AH
G`AGFV44FEaR15]MH`AKGV<3FUeR15IHGPANGV84I69U16UUI`A_JFX3MFi]17abL@B2MgD4RGai18n1
O@BFQX84WHb65Oooo`005?ooo`BYVI<4[j2K1;FXX`Bk/:`4`[Re0lW1_`C@blT4f=GD1>7Pg`CZjn/4
iNOY0mKJg@C7c]84^<;71:Rd^`BDY:d4Q9FP17B8U0=TNXP4E6ak14ANKP@eDF<4:DII11lmC`@G=DP3
42m310/Z?`@8:3d422Tn10HY?`@5:3l30bLm10<V>`@49S`422Tm10d/?`@C<4846CA50b0gA`@Y?D/4
<T=@13]:E@A3CeX4C5EN0e9IHPAHGVD4GF5W161SJ@ASIF/4IFM]16IXK@=TIf`4HfAX16QVJPA/JF/4
L6a]17E_K`=jLW84P7Ie18EjN0B;Og`4TH=o19N8P`BMS8LEoooo000Doooo1:VIT`B_X9/4]JRS1;^`
[0C2^;D3bL6o1=3;b@CHeM@4hN3O1>[[j`CUinT3e][M1<O>dPBh`/L4Z;Bk19BT[@B4UJ04M8RD0fAj
R0ADK7/4A5i^13EAH`@YAUT47ce?11LeB0<@;d<42bXo10PX?@@8:Ch41RTo10DX?`<39cd40bHk10@V
?0@8:Cd43B`o11<`@P@I=4D383M712TmB`@b@e04>dYE14=?FPA<EEh3DUUR15QNI@AMHFL4H6=Y16=U
J`AUIfd4IVQ]0fAWK0ASI6P4J6IZ16aYJ`A`K6d4MFm_0gYbLPB0MWD4QGYh18]oO0BAPgl4UhR319f<
QaGoool001Coool4ZIVC1:nPV`BeZ:<4^k2/1<:h]@?9`Kl4d<_91=SEe0CQh=l4j^_[1>GWj@?Ff]d4
alkB1;S2a`BX];/4U:B]18BEX0AdR9@3I7Z815A/N`A4GVh4=E5S12U6F@@O?Dl45cE80a0_@`@;:Sl4
22Pm10PY?P@6:Cl41BPo0`<W?@@39S/412Hl10PY?@@=;3l44c1211TdA@<P=dL4:Ce;1393D0@kBUD4
@dmJ14aEGP=BFF84F5iU15eQI`APHfT4HfE[16EWK@AVJ6d3I6M/16=TJ0AXIVX4K6U[171/K@AeKfl3
NW9b181fM@B5NWP4Rgml1963O`BGR8<4WHb75Oooo`005?ooo`BYVI<4[j2K1;FXX`Bk/:`4`[Re0lW1
_PC@blP4fMGC1>;Pg`C/k>/4k^o`0n7TiPCCem/4a<_@1;JoaPBU/KT4Tj:[18>DW`=cQY<4HgR615A[
NPA7Gfl4?EEV13==GP@YAUP38CmB11XjCP@E=DX453E9118dB@@?<TP3331610/_A@@;;T@43S1511<c
A`@H=TT47cY<0bHnC`@_A5<4>4YH14=AG@A;Ef44DeeV0e]QJPAQIVd4IVY`16Y]LPA]KgD4L75g175b
M`=_LGH4L71d175_LPAdL784Mg9c17]dM0=oMgH4Q7Yh18UmN`B>PGh4ThF119R9Q0BNSHLEoooo000D
oooo1:VIT`B_X9/4]JRS1;^`[0C2^;D3bL6n1=3;b0CIeM<4h^3O1>c/j`C^ko03hNCV1=?Gf`C4bm04
][o61:Fa^@BCXZ/4PiBO0g>6T`ASN8H4E6]j14MOK`@mEFH4<deN12U6F0<Q?e846SY>11DeBP@D=DT4
4SA910lbB0<<<4H42bm510/^A0@><4D44c=711PfB@@O>T`39Si?12m4D`@hBUP4@e5M14]GH@ACGFH3
Ff5Z165VK@AVJW04JVeb16e_M@A`LGL4LG9g0fmaMPA`L7@4LFmb17A`LPAgLW<4NgAd0gmgMPB4NWP4
RGek18j1OPBCQH44V8V419j=QaGoool001Coool4ZIVC1:nPV`BeZ:<4^k2/1<:h]@?9`Kh4d<_81=WE
d`CRh=l4k>c[1>k_l0?Qi>H4dmOK1<C;d0Bf_lH4YK6i19>RZ`B3U9l3LhJC16=hQPADJgX4Aem_13eE
IP@cCEh4:DIH0b4oDP@J>Th45CE:11@eB@@B=4T43c980```AP@;;dD42bi410h`A@@C<dL463I911lj
C0<V?Tl4;dAC13Q:F0A3DEd4BeMQ15=MIP=KHFX4HFI]16IZL0AZKG84KFme171aM`AaLWL3Kg5f171`
M0AaKg84M71b17MbL`AkM7@3OgMf18AjN0B9OG/4SX5n19>5P@BHRH@4WXf75Oooo`005?ooo`BYVI<4
[j2K1;FXX`Bk/:`4`[Re0lW1_PC@blP4fMGC1>;Pg`C/k>/4k^o`0n7TiPCCem/4a<_@1;JoaPBU/KT4
Tj:[18>DW`=cQY<4HgR615A[NPA7Gfl4?EEV13==GP@YAUP38CmB11XjCP@E=DX453E9118dB@@?<TP3
331610/_A@@;;T@43S1511<cA`@H=TT47cY<0bHnC`@_A5<4>4YH14=AG@A;Ef44DeeV0e]QJPAQIVd4
IVY`16Y]LPA]KgD4L75g175bM`=_LGH4L71d175_LPAdL784Mg9c17]dM0=oMgH4Q7Yh18UmN`B>PGh4
ThF119R9Q0BNSHLEoooo000Doooo1:VIT`B_X9/4]JRS1;^`Z`C2^;@3bL6m1=3:a`CHe=84hMkM1>_Z
j@Ccm?@3kNo`1=kQi0C@eMT4`LW>1;6k`PBQ[[H4TInY0h>DWPAdQY84IW^815Y`O`A?IWH4AUi^13iG
J0<eD684<4aN12U6F@@U@eH48d5D1250E0<N?U8473eA11dmD@@O?U848d1C12M3E@@]AeP3=4aK13eA
G`A5EV84CeaW15MQJ`AOIfl3IF]c16]_MPA`LgP4M7Ik17MhO@AjNh04O7f10g]kP0AiN7/4NGIi17]f
N0AmMgP4P7Uh0hAkNPB8OG/4S81m1923P0BEQh84VXZ519j>R1Goool001Coool4ZIVC1:nPV`BeZ:<4
^k2[1<:h]0?9`Kd4d<[71=SDdPCQg]d4jn[Y1??dm0?]ko04g^7T1=3Ef@C1bLh4/K_21:6^]PBAWjT3
PiBN17B6TPAVNhP4FW1o14mVMPA6GVh4?UMX0cE@HP@`C5h4:DII12E3EP@S@E@48D1D0ahnDP@L?E44
7CeA11lnDP@S@5<49d=E12e7F0<dC5/4?E5O14EFHPA?G6L4Ef5[15mWK`=UJg<4Jfmf171cN0AdMW/4
MgQm17YkP0AlOH43Ng^017UhN`AiMWT4NgIh17egN0B0NGP3Q7]j18QmN`B<P7d4T8>019F7PPBJRXD4
WXj85Oooo`005?ooo`BYVI<4[j2K1;FXX`Bk/:/4`[Rd0lW1_@C@b/L4f=CB1>7Ng@C[j^T4loCd0ng_
l0CNhN@4d=GI1<79cPBa^l84XJjf196OZ@>3U9h4M8JB16IkR0AJL7l4CfIf14INKP@nEfP3=E1R131<
GP@YAUT49D=F12=1E0@Q@5@37SiB11`mD@@M?E447ciB12=0D`@W@eD4;DMH0cA<F`@mDEl4AEIR14mL
I`AGHF/4GfM_0fE[L`A[KgH4L7=h17AfN`AgN7d4NW^017amP@=kNh04NGQk17UfN@AkMWP4OGMh181i
N0>4NgX4R7ek18b0O@B@Ph04UHN219Z:Q@BNSXPEoooo000Doooo1:VIT`B_X9/4]JRS1;^`Z`C2^;@3
bL6m1=3:a`CHe=84hMkM1>_Zj@Ccm?@3kNo`1=kQi0C@eMT4`LW>1;6k`PBQ[[H4TInY0h>DWPAdQY84
IW^815Y`O`A?IWH4AUi^13iGJ0<eD684<4aN12U6F@@U@eH48d5D1250E0<N?U8473eA11dmD@@O?U84
8d1C12M3E@@]AeP3=4aK13eAG`A5EV84CeaW15MQJ`AOIfl3IF]c16]_MPA`LgP4M7Ik17MhO@AjNh04
O7f10g]kP0AiN7/4NGIi17]fN0AmMgP4P7Uh0hAkNPB8OG/4S81m1923P0BEQh84VXZ519j>R1Goool0
01Coool4ZIRB1:nPVPBeYj84^jnZ1<6g/`?8_k`4clS51=OBc`CPg=X4jNOV1??clP?emOH4jN_/1=_O
hPC=dmL4_LG;1:nj`0BR[[H3UJ>/18FEX0AgR9@4K7j:165ePPAHKG/4D6Ie0dMOK`A3Ff/4?EIW13UC
I0@eD6<4<dmQ0c9>H0P`CEl4<TiO13I@H@@jDV<4?eIU0dEJJ0A=GV/4E69^15]WL@ASK7D4Jg5i0g5e
O0AfNGl4O7f217n0Q0B1PXH4Q8F918B4R0>1P8<4P7f0181lO@B1Ng`4Pgal18EmO0>8OWd4Rh1n18n3
P0BCQH84UhR419^;QPBOSXPEoooo000Doooo1:VHTPB_X9X4]JNR1;^_ZPC1]k<3b;nl1<o8a@CGd/l4
h=cJ1>WWiPCclo83mOGf1>W[k0CKgn84cM?G1;g5b`B_^/04XZjf0iFS[0B5UJ04MhRD16anRPAQMH84
F6ek151VM@=7Gfl4@e][13eFI`@iDf@4=E1S13=?H@<bCV08<4eO139>G`@fD644>U9S13mFI@=5FVP4
CEi[15ARKPAKIg44Hfae16]aN@=aMG`4MWUo17amPPAoP8@4PH:618B5R@B4Q8P3PH23181mP0B0O7d4
PG]l18=lO0B5OG`3R7im18^0OPB?Ph04ThF219N8Q0BKRhH4Whj85Oooo`005?ooo`BYV984[j2J1;FW
XPBk[jX4`KNc0lRo_0C?b<D4em;?1>3LfPCYinH4lo?b0oGemPCYjn`4fmoR1<gCe`BmaL/4[k[01::^
]P>EXj`4QIFP17N8U0A/OXX4HGF215Q]N`A@IWD3Aem_14=KJ`@mEVL4>E=T13E@H`@cCf43<TiP231=
G`@bCUl4=U1Q13YBH`@oEVD3AEYX14eNJ`ADHVh4FfMa16=/M@A[LGT3LGEl17IiO`AlOH84Oh241862
QPB4QHT4Q8B80h60P`B0OH04P7am185kO0B3O7`4QGel0hQnO@B;P7h4Sh>019>5PPBGR8@4Vh^619n>
R1Goool001Coool4ZIRB1:nPVPBeYj84^jnZ1<6g/`?8_k`4clS51=OBc`CPg=X4jNOV1??clP?emOH4
jN_/1=_OhPC=dmL4_LG;1:nj`0BR[[H3UJ>/18FEX0AgR9@4K7j:165ePPAHKG/4D6Ie0dMOK`A3Ff/4
?EIW13UCI0@eD6<4<dmQ0c9>H0P`CEl4<TiO13I@H@@jDV<4?eIU0dEJJ0A=GV/4E69^15]WL@ASK7D4
Jg5i0g5eO0AfNGl4O7f217n0Q0B1PXH4Q8F918B4R0>1P8<4P7f0181lO@B1Ng`4Pgal18EmO0>8OWd4
Rh1n18n3P0BCQH84UhR419^;QPBOSXPEoooo000Doooo1:VHTPB^WiX4]:JQ1;Z^Z@C0]K43akfj1<k6
``CEcld4g]WG1>OThPCalNl3n__j1??dm@CVjN/4f]kQ1<cBePBna//4/;[00jF_]`BHY:d4RYRR17n?
V@AeQI04K7f916EfP`=ML7d4EV]h155VM@A=Hg84BV1`14QNK`=6GFh4AEa]14ILK@A7GFd4C61_151S
L@AEIW@3FVYf161]N0AUL7X4JW=l171gO`AgO883OH2618:4R0B5QHT4QXJ:18V9S@B:RXd4R8N:0hN4
QPB6PX@4QX2118J0P0B7P7l4RH1o0hb2P0B>Ph44TXF219F7P`BHRHD4W8b71:2?RAGoool001Coool4
ZIRB1:jOVPBdYZ44^ZjY1<2e/@?7_KX4c/K31=G?c@CNfML4inCR1?7ak`?jnoX4loCe1>KYj`CJg^44
c=;F1;k6b`B`^/03YJng19RT[@B:V:84OhnI17F5T0A/OHT4IGJ30ee`O@AFJgP4DFIe14eSLPA:H704
B5i_0dIMKPA5G6d4AUa]14MMK@A<H6l4D6=a15EVM0=JJWH4H6eh16E`NPAZLg`4L7Mo17MlPP=mP8H4
PXB818F5R@B6QXX4RHV=18Z:S@B8QhX3QhB618J2Q0B6P844QX2018N0O`B9P7l3S8:018j3P@BBQH84
UHN319R9Q@BLS8L4X8n95Oooo`005?ooo`BYV984[YnJ1;BVX@Bj[ZT4`;Fa0lNm^PC>a/<4eLo=1=kI
e`CWi>84lO7_0o[knPCcm?D4i^W[1=[Nh@C<d]H4_/K;1;2j`0>U[kL4V:B]18ZHXPAoSiT4MHF@16am
R@AUMX<3GG1m15I[N0AAIWD4CF=b14YPL0A8GVl3AUe^14ELK@A6G6d4Aee]14aPK`A@Hg44EFId0eYZ
MPAPKGP4IG1j16YcO0A`Mgl4Mgb20gf0QPB2Q8P4QHF918J6RPB9RHd4RXZ=18R7RP>7Q8H4QX:418J0
P@B6P804Qh1o18V0O`><PX04SX>119:5PPBEQh<4V8V519b<Q`BPShTEoooo000Doooo1:VHTPB^WiX4
]:JQ1;Z^Z@C0]K43akfj1<k6``CEcld4g]WG1>OThPCalNl3n__j1??dm@CVjN/4f]kQ1<cBePBna//4
/;[00jF_]`BHY:d4RYRR17n?V@AeQI04K7f916EfP`=ML7d4EV]h155VM@A=Hg84BV1`14QNK`=6GFh4
AEa]14ILK@A7GFd4C61_151SL@AEIW@3FVYf161]N0AUL7X4JW=l171gO`AgO883OH2618:4R0B5QHT4
QXJ:18V9S@B:RXd4R8N:0hN4QPB6PX@4QX2118J0P0B7P7l4RH1o0hb2P0B>Ph44TXF219F7P`BHRHD4
W8b71:2?RAGoool001Coool4Z9RB1:jNV@BcYJ04^JbW1;nc[`?5^kL4c<?01=?<b@CKeM<4i>3N1>g[
jP?jnOT4o_kn1?CemPCVjN/4fMgP1<cBe@C0al`3][k41:^d^`BOZK44UJ2X18VFW`B0SYL4NHNA0g:1
S0A[O8H4IgR316AeP@APLGh4GFml0ea^N`AKK7X4G6ej15i^N`ASLGd4IG=o16YfP@=_NH<4M7b517Qo
QPAmPXP4PXF;18N9SP>;Ri04SXjB19:@T`BBTI<8SXb?18f:S0>;QhT4RhF618Z4Q0B;Ph<4S8>218f3
PP>?Q884THF319B7Q0BGRHD4VX^619f=R0BPShTEoooo000Doooo1:RHTPB^WYT4/jFP1;V/Y`Bo/jl3
aK^g1<c3`0CCc<T4fmGC1>CPgPC]jnX3n_Wi1?knoPCdmOH4i^W[1=WMh0C<d]D4`<O<0kJna0B[];/4
WjVa19FPZ0B9UYl4P8jG17V7T@=bPH`4Jgb616MhP`ATMH44H75n15e_O0=LKW/4Ffaj15a]NPANKW/4
Hg5m16EcO`AZMX43KgV317AlQ@AhOhH4OH:818:5R`B7RHh3Rh^@18j>TPBBT9<4TY6C28j<S`B=RX`3
RhN918^5QPB:Q8@4Rh>318b3PPB=Ph83ShB21965P`BDQh@4UhV519Z;QPBMSHP4X8n95Oooo`005?oo
o`BXV984[YjI1;>UX0Bi[:L4_k>_0lFk]`C<`l04dlc91=_Ed`CTh=h4kN_Z0o[in@Cno_h4m?Gf1>KY
j`CIgN04c=;E1<37c0>f_/@4ZkBk19nY/@BEX:P4RIJO182>U`AiQi43LX6<16]lQPAWN8<4I7F1161a
OPAMKg`3G6ik15]/NPALKGX4GVik16=aO@AULgl4JWJ10fmiP`AdO8D4N7n617f2R0B2QH/4QhV>0h^;
T0B>SY84TY2C19:AT`R>S8l4SHZ<0h^7R@B;QHH4RXB418^3P`B<Ph84SH>20hn4PPBAQH<4U8N419N9
Q@BJRhH4WHf81:2?RAGoool001Coool4Z9NA1:fMV0BbY9h4^:ZU1;fa[@?3^;@4bL2l1=38a@CGdLh4
gm[H1>SUh`?bl>l4oOcl1?ooo`CemOH4inSZ1=[Lg`C?dmH3a/_>1;g3b0Bc^[l4Z[6g19nW[`BFWjL4
SiVP0hVCV`B3SiL4OXZB17V5S`AePX`4LWn:0g5mR0A_O8L4Kgb6171mQ`AfP8X4O8F>1827T0>3R904
Qh^A18b>T`B?T9@4TI6E19BCU`>HUYT<V9NJ19JDU`BCT984THf>0i2:R`B?RHT4ShN718n6Q@B@QXD4
THJ40i:7Q0BDR8@4UXV519V:QPBKS8L4WXj81:2?RAGoool001Coool4Z9NA1:fMV0BbY9h4^:ZU1;fa
[@?3^;@4bL2l1=38a@CGdLh4gm[H1>SUh`?bl>l4oOcl1?ooo`CemOH4inSZ1=[Lg`C?dmH3a/_>1;g3
b0Bc^[l4Z[6g19nW[`BFWjL4SiVP0hVCV`B3SiL4OXZB17V5S`AePX`4LWn:0g5mR0A_O8L4Kgb6171m
Q`AfP8X4O8F>1827T0>3R904Qh^A18b>T`B?T9@4TI6E19BCU`>HUYT<V9NJ19JDU`BCT984THf>0i2:
R`B?RHT4ShN718n6Q@B@QXD4THJ40i:7Q0BDR8@4UXV519V:QPBKS8L4WXj81:2?RAGoool001Coool4
Z9NA1:fMV0BbY9h4^:ZU1;fa[@?3^;@4bL2l1=38a@CGdLh4gm[H1>SUh`?bl>l4oOcl1?ooo`CemOH4
inSZ1=[Lg`C?dmH3a/_>1;g3b0Bc^[l4Z[6g19nW[`BFWjL4SiVP0hVCV`B3SiL4OXZB17V5S`AePX`4
LWn:0g5mR0A_O8L4Kgb6171mQ`AfP8X4O8F>1827T0>3R904Qh^A18b>T`B?T9@4TI6E19BCU`>HUYT<
V9NJ19JDU`BCT984THf>0i2:R`B?RHT4ShN718n6Q@B@QXD4THJ40i:7Q0BDR8@4UXV519V:QPBKS8L4
WXj81:2?RAGoool001Coool4Z9NA1:fMV0BbY9h4^:ZU1;fa[@?3^;@4bL2l1=38a@CGdLh4gm[H1>SU
h`?bl>l4oOcl1?ooo`CemOH4inSZ1=[Lg`C?dmH3a/_>1;g3b0Bc^[l4Z[6g19nW[`BFWjL4SiVP0hVC
V`B3SiL4OXZB17V5S`AePX`4LWn:0g5mR0A_O8L4Kgb6171mQ`AfP8X4O8F>1827T0>3R904Qh^A18b>
T`B?T9@4TI6E19BCU`>HUYT<V9NJ19JDU`BCT984THf>0i2:R`B?RHT4ShN718n6Q@B@QXD4THJ40i:7
Q0BDR8@4UXV519V:QPBKS8L4WXj81:2?RAGoool001Coool4Z9NA1:bLU`BaXYd4]ZRS1;^^ZP?0]K44
a[bh1<c3`0CCblP4f]CA1>;Mf`?ZinD4lo7`1?glo0Coo_h4mOCd1>OWj@CKg=h3d]GG1<c?dPC5b</4
_L331;Fh_0B[/;D4Y:V_0ifSZ@BHWZ@4TiZP18jFW@B;TYX4R8nG0hF=U@B4Ri@4PXVB18>:T@B5Ri84
RHfD192CV0>FUi/4V9RL19^JW@BLVYd4WI^M19jLWP>PWZ04XZ2R1:2OXPBNW9h4VYJH19NBU0BESi03
U8f=19>;R`BBRXT4TXV719>8QPBDR8H3UHV619J9QPBHRXH4VX^719b=R0BOSXT4XI2:5Oooo`005?oo
o`BXUi44[9bG1;6RW@BfZ:<4^jjZ0l2e/@C6_;P4c<?01=?;b0CJe=44h]gK0n[Wi@CclO04oOcl1?on
oPCem?@4inOY1=_LgP?BeML4c<oB1<G8b`Bm`<<4]KRl1:^`]@BTZJl3WJ>Y19RNY0BCVZ04SYJM18^B
VPB8SiL3QHfE18B;U0B2RI84PhZA18F;TPB9SI@4T9>H0iJGV`BHV9`4ViZM19bJW@BMVid4WYbN0j2N
X0BRX:84X9nR19jLWPBJUYP4Ui:D19F?T0>DSHd4Th^;19::R@BBRHL4ThR619B8QP>ERHH4UXV619R:
QPBJRhL4W8f819n>R@BQT8XEoooo000Doooo1:RGT@B/W9L4/J:M1;JXX`Bk[ZX3`;Fa1<Jl^0C<`l04
dl_81=[Dd@CRgM/3j^OU1??al0Cmo?`4ookn1?Gdm0CWinT4fmcN0m;Ee`C<cm84aLS;1;g0``Be^;`4
Zk2e1:BY[`>MXjT4V9jT19>JX0B>UYd4Ri:J18R?U`>5SID4Q8^D18:9TPB3RY44QH^B18V=U0B@TiP3
UYNK19RHW0BKVYd4W9ZM19fKW@BNW9h3X9jP1::PXPBPWj84WYbN19ZFV0BGTY@4UHn@0iB=S@BCRh/4
TXZ919:9Q`BCR8H4U8R60iF9QPBFRHH4V8Z619Z;Q`BLSHP4Whj91:6@RQGoool001Coool4Z9NA1:bL
U`BaXYd4]ZRS1;^^ZP?0]K44a[bh1<c3`0CCblP4f]CA1>;Mf`?ZinD4lo7`1?glo0Coo_h4mOCd1>OW
j@CKg=h3d]GG1<c?dPC5b</4_L331;Fh_0B[/;D4Y:V_0ifSZ@BHWZ@4TiZP18jFW@B;TYX4R8nG0hF=
U@B4Ri@4PXVB18>:T@B5Ri84RHfD192CV0>FUi/4V9RL19^JW@BLVYd4WI^M19jLWP>PWZ04XZ2R1:2O
XPBNW9h4VYJH19NBU0BESi03U8f=19>;R`BBRXT4TXV719>8QPBDR8H3UHV619J9QPBHRXH4VX^719b=
R0BOSXT4XI2:5Oooo`005?ooo`BWUY04Zi^E1;2PV`BdYZ44^J^W0kja[@C3]k<4b;jj1<k5`PCEcLX4
fmGB0n?Mf`CZi^@4l^o^1?cjn@Cmno/4lo7a1>SWj0?MgMh4emOI1=;Be@C<cLl4aLG81;no`PBj^[h3
];Fh1:j_/PBXZZh4XjJZ19jQY`BKWZ<3V9^Q19NJX0BEV9d4TYFI19:DV0BEUYX4VIRL0i^JW@BNW9l4
XYnQ1:FQY0BVXj@4YjBU0jRUYPBYYZP4Y::T1:2MWPBMV9T4VYBE19RAT@>GShh4UXf<19F<RPBERhT4
UXZ819J:Q`>GRhL4VH^719Z<Q`BLSHP4WHj819n?R@BQT8XEoooo000Doooo1:NFT0B[ViD4/:2K1;BV
X@BiZjL3_[6]1<>g/`C8_[X4c/G21=G=bPCKeM83hmgK1>[Vi0Cbknh4o?[i1?gkn`CclO44j>OX0mgM
gPCGemT4d];E1<c=c`C5aLP4_ko21;Zj_P>d]KP4[Znb1:RZ[PBSYZX4WZ6W19^NX`>HVj44UiZP19FH
W@BBUIT4TYBH19FFVPBIV9`3ViZM19jLW`BRWj44YJ6T1:JSY0BWY:D3Z:FV1:VVZ0BTXZ@4X9fN19fH
V@BJU9D4V96A0iN?SPBFSH`4UHb:19F;R@BFRXP4UXZ70iN;Q`BIRhL4VXb719b=R0BMSXP4Whn91:6@
RQGoool001Coool4YiJ@1:^KU@B`X9/4]:JQ1;V[Y`>n/Jd4`kNc1<Rn^PC>aL84eLg:1=_EdP?SgM/4
j^KT1?;_kPCln_T4oO_k1??al@CXinP3gMgN1=OGf@CBd]D4c<g?1<G5b0Bo_l84^[Zn0kBe^0B^[k84
Z:Z^1:>VZPBNXJL4VijS0iRKX@BGVZ04UIRM19:EV@BBU9P4UIJJ19VHW0>KVYd4WYbO1::OX@BUXJ@4
YZ>T1:NTY@>XYJH4ZJJX1:BRY0BPWIh4WIRI19ZDU@BHTI43Uhn>19J=S0BES8X4UH^919J:R0BFRXL3
Uh^719V;Q`BJS8L4W8f819f>R0BOShT4XI2:5Oooo`005?ooo`BWUY04Zi^E1;2PV`BdYZ44^J^W0kja
[@C3]k<4b;jj1<k5`PCEcLX4fmGB0n?Mf`CZi^@4l^o^1?cjn@Cmno/4lo7a1>SWj0?MgMh4emOI1=;B
e@C<cLl4aLG81;no`PBj^[h3];Fh1:j_/PBXZZh4XjJZ19jQY`BKWZ<3V9^Q19NJX0BEV9d4TYFI19:D
V0BEUYX4VIRL0i^JW@BNW9l4XYnQ1:FQY0BVXj@4YjBU0jRUYPBYYZP4Y::T1:2MWPBMV9T4VYBE19RA
T@>GShh4UXf<19F<RPBERhT4UXZ819J:Q`>GRhL4VH^719Z<Q`BLSHP4WHj819n?R@BQT8XEoooo000D
oooo1:NFS`BZVY@4[YnI1;:SWPBfZ:<3^ZfX1;nc[PC4^;@4bKnk1<k5`PCDc<T3f]?@1>7Kf@CXhn44
l>cZ1?WgmPCjmoL4l>k]0nKTi0COgMh4f]WJ1=OFe`CBd=84blW;1<K4aP?3`<<4`;fo1;^i^`Be];H4
/K2b1:j//0>ZZJ`4Z:NZ1:JTZ0BUXjD4XZ2S1:FRY0BYY:D3[:JW1:jXZ@B`ZZX4/Zb/1;:/[@B_Zj`3
[j^]1:bYZPBWXj<4XifM19nIV@BMUID4Vi>B0iZ@S`BIShd4V8f;19R=RPBHS8T4VHb80iZ<R0BKS8P4
W8f819f>R@BOSXT4X8n:1::@RQGoool001Coool4YiJ?1:ZJU0B^WiT4/Z>N1;JXX`>j[JP4_k>^1<Bh
]0C9_k/4c/G21=C<b@?Jdm04hM_I1>SSh@C`k>X4nOOf1?[gm`C`k^d3i^CT1=oMgPCJfMX4emKG1=;@
dPC;bL/4a/C60l?0``C0_Kl4^kVk1;Fd]PBa/;84[Zb`0jZY[0BXYjX4YZBX1:FSY@BRX:<4YJ:T1:VT
Y@>/YZL4[ZRY1;2ZZPBb[:`4/Zb]1:n[[0>_Zjd4[:VZ1:NSX`BSWId4WiVI19fEU@BKTi83VY2?19V?
S@BHSH/4V8f:19R<R@BIS8P3VXb819^<R0BLSHP4WHj919n>R@BPShX4XY2:5Oooo`005?ooo`BWUXl4
ZYZD1:jOV@BbXih4]ZRS0kZ]Z0Bo/jh4a;Rd1<Vo^`C>aL84e<c90m[Cd0CQfmT4j>?Q1?3/jPCimoH4
n_Og1?3^k@?Vi>@4gmgN1=[IfPCGe]L4d]3B1<_9b`C6a<H3`l331<2m_`Bk^K/4]KBf1;6`/PB^[;03
ZZV/1:RWZPBVY:P4YJ>U1::PX`BUXZ@4ZJBU0jbVY`B^Z:T4/:ZZ1;:/[0Bb[:d4[j^/0jn[[@B/ZJX4
Yj>S1:>MW@BOVIT4WIFE19^CTP>JT8l4VHn=19R=R`BHSHX4V8b919V<R0>JS8P4Vhb819b=R0BMSXT4
Whj91:2?RPBRT8XEoooo000Doooo1:NFS`BZVY@4[YnI1;:SWPBfZ:<3^ZfX1;nc[PC4^;@4bKnk1<k5
`PCDc<T3f]?@1>7Kf@CXhn44l>cZ1?WgmPCjmoL4l>k]0nKTi0COgMh4f]WJ1=OFe`CBd=84blW;1<K4
aP?3`<<4`;fo1;^i^`Be];H4/K2b1:j//0>ZZJ`4Z:NZ1:JTZ0BUXjD4XZ2S1:FRY0BYY:D3[:JW1:jX
Z@B`ZZX4/Zb/1;:/[@B_Zj`3[j^]1:bYZPBWXj<4XifM19nIV@BMUID4Vi>B0iZ@S`BIShd4V8f;19R=
RPBHS8T4VHb80iZ<R0BKS8P4W8f819f>R@BOSXT4X8n:1::@RQGoool001Coool4YYF?1:VIT`B]W9L4
/:2K1;>UW`>gZJ@4^jjY1;nb[PC3^;<4b;fi1<g3_`?BbLH4f<o<1=kFe0CTg]`4jnKT1?C`k`Cglo83
lNg]1>KRh@CNf]X4fmOG1=WFe`CHdm@4e<o@0m3;b`C;aLH4bLC41<S2`PC3_Kd4_KJg0kNb/`Be[k04
/Zf^1;6[Z`B]Z:P4[jVY1;6ZZP>d[:/4]Zj]1;N_[`Bh/;04^;6`1;:^[`>`[:d4[:JV1:RQX@BTWI`4
XIVH19nFU0BMTi43W96?19^@S@BKSh`4Vhj;19^=RPBKSHT7W8f919f>R@BNSXT4Whn91:6@RPBRT8XE
oooo000Doooo1:JES`BYVI<4[IbG1;2PV`BcYIl3]jVT1;^^Z@Bo/Zh4`kRc1<Rm^@C=`kl3d/W61=S?
c0CNe]@4i=kL1>_Vi0Cdl>l4mo?b0o7]k@CVh^44g][J1=_Ge`CIe]L4f=?D1=C?d0?@bl/4blG61<W4
a0C8`/84`kfm1;ff]`>g/[<4]Jn`1;:][PBaZj/4[JRX1:nYZ@BaZZX3]:b[1;J^[@Bg[jl4^;2`1;Ra
/0Bb[Zl3/:b]1:bVYPBXXJ44Y9fL1:6IV0BOUY@4WI>A0ibAS`BKT8d4Vhn<19^>R`BKSHX4Vhf91ib=
R@BMSXT4WXj919n?R@BQT8X4XY2:5Oooo`005?ooo`BVUHl4ZIVC1:fLU`B`X9/4/jFO0kNYY0Bk[ZT4
_k:^1<>h/`C8_KT4cL>o0m;9aPCHcl`4g]KD1>CNg0C[i^@4m?3_1?OclP?akNd4i^;Q1=kJfPCKemL4
fMKG1=SCe0CDcm03d<_;1<_5aPC9a<@4b<;21<>m_@Bm][L3]k:c1;F_/0Bb[Jh4/J^[1:fXZ0B_ZJT4
/JZZ0kB/Z`Bf[Zd4]jn_1;R`/0Bh/K04/Zj_0k2/[@B/YZH4Z:6Q1:BMW0BQVIP4WiJD19fCT@>LTHl4
Vi2=19^?S0BKSX/4Vhf:19^=R@NLSHT4WHj919j>R@BOShT4XI2:1::@RQGoool001Coool4YYF?1:VI
T`B]W9L4/:2K1;>UW`>gZJ@4^jjY1;nb[PC3^;<4b;fi1<g3_`?BbLH4f<o<1=kFe0CTg]`4jnKT1?C`
k`Cglo83lNg]1>KRh@CNf]X4fmOG1=WFe`CHdm@4e<o@0m3;b`C;aLH4bLC41<S2`PC3_Kd4_KJg0kNb
/`Be[k04/Zf^1;6[Z`B]Z:P4[jVY1;6ZZP>d[:/4]Zj]1;N_[`Bh/;04^;6`1;:^[`>`[:d4[:JV1:RQ
X@BTWI`4XIVH19nFU0BMTi43W96?19^@S@BKSh`4Vhj;19^=RPBKSHT7W8f919f>R@BNSXT4Whn91:6@
RPBRT8XEoooo000Doooo1:JDSPBXUi44ZiZD1:jNV0B`XI/3/jFO1;JXX`Bj[:L4_K2/1<6e/0C5^KD3
bKjj1<k4`0CBbLH4f<o<1=gFd`CSg=X4jN?P0noYi`C]inH4iMkM1=oHe`CJeM@4f=;B1=K?c`?Ec/d4
dl[91<o6a0C;`/04b;nm1<Bk^0?0]kD4^[:`1;R`[PBg[jh4]Jj]1;F^[0Bg[jd3^[6`1;bc/@Bl];<4
^[:c1;^d]@Be[jl3[jRW1:^SXPBXWid4YI^I1::HUPBPUY<4WiBA0ijBS`BMTHd4WI2<19f?R`BMShX7
WHj:19j>R@BOShT4Whn:1:2?RPBQT8X4XY6:5Oooo`005?ooo`BVU8h4Z9NA1:^JU0B^WYP4/:6K0k>U
W`BfZ:<4^ZbW1;f`[0C1]K04aKVe0lVn^PC>a<04d/W61=S?c0CMe]<4hmcJ1>WSh0?_jNL4kNOV1>GN
g@COf=L4f]GD1=SBdPCFcll3eLk=1=?:b@C?a/@4bl;01<Ro_@C4^kP3`;Ne1;Zb/0Bh/:h4]jn^1;F^
[@Be[Z`4]jn]0kZa/0Bl/k44_;Bc1;Zb/`Bk];D4]Jn_0jnXY`B[Xj84Z9nM1:FKV@BRV9H4X9JC19nD
T@>NTXl4WI6=19f@S0BMSh/4WHn:1if>RPBNSXT4Whn919n?RPBPShX4XI2:1::ARQGoool001Coool4
YYB>1:RGT@B[VY@4[YjH1;2QV`>cYIl4]ZRS1;Z/Y`Bm/:`4`KF`1<Fi]@?9_[X4c/C01=;9aPCHcl`4
gMKC1>?LfPCYhn03knWW1>gWiPCUg]d4gmSG1=[Ee0CHd]84e/o?0mG>c@CCb/T4clK41<_2`0C8_kd4
a;^h0l2g]@Bj/[04^;2^1;N_[PBe[Zd4]Jj/1;N_[@>j/K04_;>a1;bd/`Bj/[<4^kBe1;F_[`>_Z:L4
Zj>R1:ROW@BUViT4XYRF1:2FT`BOU943WY:?19fAS@BMT8`4WHn;19f?RPNMSXX4WXj919n?R@BOShX4
X8n:1:6@RPBRTHXEoooo000Doooo1:FCS@BWUHl4ZIRB1:^KU@B]WIL3[j2J1;:SW@BdYZ04]jVT1;Z/
Y`Bm/:/3`;>_1<>g/`C7^kL4bl2l1<o5`@CCb/H4f<o;0mcCd0CSfmL4iMcI1>?Je`CMe=44e/g<1=K<
b`?EblX4d/S61<o4`@C;`;h4bKjl1<Nk^@?5^KH4`[Nd1<2e/PBl/k04^k:_1;Zb/0Bi/[03^k>a1;^c
/PBo^;P4_[Nf1;N_[PBbZ:L3[J>Q1:ZOW@BWW9T4YIVF1:>GU0BRUI44X9>@0j2BSPBOTHd4Wi2<19j@
R`BNSh/;Whn:1:2?RPBPT8X4XI2:1::@RPBSTH/Eoooo000Doooo1:FCS@BWUHl4ZIRB1:^KU@B]WIL3
[j2J1;:SW@BdYZ04]jVT1;Z/Y`Bm/:/3`;>_1<>g/`C7^kL4bl2l1<o5`@CCb/H4f<o;0mcCd0CSfmL4
iMcI1>?Je`CMe=44e/g<1=K<b`?EblX4d/S61<o4`@C;`;h4bKjl1<Nk^@?5^KH4`[Nd1<2e/PBl/k04
^k:_1;Zb/0Bi/[03^k>a1;^c/PBo^;P4_[Nf1;N_[PBbZ:L3[J>Q1:ZOW@BWW9T4YIVF1:>GU0BRUI44
X9>@0j2BSPBOTHd4Wi2<19j@R`BNSh/;Whn:1:2?RPBPT8X4XI2:1::@RPBSTH/Eoooo000Doooo1:FC
S@BWUHl4ZIRB1:^KU@B]WIL3[j2J1;:SW@BdYZ04]jVT1;Z/Y`Bm/:/3`;>_1<>g/`C7^kL4bl2l1<o5
`@CCb/H4f<o;0mcCd0CSfmL4iMcI1>?Je`CMe=44e/g<1=K<b`?EblX4d/S61<o4`@C;`;h4bKjl1<Nk
^@?5^KH4`[Nd1<2e/PBl/k04^k:_1;Zb/0Bi/[03^k>a1;^c/PBo^;P4_[Nf1;N_[PBbZ:L3[J>Q1:ZO
W@BWW9T4YIVF1:>GU0BRUI44X9>@0j2BSPBOTHd4Wi2<19j@R`BNSh/;Whn:1:2?RPBPT8X4XI2:1::@
RPBSTH/Eoooo000Doooo1:FCS@BWUHl4ZIRB1:^KU@B]WIL3[j2J1;:SW@BdYZ04]jVT1;Z/Y`Bm/:/3
`;>_1<>g/`C7^kL4bl2l1<o5`@CCb/H4f<o;0mcCd0CSfmL4iMcI1>?Je`CMe=44e/g<1=K<b`?EblX4
d/S61<o4`@C;`;h4bKjl1<Nk^@?5^KH4`[Nd1<2e/PBl/k04^k:_1;Zb/0Bi/[03^k>a1;^c/PBo^;P4
_[Nf1;N_[PBbZ:L3[J>Q1:ZOW@BWW9T4YIVF1:>GU0BRUI44X9>@0j2BSPBOTHd4Wi2<19j@R`BNSh/;
Whn:1:2?RPBPT8X4XI2:1::@RPBSTH/Eoooo000Doooo1:FCS@BVU8h4YiJ@1:RGT@BZVI<3Zi^E1:fM
U`B_WiT4/:6K1;:SWPBdYZ03]ZRS1;V[YPBk[ZT4_[2/1<6d[`C3]k84a[Zf0lVm^@C<`K`4c/>n1=34
_`CBal84d<K11<g3_P?=`[h4c<6o1<c1_@C9_KX4`kRe1<6e/`>o/k04_K:^1;fa[@Bk[j`4^:jZ1;R]
ZPBi[jd3_kJc1;^b[`Bg[JX4]:VW1;6UXPB]XIh3ZYjJ1:RKU`BVVID4YINC1:>ET@BRU8l4XY>>0j6B
S@BQTH`4X96<3:2@R`>PT8X<XI2:1::@RPBRTHX4Xi6;5Oooo`005?ooo`BUThd4YYB>1:NFT0BXUi44
ZYVC0j^KU@B]WIL4[inI1;2QV`BbXih4]:JP0kJXX`BiZjH4^jjY1;j`[0C1]:l4`kNb1<Jj]P?9_KT4
c<6l1<k3_PC@a;l4d/O21=36`@C=`kh3cL:n1<c1_`C<`Kd4bKfj1<>h]@C1]K<3_k>`1;fb[PBm/Jd4
^jn/1;R^ZPBh[JX4^Jn]0knf/`Bk/Zl4]jfZ1;BYY`BaYJ84[J6N0jZNVPBXViL4YYVE1:FGT`BSUI44
XYB?1::CSP>QTXd4XI6<1:2AS0bPT8/3X92:3:6@RPBRT8X4XY6:1:>ARaGoool001Coool4YI>=1:JD
SPBWUY04Z9NA1:ZIT`>[ViD4[IfG1:nOV@B`XI/4/Z>N1;BVX0>fZ:<4^J^V1;^^Z@Bn/:`4`KB_1<>g
/PC6^[H3bKfi1<c1_0C>`kh4d<Bo1=;7`PC@a/44cL>n0lg2_PC<`Kl4c<6m1<Vm^PC3^;D4`KFc0knc
/0Bm/Zh4_K6]1;^_[0Bh[ZX4^:fZ1;V_[@>o][<4^k:_1;N]ZPBdZJL4/JFR1:fQWP>ZWYX4Z9^G1:JI
U@BUUi<4XiFA1::DS`BRThh3XI:=1:6AS0BPTH`<X92;0j2@RPbQT8X4XY2:1::ARPBSTH/Eoooo000D
oooo1:FCS@BVU8h4YiJ@1:RGT@BZVI<3Zi^E1:fMU`B_WiT4/:6K1;:SWPBdYZ03]ZRS1;V[YPBk[ZT4
_[2/1<6d[`C3]k84a[Zf0lVm^@C<`K`4c/>n1=34_`CBal84d<K11<g3_P?=`[h4c<6o1<c1_@C9_KX4
`kRe1<6e/`>o/k04_K:^1;fa[@Bk[j`4^:jZ1;R]ZPBi[jd3_kJc1;^b[`Bg[JX4]:VW1;6UXPB]XIh3
ZYjJ1:RKU`BVVID4YINC1:>ET@BRU8l4XY>>0j6BS@BQTH`4X96<3:2@R`>PT8X<XI2:1::@RPBRTHX4
Xi6;5Oooo`005?ooo`BTTX`4YI><1:FDS@BVU8h4YiF?0jNFT0BXUi44ZIRB1:ZIT`B[VY@4[9^F0jfM
U`B^WYP4[inJ1;6QV`BbXYd4/jBO1;FVX0>fYj84^:VS1;VZY0BiZjD8^Z^V1kV[Y@BiZjH4^ZbW1;f_
Z0Bl[ZP4_:jY0k^]Z@Rj[:P8^JbX1;R[Y`BbYJ43/:>N1:nQW@B]Wi/4[9fI1:ZKU`BXVID3YiRC1:JF
T@BUUI04Y9B?1:>CSPBSThd4XY:=0j:BS0BRTH`OXY6;3:>ARaGoool001Coool4Y9:<1:FCS0BUU8d4
YYB>1:NES`>WUY04Z9NA1:VHTPBZVI<4ZiZD1:bKUP>]WIL4[YjH1:nOVPBaXI/4/Z:M1;>TW`BeYZ03
]ZNR1;RYX`BiZZ@4^J^U2;Z[YPNiZjD4^J^V1;Z/Y`Bm[jP4_:jX1;b^Z@>k[JT8^ZbX2;V/Z0BhZjL4
/ZFQ0k2SWPB_XId4[InK1:bMV@BZViL4Z9VE0jNHT`BVUY44YIF@1:BDS`BSThh4Xi>=1::BS@>RTX`4
XY6<7j:AR`bSTH/Eoooo000Doooo1:BBS0BUTh`4YIB=1:JDSPBWUHl3YiJ@1:RGT@BYV984ZYVC1:^J
U0B/ViH3[IfG1:jNV0B_WiX4/J6K1;:RW@BcY9l4]JJP0kJWXPBhZJ<4^JZT1;V[Y@RjZjH7^J^U1;V[
YPBj[:L4_JnX1;b^Z0Bl[ZT3^jfY2;Z/Z0Ri[:P4^:^W1;:UX@>`Xih4[j6M1:fOV`B/WIT4ZY^G1:RI
U@>WV9<4YYJA1:FET0BTU8l4Xi>>1:>CS@BRTXd3XY:<1::AS1nRTH/<Xi6;5Oooo`005?ooo`BTTX`4
YI><1:FDS@BVU8h4YiF?0jNFT0BXUi44ZIRB1:ZIT`B[VY@4[9^F0jfMU`B^WYP4[inJ1;6QV`BbXYd4
/jBO1;FVX0>fYj84^:VS1;VZY0BiZjD8^Z^V1kV[Y@BiZjH4^ZbW1;f_Z0Bl[ZP4_:jY0k^]Z@Rj[:P8
^JbX1;R[Y`BbYJ43/:>N1:nQW@B]Wi/4[9fI1:ZKU`BXVID3YiRC1:JFT@BUUI04Y9B?1:>CSPBSThd4
XY:=0j:BS0BRTH`OXY6;3:>ARaGoool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool009Woool30000Q?ooo`00W?ooo`030000oooooooo087oool0
07_oool500000_ooo`800004oooo0P0000Coool400000_ooo`<00003oooo0`0000?oool20000O_oo
o`00OOooo`050000oooooooooooo000000;oool010000?ooooooo`0000;oool010000?ooooooo`00
00;oool010000?ooooooo`0000Goool010000?ooooooo`0008?oool007goool01@000?oooooooooo
o`000002oooo00@0003oooooool00002oooo00@0003oooooool00002oooo00<0003oooooool01000
00;oool010000?ooooooo`0008?oool007goool00`000?ooooooo`02oooo0P0000?oool010000?oo
ooooo`0000?oool300000oooo`800004oooo100008;oool007goool01@000?ooooooooooo`000002
oooo00@0003oooooool00002oooo00<0003oooooool00oooo`030000oooooooo08goool007coool2
00001?ooo`800004oooo0P0000Goool20000Soooo`00ooooob7oool00?oooolQoooo003ooooo8Ooo
o`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(202) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
968E8B968E8B968E8B968E8B968E8B968E8B968E8B958E8C958E8C958E8C958E8C958E8C
958E8C958E8C958E8C958E8C958E8C958E8D948E8D948E8D948F8D948F8E94908F949192
948F8E948E8D948E8C948E8C948D8B958E8C958E8C958E8C958E8C958E8C968E8C958E8C
968E8C958D8A958C8A958B89948A88948A8794898693888593878492868392858191837F
8F807B918480928682928783938885938985938986948986948A87948A87948B88958B88
958C89958C89958D8A968D8A
968E8B968E8B968D8B958E8B958E8C958E8C958E8C958E8C958E8C958E8D948E8D948E8D
948F8D948F8D948F8E948F8E938F8E938F8E938F8F938F8F929090929091929192929395
929191928F8F928E8D928E8D938D8C938E8D948E8D948E8C938E8D948E8D958D8C948D8C
948D8B948B89948A8893898692878492868391848190837F90817D8F7F7B8E7D788C7A74
8A78728D7C778E7F7A8F817C8F827E908480918481918582928683928784938885938986
948A87948B88958C89958D8A
968E8B968E8C958E8C958E8C958E8C958E8C958E8D948F8D948E8D948F8E948F8E938F8E
938F8E938F8F938F8F929090929090929090919090919091909092909193909295909497
8F9193908F90908E8E908E8E918E8D928E8D938E8E938F8E928F8E938E8E948D8D948D8C
948C8A948B899489879286849184818F827F8E807C8D7D798C7B768B787389756F88716A
88736C8976708A79738B7B768C7D788D7F7A8E807C8F817D90837F908480918682928784
938885948A87948B88958C89
968E8B958E8C958F8C958E8C958E8D948F8D948F8E948F8E948F8E93908F938F8F93908F
9290909290909190909190919190919090919090928F91928E91938E92948E93968E9499
8D91948D90918E8E8F8E8D8E8F8E8E908E8E928E8F938F8F939090939090958F8F948D8C
948B8A94898893878592848290817E8E7E7B8C7B788B787489756F88726B856D66836860
846C6586706987736C88756F8978728A7A758B7C778C7E798D7F7B8F817D90837F918581
928783938885948A87958C89
968E8B958E8C958F8D958E8D948F8D948F8E948F8E938F8F93908F939090929090929090
9190919190919091929091928F91938F91938E91938D91948C91958C92958B92978B9499
8B91948B8F918C8E8F8C8D8E8D8D8E8E8D8E8F8E8E908E8F918F90929090938F8F938D8D
938B899289879286849183808F7E7C8D7A778B777388736E866F69846B6481665E7F6259
81665E826A62846D6685706986736C88756F8978728A7A758B7C778D7E7A8E807C8F837F
918581928784938986958B88
968E8C958E8C958F8D948F8D948F8E948F8E938F8F93908F929090929090919091919191
9091929091928F91938F91938E92948D92948D92958C92958A9196899196889196879298
889094888E91898D908A8D8E8B8D8E8C8C8E8D8D8E8E8D8E8F8D8E908E8F908D8E918C8B
9089889087858F83818F807D8D7C788A767288726E856E6982696380645D7D5F577C5E54
7E61587F645C806860826B63836E6785716A86736E8876718978738B7B778C7E7A8E817C
90837F918682938885948B88
968E8C958E8C958F8D948F8D948F8E938F8F93908F929090929091919191919192909193
9091938F92948E92948E92958D92958C92968B92968A9297899297869196848F95838D94
858E92868D91878D8F888C8E898C8D8A8B8D8B8B8D8B8B8D8C8B8C8D8B8C8D8A8B8E8989
8E86868D83828C807E8B7D7A8A787588736F856D688269637F645D7C5E5679584E79594F
7A5C527C5F567D625A7F665E806962826C65846F6985736D8775708978738B7C778D7F7A
8E817D908480928784948A87
958E8C958E8C948F8D948F8E938F8E93908F9290909290919191929191929091938F9294
8F92948E92958D93968D93968C93978B93988A93988993988793988591987D8B927F8B91
828C91848C90858C8F868B8E878A8D878B8D888A8C898A8B8A898B8A888A8A86888A8586
8A83838A7F7F897C7A887876867471846F6A826A647F645E7B5E5678594F755247765449
77564C785A507A5D547B60587D645C7F6860816B64836F6885726C8776708979748B7D78
8D807C8F837F928783948A87
958E8C958E8D948F8D948F8E938F8F9290909290919191919191929092938F92948F9295
8E93968D93968C93978C94988B94988A949989949A88949A87959B86949B78888F7E8B91
808B90828C90838B8F848B8D848A8C85898C86898C87898A87888A878688888385878082
867E7E867B7B85787784747282706D806A667E65607B5F59775951745349714B40724E43
73504675544A76584E785B527A5F577C635B7E6760806B64836F6985736D8777718A7A76
8C7E7A8F827E918682948A87
958E8C958F8D948F8E938F8F938F8F9290909191919191929092938F92948F93958E9396
8D93978C94988C94988B94998A959A89959B88959C88969C88979E8392997D8C937E8C91
7F8B90808B8F818A8E828A8D82898B83888B84888A84888A858789858587858184857E80
847A7B83767782737381706E7E6B697C66627A615C785B5575554D714E446E463B6E473B
6F4A3F714E4373524875564D775A52795F567B635B7E6760806B6583706A86746F887873
8B7D788E817D908581938986
958E8C958F8D948F8E93908F9290909290919191929092938F92948F93958E93968D9497
8C94988C94998B959A8A959B89959C88969C87969D87979E84949C8091987E8E957E8D92
7E8C917F8B8F7F8A8D80898B80888A81878A81878A82878A84878A838386838082837B7E
8277798172747F6F707D6B6B7B676578625E765D5874585172524A6E4B416B4338694033
6B44386D483D6F4C4271514773554C765A52785F577B635C7E6861816D6784726C877671
8A7B768D7F7B908481938986
958E8C948F8D94908F93908F9290909191929091939092948F93958E93968D94978C9498
8C95998B959A8A969B89969C88969D87979E86979F8798A180929A7E90977E8E957D8D93
7D8C917E8B907D898D7D888A7E87897E86897F878980868982888A828587828284817D7F
80797B7E72737D6D6E7A6868776362755F5C72595570554E6F4F486C4A406A4338673D30
673C2F6942366B473B6D4B4170504773554D755A527860587B655E7F6A64826F6985756F
8979758C7E7A8F8380938885
958E8C948F8E93908F9390909291919191929092938F92958E93968D94978D94988C959A
8B959B8A969C89969D88979E87979F8597A08498A1798E987C8F987C8F977C8E957D8E94
7D8D937D8C917C898D7B868A7B86887C86887C86887E868880878981888A808586808282
807E7F7D75757A6D6E776666746060715C596E56516D524B6C4D466A493F684238663D31
64382B653C2F6741356A463B6C4B416F514872564E755C5479615A7C6761806D6784726D
8778738B7D798F837F928885
958E8C948F8E93908F9290909191929091938F92948F93958E93978D94988C95998B969B
8A969C89979D88979E87989F8698A08498A18297A1788E98798F977A8F977B8E957C8F95
7C8E957D8D927B8A8E7985887985887984887683857C888A7F888A828B8C82898A818384
8082817D7B7A797373736867705E5D6D59576B544F6A4F49694C4468483F674338643D31
62372A613629633B2E65403568463C6B4C426F5249725850765E577A645D7E6A6482706B
8676718A7C788E827E928884
958E8C948F8E93908F9290919191929092938F92958E93968D94988C95998B969B8B969C
8A979E89989F8898A08699A18599A2849AA4778F9B778E98788E97798F977A8E957B8F96
7C91977D90957B8C8F78878A7583867B898B7A87897C8A8B7E8A8B80898A828B8C838686
838484827F7E7E7978746C6B6B5F5E69565567514E664C47664A4367473F664338633D32
61382B5F34265F362A603A2F63403667473D6B4E456F544C745B5378615A7C6862806E69
85746F897B768D817D928784
958E8D948F8E9390909291919191939092948E93968D94978C94998C959A8B969C8A979D
89989F8999A1889AA2869AA38399A2839AA5708A96748D97768E97788F98798F967A9097
7C92997D92977C90937D8D8F7582847883867985867A85867C87887E86878086877F8181
80807F817C7B827B797D7270716664655655634E4B624A4564484165463E644339623E33
60382B5E33245C33265B35295E3A306342386749406C5048715850755F587A655F7F6C67
83736E887A758D807C918784
958E8D948F8E9390909191929092938F92958E93968D94988C959A8B969B8A979D89989F
8999A1899BA3899CA5879CA67F96A07A939E728B97748D97758E97778E97788F96799198
7C949A7D93987E93967F9294798B8D79888A7987897985877B86887D85877D85857D7F7F
7D7C7C7D77767E77757B706D7769676A5C59604C4A60474461464063463E634339613E33
5F392C5E33265B31235A332559352A5F3D3364453C694D446E544D735C5578635D7D6A65
82716C8778748C807C918783
958E8D948F8F9290909191929092948F93958D93978C94998B959A8A969C89979E8898A0
889AA2899CA58A9FA88DA2AD8199A3738E9A748D99748E98748E98758E98768F97789199
7A939A7A9096788C90798C8F788C8E788A8C798A8C7A8A8B7B8A8C7D898A7D88887D8584
7D807E7B79787A767479706D76696670615D63504D5E47435F454062453E62433A613E34
5E392D5D3427592F21512B1D5631265A392E6041386649416B514A71595276615A7C6863
81706B8677738B7F7B918683
958F8D93908F9291919191938F92948E93968D94988B959A8A969B89969D88979F8799A1
879AA3889CA68BA1AA90A5B0899FA879919C748E99738E98738E97748E98758E97769199
78939A78909775898E75888B75888B76888B77888B78898B79898B7B888A7B86877B8383
7A7F7E797A7876767375716D736B6770645E695953614C485F474161463F61443A603F35
5E3A2E5D36295D34264D271B502D2157352B5D3E3463463E694F476F574F745F587A6761
806F698576728B7E7A908683
958F8D93908F9291919192938F93958E94978C94998B959A89969C88979E8698A08599A1
859AA3859BA6869EA8849CA78098A379929D738E99718C97718D96728E97728E97749098
769199768F9673898F71848972858873868A75878A76878A77898B79888A798586798182
787D7D767977737371706D6A6E67636B605B675853624F4A604A4460474061443C604036
5E3B305E382B5D34264A25194D291E5332275A3B3160433A664C446C544D725D5678655F
7E6D688475718A7D7A908582
958F8D93908F9291919092948F93968D94988B95998A969B88969D86979F8598A08398A2
8299A4819AA57F9AA67D97A279929D748E99708B976F8A956F8A956F8B95708C96718E97
728F98738D95728A907084896F828671848872858974858975868977878A778587778082
757B7C7477777171706E6B696B6562685F5B65585361504B604C4660494260453D5F4137
5F3C325F392D60372947231749251A502E2356372D5D40376449416A524B715B5477635E
7D6C678374708A7D79908582
958F8D9390909291929092948E93968D94988B959A89969C87979E8597A08398A18198A2
7F98A47D98A57A96A37793A0738E9A7089946C88946C86926C87926C88936C8A946D8B94
6E8D956F8C946F89906D848A6C80856E828670858872858973858976868A768487758182
737A7B7276766E6F6F6B6967676361665E5B64585461524D604E485F4A435F463E5F4238
5E3D335F3B2E633A2B4C271A4420154C2A1F53342A5B3E3562473F6850496F595275625C
7C6B6582736F897C788F8582
958F8D9390909292929093958E94978C95998A969B88979D86979F8498A18198A27E98A3
7B97A47897A57592A0728F9C6D88956A86926985916884906884906986906987926A8892
6A89936B89926C88906B848A6A80856B80856D82876F8387718488738588748386727E80
70797A6E75756B6E6E68686664615F625C5961575460534E5F4F495E4B445D463F5C4239
5C3E345E3B2F633B2D583022492316462419513228593C3360453D664E476D575174615B
7B6A6481736E887C788F8581
958F8E9391909292939093958E95988C969A8A979C88979E8598A08298A27F98A37C98A4
7897A57594A3708E9D6C889766829064838F64828E64828E65828D65838E66848F66848F
67858F67858F68848D688289687F86697F856B81866D81866F8387718287728184707C7F
6E77796A7173686C6C636564615F5D5F5A585E56535E534E5D4F495B4A445B463E5A4139
593D3359382E5B372C593225532B1E4D291E513127573A315E433B644D456B564F725F59
79686380726D887B778F8481
958F8E9391919292949094968E95998C969B8A979E8798A08599A28199A37E99A57A98A5
7598A67194A36C8D9C668392617E8C5F7E8C607F8C60808C61808C62808C62818C62818C
63818C63818B638089647E86647D84667E846980866B81866D83877082877080846E7B7E
6B7578676F71656A6B6164635E5E5C5C59575B55525B524E5A4E49594A4457453E564039
553B3354362C533429502D214C25194D2A1E50302655382F5B4139624B4369544E705E58
7867627F716C877A778E8481
958F8E9391919293949095978F969A8D989D8A999F8799A1849AA3819AA57D9AA67899A7
7297A66C92A16589985E7F8E5A7A895A7B895B7B895C7D8A5D7E8A5E7E8A5F7E8A5E7E8A
5F7E895F7C885F7B865F7A83607981637B82667D83697F856C82876E82876F7F836D7A7E
6A7477666E706168695D61615B5C5B59575658545257514D574D4955494454443E523F38
503A324F342B4E32284B2A1F46221647251A4C2D2352362D593F3760494267524C6F5C57
7666617E706C867A768E8480
95908E9492929394959196988F979B8D999E8B9AA1889BA3859BA5819CA77C9CA9779BAA
7094A4668C9C5B8292537889527686557786577987597A885A7C895B7D895C7D895B7C88
5A7B875A79855A77835A76805C767E5F7880627B82667E846A81876D82876D7E836B797D
677376636C6E5F66675B6060585A5A565655555251544F4D534C4851484350443E4E3E38
4C38314A322A482F2744261C432116421F1448291F4F332A563D355D474065514A6D5B55
7565607D6F6B8579758E8380
95908F94929293959692979A90999D8E9AA08C9CA3899DA5859DA8819DAA7D9EAC799EAF
7196A662899A547D8E4871834B71824F7484527686557987577B88597C89597C89587B88
577A8655768254737F55717C57727B5A747C5F7880647C836980866B81866C7E8369787D
667275606B6D5C6466585F6055595952545451504F4F4D4B4F4A474D46424C423D4A3D37
48373145322B432E273E241B3C1F153D1B1143261C4B3028523A335A453E624F496B5954
73645F7C6E6A8479758D8380
95908F95939394969793989B929A9F909CA28D9EA58A9FA8869FAA829FAC7E9FAE7AA0B1
7599AA648A9A517A8C416C80456D7F4A71824E7484527887567A88577B88577B88557985
5276834F73804F707D506E7A526D785670795C767E627B826880866B81876C7E8369787D
6572755F6A6D5B6365565E5F5258594F53534D4F4F4C4B4A4B48464B454149403C473C37
44373042322B3F2D2638231B351B1236170D3E221A462D254E383157423C5F4D47685853
71625E7A6D698478748D8380
96918F969494959798959A9D939CA1929FA58FA0A88CA1AB88A1AD82A1AE7DA1B0799EAE
7498A96087994B778A3A687D406B7E466F814B7283507786567C8A597E8C5A7F8C587D89
5278854C7380496E7B4C6D794E6B76516B755A737B617A826780876B82886C7F8569797E
6573755E6A6D5B6466575F605158594D52524A4D4E474948474644474340463F3B433B36
4136303F322C3D2E2735241D2F191131140B391F17422A234A352F53403A5D4B46665651
6F615D796C688377748C827F
96919097959597989A969C9F969FA395A2A893A4AC8FA5AE8AA4B083A2B07CA1B0789CAC
7699A861879949758936657A3C697D426D804771824E7686547B8A5B818F5F828F638490
5D7F8C5378854D727F4D717D51707A536E785A747C617A826781886C83896D81866B7A7F
6775785D696C5B6567565F604E5759495051474C4D43474743444344413F443F3B423A36
3E36313C312C382C262E211B2917102B120A341D163D282146332D503E39594944635550
6D605C786B688277738C827F
979190989596989A9B999EA199A2A698A5AB97A8B094AAB38FA9B585A5B37399AA7297A8
7094A45F869746738831627838677B3F6B7E4570814B7484517888587F8E5D8290658693
6585915F808C58798453758053727C56717B5B757D617B826881886D848A6F83886E7E82
6D7A7D656F71616A6D5A63654E585B495153454C4E3F4546404242413F3E433E3A413B36
3E37323B322D342B25271D181F120D240F082E1A1337251F41302B4C3C3756474361534F
6B5F5B766A678176738B827F
9892919997979A9C9D9BA0A39CA5A99DAAAF9DAEB59CB1BA98B2BE8BABB9759BAB6A91A2
668D9E5781934371862F607736657A3C6A7D436F814871834D7585547B8A5A818F5E8391
5F82905C7F8D597B8855768254747E57747E5B767F627C846881896D848B70848A708084
6E7B7E6C74756C72726B6E6E5860615357584E525345494A44464643424144403C433C38
3F38333D332E312924221B17180E0A1C090427151032211C3C2D294839355345415E514E
695E5A756A668076738B827F
9893929A98989C9E9F9EA3A6A0A9ADA2AEB4A4B4BBA5BAC2A9C2CC96B3BF83A6B47197A7
668D9E537E91406F842D5F763363783A687B426F814873854C7585507787547C8A577F8D
587F8E567C8A54798752758253737F5775805C7881627D856882896D848B70848B708085
6D7B7E6B75776C73737072716769695F61605959584F50504A4A4A47454346423F453E3A
423A363F36312F28241F1A17140E0A16060120110D2C1D1A372A264337334F43405B504C
675C597369667F75728A817F
9994929C9A9A9EA0A1A1A6A8A4ACB0A7B3B8AABAC0AEC1C9B4CBD4A0BBC68CABB8799DAB
698F9F537F923E6F842C607630617638667A3F6C7E4772844E7989537C8B577E8D59818F
5D83915C818F5A7F8C577B885777835978835D7B84627E8768818A6D848B71858B718288
6D7A7F697377687172676D6E6468686063635A5C5B5254534D4E4D4A484648444246403D
443C383F37322C27241A191714100D100300190D0A2519163227243F34314C413E594E4B
655B587268657E75728A817E
9A94939D9B9BA1A2A3A4A8AAA8AFB3ACB7BCB0BFC5B5C7CFBCD1DAABC3CD96B2BE81A2B0
6C92A25580933F6F842D60772D5F753463773B687B426E7F4A7485517B8A577F8D58818F
5B83925C83915C82905A7F8C597B875A7B855D7D87617F886781896C838A71858B75868B
7481856D777C66707460696C5F65675D6162595B5B5355554F504E4C4A484A4644494240
483F3B3F36322B2724161716110F0D0B02000C04021E15132D24213B322F49403D564D4A
645A587067657D74728A817E
9A95939E9C9CA3A4A5A7ABADACB2B6B0BABFB6C3C9BCCCD3C2D6DEB2C9D39FB9C489A7B5
7397A65983954271852F62792C5E733160743865773E6A7B446F804A74844F7888527B8B
557D8D567E8D577E8D577D8B587C8A5A7B875D7D88617E886580886981886E8288738488
778487767F8273797B686F725F6668596061575A5B5356565051504E4C4A4D49474D4643
4D433F3E37332A27251619190C0E0E0A050406010018111028211F38302E463E3C544C4A
625A576F67647C747189817E
9B9594A09D9DA5A5A6AAADAFAFB5B8B5BEC2BAC7CCC1D0D7C8DAE1B9CDD6A7BFC98FADB9
799BAA5F879947748931647B2B5D732E5D723461743A6577406A7B456E7E4972824D7685
507888527A89537B8A557B89567B89587B885B7C875F7D87627E87667E866A7E856E7F84
727F83737E80747B7D7176776C6F706568685F60605A5B5A57565452504E514C4A504946
4F46413F38352D2A281B1D1D0D1010060606020000130F0E241F1E352E2D443D3C534C4A
6159576F67647C747189817E
9B9694A19E9EA6A6A7ACAFB1B2B8BAB8C1C5BFCACFC5D3DACCDDE4BDD0D8ACC3CC96B2BE
7E9FAE658B9C4C788C36677D2A5C732B5B6F305E713662743C6677416A7A456D7D487080
4B73834D76854F7887517887537987567A87597A875C7B865F7B84627B83657B82697B81
6C7B7F6E797D6F777A6E74766C6F70696B6B6465645E5F5D5B595757545255504D534C48
4E46423F39362F2C2A21201F1113130507080000000E0B0C211D1D332E2D433D3C524B4A
6059576E67647C747189817E
9C9695A29F9EA8A8A8AEB1B2B5BABCBCC3C7C2CDD1CAD7DCD1E1E8C1D3DBB1C6D09CB7C2
85A5B36B91A1527E913B6C812C5E7528586E2D5B6F335F713862733D6676416A7A446D7D
476F7F4A72824C74844E75855077865377855578855879845B78825E788161787F64777E
67777D69767A6A73776A7173686D6F66696A6364645F605F5C5B59595654575350554E4B
4C46423E3A37302E2C222222141616070A0C0103040C0A0B201D1D322E2D433D3C524C4A
605A586E67657C747289817E
9D9795A3A09FAAA9A9B1B2B4B8BCBEBFC6C9C6CFD4CEDADFD6E4EBC6D7DEB5CAD3A2BCC7
8DABB87498A75B849743728732647A28596F2B596D315C6F355F713A62733D667641697A
436C7D466F804871814B73834D74844F758452768354768257758059747E5C747D5F747B
627379647277657074656D71656B6D6368696264646060605D5C5A5C58565B5552574F4C
4D46423F3B38312F2D2424241719190B0F100508090D0D0E22202033302F433F3E524D4C
615A596E68667C747289817F
9D9795A4A0A0ABAAAAB2B4B5BABEC0C2C8CBC9D2D6D1DCE1D9E7EDCADAE1B9CDD6A8C0CB
94B0BD7D9EAD628A9C4B788C39697E2C5D732B596D2F5B6D335E6F3760713A63733D6676
40697A436C7D456E7F4770804A72814C73824F738150737F52727D55717B58717A5A7079
5D7076606F75616D72616B6F61696B6166686163646060605E5D5C5D59575B5653564F4C
4B4542403B3933302F2626251A1B1B0F12130A0C0D161516262424363332454140544F4D
625C5A6F68677C757389817F
9D9795A5A1A0ACABABB4B5B6BCBFC1C4CACCCDD4D8D5DFE3DDE9EECEDDE3BED0D8ADC4CE
9BB6C284A4B26C91A2537F923E6E843162782C5B6F2E5A6E315D6F355F703861723B6374
3D66773F697A426C7C446D7D466F7F486F7E4A707E4D6F7C4E6F7B506E79536E77566D76
596D745B6C725D6B705E696D5F676A5F65675F63645F60605E5E5D5E5A585C5653544E4B
4B45433F3B393432302727271B1D1D1114150A0B0D1B1B1B2A292939363648444356514F
635D5C706A687D76748A827F
9E9796A6A1A0AEACABB6B6B6BEC0C2C7CBCDD0D7DAD9E2E6E2EDF1D3E0E7C4D4DBB3C8D1
A2BBC68CAAB87598A85D869846758936687D2D5D722D5A6E305C6E335D70365F71386172
3A63743C66773E6879406A7B426B7C436C7B466D7B486C79496B774C6A764E6A74516A73
55697257697059696E5B676C5C65695D64665E62635E60605D5D5D5C5958595452514D4A
4844423D3B393231312727281B1D1E1216170F10112020202F2D2D3D3A3A4B4746585352
655F5E716B697E77748A8280
9E9896A6A2A1AFACACB7B7B7C0C1C2C9CCCED2D8DBDDE4E7E7F0F4D9E5EBC9D9DFB9CCD5
A8C0CA94B0BD7D9EAD678D9F507C903E6F843061772D5B702F5C6F315D70345E70366072
3862733964753B66773D68793F697A4069794169784368764467744666734966724C6771
50666F53666E55666C58656A5A64685B63665D61635D60605C5D5C5A58575653514E4B4A
4643423D3B393332312828281D1F1F1517181B1B1C272627343232413E3E4E4A495B5655
676160736C6B7F78758A8380
9E9896A7A2A1AFACACB8B7B7C1C2C3CBCDCFD5D9DBDFE6E8EAF3F6E0EBF0D0DEE4C0D2DA
B1C6CF9DB7C287A6B47195A55C859748778B37687E2F5E732E5C70305D71325E70345F72
3560733762743763753965763B67783B66773C65763D65743F637141627044636F47636E
4B636D4E636C51636A5463695763675962655C61635D60615C5C5C5857575351504B4A49
4342413C3B3A3232322728291C1F201315162121222D2C2C3A3837464342524E4D5E5957
696362756E6C8079768B8381
9E9896A7A2A1B0ACACB9B7B7C2C2C2CCCECFD6DADBE1E6E9EDF4F7E7EFF3D8E4EAC8D8DF
B8CCD5A7BEC892AEBA7D9DAC6A8FA057819343728635657A305F74305E72315D71325E72
335F7234607335617435627437647637647637627338617139606F3C5F6D3E5F6C42606C
46606B4A61694E60685160675461665761655A60625C60605A5C5C5757565151504A4A49
4242413A3A3A31323227292A1F2222191A1A2727273432323F3D3C4B4746565250615C5A
6C666476706E817A788C8481
9F9896A7A2A0B0ACABB9B7B6C2C2C2CCCDCED7D9DAE2E6E8F0F5F7EFF6F9E1EAEFD1DFE5
C1D2DAB2C6CF9EB6C189A6B37799A8658B9C547E9142708438687C326277315F73325F73
325E72315F73315F73326073346274336274315F71315D6E335C6C365C6B395C6A3D5C69
425E69465E684A5F674E5F66536066566165585F635B5E605A5B5C5656565150504A4A49
4343423B3B3B323333272A2B222425252525302F2E3A3938454242504C4B5A5654645F5D
6E6867787270827B798C8482
9F9895A7A2A0B0ACABB9B6B6C2C1C1CCCCCDD7D8D9E2E5E6EEF2F4F5FBFDEAF1F4DAE5EA
CAD8DFBBCDD5A9BFC994AFBB85A2AF7496A5668B9C557E904874873E6D8138667A366477
336175305F73305E72315F733261743261742F5E712D5B6E2E5A6A315969345A69395B68
3D5C68415C66465D664C5E66515F665561655860635A5E60585B5B5556565151504A4A4A
4444443C3D3D3435352B2D2E2324242E2E2D383636413F3E4B48475551505E5958686261
716B697A7472847C7A8D8582
9E9795A7A19FB0ABAAB9B5B4C2C0BFCCCBCBD6D6D7E1E3E3ECEFF0F8FCFDF3F8FBE3ECEF
D5E0E5C6D4DBB5C7CFA0B8C291ABB783A0AD7596A4688B9B5B8192507A8B497385436E80
3E6A7D396679356377356276366376346276326073305D702E5B6C2F596A325A69375B69
3B5C68405D67445C664A5E665060665561655760635A5E60585B5C5657575252524C4C4B
4645453F3F3F3838383031312D2C2C373635403E3D494645514D4C5A5554625D5C6B6564
746D6C7C7573857E7B8D8683
9E9795A7A19FAFAAA9B8B4B3C1BEBECAC9C9D4D4D4DFE0E0EAECECF7F9F9FBFEFFEDF2F5
DEE6EACFDBE0C1CFD6AFC1CA9EB5BE91AAB583A0AC7695A36A8C9B6084945A7E8E537989
4C7586467081426D7F3E697B3E697B3C6779396577366274345F70335C6D355C6C395D6B
3D5D6A415E69465E684B5F685161675662665860635A5F61595B5D5758585353534E4D4D
4847464342413E3C3B3636353B3938413F3E484544504C4B5753525F5A596761606E6967
76706E7E7775867F7C8E8684
9E9794A6A09EAEA9A7B7B3B1C0BCBBC9C7C6D2D1D1DDDCDCE7E8E8F3F4F4FDFFFFF7FAFB
E7EDF0D9E1E5CAD6DBBAC9D0ACBEC69DB3BC92AAB585A0AC7A98A471919E698A98638492
5D7F8E567A895378874C72824A7080476E7E456C7C4268783F66763E6473406371426370
45626E48636D4C636C52646B55646A5A64685B63655C61625B5D5E595959555454504F4E
4A494847454443403E423F3E4543414A4746504C4B5652515D5857645F5D6B6564726C6A
79737180797788807E8F8784
9E9694A59F9DADA8A6B6B1AFBEBAB9C7C4C3D0CECDDAD8D8E4E3E3EFEFEEFAFBFAFDFEFF
F0F3F4E2E8EAD4DDE1C5D1D6B8C7CDACBDC4A2B5BD94ABB488A1AC819AA578939F718E99
6B899563839060808D5B7B895879875476845173814F707E4C6D7B4A6B784B6A774E6A75
5069745269725569705A696F5C686D5E676B5F65676063645E5F605C5B5B58565553514F
4E4B4A4B47454A46444C48464F4B49534F4D5853525D5857635E5C6963626F6967756F6D
7C7573827B7989817F8F8785
9D9693A59E9CACA6A4B4AFADBCB8B6C4C1BFCDCAC9D6D4D3E0DEDDEAE9E8F6F5F4FFFFFF
F8F9F9EBEEEFDFE4E6D2D9DCC4CED3B8C5CBAFBEC4A4B5BC98ACB490A5AD879DA68098A1
7A929C738D976E899369859065818D617D8A5F7A875C788459758058737E59717C5B717B
5D71795E7078617076646F74656E71646B6E64686A646666626262605E5D5B5857555250
514C4A504B49524D4B54504E5752515A56545F5A58635E5C6863616E6866736D6B797270
7E7775847D7B8A8280908885
9D9593A49D9BABA5A2B2ACABB9B5B3C1BDBBC9C6C4D2CFCDDBD8D7E4E3E1EFEEECFCFAF9
FFFEFDF6F5F5E9EBEBDCE0E2D0D6D9C5CED1BDC7CBB3BFC5A9B7BCA1B0B696A7AE8FA1A8
889CA383979F7D929A788E96758A937086906C828C6A808A677C86667B84667981697981
69787F6B777E6E777C6F767A6F74766D71726C6D6E6B6A6A686665646160615C5A5B5654
544E4B58524F5A54525C57555E5957625C5A65605E6963626D6866726C6A77706E7C7573
817A78867F7C8B8481918986
9C9592A39C99A9A3A1B0AAA8B7B1AFBEB9B7C5C1BFCDC9C8D5D2D0DEDBDAE7E5E3F1EFED
FCF9F7FEFCFAF4F2F1E7E7E7DADDDED0D5D6C8CED0C1C8CBB8C0C4B1BABDA7B2B69FABB0
98A5AA93A0A68D9CA188979D8393997F8F967A8B9277878F74848B728188717F86747F85
7680857980847A7F827A7C7F797A7B777777747271706E6D6E6A69696563635E5D5F5957
5E58555F5957615B59635D5B65605D6862606B65636F6866726C6A76706E7B74727F7876
837C7A88807E8D8582918987
9C9491A29A98A7A19EADA7A5B4AEACBAB5B3C1BCBAC8C3C2CFCBC9D7D3D2DFDCDAE8E4E2
F0EDEBFAF6F4FCF8F6F1EEEDE4E3E3D9DADAD0D3D3CCCECFC5C8C9BEC2C3B7BBBDADB4B6
A7AEB1A0A8AC9BA4A796A0A3919B9F8C979B889398848F94818C917E888D7C85897C8487
7E83878386888586878382838280807F7C7B7A767575716F726D6B6F696769626067605D
67605D67615E6862606A64616C66636E6866716A68746D6B77706E7A74717E7775827B78
867E7C8A82808E8683928A87
9B9391A09996A69E9CABA4A2B0AAA8B6B0AEBCB7B5C2BDBBC9C4C2D0CBC9D7D2D0DEDAD8
E6E1DFEDE9E7F6F2EFF7F2F0EDE9E6E2DFDED7D6D6D2D1D1CDCDCDC9C8C8C1C2C2BBBBBC
B6B7B7AFB1B3AAACADA4A8A99FA3A5999EA1959A9D9096998E93978A8F92868A8D84898A
85888A888889878687868484868281847F7D7F7A787B757376706D746D696F67656E6764
6E67646E68656F6866706A67726B69746D6B766F6D7972707B74727E7775817A78857D7B
88807E8B84818F8784928A88
9A92909F9795A49C9AA8A19FADA6A4B2ACAAB7B1AFBCB7B5C2BDBBC8C3C1CEC9C7D4CFCD
DBD6D3E1DCDAE8E3E1F1ECE9F1EBE8E8E3E0DDD9D7D6D2D1D2CECDCFCCCAC9C6C5C1BFBE
BDBABAB9B7B6B6B3B3B1AFAFABAAAAA6A5A6A1A1A29C9D9E999A9B9596979393948E8E8F
908E8F928E8E918C8C908A898E87858B848187807D8079777C74717A726E776F6C766E6B
756E6B756E6B766F6C77706D78716E7972707B74727D7674807876827B78857D7B87807D
8A82808D8583908885938B88
9A928F9E9693A19A97A59E9CA9A2A0AEA7A5B2ABA9B6B0AEBBB5B3C0BAB8C5BFBDCAC5C2
D0CAC8D5D0CDDBD5D3E2DBD9E9E3DFEBE3DFE4DDDAD9D4D1D2CDCACEC9C7CCC7C5C8C3C1
C4BFBDC1BBB9BCB6B5B9B4B2B6B1AFB2ADABABA7A5A5A2A2A29E9E9D9B9B9C9898969393
979392979190978F8E968D8B938A888F86848D8380837B788179757F77747D76727C7472
7C74717B74717C74727C75737D76747F7775807976827A78847C7A867E7C88807E8A8280
8C84828F8784918986948B89
99918E9C94919F9795A29B98A69E9CA9A2A0ADA6A3B0A9A7B4ADABB8B1AFBCB5B3C0BAB7
C4BEBCC9C2C0CEC7C4D3CCC9D7D0CDDCD5D1E0D8D4DED6D2D5CDC9CFC7C3C9C2C0C7C0BD
C4BDBAC3BBB8C0B7B4BBB4B0B7B0ADB5AEABB0A9A6ACA5A3A6A09EA29D9C9F9A999D9896
9B96949B94929B939099908D978E8B92898690878489807D867E7B857C79837B78827A77
817A77817A77817A77827A78837B79847C7A857D7B867E7C87807D89817F8B83808C8582
8E8684908885928A87948C89
98908D9B92909D95929F9895A29A98A49D9AA7A09DAAA3A0ADA5A3AFA8A6B2ACA9B6AFAC
B9B2AFBCB5B3C0B9B6C3BCB9C7BFBCCAC2BFCEC5C1D3CAC5D1C8C3CFC5C0C9C0BCC2BAB7
C1B8B5C1B7B5BEB4B1BBB1AEB7AEABB4ACA9B1A9A6AFA6A3ABA3A0A8A09EA49D9AA29B99
9F99979D97949C959299918E9B928F988F8C9289858E85828B83808A817E88807D877F7D
877F7C877F7C877F7C877F7D88807D88817E89817F8A82808B83818C84828E86838F8784
908886928987938B88958C8A
988F8D99918E9B92909C94929E9693A09895A19A97A39C99A59E9BA7A09DA9A29FABA4A1
ADA6A3B0A8A5B2AAA8B4ADAAB7AFACB9B1ADBBB3AFBDB4B0BDB4B0BEB4B0BFB6B1BBB2AE
B8B0ABB8B0ACB8AFACB8AEAAB5ABA8AFA7A4ACA4A2ABA29FA8A09DA79E9CA49C99A19A97
9F98959D9592A199959C949099908D978E8B948B889189868F87848E86838D85828D8482
8C84818C84818C84818C84828D85828D85828E85838E86848F8784908885908886918987
928A87938B88948C89958D8A
978E8C988F8D98908D99918E9A928F9B93909C94919D95929E96939F9794A09895A19996
A29A97A39B98A49C99A59D9AA69E9BA79F9CA8A09DA9A19DAAA19DAAA19DAAA19DA9A09C
A89F9CA8A09CA89F9CA9A09CABA19DA9A09CA89F9CA79E9BA69D99A59C99A49B98A39B98
A198959B93909A928F99918E988F8C968E8B958C8A948B88938A88928A87928987918986
918986918986918986918986918986928987928A87928A87928A88938B88938B88948B89
948C89958C8A958D8A968D8A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?oooa^FSX/WUHj<19F>S@NDSXd4U8n=19B?SPBDT8l4U96B19B?
SP>DSXd8U8j<19B=Ra>ESX`4UXj<19F>S0BFSX`4UHf:0iF<RPBERhT4U8Z819B:Q`BDRHH4ThR50i>7
Q0BBQX<4TXF11963O`B?P7/4THB019:6PP>BQh<4ThR519>9Q@BCRHH4U8V61iB:Q`BDRhP4UH^829F<
R@BESHX4UXf:5Oooo`005?oooa^FSX/WUHj<19F>S@NDSXd4U8n=19B?SPBDT8l4U96B19B?SP>DSXd8
U8j<19B=Ra>ESX`4UXj<19F>S0BFSX`4UHf:0iF<RPBERhT4U8Z819B:Q`BDRHH4ThR50i>7Q0BBQX<4
TXF11963O`B?P7/4THB019:6PP>BQh<4ThR519>9Q@BCRHH4U8V61iB:Q`BDRhP4UH^829F<R@BESHX4
UXf:5Oooo`005?oooa^FSX/WUHj<19F>S@NDSXd4U8n=19B?SPBDT8l4U96B19B?SP>DSXd8U8j<19B=
Ra>ESX`4UXj<19F>S0BFSX`4UHf:0iF<RPBERhT4U8Z819B:Q`BDRHH4ThR50i>7Q0BBQX<4TXF11963
O`B?P7/4THB019:6PP>BQh<4ThR519>9Q@BCRHH4U8V61iB:Q`BDRhP4UH^829F<R@BESHX4UXf:5Ooo
o`005?ooo`RFSX/4UXf;19F>Ra>ESX`4UHj=1iB>S@RDShd8U8n>29>?SPNCShl4TY2@19:@T@BBTI84
TY>E19:AT@>BShl8TXj=19>=S0BCSXd4U8j=0iB>S0BCSXd4U8j=19F=S0BDSH`4U8f;19B;R@>DRXP4
ThV619:7Q0BBQX<4THB11923O`>@PGd4Sgmk18imN0B<NW@4RWQb18elM`B>OgX3Sh5l18n2OPB@Q804
THB11965PPBBQX<3TXN419>8Q@BCRHH4U8Z719B;R0BES8T4UHf:5Oooo`005?ooo`RFSX/4UXf;19F>
Ra>ESX`4UHj=1iB>S@RDShd8U8n>29>?SPNCShl4TY2@19:@T@BBTI84TY>E19:AT@>BShl8TXj=19>=
S0BCSXd4U8j=0iB>S0BCSXd4U8j=19F=S0BDSH`4U8f;19B;R@>DRXP4ThV619:7Q0BBQX<4THB11923
O`>@PGd4Sgmk18imN0B<NW@4RWQb18elM`B>OgX3Sh5l18n2OPB@Q804THB11965PPBBQX<3TXN419>8
Q@BCRHH4U8Z719B;R0BES8T4UHf:5Oooo`005?ooo`RFSX/4UXf;19F>Ra>ESX`4UHj=1iB>S@RDShd8
U8n>29>?SPNCShl4TY2@19:@T@BBTI84TY>E19:AT@>BShl8TXj=19>=S0BCSXd4U8j=0iB>S0BCSXd4
U8j=19F=S0BDSH`4U8f;19B;R@>DRXP4ThV619:7Q0BBQX<4THB11923O`>@PGd4Sgmk18imN0B<NW@4
RWQb18elM`B>OgX3Sh5l18n2OPB@Q804THB11965PPBBQX<3TXN419>8Q@BCRHH4U8Z719B;R0BES8T4
UHf:5Oooo`005?ooo`RFSX/4UXf;19F>Ra>ESX`4UHj=1iB>S@RDShd8U8n>29>?SPNCShl4TY2@19:@
T@BBTI84TY>E19:AT@>BShl8TXj=19>=S0BCSXd4U8j=0iB>S0BCSXd4U8j=19F=S0BDSH`4U8f;19B;
R@>DRXP4ThV619:7Q0BBQX<4THB11923O`>@PGd4Sgmk18imN0B<NW@4RWQb18elM`B>OgX3Sh5l18n2
OPB@Q804THB11965PPBBQX<3TXN419>8Q@BCRHH4U8Z719B;R0BES8T4UHf:5Oooo`005?ooo`BFSX/4
UXj<3iF>S0BESXd4U8n=19B>S@RDShh7Thn>29>?S`bBT903TI2@196@T@B@T984T96C192BU@B@U9L4
Si6C0i2?T0R@SXh4THj=19:>S@BCSXh3Thn>19:?SPBCSXh4U8f=19B=S0BDS8X4U8^90iB9Q`BBQX@4
THB118n2O`B>P7`4SGei0hakMPB;N7<4RGE_18QaJPB8Lf`4RGI`18YiL`>;NgH4S7eh18eoNPB>P7`4
Sh5m1923O`>@Q804THJ219:7Q0BCR8D4U8Z719B;R0BES8TEoooo000Doooo19J>R`BFSX`?UHj<19F>
S@BDShd4U8j=29B?SPNCShh8Thn?39:@T0>AT904TI2A192@TPB@TI<4T9:E192DU`B?TI<3T8n@292>
SPBASXd4TXj=19>>SP>CShh4TXn>19>>SPBDSHd4U8f<19B<RPBDRhT3U8V719:6Q0BAQ844Sh9o18j0
O0B=OGT3S7]f18]hL`B9MFl4R75Z18QcK0B9MW04RWUc0h]kMPB<OGP4SGmj18j0O0B?PGd4T8=o0i24
P0BAQX84TXN419>8Q@BDRXL4U8^819F<RAGoool001Coool4UXj;19J>S0nESX`4UHj=19B?S@BDSXd8
U8n>1i>?SPRCShl<TY2@0i6@T0BAT944T92B192AT`B@TYD4T9BG18nAT`>@Si08T8j>196>S@BBSXd4
Thj>0i>?SPBBShh4Thj>19B=S@BDSH`4U8b:19B;R@>DRHL4TXJ41964P@B?PWl4SX1l18emN@><NgH4
RgQc18UeK`B8LFX4R7=/18UfL0B:NG<3Rg]f18amN0B=OgX4SX1l18n1O@B@Pgl3T8B01966PPBBQh@4
ThR519B:Q`BDRhP4UHb95Oooo`005?ooo`BFSX/4UXj<3iF>S0BESXd4U8n=19B>S@RDShh7Thn>29>?
S`bBT903TI2@196@T@B@T984T96C192BU@B@U9L4Si6C0i2?T0R@SXh4THj=19:>S@BCSXh3Thn>19:?
SPBCSXh4U8f=19B=S0BDS8X4U8^90iB9Q`BBQX@4THB118n2O`B>P7`4SGei0hakMPB;N7<4RGE_18Qa
JPB8Lf`4RGI`18YiL`>;NgH4S7eh18eoNPB>P7`4Sh5m1923O`>@Q804THJ219:7Q0BCR8D4U8Z719B;
R0BES8TEoooo000Doooo19J>R`BESX`4UHn<19F>S0BESXd3U8n=39B?SPBCT8l4Thn?0i>@S`RBT904
TI2@296@T@B@T943T92B18nATPB>TI<4SY:D18jCUPB>U9T4SI6D0hf@T@B>SXl4SXf>18n>SPB@SXh4
TXj?0i>?S`RCT904UHn?19B=S0BDRhX4U8V80i>7Q@BBQ884T85n18inN`B<NgP4RgQd0hUeK`B8LV/4
QFeV18=XH0B4K6D4QW1Y18McK0>8MFl4RGQb18YjM@B;O7L4S7ii18eoN`>?PGd4T8=o1965P@BBQh<4
ThR519B:Q`BES8TEoooo000Doooo19J>R`BESX`4UHn<19F>S0BESXd3U8n=39B?SPBCT8l4Thn?0i>@
S`RBT904TI2@296@T@B@T943T92B18nATPB>TI<4SY:D18jCUPB>U9T4SI6D0hf@T@B>SXl4SXf>18n>
SPB@SXh4TXj?0i>?S`RCT904UHn?19B=S0BDRhX4U8V80i>7Q@BBQ884T85n18inN`B<NgP4RgQd0hUe
K`B8LV/4QFeV18=XH0B4K6D4QW1Y18McK0>8MFl4RGQb18YjM@B;O7L4S7ii18eoN`>?PGd4T8=o1965
P@BBQh<4ThR519B:Q`BES8TEoooo000Doooo19J>R`BESX`4UHn<19F>S0BESXd3U8n=39B?SPBCT8l4
Thn?0i>@S`RBT904TI2@296@T@B@T943T92B18nATPB>TI<4SY:D18jCUPB>U9T4SI6D0hf@T@B>SXl4
SXf>18n>SPB@SXh4TXj?0i>?S`RCT904UHn?19B=S0BDRhX4U8V80i>7Q@BBQ884T85n18inN`B<NgP4
RgQd0hUeK`B8LV/4QFeV18=XH0B4K6D4QW1Y18McK0>8MFl4RGQb18YjM@B;O7L4S7ii18eoN`>?PGd4
T8=o1965P@BBQh<4ThR519B:Q`BES8TEoooo000Doooo19J>R`BESX`4UHn<19F>S0BESXd3U8n=39B?
SPBCT8l4Thn?0i>@S`RBT904TI2@296@T@B@T943T92B18nATPB>TI<4SY:D18jCUPB>U9T4SI6D0hf@
T@B>SXl4SXf>18n>SPB@SXh4TXj?0i>?S`RCT904UHn?19B=S0BDRhX4U8V80i>7Q@BBQ884T85n18in
N`B<NgP4RgQd0hUeK`B8LV/4QFeV18=XH0B4K6D4QW1Y18McK0>8MFl4RGQb18YjM@B;O7L4S7ii18eo
N`>?PGd4T8=o1965P@BBQh<4ThR519B:Q`BES8TEoooo000Doooo19J>R`BESX`4UHn=19F>S@BDShd7
U8n>19>?S`BCT8l4Ti2@1i:@T0RAT948T96B28nAT`>>TI<4SI6D18bAU@B<TYD4Ri:G18^DV@B;TI@3
RhnA18b>S`B<SHh4SHf>18j=SPB?SXh3T8j?196?T0BBT904Thn?19>=S@BCRhT4TXV70i:6Q0BAPh04
Sgil18ejM`B;Mg<4R7=^0hI_J@B4Jf@4PFIN17mRF@B1IUh4PVYR18A]IP>5L6T4QW=/18QeK`B9N784
RWYe18]lM`>=OWX4SX1l18n3O`BAQH44TXN419>9QPBERhPEoooo000Doooo19J>R`BESX`4UHn=19F>
S@BDShd7U8n>19>?S`BCT8l4Ti2@1i:@T0RAT948T96B28nAT`>>TI<4SI6D18bAU@B<TYD4Ri:G18^D
V@B;TI@3RhnA18b>S`B<SHh4SHf>18j=SPB?SXh3T8j?196?T0BBT904Thn?19>=S@BCRhT4TXV70i:6
Q0BAPh04Sgil18ejM`B;Mg<4R7=^0hI_J@B4Jf@4PFIN17mRF@B1IUh4PVYR18A]IP>5L6T4QW=/18Qe
K`B9N784RWYe18]lM`>=OWX4SX1l18n3O`BAQH44TXN419>9QPBERhPEoooo000Doooo19J>R`BESX`4
UHn=19F>S@BDShd7U8n>19>?S`BCT8l4Ti2@1i:@T0RAT948T96B28nAT`>>TI<4SI6D18bAU@B<TYD4
Ri:G18^DV@B;TI@3RhnA18b>S`B<SHh4SHf>18j=SPB?SXh3T8j?196?T0BBT904Thn?19>=S@BCRhT4
TXV70i:6Q0BAPh04Sgil18ejM`B;Mg<4R7=^0hI_J@B4Jf@4PFIN17mRF@B1IUh4PVYR18A]IP>5L6T4
QW=/18QeK`B9N784RWYe18]lM`>=OWX4SX1l18n3O`BAQH44TXN419>9QPBERhPEoooo000Doooo19J>
R`BESX`4UHn=19F>S@BDShd7U8n>19>?S`BCT8l4Ti2@1i:@T0RAT948T96B28nAT`>>TI<4SI6D18bA
U@B<TYD4Ri:G18^DV@B;TI@3RhnA18b>S`B<SHh4SHf>18j=SPB?SXh3T8j?196?T0BBT904Thn?19>=
S@BCRhT4TXV70i:6Q0BAPh04Sgil18ejM`B;Mg<4R7=^0hI_J@B4Jf@4PFIN17mRF@B1IUh4PVYR18A]
IP>5L6T4QW=/18QeK`B9N784RWYe18]lM`>=OWX4SX1l18n3O`BAQH44TXN419>9QPBERhPEoooo000D
oooo19J>S0BESX`4UHn=19B?S@NDShh4Thn?19>@S`RBT904TI2A0i6AT@R@TI88Si6C18jBU0B=TY@3
SI:E18bBU@B:TIH4RI6F18RAUPB7TYP4R92D0hR>T@B9SI04RXf>18^=SPB<S8h4SHf>0hj=SPB?SHh4
T8j?192=SPBAS8/4T8V81927Q@>?Ph44Sh1m18elN0B:MW84R79^18E^J@>2JF<4P6AM17eOE`AlGU@4
OV5H17mTG0B0J603PV]S18=^I`B5LFX4QW=^18QfL@B9N7<3Rg]g18anNPB>PG`4T8=o1966PPBCR8D4
U8^85Oooo`005?ooo`BFSX`4UHj<19F?S@BDShd7U8n>19>?S`BCT8l8TY2@196@T@>ATI48T96B28nA
T`B>TY@4SI:D0hfBU@B<TYD4RY6F18VAUPB8TIH4Qi:H18R@U0>8SY44RHf@18Z=SPB;SHh4S8b>18f=
SP>>SHh4Shf>192>S`B@SHh4THb;1929R0B@QhD3Sh>118n0O@B=O7P4RWIb18QbKPB5KVT3PVUS181T
G@AmGeL4O5iD17iQF0AoI5`4P6QP0h9[H`B3KVL4QG5Z18IcKPB8MW44RGQc0h]kM`B<OWX4SX5l1923
O`BAQX84ThR519B;R1Goool001Coool4UXj<19F>S0BEShd4U8n=1iB?SPBCShl4Ti2?29:@T0BAT943
TI6A292ATPR?TI<4SY:D18fBU0>=TYD4S9:E18ZAUPB9TIH4R96F18NBV0B8T9@3R8jA18V=T0B:SHh4
Rhf>18b<SPB=SHh3SXf>18n=SPB@SXl4T8f>196<R`B@RHP4T8N50hn3P@B?P7d4SGah18YfLPB8LVh4
QFiY0h9YH`B0I5d4OEmG17aNE0AnHEP4OfAL181XH0>2Jf<4PfiW18EaJPB6Lfh4R7Ia18UhL`>;NgL4
S7ij18j1O0B@Pgl4THJ219>8Q@BDRhPEoooo000Doooo19J>S0BESX`4UHn=19B?S@BDShh3Thn?19>@
S`BBT904TY2A196AT@BATI87T96C18nBU0B>TY@4SY:E18fBU@B<TYH3Ri:F18ZBU`B9TYL4QY6F18B?
U@B3SI@4QHjB0hJ=T@B7SHl4R8b>18V<S@B:Rhd7Rh^=18b;S0B=Rh`4SHZ;18j9R@B>QXH4SH>20hb0
OPB;OGX4RWQe18QcK`B5KFP4PVUS0gmTG@AlGUH4NEQ>17UIC`AjG584O5mF17eRFP=oIUh4P6UR189/
I@B4KfT4QG=]18MeL0>9N7<4Rgag18eoNPB>PGd4T8B019:7Q0BDRXLEoooo000Doooo19J>S0BESX`4
UHn=19B?S@BDShh3Thn?19>@S`BBT904TY2A196AT@BATI87T96C18nBU0B>TY@4SY:E18fBU@B<TYH3
Ri:F18ZBU`B9TYL4QY6F18B?U@B3SI@4QHjB0hJ=T@B7SHl4R8b>18V<S@B:Rhd7Rh^=18b;S0B=Rh`4
SHZ;18j9R@B>QXH4SH>20hb0OPB;OGX4RWQe18QcK`B5KFP4PVUS0gmTG@AlGUH4NEQ>17UIC`AjG584
O5mF17eRFP=oIUh4P6UR189/I@B4KfT4QG=]18MeL0>9N7<4Rgag18eoNPB>PGd4T8B019:7Q0BDRXLE
oooo000Doooo19J>S0BESX`4UHn=19B?S@BDShh3Thn?19>@S`BBT904TY2A196AT@BATI87T96C18nB
U0B>TY@4SY:E18fBU@B<TYH3Ri:F18ZBU`B9TYL4QY6F18B?U@B3SI@4QHjB0hJ=T@B7SHl4R8b>18V<
S@B:Rhd7Rh^=18b;S0B=Rh`4SHZ;18j9R@B>QXH4SH>20hb0OPB;OGX4RWQe18QcK`B5KFP4PVUS0gmT
G@AlGUH4NEQ>17UIC`AjG584O5mF17eRFP=oIUh4P6UR189/I@B4KfT4QG=]18MeL0>9N7<4Rgag18eo
NPB>PGd4T8B019:7Q0BDRXLEoooo000Doooo19J>S0BESX`4UHn=19B?S@BDShh3Thn?19>@S`BBT904
TY2A196AT@BATI87T96C18nBU0B>TY@4SY:E18fBU@B<TYH3Ri:F18ZBU`B9TYL4QY6F18B?U@B3SI@4
QHjB0hJ=T@B7SHl4R8b>18V<S@B:Rhd7Rh^=18b;S0B=Rh`4SHZ;18j9R@B>QXH4SH>20hb0OPB;OGX4
RWQe18QcK`B5KFP4PVUS0gmTG@AlGUH4NEQ>17UIC`AjG584O5mF17eRFP=oIUh4P6UR189/I@B4KfT4
QG=]18MeL0>9N7<4Rgag18eoNPB>PGd4T8B019:7Q0BDRXLEoooo000Doooo29F>S0BDShd4U8n>19>?
SP>CT8l4TY2@19:@T@RATI84T96C1hnBU0B>TYD8SI>F18bCU`B;TiP3RY>H18VCV0B7TiP4QI6H17f;
TPAoRi44PXbA0hB<T0B5S8l4QX^>18N:S@B7Rhd4R8Z<0hV:R`B:RH/4RXR:18Z6R0B:QHH4RX>318Yo
O`>9O7X4R7Qf18IdL@B4KfX4PVYT17mTGP=kGUH4N5U?17EBA`AfE4T4MeI<17QJD0AjGE@3Nf1H17eT
G0AoJ604PF]T18=_J0B5LV`3QgI`18UiM0B;OGP4SH1l18n3O`BBQh<4U8Z75Oooo`005?ooo`RESX`4
U8n=19B?SPBCShh3Ti2?19:@T0BBT948TI6B192AT`N?TY@4SY:E28fCUPB<TiL4Ri>H0hZCV0B9TiP4
Qi>H18FAV0AmRi84Oh^A18:<T@>4S904QHb?18J;SPB7RXd4Qh^=18R:S0>9RX/4RXV;18Z8RPB:QXP4
RXF618Z3P`B:Ogl3RGaj18QhMPB6M744Q6mZ189ZI0AoI5h3NeiF17QIC`AeDTL4MUA917MFC0AhFU04
NUeD0g]PF0AmI5`4OfQP185[I0B3KfP4QG9/0hMfL0B9NG@4Rgeh18f0O0B?Pgl4TXN319B:QaGoool0
01Coool8UHj<19B?S@BDShh4Thn>0i>@S`BBT904TY2A296ATPB@TI<7Si:D18jBU@R=TiH4S9>G18^C
V0>:TiP4RI>H18NCV0B5TIP4OH^B17n;T@B2S943Q8b@18F<S`B6Rhh4QhZ=18N;S@B8RX`3RHZ;18Z9
R`B:R8X4RXJ818Z5QPB:Ph<4RWmo0hUlNPB8N7H4QWAa18A_JPB2JV@4OfAN0g]NEPAhFDl4ME9717ID
B@AgET`4N5Y@17YME0=kH5P4OFAL17mXH0B1Jf@4PfmX18EbK0>7MW04RGUd18]mN0B=P7`4Sh=o19:7
P`BDRXLEoooo000Doooo29F>S0BDShd4U8n>19>?SP>CT8l4TY2@19:@T@RATI84T96C1hnBU0B>TYD8
SI>F18bCU`B;TiP3RY>H18VCV0B7TiP4QI6H17f;TPAoRi44PXbA0hB<T0B5S8l4QX^>18N:S@B7Rhd4
R8Z<0hV:R`B:RH/4RXR:18Z6R0B:QHH4RX>318YoO`>9O7X4R7Qf18IdL@B4KfX4PVYT17mTGP=kGUH4
N5U?17EBA`AfE4T4MeI<17QJD0AjGE@3Nf1H17eTG0AoJ604PF]T18=_J0B5LV`3QgI`18UiM0B;OGP4
SH1l18n3O`BBQh<4U8Z75Oooo`005?ooo`BESX`4UHj=19B?S@BDShh4Thn?0i:@T0BBT944TI6A196A
TPB@TY<4Si:D0hnBU@B>TiH4SI>F18bCU`B<U9P4RiBH18ZDV@>9U9X4R9BJ18NEV`B6U9/4N8R?17j;
T@B0Ri03PXb@18>;S`B4Rhd4Q8Z<18F9S0B6RH`3QhV:18N8RPB7QXP4R8>518N0PPB6OWh4QW]k0hEh
M`B4M784PW1]181ZIPAnIF04NemI0gMID@AdDdT4LD]0179>@`AcD4H4MEA:17IHCP=hFe84NUmG17aS
F`AnIf04P6]T18=_J@>5Lfd4QgMa18YjMPB<OWX4Sh9n1966PPBDRXLEoooo000Doooo19F>S0BESXd4
U8n=19B?SPBCShl3TY2@19:@T@BATI44TI6B192BT`B?TY@3Si:E18jCUPB=TiH4S9>G18bDV0B;U9P4
RYBI0hVDVPB8U9X4QiFK18JDV`AhR8l4OX^A182;T0>2S904Ph^?18B;S@B4RX`4QHV<18J9S0>7RHX4
QhR:18N6R0B8PhD4Qh2218InOPB6Ng/3QGQg18AdLPB2L6d4P6YV17iUH0AkGeT3MeUA17ACB@AaBd04
LTi317=@APAeE4X4MUQ>0gQKDPAjGeL4O6=K17iWH0B0Jf@4PfmY0hEcK@B7Mg44RWYf18anNPB?PWh4
THJ219B:QaGoool001Coool4UHj<19F>S@BDShd4U8n>19>?S`>BT904TY2A196AT@BATI84T9:C18nB
U0>?TYD4SY>F18fCUPB<TiL4S9BH18^DV0B:U9T3RIBJ18RDVPB7UI/4QYBK17R8S`AnRi44P8^@0h:<
T0B3Rhl4Q8^=18B:S0B5RH`4QXV<0hN9RPB7R8X4QhJ818R3Q@B7P884QWin18IkN`>5N7L4Q7Ab189`
K@B0JVH4OVEP17]OF@=gFE44M5=9175;@0AbCT<4Le1617EDBPAfF4h3N5]B17YOE`AlHe/4OVMP181[
I0B3KfT3QG=]18MgL@B:NWH4S7ij18n2OPBAQX84U8Z75Oooo`005?ooo`BESX`4UHj=19B?S@BDShh4
Thn?0i:@T0BBT944TI6A196ATPB@TY<4Si:D0hnBU@B>TiH4SI>F18bCU`B<U9P4RiBH18ZDV@>9U9X4
R9BJ18NEV`B6U9/4N8R?17j;T@B0Ri03PXb@18>;S`B4Rhd4Q8Z<18F9S0B6RH`3QhV:18N8RPB7QXP4
R8>518N0PPB6OWh4QW]k0hEhM`B4M784PW1]181ZIPAnIF04NemI0gMID@AdDdT4LD]0179>@`AcD4H4
MEA:17IHCP=hFe84NUmG17aSF`AnIf04P6]T18=_J@>5Lfd4QgMa18YjMPB<OWX4Sh9n1966PPBDRXLE
oooo000Doooo19F>S0BEShd4U8n>29>?S`>BT904TI6A196ATPB@TY<4Si:D18nCU@>>TiH4SI>G28bD
V0B;U9T4RYFJ18VEV`>8UI`4R9JL18RGWPB3TYT4OHbC17j<T@AoRi03P8^?186:SPB2RXd4PXV;18>8
R`N4R8X4QHN918F5Q`B5PH@4QGj018AjN`B3MWL3PW=c185`KPAnJfT4O6IR17YQG0AhFeD3MEE=175>
A0A^AS/4KTLk16m:?`AaCT<4Le980gEFC@AgFU84NEmF17]SF`AnIf04P6]U0h=`JPB6M6l4R7Qc18]m
N0B>PGd4T8F119>9QQGoool001Coool4UHj<19F?S@BDShh8Thn?0i:@T0BATI44TI6B192BT`B?TY@4
Si>E0hjCUPB=TiL8S9BH18^DV@B:UIX4RIFK0hREW0B8UY`4R9NN18>BV@AmS9<4OXbA17n;T0>0Rhl4
PHZ>18::S@B2RH/4PhR;1hB8RPB5QhT4QHF718F1Q0B5OX04Q7Yk18=fM`>2Lg<4PG1^17i[J@AlIV84
NV5L17QKE@=eEDd4LDi416i6>`A^Ac/4KdXo175>@`AcDTP3MEI=17MJDPAiGeH4Nf=K17iWH0B0JfD3
Pg1Z18IdK`B8N7<4Rgeh18j1O@B@QH44ThV65Oooo`005?ooo`BESX`4UHn=19B?SPRCShl3TY2@196A
T@BATI84T9:C18nBU0B?TiD3SY>F18fCU`R<U9P4RiBI18ZEVPB9UI/3R9FL18RFW0B8Uih4Pi:I17f<
T`AnS944Oh^@0h2;S`B1RXh4PXZ=18:9R`B3R8/7Q8R:18F7R@B5QHL4QH6418EnP0B4NW/4PgIg0h9c
L`B1L6h4OV]Y17aVHPAjHE`4N5]E0gEEC@AaCT@4KTHk16i7>`A_BSl4LDi317=BB0=eETd4MeYB17UO
EPAkHe/4OVMP181[I@>3L6X4QWA_18QhL`B;OGP4SX5m1925P@BCRHHEoooo000Doooo19F>S0BEShd4
U8n>29>?S`>BT904TI6A196ATPB@TY<4Si:D18nCU@>>TiH4SI>G28bDV0B;U9T4RYFJ18VEV`>8UI`4
R9JL18RGWPB3TYT4OHbC17j<T@AoRi03P8^?186:SPB2RXd4PXV;18>8R`N4R8X4QHN918F5Q`B5PH@4
QGj018AjN`B3MWL3PW=c185`KPAnJfT4O6IR17YQG0AhFeD3MEE=175>A0A^AS/4KTLk16m:?`AaCT<4
Le980gEFC@AgFU84NEmF17]SF`AnIf04P6]U0h=`JPB6M6l4R7Qc18]mN0B>PGd4T8F119>9QQGoool0
01Coool4UHj<19F?S@BDShh4Ti2?19:@T0>BT944TI6B192BT`B?TY@4Si>E18jCUP>=U9L4S9BH18bD
V@B;UIX4RYFK18VEW0B8UY`3QiJM18NGWPB4U9`4P96H17j>U@AnSI84OXbA0gn;S`AoRXd4P8V;1828
RPR1QhX3PXN:18B7RPB3PhH4Ph2218=kOPB2MgT4PG9d0gm_L0AmJf/4NfMU17QRGPAfGEP4M5QA0g9B
BPA^Bd44Jd<h16U0<`A[A3P4KDPm16m<@P=aDDL4LeE<17IJDPAhGeL4Nf=L17iXH@>1KFL4Q79/18Mf
L@B:NgH4SGmk1924P@BCRHHEoooo000Doooo19F>S0BEShd4U8n>19>@S`BBT903TY2A196ATPB@TY<4
Si:D18nCU@B>TiH3SIBG18bDV0B<U9T4RiFJ18ZEV`B9UI`4R9JL0hNFW@B7Uih4Q9BL182AV0AnSYD4
OXfB17j<T@=oRhl4OhZ=1829R`B0R8X8PHN:0h:7RPB4QhX4Ph>618>0PPB3Ngh4PWMi185bM0=oKg04
OF][17]WI@AhHUh4MUeH17AHD@=bDTX4KT]116]3>0AY@3<4Jd@h16e8?@A_C483LE5717=EC0AfFU84
N5mG17]SG0AnJ643PFeW18AbK0B7MW44RW]f18eoN`B@Q844ThV65Oooo`005?ooo`BESX`4UHn=19B?
SPBCT8l4TY2@0i:@T@BATI84T9:C18nBU0B?TiD4SY>F0hfDU`B<U9P4S9BI18^EVPB:UI/4RIFL18RF
W0>7UYd4QiNN18BDW0B0TIP4OXjE17j=TPAnS943Oh^?17n:S@B0RH/4P8R:2867RP>2QhX4Q8N:18>3
QPB3P884Pg]n189gN@B1LW@3Ofm`17e[J`AkIfD4N69N17IMF0AdF543LU9:16i;@@A[@cP4JD0c16]4
>0A]B3d4Kda20g5AA`AcED`4MUYB17QOE`AkHe`4OVQQ0h5]I`B4LV`4QgIa18YkMPB=Og/4T8B119>9
QQGoool001Coool4UHj<19F?S@BDShh4Ti2?19:@T0>BT944TI6B192BT`B?TY@4Si>E18jCUP>=U9L4
S9BH18bDV@B;UIX4RYFK18VEW0B8UY`3QiJM18NGWPB4U9`4P96H17j>U@AnSI84OXbA0gn;S`AoRXd4
P8V;1828RPR1QhX3PXN:18B7RPB3PhH4Ph2218=kOPB2MgT4PG9d0gm_L0AmJf/4NfMU17QRGPAfGEP4
M5QA0g9BBPA^Bd44Jd<h16U0<`A[A3P4KDPm16m<@P=aDDL4LeE<17IJDPAhGeL4Nf=L17iXH@>1KFL4
Q79/18MfL@B:NgH4SGmk1924P@BCRHHEoooo000Doooo19F>S0BDShd4U92?19>@S`BBT903TI6B192A
T`B@TY@4Si>E18jCUPB=U9L3S9BH18bEV@B;UIX4RYJK18VFW0B8UYd4QiNN0hJGW`B7V:44P9:J17j@
U`AnSYD4OHfC17f<T@=nRi04OHV=17f8RPAnQhT4OXJ917n7R@>0QXT4PXR:18:5Q`B2PX@4PGeo181i
N`AnLW<3OFe^17YXJ0AgHf84MEmL179IE@A`EDh3Kdm816a:@0AZ@cP4Icd`16Ll;`AY@SH4JdLk0fe;
@@A`D4L4LeE=17EJDPAhH5P4NfEN0gmZI0B2KfT4QGE_18UiM@B<OWX4Sh>019>8QAGoool001Coool4
UHj<19B?S@BDT8l4Ti2?19:@T0>ATI84T96C192BU0B?TiD4SY>F18fDU`><U9P4S9FI18^EVPB:UY/4
RIJL18RFW@B7Uih3QYNO18NHX@B0TYX4OY2G17j>U@AmSI<4OHbA0gj;T0AmRHd4OHR:17j7R@AnQXT4
OhN90h26R@B2R8X4PXF718:2Q0B1OGl4P7Uk17ibL`=mKFh4NVQX17MSHPAeGe`4LUUE171ECP=_CdP4
K4Y016Y3>0AW?C04Ic`_16U2=PA[Ac/3KD]1171@A`AcEDd4MEYB17QPF0AkIEh3OfYT189_J@B5MFl4
RGUe18anNPB?Ph04ThR55Oooo`005?ooo`BESX`4U8n=19B@S`BCT8l4TY2@0i6ATPB@TI<4T9:D18nC
U@B>TiH4SIBG0hbDV0B<UIT4RiFJ18ZFV`B9UY`4R9JM18NGWP>6Uil4QiRQ182BVPAnT9L4OXjE17f=
T`AmS943OX^@17f9S@AmR8X4OXN917j6R@AoQhT3P8J918:8RPB2QHL4PX:4185mO`B0NG/4OW9c0ge]
KPAjJ6P4Mf=R17EOG0AbFED4L5E>0fm?B0A/BT04JT<h16Lm<0AW?2l4JD8f16]7>`=]Bd44L51717=E
C@AeFU84N61H17]UGP=oJV@4PVmY18EeK`B9NGD4S7ij18n3P0BCR8DEoooo000Doooo19F>S0BDShh4
Ti2?19>@T0BBTI43TI6B192BT`B?TYD4SY>F18fDU`B=U9P3S9FJ18^EV`B:UY`4RIJM18RGWPB7Uil4
QINP0hBHX@AiSYP4O8nH17b?U`AlSYD4OHjD17f=T`=mS944O8V=17^6RPAkQXP8O8J80gj6R0B0QhT4
PHR:1825QPB0PX84P7io17eeM@=jKFh4MfIV17APH0AaG5T4KUIA16eBB`=/CDH4JTTo16Q2>0AV?C44
I3P[16Dl;`AW@CD3JTHk16a;@@A_DDP4LUI>17ELE0AiHEX3O6MQ181]I`B4LVd4QgQc18]mN@B?Pgl4
TXR55Oooo`005?ooo`BESX`4U8n>19>@S`BCT904TY6A0i6ATPB@TY<4Si:E18jCUPB=U9L4SIBH0hbE
VPB;UI/4RYJL18VFW@B8Uih4QiNO18FGX0>4V:44NHjH17b?V0AlSiL4O8jE17f>U0AmSI<3OHbA17b9
S@AkQXX4NhJ827b6R0=nQXP4P8N91868RPB0QHH4P8:2181nO`AmMGD3NVe^17MVIPAdH604LEaI16iF
D@A]DT/3K4e616Y9?`AX@SP4ISda16@h:`AU?2l4Id4e0fY6>`A/Bd44Ke58179FCPAeG5@4NF5J0gaW
H@B0KFL4Q79]18MhL`B;OGT4Sh=o19:8QAGoool001Coool4UHj<19B?SPBCT8l4Ti2@19:AT@>ATI84
T9:C18nBU@B>TiH4SIBG18fDV0><UIX4RiFK18ZFW0B9UYd4R9NN18NGW`B5Uj03Q9RQ17V>V0AlSiP4
O8nG17b>U@AmSY@4OHfC0gf<T@AlRHd4NhJ:17^6R0QlQXP3OXJ81827R@B1R8X4P8F61822PPB0OWl4
OGEe0gY]KPAgIVH4M61P175LF@A^EU44KE9;0fa=APAZBCl4J48h16Hm<@AT>2/4IC`_16M1=@=ZAS/4
K4]116mAB0AbETh4MEaD17UQFP=lIf44P6eW18AbK@B7N7<4Rgei18n3O`BBR8DEoooo000Doooo19F>
S0BDShh4Ti2?19>@T0BBTI43TI6B192BT`B?TYD4SY>F18fDU`B=U9P3S9FJ18^EV`B:UY`4RIJM18RG
WPB7Uil4QINP0hBHX@AiSYP4O8nH17b?U`AlSYD4OHjD17f=T`=mS944O8V=17^6RPAkQXP8O8J80gj6
R0B0QhT4PHR:1825QPB0PX84P7io17eeM@=jKFh4MfIV17APH0AaG5T4KUIA16eBB`=/CDH4JTTo16Q2
>0AV?C44I3P[16Dl;`AW@CD3JTHk16a;@@A_DDP4LUI>17ELE0AiHEX3O6MQ181]I`B4LVd4QgQc18]m
N@B?Pgl4TXR55Oooo`005?ooo`BESX`4U8n>19>@S`BBT904TI6B0i2AT`B?TY@4Si>E18jCU`B=U9P4
S9FI0h^FV`B:UY`4RINM18RGWPB7V9l4QYRP18BHX@>2Uj44N8jH17V?U`AjSiL4NhjE17b?U@AlSYD3
OHfB17^:SPQiQHP4NHB817J3Q@=lR8X4OhR:18:;S0B2RHX4PH>41822P@AmNgX3NG=c17=XI`A`GUd4
KEUG16]DC`AZCdT3JDa416Q8?`AW@cP4I3da168g:PAQ=RT4Hc/^0fE0=@AXAS`4Jda216mBB@AbF504
MUiG0gYTG@AnJV@4PW1[18IfL@B:O7P4SX9n19:8Q1Goool001Coool4UHj<19B?SPBCT8l4TY2@196A
TP>@TI<4Si:D18nCU@B>TiL4SIBH18bEV@>;UY/4RYJL18VGW@B8Uih4QiRO18JHX0B4V:43PYNQ17R>
V0AiSiL4NXnG17^>U@AlSiD4O8jE0gf=TPAkRXh8NHF817V4R0AfPhD3O8R:17n8RPB2Rh`4PXV:1863
Q0B0PX44OG]j0gUcL`AcJ6L4L5iM16eIE`A[E4l4JTm90fU<A0AXB3l4Id<h16@m<@AR=bX4HCHY16<k
;P=U@3D4J4Hl16]<@PA_DTT4LUQ@17INE`=jI5d4OVYT189`J`B6MW44RWah18j2OPBBR8@Eoooo000D
oooo19F>S0BDShh4Ti2?19:@T0BATI83T96C18nBU0B?TiD4SY>G18fDV0B<UIT3RiJK18ZFW0B9Uid4
R9NN18NHW`B6V:04Q9RQ0h:GX@AhSYP4NHnG17Z?U`AkSYD4O8nE17b>U@=mSI84NhZ>27V5R0AiQ8P4
MX>50gb8RPAoR8X4PX^<18:9RPB1Ph@4P8:117ekNP=iLg<4LfQW171NG@A]FEL4JeA?16Y?B@=YC4@4
J4Po16M3>0AT?C44HSLZ164f:@AS>bh3ID0e16Q6?0A[C484Ke99179HD0AfGUL3NVAM17iZI0B2L6/4
QWIa18YlN0B>PWh4TXR45Oooo`005?ooo`BESX`4U8n>19>@S`BBT904TI6B0i2AT`B?TY@4Si>E18jC
U`B=U9P4S9FI0h^FV`B:UY`4RINM18RGWPB7V9l4QYRP18BHX@>2Uj44N8jH17V?U`AjSiL4NhjE17b?
U@AlSYD3OHfB17^:SPQiQHP4NHB817J3Q@=lR8X4OhR:18:;S0B2RHX4PH>41822P@AmNgX3NG=c17=X
I`A`GUd4KEUG16]DC`AZCdT3JDa416Q8?`AW@cP4I3da168g:PAQ=RT4Hc/^0fE0=@AXAS`4Jda216mB
B@AbF504MUiG0gYTG@AnJV@4PW1[18IfL@B:O7P4SX9n19:8Q1Goool001Coool4UHj<19B?SPBCT8l4
TY2A196ATP>@TY<4Si:E18jCUPB=U9P4S9FI18^FV`>;UY`4RYNN18VHW`B8V:04QYVQ18FIXPB4VZ@3
MhnK17N>V0AhSYL4NHnG17Z>U@AkSiH4O96G0gf@U@AkS8l4N8N:17F3QPAkRH/4NXN90gb:R`AnRX/4
P8V:18:;S0B3QXH4PhB4189oOP=nNGP4M6a[16]OGPAYEUD4Ie5>16I<A`=VBT<4IdLo16I3>0AS?C84
HCP[15ld9PAO=RX3H3X_16=0=PAWAcd4Jdi516mDC0AdFe<3N65J17aXHPB0KVT4QGA_18UkMPB=PGd4
TXN45Oooo`005?ooo`BESX`4U8n>19>@S`BBT944TI6B0i2BT`B?TYD4SY>F18fDV0B<UIT4RiJK0h^F
W0B:Uih4RIRO18RHX0B6VJ44QIVR18BJY0=gSi/4MhjH17R>U`AiSiL4NXjE17^?UPAlTIL3OI2E17^<
S`AhQhX4MH>617^9R`AjQhT3O8Z;17j:R`B0RHX4PX^<18>6QPB3Q8@4PWmn0giiN0AdK6/4JemN16UF
E@AWDDh4ITa70fI:@`AWAcl4IT<h16<m<PAQ>2/4Gc@V15lf:P=P>Rl4Hd0f16M7?@A[CTD4KeA<17AK
D`=hHEX4O6QR181^J@B5M6l4RG]f18f1O@BBQh@Eoooo000Doooo19F>S0BDShh4Ti2?19:@T@BATI83
T9:C18nBU@B>TiH4SIBH18bEV@B;UY/3RiJL18ZGWPB9V9l4R9RP18JIX@B5VJ84Q9ZT0gN?V`AgSYP4
N8jG17V?U`AjSYD4NhnF17bAU`=mT9D4Nhb?17R7RPAePhH4NhV;17Z7R@=lRX/4OXZ;1829RPB2Rh`4
PhJ618>4Q0B2Ogh3OWUh17A/J`A[Geh4JEIE16MACPAVC4L3ITY316M7?`AV@cP4Hcdb164h:`AO=2H4
GcHZ0f0j;`AS@3H4IdLm16]>A@A_E4`4M5]C0gQQFPAlJ684P6iY18EdK`B9NgH4SH5m19:7Q1Goool0
01Coool4UHj<19B?SPBCT8l4TY2A196ATP>@TY<4Si:E18jCUPB=U9P4S9FI18^FV`>;UY`4RYNN18VH
W`B8V:04QYVQ18FIXPB4VZ@3MhnK17N>V0AhSYL4NHnG17Z>U@AkSiH4O96G0gf@U@AkS8l4N8N:17F3
QPAkRH/4NXN90gb:R`AnRX/4P8V:18:;S0B3QXH4PhB4189oOP=nNGP4M6a[16]OGPAYEUD4Ie5>16I<
A`=VBT<4IdLo16I3>0AS?C84HCP[15ld9PAO=RX3H3X_16=0=PAWAcd4Jdi516mDC0AdFe<3N65J17aX
HPB0KVT4QGA_18UkMPB=PGd4TXN45Oooo`005?ooo`BESXd4U8n>19>@T0BBTI44TI6C0i2BU0B>TiH4
SIBG18bDV@B<UIX4RiJL0hZGW@B9V9l4RIVQ18RJXPB6VZ<4PiVR18>JY@=`RYH4M8fG17J>U`AhSiP4
NHnF17Z@U`AlTYT3OI:G17b@T`AmSHl4MH:417R3QPAiQHH3NXF617b7R0AnQXL4P8J717n1P@B0P7l4
PGak0h9kN@AmLW04LFIT16EFE@ASCT/4HTY50fA8@@AUASh4I4<i168n<`AP>2/4GS<T15`c9P=K=BT4
GSX`16=2>0AWBD04K518175HD0=eGeP4NVEO17m/I`B3Lfh4R7Ye18f0O0BAQh@Eoooo000Doooo19F>
S@BDShh4Ti2@19:AT@BATI<3T9:D18jCUPB=U9L4S9BI18bEVPB;UY`3RYNM18VHW`B9VJ44R9ZR18JJ
X`B3VJ84PiZU0g2:UPAdSIL4MXjG17R?V0AiSiH4NY2G17bBV@=mTYL4O92C17f=S`AePX@4N8>617V5
QP=jQHH4O8N817j6Q`B0QXL4Oh611820O`B1O7/3PW]i17ebL0AaIV@4IEIE16=>B`ARBTD3I4Q116E6
?PAT@cT4HShc160h:`AN<b@4G3<V0e/e:@AN>S04Hd8h16M9@0A/D4P4LEQ@0gEOF0AjIEl4OfaW18=c
KPB8NWD4SH1l1967Q1Goool001Coool4UHj=19B?SPBCT904TY6A196AT`>@TY@4SY>F18fDU`B<U9T4
S9FJ18^FW0>:Uid4RIRO18VIX@B8VZ84QYZS18>IXPB3VZD3L8ZF17B=U`AfSYL4N8nH17V?UPAjT9L4
O9:I0gfBU`AlT9<4OHf?17F2Q0AhPhH4NHF60gZ5QPAlQhP4OXJ71826Q`AoPH44P81o185lN`>2NgT4
OG9`175VI0AUEUD4Hdi;169:A@=TB444IDHn16A3>@AR?S<4H3P[15hc90AL<bH3FcDY15hj<0AS@SP4
IdU016a@B0AaF503MEmH17YUG`AoK6L4Pg=^18QjM@B=P7`4THN45Oooo`005?ooo`BESXd4U8n>19>@
T0BBTI44TI6C0i2BU0B>TiH4SIBG18bDV@B<UIX4RiJL0hZGW@B9V9l4RIVQ18RJXPB6VZ<4PiVR18>J
Y@=`RYH4M8fG17J>U`AhSiP4NHnF17Z@U`AlTYT3OI:G17b@T`AmSHl4MH:417R3QPAiQHH3NXF617b7
R0AnQXL4P8J717n1P@B0P7l4PGak0h9kN@AmLW04LFIT16EFE@ASCT/4HTY50fA8@@AUASh4I4<i168n
<`AP>2/4GS<T15`c9P=K=BT4GSX`16=2>0AWBD04K518175HD0=eGeP4NVEO17m/I`B3Lfh4R7Ye18f0
O0BAQh@Eoooo000Doooo19F>S@BDShh4Ti2@196ATPB@TY<3Si:E18jCUPB=U9P4S9FJ18^FV`B:Uid3
RIRO18VIX@B9Vj<4RIbU18NLYPAoUZ04NY>N0g:;U`AdSIL4MHjG17N>U`AhSiH4NI6H17bDVP=mTiP4
OY>F17nBU0AiRhd4NHR:17V7R@=iQHL4NhJ817f5Q`AmQHD4OGmo17elO0AmMgH3OWMe17]`K@AgJFL4
JUaI161<BPAPAd@3HDI016=6?PAS@cT4HChc15li;0AN<bH4Fc4S0eXc9@AI=BX4Gcdc16A5?0AYCD@4
KUA=0g=LE@AhHed4OFYU189aK0B7N7@4S81l1967PaGoool001Coool4UHj=19B?SPBCT904TI6B192B
T`>?TYD4SY>F18fDV0B<UIX4RiJK18ZGW@>9V9l4RIVQ18VKX`B9W:D4QibV17nFX0AjTih3LX^G17B=
U`AeSYL4MhjG17R?UPAiTIP4O9BJ0gfCV0AnTiH4Oi:D17V;S@AiR8X4NHN90gV5Q`AkQXP4OHF717f5
Q@AmOgl4OGal17egMP=nMgD4Ng1]17MYI`AZG5T4H4a:1617A0=QAT04HdHn16=3>@AQ?S<4GcT/15hc
9PAK<B<3FS<U15Te:PAO?C<4I4Dl16U=A0A^E4d3LeaE17QSG@AmJVD4PW5/18MhM0B<P7`4THN35Ooo
o`005?ooo`BESXd4U8n>19>@T0BATI84T9:C0hnBU@B>TiH4SIBH18bEVPB;UY/4RYNM0hVHW`B9VJ44
RI^S18VLY@B7W:H4OiJP17ZCWP=bRiL4M8fG17F>U`AgSYL4N8nF17VAV0AlU9X3OI>H17jCUPAoTY@4
NH^=17V8RPAiQhT3NHF717^6R0AmQHL4OHF517eoO`AmO7`4OGMf0gigM@AkL6d4MfUW16YLF@APC4X4
H4M40f56@0ASASh4Hd<i164n<`AO>B`4GS<V15/a8`=J<bD4FCDZ15lm<`ATAC`4JDe416iDC@=cG5D4
N6=M17eZI@B2LF`4QgQd18b0O0BAQh<Eoooo000Doooo19F>S@BDShl4TY2@196ATPB@TY@3Si>E18fC
U`B<U9T4RiFJ18ZFW0B9Uih3R9RP18RJXPB9W:D4RYnX18fR[@B1VJ<4LhjJ0gB=V@QdSYP4MHjH17J?
U`AhTIT4NY>J0gZ@UPAhS904NHb?17R<SPAhRX`4NHZ<0gZ:R`AkRX`4OHV:17f8R0AmQH@4OH1n17]i
N0=jMW@4NG1]17IYIPA`HEd4He1=15i7@`=OAD04HTDn1693>PAQ?S@4GST]15dd9`AI;b43DB/M15Ha
9PAJ>Bh4H44h16I9@@A[DDX3LEUB17IQFPAlJ6<4PG1[18IgL`B;Og/4THJ35Oooo`005?ooo`BESXd4
U8n?19:@T0BATI84T9:D0hnCU@B=TiL4S9BI18^EVPB:UY`4RINN0hRHX0B8VZ84RIbU18ZOZ0B=XZd4
PIVS17>>VP=dSIT8M8jH17F>V0AfSiL4N96I17ZCVP=jT9H4N8b@17V<S`AhS8h4N8Z<17V:S0=jRX/4
NhZ<17f9RPAmR8P4OHF417f0OPAkNGP3NWId17U`K@AfJFH4L65M16=@C@ANAd<3GdE01695?PAR@cX4
HChd15hi;@AM=2L4FBlQ0e4[7@AF<BH4FST^1611>0AVBD44Je5:0g5IDPAfHEX4O6QS185`J`B6Mg<4
Rgmk1966PaGoool001Coool4UHj=19B?S`BBT904TI6B192BU0>?TiD4SI>G18bDV@B;UIX4RYJL18VG
WP>8V:04R9ZR18VLY@B:WjP4SJ:]186IX`AcSYX3M8fI27B>V0AeSYP4MXnG17RAV@AjTiX3NY2F17R<
T0AiS8l4N8b>17R:S0AiRX`3NXZ;17^:S0AmRHX4OHR817f5Q0AmP7h4NgUh0gYfM0AiL6d4MVUV171Q
G@ASD4d4GTM30em5@0ARACh4HT<j164n=0AN>Bd4GC@W15T_8@=A:ad4ES4V15Xi;PAP@CP4ITU116]A
BP=aFE84MV5J17aXH`B1L6/4QWMc18]oN`BAQX<Eoooo000Doooo19F>S@BDShl4TY2@196ATPB@TY@3
Si>E18fCU`B<U9T4RiFJ18ZFW0B9Uih3R9RP18RJXPB9W:D4RYnX18fR[@B1VJ<4LhjJ0gB=V@QdSYP4
MHjH17J?U`AhTIT4NY>J0gZ@UPAhS904NHb?17R<SPAhRX`4NHZ<0gZ:R`AkRX`4OHV:17f8R0AmQH@4
OH1n17]iN0=jMW@4NG1]17IYIPA`HEd4He1=15i7@`=OAD04HTDn1693>PAQ?S@4GST]15dd9`AI;b43
DB/M15Ha9PAJ>Bh4H44h16I9@@A[DDX3LEUB17IQFPAlJ6<4PG1[18IgL`B;Og/4THJ35Oooo`005?oo
o`BEShd4Ti2?19:AT@BATI<4Si:D0hjCUPB=U9P4RiFJ18ZFV`B9UYd4R9NO0hNIX@B7VZ<4R9bV18^Q
ZPB@YK04RInX17VAW0=dSYT4LhjH17>>U`AdSYP4MHjG17JAV@AhTiX3N92G17F9SPQeR8/4MXR;17N8
R`=hRH/4NHV;17^8RPAkQXL4Nh>317YoOPAiNWP3MWIc17EaK@AcJfL4L6AN16UID`AQC4P3GdM11656
?`AQA3X4H3le15hj;PAM=RT4GC@V0ddW6`A@;B44EcD[15dn=0ASASh4JDm70fmGC`AdGeP4NVMQ181_
J@B5MW84Rgij1926PaGoool001Coool4UHn=19>@S`BBTI44TI6C18nBU0>>TiH4SIBH18^EVPB:UY/4
RIJM18RGW`>7VJ44QiZS18RLYPB;XJX4T:F`18VOZ0AiTI`3M8jI17>>V0AcSYL4M8jH17F>U`AfTIT4
N9>J0gR@U`AeRHh8MHR;17J8R`AgR8/3N8V;17V9R`AkR8X4NhJ717^3P`AjOgh4NGYh0gIfL`AeLFd4
Lf]W171TGPAYFE<4HDa80em7@@AQASl4HD@j160o=@AN>Rh4GCHY15dd9P==9a/4D2dQ15Le:`AM?S@4
HdHn16U?A`=_Edl4M5mH17YWH@B0KfT4QGIb18]nNPB@QX<Eoooo000Doooo19F?S@BCT8l4TY6A196A
T`B?TY@3SY>F18fDV0B;UIX4RYJK18VFW@B8Uil3QiVQ18NJX`B8W:H4Rj6Z192U/0B9WjP4NI6L0gB>
V@AcSYP4LhjG17B>V0AeSYL4MY6I17RCVP=hT9L4MHV>27F8R`AfR8/4MhR;0gR9R`AiRH/4NhR:17^6
Q`AkPh<4NWmn17UjN0=fMW<4MG5]17=[I`A`I5h4JEUC165<B0=OAd44HDHo1654>PAP?cD4GSX^15df
:@AM=2H3CBLK150]8@AG=B/4GChd16=6?PAYCdL3KeM?17AOF0AjIf44P6mY18EfLPB;OWX4T8J35Ooo
o`005?ooo`BEShd4Ti2?19:AT@BATI<4Si:D0hjCUPB=U9P4RiFJ18ZFV`B9UYd4R9NO0hNIX@B7VZ<4
R9bV18^QZPB@YK04RInX17VAW0=dSYT4LhjH17>>U`AdSYP4MHjG17JAV@AhTiX3N92G17F9SPQeR8/4
MXR;17N8R`=hRH/4NHV;17^8RPAkQXL4Nh>317YoOPAiNWP3MWIc17EaK@AcJfL4L6AN16UID`AQC4P3
GdM11656?`AQA3X4H3le15hj;PAM=RT4GC@V0ddW6`A@;B44EcD[15dn=0ASASh4JDm70fmGC`AdGeP4
NVMQ181_J@B5MW84Rgij1926PaGoool001Coool4UHn=19>@S`BBTI44TI:C18nCU@>>U9L4S9BI18^E
VPB9UY`4R9NN18JHX0>5VJ44QIZS18FKYPB6WZP4Q9bW182HX`AiTYd3LhjI176<U`AaSIH8LXjG17B@
V0AfTIT3MXnF17>9S`AaQ8T4LXF817>6RPAeQhX3MXN:17N9R`AiR8X4NHF617V1PPAhOGd4MWUg0g=c
L@A`KFX4KVMS16]PF`AWF5<4HTm:0f1:A0APAd04HD@l1610=PAN>c04GSP[15dd9P=:9AT4CBTN15<b
9`AJ>c44H4<j16I<A0=/E4d4LUeF17QUG`AnKFP4Q7Ea18YmNPB@QH8Eoooo000Doooo19F?S@BCT8l4
TY6A196BT`B?TiD3SYBG18bDV@B;UIX4RIJL18RGWPB6V:03QIVQ18FJX`B5VjH4QYjX18BLY`B0V:<4
NI:M0g>>V@AaS9L4LHfF27:>U`AdT9P4MY6I0gJ?UPAcRHl4LHB917:5R0AcQXX4MHN:0gJ7RPAgRH/4
NHR:17V5QPAiPH84N7em17IiM`=cLg44L6eZ16iWH`A[H5/4IeQC169?BP=PBT@4H4M01654?0AP@3H4
GS/`15hh:`AM=2H3BRDI14dY7PAC<RL4FS/a1613>PAVC4@3K5A=179MEPAhIEl4OVeX18AeL@B:OGX4
T8F25Oooo`005?ooo`BEShd4Ti2?19:AT@BATY<4Si>E0hjDU`B<U9T4RiFJ18VFW0B8Uih4QYRP0hFI
X@B5VZ<4QI^V18JNZ0B4W:L4P9RS17VBW@=cSYT4LHbG176=UPQbSYL4M92H17JAV@=fSiH4LhV?1764
R@AbQHP4LhJ:17F7RP=fQhX4MhV;17V8RPAiQHH4NH6217QmO@AfNGL3Lg=a171]JPA^If<4Jf1K16MH
D`ARCdX3H4Y41617@0AQA3`4H40f15hk<0AN>2/4GC@V0dXU6@A=:Ah4Dc8W15Xk<@AP@cX4ITa40faD
C@AbGEH4N6EO17i]J0B4MG44RWej1925PQGoool001Coool4UHn=19>@S`BBTI44TI:C18nCU@>>U9L4
S9BI18^EVPB9UY`4R9NN18JHX0>5VJ44QIZS18FKYPB6WZP4Q9bW182HX`AiTYd3LhjI176<U`AaSIH8
LXjG17B@V0AfTIT3MXnF17>9S`AaQ8T4LXF817>6RPAeQhX3MXN:17N9R`AiR8X4NHF617V1PPAhOGd4
MWUg0g=cL@A`KFX4KVMS16]PF`AWF5<4HTm:0f1:A0APAd04HD@l1610=PAN>c04GSP[15dd9P=:9AT4
CBTN15<b9`AJ>c44H4<j16I<A0=/E4d4LUeF17QUG`AnKFP4Q7Ea18YmNPB@QH8Eoooo000Doooo19F?
S@BCT8l4TY6A192BU0B?TiH3SIBH18^EV@B:UY/4R9JM18JGW`B5V:03PiRR18:IY0B1VZD4OiZV17fG
XPAiTYd4M8jI0g2;U`Q_RYD4Kh^E172<UPAaSYL4LXnH0g>=U@AbRY04L8B916n2QPAaQ8P4LXF90gB5
R@AeQXT4MhN:17N5Q`AgP884MG]l17AgM`=aLG04KV]Y16]UHPAXGe/4IEQC165@B`=PC4H4H4U21615
?@AO@CL4Gc`b15li;@AP=bT3Ab<G14TU6PA@;R<4ESL]15e0=`ATBD43JU9;175KE0AgHeh4OFaW18=d
L0B:OGT4T8F25Oooo`005?ooo`BEShd4Ti2?19:AT@B@TY@4Si>F0hfDV0B;UIT4RYJK18RFW@B6Uil4
QIRP0h>HXPB2VJ@4PIZU17nJYPAmUj84NI:M17B>V@=`RiL8KhZE16n;U@A`S9H4LHjG17:?V0=cSID4
LXZ@1724R@A_PXH4LHB817:5R@=dQHT4MHJ917N7RPAgQHL4Mh2217EkO0AdMgL3LG5`16i[J@A[IF84
J5mK16EHD`AQD4/3H4a61619@PAPACd4Gd4g15ll<PAO>Bd4H3LY0dLS5`A99AX4D2hS15Hg;@AM@3L4
I4U10fYBB`AaFe@4Mf=N17e/I`B3M704RWei1925PQGoool001Coool4UHn=19>@S`BBTI44T9:D18nC
UP>=U9P4RiFI18ZFV`B8UYd4QYNO18FHX0>3V:84PYVT186JY@AoVZH4OINR17VBW@AdSYT3L8^G26n:
U@A_RiD4L8bF176>U`AbSiP3LhfE17::T0A`Q8T4Kh:61764R0AbQHT3M8F917F6R@AgQhX4MhF717N0
PPAeNg`4M7Mg0g5aL0A^JfT4JfER16QOF`AUF5<4HE1;0f1<APAPBD84H4Dm15m1=`AO?384GcT]160g
:@=78aL4BBDJ150^8`AF=bd4GD0g16A9@@=ZDT/4LE]D17MSGPAmK6L4PgA`18YmN@B@QH8Eoooo000D
oooo19F?S@BCT8l4TY6A192BU0B?TiH3SIBH18^EV@B:UY/4R9JM18JGW`B5V:03PiRR18:IY0B1VZD4
OiZV17fGXPAiTYd4M8jI0g2;U`Q_RYD4Kh^E172<UPAaSYL4LXnH0g>=U@AbRY04L8B916n2QPAaQ8P4
LXF90gB5R@AeQXT4MhN:17N5Q`AgP884MG]l17AgM`=aLG04KV]Y16]UHPAXGe/4IEQC165@B`=PC4H4
H4U21615?@AO@CL4Gc`b15li;@AP=bT3Ab<G14TU6PA@;R<4ESL]15e0=`ATBD43JU9;175KE0AgHeh4
OFaW18=dL0B:OGT4T8F25Oooo`005?ooo`BEShd4Ti2@19:ATPB@TY@4SY>F0hfDV0B;UIX4RIJL18NG
WPB5Uj04PiRQ0h6HXPAoV:@4OIRU17ZFX`AgTj04LhjJ1729U0=/R9@4K8JB16b7TPA/R9<4K8ZD16f;
U0A^SID3KhbD16n9T0A]Q8X4K82516j2QPA`QHP3LXF917>5R@AfQXX4MXB717F1PPAcNW/4LWIf0fi_
K`A[JFL4If=Q16INF`ATF5@4HE9=0f1>B0AOBT<4GdHn15m2>0AN?C<4Gc/^16<j:`=<9aX4A20E14`Z
7`AC=2X4Fche1697?`=XD4T4KeUB17ERG0AlJfD4PW=_18UlN0B?QH8Eoooo000Doooo19F?S@BCT904
TY6B192BU0B>TiH3SIBH18^EVPB9UY`4QiNN18FGX0B3V:43PIRR17nHY0AmV:D4NYJS17NCX0AcSYX4
L8VD0fb8U0A/QY84K8NB16b8T`A/RY@4KH^D16j=U@=_S9@4KhV@16f4RPA/P8D4KX:61725R0=bQHT4
LhF917J6RPAfQ8L4MH6217=jN`AbMWH3KVm_16]YI`AWHf44IUiK16AHE0AQDTd3H4i815m:@`AOASh4
Gd8h15hm<`AO>bh4HcX[0d`W6PA481D4C2XO15<d:PAK?SD4HTLo0fQ@B@A_FE84MF9L17a[I@B2Lfl4
RGah18n5PQGoool001Coool4UHn=19>@T0BBTI84T9:D18jCUP>=U9P4RiFJ18VFW0B7Uih4QINP18>H
X@>1V:84OiRT17fHY@AjUZ<4Mi>P17>>VPA`RI@3K8RD16b6TPA/Qi84K8RC16b:U0A]Ri@4KXfE0fn<
U0A_RI04KHB:16b0Q@A^PXH4L8F80g:5R@AcQHT4MXJ:17J4Q`AePH84LgYk179fMP=^Kfl4JfUW16MS
H@AVGU/4I5QD165BC@=PCTP4GdY315m6?PAO@SP4GSdc15lk;PAS>R/3C2LJ14@P5@A<:Ql4Dc@Z15/n
=@ARAcl3J51916mIDPAeHU`4O6]U189cK`B9O7P4ShF25Oooo`005?ooo`BEShd4Ti2@19:ATPB@TY@4
SY>F0hfDV0B;UIX4RIJL18NGWPB5Uj04PiRQ0h6HXPAoV:@4OIRU17ZFX`AgTj04LhjJ1729U0=/R9@4
K8JB16b7TPA/R9<4K8ZD16f;U0A^SID3KhbD16n9T0A]Q8X4K82516j2QPA`QHP3LXF917>5R@AfQXX4
MXB717F1PPAcNW/4LWIf0fi_K`A[JFL4If=Q16INF`ATF5@4HE9=0f1>B0AOBT<4GdHn15m2>0AN?C<4
Gc/^16<j:`=<9aX4A20E14`Z7`AC=2X4Fche1697?`=XD4T4KeUB17ERG0AlJfD4PW=_18UlN0B?QH8E
oooo000Doooo19F?S@BCT904TY:B192CU@B>U9L3S9FI18ZFV`B8Uid4QYNO18BHX@B1V:83OYRS17^G
Y0AhUjD4MI:P17:?W0A]R9D4JXJB0fV5T@QXQ904JHJ@16V7TPAZR984JXVC0f^9TPA/R904JhB:16Z0
Q@A[P8D4KH:70fn3Q`AaQ8P4LhF817B3QPAbOX04L7Uj16ieM@=[KVh4J6QV16AQG`ARG5T4HEMD161C
CP=OCdT4GT]415e6?`AL@ST4G3hd15hk;`AS>bd3F30R14TS5PA691T4DC8X15Tl<`APACd3ITi716eG
D@AdHE/4NfYT185cKPB8O7P4ShF15Oooo`005?ooo`BEShd4Ti2@19:BTPB@TiD4SYBG0hbEV@B:UY/4
R9NM18JGW`B4V:44PIRR0gjHX`AkUj@4N9NU17FBX0AbSi`4KHRE16Z6TP=YQI48J8B@16V6T0AYQi84
JXRB16Z9T`=[RI84K8R@16^4RPAZP8D4Jh2516f2Q`=_PhL4LHB817>5R0AdPhH4LWj0171iNPA^MGD3
Jfi^16QXIPATHEl4HUaI165GE0APDdh3Gdm915i;A0AMASl4G48i15`n=0AN>bl4Hc/]0eP`8PA98aH4
AR@I154b:0AI?3<4H4Dm0fI>A`A]Ee44M65K17]ZI0B1Lfh4R7ah18n5PAGoool001Coool4UHn=19>@
T0BBTY84T9>E18jDU`><UIT4RYJK18RGW@B6Uil4Q9RQ186HXP=nV:<4NiNT17RGY@AeTZ04LXnL16f8
U@AZQY83JHFA26R4T0AYQY04JHNB16Z8TPAZRI<3JhVB16b8T0A[Q8X4JX2516^0Q@A]PXL3Kh>71764
R0AcQHP4M8>6179nP0A`NGX4KWEe0f]^KPAXJ6H4I65O169LF@AQEe@4H5=>0em?B@ANBd@4GDHo15a2
>@AL?S@4GS/_16<k;@=H<284BB<F14HT6@AA<RP4FC`c1615?@=VCTL4KEMA17AQF`AkJV@4PG=^18Ql
N0B?QH4Eoooo000Doooo19F?SPBCTI04TY:C192CU@B>UIP3S9JJ18ZGW0B8Uih4QIRP18:HXPAoV:<3
O9RT17RGY@AeU:<4L8jM16b8U`AVPY04I8>?1fB2SPAUPXd4IH>>26J4S`MWQHl4J8B=16R2R@AXOhH4
JGn516^1QP=]PHH4Kh>71762Q`AbPH@4L7ao16igN@AZLG<3J6a/16=UI0AQGed4GeYH15iFD`ANDdh3
GDm915]:A0AKASh4FT4i15Tm<`AI>2h4FcL/0eTb9@AC:ah4CBTN154a9`AG>S44GT<k0fA=A@A[ETl4
LUmI17UXH`B0LVd4R7]g18n4PAGoool001Coool4UHn>19>AT0BBTY<4T9>E18jEV0><UYX4RYNL18RG
WPB5V:04PYRR17nHX`=lV:@4N9NU17FDX`A`SYd4K8RG16J2T0ATPhl7I8:>16F2S@AUPhh8IXB?1fN5
S`AXQ8d4J8:916QoQPAYOhD4Jh660ff1QPA_PhL4LH:717:1Q0A`O7l4KWMi16YaL`=XK6`4HfET165O
G@AOFUP4GUIC15iCCP=MCdT4FdY415]6?PAJ@CT4FCdc15Th;PAK=b`3FC8U15<[7PA=:Ah4DC4W15Lj
<@AN@c/3I4e516]FC`AbGeT4NFQS181bK@B8NgL4ShB15Oooo`005?ooo`BEShh4Ti6@19:BT`B@TiD4
SYFH0hbFVPB:Ui`4R9NN18FHX0B2V:84OiRS0gbHY0AhUjD4MIBS172>W@A/R9L4IX:@16B3S`MTPXh4
IH:=16F3SPQVQ8l7IhF?16R4S@AXPXT4J7n616UoQ@A[PHH3KH6616n3Q`AaPXL4LX64171lO`A^MgT4
JW5c0fQ/K0ASIF@4HEmM15mJF0ANEU<4GU=>0ee?B@AKBT@4FdHn15Y1>@AI?C<4FCP^15/g;0=I<RD4
Db/N14dY7PAA<BL4EcXa15i3>`=TCDD4JeI?179OF@AiJ6<4P79]18QkM`B?Q84Eoooo000Doooo19F?
SPBCTI04TY:C192CU@B>UIP3S9JJ18ZGW0B8Uih4QIRP18:HXPAoV:<3O9RT17RGY@AeU:<4L8jM16b8
U`AVPY04I8>?1fB2SPAUPXd4IH>>26J4S`MWQHl4J8B=16R2R@AXOhH4JGn516^1QP=]PHH4Kh>71762
Q`AbPH@4L7ao16igN@AZLG<3J6a/16=UI0AQGed4GeYH15iFD`ANDdh3GDm915]:A0AKASh4FT4i15Tm
<`AI>2h4FcL/0eTb9@AC:ah4CBTN154a9`AG>S44GT<k0fA=A@A[ETl4LUmI17UXH`B0LVd4R7]g18n4
PAGoool001Coool4UHn>19>AT@BBTY@4T9BF18jEV@><UY/4RYNN18NHX0B5VJ84PIVS17jIY@=jV:D4
MIRV176DX`A/SI`4IX>B165nS0AOOX`3H7n<1620S0AQP8`4HX2<26:1S0ASPH`3Hh6;16>0R@ATOXH4
I7f416InQ0AYP8H3Jh6616f3Q`A`PXL4L82416ikOPA[MGP4Ifma0fEZJ`AQI6<4GUiL15aIE`AKEE84
Fe9>0eY>B@AIBT@4EdDn15I0>@AE>c<4E3H/15<d:@=@;B44C2DI14dZ7PA@<2H4ECP_15]1>@=RBd<4
JEA>171NF0AhIf84Og5/18MjM`B>Q84Eoooo000Doooo19F?SPBCTI44TY:D192DUPB>UIT3S9JK18ZG
WPB7V:04QIVR186IX`AnVJD3NYRU17FHYPAaU:<4K8fL16J3TPAQOX`4Ggj<0f1oS0APP8`4HH2<16:0
S0QRPH`4Hh6<0f>1R`ASP8T4I7j616AmQ0AVOX@4JH260f^1QPA]PhL4L8:71720Q0A^Ngh4JgEh16M_
L@=UJV/4HFAS15iNG0ALFEL4FeEB15]BCP=JCTT4FDY415M5?PAF@3T4EC/c15@f;0AC=2T3D2dQ14`U
6@A=:Qh4D30V15Dh;`AK@CT3HT]316UDCPA`GUP4N6MR17maK0B7NWL4SXB15Oooo`005?ooo`BEShh4
Ti6A19:BU0B@U9H4SYFI0hbFV`B:Uih4QiRP18FIXPB1VJ<4OYVU0gZHY@AeV:H4LIBS16b=W0AVPi84
HGj<15mnS0=POh`4H82<1660S0ARP8`8HX6<16>1S0=SPH/4Hh2916AnQPATOH@4IWj416V0QP=[PHH4
KH>71722Q`A`P8@4KW]n16]eN0AWKg43IFY[165TH`ANGU`4G5UG15]EDPAKDTh3FTi915U:A0AGACh4
ET0i15Dk<`AD=R`4Dc@Y0e0]8@A<9AT4CBXN150`9PAE>2l4Fd4i0f9;@`AYE4h4L5iH17QWHPAoLF`4
QgYg18j4PAGoool001Coool4UHn>19>AT@BBTY@4T9BF18jEV@><UY/4RYNN18NHX0B5VJ84PIVS17jI
Y@=jV:D4MIRV176DX`A/SI`4IX>B165nS0AOOX`3H7n<1620S0AQP8`4HX2<26:1S0ASPH`3Hh6;16>0
R@ATOXH4I7f416InQ0AYP8H3Jh6616f3Q`A`PXL4L82416ikOPA[MGP4Ifma0fEZJ`AQI6<4GUiL15aI
E`AKEE84Fe9>0eY>B@AIBT@4EdDn15I0>@AE>c<4E3H/15<d:@=@;B44C2DI14dZ7PA@<2H4ECP_15]1
>@=RBd<4JEA>171NF0AhIf84Og5/18MjM`B>Q84Eoooo000Doooo19F?SPBCTI44TY>D192EU`B?UYX3
SIRM18ZIW`B7VJ44Q9ZS186JY@AmVZH3N9VW17:GYPA/TZ44IHVH15ioSPAJNXT4FW^90e]kR@ALOHX4
GGj:15inRPAOOXX4GWj:15mnR@=OO8P4Gg^615mjP`APNH44Hg^216ImP`=YOhD4K8:716j2Q`A_Oh<4
KGYn16YdM`AVKW03HFQY15eQH@AKG5/4FEMF15QDDPAGDDd3Ede915E9A0ADA3h4DSlh150j<PA?=2/4
CS8X0d/Z7`A68QH4AbDJ14`]8`AB=Rd4FClg0f19@PAWDT`4KeaG17IVH@AnL6`4QWYf18j4P1Goool0
01Coool4UHn>19>AT@BBTi@4T9FG18nFVP>=V9d4RYVO18NIX@B4VZ<4PIZU17fJYP=hVJL4LYNV16bB
X@AURIP4GWn>15YjR@AJNhT3Fg^915amRPAMOXX4GWj:15mnRPANOXX4Ggj90emlR0AONhH4GgZ3161i
P@ASNh84IWf30fUoQ@A/PXL4KX:716moP`A]NWh4JWAg16I^L0=QJ6T4GF5Q15]LF`AIEeH4F5AB15MA
C@=GCDT4EDU415A4?PAB?cP4D3Xb14ld:`A><RP3BbXO14HR5PA79AX4C2dS158f;@AI?cL3H4U216MB
C0A_G5L4MVIQ17i`K0B6NWH4SXB05Oooo`005?ooo`BEShh4Ti6A19:CU0B@UIL4SiJJ0hfHW@B:VIl4
QiVQ18BJX`B1VZD4OIZV0gRIY`AbUjH4K9:Q16F9V0ANOhh4FWZ915YkR@=KNhT4G7f:15enRPANOXX4
Ggj:15inRPAOOXT3Ggb815mkQPAONX<4H7V116=kPPAVOH<3JGn516b2Q`A^PXL4Kgn316ejOPAZM7L4
IVi`0f5XJ@AMHF44FeaK15UGEPAHE584Ee5=0eM=B@AEBD@4E4@n158o>0A@>S84Cc@[14hb:0=;:Ql4
AR8F14LU6PA<;B<4DSH]15To=`=PBD84Ie9<16mLE`AfIV44OW1/18IjMPB>Q80Eoooo000Doooo19F?
SPBCTI44TY>D192EU`B?UYX3SIRM18ZIW`B7VJ44Q9ZS186JY@AmVZH3N9VW17:GYPA/TZ44IHVH15io
SPAJNXT4FW^90e]kR@ALOHX4GGj:15inRPAOOXX4GWj:15mnR@=OO8P4Gg^615mjP`APNH44Hg^216Im
P`=YOhD4K8:716j2Q`A_Oh<4KGYn16YdM`AVKW03HFQY15eQH@AKG5/4FEMF15QDDPAGDDd3Ede915E9
A0ADA3h4DSlh150j<PA?=2/4CS8X0d/Z7`A68QH4AbDJ14`]8`AB=Rd4FClg0f19@PAWDT`4KeaG17IV
H@AnL6`4QWYf18j4P1Goool001Coool4UI2>19BBTPBCU9D4TIJH18nGV`>=VIh4RiZQ18RKX`B5VjD4
PIbW17bLZ@=gVjX4L9BT16J<W0AKPY84DgR9159fQPAEMhH3EgV715UjR0AJO8T4Fgf915amR@AKO8P4
FW^70eYiQ@AJMh<4FWJ015afOPAON804HW^20fInQ0AZPHL4KH:716enP`A[NGd4Ig=f16=/KP=OIVL4
Ff1P15QJFPAFEUD4EE9A15A?C@=CC4P4DDQ31514?PA>?SP4C3Pa14Xb:PA8;bL3A2HL14<Q5PA27a@4
B2TO14lc:PAF?CD3GDM016EABPA]FeD4MFEP17e_J`B5NGD4SX>05Oooo`005?ooo`BET8h4U9:B19>D
U@BAUYP4SiNK0hfIWPB;VZ44R9^S18FKY@B1W:L4O9bY0gNKZPA`U:@4IXbL15^2TPACN8T4DWJ615Eg
QP=GNHL4FGZ815YlR@AKOHT4G7f915]lR0AJNhL3FWV515YgP`AJMX04G7In15mhP0ARNh83IWj416Z1
Q`A]PXL4KGj316]iO@AWLgH4Hfa^0emVI`AKH604F5YJ15IFE@AEDU44E4m=0e=<B0AAB4<4D4@n14hn
>0A<>344BS8Z14P_9`=49Q`4@b4F148O50A8:Al4Cc<Z15Hm=@=MAd04IE5:16eKE@AeIF04OFm[18Ei
M@B>Ph0Eoooo000Doooo19F@SPBDTY84TiBE196FV0B?Ui/3SIVN18^JX@B8Vj<4QI^U186LY`AlW:T3
Mi^Z172DY0AVS9`4Fh:B15=hR@ABMXH4EGN60eMiQ`AINXP4FWb915]mR@ALOHT4Fgb815YkQ`=JNHD4
FWN315YfP0ALMWh4GgR0169kPP=VOX@4JX6716f2Q`A]OX<4JgUm16McMPASK6h3GfIW15]PH0AHFUX4
EUIE15EBD@ADCdd3Dda81558@`A@A3h4CShh14`h<@A:<RX4B2lW0d@V70A38AH4@QlD14PY7`A?<bX4
ESde0ee7@0AUDDX4KE]E17EUH0AmKf/4QGUe18j3P1Goool001Coool4UI2>19BBTPBCU9D4TIJH18nG
V`>=VIh4RiZQ18RKX`B5VjD4PIbW17bLZ@=gVjX4L9BT16J<W0AKPY84DgR9159fQPAEMhH3EgV715Uj
R0AJO8T4Fgf915amR@AKO8P4FW^70eYiQ@AJMh<4FWJ015afOPAON804HW^20fInQ0AZPHL4KH:716en
P`A[NGd4Ig=f16=/KP=OIVL4Ff1P15QJFPAFEUD4EE9A15A?C@=CC4P4DDQ31514?PA>?SP4C3Pa14Xb
:PA8;bL3A2HL14<Q5PA27a@4B2TO14lc:PAF?CD3GDM016EABPA]FeD4MFEP17e_J`B5NGD4SX>05Ooo
o`005?ooo`BET8l4U9:B19>EUPBBUiX4T9VM0hjJX0B<W:<4RIfU18FMZ0B1WJX4OIj/0gVN[`AaUZH4
HXVJ15AmSPA8LH<4Bg6214mdQ0=BMXH4EGV715MkR0QIO8T4F7^815MjQP=EMX84E7=o15EaO0AGLW/4
FWAl15mhP0=TO8<4JH2616^1QPA/OX<4JGQm16IbM@APJfd3G6AV15QOH0AEFET4DUAD155@C`A?CD/3
CdY714e6@PA<@Sd4BSdg14Pg<@A5<R/4@bhW0chT6`@l7aD4?A/A14<V70A;<2P4DSXc0eY5?PARCdT4
JeUD17=TG`AlKVX4Q7Ue18f3P1Goool001Coool4UI2?19BBTPBCUIH4TYNJ192IW@>>VZ04S9bS18VM
Y@B5WJP4PIfZ17fN[0=iWZl4LIJV16:9VPADOHh4B76314]aPPA?M8@3DWJ615EiQ`AGNhP8FGb915Qk
R0AGNXH3EGJ215AcO`AELG`4Eg9k15YdO0AON803I7b316V0QPA[PHH4K7j316UhO@AVLWD4H6]]0eaT
IPAHGf04EEUI159DE0AAD4l4Cde;0dm:A`A=AT84C48m14Xm=`A8=c44AC8[14<^9`<n91/4?1lE13dK
4@A39Q`4Bc0X158j<`=JACh4HTm916]IE0AcI5l4O6iZ18AiM@B=Ph0Eoooo000Doooo19F@S`BDTY84
TiFF19:GVPB@VId3SYZP18bLX`B9WJD4QIfX186MZPAmWZ`3NIj_176FYPARRIX4E7f>14QaP`A;LH84
CgB40e9fQPAENHL4Eg^825UlR@AHNhP4EgZ60eEfPPADLgl4EG5l15MbN`AJM7`4GgR00fAlP`AYP8H4
Jh6616anP`AYN7d4IW9e161[K@=LI6H4F5mP15EIF@ABE5@4DE1?14m=B`=?BTL4CDI214a2?@A:?CL4
B3La14Db:`A3;RL3?R@K13`O5@@m6a44@bHL14/`:0AB>S<3FTDn169?B@A[FE@4LfAO17a^JPB4NGD4
SH>05Oooo`005?ooo`BET8l4UI>C19BFU`BCV9/4TYZO0i2LXPB=WZD4RYnX18JOZPB2Wj`4OYn^0gZP
/@AeVJX4I8ZJ155jS0A1K804AFeo14YaPP=>M8@4DWR715IjR0QGNhP4EGV5159fP`=?Lh04Cg1m151^
NPABKGP4EW1i15afOP=RNh84J82616^1Q`A/OX<4JGQm16EbM@AOJVd3Ff=U15ING`ABF5T4Ce=C14e?
C`A<BdX3BdQ614]5@@A9@3`4Ac`g14@g<0A2<R/4?bdV0cPS6`@e6a84=QL=13hR6PA6;BD4CSPa0eM2
?0AOCDL4J5QC175RGPAjKFT4Q7Qd18f3P1Goool001Coool4UI2?19FCT`BDUYL4TiRK19:JW`>@W:84
SIjU18ZOZ0B6WjX4PYn/17jO[P=jX;44MIVZ16B:VPAANX`4@Fb014E]O`A:LH83CWB4159hQ`AFNXP8
Eg^815EiQ@ABMX<3Cg>014m`O@A@KWX4DVeh15I`N@ALMWh3HW^216R0QPA[PHL4K7j316UhO@AULWD4
GfY]0e]SI@AFGUl4DUQI14mCD`A=Cdl4C4]:0d]8APA;AD44BD0l14Ll=`A4=c04@S8[13l]9P<h8a/4
=A/B13HG3@@n8QX4ARdU14hh<@=G@S`4Gde716QHD`AaHUh4NVeY18AhM0B=Ph0Eoooo000Doooo19F@
S`BETi<4U9JG19>HV`BBVYl3T9bR18fNY@B:WjP4QYnZ18:O[0AnWjh3NZ2a17FIZPATRYX4DGZ<145/
P0A5KGl4BW620didQ0ABN8L4EWZ825MkR0AENHD4DWJ30dmcP0A?L7d4D6ij159]N0AFL7T4G7In0f9k
PPAXP8H4Jh6716anP`AYN7d4IG9e15mZK@=KHfD4EUiO159HF@A?De<4CDm?14a;BP=;B4H4BdE114U0
?0A7?3L4A3L`148b:`@o;BH3>2<K13DK4P@f5`d4?R8J14H]9@A>>343Ed8l15m=A`AXF5<4LF9N17Y]
J@B4N7@4SH>05Oooo`005?ooo`BET8l4UI>C19BFU`BCV9/4TYZO0i2LXPB=WZD4RYnX18JOZPB2Wj`4
OYn^0gZP/@AeVJX4I8ZJ155jS0A1K804AFeo14YaPP=>M8@4DWR715IjR0QGNhP4EGV5159fP`=?Lh04
Cg1m151^NPABKGP4EW1i15afOP=RNh84J82616^1Q`A/OX<4JGQm16EbM@AOJVd3Ff=U15ING`ABF5T4
Ce=C14e?C`A<BdX3BdQ614]5@@A9@3`4Ac`g14@g<0A2<R/4?bdV0cPS6`@e6a84=QL=13hR6PA6;BD4
CSPa0eM2?0AOCDL4J5QC175RGPAjKFT4Q7Qd18f3P1Goool001Coool4UY6?19JDU0BEUiP4UIZM19>L
X@>BWjD4Sj2X18bQZ`B8XJd4PZ6^17fQ/0=iWZh4M9RY1627V@A;MhX4>VQm141[OPA6Kh43Bg:3151g
QPAFO8X4FGj<15YoS0AHOHT4DWR50dacP0A9KW/4C6ei14i[MPAAJgD4FW=k0f5jPPAWP8L4Jh:816ao
Q@AYNGh4IG=e15iZK@=KI6H4EemP155HF@A=DU84BTe>14M9B0=7AT@4Ad=014Ho>`A3>cH4@CH`13lb
;0@m;RL3=B@M12lI4@@a50/4>AlG148Z8`A:=Bl3Dd0j15e;APAVEU44Kf5M17U/J0B3Mg@4S89o5Ooo
o`005?ooo`BFTHl4UYBD19FGV0BEVYd4TibQ0i:OY@B?X:P4S:6[18RQ[@B2XJh4OJ6`0gVN[PAdV:T4
H8NI14]gRP@jJ7d4@6]n14I_P@=;LX<4D7N615IlRPAIOX`4FWn<15QmR@ABN8D3C7>014U^N`A<KGT4
CV]f155[M@AJLg/3HGZ216N0Q`A[PXP4K7n516UiOPAULgD4GVY]0e]TIPAGGf04DEQI14eBDPA:CDh4
AdU80dM6A0A7@d04ASlk14<k=PA1=S04?c8/13d^9`<e91d4;aTA134D2`@i7aL4@RXS14Xe;`=C@3X4
GD]616IFD@A_HEd4NFaX18=gM0B<PWlEoooo000Doooo19JAS`BFU9@4UINH19FJW@BCW:43TYnU18nP
Z0B<XJ/4R:6]18:Q[PAmXK03NIj^17BHZ@APQiT4BgN:13YXO@A0Jgh4AVn10d]bP`A@MhH4EWb:15Un
S0AJOh`4F7f9159hQ@=<Lh04BFik14a]N@A>JgH4DF]e15YcN`=QNX84Ih2716^2R0A/OhD4JGUn16Ec
M@ANJVd3FfAV15MOH0AAF5T4CE9B14Y=CPA7BDP3AdI414M3@0A6?c/4@c/f144f<0@o<R`4?BhW0cDT
7@@_6A44<A@;13TO5`A2:R<4BSD_0e=0>PAMBdH4IUIA16mQG@AiK6P4PgMd18b2OaGoool001Coool4
UY6?19JDU0BEUiP4UIZM19>LX@>BWjD4Sj2X18bQZ`B8XJd4PZ6^17fQ/0=iWZh4M9RY1627V@A;MhX4
>VQm141[OPA6Kh43Bg:3151gQPAFO8X4FGj<15YoS0AHOHT4DWR50dacP0A9KW/4C6ei14i[MPAAJgD4
FW=k0f5jPPAWP8L4Jh:816aoQ@AYNGh4IG=e15iZK@=KI6H4EemP155HF@A=DU84BTe>14M9B0=7AT@4
Ad=014Ho>`A3>cH4@CH`13lb;0@m;RL3=B@M12lI4@@a50/4>AlG148Z8`A:=Bl3Dd0j15e;APAVEU44
Kf5M17U/J0B3Mg@4S89o5Oooo`005?ooo`BFTI04UiFE19NHVPBFW9l4UYnS0iFRZ0BCY:`4SjF^18ZT
/0B3X[04O:6`0gRL[0AfVJP4HHNI14UeR@@fIGX4?6Um149]P0=7LH84CWJ615AkRPAKPHl4Gh:?16>4
T0AMOh`3DgR514ebO`A=LGd4DG1j15=^N0AJM7`3HGZ216N1R0A/PhT4KH6616]jO`AWMGP4GFU/0e]U
I`AFGf04CUMI14U@D@A7C4d4@dM70d=4@`A4@Cl4A3lk148j=P@n=S44?34/13P/9P<^8A/4:AL@12/B
2P@d7AH4?BPQ14Hc;@=@?ST4FDU416=ED0A]H5`4N6]X189gL`B<PWlEoooo000Doooo19JAT0BGUID4
UiRJ19JLW`BFWj<3UJ:X19>T[0B?YJh4RZB`18>R/0AlXK03N9b/17JIZ0AQQiT4BGF913IUNP@lJGd4
@Vf00dMaPPA>MXH4E7^:15^1S`AOPXl4HhB@15eoS0=CN8D4CG9o14eaO@AAL7X4Dfih15YdO0=QNX84
Ih6816b3R@A]PHH4JgYo16MeN0AMJF`3FfEW15IOH0A>EeT4BE1A14M<C@A3AdL3@dA314A1?`A4?c/4
@SXf13hf<@@l<B`4>2`V0bhQ6`@Y5a04:a8:13@M5P@m:244AS<]0e0n>@AIBD@4HeE@16ePG0AhJfP4
PWMc18b2OaGoool001Coool4UY6@19NEU@BGV9X4UYbO19JOX`>EXZP4TjB/18nU[PB:Y;04Pj:`17bQ
/0=hW:`4MYVX1667V@A9MHT4=VEj13aYO@A2KH03Ag6214ifQPADNhX4Fh6?15n2S`ASQ904GGn<0e=h
Q@A=LWl4CG5m155`NPACKWP4FWAl0f5jPPAWPHP4K8>916f1QPA[NWl4IgEh15eYK0=KIFL4EUmP14iG
F@A9D544Ada=14=7A`=3A4<4A44o14@o>`A2>SH4?SHa13`a;0@h;2H3;R4K12TG40@[4PX4=1dF13dX
8@A6<bd3D3hi15U9A0ASEE04KF1L17Q[J0B2Mg<4S89o5Oooo`005?ooo`BFTI04UiFE19NHVPBFW9l4
UYnS0iFRZ0BCY:`4SjF^18ZT/0B3X[04O:6`0gRL[0AfVJP4HHNI14UeR@@fIGX4?6Um149]P0=7LH84
CWJ615AkRPAKPHl4Gh:?16>4T0AMOh`3DgR514ebO`A=LGd4DG1j15=^N0AJM7`3HGZ216N1R0A/PhT4
KH6616]jO`AWMGP4GFU/0e]UI`AFGf04CUMI14U@D@A7C4d4@dM70d=4@`A4@Cl4A3lk148j=P@n=S44
?34/13P/9P<^8A/4:AL@12/B2P@d7AH4?BPQ14Hc;@=@?ST4FDU416=ED0A]H5`4N6]X189gL`B<PWlE
oooo000Doooo19NAT0BHUIH4V9ZK19VNX@BIXZH3V:F[19NX/0BDZ[<4SjVe18FU/`AcVJX3LYNX172D
Y0AOQYL4AW>8135RN0@hIg/4?f]n0dE`P@A;M8@4DGR815QoSPAMPY04IHJC16F5T@=OP8`4F7V415=e
P0ACLW`4EW5k15]eO@=QNh84J86816f4RPA_PhP4KWj216ejO@AUKg43HFY]15YSI@A>F5/4BE5C14E<
CP@oADH3@492144o?PA3?SX4@C/f13hg<P@k<Rd4=2/U0bLM60@O4Pd490l812hJ4`@g9Al4@C0[0d`l
=`AFAd<4HE=?16]OF`AfJVL4PGIc18^2OaGoool001Coool4Ui6@19REUPBHVY/4VIjQ19VRYP>HYJ/4
UjR`19BZ/`B?ZKD4QJFc17>IZP=bUjP4L9BT15n6U`A6LhP4<F9h13QWN`@oJgh3AG2114]dQ0AAN8P4
F7n>15f2T0AUQY<4IHFA0en0S0AHNH@4DgF015=bO0AFLG/4FgEm0f5kPPAXPHP4KHB:16n3R0A^OX84
KGYm16E_L@=QJVd4FV=U14iHF`A9DE<4ADa>13m5AP=0@T84@Cln14<n>PA1>cH4?SLb13/b;@@d:bD3
9adH11lB3@@T3`P4;QXC13LU7`A1<2/3C3`g15I7@`AQDdl4JemK17IZI`B1MW<4Rh9o5Oooo`005?oo
o`BGTI04V9FF19RJV`BIWZ44VJ:V0iRUZ`BGZ;04U:Zc18nY]@B5YK<4LiVZ0g:GZ0A`U:@4GhJG14Ic
R0@aHWP4>6Mk13m[OP=5L844BgB4155hR0AHOhh4GH:@16F6T`AUQI43Gh2<15QiQ0ACMH04Dg9l15Ia
N`AKMGd3HG^216R1R0A]Q8X4Kh>816inPPA]NWd4IFma0f5ZK@AJHfD4CUQK14UAD`A5C4h4?dE60d12
@PA1?ch4@chj144k=P@n=c84>c8]13@[9@<W7AP47a8=12@?20@^6Q<4=bDO144`:`=<?3L4ETM3165C
C`A[Ge/4MVYW185fL`B;PWlEoooo000Doooo19NAT0BHUIH4V9ZK19VNX@BIXZH3V:F[19NX/0BDZ[<4
SjVe18FU/`AcVJX3LYNX172DY0AOQYL4AW>8135RN0@hIg/4?f]n0dE`P@A;M8@4DGR815QoSPAMPY04
IHJC16F5T@=OP8`4F7V415=eP0ACLW`4EW5k15]eO@=QNh84J86816f4RPA_PhP4KWj216ejO@AUKg43
HFY]15YSI@A>F5/4BE5C14E<CP@oADH3@492144o?PA3?SX4@C/f13hg<P@k<Rd4=2/U0bLM60@O4Pd4
90l812hJ4`@g9Al4@C0[0d`l=`AFAd<4HE=?16]OF`AfJVL4PGIc18^2OaGoool001Coool4V9:A19VG
U`BJW9d4Vj2S19bUZ@>MZZl4WJje19ba^PBH/[h4Rj^i17FKZ`=ZTJ84IXfN15N1T`A3LHH4;f1g13IU
NP@lJWd3@fn114QaP`A=MHD4E7^:15Z1S`ANPi44Gh:@0eaoS@AINhP4EGJ215AdOPAGM7h4FgIo0f9l
Q0AXPHT4KHB;1724RPA`P8@4KW]n16adM@=/LW84Jfi^15QPH@ACEeP4CU9C14E9BP=4ATH4@d9114A0
?0A3?3P4?cPc13dc;P@a:B@38Q/G11P>2P@L2@@49aD@138Q70@l;BT3B3Te15=5@@ANDDh4JEiJ17EZ
IPB0MW<4Rh9o5Oooo`005?ooo`BHTY44VING19ZLW@BKX:<4W:FY0ifZ[`BM[[D4W;6j19Rb_PB;ZkT4
MI^[0fZAXPAVSIh4Eh6C14=aQP@_H7L4=VEj13aZO@=3Kh44B76314eeQ@ADNhX4FX6?15j3T@AOPY03
G7n=15UkR0AEMX84E7An15MdOPAKMWl3HWb416R1R@A]Q8/4L8B:1720Q0A^Ngh4K7Ae0fabLPA[KVh4
F61Q15=GF0A>DU<4ADU:0dA6APA3@T44A40l14<l>0@o>3<4?C<^134Y90<R6aL460h:11`910@W5A04
<R4L13`]:@=8>CD4DdE115iACPAYGUX4MFYV181fL`B;PWlEoooo000Doooo19RBT@BIUiL4VYbM19^P
X`BLYJT3WJZ_19f^]@BL/KX4V;:n18^[^@AeVj/3JY6R16J=WPAGPI<4@g6612mPM`@fIGX4?6Ym0d=_
P@A8LH<4CGF515AkRPAJPHl4GX>A15n2T0=LOhd4FG^815EfPPADM7h4EgAn15]fO`=RO8@4J86916f4
R`A`Q8X4L82416ikOPA/M7D3K79b16]^KPAHH644DeMH14iBD`A5BDX3A4I614=2@@A4@3`4@c`h13lh
<`@m<bh4<BTT0b8K5`@H3PX470T412LE40@b8A`4?2dY0dPi=@ACAD44GU5>16UNFPAeJVH4P7Ic18^2
OaGoool001Coool4V9:A19VGU`BJW9d4Vj2S19bUZ@>MZZl4WJje19ba^PBH/[h4Rj^i17FKZ`=ZTJ84
IXfN15N1T`A3LHH4;f1g13IUNP@lJWd3@fn114QaP`A=MHD4E7^:15Z1S`ANPi44Gh:@0eaoS@AINhP4
EGJ215AdOPAGM7h4FgIo0f9lQ0AXPHT4KHB;1724RPA`P8@4KW]n16adM@=/LW84Jfi^15QPH@ACEeP4
CU9C14E9BP=4ATH4@d9114A0?0A3?3P4?cPc13dc;P@a:B@38Q/G11P>2P@L2@@49aD@138Q70@l;BT3
B3Te15=5@@ANDDh4JEiJ17EZIPB0MW<4Rh9o5Oooo`005?ooo`BHTi84VYRH19bNW`BNXjH4X:V]0j:^
]0BT];/4YK[21:W2c0BF/kl4PjJd0g6GY`AVSIh4DgjA141_Q0@]GgH4<f=h13YXN`=2Kh44B7>514ae
Q@A@MhL4E7b:15MoS@AHOhh3EWb:15AiQ`ABMH84Dg=o15MeP0ALN843HWf516R2R@A]Q8/4L8B;1720
Q@A]Ngh4JgEg0facL`A`LW44IfUY15mQH0AIFEP4Ce1@0dY:BPA7AD<4AT8o14Dn>PA2>SH4?cHa12lX
90<O6QL450h:11H60@@P4@d4;1dJ13LZ9P=3=c<4Cd=015]@C0AWG5T4LfUV17meLPB:PGlEoooo000D
oooo19RCTPBJV9P4W9jO19jSYPBPZJd3XZjd1:Bd^`BU^/84ZL;<19Jc_`B3Y[@3LINW16J=WPACOY44
@6n412eOMP@cHgP4>VQk0d9_P@A8LhD4C7F5151gQ`ADO8X4Egn=15QoSP=FO8X4E7V7159ePPACLgl4
EgF015ahP@=ROHD4J8:916f4R`A`Q8/4L82516ekOPA[MGL3K7=c171bL@AWJFT4Gf5P15UIF0A?D503
BTY:14M5@`A6@Sl4AChj148j=P@o=S44;bPT0alJ5`@D3PX45PH1120A3@@/7AX4=bXV0d<g<`A?@d04
Fe1<16MLF@AcJFH4OgEb18Z1OaGoool001Coool4V9>B19ZHV0BLWYl4WZ>V1:2Y[@>R[[@4Y;Bk1:Fj
`PBY`/`4U[>o18>V]0=aUjL4IXfN15=nT@A0Kh@4;Emf13=SN0@jJ7/3@Vn114QcQ@A<MHD4D7N715Al
RPAGOhd4F7n>0eIlRPADNHL4DWF215=cO`AGMH04G7R10f9mQ@AXPXT4KHB;1724R`A`P8D4KG]n16]e
M`=/Lg<4L79a16MYJ@AOHF04FEUH14m@D0=:BTX4AdE314I2?`A5?SX4@SXf13lf<@@_:2@37aXG11@>
2P@F1P44814=12`M6P@g:RH3@cLc14m3@0AKD4`4IeaI17=YIPAoMG84RX5o5Oooo`005?ooo`BIU984
W9ZJ19jPX@BQYZP4Y:b`0jNc^0BZ^/04[/791;C;e0BP^lH4S:^h0gVMZ`AYSil4DgnB13i_Q0@/H7H4
<65f13QVNP<oK7h4Ag:414iiR@ACO8/4Egj=15V1S`AMPi43G86?15YoS0AGNhP4EgN315UhP`AMNh@3
HWj716R1RPA]Q8/4LHF;1762R0A]NWl4JG=g0fQaLPAWKFh4I6QX161SH`AJG5/4DUAC0de>C@A:B4H4
B4A214I0?@A4?3P4?cLb12`W90<J6AL4510=110300@I3@X49ATF138W90<o=344C44n15U>B`AUFeP4
LVQU17ieLPB:PGhEoooo000Doooo19VDTPBLVYX4WZ2Q1:6VZ0BT[;03Yk>h1:Zj`0B^`LT4]<_D1:2k
aPB<ZkP3NIf[16V?W`ACOi84?Vn412aPMP@`HGH4>6Ij0cm/OPA7LX@4CWV915=lR`AGOXd4FH6?15f3
T@=LPHl4FWn<15MkR0AGMh<4FGR315ekQ0=ROXL4J86:16f4R`AaQH/4LH:816ejO`AYLgL3J75b16M]
KPATJ6P4H6=S15YLF`ABE5<3CDi=14Y8APA8A484AT0m14@l>0@o=c84;2LT0aXI5`@D40d440<011T=
2P@U6AH4<RLT0cld<@A<@Ch4FDi;16EKF0AbJ6D4OWEb18Z1OQGoool001Coool4VIBB19bJVPBNX:44
XJJX1:B//0>W/kP4Z[[01:k1b@Bdbm@4X;_618b[^0=iWJ/4JHnO15=oTP@nKh@4;61f131QMP@hIWX3
?fan14MbQ0A>NHT4Dgb;15MnS@AIPHl4GH>A0eb1S`AJOh`4Eg^815MgP`AIN8<4GG^40f9nQ`AXPHX4
KHB;1765R`AaPXP4KGYo16UcM`=XLG84Ife^16AXJ0APHf<4FUaK159DD`==CTd4BTQ614Q4@PA6@3d4
A3`h13lg<P@/9b@36QTG11@@3@@@0`046@d:12DI5P@b9b@3?c@a14a1?PAICT/4IE]H179XI@AnMG84
RX5n5Oooo`005?ooo`BIU984W9ZJ19jPX@BQYZP4Y:b`0jNc^0BZ^/04[/791;C;e0BP^lH4S:^h0gVM
Z`AYSil4DgnB13i_Q0@/H7H4<65f13QVNP<oK7h4Ag:414iiR@ACO8/4Egj=15V1S`AMPi43G86?15Yo
S0AGNhP4EgN315UhP`AMNh@3HWj716R1RPA]Q8/4LHF;1762R0A]NWl4JG=g0fQaLPAWKFh4I6QX161S
H`AJG5/4DUAC0de>C@A:B4H4B4A214I0?@A4?3P4?cLb12`W90<J6AL4510=110300@I3@X49ATF138W
90<o=344C44n15U>B`AUFeP4LVQU17ieLPB:PGhEoooo000Doooo19ZDT`BMVi/4XJ:S1:BXZPBX[k<3
[;Nl1;2oa@Beall4_=7J1:_3c@BF/[h3PJ:`16bBXPAEP9<4?fn412ePM`@]GgD4=6=g0c]XN`A2KWl4
BWB5155kRPAGOhd4F86?15^3TP=LPi44G8:@15YoS0AINhL4FW^515emQ`=QOhP4Ih6916b3RPAaQH/4
MHJ;17B1Q@A]Mg`3IW1d161YK0AOIFL4GF5R15UKF`ACEED3Ce1>14a:B0A:AT@4BD9014Po>`@o=S84
:bLT0aHG5P@A3`d42`8010`40P@N5A<4;B@Q0c/b;`A9@3d4ETe:16AJF0A`IfD4OGAb18Z1OQGoool0
01Coool4VYBC19fKV`BQXZ<4Y:RZ1:R_/`>/]k`4/;o51;G7c`BldMX4Zl?=19Jb_P>1X[04K9:R15F0
T`@oKh@4;F1g12eOM@@dHgL3>fQk149^O`A:M8D4DG^:15MoS@AHPHl4Fh>B0eb3T@ALPY04FWn<15Uk
Q`AJNhD4GGf70f5oR0AWPHT4K8>:1765R`AeQX/4M86516egO0=VL7@4H6U/15mUI`AMHF84FE]K15=E
E@=?D4h4C4Y814Y6A0A9@T04B3lk13lf<P@[9b@35QLF114?3@@;0P0430@211hE4`@]9243>c8_14U0
?@AFCDX4I5YH171WI@AmM784RX5n5Oooo`005?ooo`BJU9<4WI^K1:6RX`BTZ:X4Z:nc0jbg_0B`_lD4
]LO?1;cAfPB[`ld4U[:n0h6R/0A/TZ84EH2C13m_Q0@]H7L4;Eme13ASM`<kJ7/4@Vio14YdQ@AANhX4
Egn=15R1S`AKPi83G8>A15b2T0AJOh`4FG^715YkQ@AMOHL3HGn816N1R@A/PhX4LHF;17F6R`AdPHD4
KGMl0fI`M0APJF`4GfEW15eQHPAIFe/4DeEE0dm@CPA<BTP4BTI414U2@0A8?c/4?cHb12/W90<F5aH4
4@l=10/200@<10847QDC12dT8@<k<Rl4BD0m15I=BPATFUP4L6MU17edLPB:PGhEoooo000Doooo19ZD
T`BMVi/4XJ:S1:BXZPBX[k<3[;Nl1;2oa@Beall4_=7J1:_3c@BF/[h3PJ:`16bBXPAEP9<4?fn412eP
M`@]GgD4=6=g0c]XN`A2KWl4BWB5155kRPAGOhd4F86?15^3TP=LPi44G8:@15YoS0AINhL4FW^515em
Q`=QOhP4Ih6916b3RPAaQH/4MHJ;17B1Q@A]Mg`3IW1d161YK0AOIFL4GF5R15UKF`ACEED3Ce1>14a:
B0A:AT@4BD9014Po>`@o=S84:bLT0aHG5P@A3`d42`8010`40P@N5A<4;B@Q0c/b;`A9@3d4ETe:16AJ
F0A`IfD4OGAb18Z1OQGoool001Coool4VYFC19jLW0BSY:D4Yj^]1:bb]P>`^[l4]/?91;c<d`C2e]h4
//WC19nia0>9YkD4LiNV15V3U@A2LHD4;f9i12aNL`@aH7@3>6Eg13iZN`A4Kh04BWB414mhR0ABNh/4
EGf=0eInS@AGOXd4Egf;15QlRPAJNhL4GGf80f5nR0AUP8P4JH6816j2R0AcQ8P4MhB717IoPP=cNG/4
J6mb15mVJ0AIH644EeYK15=FEP=@DE04CTa:14e9A`A=AT<4CD<o13hg<`@Z9bD35QTI10`>3P@:1@@4
1P4011PA40@X8Al3>30^14Hn?0ADC4X4HUYG16mWI0AlM744RH5n5Oooo`005?ooo`BJUI<4WYbL1:>T
Y@BWZjd4[;:f0k2j_`Bf`lT4_<cC1<;FgPBbbM<4WkW40hVW]@AcUjH4FH>E149aQ@@_HWT4;5ic135P
M0<hIGL4?VYk14A_P0A:M8@4CgR8159kR`AEOHd3EWj=15MnS@AGOH/4F7b:15YkQ`AMOHP3HGj816F0
R0AYPHP4KX:817>4R0AgQ8L4MWn20g=iN`AXKg84GfIX15UPH@AGFU/4DeIF0e1AD0A>C4X4CDU714e6
@`A=@cl4?SLc12XW9@<F6AT430h>10X510@60@04614@12PQ7`<h<2h4AShl15A<BPARFUL4KfMT17ad
L@B9PGhEoooo000Doooo19ZET`BNW9`4XjBU1:N[[@B//[H3/;Zo1;K3b@Blc=<4`]KN1;;9d`BO^L@3
RJNe17>GYPAIPiD4@W6512mRN@@/GW<4<F1d0cQUM`@nJW/4A6n014YdQ0A?N8P4DW^;15EmS@=FOXd4
Egj=15MmR`AHO8X4FW^715emR0=QOXP4IH2816V1R0A^PXP4LhB817N4Q`AfOh83LgUk16Q_LPAOIVP4
FF1Q15MJF`ACEUH3D55@14i<BPA=BDL4CDI314e3?`@n=c<4:RLU0aHI6@@<3Ph42PD410H100@H4A04
:24O0cP`;PA6?S`4E4a:169JE`A_If@4O7Aa18V1OQGoool001Coool4VYFC19jLW0BSY:D4Yj^]1:bb
]P>`^[l4]/?91;c<d`C2e]h4//WC19nia0>9YkD4LiNV15V3U@A2LHD4;f9i12aNL`@aH7@3>6Eg13iZ
N`A4Kh04BWB414mhR0ABNh/4EGf=0eInS@AGOXd4Egf;15QlRPAJNhL4GGf80f5nR0AUP8P4JH6816j2
R0AcQ8P4MhB717IoPP=cNG/4J6mb15mVJ0AIH644EeYK15=FEP=@DE04CTa:14e9A`A=AT<4CD<o13hg
<`@Z9bD35QTI10`>3P@:1@@41P4011PA40@X8Al3>30^14Hn?0ADC4X4HUYG16mWI0AlM744RH5n5Ooo
o`005?ooo`BKUI@4X9fM1:FUYPBZ[Jl4[kFh0kFn`PBjal`4`M3G1<SJh@BicMH4Yko90hn]^@AiVjX4
GhNI14MdR@@aI7/4:eec12iMLP<dHG@4>VEg141ZN`A5KWh4BG:214efQ@A@N8P3DWZ915=kRPAENhT4
EW^915QkR0AKO8L3Ggf7169nQ`AVOXH4JWj516ioQ0AbOh<4Lgj00gAkO@AaMWL4K6m`16EXJ0AOH604
FU]J0eMFE0ABD4h4DDa:1519APA?AT44?cPe12dZ:0<K7Ad43A0@10H61P@200044`l>12@O7P<e;Rd4
A3dl15=<BPAQFEL4KfMT17adL@B9PGhEoooo000Doooo19^EU0BPWId4YJFV1:Z][`B_]KP3]Kk21;[7
c0C1d=L4b=[Q1;W=ePBW_lT3Sjfi17VKZPAOQiT4AgB9135TN`@[GG<4;Ueb0cAQM0@jIGL4@6Yk14E^
OPA9LX84CGJ5151hR0=BNXT4Dg^:15EkR@AFNhT4F7^815]lQ`=OOHL4HWj716InQPAZOXD4KWn4179o
P`AcOX03M7]m175fM`A/Kg04IFQX15mPH0AJFeX3EeID159@CPAAC4X4D4U614m6@@@o>3D4;BXX0a/M
7@@=41041PH6108000@C3`h491lN0cD^;@A4?C`4Dda:165IE`A_If@4O7Aa18V1OQGoool001Coool4
ViFD1:2MW@BUYJH4ZZf_1:ne^0>e_/84^/O<1<7@e`C8f^44^LgF1:Nob@>?[KT4NI^Z15n7V@A7M8T4
<FAk12]ML`@^GG83=65d13YUM`A0JW/4AFin14UbPPA=MXD4D7R80e9jR@ACNhX4EG^915IkR@AHNhP4
Fgb70emmQ`AROXL4IWj616YnQ@A^Oh@4LWn317=nP0=dNgd4LGIg16a_L0AUJ6P4Gf1P15YKFP=GEU@4
DU1>155<BPA@BDH4CdI113lh=@@]:RP36adM10d@40@61PH40P0011<?3P@T7ah3=Bh]14@m?0ACC4X4
HEUG16mWI0AlM744RH5n5Oooo`005?ooo`BKUI@4X9fM1:FUYPBZ[Jl4[kFh0kFn`PBjal`4`M3G1<SJ
h@BicMH4Yko90hn]^@AiVjX4GhNI14MdR@@aI7/4:eec12iMLP<dHG@4>VEg141ZN`A5KWh4BG:214ef
Q@A@N8P3DWZ915=kRPAENhT4EW^915QkR0AKO8L3Ggf7169nQ`AVOXH4JWj516ioQ0AbOh<4Lgj00gAk
O@AaMWL4K6m`16EXJ0AOH604FU]J0eMFE0ABD4h4DDa:1519APA?AT44?cPe12dZ:0<K7Ad43A0@10H6
1P@200044`l>12@O7P<e;Rd4A3dl15=<BPAQFEL4KfMT17adL@B9PGhEoooo000Doooo19^FU0BQWYh4
YZJW1:b_/@Bb^;X3^<751;o:c`C5dmX4c=gT1;g@f0B/`l`3U[:n17jO[PAURi`4C7R<13IWO@@ZG7<4
:e]_0c1NL@@fHW@4?6Ig145ZNPA5KGd4B72014]cP`==MXD4CgR7155hQ`ACNHL4EWZ715UjQ`=LNhH4
Gg^4169kP`AUNh84JG^116akO`A^NGd3KgMj16idMPA/Kg04JF][16AUI0ANGed3FeUG15MDDPAED4d4
Dda814i6@P@o>CH4;b`Z0b4P7`@A4a<41@L8100000@>2``48AdM0c<^;@A3?C`4DT]:161IE`A^If@4
O7Aa18V1OQGoool001Coool4ViJD1:6NWPBVYZL4[:na1;:h^P>h`LD4_l[?1<GCfPC<gN@4_M3H1:c3
c0>F/[h4OYn^16F;W0A<N8`4=VMm12YLL`@[Ffl3<5ia13IRM0@lIWL4@FYj14E]O@A8L804Bg>30def
Q@A?N8L4DGR715=iQ`AFNXL4FGZ70eakQPAONh@4HW^316EkPPAYNh44K7]o16iiO@=_MgX4KWAf16a_
L0AYJf/4I6ET15iOG@=KFEL4EeAB15E@C@ACC4P4CTI213li=P@_;2X38B0O114C4`@51`P4000010h;
30@Q7Ad3<bh]14<m?0ABBdX4H5UG16iWI0AlM744RH5n5Oooo`005?ooo`BKUY@4XIjN1:JVY`B/[k44
/[Rj0kS1a@Bob/l4aM?J1<cMi0Bmd=P4[<?<0iJb_PAnWjh4IH^L14ahS0@fIgd4:Uac12]KK`<`GW44
=V9d13aVM`A1JWX4AFem14Q`P0A;Lh<3CGJ514mhQ`AAN8L4DgV715IjQ`AINXL3G7^615mkQ0ARNh<4
IG^216UkP@A/Ngl4KWUm0fmgNPA^M7H4K6m`16U[J`ATIF@4GUmM0e]IE`AGE584EE1=15=<B0A>AT84
?cTf12l/:P<Q81l44A<C10D720@000043P/<124M7@<c;Rd4@cdl159;BPAPFEL4KVMT17adL@B9PGhE
oooo000Doooo19bFU@BRWih4Z:RX1:ja/PBe^[`3_<?71<;=d@C:em`4dN7X1<7Cf`Baa]03W;O218FU
/`A[TJ44DWjA13]/P@@/GWD4:5Q^0beKK`@cGg44>69c13eVMPA1JWX4A6em14M_O`=:LX84C7B414ie
Q@A@MhH4DgN515EhQ@=HNH@4FgR215ihP@AQN7l4I7Mn16MgO@AYMWX3JW=g16YaL`AXKFl4IVUZ16=T
I0AOH5l3G5]I15UFE0AGDe04EDi;14a6@P@n>SL4<2h/0b8R8P@D5QH41`X<104310@<2P/481dM0c8^
;@A3?C`4DTa:161JF0A^IfD4O7Ab18V1OQGoool001Coool4W9JE1::OWPBXZ:P4[[6b1;Fj_0>l`lL4
`/gA1<[Gg0CAhNP4`M?K1;76d0>L]l84QJFc16^AX@ABOY44>fb112aNM@@XF6h3;E]_13=OL@@hHW<4
?FIf145ZNPA4KGd4Afmo0dYbPPA<M8@4CWF5151gQPACMhD4EGR50eQiQ0AKN884GWR1165hO`ATMgh4
IgMm16UfNP=ZLgL4JW5c16Q]K`AVJFX4HfAT15mPG`=LFeT4FEID15MCD0AECT/4C4I213hj=`@`;R`3
8R8R11@F5P@72P`40@<410`:2`@P7Ad3<Rh]14<m?0ABC4X4H5YH16iWI@AlM784RH5n5Oooo`005?oo
o`BLUYD4XYnN1:RXZ0B^/K84]KZl0kc3a`C2cM44b]OL1=7Qj0C1dm/4/LK@0ibg`PB5YK<4Ji6Q159n
T@@kK844;5ie12QHKP<]Ffl4<ema13QRL`@mIWH4@FYj14A]O@A7Kgl3BW:214adQ0A>MHD4D7N615=g
Q@AEN8D3F7V415]hPPANN844HGQo16AgOPAWMgd4JGIj0fYcM`AZLG<4J6e_16IYJPASI6@4Gf1O0eaK
F@AIEU@4Ee=@15E>B`A<AT84?SXg130^;0<R8R8451HF10L:30@10`@430X;120M7@<b;Rd4@cdl159<
BPAPFUP4KVMU17adLPB9PGhEoooo000Doooo19bFU@BRWih4Z:RX1:ja/PBe^[`3_<?71<;=d@C:em`4
dN7X1<7Cf`Baa]03W;O218FU/`A[TJ44DWjA13]/P@@/GWD4:5Q^0beKK`@cGg44>69c13eVMPA1JWX4
A6em14M_O`=:LX84C7B414ieQ@A@MhH4DgN515EhQ@=HNH@4FgR215ihP@AQN7l4I7Mn16MgO@AYMWX3
JW=g16YaL`AXKFl4IVUZ16=TI0AOH5l3G5]I15UFE0AGDe04EDi;14a6@P@n>SL4<2h/0b8R8P@D5QH4
1`X<104310@<2P/481dM0c8^;@A3?C`4DTa:161JF0A^IfD4O7Ab18V1OQGoool001Coool4WINE1:>P
W`BZZJT4/K:d1;Rl_P>oa/T4a/oD1<kJg`CFi>/4a]ON1;G:d`>R_<L4SJ^h17BHY`AKQ9L4@g:7139T
NP@XFFl3:eU]135LK`@eGg44>V9c13eVMPA1JGX4@fam0dI_P0A8LH44Bg>314edQ0A?MH@4DWJ30eAf
PPAGMH04FGAn15adO@AOM7/4HW=i16AbM`=UL7@4IFea16E[K@ASJ6T4HVAT161PH0=MG5X4G5QF15]E
DPAGCd`4CDI213lk>0@a;bd392@T11LI6@@;3a041@P910d=3P@R8203<c0_14<o?PABCD`4HEYI16iX
IPAlM784RH5o5Oooo`005?ooo`BMUiD4Xj2O1:ZYZ@Ba/[@4^;bn0ko6b@C6cm@4c][O1=KTj`C6emh4
]L[C0j:la`B=ZkP4M9RW15^4U`A3LXL4<VAj12QIK`<[FFd4<Ea_13EOL@@jHW<4?FIf145YNPA3K7d3
AVn014QaP@A;Lh<4CGB414meQ0ABMX<3E7J215MeP0AIM7h4G7Am15mdN`ARLgT4I79g0fE`M0AUKG44
IF]]16=XJ@ARI6@4H61P0eeLFPALF5H4FeEB15M?C0A=AT84?c/h134_;@<T92@45aTI10/?40@520T4
3@d>128P80<c<2l4@cln159=C0AQFUT4KVQV17adLPB9PGlEoooo000Doooo19fGU@BSX9l4ZZVY1;6b
]0Bh_;h3_lK91<K?e0C>f]l4e^C[1<KGgPBeb]<3X[c718f[^0AdV:L4FhBG14=bQ`@bI7X4:5U_0b]I
K@@aG6l4=Ema13YRL`@mIWH4@FUj14=/O@=6Kh04B76114]cP`A=M8@4CgF4159fP`=DMX84EgF015Ud
OPALM7d4GgAk169cN@ATLWL3IG1d16E]L@AUJfd4HfQY169TI0APH603GEaJ15aHEPAKEE84Edm<14e6
@P@o>cP4<Bl]0b@T90@G6AT42`l@10D82@@=3@h48R0P0c<`;`A3?ch4DTe<165JF@A^J6H4O7Ab18V1
OaGoool001Coool4WINE1:>PW`BZZJT4/K:d1;Rl_P>oa/T4a/oD1<kJg`CFi>/4a]ON1;G:d`>R_<L4
SJ^h17BHY`AKQ9L4@g:7139TNP@XFFl3:eU]135LK`@eGg44>V9c13eVMPA1JGX4@fam0dI_P0A8LH44
Bg>314edQ0A?MH@4DWJ30eAfPPAGMH04FGAn15adO@AOM7/4HW=i16AbM`=UL7@4IFea16E[K@ASJ6T4
HVAT161PH0=MG5X4G5QF15]EDPAGCd`4CDI213lk>0@a;bd392@T11LI6@@;3a041@P910d=3P@R8203
<c0_14<o?PABCD`4HEYI16iXIPAlM784RH5o5Oooo`005?ooo`BMUiD4Y:2P1:^ZZPBb];D4^[k00l;8
b`C9d]H4dMcQ1=WWk@C:f^44^LgF0jS0b`BD/;d4OIj]16::W0A;N8`4>FUn12aML`<[FFd4;e]]13=N
K`@gH744>V=c13eVMPA0JGX3@fam14E^O`A7L804BW:114acPPA?Lh43D7=o159bO@AELG/4F75j15Y`
N@AML7H4H6me0f5]LPAQJfl4HFU[165VJ0AQHf@4H61P0eiMG0AMFEL4FeIC15I?C0A;AD84@3/i13<`
;`<V9RD46Q/K10lB4`@:30d45QDF12HT90<f<c84AD5015A?C@ARG5X4KfQW17aeL`B9PGlEoooo000D
oooo19fGU@BTX:04ZjZZ1;:d]@Bj_/03`/S;1<WBePCAg>44fNO]1<[Jh@BicMH3Z<3;19B`_@AmWZd4
HXZL14]hS0@iJGh4;5ec0b]IK@@_Ffd4<ei_13MPL@@jHg<4?FIf141YNP=3K7d4AFio14M`P0A:LX44
C7>214mcP@=@Lgl4DW9m15EaN`AHLGX4FW1i15e`MPAPKgD3HFeb165[K`AQJF/4HFIX165SI0APH603
GUeL15eIE`AKEU<4ETm<14]5@PA0>cT4<c0_0bHV9@@J6a/43a8C10X<3@@F5AH49R@T0cHc<PA5@D04
E4m=169LFPA_J6L4O7Ec18V1OaGoool001Coool4WINE1:BPX0B[ZZX4/[Be1;Zn`0?2b</4bM;F1=7L
h@CIind4b][Q1;W=eP>X`</4U;2m17fN[@ARRY`4BgR<13UYOP@/GG<3:eU]12mKK@@cGVl4=f1a13YS
L`@mIWH4@6Uj0d=/O@A5KWl4Ag2014YbP@A<Lh84Cg>10e1cO`ABLWd4EG5k15QaNPAJL7T4GG1f161_
M@=QKG84HF]_165YJ`AQIVP4HF=T161PH0=NGE`4GEUG15]FD`AFCd`4BdE2140k>@@c<2l39RHU11XK
6`@?4Q<42P`=11HE5P@V92@3=S<b14E1@0ADCdd4HUaJ16mXI`AlMG<4RH5o5Oooo`005?ooo`BMUiD4
Y:2P1:^ZZPBb];D4^[k00l;8b`C9d]H4dMcQ1=WWk@C:f^44^LgF0jS0b`BD/;d4OIj]16::W0A;N8`4
>FUn12aML`<[FFd4;e]]13=NK`@gH744>V=c13eVMPA0JGX3@fam14E^O`A7L804BW:114acPPA?Lh43
D7=o159bO@AELG/4F75j15Y`N@AML7H4H6me0f5]LPAQJfl4HFU[165VJ0AQHf@4H61P0eiMG0AMFEL4
FeIC15I?C0A;AD84@3/i13<`;`<V9RD46Q/K10lB4`@:30d45QDF12HT90<f<c84AD5015A?C@ARG5X4
KfQW17aeL`B9PGlEoooo000Doooo19fGU@BUXJ04[:^[1;Be]PBl_l43a<[<1<gDf0CEgn<4gNW^1<kM
h`Bnd=P3[LC>19^f`PB4Y;84K96R15=oTP@nKX@4<F9h0baKK`@^FVh4<Ee_13EOL0@hHG84>f=d13eV
M`<oJGX4@Val14A]O@A6Kgl4B6mn14Y`OP==Kg`4CVmk151^N@ACKWL4EVef15U]M0AKK783GF]`15iY
K@AOIfX4GfEW15mSI0AOH603GUiM15iJF0ALEU<4E4i;14]5@`@o>cT4=38`0bLW9`@K7Ad44A@E10X;
3@@K6a/4:RTY0cTf=PA8A4<4EU5?16=MG0A`JVP4OGId18Z2OaGoool001Coool4WINE1:FQX0B/Zj/4
];Ff1;bo`@?4b/`4cMCH1=GOh`CMjNh4c]gS1;k@f0>]a<h4VkK218BT/PA/TJ84DgnB13i^Q0@aHWP3
;5]_12iJKP@aGFl4=Em`13QQLP@kHg@4?FIg0cmYNPA2K7`4A6em14I_O`A8Kgh4BW1n0de_O0A>Kg/4
D6ii15=^M`AFKGH4FFed15]/LP=MJg04GVU]15mWJPAOIFL4Gf=T15mPH0=NGUd4GUYH15aFD`ADCT/4
BdE313lk>@@d<S039bLW11/M7@@A51D42P/=11/K6`@Z:BT3>CHf14Q4@`AFDDl4HeeL171ZJ0AmMW@4
RX9o5Oooo`005?ooo`BMUiD4YJ6P1:b[Z`Bd]KH4_;o10lC:c0C=e=P4eMoS1=gYkPC>gN<4_]3H0jg4
cPBK]/84Q:Bb16bAXPACOi84?Vj4135RN0</Ffl4;UY^135MK`@eGg04>65b13]SM0@mIWL3?fUj149/
O0A4KGd4AVmo14Q_OPA:L7h3CFml14i_N`A@KWT4Dfig15I]MPAIKG@4Ffab0ee[L0ANJFd4GfMZ15mU
I`AOHf@4Gf1P0eiNG@ANFUP4G5IC15A>B`A;AD<4?c/i13@b<0<W9bL46adM114D5@@:2`d46a/K12XY
:@<i=SH4B4A315IAC`ASGE`4L6YX17efM0B:PWlEoooo000Doooo19fGU@BUXJ04[:^[1;Be]PBl_l43
a<[<1<gDf0CEgn<4gNW^1<kMh`Bnd=P3[LC>19^f`PB4Y;84K96R15=oTP@nKX@4<F9h0baKK`@^FVh4
<Ee_13EOL0@hHG84>f=d13eVM`<oJGX4@Val14A]O@A6Kgl4B6mn14Y`OP==Kg`4CVmk151^N@ACKWL4
EVef15U]M0AKK783GF]`15iYK@AOIfX4GfEW15mSI0AOH603GUiM15iJF0ALEU<4E4i;14]5@`@o>cT4
=38`0bLW9`@K7Ad44A@E10X;3@@K6a/4:RTY0cTf=PA8A4<4EU5?16=MG0A`JVP4OGId18Z2OaGoool0
01Coool4WYNF1:JQX0B^[:/4][Jf1;k0`P?7bld4d=OJ1=WRiPCRkO44dn3W1<CDf`>cb=44X[_618bZ
^0AeV:P4GHJH14IeR@@fJ7d3;Eeb12eJKP@`G6h4<ee`13IOL@@hHG84>V=d0caVM`@nJ7T4@6Yk149[
O0A3K7/4AVek0dQ/N@A9JgL4C6Yf14iZM0AAJW<4EFUb15MYL0=IJFh4FfM/15aUJ@AMI6H4GV9S15iP
H0=MGEd4G5UH15UDDPAACDX4B4A213dk>@@b<C439bLX11/M7P@B5QL43a0A120P80@_;Bd3?CXj14]7
APAHDe84IEmN175[J@AnMg@4RX:05Oooo`005?ooo`BNUiH4YZ6P1:j/Z`Bf][H4_/320lO;c@C@emX4
fN;V1>;]l@CCh>L4a=CK0k?8d@BR^lH4S:Zh17FHZ0AMQYP4AWF913IXO@<]GG84;EY^131LKP@cGG04
=Uma13QQLP@jHg@3?6Ig13iXN@A0JW/4@V]l14=/N`A6KG/3B6ai14U[M`A<JWH4CVYd155ZL`AEJG84
EfU`0eUYKPAKIf`4G6EY15eTIPANHV<4GV1P0eeMG@ALFEP4FEAB155=BPA8A484?C/i138a<@<W9bP4
6adN118F5`@?4144820P12l];@<m>SX4BdM615QCDPAUGeh4LF]Y17igM0B:PX0Eoooo000Doooo19jG
UPBVXJ04[Zb[1;Jf]PBn`<83al_=1=3GfPCIh^H4h^ga1=?Pi`C4e=/3/lSA1::kaPB<Z[P4MIRX15f6
V0A6MHT4=VQm0beMLP@]FVh4<5a^13=ML0@fGg44>65b13YSM0<lIWL4?VQi141ZN`A2Jg`4@fak14I]
N`=8K7T4BF]g14aZMPA>JW@4DFYc15EYLPAGJG03FFU^15]WK0ALIFT4GFAV15iRH`ANH603GEeM15aI
F0AIE584DDe:14Q4@P@m>cT4<S4a0bLW:0@K7Ah44QHG10l@4@@P8204;bd]0cdj>PA;AdH4F5=B16EO
GPAaJfT4OWMd18Z2P1Goool001Coool4WYRF1:JRX@B_[:`4]kNg1<31`P?9c<h4d]SK1=gTi`CWl?@4
fNG[1<WIg`>ic=D4Z<3:19B`_@AmWZd4IhfO151lT0@nKh@3<65g12eKL0@_G6l4<Ee`13ANL0@fH784
>69c0cUTM@@kIWL4?FQi13mYNPA0JGT4@FUh0d=XMPA4Ig@4AVIc14UVLPA<Ig44D6I_15=VKP=EIV`4
F6EZ15YTJ0AKHfH4GF5S15ePH0=LGE`4FUQG15ICD@A>BdX4AT=213dk>@@c<S43:2PX11dO7`@E5aP4
6a/L12LV9`@d<S83@Chn14i:B@AKEUD4If5P17=/J`AoN7D4RX>05Oooo`005?ooo`BNV9H4YZ:Q1:n/
[0Bg]kL4`<720lW<cPCBf=/4gNCW1>O`m0CIiN/4bMWO0kW<e@BX`<X4U;2m17fN[@AWSIl4D7b@13i_
Q0<`HGL4;E]`12mLK`@aGG04=5i`13IPLP@hHW<3>FAe13]VM`@mJ7T4?fUj141YN@A1JGP3@fQf14AW
M0A6IW<4BFIb14aWL@A@IVl4DfI^0eEVK0AHIFX4FVAX15]SIPAMHF<4GF1P0eaMG0AJF5L4EU=A14i;
BPA6@d84?C/i13<b<@<X:2P47AlO11DG60@K6a`49bHW13@b<P=1?Sh4CTY915]FE@AWHF04Lfa[17mh
M@B:Ph0Eoooo000Doooo19jHUPBVXZ44[jb/1;Ng]`C0`L83bLc>1=;Hf`CMi>L4io3d1=WUj`C9fMl3
^LcE1:S0bPBD/;d4OIj]16N=W`A@O904?Vn40c1QM`@]Fg04;ea_135ML0@dGW04=V1b13QRL`<iI7D4
>fIg13eXN@@oJGX4@6Ui145YN0=3J7H4A6Md14IVL`A9IW84C6Ma151VK`ACIVh3EFI/15QUJPAJI6P4
Ff=V15eQH`AMH603G5eL15YHE`AFDe44CT]:14I3@P@m>cT4<c8a0bPX:0@M7al45ALH11/K70@W9RL4
=38b0d4n?PA>BTT4FeIE16MQH0AcK6/4OgQe18Z3P1Goool001Coool4WYRF1:JRX@B_[:`4]kNg1<31
`P?9c<h4d]SK1=gTi`CWl?@4fNG[1<WIg`>ic=D4Z<3:19B`_@AmWZd4IhfO151lT0@nKh@3<65g12eK
L0@_G6l4<Ee`13ANL0@fH784>69c0cUTM@@kIWL4?FQi13mYNPA0JGT4@FUh0d=XMPA4Ig@4AVIc14UV
LPA<Ig44D6I_15=VKP=EIV`4F6EZ15YTJ0AKHfH4GF5S15ePH0=LGE`4FUQG15ICD@A>BdX4AT=213dk
>@@c<S43:2PX11dO7`@E5aP46a/L12LV9`@d<S83@Chn14i:B@AKEUD4If5P17=/J`AoN7D4RX>05Ooo
o`005?ooo`BNV9H4Yj:Q1:n/[0Bh]kL4`L;30l_=c`CEfM/4gnKX1>[cmPCPjo04d=kT0l3BfPBaa/l4
WKO218NV]0AaUJD4G8FG14QgR`<gJ7h4;eic12iLL0@`GG44<Ui`13AOLP@eH7<3=f9d13MSM@@iIGH4
>fMh13]VM`@lIGH3?FEd13mSL@A1HW04A6=_14MSKPA;Hfd4CV=/0e5SJPADHfT4Ef=W15URI@ALHF<4
GF1Q0eaLG0AHEeL4De5@14]:B@A3@T44?3/j138b<P<W:2T471lP11<E5P@Q8B84;B`/13Xh=`=6@d84
DTi=15iIE`AYHf84MFi/181iMPB;Ph4Eoooo000Doooo19jHUPBWXZ44[jb/1;Rg]`C1`/<3blg?1=GI
f`COi^P4j_?f1>3[l0C@g^@3`=;J1;76c`BM]l84QjJd176EY@ALQIL4B7N;0cMXOP@_GW<4;Ua`131M
L@@bGW04=5mb13EPL`<gHW@4=f=e13UUMP@kIgP4>fIg13aUMP<mIG@4?f=a145RL0A4Hfl4Af=^14]S
K@A>Hf`3DF=Z15ASJ@AGHfL4FF9U15aQH`AMH643G5aL15QGE`ACDE04BdY914=2@@@l>cX4<S8b0bLX
:@@L7b044aDF124Q8P@];2`4>SPg0dI3@PABCTd4GUUG16USHPAeKV`4P7Uf18^3PAGoool001Coool4
WYRF1:NRX@B_[:`4^;Ng1<72``?;cLl4eMWK1=oVj0CZloH4h>_`1=3Ni0?0d]X4/LK?19fg`PB7Y[@4
LIFU15b5U`A8Mh/3=fQn12mNL`@^G704<5ea139NL0@dGg84=F1c0cMRM0@gHgD4>FEf13]WN0@kIWL4
?6Ef0ceUM0@oHg44@F9`14ASK`A7Hfh4Bf=]14iSK0=AHfX4E6=Y15MSI`AIHVD4G65S15ePH@=LG5`4
F5MG15=AD0A;BTT4@d9113`k>P@b<S839bPY11`O80@C5AH48B4R12d/;0@j>3L3AT=2159>C@ANFEL4
JF=R17E^K0B0NGH4Rh>15Oooo`005?ooo`BNV9H4Yj:Q1:n/[0Bh]kL4`L;30l_=c`CEfM/4gnKX1>[c
mPCPjo04d=kT0l3BfPBaa/l4WKO218NV]0AaUJD4G8FG14QgR`<gJ7h4;eic12iLL0@`GG44<Ui`13AO
LP@eH7<3=f9d13MSM@@iIGH4>fMh13]VM`@lIGH3?FEd13mSL@A1HW04A6=_14MSKPA;Hfd4CV=/0e5S
JPADHfT4Ef=W15URI@ALHF<4GF1Q0eaLG0AHEeL4De5@14]:B@A3@T44?3/j138b<P<W:2T471lP11<E
5P@Q8B84;B`/13Xh=`=6@d84DTi=15iIE`AYHf84MFi/181iMPB;Ph4Eoooo000Doooo19jHUPBWXZ44
/:b/1;Vg]`C2`/83c<k?1=KJf`CQi^T4kOCg1>O_l`CHi>X3b=SO1;S<e@BW_/P4TZjj17fM[0AZSj04
Eh6C0d=bQP@eIGX4<5md131NLP@aGG44<Uib13=OLP<dH7<4=F5d13ERM0PgI7H4=f9c0cQQL@@iH6l4
?5m]13iOK0A2H6`4AV1[14YQJ@=>H6P4DF1W15AQIPAGHFD4FV1R15aPH0=JG5`4EeMF155AD0A:BTT4
@T9113Xj>P@a<S839bTZ11lR8P@I6QX49bLW13@b<P@o?C`3BdM615IBD0AQG5X4K6IT17I`KPB1NWP4
S8B15Oooo`005?ooo`BNV9H4Yj:Q1;2/[0Bi]kL4`/;20lc>c`CFf]/4hNKY1>gdm`CWko<4f>CZ0lSH
g`Bhc=D4Ykk819:^^PAmWJ`4JXnP15N1T`=3LXH4=FEj131OM0@`GW84<Eea139NLP@cGg83=61c13EQ
M0@eHW@8=fAf13MRL`<hHG44>F1_13aOK@@nGf`4@V1/14IPJ`A:HFT3CV1X155PI`ADHFH4Ef5U15YP
HPALH603FUaL15MGEPAADE04BTY91492@@@j>SX4<C8b0bLY:P@O8R846AXJ12LW9`@d<S84?cdl0d]7
APAFDU04HEaJ16aVI0AfL6h4PGYh18b4PAGoool001Coool4WYRF1:NRX@B`[:`4^KNg1<;2`P?<c/l4
e][K1>7Vj@C]m?L4inoc1=STjP?8f=l4^<cE1:Nnb0BB[[X4OIf/16Z?X0AGPI<3@g:613EUNP@`Gg@4
<5ib135ML@@bGW84<emb0cAPL`@eHG@4=F9d23MTMP@gHW<3>65a13UPK`@lGfd4?Um/149PK0A6H6/4
BV5Y0diPJ0AAH6L4E65V15MQI@AJH684G61P0eYLG0AGEeH4DE5@14Y:B@A2@T44>SXj134b<P<W:BX4
7b8R11TJ6P@W9bL4=38b13lm?0=;AdH4EU9@165LFPA/IV@4MW1^185jN0B<Q84Eoooo000Doooo19jH
UPBWXZ44/:b/1;Vg]`C2`/83c<k?1=KJf`CQi^T4kOCg1>O_l`CHi>X3b=SO1;S<e@BW_/P4TZjj17fM
[0AZSj04Eh6C0d=bQP@eIGX4<5md131NLP@aGG44<Uib13=OLP<dH7<4=F5d13ERM0PgI7H4=f9c0cQQ
L@@iH6l4?5m]13iOK0A2H6`4AV1[14YQJ@=>H6P4DF1W15AQIPAGHFD4FV1R15aPH0=JG5`4EeMF155A
D0A:BTT4@T9113Xj>P@a<S839bTZ11lR8P@I6QX49bLW13@b<P@o?C`3BdM615IBD0AQG5X4K6IT17I`
KPB1NWP4S8B15Oooo`005?ooo`BOV9H4Yj:P1;2/Z`Bi]kH4`/;20lc=cPCGfMX4h^KX1?3em`C_m_T4
hN[_0m7Oi@C1d]X4//K?19jf`@B9Y[<4MiVX16F;W0=DOY44@W2413QXO0@bHWL4<Emc139OL`@bGW87
<Emc139PL`@dHW@4<f9d135OL@<aGFh4<ea/13ILJ`@iG6X4?EaY149NJ@A6GVP3BUmW14iOIPACH6H4
EV5U15QOH`AKGV03FU]L15IFEPAAD504BTY914=3@P@k>c/4<S<c0bLZ:`@R92D49BDU130_;P@j>CP4
AD920e1<B`AJEU@4I5mM16iXI`AhLW04PW]i18b4PQGoool001Coool4WiRF1:NRX0B`[:/4^KNf1<;2
`P?<cLh4emWJ1>;Vj0C`mOL4koKi1>7Zk`?AgnD4`M;J1;;6c`BN]/44RJJc17NIZ0AURi`3E7jA149`
Q0@hJ7`4<V9g135OL`@bGg<4<Uib1c5OL`@bH7<4=69d13=RM0@aGg43<Ee^13=LK0@fG6/4>EaZ13eL
J@A2GVT4AUiX0dYOI`A>GfH4Df1V15IQI@AHGf<4FeiP0eYKG0AFEUH4DE1@14Y:B@A3@d84>c/k138c
<`<W:R/48R@U12DU9@@`;bh4>STh14E2@P=@C4/4FUID16AOG@A^J6L4N79`189kN@B<Q88Eoooo000D
oooo19nHUPBWXZ04/:b[1;Vg]PC2`/83c<g>1=OIfPCRi^P4l?Gg1>ofn@CQj^l3dMoU1<7BfPBba/l4
W[K118VV/`AgVJP4IH^L0eAnT@A2L8@4>6Ql139RM`@aGg<4<Umc139NLPLaGg<4<V1c13ARM0@cHW@4
<Ema0c5MKP@cG6`4=Ua[13ULJP@mG6T4@UiY14INJ0=:GfL4CUmV15=PIPAFHFD4F5mS15]NH0=JFe`4
EUIF155@D0A:BTT4@d=213/k>`@b<c<39bX[128T9@@U9BD4<2l^13Xi>0A5@T83D4a;15YFE0ATGed4
KVQW17QbL0B2NgT4S8B25Oooo`005?ooo`BOV9H4Yj:P1;2/Z`Bi]kH4`/;20lc=cPCGfMX4h^KX1?3e
m`C_m_T4hN[_0m7Oi@C1d]X4//K?19jf`@B9Y[<4MiVX16F;W0=DOY44@W2413QXO0@bHWL4<Emc139O
L`@bGW87<Emc139PL`@dHW@4<f9d135OL@<aGFh4<ea/13ILJ`@iG6X4?EaY149NJ@A6GVP3BUmW14iO
IPACH6H4EV5U15QOH`AKGV03FU]L15IFEPAAD504BTY914=3@P@k>c/4<S<c0bLZ:`@R92D49BDU130_
;P@j>CP4AD920e1<B`AJEU@4I5mM16iXI`AhLW04PW]i18b4PQGoool001Coool4WiRE1:NRX0B`[:/4
^KJf1<;1`@?<c<d4emSI1>;UiPC^l_@4mO_m1>[am0?JiNX4b]SO1;_=e@BY_lT4U:nk18FR[`AdUZD3
IX^L15EnT0A8M8L4?Vf113QVNP@fI7L4<f5e0c1OL`@`GW84<Emc239QM0@_GW43;E]^12iJJP@aFFT4
=5YY13UKJ0@mG6P4@EaV0dIMIPA<GVH4DEmV15EQI@AHH6<4FUiP0eQKF`AEEUH4DE5@14Y:BPA4A4@4
?3dm13@e=@<[;Bh48b@T12h^;@@h=SH4@Cln14]8A`=EDE04GUUH16QRH@AaJfT4NWAb18AlNPB=QH8E
oooo000Doooo19nHU@BWXZ04/:b[1;Vf]PC2`L43c<c=1=OHf@CRiNH4k_;d1?Gko@CZlO@3f^GZ1<[H
g`BkcMD4ZKo919B_^`B5XZl4M9JU0fJ;W0AEOY04B7B713i]P@@hIWX4=VAg13=QM@<`Gg<4<5ib135O
L`PbHG@4;eia0beKKP@^FVX4<EUY13AJJ@@iFfP4?EaX145LIP=6GFH4C5iV155OIPAEHFD4F61S15YN
H0=HFe/4EEIF155AD0A:BTX4A4A413`m?@@d=CD3:bd^12<T90@^;Rd4>3Hf144o?PA;B4L3EE5@15iI
F0AXHV44LF]Y17YdLPB4O7X4SHF25Oooo`005?ooo`BOV9D4Yj:P1;2/Z`Bi][H4`/710lc<c@CGf=T4
h^GV1>kbm0Cenod4j_7d0m[UjPC:f=l4^lgE1:Vob@BD[k/4QJ:_17BFY@=VRi`4EGj@14QdQ`@nKH44
>6Ij13ITM`@cHGD3<5mc131NLP@aGg<8<V5d12mNL@<]Ffh4;UYZ135IJ@@dFVT4>E]X13eLJ0A1G6H3
AUeV14aNIPAAGfH4EF5U15QPH`AJGV03F5]K15EFEPAADE04BTY:14A4A0@l?Cd4=3De0b/];P@S92@4
;Rh]13Pf=PA1?ch4BdQ70eEAD0ANFEP4J69Q175[J@AjM784Q7aj18f5PQGoool001Coool4WiRE1:NR
X0B`[:/4^KJf1<;1`@?<c<d4emSI1>;UiPC^l_@4mO_m1>[am0?JiNX4b]SO1;_=e@BY_lT4U:nk18FR
[`AdUZD3IX^L15EnT0A8M8L4?Vf113QVNP@fI7L4<f5e0c1OL`@`GW84<Emc239QM0@_GW43;E]^12iJ
JP@aFFT4=5YY13UKJ0@mG6P4@EaV0dIMIPA<GVH4DEmV15EQI@AHH6<4FUiP0eQKF`AEEUH4DE5@14Y:
BPA4A4@4?3dm13@e=@<[;Bh48b@T12h^;@@h=SH4@Cln14]8A`=EDE04GUUH16QRH@AaJfT4NWAb18Al
NPB=QH8Eoooo000Doooo19jGU@BWXIl4/:^Z1;Ve]0C2`;l3c<_;1=KFe`CQhn<4k>o`1?Slo@Ccn?/3
hnc_1=GPi@C6e=/4]LO?1:2h`PBAZkL4Pj2]0gFFY0AXRi/4Fh6B151jR`A9LhD4@fj013iZO@<iIWT4
=F=g13ERMP@fHgH4=69f139PL`<`GG04;U]/12mIJP@bFVT4=e]Y13]LJ0A0GFL3A5aV14YNIPA@H6H4
EF5U15MPH`AJGV03F5]L15IGE`ABDU84C4a;14I5A@@o?cl4>3Ph0c0a<@@];2`4=cHe140n?@A9ATD4
DDe<0eYEE0ARGE`4JfET17A]K0AlMG<4QGik18f6PaGoool001Coool4WYNE1:NQW`B`ZjX4^KFd1<;0
_`?<bl/4e]KG1>7Sh`C/ko04n?cm1??hn`?Sk>l4eN3U1<KDf`Beall4X;S2196[]`B3X:d3MIJT16R;
V`AKPI84D7Z;14UcQ@A3KX04?VYm0cUVN@@eHgL4=F9f13ISMP@dHWH4<V1c0c1ML0@^Ff`4;eUZ139J
J@@gFfT4>eaX141MI`=4G6H4BUiV151PIPAEHFD4Ef1S15YNH0=HFe`4EUMG159BDPA<C4/4ATE513lo
?`@h>3P3<34a12d/;0@g=SD4@3hm14U6A@AACD`3FUED169MG0A[IF@4M6e/17aeL`B5OW/4SHJ35Ooo
o`005?ooo`BNUiD4Yj6O1;2[ZPBi]K@4`/2o0lc;b`CFe]L4hN?S1>c_l0Cho?d4loSk0n?/k`CEh>D4
a]CK1;G7c`BP^<84TJ^g18>P[@=eUZ@4J8^K15^1TPA@NX/4BG>514=^P0@nJWd3>FIi13ESM`@eHWH4
=V=f13ARMP@bH7<3<5e`12iKK0@_FFX4<UYY13MKJ@@kG6P4@5eW0dALIPA:GVH4D61V15EQI@AGH6<4
FUiP0eQKG0AFEeL4DU9B14a<B`A6ADD4?clo13Ph>0<`<C44;B`/13Lf=@A0?Sd4BDI5155=C0=JEE@4
HUeL16]UI0AdKF`4O7Ec18EnN`B=QX<Eoooo000Doooo19jGU@BWXIl4[jZY1;Rd/`C1_[h3b/W91=CD
e0COh>04j^c/1?Oin@Cko_l3kO;e1=kVjPC?fn04`LoF1:o1bPBN]Kh4TJZe0h>P[0AfUJ<4JXbK1624
U0AJOXh4DgV914aeQP=6L844@Veo23iYN`@lIgT4>FEg0cIRM0@dGg04<ea]13ELK0@iGF/4?EeZ145N
J@=6GVP4BemX155QI`AFHVH4F61S15YOH@=IFed4EeQH15=CD`A>CDd4B4M614=2@@@n?3/3=SHe13/i
>0A1?ch4B4E4151<B`AGDe83GeYI16MQH0A^JFL4MW1^17igM@B6Og`4SXJ45Oooo`005?ooo`BNUiD4
Yj6O1:nZZ@Bh];<4`Kjn0l[9b@CDe=@4gn3P1>[/k0CgnOT4noko0ngbm@CNi^X4cm_P1<7?ePB_`LX4
W[Fn196Z]@>3X:`4MYFS16Z<V`APQ9@4FWj>15=iR@A<MHH3AW21149]O`PnJG/4?6Mi13UUM`<fHW@4
=5m`13=LK@@eG6`4>Ee[13eMJPA1GVT3AUiX14]OJ0AAHFL4EV9V15QPH`AJGf43FE]M15MHF0ACDe<4
CTe=14Q7APA3@T44?S`k0cHf=@@k>CP4@Cln14Q5A0A@C4/4Ee=B0emJF@AWHF04KVUW17I`KPAnMgD4
QWml18j6Q1Goool001Coool4WYNE1:NQW`B_ZZT4^;Bc1<6n_P?:bLT4e=CD1=oPh0CZk>`4moWi1?_n
o`?]l_D4g^KZ1<oKh0C1cmH4[l7:19je_PBAZ[D3Pj2/17JEX`AZS9/4H8BD15YnSPACNHT4C7F60dI`
P@A2KGl8?VUk13aWN@@iIGL3=V9d13AOL0@cG6d4=Ea/13UMJ`@mGFX4@EiY0dINJ0A;GfP4DF5W15IR
IPAHH6<4FUmQ0eUKG@AGF5P4De=C14i=C@A8AdH4@d9113hl>`<f=SD4>cTh144o?PA8AD@4D4a;15MC
DP=OFUT4If5P16iYI`AfL6h4OWMe18IoO0B>QX@Eoooo000Doooo19jGU@BWXIl4[jZY1;Rd/`C1_[h3
b/W91=CDe0COh>04j^c/1?Oin@Cko_l3kO;e1=kVjPC?fn04`LoF1:o1bPBN]Kh4TJZe0h>P[0AfUJ<4
JXbK1624U0AJOXh4DgV914aeQP=6L844@Veo23iYN`@lIgT4>FEg0cIRM0@dGg04<ea]13ELK0@iGF/4
?EeZ145NJ@=6GVP4BemX155QI`AFHVH4F61S15YOH@=IFed4EeQH15=CD`A>CDd4B4M614=2@@@n?3/3
=SHe13/i>0A1?ch4B4E4151<B`AGDe83GeYI16MQH0A^JFL4MW1^17igM@B6Og`4SXJ45Oooo`005?oo
o`BNUi@4YZ2N1:jYY`Bg/k44`;bk0lW7aPCBdM44gMcL1>OXj0Ccm?@4oOoo0oOjn`CWkO04fN7U1<[F
f`BjbM04[;k619fc_0>BZ[D4QJ2/17ZHY0AaTIh4JHZH16>4TPAMOhh3EWZ915=hQ`A<LX84BW2014M^
OPA5K7`3@VQh13mVMP@nI7<4@6=a149SL0A5HVh4B6=]0daSK0ABI6/4EFAZ15YTJ0AKHfD4G65R0e]M
GPAIFET4EEAD151?CPA:BDP4AdE414=0?P=2?ch4AD=114Y7APA@C4/4EU9A15eHE`=TGed4JfET179/
JPAiLg44P7Ug18R0OPB?Qh@Eoooo000Doooo19jGU0BVX9h4[ZVW1;Nc/@C0_;/3bLO61=;Ad@CMg=`4
inSX1??dm0Cmool3mo[k1>O]l0CIhND4b]KK1;[9d0B/_/H4WK>l0i:Z]@B5X:`4NYRT176AWPAYRYP4
HhBB15eoSP=FNXT4DgR714abPPA:L804Afin14E/O0=2J7P4?fIf13iTL`A0Hg44@V=`14ERKPA8Hfd3
C6=/159TJ`AEI6X4FVAX15]SI@ALHF83FeeN15UIF@AEE5@4D4m>14Y9B0A7AD@4@d0n0d8o?PA5@d44
BTM6151<B`AFDU44GEQG0fAOG@A[IF@4LVaZ17UcL@B0NGL4R81n18n7Q1Goool001Coool4WYND1:JP
WPB^ZJL4]k>a1<2l^`?9alH4d]7A1=gLg0CWj>P4loCd1?goo`?gn_/4ing`1=WQi@C:e]/4^/W@1:bn
aPBM/k`3TZZe18FP[0AjV:@4LI6N16V:V0ASQ984GGn>0eIjR@ACN8L4C7:214Y`P0A7KWh4AFal0d9X
N0@oIWH4?VAc141SL@A2Hg04AF9^14QSK@=<Hf`4DVA[15ETJPAJI6P4Ff=U15aQHP=KGEh4FEUI15ED
E0A@Cdh4BTU814M5A0A3@3h3@Sln14E3@@A:AdH4D4a;15IBD@AMF5L3I5mM16]UI0AbK6X4NG=a181i
M`B8P7h4ShN45Oooo`005?ooo`BNUi@4YZ2N1:jYY`Bg/k44`;bk0lW7aPCBdM44gMcL1>OXj0Ccm?@4
oOoo0oOjn`CWkO04fN7U1<[Ff`BjbM04[;k619fc_0>BZ[D4QJ2/17ZHY0AaTIh4JHZH16>4TPAMOhh3
EWZ915=hQ`A<LX84BW2014M^OPA5K7`3@VQh13mVMP@nI7<4@6=a149SL0A5HVh4B6=]0daSK0ABI6/4
EFAZ15YTJ0AKHfD4G65R0e]MGPAIFET4EEAD151?CPA:BDP4AdE414=0?P=2?ch4AD=114Y7APA@C4/4
EU9A15eHE`=TGed4JfET179/JPAiLg44P7Ug18R0OPB?Qh@Eoooo000Doooo19jFU0BUWid4[JRV1;Ja
[`Bn^[T3alC31=3>c@CJf=P4i>?S1>o_kPCjnoX3oOko1?3cm0CRj>X4e=gQ1<GAePBhald4[;g40j:e
_@BDZk@4R:6/186JY@AhTil4LHjI16^9U@=SPi04H82=15]kR@AHNHL4E7J4155cP@=?L7h4C6ek14Y[
N0A;JWL4CVYe151YM0ABJG83EFU`15YYK`ALJ6d4GVM[15mUI`APHf@3GUmP15aKF`AHEUD4De5?14i;
BPA;AdD4BTI40da8APA?BdT4Ddm=15QCDPAMF5L4HeiL0fUSHPA_JFL4MFm]17aeL`B2NgT4RH5o18n7
QAGoool001Coool4WYJD1:FOW@B]Z:H4][6_1;jj^@?7a<<4d<k=1=[Hf0CThn<4kno^1?[knP?mo_l4
l??d1>;XjPCDgN44aM7F1;S7c@B/_L@3X[Fm19B[]0B8XJ`4PIZU17RCW`AaSYT4JhVE0f>3T0APP8d4
Fg^915QiQ`ADMX@4DG>10dm`OPA<KG/4BV]h14]ZM`A>JWD4D6Ud159YLP=EJG04FVU_15aXK@ANIf/4
GfEW161SI0=NGf04G5]K15QFE@ACDDl4CT]:14]7A@A:AT@3C4Q614m;B@ACCdd4F5=B15eHE`ASGU`3
JF=R16mYI`AeKfd4O7Ec189kN@B9PGl4ShN55Oooo`005?ooo`BNUY@4YInM1:fXYPBf/Jl4_[Zi0lO4
``C@c/d4f]SH1>CSh`C_knh4n__j0ogno`C`lo@4h^SZ1=CMh@C5dMH4^<O=1:bma0>R]Kd4U:^d18RQ
[0B1VZD4N9>O176>V@A[RID3Hh>@1620S@AKNhT4F7V715AfQ0AALh43Cg1n14a]N`A:JgP4BfYg14iZ
M@A@JG@4DVUb0eEYL0AJJFl4G6Q]15iWJ`AOIFL4H6=T0eiOH0ALFe/4F5IE15=AC`A>BdX4BdM514Y6
A0=<B4H4Cd]915=?C@AHDe84GEQG16=NG0=YHf84KfUW17E_K@AlMG<4PW]i18V1O`B?QhDEoooo000D
oooo19jFU0BUWid4[JRV1;Ja[`Bn^[T3alC31=3>c@CJf=P4i>?S1>o_kPCjnoX3oOko1?3cm0CRj>X4
e=gQ1<GAePBhald4[;g40j:e_@BDZk@4R:6/186JY@AhTil4LHjI16^9U@=SPi04H82=15]kR@AHNHL4
E7J4155cP@=?L7h4C6ek14Y[N0A;JWL4CVYe151YM0ABJG83EFU`15YYK`ALJ6d4GVM[15mUI`APHf@3
GUmP15aKF`AHEUD4De5?14i;BPA;AdD4BTI40da8APA?BdT4Ddm=15QCDPAMF5L4HeiL0fUSHPA_JFL4
MFm]17aeL`B2NgT4RH5o18n7QAGoool001Coool4WIJC1:FNW0B/YZ@4]:n]1;bh]P?4`Kl4cL[91=KD
d`CPg]d4j^WX1?Kem0?oool4n?Wi1>_^k`COi>H4d]WL1<C>d`BhaL/3[kk41:Be_0BH[;@4T:F]18NM
YPB0V:44NY:L0g>=U`A^RI<4JHF@16F1S@AQOHX4GgZ70eahQ0AIMH04F7=n15UaO0AKLG/4GG5i15i`
N0=QL7H4I6md16E^L@ATJfh4I6QZ16AVIP=RHV84H5iM15]HE`AEDU04DDa:151;B@ABCD/3E51>15MB
D@AJEU@4GeYH16=NG0AXHf43KVQV17=]J`AiLW04OWMe18AmN`B:PX04T8R55Oooo`005?ooo`BMUY<4
YIjL1:bVY0Bd[jd4_;Rf0lC1_`C=b/T4e]CC1>3Ng@CZjNP4m_Gd0oooo`ChnOT4jnk_1=oTiPCBfM`4
a<kC1;S5b`>__/@4Y;Fl19R/]0B@YJd4QifV182HX@AjTY`3LhfG16j9T`AYQI04IH6=165mRPAONXL3
G7R415UeP0AHLgh4FG5l15]aN`AMLGT4GW1h0f5`MPATKg@4IFia16A[KPATJ6X4I6IV0f9RHPAPGUd4
FeQG15EBD0AAC4X4D4]9159=B`=DD4h4Ee9A15YFE0AOFUP4HeiL16QSH@=^J6H4Lfe[17UbL0AnMgD4
Q7ek18Z2P0B@R8DEoooo000Doooo19fFT`BUWY`4[:JT1;B_[@Bl^;H3a<6o1<g:b@CFe=<4h=kM1>[Y
j0CfmO@3oooo1?Sin@C[k^l4gnCV1=;Ig0C4c]<4^<G;0jnna0BT]K`4V:bd192U[@B7WJH4P9RQ17ZB
W0=cSIL4KXVC16V5T0AUPHd4HGf:15mjQ`=LN8@4FGF015QcOPAILG`4Fg5k15eaN@ANL7P3HG1f16A_
M0AUKW44I6]^16AXJPATIVH3HV9R161NG@AKF5L4EE9@155<BPA@BdT4DTe;0eA@CPAGDU44FUID15mJ
F0ASGU`4J6=Q0fiXIPAcKF/4NG9`17igM@B4OG/4RX:01928QAGoool001Coool4WIJC1:FNW0B/YZ@4
]:n]1;bh]P?4`Kl4cL[91=KDd`CPg]d4j^WX1?Kem0?oool4n?Wi1>_^k`COi>H4d]WL1<C>d`BhaL/3
[kk41:Be_0BH[;@4T:F]18NMYPB0V:44NY:L0g>=U`A^RI<4JHF@16F1S@AQOHX4GgZ70eahQ0AIMH04
F7=n15UaO0AKLG/4GG5i15i`N0=QL7H4I6md16E^L@ATJfh4I6QZ16AVIP=RHV84H5iM15]HE`AEDU04
DDa:151;B@ABCD/3E51>15MBD@AJEU@4GeYH16=NG0AXHf43KVQV17=]J`AiLW04OWMe18AmN`B:PX04
T8R55Oooo`005?ooo`BMUI<4Y9fK1:^UXPBb[:/4^KFc0l6m^`C9a/@4d/o=1=_He`CThn44knk/0ocj
n@Coo_d4m_Ge1>W[j`CLh>84d=KI1<G>d@>mal/4/ko51:Vg_0BQ/;H4UZN^18nQZ0B8W:<3PiNO17fB
VPAhSYH4MHZC1726T0A/PX`3JX2:16MlQPAVNh@4IWV116UiP@AYN7l4JgMn0figO0A_MWX4KgAf16ea
LPA/KFh4JfYZ0fQVI@ATHF04HEaJ15]FE0ADCT/4F59?15YDDP=LEeD4GUUG169LFPAUH5h4JF=R16eX
IP=bK6X4Mg1^17aeL`B1NWP4QWml18^4P@BARHHEoooo000Doooo19fET`BTWI/4ZjFR1;:/Z`Bi]K<3
`Kfk1<W6a0CBcld4fmSG1>CSh@C_k^`3o?[i1?ono@CfmOD4jN_[1=cPhPC@e]T4aLkA0kg7b`Bc_lD4
ZKNl1:6`]PBFYjh4Sj6X18RLX`>3Uil4OI:J17R>UPAeRY<4L8J@16b2S0=ZP8X4Igb616IkQ0AVNH44
JGV116UhO`A[Mgh3KWMl16mfNPA_M7H4KG5b16a]KPA[JVX3J6IU16AQH0AQG5X4FeID15A>B`AHDTl4
FUAB0eaGE@ANFEL4HUaJ16EPGPAYHf84KFQV0g9/JPAgL6h4O7Ec185jN0B6Og`4RhB11969QQGoool0
01Coool4WIFC1:BMV`B[YJ84/Zb[1;Ve/`?1_K/4bLK41=;?c@CKf=L4i>?Q1>o^k0?ln_T4ookm1?Ke
m@CYjn/4g>3R1=3Ff@C5c]43_LO;1;>oa@BY]k`4XK2f19JW[PB?XJP4R9bS0h>GW`AmTYX4N8jF17F:
T`A`QY04K8:<0fZ0RPAWO8H4IW^416IiP@AYNH44JGQo16]gOP=^Mg`4KgIj16mdMPA]LG84K6e^16]Z
JP=XIVD4I65P165LFPAKEU@4E4i;15QBC`AJE583G5ME15iIE`ARG5X4IF1N16USHPA]J6H3LVaZ17M`
KPAlMG<4PGYh18IoO0B;Q844THV65Oooo`005?ooo`BLUI84XibI1:VSX@B`ZZP4]k6_0kji]`C5`Kl4
cLW81=GBd0CNfmX4inGS0o7_k@ClnOL4o_cj1?Cbl@CWinL4f]gN1=3EeP?8c]04`LS;1;S0a0Ba^[d4
Yk:f19n[/0BHYJX3Tj2V18fLX@B8Uid4Pi>I17n?UPAjRi83MhN?17B4R`AbPHP4LGn617AoQ@AfP8D4
NH240gYoPPAjO7l4NGYk17MgM`AdLW44L6i]0fiZJ@AYIF<4HeiM15mIE`ANF5D4GeUG165KF@=SGE/4
IF1M16QRH0A[IF<4KfQV179/JP=fL6h4NgAb17mhMPB3O7X4R81n18f5PPBARHLEoooo000Doooo19bE
TPBSW9T4ZJ>Q1;2ZZ0Bg/Jl3_[Vg1<G1_`C=bLP4eM;@1=kKfPCWiN<3lNo]1?cim`Cno?X4m?;a1>OW
i`CJgMh4d=GF0lS>d0C1b</4^<341;6j_@BW/[H4Wj^`19RUZP>CX:H4SIbQ18RGW@B3TiT4OhnF17Z;
TP=gQhl4M8B;17:1R0AaOhH4M7n517J0Q@AiP8@3NWn217YlO`AiNW/4MgMg17AbL@A`KVd3KVYY16UU
H`ASGUd4GeUG15iHE@AOFEL4HE]I0f=MF`AUH5d4J69P16]UH`A_J6H4LVaZ0gI`KPAkM784OgQf18=l
NPB8P7h4SHF21969QaGoool001Coool4W9FB1:>LV@BYXj44/:ZX1;Na[`>n^KL4aL6o1<g9b0CEd]04
g]_J1>OUh`?aknd4o?Wg1?klnPCdl_44inOW1=[MgPC@eMH3b<k@1<78b`Bh`<@4/KZm1:Nb]PBOZk04
V:FZ0i>PYPB=W:44R9NM18>CV@AoSiH4NX^B0gN7S`AdQ8/4LX68175oQPAdOhD4MX2517V0Q0=jOh84
NWao17UjN`AgMgL4M79a171^K@=^JVT4JFES16=NG@AOFEL4GUQE15mIE`AQFeT3HeeK16EPG@AXHV04
JfES16mXIPAbK6X3MW1^17]dLPAoN7H4Pgaj18R0OPB=QH84THV75Oooo`005?ooo`BLUI84XibI1:VS
X@B`ZZP4]k6_0kji]`C5`Kl4cLW81=GBd0CNfmX4inGS0o7_k@ClnOL4o_cj1?Cbl@CWinL4f]gN1=3E
eP?8c]04`LS;1;S0a0Ba^[d4Yk:f19n[/0BHYJX3Tj2V18fLX@B8Uid4Pi>I17n?UPAjRi83MhN?17B4
R`AbPHP4LGn617AoQ@AfP8D4NH240gYoPPAjO7l4NGYk17MgM`AdLW44L6i]0fiZJ@AYIF<4HeiM15mI
E`ANF5D4GeUG165KF@=SGE/4IF1M16QRH0A[IF<4KfQV179/JP=fL6h4NgAb17mhMPB3O7X4R81n18f5
PPBARHLEoooo000Doooo19bDT@BRVYP4Yj6N1:fWY@Bd[Z`3^[Fc1<6l^PC8`l84cl_91=OCdPCOg=X3
j>CR1?3]j`Cjm_@4o?Sf1?7^k@CThn<4fM[J0m3Cd`C<c/l4aLS91;k2``Bg^kd4[KBf1:N^/@>PZ:`4
VjBW19JPX`BAVil4S9NK18RCV0>4Si@4PHbA17j8S@AlQHT4O8B717j3Q`B3QXP3QHJ718>2P`B2P804
Ogak17YfM@AeLFl3LVe[16mYI`AYHV08If1M16MQGPAXHV03JVAQ16aVH`A^J6H4LFYX17A]J`AgL6h3
NWAa17igM@B2NgP4QWil18Z2P0B>QX<4TXZ75Oooo`005?ooo`BLU944XYZH1:NQWPB]YjD4]:j/0kZe
/`C1_;X4b<?21<o;b@CGdm84gmcJ0nSThPC`kN/4n_Kd1?chmPCak^d4i>?S1=WJfP?@dm<4c<k?1<G8
b@Bn`/<4]k^m1:fd]PBW[[43X:R/19^TY`BFX:<4TI^O18bGV`B8TiP3Q8nD186<T@AnR8d4O8F917b4
Q`AnPhL4PhJ80hF6Q`B3PX<4PX2017mlN`AjMWD4MG5_0g9]J`A_JFL4JF9P26MPG@AWHEh4J69P0fYT
H@A/IV<4KVQV175ZJ0AdKF/4Mg1^0gYdL@AnMgD4PW]h18InO0B:PX04SXJ319::QaGoool001Coool4
W9BA1::JV0BWXIh4[JNU1;B^[0>j]K<4`Kbj1<S3`PC?blT4em?B1=oLfP?Xi>84l>g[1?[fm0Cln?H4
lNk]1>CSh`CIf]X3d=?C1<c>c`C5b<T4_/;31;Nk_@B]];H4Yjja0j2X[0BKY:L4UZ2S196KW`B<Ui/4
R9>H0hB?U0B1S944OXR=17b5R@AlQ8L4OX>718>6R0>5QXL4Ph:318:0P0AoO7/4NWIe17EaK`=bKF/4
KfUW16URH0QWH5d4If5N16QRH0=ZI644K6IS16iXIPAaJVP4M6e[17M`KP=jM744OWMe189kN0B6OW`4
RX:018j6P`BBRXLEoooo000Doooo19bDT@BRVYP4Yj6N1:fWY@Bd[Z`3^[Fc1<6l^PC8`l84cl_91=OC
dPCOg=X3j>CR1?3]j`Cjm_@4o?Sf1?7^k@CThn<4fM[J0m3Cd`C<c/l4aLS91;k2``Bg^kd4[KBf1:N^
/@>PZ:`4VjBW19JPX`BAVil4S9NK18RCV0>4Si@4PHbA17j8S@AlQHT4O8B717j3Q`B3QXP3QHJ718>2
P`B2P804Ogak17YfM@AeLFl3LVe[16mYI`AYHV08If1M16MQGPAXHV03JVAQ16aVH`A^J6H4LFYX17A]
J`AgL6h3NWAa17igM@B2NgP4QWil18Z2P0B>QX<4TXZ75Oooo`005?ooo`BKTi44X9VF1:JNW0B[Y:84
/:ZX0kJ`[PBl]kD4`[fk1<W4`PC@blT4em;@0mkJf0CVhMl4kNWW1?Kbk`Cgl_04kNWV1>;OgP?Ge]H4
d]7A1<g=c@C9b<P4`L;21;^k_0Bf]kL3[k6c1:Z/[@BTZ:T4Wj>U19VNX@BEVYd3T9JI18jCU`B:Si84
QXZ=18B9RPB5R8X4R8R90hN6Q`B6Q8@4QX:118AoO@AoNWP4NgEc0gI`K@AdKFT4KfMU26iWI0A^J6D4
KfQV0g1ZI`AbJfT4M6e[17I_K@AiLW04NgAb0gigM@B1NWP4QGek18R0OPB;Q844ShN419::R1Goool0
01Coool4Vi>A1:2IUPBVWY`4ZjBR1;2ZZ0>f/:h4_;Ne1<:m^`C9a<84d<_91=OBd0?Nf]P4i^7O1>gY
i`Cfl^l4mo;`1>gYiPCRgmh3emKF1=;Ad@C=cLd4bLS81<72`PBk^k`4][Ng0jna/`BZ[:d4Y:RY19nS
Y@BIWZ44UIZM0i2FV@B>TiL4RXnB18J:S@B4RHX4QHR:18R8R@>7QXL4QXB418J2P@B4Ogd4OgYh17]e
L`=fL6d4M6eY16mWI@Q^If@4KVQU16mXIP=`JVL4LV]Y17A]J`AfKfd4NG9`17]dLP=nMgD4PGYh18Em
N`B8P7h4RhB118n7Q0BBRXPEoooo000Doooo19^CT@BPVIH4YYjL1:^TXPB`ZZP3][2^1;bg]@C2_K/4
bLC21=3;b@CGd]03g][H1>KQg`C]jNL4m_;_1?Obl0C]jNH4h]oN0mOFePCBdM44cLg=1<W8b0C1`/84
^k^l1;Jg]`>_/K<4ZZb]1:BXZ@BOXjD4VIjQ19FJW@>@UYT4SY>G18Z?TPB6RXd4Q8V:18F8RPB8R8T3
QhJ718J4Q0B6PX44Q7mm17mjN0AkMG<3MW1]17A]J@A_IfD8KVMT16iXI@A_J6H3L6YW179[J@AdKF/4
MVm]17UbL0AkM783OWMe185jN0B5OG/4R81n18^4P@B?Qh@4TXZ85Oooo`005?ooo`BKTi44X9VF1:JN
W0B[Y:84/:ZX0kJ`[PBl]kD4`[fk1<W4`PC@blT4em;@0mkJf0CVhMl4kNWW1?Kbk`Cgl_04kNWV1>;O
gP?Ge]H4d]7A1<g=c@C9b<P4`L;21;^k_0Bf]kL3[k6c1:Z/[@BTZ:T4Wj>U19VNX@BEVYd3T9JI18jC
U`B:Si84QXZ=18B9RPB5R8X4R8R90hN6Q`B6Q8@4QX:118AoO@AoNWP4NgEc0gI`K@AdKFT4KfMU26iW
I0A^J6D4KfQV0g1ZI`AbJfT4M6e[17I_K@AiLW04NgAb0gigM@B1NWP4QGek18R0OPB;Q844ShN419::
R1Goool001Coool4VY:@19nGU@BTW9X4Z:6O1:fVY0>b[:X4]k6_1;bg]@C2_K/4b<?11<k9a`?Dcld4
fmKC1>7LfPCXhn44lNcY1?7[j0CXhn03gMWG1=KBd@CBc/d4clc:1<W6a@C1_kh4_KZj0kVg]PBf/k<4
/Jn_1:^ZZPBVYJH4XJ6R0ibMWPBIVY/4UIJG19>CU0B>SXl4T8j?19:>SP>AS8`4T8Z918j7Q@B;Q844
Qh1m181iM`=lM744NW9^17M_K0AfKV/8MFi[17I_K0=gL6d4N75^17UbL0AkM784OGId181hMP>2NgP4
QGek18N0O@B:PX04SHF31928Q@BCRhPEoooo000Doooo19ZBT0BOUiD4Y9bJ1:RQW`B]YZ@3/ZbZ1;Na
[`Bl]kD4`[fk1<S3`@C>bLL3e<o=1=_Fd`CQg=X4j>?Q1?7/j@CajnP4j>?P0mgIe`CFd]44d/k=1<o<
bPC9a/D4`Knn1;fj^P>i]kH4][>c1;6_[`B[ZZX4YZFV1:6QXP>LWIh4VIZK19FFU`BCTi@4SXj?192>
S`BBSXh3THb<192:R@B>QhD4RhB118N0O@B0NGL3O7Aa17YbKPAgKf`4MVi[27E^J`AfKf`3Mg1]17Qa
KPAiLW04NgAb17efM0B0N7H3PW]h18EmN`B7P7d4RX:018f5P`B@R8D4Th^85Oooo`005?ooo`BJTY04
WiNE1:BLVPBXXIl4[JJT0k:/ZPBg/Jl4_;Ne1<:m^`C8`l44c/W70mC?c@CKe]<4hMcJ1>SSh@Cak>T4
lN_X1>SSh0?MfML4e];A1=;>c@C?c<X4bLK51<6o_PBm^[X3^KNf1;Jc/`Ba[jl4ZjZZ1:JUYPBQXJ83
W9fN19VJV`BEUYL4Ti>D18j>S`B@SXl4TXj>0i6<S0B@RXT4SXN518^4P@B7P7d4P7Ug0gadL@AjLVh4
Mfm/17I^J`QeKV/4MVm/0gM`K@AhLFh4NG9`17]dLPAmMW@4P7Qf0h9kN0B5OG/4Qh1m18Z2P0B=QH<4
T8R519>;R1Goool001Coool4VY:@19nGU@BTW9X4Z:6O1:fVY0>b[:X4]k6_1;bg]@C2_K/4b<?11<k9
a`?Dcld4fmKC1>7LfPCXhn44lNcY1?7[j0CXhn03gMWG1=KBd@CBc/d4clc:1<W6a@C1_kh4_KZj0kVg
]PBf/k<4/Jn_1:^ZZPBVYJH4XJ6R0ibMWPBIVY/4UIJG19>CU0B>SXl4T8j?19:>SP>AS8`4T8Z918j7
Q@B;Q844Qh1m181iM`=lM744NW9^17M_K0AfKV/8MFi[17I_K0=gL6d4N75^17UbL0AkM784OGId181h
MP>2NgP4QGek18N0O@B:PX04SHF31928Q@BCRhPEoooo000Doooo19ZBS`BNUY<4XIZG1:FNW0BYXZ03
[ZNU1;:[Z@Bf/:h4^kFc1<2j^0C5_kd3b/G21=3:b0CEd<d4fmGC1>;Kf@CYhml4jn?O0nCMfPCIe=44
d/g:1<k9a`C<alD4b<?11<Bo_@?1^kT4_;Je1;Vd/PBf/Jl4/Zf[1:^WY@>UXZ84XYjN19fKV`BLV9P4
UY>C19NCTPBGTI03Uhn>19J=R`BCRXP4ShJ418f3P0B3NgP3PGUe17mgM0AmMW84O7Ab17adL@AkM744
O7Ab0gaeL`AmMW@4OgMe181iMPB2NWP4Q7aj0hInO0B8P7h4RX:018b4PPB?Qh@4THV619B;RAGoool0
01Coool4VY:?19jFT`BQVYL4YIjL1:VRX0>^YjD4/Z^Y1;J`[PBk]K<4`;Zh1<Fo_@?:aL84d<[81=G@
c@CKeM<4h]_I1>WSg`C[hml3i=gJ1=WDd@CBcLX4c/W71<c7a@C8`l44a;nm0l6k^@Bl][D4^KBb1;Ja
[`Bb[J/4ZjNU0jFRXPBRWYh4WI^K19bHV0BFTi<4Ui>B19NAT0>GShh4UXf;19>:R0B?QX@4SH>018=k
N0>1NGD4OgMd17efLPAlM784O7Aa17]dL@AlM783O7Ec17efM0AoMgD4P7Uf189jN0B4O7X3QWil18R0
OPB:PX04S8B218n7Q0BARHH4U8^95Oooo`005?ooo`BJTXl4WYJC1:6JU`BUWY`4ZJ:P0jjWY@BbZjT4
][2^1;^e/`C0^[P4aKnm0l[5`PC@b/P4eM3=1=_Ed`CRfmT4jN?O1>_Sg`?TgMX4fMCA1=;=bPC>bLL4
c<O51<S3`@C4_kd3`K^i1;bf]@Bi];84][6_1;:]Z`B[YjD3YJ:R1::NWPBMVi/4W9RH19JCT`BGTi84
Ui6@0iN?SPBFSH/4ThZ818n6Q0B=Ph04Pg]h0h5iM@AoMg@4OGIb17adLPAlM744NgAa17adLP=lMG<4
OGId17mgM@B0NGH4PWYh18AlNP>6OW`4R81n18Z2P0B<Q884ShN41969QPBDRhTEoooo000Doooo19ZB
S`BNUY<4XIZG1:FNW0BYXZ03[ZNU1;:[Z@Bf/:h4^kFc1<2j^0C5_kd3b/G21=3:b0CEd<d4fmGC1>;K
f@CYhml4jn?O0nCMfPCIe=44d/g:1<k9a`C<alD4b<?11<Bo_@?1^kT4_;Je1;Vd/PBf/Jl4/Zf[1:^W
Y@>UXZ84XYjN19fKV`BLV9P4UY>C19NCTPBGTI03Uhn>19J=R`BCRXP4ShJ418f3P0B3NgP3PGUe17mg
M0AmMW84O7Ab17adL@AkM744O7Ab0gaeL`AmMW@4OgMe181iMPB2NWP4Q7aj0hInO0B8P7h4RX:018b4
PPB?Qh@4THV619B;RAGoool001Coool4VI6>19bDT@BOUiD4XY^H1:JNW0>YXZ04[JJS1;2YY`Bd[J/4
^;6_1;be/`?0^[L4a;jl1<W2`0C>al@4dlc91=O@c@CLeM43h=SD1=kFdPCEcLT4clO31<W2`0C7`;d4
a;fj0l>k^0C0]k@4^kB`1;N`[@Be[Z/4/:VV0jbUX`BVX9h4XYfL19nJV@BMV9H4ViJD19^DTP>KTi04
VI2=19N>R`BBRHH4T8N418V0O@>6OW/4QGai18=kN0B2NWL<PGYg0h9jN0B3NgT4Q7aj18EmN`B6OW`4
Qh1m0hV1O`B;Ph04S8F218j6Q0B@R8D4TXZ719B<RAGoool001Coool4VI6>19bDT@BOUiD4XY^H1:JN
W0>YXZ04[JJS1;2YY`Bd[J/4^;6_1;be/`?0^[L4a;jl1<W2`0C>al@4dlc91=O@c@CLeM43h=SD1=kF
dPCEcLT4clO31<W2`0C7`;d4a;fj0l>k^0C0]k@4^kB`1;N`[@Be[Z/4/:VV0jbUX`BVX9h4XYfL19nJ
V@BMV9H4ViJD19^DTP>KTi04VI2=19N>R`BBRHH4T8N418V0O@>6OW/4QGai18=kN0B2NWL<PGYg0h9j
N0B3NgT4Q7aj18EmN`B6OW`4Qh1m0hV1O`B;Ph04S8F218j6Q0B@R8D4TXZ719B<RAGoool001Coool4
VI6>19bDT@BOUiD4XY^H1:JNW0>YXZ04[JJS1;2YY`Bd[J/4^;6_1;be/`?0^[L4a;jl1<W2`0C>al@4
dlc91=O@c@CLeM43h=SD1=kFdPCEcLT4clO31<W2`0C7`;d4a;fj0l>k^0C0]k@4^kB`1;N`[@Be[Z/4
/:VV0jbUX`BVX9h4XYfL19nJV@BMV9H4ViJD19^DTP>KTi04VI2=19N>R`BBRHH4T8N418V0O@>6OW/4
QGai18=kN0B2NWL<PGYg0h9jN0B3NgT4Q7aj18EmN`B6OW`4Qh1m0hV1O`B;Ph04S8F218j6Q0B@R8D4
TXZ719B<RAGoool001Coool4V92=19^BT0BMUI84WiRE1::JV0>TWIX4Yj2M1:ZSX0B]YJ<4[jRV1;:/
Z@>f[j`4^K:_1;be/`C0^KH4`kbi1<No_0C:`[l3c/G11=?:a@CAb<<4clG01<W0_0C2^[L4`KRe0l6g
]@Bn];44^k6^1;N^Z`Bd[:T4/JVV0jnVX`B[Xj04Z:2N1:BMVPBRViT4WiVG19fGU0>LUI84VI6>19^B
S`BHSh`4TXV518j5PP>;Ph04RX5n18R0O@B7Ogd<Qgml0hMoO@B8P7d4R85n18V1O`B:PX04Rh>10hb4
PPB>QX<4ShN41928QPBBRHL4Th^819F<RQGoool001Coool4V92=19^BT0BMUI84WiRE1::JV0>TWIX4
Yj2M1:ZSX0B]YJ<4[jRV1;:/Z@>f[j`4^K:_1;be/`C0^KH4`kbi1<No_0C:`[l3c/G11=?:a@CAb<<4
clG01<W0_0C2^[L4`KRe0l6g]@Bn];44^k6^1;N^Z`Bd[:T4/JVV0jnVX`B[Xj04Z:2N1:BMVPBRViT4
WiVG19fGU0>LUI84VI6>19^BS`BHSh`4TXV518j5PP>;Ph04RX5n18R0O@B7Ogd<Qgml0hMoO@B8P7d4
R85n18V1O`B:PX04Rh>10hb4PPB>QX<4ShN41928QPBBRHL4Th^819F<RQGoool001Coool4V92=19^B
T0BMUI84WiRE1::JV0>TWIX4Yj2M1:ZSX0B]YJ<4[jRV1;:/Z@>f[j`4^K:_1;be/`C0^KH4`kbi1<No
_0C:`[l3c/G11=?:a@CAb<<4clG01<W0_0C2^[L4`KRe0l6g]@Bn];44^k6^1;N^Z`Bd[:T4/JVV0jnV
X`B[Xj04Z:2N1:BMVPBRViT4WiVG19fGU0>LUI84VI6>19^BS`BHSh`4TXV518j5PP>;Ph04RX5n18R0
O@B7Ogd<Qgml0hMoO@B8P7d4R85n18V1O`B:PX04Rh>10hb4PPB>QX<4ShN41928QPBBRHL4Th^819F<
RQGoool001Coool4V92=19^BT0BMUI84WiRE1::JV0>TWIX4Yj2M1:ZSX0B]YJ<4[jRV1;:/Z@>f[j`4
^K:_1;be/`C0^KH4`kbi1<No_0C:`[l3c/G11=?:a@CAb<<4clG01<W0_0C2^[L4`KRe0l6g]@Bn];44
^k6^1;N^Z`Bd[:T4/JVV0jnVX`B[Xj04Z:2N1:BMVPBRViT4WiVG19fGU0>LUI84VI6>19^BS`BHSh`4
TXV518j5PP>;Ph04RX5n18R0O@B7Ogd<Qgml0hMoO@B8P7d4R85n18V1O`B:PX04Rh>10hb4PPB>QX<4
ShN41928QPBBRHL4Th^819F<RQGoool001Coool4V8n=19VASPBKTY04W9BB19jFT`>PV9D4XIZG1:>L
V@BUWY/4Yj2M1:VRW`>[Y:44[JJS1;2XY@BbZZP4]:fZ1;N_[0Bi/Jd3^k>_2;fd/0Bn];04_kJa1;^b
[PBh/:/3^;2/1;R_[0Bh[ZX4]J^X1:nWY0B/Y:83Zj:O1:RPW@BWWY`4Y9bI1:6JU`BOV9D4WIFB0j6I
U@BLU904VI2=19N>R`BDRhP4THV60hn7Q0B>QX<4SHF218f4PPb<Q843S8B228f5PPB>QH<4SXJ418n7
Q0>@R8D4T8R61969Q`BBRXL4Th^819B<R@BESHXEoooo000Doooo19R?S@BITHh4Vi:@19bDTPBNUY<3
X9RE1:6JU`BSW9T4YIjK1:NPW@BYXYl3ZjBQ1:fVX`B`Z:D4/ZZX1;B]ZPBg[j`4^K6]0k^c[`Rm];04
_[B`1;nf/@Bk/Zh4^;2[0kR`[0Bh[j`4^:jZ1;F[Z0B_Yj@4[:BR0j^RW`BXX9d4YijL1:BLV@BQVYL4
WiRE19fETP>QVID4W9B@19V@S@BGSX/4U8^81969QP>?Qh@4SXJ318f5PPB=Q88<S8B10hb4PPR=QH84
SXF318j6Q0B?Qh@3T8R51928QPBARHL4TXZ719>;R0BDS8T4UHf:5Oooo`005?ooo`BHShd4VI6>19^B
T0BLU984WYJC0j2HU@BQVYL4XibI1:FNV`BWX9d4ZJ:O0j^TX@B]YZ<4/:RU1;:ZZ0Bd[JX4]jn/1;Va
[@>k/jl8_KB`1;jd/0Bo][44^k:^1;R`Z`>h/:`4^:n/1;R^ZPBeZjP4[jNT1:bTXP>[XYl4Z:2M1:NN
W0BTW9T4XIZG19nHU@BMUI83XIVE19bDT0BIT8d4Uhj;19B;R0BARHH3ShN418j6P`B=QH84SHB238b4
P@><Q888SHF218j5P`B>QX@4ShN40i28Q@B@R8H4THV719::Q`BCRhP4U8b919F=RQGoool001Coool4
V8n=19VASPBKTY04W9BB19jFT`>PV9D4XIZG1:>LV@BUWY/4Yj2M1:VRW`>[Y:44[JJS1;2XY@BbZZP4
]:fZ1;N_[0Bi/Jd3^k>_2;fd/0Bn];04_kJa1;^b[PBh/:/3^;2/1;R_[0Bh[ZX4]J^X1:nWY0B/Y:83
Zj:O1:RPW@BWWY`4Y9bI1:6JU`BOV9D4WIFB0j6IU@BLU904VI2=19N>R`BDRhP4THV60hn7Q0B>QX<4
SHF218f4PPb<Q843S8B228f5PPB>QH<4SXJ418n7Q0>@R8D4T8R61969Q`BBRXL4Th^819B<R@BESHXE
oooo000Doooo19N>S0BHShd4V92=19VASPBJTXl3Vi>@19bDT@BMUI84WYJC19nGU0BPV9D3XIVF1::J
U`BSViP4Y9bI1:FMVPBVWY/4YinL0jRPW@BYXId<ZZ6M1:VPW0BXWi`3Z:2L1:ROW0BYX9`4Zj6M1:VP
W0BXWi`3YijK1:JMV@BUW9T4Y9^H1:>KV0BQV9D4Vi>@0iZBS`BITHh4V8n<19J>R`BES8X4U8^80i>:
R0BBRXL4TXV75i69QPBBRHL8TXZ719::R0NCRhP4U8^919B<R@BES8X4UHf:19J=RQGoool001Coool4
Uhj<19R?S@BHT8d4VI6>19ZBS`>KTi04W9BA19fETPBNUY<4WiND1:2HU@>QVIH4XYZG1:>KV0BTW9T4
YIfJ1:JNV`BWWi`3Z:2M1:VQW@bZXId4ZJ2L1:ROW0>XX9`4Z9nL1:VPW0B[XId4ZJ2L1:ROW0>WWY/4
YYfI1:FLV@BTViP4Xi^H1:6HU@BKTi03VY:?19VASPBHSh`4UXj;19F<RPBDRhP3ThZ819::Q`BBRHLG
THV619:9Q`RBRXL4TXZ81i>;R0BDRhT4U8b919F<RPBESHX4UXf:5Oooo`005?ooo`BGSX`4V8n=19R@
S@BITHh4VY:?0i^CT0BLU944WIFB19jFT`BOUi@4X9RE0j6IUPBRVYL4Xi^H1:BLV@BUWIX4YYjK1:NO
W0>XX9d4ZJ6M3:ZQW@BYX9`4Z9nL0jRPW0BXWi`4ZJ2L1:^QW@BYX9`4Z9nL0jNNV`BVWIT4YIbI1:BK
V0BSViP4XIRE19^CT0>JTXl4VI6>19R?S0BFSX/4UHb:19B;R0>CRXP4TXZ719:9QaNARHH4TXV729::
Q`BBRXP7Th^819B;R@BDS8T4UHb:19F=RPBFSHXEoooo000Doooo19N>S0BHShd4V92=19VASPBJTXl3
Vi>@19bDT@BMUI84WYJC19nGU0BPV9D3XIVF1::JU`BSViP4Y9bI1:FMVPBVWY/4YinL0jRPW@BYXId<
ZZ6M1:VPW0BXWi`3Z:2L1:ROW0BYX9`4Zj6M1:VPW0BXWi`3YijK1:JMV@BUW9T4Y9^H1:>KV0BQV9D4
Vi>@0iZBS`BITHh4V8n<19J>R`BES8X4U8^80i>:R0BBRXL4TXV75i69QPBBRHL8TXZ719::R0NCRhP4
U8^919B<R@BES8X4UHf:19J=RQGoool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool009Woool30000Q?ooo`00W?ooo`030000oooooooo087oool0
07_oool400000oooo`800003oooo100000?oool400000_ooo`<00003oooo0`0000?oool20000O_oo
o`00Noooo`030000oooooooo00?oool010000?ooooooo`0000;oool00`000?ooooooo`03oooo00@0
003oooooool00002oooo00<0003oooooool00oooo`040000oooooooo0000Poooo`00O?ooo`030000
oooooooo00;oool010000?ooooooo`0000?oool00`000?ooooooo`02oooo00@0003oooooool00002
oooo100000;oool010000?ooooooo`0008?oool007goool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00;oool300000oooo`800004oooo100008;oool007_oool0
10000?ooooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`0000Goool00`000?oo
ooooo`2=oooo001loooo0P0000Coool200001?ooo`800005oooo0P0008ooool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(225) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
908B8A908B8A908B8A908C8A908C8A908C8B908C8B908C8B908C8B908C8B908D8C908D8C
908D8C908D8C908D8C908D8D908D8D908E8D908E8D908E8E908E8E908F8F909090909293
8F8F8F8F8E8D8F8D8C908E8D908D8C908D8C908E8C908E8D918E8D918E8D918E8D918E8C
918E8C918C8B918C8A908A898F89878F88868F88868E87858E85838D84818C83808B817D
897D798B817E8C83818C85828D86838D87848D87848E87858E88868E88868E89878F8987
8F8A888F8A888F8A898F8B89
908B8A908C8A908C8A908C8B908D8B908D8B908D8C908D8C908E8D908E8D908E8D908E8E
908F8E908F8F908F8F9090909090909090909091919091929092928F92948F9496909698
8F93948F91918F9090909090908F8F91908F91909092908F91908F92908F93908F928F8E
928F8D928D8B928C8A9089878F88858E86838D84828D827F8C807D8A7D79887A76877771
84756F877A75897D798A7F7B8A807D8B827F8B83808C84818C85828D85838D86848E8785
8E88868E89878F8A888F8A89
908C8A908C8B908C8B908D8B908D8C908D8D908E8D908F8E908F8E908F8F90908F909090
9091919091919092929092939092939093949093959094958F95978F95988F979A8F999D
8E95988F94958F929390929290929291929292929393939292939293939294929194908F
938F8E938D8C928C8A9189868F86838E83808C817D8B7E7A897A7687777285736D826E67
826F6984736E867771877975887B77897D79897F7B8A807D8B817E8B83808C84818D8583
8D86848E88858E89878F8A88
908C8A908D8B908D8C908D8C908E8D908E8E908F8F909090919090919191919192919292
9193939193949194959194969195969095979096989097998F979A8F989C8F999E8F9BA0
8E989B8E96988F94968F9494909394919394929494949595939595949594959494949291
94908E938D8C938B899288859084818D807D8B7D7989797587757085716B826C657E665D
806A63826E6783716B84746F867772877974877B77887C79897E7B8A807D8B827F8C8380
8C85828D86848E88868F8A88
908C8B908D8C908E8D908E8D908F8E908F8F919090919191919292919293919394919495
91949691959791969891979991979A91989B90999C90999D8F9A9E8F9A9F8E9BA08E9DA3
8D9A9D8E989A8E96988F9596909596919596929595939696949696949696959595949392
94908F948E8C938B8892878590827F8D7E7A8B7A7688757085706A826B647F655D7C6057
7E655D7F6962816C66826F6983726D857570867772877975887B77897D7A8A7F7C8B817E
8C83818D85838E87858F8987
908C8B908D8C908E8D908F8E908F8F919090919191919292919394919495919596919697
91969891979991989A91999C919A9D919B9E919B9F909CA08F9CA18E9DA28D9DA28C9DA4
8C9A9F8D999C8E979A8F97988F9697909697919696929696939696949696949595949493
94918F948E8B938A879287838F817E8C7B778A767286726C836C6580665E7C5F567A5D53
7C61587D645C7F6860806B64816E6883716B84736E857671867874877B77887D798A807C
8B827F8C84818D86848E8987
908C8B908D8C908E8D908F8F919090919191919293919394919495919597929698929799
92989B92999C929A9D929B9F929CA0929DA1919EA2919FA4909FA58E9FA58C9EA58A9BA2
8B9A9F8C999D8D989B8E98998F9798909798919797929797929696939696939595949392
93908E938C8A9288869184818F7F7B8C797588736E856E688167607D605879594F79594F
7A5D537B60577D635B7E675F7F6A63816D6782706A83736E847570867874877B77897E7A
8A807D8B83808D86838E8886
908C8B908D8D908F8E91908F91919191929291939491949592969792979892989A92999B
929A9D929B9E929DA0929EA2929FA392A0A492A1A692A2A791A3A990A3AA879CA3879AA1
8A9A9F8B9A9E8D999C8E999A8F9899909899909798919797929797939696939494939291
938F8E928B8991868490827F8D7D798A777287716B836A637F635B7B5C5377544977564B
78594F795C537B5F567C625A7D665E7F6962806C6681706A83736D847671867975887C78
897F7C8B827F8C85828E8886
908C8B908E8D908F8F91909091919291939391949592969792979992989A929A9C939B9E
939C9F939DA1939FA393A0A493A1A693A3A893A4AA93A5AB93A7AD92A7AE8198A0869AA1
899B9F8B9B9F8C9A9D8D9A9C8E999A8F989A909899919898929898929696939394929090
928D8B9188879084828E807D8B7A7689746F856E688167607D5F5779584E745044755247
76544A77584E785B527A5E567B625A7D655E7E6962806C6681706A83736E857772867A76
887D7A8A817E8C84828E8886
908D8B908E8D91908F91919191929291949492959692979892989A939A9C939B9E939DA0
939EA293A0A493A1A693A2A794A4A994A5AB94A7AD94A8AF95ABB28CA3AB849BA3879CA2
899CA08B9CA08C9B9E8D9A9D8E9A9B8F999A90999A91999A929999929797939394928F8F
918A8A9086858F81808D7D7A89777487716C836B6580645D7C5D5477554B734D41734D41
74504575534876574D785A51795E557B625A7C655E7E6962806D6782716B837570857874
877C7889807D8B83818E8785
908D8C908F8E91909091929291939392959692969892989A939A9C939B9E939DA0949EA2
94A0A494A2A694A3A894A5AA94A6AC94A8AF94AAB195ACB38FA7AF88A1A9889FA6889EA4
8A9EA28B9DA18C9C9F8D9B9D8E9A9C8F9A9B909A9B919A9B929B9B929797939394928E8E
9189898F83838E7F7E8B7A78887571846E6A8168627E625A7B5B52765449734C4070483B
714B3F734E4374524775564C775A51785E557A625A7C665F7E6A64806E6982726D847772
877A76897F7B8B83808D8785
908D8C908F8E91919191929292949592959792979993999B939B9E939DA0949EA294A0A5
94A2A795A4A995A5AB95A7AD95A9B095AAB295ACB493ACB589A3AC89A2AA89A1A88AA0A5
8B9FA48C9FA38C9DA08D9C9D8D9B9C8E9B9B8F9B9B909B9B929C9C939999939595928F8F
918B8A8F83838D7E7D8A787686726F826C687E655F7B6058795A51755349734C416F4639
6F4538704A3D724E4273524774564C765A51785E567A635B7C67617E6C6681706B837570
867975887E7A8B827F8D8784
908D8C908F8F91919191939392959692969893989A939A9D939C9F949EA294A0A495A2A7
95A4A995A6AC95A8AE96AAB095ABB395ADB595AFB887A4AD88A3AC89A3AA89A2A98AA2A7
8CA2A68DA1A58D9FA18C9C9E8D9B9C8E9B9C8E9C9B8F9A9B929B9A939A9A929695929291
928F8E8F86858D7E7D897775846F6D806A667C635D795E56775850755349724C4170473A
6D42346E45386F493D704D4272514774564D765B52785F587A645D7D69637F6E6982736E
857874877D798A817E8D8684
908D8C918F8F91919291939492959792979993999C939B9E949EA194A0A495A2A695A4A9
96A6AC96A8AE96AAB196ACB396AEB696B0B992AEB885A2AC87A3AC88A3AB89A2A98BA3A9
8DA4A98EA4A78EA1A38C9C9D8D9B9C8E9B9C8A98988E9B9B919999939A9A949998949493
949290918A888E8381877876826E6C7D67657A615B775B5476574F745349724D4270473B
6C41346C40326D44376E483D6F4D4271524873574E765C5478615A7B67607E6C6681716C
847672877B788A817E8D8684
908D8C91908F91929292949592969893989A939A9D949DA0949FA395A1A695A4A996A6AB
96A8AE97ABB197ADB497AFB697B0B998B3BD87A6B184A2AD86A3AC89A4AC89A3A98CA5AB
8EA7AC90A7AA8FA3A58E9F9F8998998D9B9C8B98988E9A9A909A9A929999959B9B959594
969391958E8B928986887C7A7F6F6C7B6562775F5A75595374564E745349724E4370483C
6D43356B3E2F6A40336A44376C483D6E4E4470534A735950765E5779645D7C6A647F6F6A
837570867A7789807D8C8683
908E8D91909091939392959692979993999C939C9E949EA194A0A495A3A896A5AB96A8AE
97AAB198ADB499B0B799B1BA97B2BB96B3BD80A0AD83A2AC86A3AC88A5AC8AA4AB8CA6AC
8FA9AE91A8AC90A5A791A2A28795968A96978C97988E979790999A929999949998949391
95918F958D8A958B888F817D847571786662745D5872575173544C735249734F44704A3D
6E43366B3E2F693E30673F326743386A493F6D4F4671554D745B5477625B7B68617E6E68
82736F857976897F7C8C8583
908E8D91909091939392959693989A939A9D949DA0949FA395A2A695A4A996A7AD97A9B0
98ACB399B0B79BB3BB9DB6BF95B1BA8CABB680A0AC83A2AC86A4AD88A4AC8AA4AB8CA7AD
90AAAF91A7AB90A5A790A2A38A9B9C8B999A8D999A8E9898909A9A939999949998939391
94908E9289879289858F817C8A79757D6B67725B5771555071534B735349734F44714A3E
6E44376C3F30683C2D663D2E633D3267453A6A4B426E5249725951755F5879655F7D6C66
81726D847874887F7B8C8582
908E8D91919092939492969793999B939B9E949DA194A0A495A3A896A5AB96A8AF97ABB2
98AEB69AB2BA9DB7BFA2BCC694B1BB82A3AF82A2AE84A3AD86A4AD88A4AC89A4AC8CA7AD
8FA9AE8FA5AA8C9FA28C9EA08C9D9E8C9C9D8E9B9C8F9C9C919D9D939C9C949A99949795
93918F928B889088838E817C8A7974826F6A745E596F544F70534B73534A735045714B3F
6E45386C4032693C2D5F3628603A2E63403567483E6B4F466F564E745D5578635D7C6A64
80716C847773887E7B8C8582
908E8D919191929494939798939A9C949C9F949FA295A1A695A4A996A7AD96A9B097ACB4
98AFB89AB3BC9DB8C1A0BBC695B2BC86A5B084A4AE85A4AD86A4AC88A4AC89A4AC8BA7AD
8EA8AE8EA5AA8A9DA08A9C9E8B9B9D8C9C9D8E9B9C8F9C9D919D9D939C9C939A99949695
92928F918D898D87828B807B87797482706A79645E72585371544C73534A735146724C40
6F47396E42346D40305A31235C3529603D3264443A694C436D534B725A5376615B7A6863
7E6F6B837672877D7A8B8482
908E8D919191929495939799949A9D949DA095A0A495A3A895A5AB96A8AF96ABB296ADB6
97B0B998B3BD99B6C096B4BF91AFB98AA8B386A4AE85A3AD86A3AB87A4AC88A4AC8AA6AD
8DA7AD8DA5AA8A9EA2899A9C8A999B8B9B9C8D9B9D8F9C9D919D9E939D9D939A99939594
92918F908C888C8681887E798476717F6E687A655F755C5673574F73554C745247724D41
70483B6F44356F4131572F215832265D392E62413766493F6B5048705850745F59796761
7D6E69827571867D798B8481
918E8E91929292959693989A949B9E959EA295A1A695A4A996A7AD96A9B096ACB496AEB7
96B1BA95B3BD94B3BF92B0BB8EABB689A6B085A3AE84A1AB85A1AA86A2AA87A3AB89A4AC
8BA6AC8BA4AA8BA0A4899A9D89989A8B999B8D9B9D8F9B9C909C9D939D9D939A9A939695
91908E8F8B888A8480867D788275707E6E687A665F755E56745A5174574D745348724E42
71493C704537724333552D20542E2259362A5F3E3364463C694E456E564E735E5778655F
7C6D68817470867C798B8481
918F8E92929293969794999B959C9F959FA396A3A796A5AB96A8AF96ABB296ADB695AFB9
95B1BC94B3BF91B1BD8FAEBA8BA8B387A3AD83A1AB839FA9849FA885A0A986A2A987A3AA
89A4AB8AA3A98AA0A5889B9E8897998A999A8C9B9C8E9B9D909C9D939D9D939A9A939695
90908E8E8B8889837F847B7780736F7C6D67796660766058765C5475584F745449724F43
714A3D714638744535593123502A1D5632265C3A3062433A674C436C544C715C5576645E
7B6C6780746F857B788A8381
918F8E929393939697949A9C959DA096A1A596A4A997A7AD97AAB197ADB496AFB895B1BB
94B2BE92B3C090AFBB8DACB787A3AE83A0AA829FA9829DA7839EA7849FA785A0A886A1A8
87A2A988A1A889A0A5889B9F87979A89989A8B9A9B8E9A9C909C9D929D9D939A9A929594
8F8F8D8C898788827F837A757E726D7A6C6678666077625A765E5574595073554A714F44
6F4A3E6F4638714536633829542B1E512C2059382D6041376549416A524A705A5375625C
7A6B6580736F857B788A8381
918F8E929393949798959B9D969FA297A2A697A6AB98A9AF98ACB397AEB796B1BA95B3BD
93B4C091B3C08EAEBA89A6B3829EAA7F9DA8809CA6809CA5819CA5829DA6839EA7849FA7
859FA7869FA6879EA3869A9F86979B88989A8A999B8D999B909C9C929C9D939A99919493
8E8E8C8A878586807D8078747C706B796B6577666077635B765F56745A5172554A704F44
6D4A3E6B4437694134643A2B5B3022542E2159362B5E3F3564483F6950486E595274615B
7969647F726E847A778A8380
918F8F939494959899969C9E97A0A398A4A899A7AD99ABB199AEB598B1B997B3BD96B5C0
93B7C390B4C08BACB984A1AD7F9AA67C9AA57D9AA57E9BA47F9BA4819CA5829DA5829DA5
839DA5849CA3849BA185989D85969A87979A8A999B8C9A9B8F9C9D939C9D939999919393
8D8D8C888684847F7C7F77737B706B796B6577676077635C755F57735A5170554B6E4F44
6B493D674236643F325E3628572C1E56302359362A5D3D3362463D674E466D575072605A
7868637E716D847A768A8280
92908F94949595999A979DA098A2A59AA6AA9AA9AF9BADB49BB0B89AB3BC99B6C097B8C3
93B8C48FB3BF88A9B57F9CA97997A37997A27A98A27C99A37E9AA47F9BA4809CA4819CA4
819BA38299A181989E82959A82949885959888979A8B999B8F9C9D929C9D939999909392
8D8C8B888582827D7A7D76727A706B786B6577676176635C745F57715B516E554B6C4E44
68483D644135613D315B3426552B1D542C205733285B3B3160443B654C456B554E715E58
7767627D706C837976898280
92908F949595969A9B989FA19AA3A79BA8AC9CACB19DB0B69DB3BB9CB6BF9BB9C49ABCC8
95B8C48DAFBC81A3B07697A47493A07594A07896A17A97A27C99A37E9BA4809BA47F9BA3
809AA17F979F7F959C7F93988092968393978696988A989A8E9C9D929C9D939998909392
8C8B8A878381827C797D76727A706B776B6676676174635C735F57705A516D554B6A4E44
66473D6141355D3D31583125532C1E50271B54302558392F5E4139634A4369544D6F5D57
7566617C6F6B82787589827F
929090959696989B9C9AA0A39CA5A99EAAAE9FAEB4A0B2B9A0B6BE9FB9C39EBDC89EC0CD
9ABAC68CACB97C9EAC6D909F6E8F9D71919E7494A07896A17B99A37D9AA47F9BA37F9BA2
7E99A17D969D7C91997B8F957D8F9480909484939689979A8E9B9C929C9D939998909292
8C8B89868380827C797D76727A706B776B6675666172625B715E566E59506B544A684E44
64483D5F41365B3C325431254F2B1E4C2317502D2255362C5B3F3661484167524B6D5B56
7465607B6E6A82787589817F
939190969797999C9E9CA2A49EA8ABA1ADB1A2B1B7A3B6BCA3B9C1A2BDC6A2C0CBA1C3CF
9FBCC88DACB8799BA9658B9B688B9A6D8F9C71929E7695A17B99A37D9AA37F9BA47E9AA1
7C989F79949C778F97778C93798B907C8C908291948896998E9B9C929C9D939999909392
8D8B89868381827C797E777379706C766B6574666171615A6F5D566D58506A534A664E44
62483D5E42375A3D3250312549261A471F134C291F523329573D345E463F6450496B5A54
72635F796D6981777488817F
9391919798989B9E9F9EA4A6A1AAADA4B0B4A6B5BAA7BAC0A7BDC5A6C0C9A4C3CEA3C2CD
A0BDC88CAAB77497A65E8697638898698C9A6E8F9C7494A07B99A37F9CA5829EA6829CA4
7D98A076939B738D95748B9275888E77878C808E918795978E9B9D939D9E949A9A929493
8E8D8A888481847E7A8078747A716D766B667365606E605A6D5C556B585069534A654E44
60483D5D4238593E334E3126442319411C1047261C4E3027543A325B443D624E48695853
71625E786C6980777488817F
9492919899999D9FA1A1A6A8A4ADB0A8B3B7ABB9BEACBEC5ACC2CAAAC4CDA5C4CFA3C1CB
A2BCC68BA9B57094A45982945F8596658A986B8D9B71929E7898A2809DA6849FA789A1A8
839CA379949D738D95728C9374898F77878C7F8D908794978E9B9D949E9F969B9B949594
92908D888381867F7C827A757B726E746A6571645F6C5E596A5A5469574F68534A644D44
60483E5D4338573D32492E243E21173C190F43231A492D2550373057423B5F4C46675651
6F615D776B687F767387817E
9592919A999A9FA1A2A3A8AAA8B0B3ACB7BBB0BEC3B3C4CAB4C9D0B1CAD3A1BFCBA0BCC7
9DB7C289A7B36C92A2547E915A8293618796688C996E909C75949F7C9AA4819DA688A0A8
859EA57F98A0789098738C9374898F79898E7F8D918794978F9B9D959E9F989D9D979896
9694908E87848D8480887E797B736F756B66716560695D5868595367554E685249654E44
61493F5E4439553C31432B22361D1436160D3E2018442A234C352E533F395C4A44645550
6D5F5B756A677E757287807E
9593929B9B9BA1A3A4A6ABADACB3B6B1BCBFB7C4C8BCCCD1C1D4DAB9D0D8A4C0CB9AB6C2
95B1BC82A1AF688F9F507B8E5780915E8594668B996C8D9A71919C7896A07D9BA4819DA5
819BA47D979F79929A758C94768B917A8B90808E928895988F9B9E959E9F989E9E989997
969490938C8794898493867F8077727A6E697669646B5F5A695B5568564F69534A674F46
634B4161473B533A303F29212F1911301209371D153F272047312B4F3C3758484361534E
6A5E5A7469667D757286807E
9694939C9C9CA3A5A6A9AEAFB0B7B9B7C0C3BECACEC6D4D9D0E1E6BFD3DBAEC7D09DB8C3
92AEB97B9DAB648C9C4D798D547D8F5B82926489966B8D9A70909B74929D7996A07C99A2
7C98A17A949D779199758D94758A907B8C92819094889699909B9D969D9F999E9E999998
969391938D88938A84948780897D7782756F7B6D6771635D6D5E576C59516B564D6A5148
674D4364493E50392F3B28202B1911290E0631181139231D422E294B3A355545415E514D
685D597268657C7471867F7D
9794939E9D9DA5A7A7ACB0B1B4BABCBBC4C7C4CFD2CDDADED8E8ECC7D9DFB5CAD2A2BBC5
90ADB9789BAA60899A4C798C507B8C587F8F608592688B986F909C74939E79959F7A97A1
7C98A17B959F79939C788F97788C937C8F9482939789979A909B9D969D9E999E9E9B9B9A
979392928C899188838E837E897D778477717E6F6975676072615A705C546E584F6C544A
6C5045664A3F4E382F35251F2B1A13240B052A140E321F193C2B2646373251433F5B4F4B
665B587067647B7371857F7D
9795949F9E9EA7A8A9AFB2B3B7BCBEC0C7CAC9D3D6D3DFE3DEECF0CFDFE4BBCED6A6BEC8
91AEBA789BA95F88994C798C4D7889547C8B5C818E6386936B8B9771919B76939D77959E
7A96A07B959F7B959D7A929A7B90977E919784959989989B8F9A9C959C9D999E9D9D9D9C
9C9896968F8C9188858A817D867B768376717F706A79696376645C735F56715A5170574D
71544965493E4C372E31241E2A1A14210B051E0B072A19153627234134304D413D584D4A
645A576F66647A7370857F7D
989594A09F9FA9AAAAB1B4B5BABFC1C3CACCCDD6D9D8E2E5E3EFF3D4E3E8C1D2D9ABC1CB
94B0BC799CAA61899A4D7A8D4B7688517888587D8B5F818E6686926C8A95708E9873909B
76929C78939C79939D7B939C7D939B80939985969B89989B8E999B929A9B969B9A9B9B99
9E9A979C9491998E8A8F8581887D7883767180706A7B6B6478665E756057745D53755A50
75574C63483E4B362E3326212619141F0D081405022315113023203D312E493E3B554C49
6159566D6563797270847F7D
989695A1A0A0AAABABB3B6B7BDC1C2C7CCCED1D8DBDCE5E8E7F1F5D8E5EAC7D7DDAFC5CD
98B3BE7E9FAD658C9C4F7C8E4A75874E7585557A885C7D8A62828D6785906C8993708C96
738F9976909A78929C7A939B7D949B80959B84969B89989B8C989A909899949897979896
9A96949A94909A908B968A8590837D897B7585746D7F6E677D696079645A796056795D52
77594D63483F4C3830372823241915180B080E03001C110E2A201D382E2C463C3A534A48
6058556C6563787270847E7D
999695A2A1A0ACACACB5B7B8BFC3C4C9CED0D4DBDDDFE7EAEAF4F7DBE6EBCAD9DFB4C8D0
9CB6C083A2AF6A8F9F547F904974864B7383527685587A875F7E8A64828D6986906D8993
718C96748F9877919A79929B7D939B80959B84969B88979B8B96998E9697919695949593
97939197918E978D8995898492847E8E7E78897870847169816C637F685E7E63597C5F54
76584C62483F4C3831392924241A16140B09090100150C0A251D1B352C2A433B39514947
5E57556B6462777170837E7D
999695A3A2A1ADADADB7B8B9C1C4C5CCD0D2D6DCDEE2E9EBEDF6F9DDE8ECCDDBE1B8CCD3
A2BAC488A7B37094A35A83944B76884971814F74825678845C7B87627F8966838E6B8691
6F8993728D97758F9979919A7C939B7F949B83959B8696998995978B94958E9393919291
94918F948F8B948B8793878290837D8E7E778B797188746B846E65826A6081665C7F6156
73564B5E473E4B3831382924241A17110C0A0702010E0807211A19322B2A413A394F4947
5D56556A6462777170837E7D
9A9795A4A2A1AEAEADB8B9BAC3C5C6CED1D3D9DEE0E4EBEDF0F8FAE0EAEED0DDE3BDCFD6
A8BFC890ACB87799A7608898517A8C4871824D72815475825A7985607C8765808B69848F
6D8892718B95748E977790997B929A7E939A81949A8494988793968992948C91918E908F
908E8C928C8991898591858190827C8E7E778C79728A756D877067866C6285685D7F6156
70544A5C463D493730362924221A17100C0C0503030B07071F1A1A302B2A403A394E4947
5C5755696463767170837E7D
9A9795A4A2A2AFAEAEB9BABAC4C6C7CFD3D4DBDFE1E6ECEEF2F9FBE3ECEFD2DFE4C1D2D9
ADC3CC97B1BC7D9EAB678D9C577F904C74854D71805374815978845E7B86637E8968828C
6C8690708A94738D96768F977A91997D92998093998293978491948790918A8F8F8C8E8D
8E8C8A8F8A878F87848F84808F817B8E7D778D7A728B756D897268886D6385685D7C5F54
6C52485A443C46352F3327232019170E0C0C0302030E0C0C201C1C302C2B3F3B3A4E4948
5C5756696463767170837E7D
9A9796A5A3A2AFAEAEBABBBAC5C7C7D1D3D4DDE0E1E9EDEFF5FAFCE5EEF1D5E1E6C5D5DB
B4C7CF9EB6C085A4B16F93A25C83945179894F73825374815877835E7A86627D8867818B
6B858E6F8892728C95758E967990987B90977E9197819095828F92848E90878C8D898B8B
8B89888D88858D85828D827E8E7F7A8D7D768D7A728C766D8B7269896E6384675D775C52
684F4754413A42342E2F25221C17160B0B0B000001111010211F1F312E2E403C3C4E4A4A
5C5857696564767270837E7D
9A9796A5A3A2B0AFAEBBBBBAC6C7C7D2D4D4DEE1E2EBEFF0F8FCFDE8F0F2D9E3E7C9D7DD
B9CBD2A4BBC48EAAB57899A7648999577E8E5176855374825877835D7A85627D8866808A
6A848D6E8790718A93758C95778E967A8F957C90957E8E93808C90828B8E848A8B868989
8987868A86838B84818C817D8C7F798D7C758D79728C766D8A7269866C627F645A71584F
614C444F3E383D312C2B232117151408090A010203141314242223333031413E3E4F4C4B
5D59586A6665777271837F7D
9A9796A5A3A2B0AFAEBBBBBAC7C7C7D3D4D4DFE1E2ECEFF0FAFEFEECF2F5DDE6E9CEDADF
BECED5ACC0C996AFBA82A0AC6E909E608594557A895475845878845D7B86627D8866808A
6A838D6D868F718991748B94768D95788D947A8D937C8C907D8A8D7F888B818789838687
86858487838189827F8B7F7C8B7E798C7B758D78718C756D8971688369607960576A544C
5A48414A3B36382E2B26201F121212040608090A0B181819272626353434434141514E4D
5E5A5A6B6766777372837F7E
9A9795A5A2A1B0AEADBBBABAC7C7C6D3D4D3DFE1E1EDEFEFFBFEFEF1F6F8E2EAECD3DEE3
C5D3D9B3C5CD9FB5BF8BA6B17A98A66A8C9B5C808F5779875A79865E7B87627E8966808B
6A838D6D868F708890728A92758C94778C93788B9179898E7A878A7B85887D8486808485
82828284817F877F7D887E7A8A7C778B7A748C78718B756D876F667D665D725C54625049
52443E443834322B29201D1C0D0F100002040F10111D1D1E2B2A2B383737464444535050
5F5C5C6C6867787473847F7E
9A9795A5A2A1B0AEADBBBAB9C7C6C5D3D3D2DFE0E0ECEEEEFBFDFDF5F9F9E8EEF0D9E3E6
CBD7DDBBCBD1A8BCC495ADB785A1AC7695A26789975E7F8D5D7C895F7D89637E8A67818B
6A838D6D858E6F8790718891748B92768B9275888E76868B7684887882867981847C8182
7F8080817E7D847D7B867B78887B7689797389766F88736B826B6377625A6B58515C4C46
4C403C3D34312C2826191A1A0C0E100205071314162122232F2E2F3C3B3B494747555352
615E5E6D6A6979757484807F
9A9695A5A2A0AFADACBAB9B8C6C5C4D2D1D1DEDEDEEBECECFAFBFBFAFCFDEEF2F4E0E7EA
D1DCE0C4D1D6B2C3CA9FB4BD91A9B3839EA97693A069889664849063818D65808C69838D
6B838D6D858E6F868F71879074899175899072868C718389728186747F83767F82797D7F
7C7D7E7E7C7B817B79837A7786787487777285736D836F687C6760715E5764544E554844
463D3A37312F262424141719080D0F0B0E10191B1C262728333334403F3F4C4A4A585555
6360606E6B6A7A767585807F
9A9695A4A1A0AFACABB9B7B6C5C3C2D0CFCEDCDCDBE9E9E8F6F6F6FFFFFFF4F7F7E6EBED
D8E0E3CBD6DABBC9CFA8BAC29CB0B88EA5AF859EA879949F718D996C89956C86916E8690
6E868F6E868F6F858E71878F74899074888F71858C6E81876E7E83707C81727C80757B7D
787B7C7A79797D787780777582767383757081706B7D6A6574635D6A5A545D504B4F4541
403A38312E2D212223131619060B0D1316182021232C2D2E3838394443434F4E4E5A5858
656362706D6C7B7776858180
9A9694A4A09FAEABAAB8B6B5C3C1C0CECDCCD9D9D8E5E5E4F2F2F1FFFFFEFBFCFCECF0F1
DFE5E8D2DBDEC4CFD4B2C1C8A5B6BE9AAEB691A6AF889EA87F97A17A939D789099788D96
768C94738A9272889074888F76899074878F72858C6F81886D7E836D7B806F7A7E737A7C
75797A7778787976757C75737D74717E716D7A6C687667626D5F5A635652574C4949413F
3B36352C2B2C1F21221116190D11141B1E2027282A3233343E3D3E4847485351515D5B5B
686564726F6E7C7877868280
999594A39F9EADAAA8B7B4B3C1BFBECBCAC9D6D5D4E2E1E0EEEDECFBFAF8FFFFFFF3F4F5
E6E9EBD9DFE2CCD5D8BCC8CDAFBDC3A5B5BC9CAEB593A6AE8BA0A8879BA385989F82959C
7F929A7B8F967A8D94788A91798A9177898F74868D7182886F7F846D7B816F797E71797C
72777A74777775747477737278716F786E6B7468656E635F655B575C524F504947433E3D
35333328292B1E202213181A191C1F2426282F303139393A4343434D4C4C575555615E5E
6A67677470707D7978868281
999593A29E9DABA8A7B5B2B1BFBCBBC9C6C5D3D1D0DEDCDBE9E8E6F5F4F2FFFEFDFAF9F9
ECEEEEDFE3E5D3D9DBC5CED1BAC5C9AFBCC1A8B6BB9EAEB497A8AF93A3AA909FA58C9BA1
89989E84949A8493997F8E957E8D937C8B917A888E76848A738186717D82717B7F737A7D
73787A747677747474767271756F6D736B696E666368605D5F5755564F4D4A45443D3B3B
2F303127292A1D1F221C20222527292D2F303637384040414948495251515B5959646261
6D6A697672717E7B79878381
989493A19D9CAAA6A5B3B0AEBCB9B8C5C3C1CFCDCBD9D7D6E4E2E0EFEDEBFAF9F7FEFCFB
F2F1F1E5E7E8DADDDFCDD3D5C2CBCEB9C2C6B3BDC1A9B6BAA1AFB49EAAAF99A5AA95A1A5
919EA28B999E8B979C869398849195818D937E8A8F7B878C778387758084747D81757B7E
75797B747678737474757271726E6D6F6968696361635D5B5A5553504C4B444242383839
2D2F30242628222527282A2C2F31323637393E3F404646474F4E4E5756565F5D5D676564
6F6D6C777473807C7B888382
989392A09C9AA8A4A3B0ADACB9B6B5C2BFBECBC8C7D4D2D0DEDCDAE8E6E5F3F2F0FDFBFA
F6F4F3EBEBEBE0E2E2D5D8DACACFD1C1C8CBBCC3C6B4BDC0ACB6B9A8B1B4A1AAAD9DA7A9
99A2A5949EA2919B9E8D979B8A9497869094838C9180898D7B8589798286787F82787D80
777A7C767879757576757272716E6D6B67676561605E5B5A5553524B4A4A404041343637
292C2D27292B2D2F3032343538393A3F3F404646474D4D4D5453545C5A5A6361616B6868
726F6E7A7675817D7C888483
9793919F9B99A6A2A1AEAAA9B6B3B1BEBBB9C6C3C2CFCCCBD8D5D4E1DFDDEBE9E7F6F3F2
F9F6F5F1EFEEE6E6E5DCDCDDD2D4D5C9CDCEC4C9CABEC3C4B7BCBEB2B7B8A9B0B2A5ABAD
A0A7A99CA3A5979EA0949B9D90979A8C9396878F92848B8F80878A7D84877A80837C7F81
797B7E78797B787778767474716E6E6A68676361605C5A5952515248494A3F4041343638
2B2C2D3132343637393C3C3D4142424747484D4D4D5453535A5959615F5F6865656E6C6B
7572717C7877827E7D898583
9692919D9998A4A09FABA8A6B2AFADBAB7B5C1BEBDC9C6C4D1CECDDAD7D5E2DFDDEBE8E6
F4F0EEF6F2F0EDEAE8E2E1E0D7D8D7CFD1D1CACCCCC5C7C8BEC1C1BABCBCB3B5B6ACB0B1
A7ABACA3A7A89EA2A39A9E9F969A9C9196988C9194888E9084898C8085887D81847D7F81
7C7E807C7D7E7B797A777575726F6F6B696962616159595952525247494A3D3F41353739
3636383B3C3D4040414545464A4A4A4F4E4F5554545A5959605E5E6664636C6969726F6E
7874747E7A7984807F8A8584
9691909C9896A29E9DA8A5A3AFABAAB5B2B0BCB9B7C3C0BECAC7C5D2CECDD9D6D4E0DDDB
E8E4E2EFECEAF1EDEBE8E4E3DDDBDAD4D3D2CDCDCCCAC9C9C5C5C4C1C0BEBABAB9B3B3B3
AEAFAEA8A9AAA4A5A5A0A2A29B9D9E96999A9194968C9092888C8E8387897F82847D8081
7C7E807F7E7F7E7C7C7876767371716C6A6A62616258595A515252494B4C3F41423E3E3F
4242434545464A494A4E4D4E5251525756565C5A5A605F5F6663636B6868706D6D757271
7A7776807C7B8581808A8685
95918F9A9695A09C9AA6A2A0ABA7A6B1ADACB7B3B2BDBAB8C3C0BEC9C6C4D0CCCBD6D3D1
DDD9D7E3DFDDEAE6E4EAE6E4E2DDDBD9D5D3CFCECCCBC9C8C8C6C4C5C2C0BEBCBAB8B6B5
B3B2B1AEADACAAA8A7A5A5A4A0A0A09A9B9B9597989092938D8E90878A8B8284867F8183
7E7F81807F7F7C7B7C7776767371716C6A6B6262635A5A5B5152534B4C4D4747484A494A
4C4C4C504F4F5352525755565A59595E5D5D6261606765646B69686F6D6C747170787574
7D7A79827E7D8682818B8785
94908E9995939E9A98A39F9DA7A4A2ACA9A7B2AEACB7B3B1BCB8B7C1BEBCC7C3C1CCC8C6
D2CECCD7D3D1DDD9D6E3DFDDE3DEDBDBD6D4D1CDCBCBC8C6C7C4C2C5C1BFC0BCBAB9B6B4
B5B2B1B1AEADAEABA9AAA7A6A4A2A19E9E9D9A99999494959191928B8C8E89898A818385
8283838381827F7D7D7B78787573736D6C6C6665655B5C5D545555535352535253555454
5756565958585C5B5B5F5D5D6260606664636967676D6A6A706E6D7471717875747C7978
807C7B84807F8884828C8786
948F8D9793919B9796A09B9AA4A09EA8A4A2ACA8A6B0ACABB5B1AFB9B5B3BEBAB8C2BEBC
C7C3C1CBC7C5D0CCC9D4D0CEDAD5D2D9D4D1D4CFCCCBC7C4C5C1BEC1BDBABEBAB8B9B6B4
B5B2B0B3AFADAFAAA9ABA8A5A7A4A3A3A19F9E9B9A9896979492928F8F908D8C8C858687
858585838282807E7E7C79797674746F6E6E6B69695E5E5E5C5B5B5D5C5C5E5D5D5F5E5E
615F5F6361616563636865656A68676D6A6A706D6D73706F7673727976757C79787F7C7B
827F7E8682808985838C8886
938E8D9691909995939C9896A09B9AA39F9DA6A2A1AAA6A4ADA9A8B1ADABB4B0AFB8B4B2
BCB7B6BFBBB9C3BEBCC6C2BFCAC5C2CCC7C4CEC8C6CCC6C3C3BEBBBEB8B5B7B4B2B5B1B0
B3AEADB1ADABAEA9A7AAA6A4A7A3A2A5A19FA09C9A9B98989693939290918E8D8D8A898A
8787878584848280807E7B7B7977777270716E6C6C676565686666686666686666696767
6B68686C6A696E6B6B706D6D726F6E7471707673727975757B78777D7A79807C7B837F7E
8581808884828A86858D8987
928D8C94908E9792919995939C97969E9A98A19D9BA39F9DA6A2A0A9A4A3ABA7A5AEAAA8
B1ACAAB3AFADB6B1AFB8B4B2BBB6B3BDB8B5BEB9B6C1BCB8BDB7B5BAB4B1B5B1AEAFABAA
ADA9A7ADA8A7ABA6A4A8A4A2A6A19FA39F9D9F9B9A9D9998989595959292918E8E8D8C8C
8A89898785858482827E7C7C7E7B7B7A777775727173707072706F72706F73706F737070
7471717572727673737875747976757B78777D79787E7B7A807D7B827E7D84807F868281
8884828A86848C87868E8988
918D8B938E8C94908E9692909893929995939B97959D98979E9A99A09C9AA29E9CA49F9E
A6A19FA7A3A1A9A5A3ABA6A4ACA7A5ADA9A6AEAAA7AFAAA7AEA9A6ADA8A5AEA8A5A8A4A2
A6A29FA6A2A0A5A19FA6A19FA49F9D9F9B999C99989A9695979493969291928F8F8F8D8C
8D8A89878584898685848180827F7E817D7D7E7B7A7D7A797C79787C79787C79787D7979
7D7A797E7B7A7F7B7A807C7B817D7C827E7D837F7E84807F858180878381888482898584
8A86858C87868D89878E8A88
908C8A918D8B928D8C938E8D948F8E94908E95918F9692909793919894929994939A9594
9B96949B97959C98969D99979E99979E9A989F9A989F9A989F9A989E9A979E99979C9896
9B97959C97959B96959C98959D98969A969499959497939296929195919094908F928F8E
908C8B8A87868B87868A8685898584888483878382868381868281868281868281868281
8783818783828783828884828884838985838985848A86848A86858B87858C87868C8887
8D89878E89888E8A888F8A89
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?ooo`b@RhX8T8b:4i2<Ra>@SH`8T8f=1i2>S@R@SXh4T8n?192@
T0B@TY<4Shn?0hn>S@B?SH`4T8j=292=S0B@SX`3T8j=396>S@RASX`4THb;0i6<RPB@RXT4ShV728n8
QPB>QhD3SXF318f4P@B<Ph04Rh5m18UmN@B;PGh4S8>10hb5PPB=QX<8SHN418j7Q@N>R8H4SXV718n9
Q`R?RXP4ShZ918n;RAGoool001Coool<T8^:292<RQ>@S8/CT8f<292=S@N@SXd8T8j>192?S`B@T904
T9:C18n?S`>?SXd4Shf<192>S@R@SH`4T8j<0i2>S@bASXd8THj<196<R`>AS8X4T8Z918n9Q`R?R8H4
SXN50hj5P`B=Q844S8>018^1O@B9OGT4Rh5n18b3P@><QH84SHJ328f7Q0B>QhD7SXR618j9Q`B?RHL8
ShZ818n:R@B?RhTEoooo000Doooo392;RPR@S8XCT8b;4i2=S0R@SHd7T8j=292>SPB@Shl4T92@192B
T`B?Shl3Shj=18n=S0B@SXd8T8f<192>S0>@SXd<THj=296>S0BAS8/3THb:192:R@B?RHL8ShR618j7
Q@>>QH<4SHB118b3P0B;PGd4RGei18^1OPB<Ph43S8F218f6P`R=Qh@4SXN51hj8QPB>RHL4ShV728n:
R0B?RXT4Sh^95Oooo`005?ooo`B@RhX8T8b:192<R`N@SH/8T8f<392>S@>@SXh4T8n>292?S`b@T903
T96A192ATPB@TY84Si:D18nDUPB@UYP4Si>D0hnAT@B?T904T92@192?S`BAT8l4TI2@0i:@S`BAT8l4
TY2?19>@S`BBShh4TXn=19:=R`>BS8X4T8V718n8Q@B>QX<4SHB218f2O`><P7d4RWei18QjMPB7Mg44
Q7E_18MjM@B9OGT3RWmk18Z0O@B;PWl4Rh>018b4P@B<QH83SHF318f6Q0B>QhD4SXR618j9Q`B?RXP4
ShZ95Oooo`005?ooo`B@RhX8T8b:192<R`N@SH/8T8f<392>S@>@SXh4T8n>292?S`b@T903T96A192A
TPB@TY84Si:D18nDUPB@UYP4Si>D0hnAT@B?T904T92@192?S`BAT8l4TI2@0i:@S`BAT8l4TY2?19>@
S`BBShh4TXn=19:=R`>BS8X4T8V718n8Q@B>QX<4SHB218f2O`><P7d4RWei18QjMPB7Mg44Q7E_18Mj
M@B9OGT3RWmk18Z0O@B;PWl4Rh>018b4P@B<QH83SHF318f6Q0B>QhD4SXR618j9Q`B?RXP4ShZ95Ooo
o`005?ooo`B@RhX8T8b:192<R`N@SH/8T8f<392>S@>@SXh4T8n>292?S`b@T903T96A192ATPB@TY84
Si:D18nDUPB@UYP4Si>D0hnAT@B?T904T92@192?S`BAT8l4TI2@0i:@S`BAT8l4TY2?19>@S`BBShh4
TXn=19:=R`>BS8X4T8V718n8Q@B>QX<4SHB218f2O`><P7d4RWei18QjMPB7Mg44Q7E_18MjM@B9OGT3
RWmk18Z0O@B;PWl4Rh>018b4P@B<QH83SHF318f6Q0B>QhD4SXR618j9Q`B?RXP4ShZ95Oooo`005?oo
o`B@RhX8T8b:192<R`N@SH/8T8f<392>S@>@SXh4T8n>292?S`b@T903T96A192ATPB@TY84Si:D18nD
UPB@UYP4Si>D0hnAT@B?T904T92@192?S`BAT8l4TI2@0i:@S`BAT8l4TY2?19>@S`BBShh4TXn=19:=
R`>BS8X4T8V718n8Q@B>QX<4SHB218f2O`><P7d4RWei18QjMPB7Mg44Q7E_18MjM@B9OGT3RWmk18Z0
O@B;PWl4Rh>018b4P@B<QH83SHF318f6Q0B>QhD4SXR618j9Q`B?RXP4ShZ95Oooo`005?ooo`B@S8X8
T8b;192=R`B@SH`3T8f=192>S@R@Shh4T8n?192@S`>@T908T96A192BTPR@TY<4T9>D0i2CU@B@U9D4
SiFG18nEV0B?UiX4SiVM18jEV0>?U9D4Si:C292BTPBATY84TY:C0i>CTPBBTi84Ti>B19BBT@BDT8l4
Thn>19>=S0>BS8X4THV618n6P`B>Ph04S85m18]nNP>9NWH4QgMb18EcK@B2KVL4PVmY18AcKPB6Mg43
QgUe18QkM`B9OGT4RGmk18Z0O@B;PGh3Rh>018b4P@B=QH<4SHJ418j8Q@B>RHL4ShZ85Oooo`005?oo
o`B@S8X8T8b;192=R`B@SH`3T8f=192>S@R@Shh4T8n?192@S`>@T908T96A192BTPR@TY<4T9>D0i2C
U@B@U9D4SiFG18nEV0B?UiX4SiVM18jEV0>?U9D4Si:C292BTPBATY84TY:C0i>CTPBBTi84Ti>B19BB
T@BDT8l4Thn>19>=S0>BS8X4THV618n6P`B>Ph04S85m18]nNP>9NWH4QgMb18EcK@B2KVL4PVmY18Ac
KPB6Mg43QgUe18QkM`B9OGT4RGmk18Z0O@B;PGh3Rh>018b4P@B=QH<4SHJ418j8Q@B>RHL4ShZ85Ooo
o`005?ooo`B@S8X8T8b;192=R`B@SH`3T8f=192>S@R@Shh4T8n?192@S`>@T908T96A192BTPR@TY<4
T9>D0i2CU@B@U9D4SiFG18nEV0B?UiX4SiVM18jEV0>?U9D4Si:C292BTPBATY84TY:C0i>CTPBBTi84
Ti>B19BBT@BDT8l4Thn>19>=S0>BS8X4THV618n6P`B>Ph04S85m18]nNP>9NWH4QgMb18EcK@B2KVL4
PVmY18AcKPB6Mg43QgUe18QkM`B9OGT4RGmk18Z0O@B;PGh3Rh>018b4P@B=QH<4SHJ418j8Q@B>RHL4
ShZ85Oooo`005?ooo`B@S8X8T8b;192=R`B@SH`3T8f=192>S@R@Shh4T8n?192@S`>@T908T96A192B
TPR@TY<4T9>D0i2CU@B@U9D4SiFG18nEV0B?UiX4SiVM18jEV0>?U9D4Si:C292BTPBATY84TY:C0i>C
TPBBTi84Ti>B19BBT@BDT8l4Thn>19>=S0>BS8X4THV618n6P`B>Ph04S85m18]nNP>9NWH4QgMb18Ec
K@B2KVL4PVmY18AcKPB6Mg43QgUe18QkM`B9OGT4RGmk18Z0O@B;PGh3Rh>018b4P@B=QH<4SHJ418j8
Q@B>RHL4ShZ85Oooo`005?ooo`B@S8X4T8f;292=S0B@SXd3T8j>192?S`B@T904TI2@196AT@BATI83
TI:B196CT`BATi@4TIBE196DUPBAUIH4T9FG0i2FV0B@UiT4SiNJ18nHW0B?VIh4Si^P18jHV`>>UYP4
SiBF18nDU0B@Ti@4TI>D19:DU0>DUID4TiFE19BEU0BEU9@4U9:A19B@SPBCSH`3Th^919:8Q@B@Q844
SH1m18]mN@B9NGD3QgE`18EaJ`B2K6D4OVIM181ZH`B2KVL4Pg5[0hAdK`B6Mg84QgUd18MkM`B8O7T4
RGik0hZ0O@B;PWl4S8>018b5PPB=QX@4SXR618n:R1Goool001Coool4T8b:192=R`R@SH`4T8j=0i2>
SPB@Shl4T92@196@T0BATI44TI6B0i6BTPBATi<4TI>D196DU@BAU9H4TIFF192EU`>@UYP4T9NI18nG
VPB?V9`4SiVN18nKX0B>V9/3SYJH18nDUPB?U9@4T9>D196CU0BBU9@3U9FE19>EU@BDUI@4UIBD19BB
T@BDT8h4Thf<0i>;R@BBR8D4T8B118f0O@B;OGT4RGUe0hMeL0B5LF/4PVaU17iVG@B0JV<4PViW18=a
J`>4M6l4QWMb18MiM0B7NgL4R7ai18UnN`>:P7d4Rh9o18b3P0B<QH84SHJ418j8QPB?RXPEoooo000D
oooo192<RPB@SH/8T8f<192>S@>@SXh4T8n?192@T0BAT904TI6A196ATP>ATY84TI>C196CU0BAU9D4
TIBF196EUPB@UIL3T9JH192GV@B?UiX4SiRL18nIWPB?Vj04SYRK0hjFV0B?U9H4SiBD192CU0BATi@4
TYBD0iBEU@BCUID4U9FD19FDU0BDTY44U92>19>=S0>CRhT4TXR51924P@B=P7d4Rgei18UiM@>7MG04
QG5[189/I@AnIUd4P6YS189^I`B3LF/3Q7A_18IgLPB7NG@4Qg]g18QlN@B9OW/3RX1m18^2O`B<Ph04
S8F218f6Q0B>R8H4ShZ85Oooo`005?ooo`B@S8X4T8f;292=S0B@SXd3T8j>192?S`B@T904TI2@196A
T@BATI83TI:B196CT`BATi@4TIBE196DUPBAUIH4T9FG0i2FV0B@UiT4SiNJ18nHW0B?VIh4Si^P18jH
V`>>UYP4SiBF18nDU0B@Ti@4TI>D19:DU0>DUID4TiFE19BEU0BEU9@4U9:A19B@SPBCSH`3Th^919:8
Q@B@Q844SH1m18]mN@B9NGD3QgE`18EaJ`B2K6D4OVIM181ZH`B2KVL4Pg5[0hAdK`B6Mg84QgUd18Mk
M`B8O7T4RGik0hZ0O@B;PWl4S8>018b5PPB=QX@4SXR618n:R1Goool001Coool4T8b;192=S0R@SXd4
T8n>0i2?S`BAT904TI6A196BTPBATY<4TI>D0i6DU@BAU9H4TIFG196FV0BAUiT4TINJ196HV`>@VI`4
T9VM18nJWPB?VYl4SY^P18jMX`B=VYd3SYRJ18jFV0B?UIH4T9FF196EUPBBUID3TiJF29BFUPBEUID4
U9>B19B@S`BDSX`3Th^819:7Q@B@PWl4SGij18]jMPB8MG03QG1Z189[I0AoIEd4O61G17iUG@AoJF84
PFaV0h9_J@B3LVd4QGE`18IgLPB7NGD4R7]g0hUmNPB:Og`4Rh5n18b3P@B=QH<4SXN518n9QaGoool0
01Coool4T8b;192=S0R@SXd4T8n>0i2?S`BAT904TI6A196BTPBATY<4TI>D0i6DU@BAU9H4TIFG196F
V0BAUiT4TINJ196HV`>@VI`4T9VM18nJWPB?VYl4SY^P18jMX`B=VYd3SYRJ18jFV0B?UIH4T9FF196E
UPBBUID3TiJF29BFUPBEUID4U9>B19B@S`BDSX`3Th^819:7Q@B@PWl4SGij18]jMPB8MG03QG1Z189[
I0AoIEd4O61G17iUG@AoJF84PFaV0h9_J@B3LVd4QGE`18IgLPB7NGD4R7]g0hUmNPB:Og`4Rh5n18b3
P@B=QH<4SXN518n9QaGoool001Coool4T8b;192=S0R@SXd4T8n>0i2?S`BAT904TI6A196BTPBATY<4
TI>D0i6DU@BAU9H4TIFG196FV0BAUiT4TINJ196HV`>@VI`4T9VM18nJWPB?VYl4SY^P18jMX`B=VYd3
SYRJ18jFV0B?UIH4T9FF196EUPBBUID3TiJF29BFUPBEUID4U9>B19B@S`BDSX`3Th^819:7Q@B@PWl4
SGij18]jMPB8MG03QG1Z189[I0AoIEd4O61G17iUG@AoJF84PFaV0h9_J@B3LVd4QGE`18IgLPB7NGD4
R7]g0hUmNPB:Og`4Rh5n18b3P@B=QH<4SXN518n9QaGoool001Coool4T8b;192=S0R@SXd4T8n>0i2?
S`BAT904TI6A196BTPBATY<4TI>D0i6DU@BAU9H4TIFG196FV0BAUiT4TINJ196HV`>@VI`4T9VM18nJ
WPB?VYl4SY^P18jMX`B=VYd3SYRJ18jFV0B?UIH4T9FF196EUPBBUID3TiJF29BFUPBEUID4U9>B19B@
S`BDSX`3Th^819:7Q@B@PWl4SGij18]jMPB8MG03QG1Z189[I0AoIEd4O61G17iUG@AoJF84PFaV0h9_
J@B3LVd4QGE`18IgLPB7NGD4R7]g0hUmNPB:Og`4Rh5n18b3P@B=QH<4SXN518n9QaGoool001Coool4
T8b;192=S0B@SXd4T8n>192?S`>AT904TI6A196BTPBATi@4TIBE196EUP>AUYL4TIJH196GV@BAV9X4
TIVL196JW@BAVih3TI^O192LX0B?W:44SYfR18fMXPB<WJ@4S9ZO0hfIW0B>UiX4SiNH18nFU`B@UYL4
TIJF0i:FUPBCUYH4U9JF19BEU@BDU9<4U96?19B>R`>CRXL4TXN318n1OPB<NgL4RWIb18IbK0>3K6D4
P6IN17aOEPAjGE<4O65H17eTG0AoJ603P6]T185^J0B3LF/4Q7=^18EfL@B6N7@3Qg]g18QmN@B:P7`4
Rh9o18b4P@B=QX@4SXV75Oooo`005?ooo`B@S8/4T8f<192>S@B@Shh4T8n?0i6@T0BATI44TI:B196C
U0BAU9D4TIFF0i6FU`BAUYP4TINI196HVPBAVI`4TIZM196KWP>AVil4T9bP18nLX@B>WJ84SIfR18bM
Y0B<VYl3SIVL18jGVPB?UiP4SiJG192FU`BAUYH3TYJF19>FUPBDUYH4U9FE19BDT`BDTHl4U8j;0i>:
Q`BBQh<4Sh5n18akM`B:MW84QW9/0h=/I@B0IUh4O5mF17YMD`AlHEP4OFAL17mXH0>0Jf@4PFiX18=a
J`B4Lfh4QGIa18IhM0>7NgL4R7ei18Z0O0B;PWl4S8B118f6Q0B>RHLEoooo000Doooo192<R`B@SH`4
T8j=192?SPB@Shl3TI2@196AT@BATY84TI>D196DU@BAUIH3TIJG196FV0BAUiT4TIRJ196IW0BAVYd4
TI^N0i6KW`B@W:04SibQ18jMXPB=WJ84S9fT18bJW`>=VI`4SYNJ18nGV0B?UYL4T9JG196FUP>BUYH4
TiJF19BFUPBDUID4U9BC19BAS`BDSX/3ThZ719:7P`B?PGh4S7]g18YfLPB6LV`3PfaU181VGPAlGeH4
NUeC17aQF0AmI5`4OfQP0h1[I0B1KVP4Pg5[18AcKPB5MW44QWQd0hMkM`B8OGT4RX1l18^2O`B<Q844
SHJ418j9QaGoool001Coool4T8b;192=S0B@SXd4T8n?196@T0>ATI44TI:C196CU0BAU9D4TIFG19:F
V0>BUiT4TYRK19:IW0BBVYd4TY^O19:LX0BBWJ43TIjR196OY0B@WjD4SYnU18bNY@B:Vj84RiZO0hbI
W@B=V9/4SYRI18nGV0B@UiP4TING0i:GU`BBUYH4TiJF19>EU@BDTi84Ti2>19><RP>BR8H4THB118mo
N`B<NGD4R7=^18E^J0>1If04OF1H27UIC`AjGE<4Nf1G17eSF`=nIel4OfYS185]I`B2L6X4Pg=^18Ae
L0>6N7@4Qg]g18UnNPB:P7d4Rh>018f6P`B>R8HEoooo000Doooo192<R`B@SH`4T8j=192?S`BAT903
TI6A196BT`BATi@4TIBE196EU`BBUYP3TYNI19:HV`BBVI`4TYZM19:KW`BBW:04TYfQ0i6NXPBAWj@4
T9nU18jOY@B<WZD4RY^R18^JW`><VId4SIRK18jHV@B?UiP4T9NH196GU`>BUiL4TYJF19>FUPBCUID4
U9>B19>@SPBCS8X3TXR61964P@B?Og/4S7Ue18QcKPB5KVP3PFMP17ePF0QiFDl4NUeC17]PE`AmHe/3
OVMO17mZH`B1KFL4PW1Z18=cKPB4MG03QWQd18MkM`B9OWX4RX1m18^3P0B=QX<4SXR65Oooo`005?oo
o`B@S8/4T8f<192>S@B@Shl4TI2@0i6AT@BATY<4TI>D196DU@BAUIL4TYJH0i:GV@BBV9/4TYVL19:J
W@BBVil4TYbP19:MX@>AWZ84TInT192OY@B>WjD4S9jU18ZKXPB;VYl3S9VM18fHV`B>V9T4SiNH192G
V0BAUiL3TYNG19:FUPBCUYH4TiFE19BCTPBCT8h4Thb:0i:8QPBAQ844Sgmk18aiM@B8Lfh4QFiX0h5W
H0AmH5P8NEU?17YMD`AkH5L4OF=K0giWG`AoJV<4PFeW189`JPB3Lfh4Q7E`0hIhM0B7NgL4RGij18Z0
O@B;Ph04SHJ318j8QQGoool001Coool4T8b;192=S0B@SXd4T8n?196@T0>ATI44TI:C196CU0BAU9D4
TIFG19:FV0>BUiT4TYRK19:IW0BBVYd4TY^O19:LX0BBWJ43TIjR196OY0B@WjD4SYnU18bNY@B:Vj84
RiZO0hbIW@B=V9/4SYRI18nGV0B@UiP4TING0i:GU`BBUYH4TiJF19>EU@BDTi84Ti2>19><RP>BR8H4
THB118moN`B<NGD4R7=^18E^J0>1If04OF1H27UIC`AjGE<4Nf1G17eSF`=nIel4OfYS185]I`B2L6X4
Pg=^18AeL0>6N7@4Qg]g18UnNPB:P7d4Rh>018f6P`B>R8HEoooo000Doooo192<R`B@SHd4T8n>196@
S`BATI43TI:B196CU0BAU9D4TYJG19:GV0BBV9X3TYVK19:JW@BBVih4TYfP19:NXPBBWj<4TZ2T0i:Q
YPBBXZL4TJ>Y192SZPB7W:<4QiZQ18ZJW`>;VYh4SIVL18jIVPB?V9T4T9RI192GV0>AUiL4TYNG19>F
UPBCU9@4Ti:A19>?SPBBRhT3THJ41922O`B=OGT4RWMb18MaJ`B3JV<3Of=K17]LD`AgE4T4MeI;17QI
C`AiG5<4NemF0gaRFPAmIUh4OfUR181/IPB1L6X4Pg=]0hAfL@B6NGD4R7ah18UoO0B;PWl4S8F218j8
QQGoool001Coool4T8b;192=S@B@Shh4TI2?196AT@>ATY84TI>D196DU@BBUYL4TYNH19:HVP>BVI/4
TYZM19:KWPBBWJ04TYjR19:OX`BBX:@3TZ6V19:RY`BAXjT4T:>Z18NLX`B7VZ44RYZO0h^JWPB=VI`4
SYVJ18nHV@B@V9T4T9NH0i6GU`BBUiL4TiJF19>DU0BCTY44Thn>19:;R@>AQX@4T89o18emN@B:Mg84
Qg5[18=ZH`=oHe/4NeaC17MDB@AgET/4N5U?17ULD`AkGeH3O69J17eVGPAoJF84P6aV185`JPB3Lfd3
Q7Ia18IiM@B8O7P4RGml18^2O`B<QH84SXR65Oooo`005?ooo`B@S8/4T8f=192?SPBAT8l4TI6A0i6B
TPBATi@4TIBE19:FU`BBUiP4TYRJ0i:IV`BBVYd4TY^N19:MX0BBWZ84TYnS19:PY0>BXJH4TZ:W196S
Z@B@XjX4QibS18NJX@B:VYl3RiZN18fIW0B>VIX4SiRI192HV@B@UiP3TING19:GU`BCUYH4TiBD19>B
T@BCShh4TX^90i66Q0B@PWl4SGei18YgLPB7LF/4PfYS0gmSF`AkG5<4MeA917MFB`AhFDl4NEaC17]O
EP=lHUX4OFIN17mYHPB0K6H4PG1Z18=cK@>4MW44QWUe18QlN0B9Og`4Rh9o18b5PPB>R8HEoooo000D
oooo192<R`B@SHd4T8n>196@S`BATI43TI:B196CU0BAU9D4TYJG19:GV0BBV9X3TYVK19:JW@BBVih4
TYfP19:NXPBBWj<4TZ2T0i:QYPBBXZL4TJ>Y192SZPB7W:<4QiZQ18ZJW`>;VYh4SIVL18jIVPB?V9T4
T9RI192GV0>AUiL4TYNG19>FUPBCU9@4Ti:A19>?SPBBRhT3THJ41922O`B=OGT4RWMb18MaJ`B3JV<3
Of=K17]LD`AgE4T4MeI;17QIC`AiG5<4NemF0gaRFPAmIUh4OfUR181/IPB1L6X4Pg=]0hAfL@B6NGD4
R7ah18UoO0B;PWl4S8F218j8QQGoool001Coool4T8b;192>S@B@Shl4TI2@196ATP>ATi<4TIBE19:F
U`BBUiT4TYRJ19:JW0>CVih4TibO19>MX@BCWj<4Tj2T19>QYPBCXjP3TjBZ19>UZ`BCYjd4TZN^186H
X0B6VZ44RI^O0h^KW`B<VYd4SIZL18jIVPB?V9X4T9RI0i6HV0BBV9P4TYJF19>CU0BBT904TXf;1968
Q`>@Q884SX1m18]jMPB9M6l4QFiX185WH0=mGeL4NEQ>17A@A0AeDTL4MUA:17MHCPAhFe83NUiF17]R
FPAmIEh4OVUR181/IPB1L6X3Pg=^18EgLPB6NWH4R7ej18Z1OPB<Q884SXR65Oooo`005?ooo`B@S8/4
T8j=192?S`BAT904TI6B0i6CT`BAU9D4TYJG19:GV@BBV9X4TYZL0i>KWPBCW9l4TifQ19>OX`BCX:@4
Tj6V19>SZ0>CY:X4TjF[19>W[@BBYjh4PIRP18JJX@B9Vil3Ri^O18bJW@B=VY`4SYVJ18nHVPB@V9T3
TIRH19:HV0BBUYH4Ti>D19:@T0BBSH/4THR70i24PPB>P7d4RgYf18UdK`B5KVP4PFMP0geOE`AiF4h4
M51417EBA`AfE4X4MeQ>17QKDP=jGUH4Nf9J17eUGPAnJF84P6aV185`JP>3Lfh4QGMb18IjMPB8OGX4
RX5n18b4PPB>R8HEoooo000Doooo192<R`B@SXd4T8n?196@T0BATI83TI>C196DU@BBUYL4TYNI19:H
VPBBVY`3Ti^N19>LW`BCWJ44TinS19>PY0BCXJH4Tj>X0i>TZPBCYJ/4TjN]19:W[PB1V:04QYZQ18VK
W`>;Vil4S9ZM18fJW0B>VIX4SiRJ192HV@>AV9P4TYRH19:FUPBCTi@4TY2@19:=R`BAR8L3T8B218j0
O@B;NWH4RGA_18E^J0B1If03OEmG17UHCPAdD4@4ME9717IDBPAgF4h4N5]B0gYNEPAkHUX4OFEN17iY
HPB0K6H4PG1Z0h=cKPB5Mg84QWYf18QmNPB:PGh4S8B218j8QQGoool001Coool4T8b;192>S@B@Shl4
TI2@196ATP>ATi<4TIBE19:FU`BBUiT4TYRJ19:JW0>CVih4TibO19>MX@BCWj<4Tj2T19>QYPBCXjP3
TjBZ19>UZ`BCYjd4TZN^186HX0B6VZ44RI^O0h^KW`B<VYd4SIZL18jIVPB?V9X4T9RI0i6HV0BBV9P4
TYJF19>CU0BBT904TXf;1968Q`>@Q884SX1m18]jMPB9M6l4QFiX185WH0=mGeL4NEQ>17A@A0AeDTL4
MUA:17MHCPAhFe83NUiF17]RFPAmIEh4OVUR181/IPB1L6X3Pg=^18EgLPB6NWH4R7ej18Z1OPB<Q884
SXR65Oooo`005?ooo`B@SH/4T8j=196@S`BATI44TI:B0i6DU0BBUIH4TYNH19:HVPBCVY`4Ti^N0i>M
X0BCWZ84Tj2T19>QYPBCXZL4U:BY19BUZ`>DYjd4U:R_19F[/PB<Xj/4Q9^S18NLXPB9W:03RibP18bK
WPB=VYd4SYZK18nIVPB@VIX3TIVJ19:IV@BBUiL4Ti>D19:?S`BARXX4T8J50hn1P0B=OGX4RGMd18Ma
K0B3JfD4P6AM0gaME0AgED/8Lde117A@A@AeDdP4MUM=0gQJD@AiGUD4Nf9J17aUGPAnJF84P6eW0h9a
J`B3MG04QGQd18MlN0B9P7d4Rh>118j7QAGoool001Coool4T8f;192>S@BAT8l4TI6A196BTP>AU9@4
TYFF19:GV0BBV9X4TiZL19>KWP>CWJ04TijR19>PY0BCXJH4Tj:W19BTZ@BDYJ/3U:N]19BX[`BEZk84
S:>[18BKX`B7W:84RIbP0h^LX0B<Vih4SIZM18jJV`B?VIX4T9VJ0i6IVPBBVIT4TYNG19>CU0BBShl4
THZ:1926Q@>?PH04SGej18UgM0B7LF`4Pf]U181TG@=lGE@4MeE;27==@@AdD4D4ME=817IGC@=hFU44
NEiE17]RFPAlIEh4OVUR181]I`>2LF/4PgE`18EhM0B7O7P4RH1m18^3P@B>QhDEoooo000Doooo192=
R`B@SXd4TI2?196AT@BATY83TIBD19:EUPBBUiP4TYRJ19>JW0BCVih3TifP19>NXPBCX:@4Tj6V19>R
Y`BDY:T4U:F[0iBW[@BDZ:l4UJ^b18bSZ`B4Vj<4QibR18VLX0>;W:04S9^N18fJW@B>VY/4SiVJ192I
VP>AVIX4TYVI19:GU`BCTi@4TXn?196:RPB@QXD3Sh6018emNPB9Mg@4Qg5/18=[I@B0I5d3O5eD17ME
B`QcCD44M51517ECB0AfEdd3N5YA17UNE@AkHUX4O6EN17iYHPB0KFL3PW5[18=eL0B5N7@4Qgah18V0
O@B;Ph44SXN55Oooo`005?ooo`B@SH/4T8j=196@S`BATI44TI:B0i6DU0BBUIH4TYNH19:HVPBCVY`4
Ti^N0i>MX0BCWZ84Tj2T19>QYPBCXZL4U:BY19BUZ`>DYjd4U:R_19F[/PB<Xj/4Q9^S18NLXPB9W:03
RibP18bKWPB=VYd4SYZK18nIVPB@VIX3TIVJ19:IV@BBUiL4Ti>D19:?S`BARXX4T8J50hn1P0B=OGX4
RGMd18MaK0B3JfD4P6AM0gaME0AgED/8Lde117A@A@AeDdP4MUM=0gQJD@AiGUD4Nf9J17aUGPAnJF84
P6eW0h9aJ`B3MG04QGQd18MlN0B9P7d4Rh>118j7QAGoool001Coool4T8f<192?SPBAT904TI:B196C
T`>BUIH4TYJH19:HVPBCVY`4Ti^N19>MX0>DWZ84U:2T19BRYPBDXjP4U:FZ19BV[0BDZ:l3U:Za19F/
/`B?Yjl4R:6Y18ROYPB8WZ@4RYjR0h^MX@B<W9l4SI^M18jJW0B?VY/4T9ZK0i6JV`BBVi/4TYNG19>C
U0BBSXh4THV918n3P`>>Ogh4RgYh18QeL@B4KVX4PFQR17iRFP=kFe84MUA917=<@0A`B3/4LD/o17=>
@`AdDTL3MEI<17MJD@AhGUD4NV9J17aVG`AnJV@3P6iY189bK@B4Mg84QgYf18UoN`B;Ph04SHN55Ooo
o`005?ooo`B@SH`4T8n>196@T0BATY84TI>C0i:EUPBBUYP4TYRJ19>JW0BCVih4TifP0iBNXPBDX:@4
U::V19BSZ0BDYJX4U:J/19BX[`>DZ[44UJbc18nW[`B8XJT4R9nV18RNY0B:WZ83RifQ18bLW`B=Vid4
SYZL18nJV`B@VY/3TIZK19:KV`BBUiL4Ti>D19:>SPBARHT4Sh>30hioOPB;NWP4R7Ea18A^JPB1J684
OV9J0g]KDPAfE4T4Lda01718>`AaBcl4Ldi317ABA`=eET`4MeYA17QNE@AjHUX4O6IO17iZI0>0KVT4
PW9]18AgLPB7NWH4RGmk18^3P0B=QhDEoooo000Doooo192=S0B@Shh4TI2@196BTPBATi<3TYFF19:F
V0BBV9X4TiZL19>KWPBCWJ03U9jR19BPY0BDXZH4U:>X19BUZPBDYZ`4U:R_0iBZ/@BE[;<4SjN_18RQ
Z@B8WjH4R9jT18ZNXP>;WJ44S9bO18fKW@B>VY`4SiZK192JV`>AVY/4TY^K19:GU`BCTi@4TXj>1969
R@B?Ph<3SWmn18]jN0B8MG44Q6iZ185XHPAnHUX3Ne]B17IDB@AcC404L4Pk175;?`AcCT<4M5970gEF
C0AgFU44N5iE17YRFPAlIUl4OVYT0h1^J@B2LVd4Q7Mb18MjMPB9Og/4Rh>018f7QAGoool001Coool4
T8f<192?SPBAT904TI:B196CT`>BUIH4TYJH19:HVPBCVY`4Ti^N19>MX0>DWZ84U:2T19BRYPBDXjP4
U:FZ19BV[0BDZ:l3U:Za19F//`B?Yjl4R:6Y18ROYPB8WZ@4RYjR0h^MX@B<W9l4SI^M18jJW0B?VY/4
T9ZK0i6JV`BBVi/4TYNG19>CU0BBSXh4THV918n3P`>>Ogh4RgYh18QeL@B4KVX4PFQR17iRFP=kFe84
MUA917=<@0A`B3/4LD/o17=>@`AdDTL3MEI<17MJD@AhGUD4NV9J17aVG`AnJV@3P6iY189bK@B4Mg84
QgYf18UoN`B;Ph04SHN55Oooo`005?ooo`B@SH`4T8n>196AT@BATY84TYBE0i:EU`BBUiT4TiVK19>K
WPBCWJ04U9jR0iBPY@BDXZL4UJBY19FUZ`BEYjd4UJV`19FZ/P>E[;@4Tjbe18VS[0B9XZX4RJ6X18ZP
Y@B;Wj@3S9nS18bMX0B=W9d4SI^L18jKV`B?Vi/3T9^K19:LW0BCVIT4TiFE19:?S`BARhX4Sh>30hen
O@B:N7H4QW9_189/J0AnIEl4Nf1H0gUJD@AeDdT4Lda116m6>@A_ACP4L4Xm179>@P=cDTL4M5I<17IJ
D@AhGUH4NV=K17aWH@=nK6H4PG1[18=eL0B6NGD4R7ij18^2O`B=Qh@Eoooo000Doooo192=S0B@Shh4
TI6A196BTPBBU9D3TYFG19:GV@BCVI/4Ti^N19>MX0BDWZ83U:2U19BRY`BEY:T4UJF[19FW[@BEZK04
UJZb0iF/]0BC[;D4RJ>/18VRZPB9XJP4RZ2U18^OY0><Wj<4S9fP18fLW@B=Vi`4SY^K18nKV`>@Vi/4
TYbL19>IV@BCUID4TXn?196;RPB?Ph<3SGim18YhMPB6LVl4PVaX17iUG`AkH5P3NEYA17ECB@AcC444
KdHi16m5>0A`BSd4LTi20g=BA`AdET`4MUYA17QNEPAjHe/4O6MQ0gi/IPB1L6/4PgE`18IiM@B8OWX4
Rh9o18f7Q1Goool001Coool4T8f<192?SPBATI44TI:B19:DU@>BUIL4TYNI19>IV`BCVih4TifP19BN
XP>DX:D4U::W19FTZ@BEYJ/4UJN]19FY/0BEZ[83UJbd19>/]@B9Xj`4RJ:Z18VQZ0B:X:D4RinT0hbO
X`B<WJ04SIbM18fKW0B>Vi/4Si^K0i2KV`BBW9`4TiVI19>EU@BBShl4TH^:18n3P`>=OWd4RWQf18Ib
K`B2K6P4OVEO17]PF0=iFU44ME=917=<@@A_AST4KdDh171:?@AbCT83Le9717AFC0AfFU44N5iF17YS
F`AlIf43OVaV185`J`B3MG04QWUe18QnNPB;PWl4SHN45Oooo`005?ooo`B@SH`4T8n?196AT@BATi<4
TYFF0i:FV0BCV9X4TiZM19>LW`BDWZ84U:2T0iFRY`BEY:T4UJJ/19FX[PBFZ[04UJ^c19F]]@>E[kP4
QjB]18RS[0B9XjX4RJ:Y18ZRY`B<XZH3SJ6U18fOX@B<W9h4SI^L18jKW0B>W9/3SiZK19:KVPBCVYX4
TYJE19:BT@BBShh4ShJ50henO@B9MgD4Q6m]181ZIPAlHed4NEiF0gMHD0AeDdT4LTa11717>PA]@S@4
KTDh16m9?@=`CD84LU5717AFC@AfFe84N5mH17YTG@=mJF<4OfiY189cKPB5N7@4Qgei18Z1OPB=QX@E
oooo000Doooo192=S0B@Shl4TI6A196CT`BBUIH3TYJH19>HVPBCVYd4TibO19BNXPBDX:@3UJ:W19FT
Z@BEYZ`4UJR^19JZ/0BEZk<4UJfe0iF_^0B7Y:d4R:>/18VSZPB9XZT4RZ:W18bRYP>=XJD4SInQ18bL
WPB=Vi`4SY^L18jLV`>?VY/4TY^J19>JVPBBUYD4TY:A19:?SPB?QXD3SGim18UgM@B4Kfd4P6YV17aS
G@AiGUH3MeQ@17ECB@AbC444L4Lj16e2=0A^ACP4KdTm0g1=@PAbDDL4M5I=17IKDPAhGeP4NVAM0geY
H`AoKVT4PW=^18EhM0B7OGT4RX5n18f6Q1Goool001Coool4T8f<192?S`BATI44TI>C19:EUP>BUYP4
TiRJ19>JW@BCW9l4U9jR19BPY0>EXZL4UJBY19FV[0BEZ:h4UZZ`19F[/`BE[KD3UJnh18NT[@B8Xj`4
RJ>Z18VRZ@B:XZL4S::V0hfQY@B=Wj44S9bN18fKW0B>Vi`4SYbK0hnJV`BBViX4TiZJ19:FU@BBTY44
TXn>18n6Q@>=OWd4RGMe18A_K@B0JVH4O6=M17UNEP=gF504ME=9179<@@A`AcX4KD8d16i5>0A_BCd3
L4e2179AA`AdETd4MU]B17QOF0AjI5d3OFUS17m^J@B2Lfh4QGQd18MmN@B:PGh4SHJ45Oooo`005?oo
o`B@SH`4T8n?196AT@BATi<4TYFF0i:FV0BCV9X4TiZM19>LW`BDWZ84U:2T0iFRY`BEY:T4UJJ/19FX
[PBFZ[04UJ^c19F]]@>E[kP4QjB]18RS[0B9XjX4RJ:Y18ZRY`B<XZH3SJ6U18fOX@B<W9h4SI^L18jK
W0B>W9/3SiZK19:KVPBCVYX4TYJE19:BT@BBShh4ShJ50henO@B9MgD4Q6m]181ZIPAlHed4NEiF0gMH
D0AeDdT4LTa11717>PA]@S@4KTDh16m9?@=`CD84LU5717AFC@AfFe84N5mH17YTG@=mJF<4OfiY189c
KPB5N7@4Qgei18Z1OPB=QX@Eoooo000Doooo192=S0BAShl4TI6B196CU0BBUIL3TYNI19>IW0BCVih4
U9jQ19BPY0BEXZH3UJBY19JV[0BFZ:h4UZZa19J//`BF[[H4U[2i0i:^^0B5XZ`4Qj>/18RSZ`B9XZT4
Rj>Y18fTZ@>>Y:L4SZ6S18bLW@B=Vi`4SY^L18ZHV0>>Vi/4TIVI19>JVPBDVIP4U9BC19BBT0BARXP3
SX>118MhMPB2KV`4OFMU17YQF`AgFe@3MUM?17ACB@AbCD84L4Lk16a1=0A/@384KD@g0fi8?@A_CD84
LE9817=GCPAfG5@4N65J0g]WH0AnK6H4PG5/18AfLPB7NgP4RX5n18f6Q1Goool001Coool4T8f<196?
S`BATI84TI>D19:EU`>BUiT4TiVL19>KWPBDWZ44U:2T19FRYP>EY:T4UZJ/19JX[PBFZ[44UZbc19J^
]PBF/;T3TZjh18FR[0B7Xj`4R:>[18VRZ@B;XjT4SJBY0hjTY`B>XJ<4S9bM18fKW0B>Vi`4RYRH0hjK
V`BAVIT4TiZJ19BIV0BDU9<4U9:@196:R0>>Ph44QgQf189^K0AmIfD4NV5K17MKE0=fEdl4M5=9179=
@PA`Ac/4K44d16a0<PA]A3L3KTPm16m=@PAaDTP4LeM>17ILE0AhHEX3NfMP17i/IPB1LF`4Q7Ib18Mk
N0B:PGh4SHJ45Oooo`005?ooo`B@SH`4THn?196ATPBATi@4TYFG0i:GV@BCVI`4Ti^N19BNX@BDX:@4
UJ:V0iFTZ@BFYZ`4UZR^19JZ/@BF[;<4UZjf19J`^@>B[[P4QJ:/18NS[0B8Xj/4RJ:Y18^SZ@B=Y:T3
SZBW18jQX`B<W9d4SI^L18jKW0B:V9P3SY^K196IV@BCVYX4U9VH19BDT`BDTY04THZ80hj3P@B7N7H4
PVi/17eWI@AjHE/4Me]D0gIGC`AdDdT4LTe21717>`A/@C@4K40b16e4=`=^B3d4Kde2175BB0AcEdh4
MUaD17QQFP=kIf04OVaV185aK0B4MW84Qg]h18Z1OPB=QX@Eoooo000Doooo192=S0BAShl4TI6B196C
U0BBUIL3TYNI19>IW0BCVih4U9jQ19BPY0BEXZH3UJBY19JV[0BFZ:h4UZZa19J//`BF[[H4U[2i0i:^
^0B5XZ`4Qj>/18RSZ`B9XZT4Rj>Y18fTZ@>>Y:L4SZ6S18bLW@B=Vi`4SY^L18ZHV0>>Vi/4TIVI19>J
VPBDVIP4U9BC19BBT0BARXP3SX>118MhMPB2KV`4OFMU17YQF`AgFe@3MUM?17ACB@AbCD84L4Lk16a1
=0A/@384KD@g0fi8?@A_CD84LE9817=GCPAfG5@4N65J0g]WH0AnK6H4PG5/18AfLPB7NgP4RX5n18f6
Q1Goool001Coool4T8f<196@S`BATY84TYBE19:FV0>CV9X4TiZM19BMX0BDWj<4UJ6V19FTZ@>FYZ/4
UZR^19N[/@BG[K@4Ujnf19N`^@BH/kd3QjJa18BR[@B6Xj`4RJB/18VSZ@B<YJ/4SZN/0i2WZPB?XjD4
SYnO18VHV@B=Vi`4RiRH0hjJVPB@VYX4TYVI19FKV`BEUI@4UY>A19F>R`>BRHH4R7aj17m_K0AkIF84
MemJ17EID`=dETh4M5=9179>@`A`B3`4KD<e16/n;`AZ@3<3JT@g16a8?@A^CT@4L5=:17=ID0AfGUL3
NFAM17aZI0AoKfX4PgE`18IjM`B9P7d4S8J35Oooo`005?ooo`B@SH`4TI2?196BTPBBU9D4TYJH0i>H
VPBCVYd4U9fP19BOX`BEXJH4UJBY0iJVZ`BFZ:h4Uj^a19N]]0BG[kH4Uk2i19Rc_@>7Y[44Q::]18JS
[0B9Y:`4RJ>Y18bUZ`B>Yj`3T:NZ18nSY@B>Wil4RIRI18fKW0B;V9P3SYZJ192JVPBBVIT4UI^K19FE
U0BFTi44UHj;0i:9QPB8O7X4Ofm/17]UHPAgGeX4MEUC0gAFCPAdDdT4LTi31718?0A]@cD4Jch_16Y0
<`=ZA3L4K4Pm16i>A0A`DdX4LeU@17INE`=iI5d4O6YT17m_JPB3MG04QWYg18V0O@B<QX<Eoooo000D
oooo192=S0BAT8l4TI:B19:DU@BBUYP3TiRJ19>JW@BDWJ04U9nS19FQYPBEY:T3UZJ[19JX[PBGZk44
Ujfd19N_]PBG/;T4V;>m0hNV/@B4XZd4QZ>/18VT[0B9XjT4S:F[18jW[0>@YjX4Sj>U18jOW`B9V9T4
SI^L18^HV0>>VYX4T9ZJ19:IV@BEVi/4UIFD19JCT@BESX/3TXV618QlNPAoKf`4NfER17MOFPAeFE<3
M5I>17ACB@AbCT<4L4Pl16e3=@A[?Rl4JT0c0fY4=`A/B3d4KTi4171CBPAcFE04MUiG0gUTG@AlJV@4
OfmZ18=eL0B6NWL4RH1m18b6PaGoool001Coool4T8f<196@S`BATY84TYBE19:FV0>CV9X4TiZM19BM
X0BDWj<4UJ6V19FTZ@>FYZ/4UZR^19N[/@BG[K@4Ujnf19N`^@BH/kd3QjJa18BR[@B6Xj`4RJB/18VS
Z@B<YJ/4SZN/0i2WZPB?XjD4SYnO18VHV@B=Vi`4RiRH0hjJVPB@VYX4TYVI19FKV`BEUI@4UY>A19F>
R`>BRHH4R7aj17m_K0AkIF84MemJ17EID`=dETh4M5=9179>@`A`B3`4KD<e16/n;`AZ@3<3JT@g16a8
?@A^CT@4L5=:17=ID0AfGUL3NFAM17aZI0AoKfX4PgE`18IjM`B9P7d4S8J35Oooo`005?ooo`B@SXd4
TI2@196CT`BBUIH4TYNI0i>IW0BCW9h4U9jQ19BPY0BEXjP4UZF[0iJX[PBGZ[44V:fd19V`]`BI/KX4
Uk:k19Jc_@>0X:d4Pj:/18JS[0B8YJ`4RZB[18bV[0B?ZJh3TJR/192UY`BAXZ84QiFF18ZFU`B<UiP3
SYNG192IVPBBVIT4U9VH19BCT@BETHl4UHf:0iF;R0B?PGd4Q7Ea17QVHPAdGEP4LUMA0g=DC0AcDTT4
Ldm4171:?@A^@cH4Jch_16Tn<0=W?c84Id<h16Y9?`A]CdH4LEE=17AKE0=gHU/4NfQQ17i^J0B2Lfl4
QGUf18UoO0B<QH<Eoooo000Doooo192>S@BAT904TI>C19:EUPBBUiT3TiVL19>LWPBDWZ44U:2T19FS
Z0BFYJ/3UZR^19NZ/@BH[K@4VK2g19Va^PBG/[/4U[>m0h2P[@B3XZ`4QZ>/18RU[0B:Y:/4S:J/18nY
[P>AZ:`4T:FW196RXPB7UIH4RYJG18bGV0>>UiL4T9VJ19:IV@BDVIP4U9>A19FAS`BESHX3UH^818n1
O@B4MG44N6IR17AMF0AbEe43LeA<17=BB@AcCd@4L4Xm16i3=PA[?Rl4JCh`0fLo<PAW@cP4JTTo16e?
APAaEDd4M5]D0gMRF`AkJ644OViX189cK`B5NGH4RGml18b5PaGoool001Coool4T8j=196@T0BATi<4
TYFF19:GV@>CVI`4TibN19BNX@BDX:@4UJ>X19JUZ`>FZ:h4UjZa19R]]0BI/;L4VK6j19Nb^`BF/kd3
P:2]18>R[0B6Xj`4R:F/18ZTZ`B<YZ`4SjV^0i6X[0B@YJL4TJ:R18NEUPB:UYL4S9NH0hjGU`B@VIX4
TYVI19BIV0BDTi44UI6?19F=RP>ERhP4Sh5m18AeL@AhIV84M5eH179GD@=cE4`4Le9917=?A0A`BSd4
KT<f16/n;`AY?S03Iclb16M3>0AZBCl4KDm6175EC@AdFe@3Mf9K17]XH@AnKVP4PW=_18EiMPB9Og`4
S8F35Oooo`005?ooo`B@SXd4TI2@196CT`BBUIH4TYNI0i>IW0BCW9h4U9jQ19BPY0BEXjP4UZF[0iJX
[PBGZ[44V:fd19V`]`BI/KX4Uk:k19Jc_@>0X:d4Pj:/18JS[0B8YJ`4RZB[18bV[0B?ZJh3TJR/192U
Y`BAXZ84QiFF18ZFU`B<UiP3SYNG192IVPBBVIT4U9VH19BCT@BETHl4UHf:0iF;R0B?PGd4Q7Ea17QV
HPAdGEP4LUMA0g=DC0AcDTT4Ldm4171:?@A^@cH4Jch_16Tn<0=W?c84Id<h16Y9?`A]CdH4LEE=17AK
E0=gHU/4NfQQ17i^J0B2Lfl4QGUf18UoO0B<QH<Eoooo000Doooo192>S@BAT904TI>C19:EUPBCV9X3
TiZM19BMX0BDWj<4UJ:V19FTZ@BFYjd3UjV`19R//`BI/;L4Vk>k19ff_`BE/KX4S:^f0h2P[0B3XZ`4
QZB]18RT[0B:Y:/4S:N]192Z[`>AYj/4T:FW192RX`B:Vi`4RiVJ18fIVP>>V9P4T9ZJ19>IV@BDVIP4
Ti>A19B@SPBBRHL3TXV518n1O0B:NGD4OF]W179KE`AaEE03LE=;17=CB@AcCd@4LDXn16i4=`A/?c04
J3`]0fHm;PAS?C84IdDj16Y;@PA^DTT4LUUA0gEOF0AiIEl4OFaV185bK@B4N7@4R7mk18b5PQGoool0
01Coool4T8j=196@T0BATi<4TYFF19>HVP>CVYd4U9fP19BOX`BEXZH4UJBY19JW[@>GZK04V:bc19V`
]`BK/k/4WKJo19Fa^PB<ZkH3P:2/18>R[0B6Y:d4R:B/18ZTZ`B<Yjd4T:Z_0i6WZ`B@YJL4T::S18ZK
W0B;VIX4SIVJ0hjHV0B@VYX4TiVI19BIV0BCTi44U92>19:9Q`>BRHD4Sh5l18YiM@AmJfL4LU]G175E
D0=aDd/4Le=917=?A0AaBSh4KT@g16`o<0AX?2d3ISd^16<m<PAWACX4JT]216iBB@AbFE43MEmH17UU
G`AmK6H4PG9]18AhM0B8Og/4S8F25Oooo`005?ooo`B@SXd4TI2@196CT`BBUIH4TiRJ0i>JW@BDWJ04
U9nS19FRYPBEY:T4UZN]0iNY/0BH[;<4VK2g19^c^`BM][l4UK6j18b[]P>0X:`4Pj:/18JT[@B8Y:`4
RZB[18bW[@B@ZZl3TJN[192UY`B@XZ<4RY^L18^IVPB=VIX3SYRH192JVPBCVIT4U9VH19>CT@BDT8h4
TXV70i:9Q@B?PG`4RWUe17e[I`AbFeL4LEE@0g5CB`AcDdT4Ldm4175:?PA^A3L4K3l`16Pl;@=V?Bh4
Hcdb16M5>PAZBd84KU99179ID@=eGeP4NFEO17e/IPB1LVd4Q7Qd18QoN`B<QH8Eoooo000Doooo192>
S@BATI04TY>D19:FU`BCVI/3Ti^N19BMX@BDX:@4UJ>X19JUZ`BFZ:l3Uj^b19R^]PBJ/[X4WKNo1::l
aPBD/K/4PZ>_0h:R[PB4Xjd4QZB]18RT[0B9Y:`4S:N]18nY[P>?YJX4S9nR18bNX0B<WIh4S9bM18jK
W0>?W9`4TIfM19>LW0BDVYT4U9NE19>AS`BBRhP3T8R318j1O0B:NG@4PVmZ17ANF@A_E4l3L5=;17=C
BPAcD4D4LD/o16i5>0A/@384JC`]0elf:0AP>Rh4Hd0e16M8?PA[CdH4KeI>0gAME@AhHed4O6YT181a
K0B4Mg<4R7ik18b5PQGoool001Coool4T8j=196AT0BBTi@4TYJG19>IV`>CVih4U9fQ19BPY0BEXjP4
UZF[19JX[`>GZk84V:jf19Zb^PBM]kl4X[c619Ba^`B2Xjl3PZ:^18BS[@B6Y:d4R:B/18VT[0B<Yjd4
SjV^0hnUZPB<Wj84S9jP18bMWPB<W9d4SY^L0hnLW0BAWId4TibL19BJV@BDUiD4Ti6?19:;R0>@R8<4
SX5l18YiM0B2KfX4M5iI16mDC`=`Dd/4Le=:17=@A@AaBcl4KTDh16a0<PAY?2d3GcHX160j;PAS@3D4
IdPn16]?APA_ETh3M5eE17QSG@AlJV@4P75/18AgL`B8OW/4S8F25Oooo`005?ooo`B@SXd4TI6@19:C
U0BBUYL4TiVK0i>KWPBDWJ44U:2T19FSZ0BFYJ/4UZR_0iN[/PBH[[H4V[:j19fg_`BR_<H4U;6k18:S
[`>2XZh4Q:>]18JT[@B8Y:`4RJB/18bW[@B?ZJh3SjFZ18bOXPB<WZ04S9fN18bLW@B>Vi`3SibL196M
W@BCW9`4U9ZI19BGU@BCTHl4TX^80i28P`B>PG`4RWUd189_JPAdGUT4KeA?0g1CB`AcDdX4Le15175;
?`A^ACP4K40b16Tl;@=O=RP4H3X^16=0=@AWB3h4Jdm616mFCP=dGED4N6=M17aZI0B0LF`4Q7Mc18Qn
N`B<QH8Eoooo000Doooo192>S@BATI04TY>D19:FU`BCVI/3Ti^N19BMX@BDX:@4UJ>X19JUZ`BFZ:l3
Uj^b19R^]PBJ/[X4WKNo1::laPBD/K/4PZ>_0h:R[PB4Xjd4QZB]18RT[0B9Y:`4S:N]18nY[P>?YJX4
S9nR18bNX0B<WIh4S9bM18jKW0>?W9`4TIfM19>LW0BDVYT4U9NE19>AS`BBRhP3T8R318j1O0B:NG@4
PVmZ17ANF@A_E4l3L5=;17=CBPAcD4D4LD/o16i5>0A/@384JC`]0elf:0AP>Rh4Hd0e16M8?PA[CdH4
KeI>0gAME@AhHed4O6YT181aK0B4Mg<4R7ik18b5PQGoool001Coool4T8j=196AT@BBU9@4TiNH19>J
W0>DW9l4U9nR19FQYPBEY:T4UZN]19JY/0>G[;@4V:nh19Zc_0BM^<44X;_619Fb_0B6YK03Q:B^18FT
[@B6Y:`4R:B/18VT[0B;Yjd4SZR^0hjUZPB:WJ04RYbN18^KW@B<W9d4SY^L0hnLW@BAWId4TibL19>J
V@BDUYD4TY:?196=R@>=Qh84Rh1k18MiM0B2L6X4NFAN179HD`=aE4`4Le=:17=AAPAbC404KdLi16i2
=0A]@303FS4S15`e:@AP?C84I4@j16U<@`A]Dd/3LUYC17IQF`AjJ6<4OVm[18=fLPB7OGX4RhB25Ooo
o`005?ooo`B@SXd4TI6A19:DU0BCUiP4TiZL0iBLW`BDWj84UJ6V19FTZ@BFYjd4UZV`0iN/]0BH[kP4
V[>l19fh`@BP^lH4UK:l18JU/0>4Y:h4QJB]18JT[0B8Y:`4RJB/18^W[@B>Z:h3SZFZ18ZMX0B:W9h4
Ri^M18bLW@B>Vi`3SibM196MW@BCW9`4TiZI19BFU@BBTXl4THf90hf7PPB;P7/4QgUd189`JPAiI5h4
LUQC0g5DC0AcDdX4Le56179<@0A_AcT4KT8d16e0<0=J<B<4G3DY160m<PATA3X4JDa316eCB`=bFU<4
MV5K17YXH`AnKf/4PgIb18MmNPB;Q88Eoooo000Doooo192>S@BATI44TYBD19>GV0BCVY`3U9bO19BO
XPBEXJH4UJBY19JW[@BFZK03Ujbd19R_^0BJ/k`4WKS11:2kaPBE/[`4QZF`0hBT[PB5Y:d4QZB/18RT
[0B9Y:`4RjN]18jX[P>>YJX4RYfP18ZLWPB;Vid4S9bM18jKW0>?W9d4TIfM19>LW0BCVYT4U9JE19:B
S`BASHT3SHN218^0N`B7NG@4PW1Z17UTGPAbF5<3LEA<17=CBPAcDDH4LTa016m7>@A^@S@4KD0`0eXa
8`AL=BT4H3db16A4>PAYC4<4KE=;0g9JD`AfHE/4NVQS17i_J`B3MW84Qgej18^4PQGoool001Coool4
T8j=196AT@BBU9@4TiNH19>JW0>DW9l4U9nR19FQYPBEY:T4UZN]19JY/0>G[;@4V:nh19Zc_0BM^<44
X;_619Fb_0B6YK03Q:B^18FT[@B6Y:`4R:B/18VT[0B;Yjd4SZR^0hjUZPB:WJ04RYbN18^KW@B<W9d4
SY^L0hnLW@BAWId4TibL19>JV@BDUYD4TY:?196=R@>=Qh84Rh1k18MiM0B2L6X4NFAN179HD`=aE4`4
Le=:17=AAPAbC404KdLi16i2=0A]@303FS4S15`e:@AP?C84I4@j16U<@`A]Dd/3LUYC17IQF`AjJ6<4
OVm[18=fLPB7OGX4RhB25Oooo`005?ooo`B@SXd4TI6A19:DU@BCUiT4U9ZM0iBMX0BEX:@4UJ>X19FU
Z`BFZ:l4UZ^b0iJ]]PBG/;T4V;>m19Vf`0BF];l4TJni18ZX/`>6Y:h4QJ>]18JSZ`B7Y:`4R:B/18ZV
[@B=Yjd3SJFZ18ZNXPB9VY`4RYVK18^KW0B=Vid3SibM196MWPBCWId4TiZI19>EU0BBTHl4T8b80hb6
P@B8OWT4Q7Ia17m^J0AjIEl4MEaF0g=GC`AcED`4M597179=@@A`B3/4Kd@e16m1<@=G;b44F38V15di
;PAR@CL4ITTo16]@B0=`F504M5mI17UWH@AmKVT4PWEa18ImN@B;Q84Eoooo000Doooo192>S@BATI44
TYBE19>GV@BDVYd3U9fP19FPY0BEXjP4UJF[19JX[`BFZk83UZff19N`^@BH/kd4VKK019Jd_`BA[kT4
RZRc0hJT[PB5Xjd4QZ>[18NT[0B8Y:`4RZJ]18fW[@>=YJX4RYjR18VJW0B:VI/4Ri^L18fKW@>?W9d4
TIfN19>MW@BCVYT4TiFD19:AS`B@S8P3S8J118QnN@B4MW44OfiX17YUG`AeG5H3LeM?17=EC0AdDTL4
LTe11718>`A_A3D4Kd4a0eL_8@AH<RH4GCT^1691=`AVBCl4Je180g1HD0AdGeT4NFMQ17e^J@B2MG44
QWei18^4PAGoool001Coool4T8j=196AT@BBU9D4TiNI19BJW@>DWJ04UJ2T19FSZ0BEYJ/4UZR_19J[
/P>F[KH4Uk2i19Rc_@BI]/04U[Bo196_^@B:Z;<3QZB^18FS[@B6Xj/4QjB/18RT[0B:YZd4SJN]0hfU
ZPB:WZ84RIZL18ZIV`B;Vi`4SI^M0hnLW@BAWIh4TifM19>JV@BCUI@4TY6?192<R0><QX44R7ii18Af
L@AoKVP4NVEO17ELEP=cEdl4LeE<17ABA`AbCD44L4Pk16m4=@A_@C43EblQ15Pb9PAM>Bh4HT4g16I9
?`A[D4P3L5Q@17AOF@AiIf44OFiY189eL@B6OGT4RhB15Oooo`005?ooo`B@SXd4TI6A19:DU@BCUiT4
U9ZM0iBMX0BEX:@4UJ>X19FUZ`BFZ:l4UZ^b0iJ]]PBG/;T4V;>m19Vf`0BF];l4TJni18ZX/`>6Y:h4
QJ>]18JSZ`B7Y:`4R:B/18ZV[@B=Yjd3SJFZ18ZNXPB9VY`4RYVK18^KW0B=Vid3SibM196MWPBCWId4
TiZI19>EU0BBTHl4T8b80hb6P@B8OWT4Q7Ia17m^J0AjIEl4MEaF0g=GC`AcED`4M597179=@@A`B3/4
Kd@e16m1<@=G;b44F38V15di;PAR@CL4ITTo16]@B0=`F504M5mI17UWH@AmKVT4PWEa18ImN@B;Q84E
oooo000Doooo196>SPBATY84TYFF19>HVPBDVih3UIjR19FQYPBEY:T4UZN]19JY/0BF[;@3UZjg19Ja
^PBE/kd4U;>o19:`^`B>ZkH4RJJ`0hFS[PB4XJ/4QJ6Z18JRZPB7Xj/4RJB/18^V[0>;Y:X4Rj2T18VJ
W@B9V9X4RiVK18fKW@>?Vi`4T9bM19>MW@BCVYX4TiJE196@SPB?RhP3RXB018ImN0B2MG04OViX17YV
G`AeGUH3M5YA17AGC@AdDdP4LTi21759?0A`ACL4LT<c0eD]80AD;R84FCHZ15ln<`ATAS`4JDi50fiF
CPAcGUL4N6EO17a]J0B1M704QWai18^4PAGoool001Coool4THj>196BTPBBUIH4TiRJ19BKWP>EWZ84
UJ6V19FTZ@BFYjd4UZV`19J/]0>F[[L4U[6j19Fc_@BD/kl4T[2k18j[]PB9Y[03QJ>^18BQZ`B5XJX4
QZ:Z18NSZ`B9Y:`4RjJ/0h^TZPB;X:@4RIZM18VHVPB;VI/4SI^M0hnKW0B@W9d4TifM19>JVPBCUYD4
TI2>18n;R0>:Q804QWeh189eL0AnKVP4NVIO17ENEP=dFU44M5M=17ACB0AbCT84LDTl1715=`Ab@c<3
EBdP15@^8PAI=RX4Gchc16A6?0AYCTD3KUI>17=NE`AhIEl4O6eX185dL0B6O7T4RhB15Oooo`005?oo
o`BASXh4TI:B19:EUPBCV9X4U9^N0iFNXPBEXJH4UJBY19JW[@BFZK04UZbd0iJ^]`BF/KX4UK>m19Bc
_`BB/;/4SZ^f18VV/0>5Xjh4Q:6[18FQZPB6XZX4Qj>[18VT[0B;YZ`3RjBZ18^PY0B9VYd4RIRJ18^I
V`B=Vid3Si^L192LW@BCWId4TiZJ19>FU@BAT8h4Sh^80hZ4P0B6OGP4PWE`17i^J0AjIUl4MEiF0gAJ
D@AdEdd4M5=8179>@PAaBC`4L4Dg1793<`=E;B04E2hR15Tf:PAO?S<4I4Hl16U>A@=^ETh4LeiG17QU
G`AlKFP4PGA`18IlN@B;Q84Eoooo000Doooo196>SPBATY84TYFF19>HVPBDVih3UIjR19FQYPBEY:T4
UZN]19JY/0BF[;@3UZjg19Ja^PBE/kd4U;>o19:`^`B>ZkH4RJJ`0hFS[PB4XJ/4QJ6Z18JRZPB7Xj/4
RJB/18^V[0>;Y:X4Rj2T18VJW@B9V9X4RiVK18fKW@>?Vi`4T9bM19>MW@BCVYX4TiJE196@SPB?RhP3
RXB018ImN0B2MG04OViX17YVG`AeGUH3M5YA17AGC@AdDdP4LTi21759?0A`ACL4LT<c0eD]80AD;R84
FCHZ15ln<`ATAS`4JDi50fiFCPAcGUL4N6EO17a]J0B1M704QWai18^4PAGoool001Coool4THn>19:B
TPBCUYL4U9VK19FLW`>EWj<4UZ>W19JUZ`BFZ:l4UZ^b19J]]P>E[kT4UK6l19Bc_`BA/Kd4Sjjj18^X
/`B7Xjd3Pj6[18>OZ@B4WjP4QJ2Y18JRZ@B7XjX4RJB[0hZSZ@B:X:D4R9^N18RGV@B:VIX4S9^L0hjK
W@B@W9d4TifM19>JVPBCUYD4T92>18j;R0>9Pgl4Q7]g181cK`AlKFL4NFIP17IPF0=fG5@4MEQ?17AD
B@AbCd<4LDXm1756>0AdACD3FC4S150Z7@AF<RH4G3X`1693>PAWC4<3K5A<175LE@AfI5h4NfaW181d
K`B5NgP4RX>15Oooo`005?ooo`BAShh4TY:B19>FU`BDVI/4UIbO0iFOX`BFXjL4UZF[19JX[`BFZk84
UZff0iF_^@BE/K`4U;>o196a_@B?[[X4RjRc18NS[@>3XJ/4PinY18BOZ0B5X:T4QZ:Y18NSZPB9Y:/3
RZ>Y18ZPY@B8Vih4R9NI18ZIVPB<Vi`3SY^M192LW@BCWId4TiZJ19>FU@B@T8h4SX^80hV3O`B4NgL4
P7=_17a]I`AiIV04MV1H0gILE0AeF4l4M5A9179?@`AaBSd4LDHh17A5=@=I<B<4D2XM15Hb9PAL>S04
HT<j16M<@`=/E4`4LEaE17ITGPAkK6L4P7A_18EkN0B:Ph4Eoooo000Doooo196?SPBBTY84TiJG19BI
V`BEW9l3UInS19JSY`BFYJ/4UZR_19J[/PBF[KH3UJni19Fa_0BD/kl4TK6m18n^^PB;Z;<4Qj>]0h>Q
Z`B3WjT4Q9nX18FPZ@B6XZT4Qj>Z18VTZ`>:XjT4RZ2U18RKWPB8UiT4RYVJ18bKW0>>Vid4T9bM19>M
W@BCVYX4TiJE192@SPB>RhP3RH=o18AkM`B0Lfl4O6eW17UVH0AfH5P3MUaD17EHC`AdE4T4LTm3175:
?@AaASP4M4De0eTa8`A@:Qd4ES8V15`j<0AR@cX4Ida30faDC0AaG5D4MVAN17]/I`B0M6l4QG]h18Z3
PAGoool001Coool4THn>19:BTPBCUYL4U9VK19FLW`>EWj<4UZ>W19JUZ`BFZ:l4UZ^b19J]]P>E[kT4
UK6l19Bc_`BA/Kd4Sjjj18^X/`B7Xjd3Pj6[18>OZ@B4WjP4QJ2Y18JRZ@B7XjX4RJB[0hZSZ@B:X:D4
R9^N18RGV@B:VIX4S9^L0hjKW@B@W9d4TifM19>JVPBCUYD4T92>18j;R0>9Pgl4Q7]g181cK`AlKFL4
NFIP17IPF0=fG5@4MEQ?17ADB@AbCd<4LDXm1756>0AdACD3FC4S150Z7@AF<RH4G3X`1693>PAWC4<3
K5A<175LE@AfI5h4NfaW181dK`B5NgP4RX>15Oooo`005?ooo`BAShh4TY>C19>FU`BDVY`4UIfP0iJQ
Y@BFY:T4UjN]19NZ/@BG[K@4UZnh0iFa^`BD/[h4T[?0192_^`B=[;L4Qj>^18>PZP>2WjT4PYfW18>N
Y`B4WjL4QJ2X18JQZ0B7XZT3R:6X18VPY@B8Vil4QiNJ18VHVPB;VY/3SYZL192LW@BBWId4TiZJ19:E
U0B?Shd4S8V70hR2O`B3NWD4OW9]17Y/IPAhIV04Mf9J0gINE@AdFE04LeE:175?A0A_BSh4KdHh1755
=P=S>2T4E2/N154/80AI>2d4H44g16E9@@=ZDTX4L5YC17ERG0AjJfD4P7=_18EkN0B:Ph4Eoooo000D
oooo196?SPBBTi<4TiJG19BJW0BEWJ03UZ6U19JTZ@BGYjd4UjZa19N]]0BF[kP3UK6k19Bb_PBB/l04
T:nk18f/]`B7Xjh4Pj2Z0h:OZ@B2WJL4PijW18BOY`B5X:P4QZ6X18NRZ@>8XJP4RJ2U18RKW`B7UiX4
RIRJ18^JV`>>VY`4T9bM19:MW@BCVYX4TYFD18n?S@B<RHL3R89o18=jM@AnLVd4NVaV17QVH0AgHUX3
MUiE17AID0AcEDX4LDm416m:?PA_ASP4LDDf0f<h:@AD:ah4DB`P15Th;@AP@CL4IDU10fYBBPA`FU<4
MF9L17Y[I@B0Lfl4QG]h18Z3PAGoool001Coool4THn>19:CT`BCUYL4U9ZL19FMX0>FXJD4UZBY19NW
[@BGZ[44Ujfd19J_^0>E/K/4U;:n19:c`0B@[k/4SJbg18NS[PB3X:X3PYnY18:MY`B3WZL4Q9nW18FP
Z0B6XJP4Qj:Y0hRQZ0B9X:D4R9^O18NGVPB9V9X4RiZK0hjJW0B@W9d4TYfM19>JVPBBUI@4Shn=18b9
Q`>8PWl4PgYe17ibK@AjK6H4N6IP17MRFP=fGUD4M5U@17=EBPAaCd@4KdXn16m6>0AaACH3HcPY15@[
7PAA;204FCP]1611=`AUBD43JU9:171JD`AeHU`4NV]U181cK`B5NgP4RX>15Oooo`005?ooo`BAShh4
TY>C19BGV0BEVid4UYnR0iNRYPBGYZ/4V:V_19R//`BG[[L4U[6j0iFc_@BC]<04TK?018j^^PB9Y[<4
PYjZ17nMZ0>0W:H4P9bU186LY@B2WJH4PijW18BOY`B5WjL3QYnV18NNX`B6VYl4QYNK18RHVPB:VI/3
SIVK192LW0BBW9d4TiZI196DT`B>SX`4RXN50hJ0O@B0N7@4O71[17U[I@AgIV04Mf=K0gIOEPAdFU44
LUE:171?A0A]BSh4Jd@g16U1=0=T>R/4Fc0R15@^8@AI=R/4GSle16A8?`=YD4P4KUUB17AQF`AiJF@4
Og9^18AjM`B:Ph0Eoooo000Doooo196?SPBBTi<4U9NH19FKW@BFWj83Uj:V19NVZ`BHZJl4V:bc19N^
]`BF/KX3UK>m19>d`0BA/l04SZjj18VV/`B2WZX4OifX0h2LYPB0W:D4PIbU18:MYPB3WZL4Q9nW18FO
Y`>6WjH4QijS18JJW`B6Ui/4R9RJ18ZIV`>=VI/4T9bL19:LW@BCVYT4TIBC18j>S0B:QhD3QX1m181h
M0AlL6/4NF]U17MVH0AgHe/3MUmF17AJD@AbEDX4L4m416e:?PA[A3L4JD4d0f@j:`AK<284E2hQ15Tf
:`AN?cD4I4Po0fU@B0A^FE84M65K17UYI0AoLVh4Q7Yg18Z3P1Goool001Coool4THn>19:CT`BDUiP4
UI^M19JOXP>GXZH4UjJ[19RY[`BH[;<4Ujjg19Ja^P>E/kd4TkC0196c`0B>[[X4RJJc18:NZPAoWJP3
P9bV182LY@B1W:D4PYfV18>NY`B4WjL4QInW0hJOYPB7WZ<4QYZO18JGV`B8V9X4RYVK0hfIV`B@W9`4
TYbM19>JV@BAU9<4SXj<18Z7Q@>6P7d4P7Qd17a`J`AiJfD4MfIP17MSF`=fGeH4M5YA179EBPA`Cd@4
KDXn16]4=`AY@C@3I3X[15/`8PAD;R44FCH[15ho=@ATB3l3JE1816iIDPAdHE/4NFUT17mbKPB4NWL4
RX>05Oooo`005?ooo`BAShh4TY>C19BGV0BEVid4UYnR0iNRYPBGYZ/4V:V_19R//`BG[[L4U[6j0iFc
_@BC]<04TK?018j^^PB9Y[<4PYjZ17nMZ0>0W:H4P9bU186LY@B2WJH4PijW18BOY`B5WjL3QYnV18NN
X`B6VYl4QYNK18RHVPB:VI/3SIVK192LW0BBW9d4TiZI196DT`B>SX`4RXN50hJ0O@B0N7@4O71[17U[
I@AgIV04Mf=K0gIOEPAdFU44LUE:171?A0A]BSh4Jd@g16U1=0=T>R/4Fc0R15@^8@AI=R/4GSle16A8
?`=YD4P4KUUB17AQF`AiJF@4Og9^18AjM`B:Ph0Eoooo000Doooo196?S`BCU9@4UIRI19JLWPBGX:<3
V:BX19VW[@BIZk44VJje19Ra^@BG/kd3U[G019>g``B@]<04Rjbi18BQ[@AoVZH4O9ZU0gfJY@AnVj@4
Oi^T186LY@R2WJD4PifU0hBLX`B4Vj44QIRM18FFVPB7UiX4RYVK0hbJV`B?W9d4TibM19>IV@BATi<4
SHf<18R6Q0>4Og`4OgMc17]`J`AiJfD4MfMP17MSG0=eGeL4LeYA171EB`A^Cd@4JdTm16M2=PAT?c83
GSHX15L/7PAF<2<4FCHZ15dm<`ARASd3Idi616eGD0AbH5X4N6QS17iaK@B4NWH4RX:05Oooo`005?oo
o`BAShl4TiBD19FHV@BFW9h4Uj2S0iRTZ0BIYjd4VJ^a19V^]@BH/KT4Uk>m0iJe`0BC]l<4T;C018^/
^@B4XJd4OiZV17bJY@=mVZD4OY^T17nKY0B1W:D8PYfU18>MY@>4W:<4Q9^Q18FHW@B5UYX4QiNJ18ZI
V`><VY/4SibM19>LW@BCVIT4TI>C18f=S0B8QX@3Q7ml17mgL`AkL6/4NF]U17MWH0AgHe`3MEmG17=J
D@A`ED/4KTm416]9?@AW@SH4I3lb0ehf:0AG;1h4ES0S15Tf:PAM?C<4HTHm0fM>APA]Ee04LV1J17QX
H`AnLFd4Q7Yf18Z2P1Goool001Coool4THn?19>DU0BEV9T4UYbN19NPX`>HY:P4VJN]19V[/@BI[[D4
V;6i19Nc_@>F]L04TkO3192d`0B;[;T4Q:6]17nJYPAlVZD3OIZU17jKY0AoVj@4PIbU28:MY@B3WJD3
Q9bS18BKX@B5V9d4QIJJ18NGVPB:VI/3S9ZK18nLW@BCW9d4TiVI196CT`B=SH`4R8J40hAoO0AoMg<4
Ng1[17U[I@AgIf04Mf=L0gEOE`AcFU44L5E;16i?A0A[BCd4Id8f16@o<P=N=RP4Eb`N15H`8`AI=RX4
GCdc1696?@=WCTH4KEM@179PFPAhJ6<4OW5]18AjMPB:PX0Eoooo000Doooo196?S`BCU9@4UIRI19JL
WPBGX:<3V:BX19VW[@BIZk44VJje19Ra^@BG/kd3U[G019>g``B@]<04Rjbi18BQ[@AoVZH4O9ZU0gfJ
Y@AnVj@4Oi^T186LY@R2WJD4PifU0hBLX`B4Vj44QIRM18FFVPB7UiX4RYVK0hbJV`B?W9d4TibM19>I
V@BATi<4SHf<18R6Q0>4Og`4OgMc17]`J`AiJfD4MfMP17MSG0=eGeL4LeYA171EB`A^Cd@4JdTm16M2
=PAT?c83GSHX15L/7PAF<2<4FCHZ15dm<`ARASd3Idi616eGD0AbH5X4N6QS17iaK@B4NWH4RX:05Ooo
o`005?ooo`BBT8l4U9BE19FIVPBGWJ04V::U0iZVZPBJZJl4Vjfd19^`^0BJ/k`4VKK00iNh``BC^<@4
Sk>o18RY]@AoW:T4NINS17VGXP=jV:84O9VS17jJY0AoVj@4P9bT186LY0B1Vj<3PYVQ186HWPB2UIX4
PYBH18FEV0B8UiX3RiVK18nLW@BBW9d4TiVI192CTPB=S8/4R8F20h9mNPAmMW84NW1[17Q[I@AgIf44
MV=L0gAOE`AaFe44KUE;16a>A0AXB3d4I44e164m<@=K=2H4EB/M15@/80AG<bP4Fc/a1614>`=UC4D4
JeE>175NF0AgIf84OG1/18=iMPB9PX0Eoooo000Doooo19:@S`BDU9D4UIVJ19NMX0BHXZD3VZJZ19ZY
[`BK[K@4Vk2h19Zc_0BI]/03UkS319>ha0B?/kl4R:Ve17nLZ@AiUj<4NINR0gZHXPAlVJ<4OYZT17nK
Y0B0W:@4PIbT186KX`>2VJ44PIRN18:EVPB2U9P4QIFH18RGVP>;VI/4SibM19:LW@BCVIT4T9>B18f<
R`B8QH83PWej17efLPAjL6/4N6]U17MWH@AfHe`3M5mG175KD@A^ED/4K4i416Q8?@AT@CD4HCda0e/d
9PAE:ad4E2`P15Lc:0AK>c44H4@k0fE<A@A[EDh4LEiH17MWHPAmL6`4PgUf18V2P1Goool001Coool4
TY2?19BDU@BEVIX4UifP19RRY@>JYZX4VZV_19^]]0BK/;P4V[>l19Vf`0>G^<<4TkS418nc_`B8ZKD4
OibY17VGX`AiUj83NYRR17bIX`AnVZ@4Oi^T182LY0B1W:@4PI^S0h:IX@B1V9h4PYFJ18:DV0B5UIP4
R9NJ0h^IV`B?W9d4TYbM19>IV@B@Ti84SHb;18R5PP>2OGX4OGIb17Y`J`AhJfD4MfMQ17ISG0=dGeL4
LE]A16iEB`A/CT@4J4Pm16A1=@AQ?C43Fc@V15D[7@AD;204Ec<X15/k<@APA3/3IDa516]ECPAaGUP4
MfMR17e`K0B3NGH4RH:05Oooo`005?ooo`BBT8l4U9BE19FIVPBGWJ04V::U0iZVZPBJZJl4Vjfd19^`
^0BJ/k`4VKK00iNh``BC^<@4Sk>o18RY]@AoW:T4NINS17VGXP=jV:84O9VS17jJY0AoVj@4P9bT186L
Y0B1Vj<3PYVQ186HWPB2UIX4PYBH18FEV0B8UiX3RiVK18nLW@BBW9d4TiVI192CTPB=S8/4R8F20h9m
NPAmMW84NW1[17Q[I@AgIf44MV=L0gAOE`AaFe44KUE;16a>A0AXB3d4I44e164m<@=K=2H4EB/M15@/
80AG<bP4Fc/a1614>`=UC4D4JeE>175NF0AgIf84OG1/18=iMPB9PX0Eoooo000Doooo19:@S`BDUID4
UYZK19ROX@BJXjL3VjR/19b//@BM/;H4WK>k19bf_`BK^L@3V[c819Fha0B=[k`4PJ>`17JGY0AdTj04
MIBP0gRFX@AjUj84O9VS17jKY0B0Vj@4Oi^S182JX@=oUil4OiFL17nCV0B0TYH4Pi>G18JFV0>:V9X4
SYbM19:LW@BCVIP4T9>B18b;RPB7Ph43PWai17efLPAjL6/4Mf]V17IWH@AdHe`3LemG171JD@A]ED/4
JTi416I7?@AQ@CD4GCda0ePa9@AC;1h4D2LK15@`9@AH>Bl4GT4i0f=:@`AYE4d4KeeG17EVH@AlKf/4
PWQe18V2OaGoool001Coool4TY2?19BEU@BFVY/4V9nQ19ZSY`>KZ:`4W:ba19f`]PBM/k/4W;Jo19^i
a0>J_<P4UKS418f__0B1Xk04MYNT17BCX0AeU:03N9JQ17ZGXPAlVJ<4OY^T182KY0AoVj<4P9ZQ0gnG
W`AoUI`4Oi>H182BUPB3TiL4QYJH0hZHVPB>W9d4TYbM19>IV0B@Ti84S8^:18N3P@>2O7T4OGIb17Y`
J`AgJfH4MVMQ17ASG0=cGeL4L5YA16eEB`AZCT@4ITLm1651=@AM?C43F34U15</7PA@9a/4E30U15Pi
;`AN@CT3HdY316UDC@A_GEL4MFIQ17a_J`B2N7D4RH9o5Oooo`005?ooo`BBT8l4U9FE19JJV`BHWj44
VZ>W0i^X[0BL[;44WK2f19fc^`BL][l4VkW40iZlb0BE^<@4SJnl186S/0AfUj@4M9>P17FDX0=hUZ44
NYNR17bIX`AnVj@4P9^T17nKX`B0VZ43OiNO17nEW0AoTiP4P9:F18>CU`B6UYP3RYRJ18jLW@BBW9d4
TiVH192CTPB<RhX4Qh>10h9lN@AmMW84NW1[17M[IPAfIf44M6=L0g=OE`A`FU44KEE;16Y>A0AVAcd4
HD4e15dm<@=H<BD4Db`N150W6`AD<2D4F3T_15i1>@=SBT<4JEA=16mME`AeIV44O6m[189hM@B9PWlE
oooo000Doooo19:@S`BDUID4UYZK19ROX@BJXjL3VjR/19b//@BM/;H4WK>k19bf_`BK^L@3V[c819Fh
a0B=[k`4PJ>`17JGY0AdTj04MIBP0gRFX@AjUj84O9VS17jKY0B0Vj@4Oi^S182JX@=oUil4OiFL17nC
V0B0TYH4Pi>G18JFV0>:V9X4SYbM19:LW@BCVIP4T9>B18b;RPB7Ph43PWai17efLPAjL6/4Mf]V17IW
H@AdHe`3LemG171JD@A]ED/4JTi416I7?@AQ@CD4GCda0ePa9@AC;1h4D2LK15@`9@AH>Bl4GT4i0f=:
@`AYE4d4KeeG17EVH@AlKf/4PWQe18V2OaGoool001Coool4TY2@19FFUPBHVi`4VZ2S19bUZ@>NZZh4
Wjjd1:2b^@BP][h4WkW319jmb0>N`<d4V[[618b/^@AlWZ`4KI2O16j?W@AaTIh3M9BP17RFX@AkVJ<4
OIZT17nKX`AoVj84OYVQ0gfFW@AlTIT4NhnE17f?U0B0T9@4Q9>F0hVGVPB>Vi`4TYbM19>IV0B@TY84
S8^918J3P0>2O7T4OGIb17Y`J`AgJfH4MFIQ179RF`=aGUH4KUU@16]DBPAXCT@4I4Pm15m1=PAK?383
E34U14l[7PA<8aL4D2dR15Df;0AK?cH3HDQ116MBB`A]FeH4M6EP17]^JPB2N7D4RH5o5Oooo`005?oo
o`BBT904UIJF19RKW0BJX:<4W:FY0ijZ[PBO[[@4X;:i1:2f_PBO^L<4W[g80ik0c@BJ^/H4S:bi17bN
[0A]T9l4KXnM176AWP=dU:04N9JQ17^IX`AmVZ@4Oi^S17nKXPAnVJ43OIJM17bAV@AkSiD4OHnD182@
U0B4TiH3RINJ18jKW0BBW9d4TiVH192BTPB<RhT4QX>00h9lN@AmMW84NW1[17M[IPAeIV44LV9K0g5N
EPA^FE04JeA:16Q>A0ATB3d4Gd4f15/l<P=D<BD4Cb/N14`S5`A@;B84ECH/15/o=P=QB444Ie9;16eK
EPAdIF04NfiZ189hM@B9PGlEoooo000Doooo19:@T0BEUYH4V9^L19ZPX`BLYJT3WZZ^19n^]0BP/[T4
X;Jn19ni``BN_LP3W/3=19ZjaPB<[;T4O9j/16f@W`A^Sid4LI6N0gBDX0AhUZ44NiVS17fJY0AoVj<4
Oi^R17jIX@=mUYd4O96I17^?U@AmSi@4P92D18BCUP>9UiX4SY^L19:LW@BCVIP4T9:B18b;R@B6Ph03
PWai17efLPAjL6/4Mf]V17EVH@AbHU/3LEiF16iID0A[E4X4J4i416A8?@AO@CH4Fc`b0e@a9@A?:ah4
C2<G150]8PAE=R`4Fclf0f58@@AWDT/4KE]F17AUH0AkKVX4PWQe18V1OaGoool001Coool4Ti6@19JG
U`BIW9h4W::T19jXZ`>Q[K44X[6g1:>f_0BS^L44X[g61:;0b`>Q`ll4Wkc818f/^0AiVjT4IH^K16R;
VPA]Si`3LI:N17JEX@AkVJ<4OIZS17nKY0AnVZ44O9RO0gVDW0AgSiL4MhbC17V;T0AlS904PY6D0hRF
V@B>Vi`4TYbM19>IV@B@Ti84SH^918J3P@>2O7T4OWMc17U`K0AfJfD4M6IQ175QFP=_GEH4KEQ@16YC
BPAVCT@4HTPm15i2=`AJ?C83D34U14TV6PA77a<4C2TO158c:@AG?C@3GTHo16A@B@A[FU@4LV=O17U]
J@B1Mg@4R85o5Oooo`005?ooo`BCTI04UYNG19VLWPBLXZ@4WZR[0j6]/@BR/KL4XkJl1:>i`@BR_LH4
X/3;0j73c`BO_<P4SJbh17VKZ@AURi/4J8^J16f?W0=aTYh4MYFQ17^IX`AmVZ<4Oi^T17jJX@AlV9l3
NIBL17N?U`AgS9<4NH^@17b<T0B2TI@3R9JI18jKW0BBW9d4TiVI192CTPB=RhT4QX>10h9lN@AnMg<4
NG1/17I[I@AdIV44LF5J0fmMEPA]F504JU=:16I>A0ARB3d4GT8g15Xm<P=@<BD4BBHJ14LO4`A<:Al4
DS<Y15Lm=0=NASl4I51916]JE0AbHel4NFeY185gM0B8PGlEoooo000Doooo19>AT0BFUiL4VIbN19bR
Y0BNZ:/3XJfa1::a]`BS][`4XkW11::maPBR`</3XL??19nlb0B=[;P4NI^Y16F;V`AXRiX4KHnL0g6B
WPAfUJ44NiVS17fJX`AoVj@4OYZQ17bHW`=iU9`4MhnG17N<T`AiRi04O8b@18:AU0>8UYT4SY^L19:L
W@BCVIT4T9>B18f;R@B6Ph43PWai17igL`AiL6`4MV]U17AVH@AaHEX3KeeF16eHD0AZDdX4ITi41698
?@AN@SL4FSdb0e0a9@A99QX4AalC14`Y7`AB<bT4Ecdd0ei6?`ATD4T4JeYD179SG`AiKFT4PGMd18R1
OaGoool001Coool4Ti6@19JGU`BIW9h4W::T19jXZ`>Q[K44X[6g1:>f_0BS^L44X[g61:;0b`>Q`ll4
Wkc818f/^0AiVjT4IH^K16R;VPA]Si`3LI:N17JEX@AkVJ<4OIZS17nKY0AnVZ44O9RO0gVDW0AgSiL4
MhbC17V;T0AlS904PY6D0hRFV@B>Vi`4TYbM19>IV@B@Ti84SH^918J3P@>2O7T4OWMc17U`K0AfJfD4
M6IQ175QFP=_GEH4KEQ@16YCBPAVCT@4HTPm15i2=`AJ?C83D34U14TV6PA77a<4C2TO158c:@AG?C@3
GTHo16A@B@A[FU@4LV=O17U]J@B1Mg@4R85o5Oooo`005?ooo`BCTI44UiRH19^NW`BNY:H4XJZ]0jB`
]0BV]KX4Yk[01:Nma@BV`<T4Y<?>0j?2c@BP_LP4S:Zg17BGYPANQYL4HhRH16V<VP=^Si`4M9BP17^I
X`AoW:D4PYjV18:LY0AmV:03MY>K17>=U@AdRi84MHR>17N7S0B0SY43QiFG18jKW@BCWIh4U9ZJ19:D
T`B>SHX4R8B10hAnNPB0N7@4NW5]17I[IPAcIF04KV1J0feLE@A[F504JE=:16E>A0APB3d4GD8h15Tn
<`=><BH4A2<I144L40A79Q`4CS0W15@j<P=KA3d4HTi816UHD`AaHUh4N6aY181gM0B8PGlEoooo000D
oooo19>AT@BGV9P4VijO19jTYPBQZZd3Y;2d1:Je^PBW^/04Ykg51:K0b@BT`lh3Xl;=1:2mb0B<Z[L4
M9NV15j6U`ASR9P4JHbJ0fj?W0AdU:04NiVS17nLY@B2WZH4PYbT17fHX0=fTi/4LhfE17B;TPAeR8h4
MhN<182>T@>7UIL4SY^M19>MWPBDVYX4TYBC18j=RPB8Q843Q7ij181hM0AjLFd4MV]V17=UH0A^H5X3
KEaE16]HD0AYDdX4IDi41618?@AM@SP4FChc0dha9PA48aT4@A`@14LV70A><2L4E3Xb0e]4?@ARCTP4
JEQC175RGPAhK6T4P7Md18R1OaGoool001Coool4Ti6A19NHV0BKWYl4WZBV1:6Z[@>T/;@4Y[Fj1:Nj
`0BW_LD4Y/391:C3cP>S`/d4X;g818bZ]`AdUjH4GXJG16>8V0AYS9X3KXnL17BDX0AkVJ<4OibU18:N
YPB2W:@4OIRP0gJCV`AcSID4M8^B17F8SPAgQh`4P8jA0hNEU`B>Vid4TifN19BJVPBBU9<4SXf:18R4
P@>4OWX4P7Qd17YaK@AfJfH4LfEP16iPFP=]G5D4JeQ@16UCBPAUCT@4H4Pm15e2>0AI?S<3CS4V14@S
6@A17104AbHL14h`9`AD>S83Fd@m169>B0AYF5<4LF9N17Q/J@B0Mg@4R85o5Oooo`005?ooo`BCTI44
UiRH19^NW`BNY:H4XJZ]0jB`]0BV]KX4Yk[01:Nma@BV`<T4Y<?>0j?2c@BP_LP4S:Zg17BGYPANQYL4
HhRH16V<VP=^Si`4M9BP17^IX`AoW:D4PYjV18:LY0AmV:03MY>K17>=U@AdRi84MHR>17N7S0B0SY43
QiFG18jKW@BCWIh4U9ZJ19:DT`B>SHX4R8B10hAnNPB0N7@4NW5]17I[IPAcIF04KV1J0feLE@A[F504
JE=:16E>A0APB3d4GD8h15Tn<`=><BH4A2<I144L40A79Q`4CS0W15@j<P=KA3d4HTi816UHD`AaHUh4
N6aY181gM0B8PGlEoooo000Doooo19BBT@BHVIT4WInQ1:6VZ0BT[K03Z;>g1:^i_PB/_/D4[<;:1:[4
c@BUa<l3Xl7;1::laPB;ZKD4L9BT15V2U0AOQIH4IHZH0f^=V`AaTYh4N9RR182MYPB4WjL4RJ6X18>L
X`=iU9d4LhfE17:<T`AdRHl4MhN<17n=T0>7U9L4SY^M19BNW`BFVi/4U9FD19:@S@B8Ph43QWml189j
M@AkLVh4M6YU175TG`A/GUT3JUYD16UGC`AXDdX4I4e41618?PAM@cP4Ecdb0dT^90@n8AL4?1T?14<S
6PA9;BD4D3L`0eM2>`AOC4H4IeIA16mQG@AgJfP4OgIc18N1OQGoool001Coool4U9:A19RIV@BMWj44
XJJX1:B]/0>X/kL4ZkVn1:bna@B/`/X4Z/C=1:G4c`>S`L/4X[c618^Y]@A`U:@4FH:D15n5UPAURYP3
JhfK176BWPAhV:84P9fV18BOY`B9XJP4PibS0gVDW@AcSID4LXbC17B9S`AgQh`4Ohf@0hNDU`B>Vid4
U9jO19JKV`BDUI@4TY2=18R3P@>6Og`4PWYe17]bKPAdJVD4LFAO16aNF@=ZFU@4JEM?16QCBPATCD@4
H4Pn15e3>0AG?C83BBhT13hQ5`@l6@l4@b<J14T]9@A@=c03Ed8k15m<APAWEU44Kf5M17M[J0AoMW<4
Qh5n5Oooo`005?ooo`BDTY44V9VI19fOX@BQYZP4Y:f`0jRc]`B[^Kh4[;k51:c2bPBZa<d4YLC?0j?1
b`BR_<H4RjVe172DY0AIPY@4GhFF16F:V0=[SI/4LI:N17RHXPB0WJH4Q9nW18VQZ0B3W:<3NIBM17>=
U@AbS9<4M8V?17N7S0AoSI03QiBG18jKW@BDWYl4UY^K19BEU0BBT8d4R8>10hIoO0B2NWD4Ng9^17AZ
I@AaI5l4K5iI0fYJE0AYEdl4J5=:16A=A0APB3h4GD<h15Lm<P=9;R@4?R4G13`I3`A38aX4BBdU150g
<0=G@S/4Gda616MFD@A_HEd4Mf]X17mfL`B7PGhEoooo000Doooo19BBT@BHVIT4WInQ1:6VZ0BT[K03
Z;>g1:^i_PB/_/D4[<;:1:[4c@BUa<l3Xl7;1::laPB;ZKD4L9BT15V2U0AOQIH4IHZH0f^=V`AaTYh4
N9RR182MYPB4WjL4RJ6X18>LX`=iU9d4LhfE17:<T`AdRHl4MhN<17n=T0>7U9L4SY^M19BNW`BFVi/4
U9FD19:@S@B8Ph43QWml189jM@AkLVh4M6YU175TG`A/GUT3JUYD16UGC`AXDdX4I4e41618?PAM@cP4
Ecdb0dT^90@n8AL4?1T?14<S6PA9;BD4D3L`0eM2>`AOC4H4IeIA16mQG@AgJfP4OgIc18N1OQGoool0
01Coool4UI:A19ZIVPBOXJ84XjRZ1:R`/`>/]k/4/;k31;?4bPBdbM04/L[C1:6ob`>P_<L4WKO218VW
/`A/TZ84E7jA15Z2T`AQQiH3J8bI16j@W0AeU9l4O9ZT186MYPB8X:P4QIjU0gnHX0AhT9P4LhbC17B9
S`AiRHh4OhfA0hNDU`B?Vid4UIjO19RMW@BGV9H4UYB@18j7Q0>=Q804R7ii17]cK`AeJfH4LFEP16UM
F0=XFE<4IeE>16QBB@AUCT@4HDTo15i4>@AE?343@b/R13HM50@f5Pd4?R0H14@Z8`A<=Bh3Dcli15a:
A0ATEE04KEmK17EZI`AnMG84Qh1n5Oooo`005?ooo`BETY44VYVJ19nQXPBSZ:X4Z;2c0jbg^`B`_/<4
/lC:1;C9d0Bab]<4XKo;0j2la`BM]l84RJNc16bBXPADOY44FX:C1667UP=XS9T4KY2L17FDW`AlVZ@4
PIfV18RPZ0B5WZD3OiRP17R@V0AcS9<4M8V?17V9SPAoSI43QiBG18nKW@BEWYl4V9fM19NHUPBFU904
SXN40hf4P0B8OWT4Ng=_17E[IPAaIF04JEeH0fQID`AWEDh4J59916E>A0AQBCl4GT@i15Dl<@=3:b84
=QdD13HF3@@n81P4A2XS14`e;P=C?cT4G4Y416AED0A]Ge/4MFYW17ieLPB7P7hEoooo000Doooo19FB
T@BJVIX4Wj6R1:>XZPBX/;<3[;Nk1;2n``Bca<X4]<W@1;7:d`BQ_l/3X;c719fg`PB9Yk<4K9:R15An
T@AJPY<4HHNF0fR<V@A^T9`4MIBO17bJY0B1WJH4R:2X18FNY@=oV:04N92H17><T`AdRHl4NHV>17n=
T@>7U9L4Si^M19FNW`BHWId4UiRF19JDT0B>Qh@3SHB018QnN@AkLfl4MF]V175UH0AYGEP3J5UC16ME
CPAXDTT4IDi41659?`ANA3T4EC`a0d<[8P@f7A@4=QH=13hP60A4:R<4C3D^0e<o>@ALBT@4I5E@16eO
F`AeJVL4OWEb18N0OQGoool001Coool4UI:A19ZIVPBOXJ84XjRZ1:R`/`>/]k/4/;k31;?4bPBdbM04
/L[C1:6ob`>P_<L4WKO218VW/`A/TZ84E7jA15Z2T`AQQiH3J8bI16j@W0AeU9l4O9ZT186MYPB8X:P4
QIjU0gnHX0AhT9P4LhbC17B9S`AiRHh4OhfA0hNDU`B?Vid4UIjO19RMW@BGV9H4UYB@18j7Q0>=Q804
R7ii17]cK`AeJfH4LFEP16UMF0=XFE<4IeE>16QBB@AUCT@4HDTo15i4>@AE?343@b/R13HM50@f5Pd4
?R0H14@Z8`A<=Bh3Dcli15a:A0ATEE04KEmK17EZI`AnMG84Qh1n5Oooo`005?ooo`BETi84Vi^K1:6S
Y0BVZjd4[;>f0k6l_`Bga<P4_<cA1<7DfPBid=P4Y<3;0iZf`PBE/K`4PZ6_16R?W`A@Nhh4Eh2A15j5
U0=VRiT4K8fJ176AW0AhUZ04OI^T186MY@B1Vj@3OINO17VBVPAeS9@4MX^A17Z;T0B0SY83R9FH18nK
WPBEWYl4V9jN19RIU`BFU904Thb70iB9Q0BCQWl4P7Mb17Y^J@AfJF@4JemJ0fUKE@AXETl4JE=:16M?
APASBd44HDLk15<j<0<o:B44;aTA130B2@@g7AD4?bLP14La:`=??3L4F4Q3165CCPAZGUX4M6UV17ee
LPB6P7hEoooo000Doooo19FCTPBKVi/4XJ>T1:J[[@B//kH3/Kbo1;O4b0Blc=44`MCJ1;W@f0BT`</3
V[K219Fa_0B2XJl4J8nO151kSPAGP944GXFD0fJ;V@A/SIX4LI6L17RFX0AmVj@4PIfU186KY0=mUil4
NI:J17F<U0AfRi44NX^@182>TP>8UIP4Si^N19FNW`BHWYh4V9VG19JDT0BCS8L3U8V419>6O`B0Mg84
NViY17IYI0A[GeX3JE]E16QFC`AYDdX4Idm616=;@@AQAc/4DcX`0clY8@@_6A44<18913LM5@@o9b04
Ac4[0dll=`AHB4<4HE=>16YNFPAdJFH4OGEb18J0OQGoool001Coool4UI>B19^KV`BQXj@4YZ^]1:bc
]P>a_;l4]lC81;c<d@C1e=X4^M3H1:C0b`>J]/84UK6l18:Q[`AXSil4D7^>15N0T@ANQI@3IX^I16b=
VPAaTI`4N9JP17fKY0B1WJD4PI^T0gfGW`AiTYX4MHbD17J;T@AjRi04P8jB0hREV0B?Vih4UIjO19RN
WPBHVIL4UYB@19><Q`>DRH@4ThIo181gLPAjKVT4MVUT16]OFP=YFeD4J5I?16UCBPAWCdH4Hd]11657
>`AC>S03?bTQ12lI4@@`4PT4=adE13lW80A7<B/3Cc`g15Q8@`AQDdh4JUiJ17AYIPAmMG84QX1n5Ooo
o`005?ooo`BETi84Vi^K1:6SY0BVZjd4[;>f0k6l_`Bga<P4_<cA1<7DfPBid=P4Y<3;0iZf`PBE/K`4
PZ6_16R?W`A@Nhh4Eh2A15j5U0=VRiT4K8fJ176AW0AhUZ04OI^T186MY@B1Vj@3OINO17VBVPAeS9@4
MX^A17Z;T0B0SY83R9FH18nKWPBEWYl4V9jN19RIU`BFU904Thb70iB9Q0BCQWl4P7Mb17Y^J@AfJF@4
JemJ0fUKE@AXETl4JE=:16M?APASBd44HDLk15<j<0<o:B44;aTA130B2@@g7AD4?bLP14La:`=??3L4
F4Q3165CCPAZGUX4M6UV17eeLPB6P7hEoooo000Doooo19JDT`BLW9`4XjFV1:V^[`B`]kT3]l331;k:
cPC6e=T4d>7V1;oCf`B^am03WKS319:^^@AkWJ/4I8bL14eiS@ADOHl4Fh:B0fB9UPA[SIX4L92K17BB
W@AiUZ04O9VR17bHX@=jU9d4Mi6I17F=U0AeRY04NhbB186@U0>8UYT4T9^M19JMW`BIWYh4VIVH19JC
T@BCSHP3ThZ419B7P0B9OGL4PWE_17]]I`AaHed3KEiG16aID@A[ETd4JU5816M=@`ATBCh4D3T_0c/X
80@[6A44:@h6134H4@@i8ad4@RhY0d/j=@AEAD44GU5=16QMF@AbJ6D4O7Aa18IoOAGoool001Coool4
UYBC19bLW0BSYJH4ZJj_1;2g^@>g`<<4_/[>1<KDf@C@hNH4_m?K1:k7d0>M^<<4TZji17^MZ`ATS9`4
CGV=15AmS`AKPY83I8VF16^=VPA`T9/4M9:M17VFX0AlVJ84O9RQ0gZDW@AgTIT4MHfD17F:T0AkS984
PI2D0hRFV@B@Vid4UYfO19VNWPBIVIP4UY>A19>=R0>CRX@4U8N018UmM`B2MFl4NfeW175SG@=]GUL4
K5UA16]FC@AZDDP4Ide316A9?PA@>Bl3>bPP12/I4@@Y3PH4<APA13TS7@A2;RT3BcXe15E5@@ANDDd4
J5eI179XI@AlM744QWmm5Oooo`005?ooo`BFU9<4W9bL1:>UYPBY[Zl4/;Ni0kO0``Bnb/h4a]CI1=3Q
iPBodm/4[/O@0ifh``BB[[T4Nif[16B<W0A=NHd4E7f?15^2TP=TRIH4JhfJ172@V`AdTYd4NIJP17bI
XPAlV:43NYBM17NAV@AeSI@4MHZ@17^<TPB1T9@3R9JI192KW@BFWIl4VIjN19VIV0BFTi44Thf80i>:
Q0BDQh04RGeg189eK`AkKFL4LF=M0feNE`A/FE44JeI=16YAB0AWCD<4I4Tn150i;`<k:204:aTA12T>
1P@a6144>B<M148^:@=;>SD4EDE115iAC@AXGET4LVQU17adL@B6OgdEoooo000Doooo19NDT`BNWId4
YJNW1:b`/@Bd^[`3^lC71<C?dPC=f]h4f>S/1<OIg`Beb]83X[_5192]^@AhVjX4H8VJ14aiS0A@Nh`4
F7n?0f25TPAXRiP4Ki2L17BCWPAiUIl4NYNQ17bHX@=kUIl4NI>L17R?U`AhS9<4O8nD18:CU`>9UiX4
T9^M19JMWPBIWYh4Vi^J19NCTPBBS8T3THR318j3OPB9OGL4Q7Ma17i_J@AeIf03LV5J171LE0A^F4l4
K5A:16a@A@AVBSl4CSP_0cDU7`@[6Q<490/512XD3P@b7aT4?2/V0dHg<PAA@cl4Fdm;16IKF0A`If@4
Ng=a18EoOAGoool001Coool4UiBC19jMW@BUYjL4[;2a1;Bj_0>ka<L4a<oB1<gJgPCHj>`4amWO1;G:
dP>R^lD4T:fi17RKZPAPRIX4C7V<151kS0AHOhl3H8FB16R;V0A_T9`4M9>N17VEW`AjUj44O9RQ0g^E
W`AiTi`4N8nG17R<T`AlSi@4PY>G0hVGVPB@Vid4UYfN19VNWPBKViX4Ui>B19:<R@>AR8<4SX=n18Um
M`B4Mg44OVmY17EWH0=bHEX4L5aD16iHC`A/E4X4K51516I:?`A>>2l3=BDO12/J4`@T2`D4:Q@>138O
6@@l:bH3ASLb1553?`AKCd/4IU]H171WI0AkLg44QGmm5Oooo`005?ooo`BGU9<4WYfM1:FWY`B//;44
];Zl0k_4a`C4cm84cM[N1=SXk0C7fMl4]L[B0j:ka@B@[KT4N9^Z1629VPA<NH`4D7^<15QoS`=PQI84
J8^H16n@W0AdTih4NIFO17ZGX@AlV:43NiFO17VCW0AhSiL4N8bC17b?U0B2TiL3RINJ192KW@BFWIh4
VIjN19^KVPBGTi84TXb90i68P`B>Pgh4RGeg18AgL@AnKfT4MFMP0g9QFPA`G5@4KUQ?16aDBPA/D4D4
ITXo14hh;`<e9Al4:aXC12@;1@@Z50h4<QlI13`[9P=6=c84DD<o15]?B`AVFeP4L6MT17]cL@B5OgdE
oooo000Doooo19NDT`BNWId4YJNW1:b`/@Bd^[`3^lC71<C?dPC=f]h4f>S/1<OIg`Beb]83X[_5192]
^@AhVjX4H8VJ14aiS0A@Nh`4F7n?0f25TPAXRiP4Ki2L17BCWPAiUIl4NYNQ17bHX@=kUIl4NI>L17R?
U`AhS9<4O8nD18:CU`>9UiX4T9^M19JMWPBIWYh4Vi^J19NCTPBBS8T3THR318j3OPB9OGL4Q7Ma17i_
J@AeIf03LV5J171LE0A^F4l4K5A:16a@A@AVBSl4CSP_0cDU7`@[6Q<490/512XD3P@b7aT4?2/V0dHg
<PAA@cl4Fdm;16IKF0A`If@4Ng=a18EoOAGoool001Coool4UiFD19nNWPBWZ:T4[k:c1;Nl_P?0alX4
bM?F1=?Oh`CNk?04cmoT1;_>eP>V_/P4TJjj17RKZ@AOR9T4C7V<14ehR@ADO8/3G86>16>6T`A[RiL4
LI6K17JCW@AgUIh4NYJP0g^EW`AkUId4NY:J17^@U`AnTIL4Q9FI0hVHV`B?VY`4UIbM19VNW@BMWI`4
W9RF19J?S0>AR8D4RX5m18IkMPB3MW44Og1Z17UYH`=fI5`4LemF175JD@A`Edd4LEA916E9?PA<=bh3
<B@N12XJ50@Q2`D47P/712XI5@@f9b<3@C@`14e1?@AHCDX4I5YG16mVI0AjLg04QGmm5Oooo`005?oo
o`BGUI@4WijN1:NXZ@B_/[<4]kbn0l37bPC9dmH4dmoS1=k/l0C?gn@4^lkF0jJnb0BA[[X4N9^Y15n8
V@A<NH`4CGR915AlR`=LPHh4HhJC16^;U`AaTI/4MY>M17NEWPAjUZ03NiFO17^EW@AjTYX4Ni2G17jA
U`B4UIT3RIRK18nJW0BEW9d4VIjM19fMW0BLV9H4UXn<0i68Q@B:PGd4QW]f18=fL@AoL6X4NFUS0gIT
G0AcGeH4LEYA171GC@AaE4T4IDTn14`g;P<a91h4:QXD124;1@@N2`L4:QTE13HW8`=1=304CD4m15Q=
BPATFUL4KfIT17YcL0B5OgdEoooo000Doooo19NEU0BOWYh4YjRY1:nb/`Bg_;h3`<O:1<WCePCCgn<4
g^c`1<oOi0Bkc]H3Y[k8196^^PAhVjT4GhRI14aiS0A=N8T4E7b;0eb1SPASQY<4Jh^G176AV`AfTid4
MiFN17ZFX0=kUIl4NiFM17ZBVPAkT9L4OY6G18BEV@>9V9/4SiZL19FLW@BIWYd4WIfL19bHUPBFSh`3
THR518Z1O@B6NgH4PgIa17m`JPAiJF<3MVAL17=OEPAaFU44L5M=175DB@AUBCh4C3L^0c4T7P@Z6Q@4
8@/511h;1`@Z6AD4=RLS0d4d<0A=@Cd4F4e:16AJE`A_IV@4NW=`18EoOAGoool001Coool4UiFD19nN
WPBWZ:T4[k:c1;Nl_P?0alX4bM?F1=?Oh`CNk?04cmoT1;_>eP>V_/P4TJjj17RKZ@AOR9T4C7V<14eh
R@ADO8/3G86>16>6T`A[RiL4LI6K17JCW@AgUIh4NYJP0g^EW`AkUId4NY:J17^@U`AnTIL4Q9FI0hVH
V`B?VY`4UIbM19VNW@BMWI`4W9RF19J?S0>AR8D4RX5m18IkMPB3MW44Og1Z17UYH`=fI5`4LemF175J
D@A`Edd4LEA916E9?PA<=bh3<B@N12XJ50@Q2`D47P/712XI5@@f9b<3@C@`14e1?@AHCDX4I5YG16mV
I0AjLg04QGmm5Oooo`005?ooo`BHUI@4X9nO1:VZZPBa];D4^[o10l?:c0C=e]T4f>;U1>?_l`CDhnP4
`M;I0j_1b`BD/;`4NIbZ1669VPA=NXd4BgJ8155hR0=HOH/4Gh6>16J6TPA/RYD4L8jH17>@V`AfTY`3
N9>L17VCW@AkTi`4OI>K182CV@B5UY/3RIRK18jIV`BBVY/4UY^J19^KV@BNVYL4W9BA0iV>RPB?QH44
R7eh18=fL@B0L6X4Nf]T0gQVGPAeH5L4M5eC17EJD0AeEd`4HdPn14/f;P<c9R449QTD11l=20@D1@84
8aDA130S80<m<Bh4BChk15E<B@AQFEH4KFES17UbL0B4OgdEoooo000Doooo19REU0BPWil4ZJZZ1;6d
]@Bj_l43`l[<1<gFf@CHh^D4hnoc1=CSj0C1d]T3Zl7;19B`_0AiW:X4HHVJ14ejS@A;MXP4DGR80eQm
R`AOPHh4IXJB16b:U@A`SYP4Li2K17JBW0=hTi`4NI>M17^CW0AmTi/4P9>I18FFV`>9V9/4SYVK19:J
V`BFViX4Vi^I19jJU`BLU943VHj:18n5P@B8OGP4PgIa181`JPAkJf@3N6IN17EPE`AdGE<4MEY@17EG
C0ASB3h4BcH^0c<V8@@V6A@47`d811@50P@S5A44<2<P0cda;PA9?S/4EDa9165IEPA]IF<4NG9`18Ao
OAGoool001Coool4V9FD1:2OW`BYZZX4/KBe1;Zo`@?3b/`4cMKI1=SRi@CSko<4e>?X1<7Bf@>[`L/4
U;2l17VLZPAQRIX4CGZ=14]fR0AAN8P3F7f;15n1SPAVQY84K8ZE172>V0AcT9/4MY:L0gRCW0AiTid4
Ni>L17fCV`B0TiT4QIJK0hVHV`B>VI/4TYZK19JKVPBKViT4WYZG19bDT@>ISXX4ShF118QmN0B3MW44
P71Z17][I0=hIUh4MF1G17AMD`AeFU04MEM<16=8?PA;=Rh3<bHQ12HI50@O3@P450D212<E4@@`8b03
?C4^14Tn>`AEC4T4HEUF16eUH`AiLW04Q7mm5Oooo`005?ooo`BHUI@4X9nO1:VZZPBa];D4^[o10l?:
c0C=e]T4f>;U1>?_l`CDhnP4`M;I0j_1b`BD/;`4NIbZ1669VPA=NXd4BgJ8155hR0=HOH/4Gh6>16J6
TPA/RYD4L8jH17>@V`AfTY`3N9>L17VCW@AkTi`4OI>K182CV@B5UY/3RIRK18jIV`BBVY/4UY^J19^K
V@BNVYL4W9BA0iV>RPB?QH44R7eh18=fL@B0L6X4Nf]T0gQVGPAeH5L4M5eC17EJD0AeEd`4HdPn14/f
;P<c9R449QTD11l=20@D1@848aDA130S80<m<Bh4BChk15E<B@AQFEH4KFES17UbL0B4OgdEoooo000D
oooo19RFU@BQX:04ZZ^[1;>f]`Bm`L83alc>1=7Hf`CLiNP4io7e1=SUjPC7emd3[lG=19Rc_PAnWjd4
IHbL14mlSPA:MHL4CWF50eEjR0ALOHX4HX:=16N5T0A/RI<4L8bF17>?V@=fT9X4N9:L17ZCV`AmU9/4
P9FK18BFV`>9V9/4S9RJ192HV@BDV9L4UiRF19ZFU0BJU903VY2;19J:Q@B@Pgd4RG]e18EdK@AoKVL3
OFUP17UTFPAiH5H4NEeB17MIC@ASB3l4C3P`0cLX8`@T6AD460/810h300@L4@h4:R0M0cP^;0A6?3X4
DdY8161HE@A/IF<4N79`18AnOAGoool001Coool4V9JE1:6PX0BZZj/4/kJg1;g1`P?7c<h4dMSK1=cU
j0CWlOD4f>GZ1<OGg@>_aLd4V;>n17jO[@AUS9`4Cgb>14YeQ`A>MHD3EGZ815amRPARPXd4IhF@16b9
T`A`S9H4LhnI0gJ@VPAhTY`4NY>K17fDV`B0UI/4Q9JK0hVHV`B<V9X4T9RI19BHU`BGV9H4VYJD19ZD
T0>JT8/4UXZ51923O@B9NgD4QGA]17m^I`=mJF04NFAJ17UPEPAiGE84MeU=16=8?`A<>303=bPS12@I
5@@H2`P43P<011`A3P@Z81d3>2h/14Hl>PACBTP4H5QE16aUH`AhLW04Q7im5Oooo`005?ooo`BHUYD4
XJ2P1:Z[Z`Bc][L4_L720lO<cPCAf=/4g>GX1>Oam@CHiNX4amOM0jo5c@BH/kh4OYn]16F<W0A?O8h4
BWF714ieQ@=ENXP4G7f:16:2S@AWQI04K8VC172<UPAcSiT3MY2J17RBW0AjTi/4OIBK182EV`B4UY/3
RIRK18bHVPB@V9T4U9RG19NHUPBJUY@4VYB@0iZ@R`BFRXD4T8=m18UkM@B5M6d4OfiW0geYH0AiI5X4
NF1F17UMDPAgFDd4HdPo14`h<0<g:2<491TE11P;20@>0`04714>12XP7@<h;R`4AS`j15=:B0APF5D4
K6ES17QbL0B4OWdEoooo000Doooo19RFU@BQX:04ZZ^[1;>f]`Bm`L83alc>1=7Hf`CLiNP4io7e1=SU
jPC7emd3[lG=19Rc_PAnWjd4IHbL14mlSPA:MHL4CWF50eEjR0ALOHX4HX:=16N5T0A/RI<4L8bF17>?
V@=fT9X4N9:L17ZCV`AmU9/4P9FK18BFV`>9V9/4S9RJ192HV@BDV9L4UiRF19ZFU0BJU903VY2;19J:
Q@B@Pgd4RG]e18EdK@AoKVL3OFUP17UTFPAiH5H4NEeB17MIC@ASB3l4C3P`0cLX8`@T6AD460/810h3
00@L4@h4:R0M0cP^;0A6?3X4DdY8161HE@A/IF<4N79`18AnOAGoool001Coool4VIJE1::QX0B/[:`4
]KNh1;o3a0?9c]04e=_M1=oWjPCZm?L4fnK[1<[Ig`>db=04W;K018>R[`AZSil4E7n@14UdQPA;Lh<3
DWJ515QjQ`AOOXX4I8:=16V6T0A]RI<4LHbF0gB?V0AgTIX4NI:K17fCV`B0UI/4Q9JK0hRGV`B;UYT4
SYJG196FU@BDUI<4Ui>A19NASP>GSHT4UHV419:4OPB>OWP4RGQ`18AaJ@>1K6<4OfQN17iSF@AlGe@4
MUQ<1698?`A<>343>BTT12@J5P@D2`T42@4011D<2P@U7A/3=B`Z14<k>@AABDL4GUME16]THPAgLG04
Pgim5Oooo`005?ooo`BIUYD4XZ6P1:b/[0Be]kP4_l?40lW>d0CDfmd4gnOZ1>[dm`CKi^/4b]WO0kC8
d0BL]/04Pj:_16Z?W`ADOi04BGB614]cP`=BMXD4F7Z715mnRPATPXd4JHJ@16f9T`AaS9H3M8nH17NA
VPAiTY/4OI>K182EV`B4UY/3R9NK18^FV@B>UYL4TIJE19BET`BGTi44Ui6>0iN=R@BERH@4TXAn18in
N0B9N704Q75Y0h5/H`AoJ5h4OV=I17aOE0AfF4`4HTPo14`h<@<i:B@491XF11@;2@@90@045@`:12DM
6`<e;2X4@c/i1559A`ANEeD4JfAR17MaL0B3OWdEoooo000Doooo19VFU@BRXJ04[:b/1;Fg^0Bo`l@3
bLk@1=CKg@COinX4j_Cg1=_Vj`C:fMl3]<S@19bf`0B3XZl4JXnO15AoT0A9M8H4Bg>30e9fQ@AHNXL4
Ggj:16B2S@AYQY04KHVC176<UP=dSiP4Mi6J17VBV`AmTi/4P9FK18BFV`>8Ui/4RiJI18jFU`BAUYD4
U9FC19NCT@BGTHh3Uhf919F9Q0BBQ7h4SWih18UhL0B4LFT3PFaS17mXGPAnHeT4O5mD17IHC0ARB3l4
C3Pa0cTY90@T6QH450/910T100@E30X49AdK0cD/:PA3>cT4DDU715iGE@A[I684Mg5`18=nOAGoool0
01Coool4VIJE1:>RX@B][Jd4]kRi1<74a@?<d=84e]cN1>;Yj`C]m_T4gNS/1<gKh@>hc=<4X[[418RW
/`A`U:<4FX>D14]fR0A9LH43CgB215IhQ0ALNhL4HWn916J3SPA[QY44KhVC0g:=U`AeSiT4NI6J17bC
V`AoU9/4PiFK0hJFV@B9UIL4RiBE18jCT`BATY44U96?19B?R`>DRhL4ThN21923O@B>OWL4RgUa18Qd
J`>4KVD4PVYP185VG0AoHEH4LeI;15i7?PA;>343>2TT12@J5`@A30X41`8110h81`@Q6QT3<R/Z144j
>@A?BDL4GEIE16YTHPAgLG04Pgim5Oooo`005?ooo`BIUYD4Xj:Q1:f][@Bg^;T4`LC50lc@dPCFg=h4
h^W[1>gfn@CMj>`4cM_Q0kS<d`BR^/@4R:Nc172DX`AJPi@4BgJ814UaP@=?M884EWR415akQ`AROhT4
IX>>16^6T@A_RI<3LXfG17F?V@AiTIX4O9>K17nDV`B3UI/3QYJI18VEU`B;U9D4SY>C196BT@BDTHl4
U8n;0iB;Q`BCQh84T8=m18inM`B;NG44R7A[0hA^I@B2JV04PFIL17mQEPAcET/4GTLn14/h<@<h:B@4
91XG114<2P@70P443PP7124J6@<b:bX4@CXi14m9A`AMEUD4JVAR17MaL0B3OWdEoooo000Doooo19VF
U@BSXZ44[Jf]1;Nh^@C1a<D3c=3B1=KLgPCRjN/4kOKi1=gXk0C=fn43^<cC1::ja0B8Yk<4L9BS15Z3
U0A;MXP4BG610dmdPPAFN8@4G7^7169oR@AVPhh4JhJA16n9T`=bSIL4MHnI17VAVPAlTi/4OiBK18>E
V`>6UYT4RIFG18^DU@B>Ti<4TI:A19BAS`BDSh/3U8^719>7PPB@Pgd4SWig18]iL@B8M6/3Q6iU189Z
H0B1IU`4Of5F17=FB`ANAch4BcPa0cPY90@T6QL44@`:10L20@@>20L48AXI0c8[:PA1>ST4CdU715eF
E@AZI684Mg5`18=nOAGoool001Coool4VIJE1:>RX@B][Jd4]kRi1<74a@?<d=84e]cN1>;Yj`C]m_T4
gNS/1<gKh@>hc=<4X[[418RW/`A`U:<4FX>D14]fR0A9LH43CgB215IhQ0ALNhL4HWn916J3SPA[QY44
KhVC0g:=U`AeSiT4NI6J17bCV`AoU9/4PiFK0hJFV@B9UIL4RiBE18jCT`BATY44U96?19B?R`>DRhL4
ThN21923O@B>OWL4RgUa18QdJ`>4KVD4PVYP185VG0AoHEH4LeI;15i7?PA;>343>2TT12@J5`@A30X4
1`8110h81`@Q6QT3<R/Z144j>@A?BDL4GEIE16YTHPAgLG04Pgim5Oooo`005?ooo`BJUiD4Y::Q1:j^
[@Bh^KX4`lG60lkAd`CIg^04i>_]1?3hnPCPj^h4d=gS0kg?ePBX_lP4T:bh17NIY`APR9P4DGZ<14Qa
PP==LX44E7F215YiQ@APO8L4IH2;16V4S`A]R983LH^E17B>U`AgT9T4Ni:J17jCVPB1U9X3Q9BH18NC
UPB9TY@4S96A18j@S`B@SX`4TXb90i69Q@BAQH44T89l18inM`B<NG84RWE]0hM`I`B6K684QFQM17mQ
EPA`E4X4G4Hm14Tg<0<f:B@48QXG110<30@50`<42`L711lJ6P<`:bX4@3Xi14i9A`ALEeD4JFAS17Ia
L0B3OWdEoooo000Doooo19ZGU@BTXZ44[Zj]1;Ri^PC3aLH3c]7C1=WNh0CTjnd4l?Sj1>3ZkPC@gN<3
_LoF1:Rob0B@[;P4MiVW1628V0AANX`4B7620debP@ADMH84FWV5161lQ`AUP8/4JHB?16f8TP=aRiD4
M8jG17N@V@AkTYX4OY>J186DVP>4U9P4Qi>F18VBU0B<TI44SY2?192>S0BBS8T3THV51965P@B@PW`4
SWig18aiLPB:MFd3Qg1W18I/HPB5J5d4Of5F171DBPALASd4BCL`0cHY90@R6QL440`<10D30`@;1`L4
7aXJ0c0[:PA0>ST4CTU715aGE@AYI6<4MW5`18=nOAGoool001Coool4VYNE1:BRX@B^[Zd4^;Vj1<?5
aP?>dM<4fMkP1>C[k@C`n?X4h>[^1=3Mh`>mcmH4Z;o8192/^0AgVJL4H8RH155jS0A8LH83CG:115Ae
PPAJNHD4H7b716F0R`AYQ8l4KHRB0g6;U@AdSYL4Mi2I17^BVPAnTiX4PIBJ0hBDV0B7TiH4RI:D18bA
T@B>T8l4T8j<19:<R@>ARHD4THF11922O0B>OWL4S7Ub18YeK@>7L6L4QVaR18EXG@AoHEH4L5A:15a6
?@A9=c03=RTT128J5`@@30`41@<310/71`@O6QX3<2/Z140j>@A>BDL4G5ME16UTH`AfLG04Pgim5Ooo
o`005?ooo`BJUiD4Y::Q1:j^[@Bh^KX4`lG60lkAd`CIg^04i>_]1?3hnPCPj^h4d=gS0kg?ePBX_lP4
T:bh17NIY`APR9P4DGZ<14QaPP==LX44E7F215YiQ@APO8L4IH2;16V4S`A]R983LH^E17B>U`AgT9T4
Ni:J17jCVPB1U9X3Q9BH18NCUPB9TY@4S96A18j@S`B@SX`4TXb90i69Q@BAQH44T89l18inM`B<NG84
RWE]0hM`I`B6K684QFQM17mQEPA`E4X4G4Hm14Tg<0<f:B@48QXG110<30@50`<42`L711lJ6P<`:bX4
@3Xi14i9A`ALEeD4JFAS17IaL0B3OWdEoooo000Doooo19ZGU@BTXZ84[jj^1;Vj^PC4a/L3cm?D1=_O
h@CVk>h4l_Wk1>?/k`CBgn@3`M;I1:g3c0BG/K`4OIj[16N=W0AGOi04C7B50deaP0ACM844FGR415ik
QPASOXT4J8:<16b6T0=`RY@4LhfF17J?U`AjTIT4OI:I182CV@>2TiL4Q96D18N@T@B:Shl4S8j=18j<
RPB?RXL3ShN418n4P0B?PG/4SWeg18ejLPB;MFd3RG9X18Q]H`B5J5d4O5mD16aBB0AJA3`4ASD_0c<W
8`@P6AL43P`<10<20`@>30`481`L0c0/:`@o>cX4CTU815aGEPAYI6<4MW5`18=nOAGoool001Coool4
VYNE1:BRXPB_[Zh4^KZj1<C6a`??dm@4fmoQ1>K/kPCbnO/4hnc_1=;Oi0?1d]T4[L?<19Na_0AmWZ/4
IhfL15MoT0A<M8D3CG6015=dP@AIN8@4GW^616=nR@AXPX`4K8J@0g2:U0AcSIH4MXnG17ZAV@AmTYT4
P9>I0h:CU`B4TI@4Qi2A18Z?S`B<SXd4SXb:18n:Q`>?Qh@4ShB018n1N`B>OGL4SGYb18]eK@>9LVP4
R6eS18EXG@AlGe@4K59815Y4?0A6=Bl3<bLS120I5`@>30`40`8310h<30@P71`3<2`[13lk>PA>BDP4
G5MF16UTH`AfLG04Pgim5Oooo`005?ooo`BJUiD4Y::R1:n^[PBi^[X4a<K70loCe0CKgn44i^c^1?;i
n`CSk>l4d]oT0l7Bf@B]`l`4Uk6l17fNZ`AWSI`4Egn@14adQ@==LH04DgB115UhQ0ANNhH4Hgj916R2
S0A/QY03L8ZD17>=UPAfSiL4NY6I17fBV@B0TiT3PY>G18BAU0B7T944RXn?18b>S@B>S8X4ShZ70hn7
Q0B?Q804Sh5k18imM`B=NW84RgE]0hUbJ0B8KF<4QFQM17aOE0A/DTP4FT@l14He;`<c9b<481TG10h<
30@30P<43P`<120L70<`;2/4?c/j14i9B0ALEeH4JFAS17IaL0B3OWdEoooo000Doooo19ZGU@BTXZ84
[jj^1;Vj^PC4a/L3cm?D1=_Oh@CVk>h4l_Wk1>?/k`CBgn@3`M;I1:g3c0BG/K`4OIj[16N=W0AGOi04
C7B50deaP0ACM844FGR415ikQPASOXT4J8:<16b6T0=`RY@4LhfF17J?U`AjTIT4OI:I182CV@>2TiL4
Q96D18N@T@B:Shl4S8j=18j<RPB?RXL3ShN418n4P0B?PG/4SWeg18ejLPB;MFd3RG9X18Q]H`B5J5d4
O5mD16aBB0AJA3`4ASD_0c<W8`@P6AL43P`<10<20`@>30`481`L0c0/:`@o>cX4CTU815aGEPAYI6<4
MW5`18=nOAGoool001Coool4VYNF1:FSXPB_[Zh4^[^j1<G7a`?Adm@4gN3Q1>W]k`Cen_`4iNka1=GQ
iP?5eM/4]<O?19jf`0B5Y;44Ki>R15b3U0AANHT3Cg>215=dP@AHMh<4GWZ6169mR0AWPH/4JhF>0fn8
TPAbS9D4MHjF17V@V0AkT9L4OY6G0h6@U@B2Si84Q8j@18N<S@B9Rh/4RhV818f8Q@>=QH84SH9n18io
NPB=OGH4SGYb18afK@>;LVT4RFiS18AWG@AgG584J4m715A1>PA2=2h3;bDR11`G5P@;2`/40001114@
40@Q7al3<Bh^140l?0A>BTX4G5QG16UUI0AfLW04Pgim5Oooo`005?ooo`BJUiH4YJ>R1:n^[PBj^kX4
aLO70m7Ce0CMh>44jNg_1?Gjo0CUk_44eN7V0lGEf`Bdall4W[K018FT/@A_Tj84G8>D155iR@=?Lh84
DgB115QgP`ANNXH4HWf816N1R`A[QHh3KhRB17:<U@AeSYH4NI2H17^@U`AnTIL3PI2E18:?TPB4SY04
Qhb=18V;R`B;RHP4SHR50hf5PPB=PWh4SWmj18emMPB=NW84S7I]0h]bJ@B9KV<4Q6MM17MLDPAXCdL4
E44j148d;P<_9B8471LF10/;2`@000444A0@124O7`<a;Rh4@3`l14i:BPALF5L4JFET17IbL0B3OWdE
oooo000Doooo19ZGUPBUXj84[jj^1;Zk^PC5alL3dM?D1=gPh@CYkNl4mO[l1>G^l@CEhNH3aMGK1;C7
c`BN]/04QJBa16nCXPALPi@4DGV90dmcPPACM844F7N315ijQPAROHP4Ih6;16^5SP=_R984LXbE17F>
UPAiT9P4Ni2G17jAU`>1T9D4PXnB18B>T0B7S8d4RH^;18^9R0B=R8D3SHF218f2OPB>OgX4SGef18ej
LPB<MVd3Rg9Y18U^H`B4Ied4MeaB16Q?A`AD@CX4@S@^0blU8P@L5aH42`/;10000@@A41048AlO0c4^
;PA0?3`4CTY:15aHE`AYIF@4MW9`18=nOAGoool001Coool4VYNF1:FSXPB_[Zh4^[^j1<G7a`?Adm@4
gN3Q1>W]k`Cen_`4iNka1=GQiP?5eM/4]<O?19jf`0B5Y;44Ki>R15b3U0AANHT3Cg>215=dP@AHMh<4
GWZ6169mR0AWPH/4JhF>0fn8TPAbS9D4MHjF17V@V0AkT9L4OY6G0h6@U@B2Si84Q8j@18N<S@B9Rh/4
RhV818f8Q@>=QH84SH9n18ioNPB=OGH4SGYb18afK@>;LVT4RFiS18AWG@AgG584J4m715A1>PA2=2h3
;bDR11`G5P@;2`/40001114@40@Q7al3<Bh^140l?0A>BTX4G5QG16UUI0AfLW04Pgim5Oooo`005?oo
o`BJUiH4YJ>R1;2_[PBk^kX4a/O70m;De0CNhN84jno`1?Slo@CXl?84fN?W0lWGg@Bibm84Y;_418jZ
]@AhVJL4I8VI15MnSP=AMXD4DgB215QgP`AMNXD4HWf816J0RPAZQ8d3KXN@176:T`AeS9D4MhjF17Z?
U@AlT9D3OXjC182<T0B2Rhh4Q8Z;18J9R@B9QhH4RXJ30h^4P@B<PGd4S7mi18elM@B=NG84S7I]0hYb
J@B6K684OfAJ175HC`AQC4@4Cchh13da;0<[8b445aDD10P92P@10P<451<D12@R8`<c<344@Chn14m<
B`AMFEP4JVIU17MbL@B3OgdEoooo000Doooo19ZGUPBUXj84/:n^1;^k^PC6alL3d]CD1=kQhPC[ko04
n?cm1>S`lPCIhnL3bMOM1;W;dPBT^l@4SZZe17RIY`ATRIT4Egj>0e5fQ@ACM884F7N315ejQ@AROHP4
IX2:16Z4S@=^Qi04LHZC17F<U@AgSYH4NXnE17b@U@=nSY<4P8b@18:;SPB4RX/4QXV918V7QPB:QX<3
RhB118b1O@B<OgT4SGae18eiLPB<MVd3RW9Y18I/HPAoI5X4LEQ?165<A0A??SP4?C4/0b/S8@@G5A@4
20T:10420`@D4a@4928S0c<`<@A1?Sh4Cda;15eIF0AZIVD4Mg9a18=oOAGoool001Coool4VYNF1:FS
XPB`[jh4^k^j1<K7a`?Be=@4g^7R1>__l0Cho?d4j?3b1=WSi`?9emd4^L_B1:Bka0B>Z[D4N9VW16B9
V@AGOXh3DGJ515=dPPAHMh<4GGZ5169mR0AVP8X4JXB=0fj7T0AaRY<4MHbE17N>UPAjSiD4O92E0gj>
T`B0S904PX^>18B:R`B6RHT4RHN618Z6P`>;Q844S85m18aoN@B=O7D4SGUb18afK@>:LVT4QVaR17mT
FPAaF4l4HDa414ln>0@m<B`3:b<Q11LE50@82@X40@8311@C50@T8R<3<c0a144n?PA?C4/4GEUH16YV
I@AgLW44Pgmm5Oooo`005?ooo`BJUiH4YJ>R1;2_[PBk^kX4alO70m?De0COhN84k>o`1?[noPC/l_D4
gNKY0lkJg`Bnc]D4[<3919J_^PB2X:`4KY2N1625U0=ENXT4E7F415QhQ0AMNhH4HWf816J0RPAZPhd3
KHJ?1769T@AdRi@4MXfE17R=U0AjSI<3O8b@17f:S@AoR8/4PHN918>6Q`B6QH@4Qh>10hV2O`B;Og`4
Rgii18akM@B=N744S7E]0hUaJ0B3JF04NF1G16YDC0AJB444BS/f13P^:`<V81l44Q8B10@620@92P/4
61PI12LV9P<e=3@4@d51155>C@ANFUX4JfMV17McLPB3OghEoooo000Doooo19ZGUPBUXj84/:n^1;^k
^PC7alL3dmCD1=oQhPC/ko04n_kn1>cbm@CMi^T3c][O1;k>e@B/`<T4UZnj18:P[0A^T9h4H8FD0eEj
R@ADMH@4F7R415ekQPAROHP4IX2:16Z3S@=]QXl4LHVA17B;U0AfSID4N8fD17Z=T`=lS904OHZ=17n8
R`B1QhT4PhJ718J5Q0B7Ph43RH9o18]oO0B;OWT4S7]e18ehL@B<MFd3RG5X18=YH0AiH5L4JUA<15Y8
@@A:>cH4>2h[0bHP7`@B4Q8410H810T:2`@H61T49bHV0cDd=0A3@D44DDi=15iJFPA[IfH4Mg=b18=o
OQGoool001Coool4VYNF1:FSXPB`[jh4^k^j1<O7a`?Ce=@4gn7R1>c_l0Cjo_h4k?;e1=gVj@?>f]l4
_/kE1:c0b@BF[kX4PZ2/16j@WPAPQI@3EGZ915AeQ0AHN8@4GG^6169mR0AVP8X4JX>=0ff6S`AaRI44
M8^D17J=U@AhSI@4NXfC0gb<T0AmRXd4OhR;1867R@B3QXL4QXF418N3P@>9PWl4Rgml18]nN@B<NgD4
SGQa18aeK@>9LFP4PfUP17UPE`AZE4`4FTQ114Xk=P@h;R/39R0O118B4P@41PP42@X;11PH6@@W9RH3
=C@d14=1@@AACTd4GUYJ16]WIPAgLg84Pgmn5Oooo`005?ooo`BJUiH4YJ>R1;2_[PBk^kX4alO70m?D
e0COhN84k>o`1?[noPC/l_D4gNKY0lkJg`Bnc]D4[<3919J_^PB2X:`4KY2N1625U0=ENXT4E7F415Qh
Q0AMNhH4HWf816J0RPAZPhd3KHJ?1769T@AdRi@4MXfE17R=U0AjSI<3O8b@17f:S@AoR8/4PHN918>6
Q`B6QH@4Qh>10hV2O`B;Og`4Rgii18akM@B=N744S7E]0hUaJ0B3JF04NF1G16YDC0AJB444BS/f13P^
:`<V81l44Q8B10@620@92P/461PI12LV9P<e=3@4@d51155>C@ANFUX4JfMV17McLPB3OghEoooo000D
oooo19ZGU@BUXZ44/:j]1;^j^PC7alH3dmCC1=oQh@C]knl4nokn1?7fn0CRj^`3dmkS1<GCf@BcaLd4
WkFo18^V/@AjV:H4JXbK0eb0S`AGNHL4FWV615ikQ`AROXT4IX2;16Z3S@=]QXl4L8R@17::TPAeS9@4
MhbC17R;T@=iRHh4NXN:17^5R0AmQ8H4P8B518:2PPB4PGl3Qgmm18QnNPB:O7L4RgYd18ahL@B;MFd3
QfmV17eVG@AbG5@4HU191594?PA4>3@4<R/Y0b0M70@=3a04008410l@4@@M7Ah4:bX[0cPg=`A6A4@4
De1@15mLG0A/J6L4N7Ac18AoOQGoool001Coool4VYNE1:FRX@B`[Zd4^kZj1<O7aP?Ce=<4gn7Q1>g_
k`Cko_h4lOKh1>;Zk0?Cg^<4aM?I1;?5c@BO]Kl4RjJa17ZHYPAZS9/3G82?15MiQ`AJNHH4GW^7169n
R@AVP8/4JX>=0ff6S`A`R904LXZB17F<U0AgS9<4N8^A0gV9SPAjQhX4NhF817f4QPB0Q8D4PX:218B1
O`>7Ogd4R7ij18YlM`B;NW@4S7Qa18]eK@>7KfH4OFIM179LE0ARD4T4DT@n14@h=0@b:bT381dL10d?
40@00P@43a0A11dM7P@[:R/3>3Lg14I4A0ACD504GeaL16aXI`AhM7<4Q7mn5Oooo`005?ooo`BJUiD4
YJ:Q1;2^[@Bk^[X4alO60m?Dd`COhN44kNo_1?_noPCam_P4h^[/0m?Nh`C5dmT4/lG=19ne_`B;Y[44
NYRV16Z<V`=LP8l4EgV715YiQPANNhL4HWj916J0R`AZPhd3KHJ?1728T0AbRY84MHbD17N<T`AhRi43
NHV>17Z7RPAkQHP4OHB61824Q@B2PX84Q85o0hMoO@B8OWX4RWag18]jM0B<N744RgE]0hM_IPAmIUd4
LUaD169@B@ABA3h4A3Pd138[:@<P7A`43@l@100210@?41447AdN12/Z:`<h=cL4ATA415=@D0AOG5`4
K6QW17QdL`B4OghEoooo000Doooo19ZGU@BUXZ44/:j]1;^j^PC7alH3dmCC1=oQh@C]knl4nokn1?7f
n0CRj^`3dmkS1<GCf@BcaLd4WkFo18^V/@AjV:H4JXbK0eb0S`AGNHL4FWV615ikQ`AROXT4IX2;16Z3
S@=]QXl4L8R@17::TPAeS9@4MhbC17R;T@=iRHh4NXN:17^5R0AmQ8H4P8B518:2PPB4PGl3Qgmm18Qn
NPB:O7L4RgYd18ahL@B;MFd3QfmV17eVG@AbG5@4HU191594?PA4>3@4<R/Y0b0M70@=3a04008410l@
4@@M7Ah4:bX[0cPg=`A6A4@4De1@15mLG0A/J6L4N7Ac18AoOQGoool001Coool4VYNE1:FRX@B`[Zd4
^kZi1<O6a@?Cdm84gn3P1>c^kPCkoOd4mOWi1>S^l0?IhnH4bmOM1;_;d@BX_<@4UJfg18FQ[0AfUJ83
IhVG15ioS@AMO8T4Ggf916=nRPAWPH/4JX>=0ff5SPA_Qi04LHRA17B;TPAfRi84MHR>0gJ6R`AfQ8P4
N8:617V1Q0AlPH84Oh20185nO@>4OG/4QW]h18QkMPB9NG<4RGI_18QcJ`>2Jf<4Mf9J16]HD@ALC4H4
C40l13dd<@@/:2H36AXJ10`>40@21@L44a@F124R8`@_;Rl3?3/k14U7A`AEDe84HEiN16eZJ@AiMG@4
Q81o5Oooo`005?ooo`BJUiD4YJ:Q1;2^[@Bk^[T4alK50m?CdPCOh>04k>k^1?_mo@CenOT4j>k`0mWS
iPC;emd4^l_A1:Rla0BE[KL4QJ6/17JEXP=WRIL4GWn=15elR@AOOHT4Hgj:16N1R`AZPhd3KHF>16n7
T0AaR944M8^B17J;TPAeR8h3MXJ;17J4R0AhPXH4NH6417b1PPAoP804PGim0hAmN`B6NgP4R7]f18Ui
L`B9MVl4R7=[0h9[H`AgHUX4JeQA15a<APA<@3`4?C@a12`X9P<I6QX430h@10851`@C51H48B8S12l^
;`<l>c/4BDM715ECDPAQGUh4KFYY17UeM0B4P7lEoooo000Doooo19ZGU@BUXZ44/:j]1;^j^@C7a/D3
dm?B1=oPh0C/k^h4nogm1?Gin@CXk_03fN?V1<_Gg@Bkbm44Z;c419F]]`B5XJ`4MYFR0fN9U`ANOhd4
GGb915mmR@ASOXX4Ih6;16Z3S@=]QHh4KhN@1768T@AdRi84MX^B17F8SP=fQX/4MXB817R2QPAiPH@4
O86217n0P0B1OWd3Q7ek18IkN0B8NgH4RGUc18UfK`B8Lf/3PV]S17MRFPA[F544G4a614a0?0@m=344
;2PV0aTJ6P@<3Q040PD711<D5P@Q8R<4;bh_0c`k>`A9AdL4EE=B165NGPA]JVT4NGEd18B0OaGoool0
01Coool4VYNE1:FRX@B`[Zd4^kZi1<O6a@?Cdm84gn3P1>c^kPCkoOd4mOWi1>S^l0?IhnH4bmOM1;_;
d@BX_<@4UJfg18FQ[0AfUJ83IhVG15ioS@AMO8T4Ggf916=nRPAWPH/4JX>=0ff5SPA_Qi04LHRA17B;
TPAfRi84MHR>0gJ6R`AfQ8P4N8:617V1Q0AlPH84Oh20185nO@>4OG/4QW]h18QkMPB9NG<4RGI_18Qc
J`>2Jf<4Mf9J16]HD@ALC4H4C40l13dd<@@/:2H36AXJ10`>40@21@L44a@F124R8`@_;Rl3?3/k14U7
A`AEDe84HEiN16eZJ@AiMG@4Q81o5Oooo`005?ooo`BJUYD4YJ:P1:n][0Bj^KP4a/G40m;Ad@CNg]h4
jnc/1?[kn`Cjo?d4k_;d0n3WjPCAg>04a=7F1;;3bPBO];d4TJVc18>NZ@=fTj04JHRF16B4T0ASPHd4
IH2<16V3S@A[Phd3KHF>16n6S`AaQi04M8VA17F9T0AbQX`3LH>917:1QPAdOh<4MWn217UmO`AlOGh4
OWak0h5kN@B3NWL4QWQd18MgLPB5Lfd4PfmX0gaWH0AaGUL4I5A>15E8A0A6?CX4=c4_12HT90<D5aT4
20d?10/>40@I6a`49RLX13<c=0=0?cl4C4Y:15QEE@ASH604KV]Z17YfM@B5P7lEoooo000Doooo19ZF
U@BUXZ04[jf/1;Zi^0C6aL@3d]7A1=kNgPC[k>`4n__k1?[lo@C^l_@3h>OZ1=7Lh0C4dMH4//?:19nd
_@BAZK<4PijY0gJCX0AYR9H4I8B@16>1S@AUP8`4JH>=16^3S@=]QHh4KhJ?1767T0AdRI44MHV@17:6
S0=aPhT4LX6617AoP`AfOh84NGeo17amOPAnO7/3PG]i18=jM`B6N7@4QgMb18EcK@B3KfP3O6MP175N
E`ATE4h4EDQ414Hm>P@g<Bl49R@T0a@G6@@83@l42`h@11TK70@V9bP4<c<d0d0o?`A<BTX4F5EE16=P
H0A^JfX4NWIe18F0OaGoool001Coool4VYJE1:FRX0B_[J`4^[Vh1<K5a0?BdM44g]kN1>_/k0Cjno/4
n_cm1>kbm0?PinX4dMcP1<CAePBb`lX4WkBm196Y/`B3WZT3MY>P16V8UPATQ904Hh6=16F0S0AYPhd4
Jh>=0ff5SPA_QXl4LHN@17B9T@AeRI04LXJ<0g63R@AbPHH4M7n317IoPPAiOGl4O7en17ilN`>1NgT4
PgYg18IhM0B7Mg84QG=]18=_J0=lIf04LEiG16ADCPAEB4@4ASdj13La;`@V92@351LI10P=3`@;3Q04
6A/L12HW:0@c<c@3@3lo14a:BPAHEED4Hf1P16i[JPAjMWD4QH1o5Oooo`005?ooo`BJUYD4YJ:P1:n]
[0Bj^KP4a/G40m;Ad@CNg]h4jnc/1?[kn`Cjo?d4k_;d0n3WjPCAg>04a=7F1;;3bPBO];d4TJVc18>N
Z@=fTj04JHRF16B4T0ASPHd4IH2<16V3S@A[Phd3KHF>16n6S`AaQi04M8VA17F9T0AbQX`3LH>917:1
QPAdOh<4MWn217UmO`AlOGh4OWak0h5kN@B3NWL4QWQd18MgLPB5Lfd4PfmX0gaWH0AaGUL4I5A>15E8
A0A6?CX4=c4_12HT90<D5aT420d?10/>40@I6a`49RLX13<c=0=0?cl4C4Y:15QEE@ASH604KV]Z17Yf
M@B5P7lEoooo000Doooo19ZFU@BTXJ04[jb[1;Vg]PC5`l83d<o>1=cLf`CYjNP4m_Kf1?ooo`CdmoL3
i^_]1=SPh`C;e]X4^lW?1:Rj`PBL/;P4SZF_0hFNZ0AiU9l4LHfI16b9U@A/QY44KXJ@1fj6S`A_QHh4
LHN?17B9T0AdR8l4LHF<0fj1Q`A^OX<4L7b1179lP0AeNgd4N7]l17YiN@=mN7L4P7Me189fL`B3MG04
PG1[17eZI@=dHed4JUYD15e@B`A?AD44@3Xh134^;@@Q8R<34aHI10H;3@@C5QP4824S12`];P@h>3T3
A4=314m>CPAJF5P4IF=R171]K0AkMgH4QH605Oooo`005?ooo`BJUYD4Y:6P1:n/Z`Bi]kH4aL?20m3?
cPCLg=/4jNWX1?KfmPCoool4m?Og0nK[k@CHh><4bmKJ1;_9c`BX^/84W;2h18jU[`>5WZP4NIBO176=
V@A/RID4K8JA16j6T0M^QXl4KhF>1767S`AdRI04M8R?1765S0=^PHL4KWj3171lP@AbO804MG]m17Qk
O0AjNGT3OGQg181gM@B2MW<4PgE`185`J`AmJVD3M6=M16YJE0AMD4/4CdE1140j>0@a;Rd48B8S0a<F
6@@62`d44aHH120Q8`@/;Bh4>3Pi0dA3@`A?CTh4FUQH16ESHPA`KF`4NgMf18F1P1Goool001Coool4
VYJE1:BQX0B_[:/4^KNf1<G3`P?@clh4g=cK1>WYj0Cfm_H4oooo1?Cgm`?Vjnd4f>3S1<_FfPBkbLl4
Z;[219b`^0B>YJl3QIjX17VDW`AaSIT4K8VE16b6T@A^QY07KXJ?16n5SPAaQhl4M8V@17B8S`AaQH`3
KX6716inP`A`O844LWb017EkO@AhNg`4NWUi0gehM`B0MgD4PWIc18=eL0B1L6/4OFYU0gASG@AZFU@4
GE1;14m5@@A0>SP4<Bh]124R8`<C5QT41P/=11<F60@P8B<4;2d^13Ph>@=4@d<4Cdi>15YHF0AUHf84
L6e/17]gMPB5PH0Eoooo000Doooo19ZFU@BTXJ04[jb[1;Vg]PC5`l83d<o>1=cLf`CYjNP4m_Kf1?oo
o`CdmoL3i^_]1=SPh`C;e]X4^lW?1:Rj`PBL/;P4SZF_0hFNZ0AiU9l4LHfI16b9U@A/QY44KXJ@1fj6
S`A_QHh4LHN?17B9T0AdR8l4LHF<0fj1Q`A^OX<4L7b1179lP0AeNgd4N7]l17YiN@=mN7L4P7Me189f
L`B3MG04PG1[17eZI@=dHed4JUYD15e@B`A?AD44@3Xh134^;@@Q8R<34aHI10H;3@@C5QP4824S12`]
;P@h>3T3A4=314m>CPAJF5P4IF=R171]K0AkMgH4QH605Oooo`005?ooo`BJUY@4Y:2O1:j[ZPBh][D4
`l700lk=c0CIfMP4iNGT1?;bl@Coooh4nocl0nc`l@COiNP4d]_N1<C?e0Bb`LP4YKJn19Z^]P>AYZl4
R9jX17nGX@AjTid4N92I17R=UPAfS9@3LhZB17:8T0AdR8l4MXV@17B7S`AbQH`3Kh6816enP`A]Nh04
KgYn17=jO0AeNGX4MgQh0gUfM@AlMG<4OGAa17iaK@AjK6P4MVMR0feOFPASEU84Eda914U1?`@k=SD4
;2//11lQ8P<A5QT43A4D11/N80@W:2X4<S<d13hm?P=8AdP4De5A15eKF`AXIF@4LVm^17ahM`B6PX0E
oooo000Doooo19ZFU0BTX9l4[Z^Z1;Rf]@C3`L03c/g<1=WIf0CUiN@4l_;a1?oooPCko?`3k?3a1=oU
j0CBfmh4a<oD1;;1b0BU][h4VZjf0i6V[`B8WZP4OiNQ17ZCW@AhT9T4N8fF17J<U0=cRY84LXR@17B8
S`AfRI04M8N?17:5S0=_PHP4KGj316ekP0A_NWh4LgYl17EiNPAgN7P3NGIe17aeL`AmM744OW5]17Y/
J0AfIf83KEmJ16=FDPAGC4T4BD4o13/f=@@/:b`47b4R0a4F6@@=4A@46ahP12LX:P@b<c@4?Sdn0dQ7
B0ACDE44GE]K16QUI0AbKfh4O7Qg18J2P1Goool001Coool4VYJD1:BPW`B^ZjX4^;Je1<?1`0?>cL`4
fMWH1>GUi0Cbl_44ooon1?_lo0?/l?44gnGX1=;KgPC4cm@4//781:Ff_PBJ[[H3TJJ_18RNZ0AoUj44
NY>M17R@V@AhSIH4MXbD0g>:TPAbR904M8R?17J9T0AdQhl4LXF<0fn1R0A]OX<4KG^016mjOPAcNW`4
MGUj17MhN0=iMWD4O7Ec17edL@AnLFd4NVaX17IWHP=]GeX4HeIB15M<B@A9@Cl4>cHe12`[;0@O8B83
4AHI10dA50@K7R049bPZ138c=0@n?Ch3B4M815=AD@AMFe/4J6ET179_KPAlN7L4QX:05Oooo`005?oo
o`BIUI@4XinN1:fZZ0Bg];<4`Knn0l_:b@CFeM@4h^7P1>k]k0Ckn_P4oooo0o?dm@CVjN/4fMoR1<cE
f0Blb<d4[kg31:Fe_0>L[[D4TjJ^18^PZ0B7Vj<4QIRO18:EW0AoTYX3NhnF17Z=U0AhRY44NHZA17N9
S`AdQXd3LH:816moQ0A]Nh44KgUn175iO0AbMgX4M7Mg0gEdM0AgLg84N75_17Q^J`AdJ6D4KV=O0fEK
E`ALDTl4D4U714<n?@@e<c<4:2T[11hP8P<C61X46A`O12@V:0@_<344>CTj14=3@`==C4`4EeEE165N
GPAZIfL4M71`17eiN0B6PX4Eoooo000Doooo19VEU0BSWih4[JZX1;Nd/`C1_kh3bl[91=KEe0CRhN04
k^g/1?_jn0Coool3loCe1>KYj`CIgn84c=GH1;c8c@B__L<4YKFl0ib^]@BCYZh4Rj2X18NKX`B5V9l4
PYFL17nBVP=kSiH4NXfD17R:T@AiRY44MhV?17B6S@=aPXP4Kgn416ekP@A_NGh4LGUl179gNPAdMgL3
MGAd17McLPAhLFl4N6i[17AXI@A^Hel3IE]G15aBC`A@BDL4@chm13Dc<`@X:B/47R0R0a<H6P@I71l4
92HX12l`<@@i>CX4@d=30de<C0AGEED4HEiN16YWI`AdL704OGUh18J2PAGoool001Coool4VIFD1:>O
WPB]ZZP4]kBc1<6o_P?;b/T4e]GD1>;Qh0C^kN`4no[h1?ooo`?cm?D4i^W[1=WOhPC<eMP4_<S=1:nm
``BU]K`3W:je19>V[PB;X:P4Qi^S18FHW`B2UI`4Oi:J0g^?UPAjSI@4N8ZA17V:T@AgRHl4M8J=0g62
R0A_Oh@4KG^116miOPAaNG`4LWMj17AgM`=eM7@4Mg=b17QaK`AhKV/4M6QU16iSG`=UFeL4G59?1519
A`A3?Sd4=C<c12PY:`@N82834aPJ11TL7`@T9RP4;c0a13Ti>PA3@d<3CDa<15MEE@AQGUh4JVMW17A`
L0AmNGP4QX:15Oooo`005?ooo`BIUI@4XinN1:fZZ0Bg];<4`Knn0l_:b@CFeM@4h^7P1>k]k0Ckn_P4
oooo0o?dm@CVjN/4fMoR1<cEf0Blb<d4[kg31:Fe_0>L[[D4TjJ^18^PZ0B7Vj<4QIRO18:EW0AoTYX3
NhnF17Z=U0AhRY44NHZA17N9S`AdQXd3LH:816moQ0A]Nh44KgUn175iO0AbMgX4M7Mg0gEdM0AgLg84
N75_17Q^J`AdJ6D4KV=O0fEKE`ALDTl4D4U714<n?@@e<c<4:2T[11hP8P<C61X46A`O12@V:0@_<344
>CTj14=3@`==C4`4EeEE165NGPAZIfL4M71`17eiN0B6PX4Eoooo000Doooo19VET`BRWYd4ZjRW1;Fb
/@Bo_;/3bLK51=?Ad0CNg=/4jNSV1?GdlPCoo_d3n_Wi1>c^kPCOhnD4dmWK1<G>d@BjaLT4[kc10jRf
^`BN[[@4UjR_19>SZPB@WjD4S9^Q18VHWP>4U9X4Q9>I17n>U@AnSI<4O8^A17Z8SP=fQ8X4Lh66175m
PPAaNgl4LgYm17=hNPAdMWL3M7Ad17IbL@AeKfd4Lf]Y16iVH`AXH5d3GeME15I?C@A:AD@4?C/k12l`
<@@W:BX47AlR0a`P8P@U9bT4;Bl`13Hg>0A0@444BDQ90e9AD@AKFET4I69Q16eZJ@AfLW44OW]i18N3
PAGoool001Coool4VIFC1::NW@B[Z:L4]K:a1;nl^`?9a/D4dm7@1=kLf`CYj>H4mOCb1?ono@?jnOT4
k>k^1=oSi@CCfM/4aLkA1;[5b@B__<43Z;Jk19j^]0BGZ:l4Tj>Z192OY@B<Vj44RIRN0hBDVPB4TiT4
OhjE17j=T`AlRi44NXR>0gJ4RPAcPHH4LGf2175kO`AcNWd4LgQj17AfM`=dM7@4MW9a17E_K@AcJfT4
KVIS16QPG@=OEeD4ETm=14Y5A0@m>c/4;c0a12LY:P@M7b83720R12DW:@@];c04=SLh1410@@A9B4T3
DU5A15]IF@ATHV44KFYY17IbL@AnNgT4Qh>15Oooo`005?ooo`BIUI<4XYjM1:^XY`Be/[44_kbk0lW6
a@CCdM04g]cK1>WXiPCem?84ookm0o[in@C/k^h4gn?U1=?If`C5c]44^/G91:nl`@>X][/4WZjd19NX
[`BCXjX4T9nU18bKX@B9V9h3Q9BJ18BCV@AoSYD4OXfC17b;T@AjR8h3MXB:17>1QPAaOH84LG]o17=j
O@AcN7X4M7Ig0gAdM0AfLW44MFm]17=[J@A^IV<4J61M0emGE@AFCdd4BTE413dk>`@_<3449bTZ11dO
8P<L82849BLY12d_<0@f=cP4@41114U8B@=BDE44FeUI16ARH@A]JVT4MW9a17ikN@B7Ph4Eoooo000D
oooo19VET`BRWYd4ZjRW1;Fb/@Bo_;/3bLK51=?Ad0CNg=/4jNSV1?GdlPCoo_d3n_Wi1>c^kPCOhnD4
dmWK1<G>d@BjaLT4[kc10jRf^`BN[[@4UjR_19>SZPB@WjD4S9^Q18VHWP>4U9X4Q9>I17n>U@AnSI<4
O8^A17Z8SP=fQ8X4Lh66175mPPAaNgl4LgYm17=hNPAdMWL3M7Ad17IbL@AeKfd4Lf]Y16iVH`AXH5d3
GeME15I?C@A:AD@4?C/k12l`<@@W:BX47AlR0a`P8P@U9bT4;Bl`13Hg>0A0@444BDQ90e9AD@AKFET4
I69Q16eZJ@AfLW44OW]i18N3PAGoool001Coool4V9BC1:6MW0BZYZD4/k2^1;bi^0?5`l44clg;1=WG
ePCTh^04kng[1?[im`?no?/4l_7a1>GWj0CJgMl4cM?E1<;;cPBi`/H3/kg11:Vf^PBQ[k@4WZZ_19VU
ZPBEXJD4TIjR0h^IWPB;Ui`4QY>H18BAU@B1SI<4OXZ?0g^7S0AgPhL4MH2417AmP@AeNgh4MGUk17Af
N0=cM7@4MG9a179^K@A_JFP4JF=Q16=MF`=JEE<4D4a;14A2@P@h>3T4;Bl`12@V:0@R9BL3:2X/12la
<P@f=cT4?Sm014I6A`A?CTh3EeIF15mMG@AWIF@4Kfe/17MdL`B0O7/4R8>25Oooo`005?ooo`BHU9<4
XIfL1:ZVY@Bc/:h4_;Vh0lG3`@C?cL/4fMOF1>CRh0C_kN/4n_Wg0okln`CblO44iNOX1=[Mg`C=dmD4
`/_>1;W2aP>c_L44ZKJj1:6_]0BNZZl4VJFZ19FQY@BAWZ83RiVN18^GW0B6TiP4Q96E186=T`AnRXl3
NhN<17N3Q`AeP8@4M7f117EkOPAeNG/4M7Ih0g=dM0AeLW44LVi]16mYJ0AYHf44HeeK0eYED`A@C4/4
A49213Ph>@@];c0492HX128U9`<X:R`4;c4b13Hg>@@n?d04ATI714m>CP=GEUH4GeeM16MUI0A_KF`4
MgAc181lN`B8Ph8Eoooo000Doooo19RDT`BQWI`4ZZJU1;>`[PBl^KP3aL?11<o=b`CIemH4i>;P1>o]
j`CjnOL3o_ck1?;al@CUinP4f]gO1<gCe@C2blh4^L;60k>m`@BY][X4XJnd19jZ[`BIYJX4UJ6U196N
XP>;VIh4RiNL18JCV0B4TID4PHfC17j:S`=kQh`4Mh>717F0Q0AdOH44MG]n17EiN`AdMWP3LgAd17Eb
L@AbKVd4KfUX16USH@ASGE/3FUEC151<B`A4@T84>3Pi12d_<0@T9RP48RDW0bPZ;0@_<C84=SLi13ho
@0A6ATL4Cdi>0eMFEPAOGEd4IfET16m]K0AgM7<4P7ak18R3PQGoool001Coool4V9BC1:6MW0BZYZD4
/k2^1;bi^0?5`l44clg;1=WGePCTh^04kng[1?[im`?no?/4l_7a1>GWj0CJgMl4cM?E1<;;cPBi`/H3
/kg11:Vf^PBQ[k@4WZZ_19VUZPBEXJD4TIjR0h^IWPB;Ui`4QY>H18BAU@B1SI<4OXZ?0g^7S0AgPhL4
MH2417AmP@AeNgh4MGUk17AfN0=cM7@4MG9a179^K@A_JFP4JF=Q16=MF`=JEE<4D4a;14A2@P@h>3T4
;Bl`12@V:0@R9BL3:2X/12la<P@f=cT4?Sm014I6A`A?CTh3EeIF15mMG@AWIF@4Kfe/17MdL`B0O7/4
R8>25Oooo`005?ooo`BHTi84X9bJ1:RTX`B`[J`4^KJe0l:o_PC;b<L4e=;@1=kLfPCXi^D4lo;`0ogk
nPCfm?<4jn_[1>3RhPCEf=X4b/oA1<78b`>l`lH4];g01:bf^@BX/K@4XJZ]19fWZ@BIXZD3U9jR196K
WPB=Ui/4RYBG18J@U0B3S943P8V=17^5R@AiPXH4N7n217QmP0AgNW`4MWQi0gEeMPAeLW84LFi]16]W
I`AUHF04GU]J0eECDPA;BTX4@41113@f=`@Y;2d49bT[12d_<0<b=3D4>3Tj13lo@0A6ATL4CDe=15AC
E0=LFUX4Hf5Q16]XJ0AbKfh4NWIe185mO0B8Q8<Eoooo000Doooo19RCTPBPW9X4Z:BS1;2][0Bi][D3
`[nn1<_8a`CDd]04g]cJ1>SVi@Ccl_03oO_j1?Kdl`C[jn/4h>;R1=GHfPC:cm44`LS;0kc3aPBd_L04
[;Ji1:Ra]0BQZZd4WJNY19VRY@>DWZ84TI^N18fGV`B:U9L4QY2D18><T@>0RHd4NhF917V2QPAhOh84
N7f017MjO0AfN7T3MGEf17EbLPAaKVd4JfMW16EQH0ANFeX3EE=B14]:BPA0@444=3Hg12T/;@@W:B/4
;Bl`0c8d=@@h>CX4?cm014I6A`A=CDd4E5=D0eaJFPASHF44JfQX179_KPAjMWD4PGel18R4PaGoool0
01Coool4V9>B1:2LVPBXY:<4/:f/1;Vf]@?2_kh4blS71=CBd0CNg=X4j>KU1??bl0?mnoX4m_Cc1>_[
j`CPh^84eMSJ1<[?d@C1b</3_<?61;Bm`0B/][T4Z;6d1:6Z[@BMYjT4VJ:U0iBNXPBAVih4SINK18ZD
U`B6T9@4PhbA0h29S@AkQHT4NH:617QoPPAhOH04MgYl17IhN@=eMGH4MG9b175^K@A[IfL4IF5P15iK
FP=EDe84BdY:1410@@@d=SL4:B`]12LY:`@];c03<S@e13Pi>P@o?d04ATI714e=C@ADDe@3G5YJ16=Q
H@A[J6P4LVm^17YfM@B1OG`4R8B35Oooo`005?ooo`BHTi84X9bJ1:RTX`B`[J`4^KJe0l:o_PC;b<L4
e=;@1=kLfPCXi^D4lo;`0ogknPCfm?<4jn_[1>3RhPCEf=X4b/oA1<78b`>l`lH4];g01:bf^@BX/K@4
XJZ]19fWZ@BIXZD3U9jR196KWPB=Ui/4RYBG18J@U0B3S943P8V=17^5R@AiPXH4N7n217QmP0AgNW`4
MWQi0gEeMPAeLW84LFi]16]WI`AUHF04GU]J0eECDPA;BTX4@41113@f=`@Y;2d49bT[12d_<0<b=3D4
>3Tj13lo@0A6ATL4CDe=15ACE0=LFUX4Hf5Q16]XJ0AbKfh4NWIe185mO0B8Q8<Eoooo000Doooo19NC
T@BOViT4YZ:Q1:jZZ@Bf/k43_[^i1<K3`PC?c</4f=GD1>7Og@C[jNL3m_?b1?Wfm@Caknh4i^KU1=cL
g@CBe=D4bLg>0lC9bPBn`l@4]kbn1;:g^0BY/;84YJ^]1:2WZ@>LXjD4UijP19BKW@B@UiX4S9>F18N?
TP>4Rhl4P8N:17f4Q`AjP8<4O7n117UkOPAhNG/3N7Mh17IdM0AaKVh4JVQW16=QH0ALFUT3DU5B14Q9
BP@o@444=3Hh12//;@@a<S@4=SLi0c`l?@A1@T84AdM814e=C@ADDe<4FUUI0f5OG`AXIFD4KVa[17Eb
L@AlN7L4PWim18V5PaGoool001Coool4Ui>A19nKV@BVXZ44[ZZY1;Jc/@>n^kT4a/?21<o<b`CHeM@4
hMoM1>_Yi`?flo84nOKe1?7_kPCVi^D4g=cM1=;De@C9cLh3a<W:1;k3a0Bg_;h4/[Nh1:V`/PBUZjd4
X:NY0ibSY@BGWZ04U9^M192GVPB<TiH4QhnB0hB;S`B0QhX4OHB717Z0P`AlOh44NG]n17QiN`=hMgP4
MWAd175^KPAZJ6L4Hf5P15aJF@=BDE84B4U:13m0@@@d=SP4:b`]134b=0@f=cT3?3`m1452@PA7AdP4
CDe=15ACD`AJFET3HEmO16QUI@A^K6/4MG9a17ahM`B2OWd4RHF35Oooo`005?ooo`BGTi44Wi^I1:JR
X@B^ZZT4][>a0kjk^@C6`l84clc;1=SEe0CQgmd4jnWW0oKclPCim_D4lNo^1>KVi@CLg=d4d]CE1<W=
cP?4bLX4_/?41;Nl_PBb]kP4ZK2b1:F[[@BPYjT3W:>U19NNX0BDVid4T9NJ18bCUPB7Si83Q8^?1827
RPAmQ8L4NX2317aoP@AiNgh4N7Uk0gQgN0AfM7@4LFi^16YXI`ASHF04G5YI0e9ADPA8BDX4?d1113@f
>0@[;2d4<C8d13Hg>@<l?3d4@D9214M7B0A=CDd4E5=C15YIF@=QGel4J6EU16i/J`AeLW44O7Qg189n
O@B9QH<Eoooo000Doooo19JBT@BMVIP4Y:2O1:^XYPBb[jd3^[Ne1<6n_@C9a/@4dLk=1=[Ge@CRgmd3
jnSV1?C`kPCfl_04kN[X1>;Qh0CGf=L4cm7A0l[<c0C5alP4_/711;Zl_0Bc]KH4[;2a1:N[[0>SYjP4
WZ:S19ZNW`BFVY`4TIJH18bAU0>8SY04Q8V<1825R0AmPH@4OGn117anP0AlOGh3NgUj17MeM@AbKfl4
JfUY169QH@AIFET3DU9B14M9BP@m?d44=CLi13Hf>0@k?3d4@4110dE5APA:BTX4Cdi?15EDE0AJFET4
H5iN0fITH`A/JFT4LVm^17QdM0AnNWT4Q81o18Z5Q1Goool001Coool4UY:A19fIV0BTX9l4ZjRV1;:_
[@>j]kD4`Kjm1<W6a0CAc/d4f]OE1>;Og@?[j>H4m?3^1?Kbl0C]j^P4h^7P1=OHe`C?dM43b/c<1<G7
b0Bn`L44^[bl1;>e]PB//;44Yj^/0j>WZ0BNXZ<4VYjO19JJW0BAUYP4S96D0hR>T0B4RH`4P8F817f1
Q0AmOh44O7j017amOP=kNGX4MgEe179_K`A[JFT4HV5Q15UIF@=BDU84AdU:13do@@@e=cT4=SHh13/l
?@A0@443ADE614Y:BPA?CTl4EEAD15YIF@APGUh3IVAS16aYJ@AbKfh4N7Ad17ijN@B4P7l4RXF45Ooo
o`005?ooo`BFTY44WIVH1:BPW`B[Z:H4/Zn]0kZg]@C1_[d4bLK41=7>c@CJemD4h]oM0n_XiPCdl>h4
m_;`1>gZj0CRhN04emSG1<oAd@?:c<`4aLO81;k1`@Bj_;`4/kFf1:b`/@BWZj`3XjNX19jRX`BJWYl4
UYZL196FV0B<TI@3R8j@18B9S0B0QHP4OH6417eoP@AlOX04O7en0g]iNPAgMGD4LVm_16]YJ@ARHF44
FEUI0e9BDPA7BDX4?Cm113Dg>@@f=SP4>c`m1410@@=5ADH4BTY:14m>C`AEE5@4FUUI161NGP=VI6<4
K6UY179_KPAhM7@4OWYi18B0O`B:QH@Eoooo000Doooo19JBT@BMVIP4Y:2O1:^XYPBb[jd3^[Ne1<6n
_@C9a/@4dLk=1=[Ge@CRgmd3jnSV1?C`kPCfl_04kN[X1>;Qh0CGf=L4cm7A0l[<c0C5alP4_/711;Zl
_0Bc]KH4[;2a1:N[[0>SYjP4WZ:S19ZNW`BFVY`4TIJH18bAU0>8SY04Q8V<1825R0AmPH@4OGn117an
P0AlOGh3NgUj17MeM@AbKfl4JfUY169QH@AIFET3DU9B14M9BP@m?d44=CLi13Hf>0@k?3d4@4110dE5
APA:BTX4Cdi?15EDE0AJFET4H5iN0fITH`A/JFT4LVm^17QdM0AnNWT4Q81o18Z5Q1Goool001Coool4
UY6@19bHUPBRWYd4Z:FS1:n[ZP>e/[04_;Vg1<?0_PC:alD4d/k=1=WFe0?PgM/4j>CR1>o/jPCakN/4
j>CS1=gKfPCDdm83cLg<1<[9b@C5aL@4`L2n1;Zj^@Bc/k<4[Zn^0jRYZPBTYJD4X::R19^MWPBFVIX4
TIBF0hb@TPB8S8h4PhN917n2Q0AmP844O7j017mnO`=nO7`4N7If17=aL@A/JVX4HV5R15QIFP=ADU84
BD]<13m1@P@n?Sl4@T9314E5APA:BDX3CTe>159ADPAGEUH4G5YJ161OG`AVHf<3JfQX171]K@AeLW44
NWMf181lN`B5PH04RXJ55Oooo`005?ooo`BFTI04W9RF1::NW@BXYJ<4[j^Z0kFb/0Bl^KL4`l2n1<[7
a@CBc/d4fMKD0n3Mf`CXi>84kncZ1?7]j`CXi><4gM_J1=CCdP?=cL`4b/W91<G5a0C1`;h4^[Zi1;>c
/`B^[jh3Z:VZ1:BUY@BPXZ84VifN19JIVPBAU9H3S92B18R<SPB3QhT4Oh:417f0P@AlOX04Ogio0gil
O0AhMWH4Lg5a16aZJPARHF84F5UJ0e5BDPA9Bd`4?d5213hn?`A2@T<4ADE614Y9BP=>CDh4DU5B15MF
EPALFUX4H5mO16ISH`=[J6P4L6e]17EbL@AjMgH4P7ak18F1P0B:QXDEoooo000Doooo19JAT0BLV9H4
XYjM1:RUX`B_ZjX3]K:`1;bi]`C3`;h4b/O51=;>c@CIe]@3h=gK1>SThPC_k>X4lNg[1>STh`CMfmX4
e=?B0lg=c0C:bLT4aLG41<70_PBj^[T4/k>c1:j_[P>XZJX4Y:FU1:2RXPBKWIh4UYVJ196DUP><T984
R8b>18>7R@AoPX@4OH2117anP0AoOWl3OWal17QfMPAcLG44K6YZ169QHPAHFEX3DE9B14U;C0@o@D84
?Sho1492@`A5ADH4BTU:0di=CPABDE84EeIF15aJFPAPGel4IV=S0f]XJ0A`KFd4MG9a17YgMPB0O7/4
QH6018Z6QAGoool001Coool4UY6@19bHUPBRWYd4Z:FS1:n[ZP>e/[04_;Vg1<?0_PC:alD4d/k=1=WF
e0?PgM/4j>CR1>o/jPCakN/4j>CS1=gKfPCDdm83cLg<1<[9b@C5aL@4`L2n1;Zj^@Bc/k<4[Zn^0jRY
ZPBTYJD4X::R19^MWPBFVIX4TIBF0hb@TPB8S8h4PhN917n2Q0AmP844O7j017mnO`=nO7`4N7If17=a
L@A/JVX4HV5R15QIFP=ADU84BD]<13m1@P@n?Sl4@T9314E5APA:BDX3CTe>159ADPAGEUH4G5YJ161O
G`AVHf<3JfQX171]K@AeLW44NWMf181lN`B5PH04RXJ55Oooo`005?ooo`BETHl4VYJE1:2LVPBVXZ04
ZjNV0k6][0Bg/k84_KZh1<?0_PC9a/@4d<c;0mKCd@CMfML4hmoM2>[Vi0CRgM/4fMGC0lo>c0C;bLP4
b<K41<G2`0Bn_;X4^;Je1;>b/@>^[J`4ZZRW1:FUY0BPX:04VY^K19FGV0>@TY<4SHj@18N:R`B2Q8H4
Oh6317ioP@B0Ogl3O7]l17MfMPAcLG44K6Y[169RH`AJFU/3DE9C14]<C@A7AdP4BTU:14a<C0A@Cdl4
De9B0eMEEPAJFET4GUeM169QH0AWIF@4JfUX0fm]K0AdLG04N7Ed17ejN@B2OWd4QX:118^7QAGoool0
01Coool4UI6?19ZFU@BPW9X4YZ:P1:^WYP>a[J`4]k>b1;fj^0C3`;h4bLK41=3<b`?Fdm44gMWG1>?O
g@SZi^@4h]gK1=WEd`??c/`4blW81<S6a0C5`/04_[bj1;Rf]@Bc/[43[Zf/1:ZXY`BUYJ@4X:2P19ZK
V`BEUiP3T9:C18f>T0B7RX/4PXB617n1P`AnOh44P7mo0gakO0AgMWH4Lg5a16aZJ`ARHV<4FUYK0e5B
D`A;C4d4AdM814Y9BPA<C4`4D4m?15=BDP=GEEH4FUUI15iMG@ARHF04IfET16]YJ0=_KF`4M75`17Qe
M0AmNWT4PWim18J2P@B;QhDEoooo000Doooo19FAS`BJUYD4X9bJ1:JRX0B[YjH3/Jf/1;Nc/PBm^[P4
`l2n1<W6a0C@c</3e]?A1=gIe`CSgmd8j^KT1>;Mf`CIeM<3clk<1<_9b0C8a/@4aL;01;jl^PBh][D4
/k:a0jj][0BZZ:L4YJFT1:2PX0BJVi/4UINH0i2BT`B=SY04QhZ;18:4QPAoPH<4OWn1181oO`=lNg`4
MgIf17=aL@A/JV/4HV9S15YJF`=ADU<4Bda=14M7B0A:BDX4C4a<151?C`ACDU83EeEF15YIF@ANGEd4
HV5P16MUI0A[JFP3Kfe/17AaL0AhMG@4OGYi189nO@B6PX44RhN55Oooo`005?ooo`BETHl4VYJE1:2L
VPBVXZ04ZjNV0k6][0Bg/k84_KZh1<?0_PC9a/@4d<c;0mKCd@CMfML4hmoM2>[Vi0CRgM/4fMGC0lo>
c0C;bLP4b<K41<G2`0Bn_;X4^;Je1;>b/@>^[J`4ZZRW1:FUY0BPX:04VY^K19FGV0>@TY<4SHj@18N:
R`B2Q8H4Oh6317ioP@B0Ogl3O7]l17MfMPAcLG44K6Y[169RH`AJFU/3DE9C14]<C@A7AdP4BTU:14a<
C0A@Cdl4De9B0eMEEPAJFET4GUeM169QH0AWIF@4JfUX0fm]K0AdLG04N7Ed17ejN@B2OWd4QX:118^7
QAGoool001Coool4U92>19VET`BNVYP4XinM1:NTXP>/ZJL4/Zj/1;Nc/@Bl^;L4`Kjl1<O3`@?<b<H4
d/k<1=OCd@CMfMH4hmoM1>?Nf`CKe]@3dLg;1<_8aPC7a<84aL6o1<2l^PBi][@4]K:a0k6^[@B^ZjT4
ZZNV1:BRX@BNWYd4VYVI0iBDU@BATI84Rhb>18V9RPB1PhD4PX>318>1PP=oOGd4NgQh17EcL`A]K6`4
IVEU15]LG@=DEED4De=B15=BD`AEE5@4EeIF15UHF0ALFe/3GeeM169PH0AVI6<4JFMW16eZJPA`KVd3
M75a17QeM0AlNGP4P7ak18B0O`B8Q884S8N65Oooo`005?ooo`BDT8h4VIFC19jJV0BSWid4YjBR0jbY
Y`Bb[Z`4]k>a1;bh]`C1_[`4al?10lc8aPCBc/`4em?A1=gIePCSgmd4hmkK1=_Fe0?AcL/4blS61<O4
`PC5`Kl4`;bj1;Vf]0Be/[43/Jj]1:j[Z@BZYjH4Y::Q19jNW@BJVIT3U9BE196ATPB;S8h4RHV:1863
Q@B2Ph<4Ph620gmmO@AkN7P4MG=c16e/K0AVIFD4FeaM0eAEE@ACDe84De9C15EDE0AGEUH4FEQH15aK
F`=OGEd4HV1P16ITH`AYIfL4KFYZ171^K@=dLG44N7Ed17aiN0B0O7/4Q81o18R4PPB<QhHEoooo000D
oooo19B@SPBIUI<4WYZH1:>OW@BWY:83[:VW1;:^[0Bg/k44_;Rg1<6n_0C7`l43c<S61=;>c0CGdm44
gMWF1>?Og@CSg]/4fmKD0m7=b`C;b<H4alC21<G1_`C0_;X4^KJd1;Fb/@>a[Zd4[Z^Y1:ZWYPBTXZ44
WYjM19ZIV@>DU9D4TI6B18^<SPB9RHX4PH>518:3P`B3PH83Ogem17]hN0AeLg<4KFa/16IUI@AKG5d3
E5EE15=CDPACDU<4EEAD15MFEPAIF5P4G5]K0emMG@ARH604IVAS16UWI`A]JVX4L6i]0gAaL@AhMG@4
O7Uh181lN`B4P7l4R8B218b7QQGoool001Coool4U92>19VET`BNVYP4XinM1:NTXP>/ZJL4/Zj/1;Nc
/@Bl^;L4`Kjl1<O3`@?<b<H4d/k<1=OCd@CMfMH4hmoM1>?Nf`CKe]@3dLg;1<_8aPC7a<84aL6o1<2l
^PBi][@4]K:a0k6^[@B^ZjT4ZZNV1:BRX@BNWYd4VYVI0iBDU@BATI84Rhb>18V9RPB1PhD4PX>318>1
PP=oOGd4NgQh17EcL`A]K6`4IVEU15]LG@=DEED4De=B15=BD`AEE5@4EeIF15UHF0ALFe/3GeeM169P
H0AVI6<4JFMW16eZJPA`KVd3M75a17QeM0AlNGP4P7ak18B0O`B8Q884S8N65Oooo`005?ooo`BDShd4
Ui>A19^GUPBPViX4Y:2N0jRTXPB/Z:H4/:b[1;Fa[`Bi]K<4_[Zh0l:n_0C7`l44blO51=3<b@CDd<h4
f]GB1=WDd@?Dcl`4blO41<G1_PC1_KX4_[Zh1;Vf]0Be/[03/jn]1:nZZ@B[Z:D4YjBS1:>QW`BNViX3
V9JG19BBTPB?Si04SHb<18F6Q`B5QHD4Ph:20h1nOPAlNGT4MWAd16m^KPA[JFT4GUiN0eaKF`AMG5`4
GUeM15mNGPAQGel4Hf5Q16ESH`=XIFD4JVQW16eZJPA`KFd4Lg1_17IcLP=iMWD4O7Uh17mlN`B2Ogh4
QX:018V5P`B<R8HEoooo000Doooo19B?S@BGTi44ViNF1:2KVPBTX9h3Z:BR1:bXYPB`[:/4]K6_1;Ve
/`Bn^[P3`[jl1<O3`@C;alD4d<c91=C@cPCJeM84fMCA0mC?c0C;al@4aL6n1<6m^PBn^[P4^KJd1;Fb
/0>c[jd4[jZY1:^XY@BWY:<4Xj6O19jKVP>HUYL4U9:B18n?T0B=S8`4QHJ718F5Q@B3PX83P7in17ai
N@AfM7@4Kfi^16]YJ@ANGUh3G5]K15eLG0ANGEd4GeiN165OG`ASHF44IF=S0fQUI@AZJ6L4KFYZ171]
K@AcL6l4MW=b0gUfM@AlNGP4Ogak189oOPB6PX04RHF318b8QQGoool001Coool4U8n=19NCT@BKUiH4
X9^J1:BPWP>XY:84[:RV1;2/Z`Be/Jl4^KFc1;jj^0?2_[`4al?11<_7a@C@c<T4e=3>1=[EdPCIe=43
e<o<1<_7a0C5`Kh4`Kfj1;jj^0Bi][@4]K:`0k>_[@B_ZZT4ZjRU1:NTX`BSXIl4WY^J0iRFU`BDTY84
Shn@18f<S0B5QXL4QHF518>2PP>0OWh4O7Ui17IdM0A_KVh4JfUY15iNGP=LFe/4GEaL15iMG@AOGUh4
HEmO16=QH@AUHf<3J6EU16YXI`A]JVX4L6e]17=`K`AfLg83NGIe17aiN0AoO7/4PWmn18J2P0B9QH<4
S8R65Oooo`005?ooo`BDShd4Ui>A19^GUPBPViX4Y:2N0jRTXPB/Z:H4/:b[1;Fa[`Bi]K<4_[Zh0l:n
_0C7`l44blO51=3<b@CDd<h4f]GB1=WDd@?Dcl`4blO41<G1_PC1_KX4_[Zh1;Vf]0Be/[03/jn]1:nZ
Z@B[Z:D4YjBS1:>QW`BNViX3V9JG19BBTPB?Si04SHb<18F6Q`B5QHD4Ph:20h1nOPAlNGT4MWAd16m^
KPA[JFT4GUiN0eaKF`AMG5`4GUeM15mNGPAQGel4Hf5Q16ESH`=XIFD4JVQW16eZJPA`KFd4Lg1_17Ic
LP=iMWD4O7Uh17mlN`B2Ogh4QX:018V5P`B<R8HEoooo000Doooo19>>S@BFTI04VIFC19bHUPBPViX3
XinM1:JRX@BZYZ@4[JVX1;6]Z`Bd/:l3^;Bb1;bg]PBo^kT4`kjl1<K2_`C:aL84c<O40lk8aPC<a/<4
`kjk1;jh]@Bg];84]K6`1;>^[@>a[J/4[ZVW1:ZVY0BWXj84YJ6O1:2LVP>KV9P4UY>C19:@T@B>SHd4
RXV:18N7Q`B5Q8@3PX2017ikN`AiMgL4LW1a16i/K0AWIFD;J6IV16UWI`A[J6P4K6YY16i[J`=`KFd4
LVm^17AaL0AfLg84NGEe17]hM`=mNWT4P7ak18=oOPB5PH04R8B218Z6Q@B=RHLEoooo000Doooo19>>
S@BFTI04VIFC19bHUPBPViX3XinM1:JRX@BZYZ@4[JVX1;6]Z`Bd/:l3^;Bb1;bg]PBo^kT4`kjl1<K2
_`C:aL84c<O40lk8aPC<a/<4`kjk1;jh]@Bg];84]K6`1;>^[@>a[J/4[ZVW1:ZVY0BWXj84YJ6O1:2L
VP>KV9P4UY>C19:@T@B>SHd4RXV:18N7Q`B5Q8@3PX2017ikN`AiMgL4LW1a16i/K0AWIFD;J6IV16UW
I`A[J6P4K6YY16i[J`=`KFd4LVm^17AaL0AfLg84NGEe17]hM`=mNWT4P7ak18=oOPB5PH04R8B218Z6
Q@B=RHLEoooo000Doooo19>>S@BFTI04VIFC19bHUPBPViX3XinM1:JRX@BZYZ@4[JVX1;6]Z`Bd/:l3
^;Bb1;bg]PBo^kT4`kjl1<K2_`C:aL84c<O40lk8aPC<a/<4`kjk1;jh]@Bg];84]K6`1;>^[@>a[J/4
[ZVW1:ZVY0BWXj84YJ6O1:2LVP>KV9P4UY>C19:@T@B>SHd4RXV:18N7Q`B5Q8@3PX2017ikN`AiMgL4
LW1a16i/K0AWIFD;J6IV16UWI`A[J6P4K6YY16i[J`=`KFd4LVm^17AaL0AfLg84NGEe17]hM`=mNWT4
P7ak18=oOPB5PH04R8B218Z6Q@B=RHLEoooo000Doooo19:=S0BDT8h4Ui:A19VET`BLUiH3WYZH1:6M
V`BSWid4YZ:P1:VTX`B[YjD3[ZZX1;6/ZPBc[jd4][6_1;Rd/PBk][<4_KRe0kji]PC1_;P4_KNe1;Zd
/@Be/Jh4[j^Z1:fYY`>]Z:L4ZjJT1:RTXPBVXIl4XinM19nKVP>MVIP4V9FE19FBTPBASXh4SHb<18Z9
R@B7QHD3Q8:217ilO0AnNg/4NWMg17EbL@AcL707LW1_17=`K`AcL704M75a17EbLPAfLg<3N7Ed17Uf
M@AkN7L4OGUh17ikNPB0OG/3PWim18B0O`B6PX44R8B218Z6Q0B<QhH4SXV85Oooo`005?ooo`BBSH`4
U92>19NBT@BIUI<4W9NF0ijJV0BQWI/4XinM1:JRX0BYY:<4ZjNU0jjZZ0Ba[:X4/jn]1;Ja[`Bh];84
^kJc1;fh]@>n^KH4`Kbh1;fg]@Bj];44]K6^1:n[ZPB]ZJL3[JRW1:^VY0BXY:84YZ6O1:>OW@BOViX3
WIVH19REU@BETY84THj>18f<S0B:RHT4QhF50hB2PPAnO7`4OW]k17YgM`AeLW44Lg1`1g9`K`AcL6l4
Lg1`17AaL@AeLW84MW=c0gQeM0AiMWD4NgQg17eiN0AnNgX4P7ek0h9nO@B4P7l4QX:118R4PPB:QX@4
S8N618j9R1Goool001Coool4TXf<19B@SPBGTY44VIFC19bGUP>NVYP4XIfK1:>OW@BVXZ04ZJBS1:^W
Y@>^ZZP4/JbZ1;>_[@Bf/Jl4^;Bb1;^f/`Bm^;D3_[Vf1<6l^0Bm]kD4^[Ba1;Fa[PB_ZjX4[JVW0jfX
Y`B[YZ@4Z:BR1:JQW`BSWid4Wi^J0ifIV0BHUID4UI:B196>SPB=S8`4RXV918N5Q@>4PX84OWal17ik
N`AjMgL4MG9a17=`L0MbL6l4Lg1_17=`L0AdLG44MG9b17IcL`=hMG@4NGIe17]hM`AmNGP4OW]j181m
N`>2OWd4Q81o18J2P@B8Q884RXJ418b7QPB>RHPEoooo000Doooo19:=S0BDT8h4Ui:A19VET`BLUiH3
WYZH1:6MV`BSWid4YZ:P1:VTX`B[YjD3[ZZX1;6/ZPBc[jd4][6_1;Rd/PBk][<4_KRe0kji]PC1_;P4
_KNe1;Zd/@Be/Jh4[j^Z1:fYY`>]Z:L4ZjJT1:RTXPBVXIl4XinM19nKVP>MVIP4V9FE19FBTPBASXh4
SHb<18Z9R@B7QHD3Q8:217ilO0AnNg/4NWMg17EbL@AcL707LW1_17=`K`AcL704M75a17EbLPAfLg<3
N7Ed17UfM@AkN7L4OGUh17ikNPB0OG/3PWim18B0O`B6PX44R8B218Z6Q0B<QhH4SXV85Oooo`005?oo
o`BASH/4Thj<19B@SPBFTY04V9>B0iVET`BKUiD4WIRG19jJV@BPW9X4XYjL0jBOWPBVXIl4Yj>Q1:VU
X`B[YZ@4[:NU1:fYYP>^ZZL4[jZW1:jYYPB]Z:D4[ZRU1:RTXPBVXYl3YZ:P1:FQW`BVXIl4Y9nM19nK
V@BLVIP3VYJE19NDT`BFTY44TXn?18n=S0B=RXT4QhF40hV6Q@B4PH04PWmn185mO@AnNgX4OGYi2gai
N0AmNGT4OGYi17ikNPAoNgX3P7ak185mO0B2OWd4Pgmn18B0O`B5PH03Qh>118R4PPB9QH@4RXJ518b7
QPB=RHL4SXZ85Oooo`005?ooo`BASH/4Thj<19B@SPBFTY04V9>B0iVET`BKUiD4WIRG19jJV@BPW9X4
XYjL0jBOWPBVXIl4Yj>Q1:VUX`B[YZ@4[:NU1:fYYP>^ZZL4[jZW1:jYYPB]Z:D4[ZRU1:RTXPBVXYl3
YZ:P1:FQW`BVXIl4Y9nM19nKV@BLVIP3VYJE19NDT`BFTY44TXn?18n=S0B=RXT4QhF40hV6Q@B4PH04
PWmn185mO@AnNgX4OGYi2gaiN0AmNGT4OGYi17ikNPAoNgX3P7ak185mO0B2OWd4Pgmn18B0O`B5PH03
Qh>118R4PPB9QH@4RXJ518b7QPB=RHL4SXZ85Oooo`005?ooo`BASH/4Thj<19B@SPBFTY04V9>B0iVE
T`BKUiD4WIRG19jJV@BPW9X4XYjL0jBOWPBVXIl4Yj>Q1:VUX`B[YZ@4[:NU1:fYYP>^ZZL4[jZW1:jY
YPB]Z:D4[ZRU1:RTXPBVXYl3YZ:P1:FQW`BVXIl4Y9nM19nKV@BLVIP3VYJE19NDT`BFTY44TXn?18n=
S0B=RXT4QhF40hV6Q@B4PH04PWmn185mO@AnNgX4OGYi2gaiN0AmNGT4OGYi17ikNPAoNgX3P7ak185m
O0B2OWd4Pgmn18B0O`B5PH03Qh>118R4PPB9QH@4RXJ518b7QPB=RHL4SXZ85Oooo`005?ooo`BASH/4
Thj<19B@SPBFTY04V9>B0iVET`BKUiD4WIRG19jJV@BPW9X4XYjL0jBOWPBVXIl4Yj>Q1:VUX`B[YZ@4
[:NU1:fYYP>^ZZL4[jZW1:jYYPB]Z:D4[ZRU1:RTXPBVXYl3YZ:P1:FQW`BVXIl4Y9nM19nKV@BLVIP3
VYJE19NDT`BFTY44TXn?18n=S0B=RXT4QhF40hV6Q@B4PH04PWmn185mO@AnNgX4OGYi2gaiN0AmNGT4
OGYi17ikNPAoNgX3P7ak185mO0B2OWd4Pgmn18B0O`B5PH03Qh>118R4PPB9QH@4RXJ518b7QPB=RHL4
SXZ85Oooo`005?ooo`B@S8X4THf;19:=S0BCSXd4U8n>0iB@SPBETHl4UY:@19NCT@BHU984VIBC0iZE
U0BKUY@4ViNE19bHUPBMVIL4WYVG19jJV0^OVYP4WYZG19jIU`BLV9H4ViNE0ibGU@BKUYD4W9RE19fH
UPBJUY@4VIFD0iNCTPBFTY44UI6@19B@S`BBShh4T8b;18Z7QP>;QhH4RXJ518V5Q0B8Q8<4Qh>218J3
P@n6PX44Qh>128N3PP>8Q884R8B318V5P`B9QH@4RXJ418Z6Q@>;QhD4S8N618b8Q`B=RHL4SXV818j:
R0B?RXTEoooo000Doooo192<RPBASH/4TXf<19>>S@BDShh3U92>19FAS`BFTY04Ui>A19RDTPBIU9<3
VYFD19^FU0BKUiD4W9RF19fIU`BNVIL4WYZH2inJV0BNVYL4WYVG19bHUPBKUiD3W9NE19^FU@BLV9D4
WIRF19ZFU0BIUI@3Ui>B19JBT@BETI04U92?19:?SPB@S8/4RXN60h^7QPB:QXD4RHF418R4P`B7Ph84
QX>13hJ2P@B7Ph48Qh>20hR4PPB8Q8<4RHF318V5Q0B:QX@4RXJ50h^7Q@B<QhH4S8R718f9Q`B>RHP4
SXZ818n:RAGoool001Coool4T8b:196=R`BBSH`4Thj=19B?SP>DT8h4UI6?19JBT0BGTi44V9BB19VD
T`>JUI@4ViJD19^GU@BLV9H4WIVG19jIU`BNVYP;WiZH19jJU`BNVIL4W9RF19^GU@>LUiD4ViJE19bH
U@BMV9H4VYJD19VEU0>GTi84UY:A19FAT0BDT8l4TXn>192<R`B:QhH3RhN618Z6Q@B9QH@4R8B318N3
PPB6Ph4?QX:118N3P@R7Ph83R8B218R4P`B9QH<4RHF418Z6Q0B:QXD3RhN518b7QPB<R8L4SHV718j9
R0B>RXP4ShZ95Oooo`005?ooo`B@S8X4THf;19:=S0BCSXd4U8n>0iB@SPBETHl4UY:@19NCT@BHU984
VIBC0iZEU0BKUY@4ViNE19bHUPBMVIL4WYVG19jJV0^OVYP4WYZG19jIU`BLV9H4ViNE0ibGU@BKUYD4
W9RE19fHUPBJUY@4VIFD0iNCTPBFTY44UI6@19B@S`BBShh4T8b;18Z7QP>;QhH4RXJ518V5Q0B8Q8<4
Qh>218J3P@n6PX44Qh>128N3PP>8Q884R8B318V5P`B9QH@4RXJ418Z6Q@>;QhD4S8N618b8Q`B=RHL4
SXV818j:R0B?RXTEoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo002Ioooo0`0008Coool009coool00`000?ooooooo`21oooo001koooo1000
00;oool400000oooo`800004oooo100000;oool300000oooo`<00003oooo0P0007koool007_oool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`040000oooooooo00000_ooo`040000oooooooo
00000_ooo`030000oooooooo00?oool010000?ooooooo`0008?oool007coool00`000?ooooooo`03
oooo00<0003oooooool01Oooo`040000oooooooo00000_ooo`030000oooooooo00@00002oooo00@0
003oooooool00023oooo001moooo00<0003oooooool00oooo`030000oooooooo00;oool200001?oo
o`<00003oooo0P0000Coool40000P_ooo`00Noooo`040000oooooooo00000_ooo`040000oooooooo
00000oooo`030000oooooooo00Goool00`000?ooooooo`2=oooo001loooo0P0000Coool200001?oo
o`<00004oooo0P0008ooool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(248) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
8C89888C89888C8A888C8A898C8A898C8A898C8A898C8B8A8D8B8A8D8B8A8D8B8B8D8C8B
8D8C8B8D8C8B8D8C8C8D8D8C8D8D8C8D8D8D8D8D8D8D8E8D8D8E8E8D8F8F8D8F908E9193
8D8F8F8D8E8D8D8D8C8D8E8D8D8D8C8E8D8C8E8D8D8E8E8D8E8E8D8F8E8D8F8E8D8F8E8C
8F8E8C8F8C8A8F8B8A8E8A888D89878C88868C87858C86848B85828A838089817F887F7B
857C7788807D89827F8984818A84828A85838A85838A86848B86848B87858B87858B8786
8B88868B88868B88878B8987
8C89888C8A898C8A898C8B8A8D8B8A8D8B8B8D8C8B8D8D8C8E8D8C8E8E8D8E8E8E8E8E8E
8E8F8F8E908F8F90908F91918F91918F91928F92928F93938F93948F94968F95978F979A
8E94968E93938F92928F92928F9191909191919292919392919392929392929291929290
92918F918F8D918D8B8F8B898E89878D87848C85838B83808B807D887D79867A76847670
82746E857974867C78877F7B88807D89817E89827F8983808A84818A85828A85838A8684
8B87858B87858B88868B8887
8C8A888C8B898D8B8A8D8B8B8D8C8C8E8D8C8E8E8D8E8F8E8F8F8F8F90908F90908F9191
90929290939390949490949590959691969791969891979991989A90999C909B9E909CA1
90999C909899909697919696919595929696939696949796939796949796959695949493
93929093908E928F8C918C899089868E86838D83808B807C897C7887787384746E816E67
816F6983746E857772867A76877C78877E7A887F7C88807D89817E8982808A83818A8482
8A85838B86848B87858B8886
8C8A898C8B8A8D8C8B8D8C8C8E8D8D8E8E8E8F8F8F8F9190909191909293909393919495
91959691969792979892989A92999B929A9C929B9D929C9F929DA0929EA2929FA491A1A6
919EA1919C9E929A9B92999A93999A949999959999969A99959A99959A98969897969695
95949295929094908D938C8A9189858F85818D817D8B7D7888787386746D826E677E685F
806C6582706983736D847671857874867A76877C78877D7A887F7C88807D89827F898380
8A84828A85838B87858B8886
8C8A898D8B8A8D8D8C8E8D8D8E8F8E8F9090909191909293919394919595929697929798
93989A93999B939B9D949C9E949DA0949EA1949FA394A0A494A2A694A3A793A3A992A5AB
92A1A5929FA2939E9F939D9E949C9D959C9C969C9C969C9C979D9C979C9B989B9A979997
97969496949196908E958D8A92888590837F8D7F7B8A7A7587756F8570688169617D645B
7F6960816C6582706983736D847570857772867975867B77877D79887E7B88807D89827F
8983818A85828A86848B8786
8C8A898D8C8B8E8D8C8E8E8E8F909090919190939391949592969692979893989A939A9B
949B9D959D9F959EA195A0A296A1A496A2A696A4A896A5AA96A6AB95A7AD94A7AD93A8AE
93A4A993A2A594A1A395A0A1959FA0969F9F979F9F989F9E989F9E999E9E999D9C999B9A
99989698959397918E968E8A94888591837E8E7E798A797387726B836C647F645B7D6258
7F665D806961816D6582706983726C84756F857772867974867B76877D79887E7B88807D
89827F8A84818A85838B8785
8C8B898D8C8B8E8E8D8F8F8F90919190939391949592969793989993999B949B9D959D9F
959EA196A0A397A2A597A3A798A5A998A7AB99A8AD99AAAF99ABB198ACB295ACB393A9B0
93A6AB94A5A895A4A696A3A497A2A398A2A298A1A299A1A19AA1A09AA1A09B9F9E9B9D9C
9A9A989A969499928F978E8A95888592837E8F7C778B77718670688368607E60567D6056
7E645A80675E816A62816D65826F6983726C84746F857771857874867B76877D79887F7C
88817E8983808A85838B8785
8C8B8A8D8D8C8E8F8E8F9090909292919495929697939899949A9B959C9E959EA096A0A2
97A1A498A3A798A5A999A7AB9AA9AE9AABB09BADB39BAFB59CB1B79CB3BA93ACB491A8AF
93A8AD95A7AB96A6A997A5A798A4A699A5A59AA4A49BA4A49BA4A39CA3A29CA1A09C9F9D
9C9C999B97959A9390988E8B96888493827D8F7C768B756E866D6582665D7D5E537D5F55
7E62587F645B80675F816A62826D65826F6983726C84746F857771867974867B77877E7A
88807D89827F8A84828B8785
8D8B8A8E8D8D8F908F909191919394929596939899949A9B959C9E969EA097A0A398A2A5
99A5A899A7AB9AA9AD9BABB09CADB29CAFB59DB2B89EB4BB9FB7BE9FB8C08DA8B191A9B0
94A9AE96A9AD97A8AB98A8AA99A7A89AA7A89BA7A79CA7A69DA7A69EA6A59EA3A39EA09F
9D9C9A9C97959B9390998E8B96888393817C8F7B758B736C866C6482655B7D5C517D5E53
7E60567E62597F655C80675F816A62816D66826F6983726C84756F857772867A75877C78
887F7B89817E8A84818B8684
8D8B8A8E8E8D8F909090929291949593979894999B959C9D969EA097A0A398A3A699A5A9
9AA8AC9BAAAE9CACB19DAFB49EB1B79FB4BA9FB6BDA0B9C0A3BDC497B3BC8EA9B292ABB2
95ACB097ACB098ABAE9AABAD9BAAAB9CAAAA9DAAAA9EAAAA9FAAA9A0A9A7A0A5A4A0A2A0
9F9C9A9D97959C92909A8D8A96878393807B8F7A748B736B876B6382645A7D5C507D5B50
7D5D537E60557F62597F655C80675F816A63816D6682706983736D847570857874867B77
877E7A88807D8983818A8684
8D8C8B8E8E8E8F9191919394929596939899959B9D969DA097A0A398A3A69AA5A99BA8AC
9CABAF9DADB29EB0B59FB3B9A0B5BCA1B8BFA2BBC2A4BFC79CB8C192B0B993AFB695AEB4
97AFB399AEB29AAEB19BADAF9CACAD9DACAC9EADACA0ADACA1AEADA1ABA9A2A7A6A1A3A1
A09D9B9F97959D92909A8C89968682937F7A8E78728A726A876B6282645A7F5D527C594D
7D5B4F7D5D527E5F557E62597F655C806860806B63816E6782716A83746E847772857A76
877C7988807C8983808A8684
8D8C8B8E8F8E909292919494939798949A9B969C9E979FA298A2A59AA5A89BA8AC9CABAF
9DAEB39FB1B6A0B4B9A1B6BDA2B9C0A3BCC4A3BFC7A0BEC794B3BD95B3BC96B2BA97B2B7
99B2B79BB2B69CB1B39DAFB19EAFAF9FAEAE9FAFAEA1AFAEA3B0AEA3ACABA3A8A6A2A2A0
A29E9CA097959F928F9B8B88978581927E798D77718A7169876B6283655B805E537D584D
7C574B7D5A4F7D5D527D5F557E62597F655D7F6860806B64816F6882726C847570857874
867B78877F7C8982808A8684
8D8C8B8F8F8F909292929596939899959B9D969EA098A1A499A4A89BA7AB9CABAF9EAEB3
9FB1B6A1B4BAA2B7BEA3BAC1A4BDC5A5C0C8A6C3CD97B8C296B6BF97B5BD98B4BC9AB4BA
9BB5BA9DB5B99EB4B69EB1B29FB0B0A0B0B0A0B1AFA2AFAEA3ADACA5ACABA4A6A5A4A3A1
A4A19FA29997A092909B8B88968380927D798D7670897068876A6284655B815F547E5A4E
7B55487C574B7C5A4E7C5D527D5F567D62597E665D7F6961806C6681706A83736E847772
867A76877E7B89827F8A8583
8D8C8B8F908F919393929697949A9B969C9E97A0A299A3A69BA6AA9CAAAE9EADB29FB1B6
A1B4BAA3B7BEA4BBC2A5BEC6A6C1CAA8C5CEA2C2CC93B5C096B6BF98B6BF99B6BC9BB7BC
9EB8BDA0B9BCA1B7B8A0B3B3A1B2B2A3B2B19EACABA1ACACA3AAA9A5A9A8A5A8A7A6A5A3
A7A2A0A49B98A295929B8C8996827F917C788C756E896F67866A6185655B826055805B4F
7D56497C54477C574A7B5A4E7B5C527C60567D635A7E675F7F6A63806E6882726C837671
857975877D7A88817E8A8583
8D8D8C8F9090919494939798959B9C979EA098A1A49AA5A89CA9AC9DACB19FB0B5A1B3B9
A3B7BDA5BBC2A6BEC6A8C2CAA9C5CEAAC9D398BBC794B6C096B7C099B8C09AB7BD9DB9BF
A0BBC0A3BCBFA3B9BAA3B5B59FADAEA0ACAD9CA7A7A0AAA9A3A9A8A5A9A8A7ABAAA8A4A2
A8A29FA79E9AA69A979E908C9583808F7A768B746E886D6686696185665C846256815D51
7F574A7C53457B54477A564A7A594E7A5C537B60577C645C7E68617F6C6681706A83746F
847874867C7988817E8A8583
8E8D8C909190929595949899969C9D979FA299A3A69BA7AA9DABAF9FAEB3A1B2B8A3B6BC
A5BAC1A7BEC6A9C3CAABC6CFABC8D1A9C9D491B5C294B6C197B7C19AB8C09CB8BE9FBAC0
A2BDC2A5BDC0A4BABAA5B5B59AA8A99DA9AA9FAAAAA1A9A9A4ACABA6ABABA8ACAAA8A6A3
A9A4A1A89F9BA79C98A1928E9888848E7B778A726D876C6586686086665D856358835E52
80584B7E54457B534678534677554A78594F795D547B61597C665E7E6A63806E6982736E
847773867C7888807D8A8482
8E8D8C90919192959694999A969D9F98A1A39AA5A89CA9AD9EADB1A0B1B6A2B5BAA4B9BF
A6BDC4A9C2C9ACC7CFB1CDD6ABCAD39FC1CD90B4C094B6C198B8C19BB8C09DB9BFA0BBC0
A3BEC2A4BABEA2B6B7A1B1B29BAAAB9FAAABA1ABABA3ABABA5AEADA8ADACA9ADABA9A8A5
A9A4A2A79D9AA79C98A3948E9D8C8792807A88716B866A6486685F87675E876459856053
825A4C7F55477B524378514374504676554B775A51795F567B635C7D68617F6D6781716C
837672857B7787807D898482
8E8D8C909291939696959A9B979EA099A3A59BA6AA9DABAF9FAFB4A1B3B8A3B7BDA5BBC2
A7C0C7AAC5CDAFCBD3B5D1DBA6C7D193B7C393B5C196B7C199B9C19CB8C09EB9BFA1BBC0
A4BDC1A4B9BCA0B2B4A0AFB1A0AEAEA1ADADA3ACADA5ADADA7AEAEA9AEADAAACABAAA9A6
A9A4A1A89E9BA59C96A2948E9E8C8796827C89726D85696486686088685E88655A866154
835B4E8157497F5445744C3F724D4273524775574D775C537961597C665F7E6B6580706B
827570857A76877F7C898482
8E8E8D919292939797969B9D98A0A29AA4A79CA8AC9FADB1A1B1B6A2B5BBA4B9C0A6BDC5
A8C2CAAAC6CFAECCD5AECDD8A1C2CE94B7C396B7C298B8C29AB8C09DB9C09FB9BFA1BBC0
A4BCC0A4B9BCA0B1B3A1AFB0A1AEAFA3AEAFA4AEAEA6AFAFA8B0B0ABB0AFABADABACAAA7
AAA5A2A9A09CA59B95A2938E9D8B8596817B8E766F876B6587696189685F89665B886255
855D4F84594A8356466F47396F4A3D704E4373544A755950785F577A645D7D69637F6F69
82746F847975877E7B898481
8E8E8D919393949798969C9E99A1A39BA6A99EAAAEA0AFB3A2B3B8A4B7BDA5BCC3A7C0C7
A8C4CCAAC7D1AACBD5A7C8D4A2C2CD9CBCC79AB9C39AB8C19CB8BF9EB9BF9FB8BFA1BAC0
A4BBC0A4B9BCA2B3B6A1AFB0A2AEAFA4AFAFA6B0B0A8B0B0AAB1B1ACB1B0ADAFADADAAA8
ACA6A3AAA19CA59A95A0928C9B8A8496817A9078718B6F68896B628A6A608B685C896356
865E50865A4B8557476D45376B463A6E4B4071514773574E765D5479625B7B68617E6D68
81736E847874867E7B898381
8F8E8D929393949899979D9F9AA2A59DA7AA9FACB0A1B1B5A3B5BBA5BAC0A7BEC5A8C2CA
A9C6CFA9C9D3A8CAD6A7C7D2A3C2CD9FBDC79BBAC39BB8C09DB7BF9EB8BFA0B9BFA2BABF
A3BBC0A4B9BDA4B5B8A2AFB1A3AEAFA5AFAFA7B1B1A9B1B1ABB2B1AEB3B1AEB0AEAEACA9
ADA6A2AAA19CA49994A0918B9B898396817A9179728D72698C6F658C6C618C695D896457
885F51875B4C8859486B44366943376B483D6E4E4471544B745A527760597A665F7D6C66
80726D837874867D7A898381
8F8E8E92949495999A989FA09BA4A69EA9ACA1AEB2A3B3B8A5B8BEA7BCC3A8C1C8A9C4CD
AAC8D2AACBD6A8CAD6A7C7D2A3C1CB9FBBC49CB9C29DB7BF9EB7BE9FB8BEA0B9BFA2BABF
A3BABFA5B9BDA5B6BAA4B2B3A4AEAFA6AFB0A8B1B1AAB1B1ACB2B1AFB4B2B0B1AFAFADAA
ADA6A2AAA19CA498939F908A9A888296817A927A728F746B8F71678E6E638C695E8A6558
885F52865C4D885A4A6F47396540336845396C4B4170524873584F765F5779655E7C6B65
7F716C827773857D7A888381
8F8F8E939595969A9B99A0A29DA6A8A0ABAEA2B0B4A5B5BBA7BAC0A9BFC6AAC3CBABC7D1
ABCBD5ABCDD9A9CAD5A7C7D2A1BEC89DBAC29DB8C09DB6BE9EB6BEA0B7BEA1B9BFA2B9BF
A4BABFA5B9BDA6B7BAA5B3B5A4AFAFA6B0B0A9B1B1ABB2B1AEB3B2B0B4B2B1B2AFB0ADA9
ADA6A2AAA09BA498939F90899A8780958179937B7292776E9173698F6F648D6A5E8A6558
876052845B4C835849744B3C6740336440346A483D6E504672564D755D5578635C7B6A63
7F706B827672857C79888380
8F8F8E939595979B9C9BA1A39EA7AAA2ADB0A4B3B7A7B8BDA9BDC3ABC2C9ADC7CFADCBD4
ADCFDAADD0DBABCBD6A6C3CEA0BAC39CB8C19DB6BF9EB6BE9FB6BDA0B7BEA2B9BFA3B9BF
A4B9BEA5B8BDA6B7BAA5B2B5A5B0B1A7B0B0AAB2B2ACB2B1AFB5B3B2B5B3B3B3B0B1ADA9
AEA6A2A99F9BA598929F8F8899877F968179947C7494797092756B8F71658D6C5F8A6659
86605282594B7E5547754C3D6A4032633E3169473B6D4E4471554B745B5377625B7A6862
7E6F6A817571857C79888280
908F8F949696989C9D9CA3A5A0A9ACA4AFB3A7B5BAAABBC0ACC0C7AEC6CDB0CAD3B0CFD8
B0D3DDAFD1DCABCAD4A4BEC99EB7C19BB5BE9CB5BE9EB6BD9FB6BDA1B8BEA2B9BFA3B9BF
A4B9BEA6B8BCA5B6B9A5B2B4A5B0B1A8B1B1AAB3B2ADB3B2B0B6B4B3B5B3B4B3B0B2ADA9
AEA6A2A99E9AA597919E8E879A877F97827A967E75957B7193776C9072678D6C60896659
85605280584B7B5446734A3B6A3F306942346A463B6D4D4270534A735A517661597A6761
7D6E69817570847B78888280
90908F9597979A9E9F9EA5A6A2ABAEA6B2B5AAB8BCADBEC3B0C4CAB2C9D1B3CFD7B4D3DD
B3D5DFB1D1DBAAC7D2A1BAC59BB4BE9AB4BC9CB4BC9DB6BD9FB7BEA1B8BEA3B9BFA4B9BE
A5B9BDA6B7BBA5B5B8A5B1B3A5B0B0A8B0B1AAB2B1ADB4B2B1B6B4B5B6B4B5B3AFB3ADA9
AFA6A1AA9E98A496909F8E879B888199847B988077967C7294786D9173678D6D6189675A
855F537F584A7A544673493B6B40316941336A45396C4B406E5248725850755F58786660
7C6D68807470847B78888280
9190909698989B9FA0A0A6A8A4ADB0A9B4B8ADBBBFB0C2C7B3C8CEB6CED5B8D3DCBAD9E3
B9D8E1B4D1DAA8C4CE9CB6C198B1BB99B2BB9AB3BC9DB5BDA0B7BEA2B9BFA4BABFA5BABE
A6B9BDA5B6BAA5B3B6A4B0B2A4AFB0A7AFAFAAB1B0AEB3B2B2B6B4B5B6B4B6B3AFB4ADA9
AFA6A1AA9E98A59690A090889D8A829B857D998178977D7395796E9174688E6E6189675A
8460537E594B79554772493B6C4334663D2F6843366A493E6D504670574E745E5677655E
7B6C677F736F837A7787827F
9191909799999DA0A1A2A8AAA7B0B2ACB7BAB0BEC2B4C5CAB8CCD2BBD2D9BDD8E0C0DFE8
C0DBE3B4CED7A5C0CA95B1BC93AEB996B0B999B2BB9CB4BCA0B7BEA3B9BFA6BABFA6BABE
A7B9BDA5B6B9A4B2B5A2AEB1A3ADAEA5ADADA9B0AFAEB3B1B3B6B4B6B7B4B7B4B0B5ADA9
B1A6A1AB9E98A79790A3918AA08C839D877E9B8279987E7396796E9274688E6E6289685B
8461537F5A4D7A564871493B6A423464392B66403368473C6B4E446E554C725C5576635D
7A6B667E726E837A7687817F
929191989A9A9EA2A3A4AAACAAB2B4B0BABDB5C2C6B9C9CEBDD0D6BFD6DDC2DCE4C5E1EA
C4DCE4B5CDD5A2BDC78DABB88FABB693AEB897B0B99BB4BCA1B8BEA5BABFA8BCC0A9BBBF
A8BABDA5B6B9A2B0B4A0ADAFA1AAACA3AAAAA8ADADADB1B0B3B6B3B8B7B4B9B4B0B6AEAA
B3A7A1AE9F99AA9991A6938BA28D859F887E9C837A987E7395796E9274688E6F628A695C
856254805C4E7B5749704B3D663F31613628633D30664439694C426C534A705A5374625C
796A647D716D82797687817F
929291999B9BA0A4A4A7ACAEADB5B7B4BEC0B9C6CABECED2C2D5DAC5DBE1C7E0E8C8E2E9
C9DEE5B6CCD49EB9C387A7B48BA8B38FABB594AEB79AB2BAA1B7BEA6BBC0AABDC1ACBCBF
A9B9BCA3B4B89EADB19EACAE9EA8AA9FA5A6A6AAAAADB0AFB4B5B3B9B7B4BBB5B1B9AFAA
B6A9A2B0A199AD9B93A9958DA58F86A189809D847A977D7395796E9374688F6F628A695C
856355815D4F7C584A6F4B3C623C2E5D3224603A2E6342376649406A51496E595173615A
7768637C716C81797586817E
9392919B9C9BA2A5A5AAAFB0B1B8BAB8C1C4BFCBCEC5D3D7CADBE0CBE0E6CBE3EBCAE1E7
CADCE2B4C9D199B5C081A2B086A5B18CA8B392ACB598B0B89EB5BBA5B9BFA8BABEAEBDBF
A9B9BCA0B1B69BAAAE99A8AB9AA4A69CA2A3A5A8A7ADAFADB4B5B3BAB8B5BDB6B2BBB1AB
BAADA5B2A199B19D95AF998FA99289A28A809D847A977D7394796D9274689070628B6A5C
866456835F507C58496C483B5E392C592F225C382C603F3563473E674F476C5750715F59
7667627B706B81787586807E
9493929C9C9CA4A7A7ACB1B1B5BBBCBDC5C7C5D0D2CDDADDD3E3E7D7EAEFCBE2E9CADEE4
C6D8DEB2C6CE95B2BD7C9EAC82A1AE89A6B08FAAB395AEB59BB1B7A2B6BBA5B8BCAABABD
A6B6B9A0B0B49AA9AD97A5A898A2A49EA3A3A5A7A6ADAEADB5B5B3BBB8B5BEB7B2BDB2AC
BCAEA5B6A29AB7A197B59D92A99389A28A809E857B967D7393786D907367906F628D6A5C
8866578660517D5849694639583629552D2159352A5C3D3260443B644C4569554E6E5D57
7466617A6F6B80777486807E
9493929D9D9DA6A8A8AFB3B3B8BEBFC2C9CBCBD5D7D6E1E4E1EFF2DFEFF3CEE2E7C7D9DF
C2D3D9ACC2CA91AEBA789AA97F9EAB85A3AD8DA9B193ABB397ADB39EB1B7A2B5B9A5B6B9
A3B3B7A0AFB39BA9AD98A4A79AA3A49FA4A4A6A8A7ADAFADB5B5B3BBB8B4BEB7B2BEB2AC
BCADA5B9A59CB9A399BAA095A89289A38B819F867B947C7292776C9072669170628F6C5D
8C67588B63537C5748664538533328502A1E543227573A305C4239614A4266534C6C5B56
726460786D6A7F777485807E
9594939E9E9EA8AAAAB2B5B5BCC1C1C6CDCED1D9DBDEE7E9EDF8FAE0EEF1D3E4E8C6D6DC
BBCDD4A3BBC58BAAB67598A67B9BA882A0AA8AA5AE91A8B096ACB29BAEB4A0B1B6A2B3B7
A2B1B59FADB19CA9AC9AA5A89BA2A4A0A5A5A6A9A8AEAFADB6B5B2BCB7B3BFB7B2BFB2AC
BDADA5B9A69DB9A398B79E93AB948AA58D829F867B957D7294786D947467937163926D5E
906A5A8E66557955476243364F33274B261B4E2E2452362D573E365D474063504A695954
70635E776C697E7673857F7D
969493A09F9FAAABABB4B7B7BFC3C3CAD0D0D6DDDEE3EBEDF2FBFDE5F0F3D7E4E8C7D6DC
B6C9D09EB8C287A6B27396A47898A47F9CA686A0A98DA5AD93A9AF98ABB09DADB19CADB2
9EADB19CAAAE9BA8AB9AA5A79BA2A4A1A6A6A8ABAAAFB1AEB6B4B1BCB6B2BFB7B1C1B4AD
BFAEA6BAA69DB7A298B39C92AD958BA88F84A2877C9B8074997B6F987769977365967060
966D5C9067567754455B40344F3328462419482A214C3229523B3358443D5F4E48665752
6E615D756B687C7572847F7D
969594A1A0A0ABACACB6B8B8C2C5C5CDD2D2DADFE0E7EEEFF6FDFEEAF2F4D9E4E8C7D6DC
B4C8CF9CB6C085A4B07296A47495A17B98A3829CA589A0A88FA4AB95A7AC98A8AD98A9AD
9BA9AE9BA8AC9CA8AB9CA6A99FA6A8A4A9A9AAAEADB0B1AFB6B3B0BBB5B0BEB5AFC1B4AD
C1B0A7BDA89FB9A399B29C91AE958AAA9085A68A7EA184779E7F719C7A6B9A76669A7363
9B705F906655745244583F3450342946261B3E231B452D254C373053413B5B4B46635551
6B605C736A677B7472837F7D
969594A1A1A0ADADADB8B9B9C4C6C6D0D3D4DDE1E1EAEFF0F8FEFFECF3F5DBE5E9C8D7DC
B4C7CE9BB5BF85A4B07396A472929F78959F7F99A1869CA38CA0A691A3A894A5A997A6AB
99A8AC9BA8AC9DA9AC9FA9ACA3ABACA6ACACACB0AEB1B2B0B5B3B0B9B4AEBDB3ADC0B2AA
C2B0A7BFAAA1BCA59BB59D93B1978CAC9185A98B7FA48679A181739E7B6C9D78689F7565
A073618D64537351435C41364D332942251B331B143D272045322C4E3D3857484360534F
695E5A7169667A7471837E7C
979594A2A1A1AEAEADB9BABAC5C7C7D2D5D5DFE2E2ECF0F0FAFEFFEDF3F5DEE7EAC9D8DC
B5C8CE9DB6BF87A5B17597A472919E76929D7C969E8399A0899CA28E9FA492A2A796A5A9
99A7AB9CA8AC9EAAAEA1ABAEA5ADAEA9AFAFADB1B0B2B3B0B5B3AFB8B3ADBBB2ABBEB1A8
C0AEA5BFAAA1BEA69CB9A095B3998DAE9286AA8C7FA58779A48273A17D6DA27A6AA37766
A173618B62527351435D41364930273A21192B171035221C3F2E29493A355346415D514D
665C59706865797370827E7C
979594A3A2A1AEAEADBABBBAC7C8C8D3D5D5E0E3E3EDF1F1FBFFFFEEF4F5E0E8EACCD9DD
B7C9CFA1B8C08CA7B37A99A671919D73909A7A939C81969D87999F8C9DA291A0A595A3A7
99A6AA9CA9AC9FABAEA3ADAFA6AFB0AAB1B1AEB2B1B2B4B1B5B3AEB8B2ACBAB1AABDAFA7
BEADA4BEAAA0BDA59BBAA095B59A8EB29588AD8E81A9897AA88475A78170A77D6CA67A68
9F7260896051714F425C3F34452E26331F1825140F2C1C173829254436324F433F5A4F4C
645B586E6764787270827E7C
979594A3A2A1AFAFAEBBBBBBC8C8C8D4D6D5E1E3E3EFF1F1FCFFFFEFF3F4E1E8EACFDBDE
BBCBD1A5BBC291ABB57E9CA873929E718E987891997F949B85989D8B9BA0909FA495A3A6
99A6A99DA9ACA0ACAFA4AEB0A8B0B1ACB2B1B0B3B2B3B4B0B5B2AEB8B1ACBAB0A9BCAEA6
BDACA3BDA99FBCA49ABAA094B79B8FB49689B29183AF8C7DAD8777AC8373AB806EA97B69
9B6F5D845D4E6E4D40593D33422D252D1D171F120E2316123225223F34304B413E574E4B
625A576D6664777270817D7C
979594A3A2A1AFAFAEBCBCBBC8C9C8D5D6D5E2E4E3F0F1F1FDFFFFF0F3F4E2E8EAD1DCDF
BFCED3ABBEC596AEB7839FAA7795A0708D98768F987E939A84969C8A9A9F909EA295A2A6
99A6A99DAAADA1ACAFA5AFB0A9B1B2ADB3B2B0B4B2B3B4B0B5B2AEB8B1ABBAAFA8BBADA5
BDABA2BDA89EBCA499BA9F94B99C8FB79789B59284B38E7FB08979B08574AE816FA87A67
956B5A805A4C694A3E533A303C2922271A15190F0C1C110E2D221F3B322F493F3D554D4A
6059576B656376716F817D7B
989594A4A2A1B0AFADBCBBBAC9C9C8D6D6D5E3E4E3F0F1F0FEFFFEF1F4F4E2E8EAD4DDE0
C3D0D5B1C1C89AB1BA88A3AD7B98A373909A768E977D929984969C8A9A9E909EA195A2A5
9AA6A99EAAACA3ADAFA7B0B1AAB2B2AEB3B3B1B4B2B4B4B0B5B2ADB7B0AABAAEA7BBADA4
BCAAA0BDA79DBCA398BBA094BA9C8FB9988AB79485B58F7FB48B7AB38775AE816FA37664
8F66567A574962453A4C352D35251E2116121109061A110F2A221F39312E473F3C534C4A
5F59576B656376716F817D7B
989594A4A2A0B0AEADBCBBBAC9C8C7D6D6D4E3E3E2F1F1F0FFFFFDF1F4F4E3E9EAD6DEE1
C8D3D7B5C4CAA0B5BC8FA7B07F9BA578939D788F987E929985969B8B9A9E919EA296A2A5
9BA6A9A0AAACA4AEB0A8B0B1ACB3B3AFB4B3B2B5B2B4B3AFB5B1ACB7AFA9B9ADA6BAABA3
BCA89FBCA69CBCA398BB9F93BB9B8EBA988AB99485B79080B68C7BB28674AB7E6C9C7160
8961537151445B41364430292E201B1A110E0B04031B13122A222038312F453F3D524C4A
5E59576A656375716F817D7C
979594A3A1A0B0AEADBCBBB9C9C8C6D6D5D3E3E3E1F1F0EFFFFFFDF1F4F3E5E9EAD8DFE1
CBD5D8B9C7CCA7B9C096ACB4869FA97F98A17B929B7F929A86979C8C9B9F929FA298A3A5
9DA7A9A1ABADA5AFB0AAB1B2ADB3B3B0B4B2B2B4B1B4B3AFB6B0ABB7AEA8B8ACA5B9AAA2
BBA79EBBA59ABBA297BB9E92BB9B8EBA9789BA9485B99080B68B7AB08472A67A69946B5C
805C4E694B40533B323D2B25261A16120C0A0903031A15132A2322383230453F3E524C4B
5E59576A6564757170807D7C
979594A3A1A0AFADACBBBAB8C8C7C5D5D4D2E2E1DFF0EFEDFFFEFCF3F4F4E7EAEADBE0E1
CED6D9BFCBCFADBDC39EB1B78FA5AD879EA77F969E81949B87989D8E9CA094A0A399A4A7
9EA8AAA3ACADA7AFAFABB1B1AEB4B2B1B4B2B3B4B0B4B2ADB5AFA9B6ADA6B7ABA3B8A9A0
BAA69DBAA499BBA195BB9D91BB9B8DBB9789BB9384B9907FB48A78AB806F9D74648A6556
75554960463B4A362E3325201B14110804030C07071C17162A252438333245403F524D4C
5E5A586A6664757270807D7C
979593A3A19FAFADABBBB9B7C7C5C3D4D2D0E1DFDDEFEDEBFDFCFAF6F5F4E9EBEADDE2E2
D2D9DBC4CED0B5C1C6A6B5BB99ACB28FA4AB869BA385979E8A9A9F909EA296A1A49CA5A8
A1A9AAA5ACADA9AFAFACB1B1B0B4B2B2B4B1B4B3AFB4B1ACB4ADA8B5ABA4B6A9A1B7A79F
B9A49BB9A297BA9F93BB9C90BB9A8CBB9687BA9283B78E7DB08675A47A6A946D5E7F5E51
6A4E43573F36413029291E1B130E0D030000100D0C1E1A192C2827393534464241534E4D
5F5B596A6665757271817D7C
979493A2A09EAEABAAB9B7B6C5C3C2D2D0CEDFDDDBEDEAE8FBF9F7F7F5F3ECECEBE1E4E4
D6DBDCCAD1D3BBC5C9ADBABEA2B1B698A9B08FA2A88B9CA38E9DA293A0A498A3A69EA7A8
A3AAABA8ADADABB0AFAEB2B0B2B4B2B4B4B1B4B1ADB3AFAAB3ACA6B3A9A2B4A79FB6A59C
B7A399B8A095B99D92B99A8EBA988AB99486B79080B38A7AA980709A736488665874574B
60473E4C39313629241E18150D0A0A020000120F0F201D1D2E2B2A3B373748444354504F
5F5C5B6B6766767371817E7C
979492A29F9DADAAA9B8B6B4C4C1BFD0CDCBDCDAD7E9E7E4F7F4F2F9F6F4EFEEECE5E6E5
D9DCDDCFD4D5C2C9CBB4BEC1AAB6BAA1AFB49AA9AE94A3A894A3A797A3A79CA5A7A2A9AA
A6ABABAAAEADADB0AFB0B2AFB4B4B1B6B4B0B3B0ACB2ADA8B1A9A3B2A7A0B2A59DB4A29A
B5A097B69E93B69B8FB7988BB79587B69283B18C7DAC84759F796A8F6C5E7D5E52695045
55413941312C2A211E151111050404060405151313242121312E2D3D3A3A4A4645555251
615D5C6C6867767372817E7D
969392A19E9CABA9A7B6B4B2C1BFBDCDCAC8D9D6D3E5E2DFF1EEEBFAF7F4F3F0EEE8E7E6
DDDEDED4D7D7C8CDCEBAC2C4B1BABDA8B3B7A4AFB39EAAAE9CA8AB9CA8AAA1A9AAA7ACAB
ABAEADACAFAEAFB0AEB2B1AEB6B3AFB6B2AEB3AFAAB0AAA6AFA7A1AFA49EB0A29BB2A097
B29E95B29B90B3988CB39588B29184B08D7FAA8677A17C6E93716483645871574C5D483F
4A3933352A26201B190E0D0D0000010D0C0C1A1919282525343231403E3D4C4948575453
625F5E6D6A68777473817F7D
969391A09D9BAAA7A6B4B2B0BFBCBACAC7C5D5D2CFE0DDDAECE8E5F8F4F1F6F2EFEAE8E7
E1E0DFD7D8D8CDD0D0BFC5C7B6BDBFB0B8BAABB4B6A7B0B2A4ADAFA5ADAEA8ADAEACAFAD
AEB0AEAEB0ADB0AFADB2B0ACB5B1ADB4AFABB1ACA8AFA8A3ADA59FACA09BAD9F98AF9D95
AE9A91AE978DAD9388AD9084AB8C80A7867A9F7E7195746886685D765C52644F46514039
3D312D292320181515070909030305121212201E1F2C2A2A3836364441414F4C4B595756
6461606E6B6A787574827F7E
9592919F9C9AA8A6A4B2AFADBCB9B7C6C3C1D1CECBDCD8D5E7E3E0F2EEEAF7F3F0EEEAE8
E4E2E0DADAD9D0D2D1C4C8C8BCC1C2B7BCBDB3B9BAAFB5B6ACB3B4ACB1B1AFB1B0B1B1AF
B1B1AFB0B0ADB2AFACB2AEAAB4AEAAB2ACA8B0AAA5AEA5A1ABA29CA99E98A99B94AA9991
A9968DA99389A68E84A58A80A1857A9C7F7392766B876C6278605769544C584640453833
302926201C1B1210110406070C0C0D19191A2625253130303D3B3A474545524F4F5C5958
6663626F6D6C79767582807E
9592909E9B99A7A4A2B0ADABB9B6B4C3C0BDCDC9C6D7D3D0E1DDDAEBE7E3F5F0EDF1ECE9
E6E3E1DCDBD9D3D3D2C9CBCAC3C5C5BDC0C0BABDBDB5B9B9B2B6B6B3B5B4B4B4B2B4B2AF
B4B2AEB1AFACB4B0ABB1ACA8B1ACA7B0AAA5AFA7A2ABA29DA89F99A59A95A49791A4958E
A39189A18E859D89809B847B967E7490776D866E657A645B6B58515C4C464B3E3A38302D
2522201817170B0B0C0B0C0D1617172221222D2B2C37363641403F4B49495553525F5C5B
686564716E6D7A777683807F
9491909C9A98A5A2A0ADAAA8B6B3B1BFBCB9C8C4C2D1CDCBDBD6D3E4E0DCEFEAE6F2EDEA
E8E3E1DFDBD9D7D4D3CECDCCC7C7C6C1C2C1C0C0BFBBBCBBB8B9B8B9B8B5B7B5B2B6B3B0
B6B2AEB3AFABB4AFAAB1ABA7B0AAA5AEA6A2ACA39FA89F9AA49B96A197919F938E9F908A
9C8C8598888194837B927E768C7770846F6879665F6D5C555F514B4F44403E36342C2927
1D1C1C1010110E0E101717182020212A292A3433333D3C3C474545504E4D595756625F5E
6A686773706F7B787783817F
93918F9B9897A3A09EABA8A6B3B0ADBBB8B5C3C0BDCCC8C5D4D0CDDDD9D5E6E1DEEFE9E6
E9E3E0E1DCD9D9D6D3D1CFCDCAC8C7C6C5C3C4C2C0C0BFBDBDBBB9BDB9B6B8B5B1B8B3AF
B6B1ADB4AEAAB2ADA8B0AAA5AEA7A2ABA39FA79F9BA49C979F97929C938E998F8A988C86
94878190827D8D7E788A797283726B7869636E5F5A615550534946443D3B34302F242323
1515161112131A1A1B2121222A292A3231323B3A3A4342424C4A4A5452525D5A5A656262
6D6A697472717C7A78848180
93908E9A9795A19E9CA8A5A3AFACAAB7B3B1BEBBB8C6C2BFCEC9C6D6D1CEDED8D5E6E0DD
E8E2DEE3DDD9DBD6D3D3CFCCCDCAC7C8C5C3C6C3C0C3C0BDC0BCB9BEB9B5BAB5B1B8B3AE
B5B0ABB4ADA9B1AAA5AEA7A3ABA49FA7A09CA39C989F98949A938F978F8B928A86928782
8C827D897E7A867A7582746F796C686E635F635955564F4C4843413A38372C2C2C1E1F20
1414151C1C1D2423242B2B2B3332323A393A4241414A484852504F595757615E5E686665
6F6D6C7674737D7B7A858281
928F8E9896949F9C9AA5A2A0ACA9A7B3AFADB9B6B3C0BCB9C7C3C0CEC9C6D5CFCCDBD5D2
E1DBD8E2DCD9DCD6D3D5D0CDCEC9C6C9C5C2C6C2BFC4C0BCC0BBB8BFB9B4BBB5B0B7B1AC
B4AEA9B1ABA6AEA7A3ABA49FA8A19CA39D999F98959B9491968F8C918A878C858289817D
857D7A847B788176737A6F6C716764665E5C5A54524D4948413F3E3434342728291D1E1F
1F1E1F2726272E2D2E3534343C3B3B434141494848504F4E5755555E5C5B6563626B6968
72706F7876757F7C7B858381
918F8D9794929D9A98A39F9EA8A5A3AEABA9B4B0AEBAB6B4C0BCB9C6C1BFCCC7C4D1CCC9
D6D1CDDBD5D2DCD6D2D6D0CCCFC9C6C9C4C0C4C0BCC3BDBAC0BAB6BEB7B2BAB3AFB5AFAA
B2ABA7AEA7A3ABA4A0A8A29DA49E9A9F99969B959296918D918C898C878486817E827D7A
7F7A797F78767B7371736B696B6462615C5A5451504746463C3C3C313233252627252525
2C2B2C3231323837383E3D3D4543434B4949514F4F5755555D5B5A6361606967666F6D6C
7572717A7877807E7C868382
918E8C9693919B9896A09D9BA5A2A0AAA6A4AFABA9B4B0AEB9B5B3BEBAB7C3BFBCC8C3C0
CCC7C4D0CBC7D5CFCCD5CFCBCFC8C4C8C2BEC2BDB9BFBAB6BDB7B3BCB5B0B7B0ACB2ABA7
AFA8A4ABA5A1A8A19DA59F9AA09B979C969397928F928D8B8E8A88888483827F7D7E7B7A
7B78777C777577716F6F6A686863615D5959504E4E444445393A3A3132322D2D2D333232
3837373D3C3C4342424847474D4C4C5351515856565D5C5B6361606866656D6B6A72706F
7775747C7A79827F7E878483
908D8C9491909995949D9A98A19E9CA6A2A0AAA6A4AEABA8B3AFACB7B3B0BBB7B4BFBAB7
C3BEBBC6C1BECAC4C1CEC8C4CDC6C2C7C1BCC0BAB6BBB5B1B9B2AEB7B1ACB3ACA8AEA8A3
AAA4A1A7A19DA59E9AA29C979D9894989390938F8D8E8B898B8886858282827F7E7A7979
7A7877787574726E6E6B686763605F5857574F4E4E4243443A3A3A3938383C3A3B403F3F
4443434947474D4C4C5250505655545B59595F5E5D6462616866666D6B6A716F6E767472
7A78777F7C7B83807F878583
8F8C8B93908E9693929A97959E9A99A19E9CA5A19FA8A5A3ACA8A6AFABA9B3AFACB6B2AF
B9B5B2BCB7B4BFBAB7C2BCB8C4BEBAC1BBB7BEB7B4B8B2AEB4AEAAB1AAA6ADA7A3A8A39F
A59F9CA39D9AA19A979C989498949296928F928E8B8C8A88888684848282817F7F7A7979
797877757373706E6D6A6766615F5F5857585251514444454342424746454A48484D4B4B
504F4F5452525856565C5A595F5D5D6361616765646B68686E6C6B72706F767372797776
7D7B79817E7D848281888584
8E8C8A918E8D9491909794929A97959D9A98A09C9BA39F9DA5A2A0A8A4A2ABA7A5ADA9A7
B0ACA9B2AEABB4AFADB6B1AEB7B2AEB8B2AEB7B1AEB5AFABAFA8A5AAA49FA4A09DA29E9B
A09B989F9A979C979398949196939095928F908D8B8D8A89888685858383807F7F7C7B7B
787878747373706E6D6967676362625B5A5A5653534F4E4E5251515553535755555A5858
5C5B5A5F5D5D6260606563636866656B69686E6C6B716F6E7472717775747A78777D7B79
807D7C83807F868382898685
8E8B89908D8B928F8D9491909693929995949B97969D9A989F9C9AA19D9BA39F9DA5A19F
A7A3A0A8A4A2AAA5A3ABA6A4ACA7A4ACA7A4ACA7A4ADA7A3A7A19EA39E9AA09C999C9896
9A969399959398949297939095918F928F8D8F8C8A8C8988888685858383817F7F7D7C7C
7A797976747472706F6A68676765656361605F5D5D605E5E615F5F636160646362666464
6866666A68686D6B6A6F6D6C716F6E7371707573727875747A78777C7A797E7C7B817E7D
83807F858281878583898785
8D8A898E8B8A908D8B918E8D93908E9491909693919794929895949A97959B98969C9997
9D9A989F9B99A09C9AA09C9AA19D9AA19D9AA19D9AA09C999E9A979D98959B9794959290
94918E95928F94908F94908E94908D908D8B8E8B8A8C8988888685878484848281817F7F
7E7C7B767574767473716F6E706E6D706E6D6F6D6C6F6D6C706D6D706E6D726F6F737170
7472717673727775747876757A78767B79787D7A797E7C7B807D7C817F7E83807F848280
8683828785838986858A8786
8C8A888D8A898E8B898E8C8A8F8C8B908D8C918E8C918E8D928F8E93908E93908F94918F
95919095929095929196939196939196939196939196929095918F94918E93908E918E8C
908D8B908D8B908D8B918D8B908D8B8D8A898C89888A8887898685888584868483858382
82807F7D7B7A7F7D7C7F7C7B7E7C7B7E7B7A7D7B7A7D7B7A7E7B7A7E7C7B7F7C7B7F7D7C
807D7C817E7D817F7E827F7E83807F838180848280858281868382868483878583888584
8986858987858A87868B8887
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?ooo`R<RHP4S8Z83hb:R@B<RhX8SH^:18f;R`^=S8/4SHb<28f=
S0N=SHd4SHj=18f>SPB=Shl4SHn@18jAT`B=Shl3SHj=18f=S0B=SXd4SHf<18j=S0B>SHd7SXj=28n>
S@R?SX`4Shb:0hn;RPB>RXP4SHV718b8QPB<QhD4S8J40h^5PPB:Ph04RH5o18QoN`B5O7L4R81m18V2
O`>9Q844RXB228Z5P`B:QX@4RhJ41h^7Q@B;QhH8RhR618^8Q`B;RHLEoooo000Doooo28b9R0B<RXP?
S8Z918b;RPR=RhX4SH^;2hf<R`B=S8`8SHf<1hf=S@B=SXd4SHj>18f?S`B=Si04SY6C18f?S`>=SXd4
SHf<18f>S@B=SH`4SXf<18j=S@N>SXd8Shj=28n>S0B?S8X3Sh^:18j:R0B=RHL4S8R618b7Q@B<QX@3
RhF218Z3P0B9PGl4R7mk18ElM`B8P7d4RH9o0hV4P@B:Q888RXF318Z6Q0B;QX@7RhN518^7QPR;R8H4
RhR718^9QaGoool001Coool8S8V818b:R0n<RXT4S8^:28f;RPB=Rh/;SHb;18f<S0R=SH`7SHf=18f>
S@B=SXh4SHn?18f?T0B>TI<4SHn?0hf>S@B=SH`4SHj=18f=S0B>SH`4SXf=1hj>S@R?SXd8Shj<18n<
RP>?RhX4SXZ818f9Q`B<R8H4S8N518b6Q0>;QH84RX>018V1O`B8Og/4QGag18R0O@B9PWl3RHB118Z4
PPR:QH<4RXJ418^6Q0N;QhD4RhN628^8QPB;R8L4RhV75Oooo`005?ooo`B<RHP8S8Z918b;RPB=RhX3
SH^;18f<R`B=SH`4SXf<18j>S@N>SXh4SXn?18j@S`B?T908Si6A18nATP>?TY84Si>C18nCU0B?U9H4
SiFG18nGVPB>U9H3SY>C28nBTPB?TI44T96A196BTPNATi84TY>B19:BT@BBTY04TY6?196?S@>ASH/4
Sh^918j9Q`B=Qh@4S8F318^3P0>;P7d4R7ei18IjMPB4MW04PWA^18EiM0B6O7P3Qgmk18R0O@B9PGh4
RH9o18V3P0B:Q843RXF218Z5P`B:QX@8RhN518^8QPB;R8LEoooo000Doooo18b9R0R<RXT4S8^:18f;
RP>=Rh/4SHb;18f=S0B>SH`4SXj=1hj>SPB>Shl4SY2?18n@T0R?TI44Si6B0hnBTPB?Ti<4Si>D18nD
UPB?UIL4SiNJ18jDUP>>Ti<8Si:B18nAT@B@TI44TI:B1i6CTPBBTi84TY:A19:BT0BBTHl4THn=0i6=
R`B?RhT4SXV718f7Q0B<QH<4Rh>00h^0O@B8OGT4QWYf18AfL0B2M6h4QGUd18IlN0>7Og/4R81m18V1
OPB9PWl4RH>018Z4P@>:QH84RXF318Z6Q0R;QhD4RhR618^8QaGoool001Coool4S8V828b:R@B<RhX4
SH^:0hf;R`B=S8/4SHf<18j=S0B>SXd7SXj>18j?S`B>T8l4Si2@28nAT@B?TI83Si:B18nCT`B?Ti@4
SiBF18nEU`B?UiX4SYBF0hjCT`R?TY84Si6A192AT@BATY87TI>B19:CTPBBTY44TY:@19:AS`BAShd3
THf;18n;R@B>RHL4SHN418b5P`B;Ph03Rh1m18QmN@B6NWH4Q7I`189dKPB5NG@4QWah0hMoN`B8P7d4
RH5n18V2O`B9Ph04RXB10hZ5PPB:QH<4RXJ428^7Q@B;R8H4RhR75Oooo`005?ooo`B<RHP8S8Z918b;
RPB=RhX3SH^;18f<R`B=SH`4SXf<18j>S@N>SXh4SXn?18j@S`B?T908Si6A18nATP>?TY84Si>C18nC
U0B?U9H4SiFG18nGVPB>U9H3SY>C28nBTPB?TI44T96A196BTPNATi84TY>B19:BT@BBTY04TY6?196?
S@>ASH/4Sh^918j9Q`B=Qh@4S8F318^3P0>;P7d4R7ei18IjMPB4MW04PWA^18EiM0B6O7P3Qgmk18R0
O@B9PGh4RH9o18V3P0B:Q843RXF218Z5P`B:QX@8RhN518^8QPB;R8LEoooo000Doooo18b:R0B<RhT4
SH^:18f;R`B=S8`3SXf<18j>S@B>Shh4Shn?28n@T0>?TI44T9:B192CT`B@U9@4T9BE192EUPBAUYL3
TIJH196GV@BAV9X4T9VL192KWPB@W:44T9VL0i2HV@B@UYL4TIJF196EU@BBUYH4TiJF0iBGUPBCUiH4
U9NF19FFU@BDU9<4Ti:@19>@SP>BSh`4THb91929QPB>QX<4SH>018^0O0>9O7P4QgQc18AdKPB1KVL4
PFmY18=dKPB5Mg83QWYf18MlN0B7OWX4R7ml18R0O@B9PGh3RH:018Z3P@B:Q884RXF318^6Q0B;QhD4
RhR65Oooo`005?ooo`B<RXP4S8^918f;RPB=Rh/4SHb<0hj=S0B>SXd4SXn>18n?S`R?T903Si6A192B
TPB@Ti<4T9BD192DU@B@UIH4TIJG0i6FV0BAUiT4TIRJ192IW0B@Vih4T9bQ192IW0>@V9T4T9JG196F
UPBAUID4TYJF19>FUP>DUiH4TiNF19BGUPBEUYD4U9BC19>BT0BCT8h3TXn<196<R@B@RHH4SXJ318f3
P0B;P7`3RGah18MhL`B4M6h4PFiW185_J@B3M6h4QGMb0hIjMPB7O7P4Qgij18QoO0B8P7d4RH5n0hV2
P0B:Ph44RXB218Z5P`B;QX@4RhN518^8QQGoool001Coool4S8Z818b;R@B=RhX4SH^;18f<S0>>SH`4
SXj=18j?SPB?Shl8Si2@0hnAT@B@TY84T9>C192DU0B@U9D4T9FF196FU`>AUYP4TINI196HVPB@VI`4
T9^N192LX@B@VI`3T9RI192FU`BAUYH4TIFE19:FUPBCUYH3U9NF19>GUPBDUiH4UIJE19BDT`BCTY04
Ti2>0i:?S0BAS8T4T8V618j6P`B=Ph04Rh1l0hUlN0B7N7<4Q7A^185^I`B1KfT4PgA^18EgLP>6NWH4
Qgah18MnNPB8Og`4R81m18V1OP>9PX04RX>118Z4PPB:QH<4RhJ418^7Q@B;R8HEoooo000Doooo18b:
R0B<RhT4SH^:18f;R`B=S8`3SXf<18j>S@B>Shh4Shn?28n@T0>?TI44T9:B192CT`B@U9@4T9BE192E
UPBAUYL3TIJH196GV@BAV9X4T9VL192KWPB@W:44T9VL0i2HV@B@UYL4TIJF196EU@BBUYH4TiJF0iBG
UPBCUiH4U9NF19FFU@BDU9<4Ti:@19>@SP>BSh`4THb91929QPB>QX<4SH>018^0O0>9O7P4QgQc18Ad
KPB1KVL4PFmY18=dKPB5Mg83QWYf18MlN0B7OWX4R7ml18R0O@B9PGh3RH:018Z3P@B:Q884RXF318^6
Q0B;QhD4RhR65Oooo`005?ooo`B<RXT4S8^:18f<R`B=S8`4SXf=0hj>SPB?Shl4Si6@192AT@B@TY<4
T9>C0i6DU@BAUIH4TIJG19:GV0BBV9X4TYVK19:JW0>BVid4TYbO19:MX0BBWZ84TYnT196QYPBAWZ43
TIbN19:JV`BBVIX4TiVJ19BIV@BEVIT3UYZI19FJV@BEVYP4UYRG19JFU@BEU984UI:@0iB@S@BCS8X4
THV518n5P@B=PGd4Rgeh0hQhL`B6M6d4PViW17iXG`B0K6D4PW1Y18=cK@>4MW44QGQd18IjMPB7O7P4
Qgej18QoO0>8P7d4RH9o18V3P0B:Q884RXF318^7Q@B;R8HEoooo000Doooo18b:R@B<RhX4SHb;18f<
S0B>SHd3SXj>18n?S`B?TI04T96A192BT`B@Ti<3TIBE196EUPBAUYL4TYNH19:HVPBBVI/4TYZL0i:K
W@BBW9l4TYfP19:NXPBBWj@4TJ6V196NX@>AW9h4TYZK19:IVPBCVIX4U9VI19FIV@>FVYT4UIZI19FJ
V0BFV9L4UYJE19FDTPBETY03U92=19><RPBARHD4ShF118f1O@B;OGP3R7Qc18IdK@B2KVL4OVQO181/
I@B2L6T4Pg=]0hAfL@B5N7@4QWYf18MlN0B7OGX4R7ml0hR0O@B9PWl4RH>018Z4PPB:QH<4RhN518^8
QQGoool001Coool4S8Z918b;RPB=S8/4SHb<18j=S@>>SXh4Shn?18nAT0B@TI44T9:C192CT`>AU9D4
TIFF196FU`BBUiP4TYRJ19:IV`BBVY`3TY^M19:LW`BBWJ04TYjR19:OY0BAXJH4TIjQ0i6LWPBBVY/4
TYVJ19>IVPBDVIT4UIVI0iJJV@BEVYT4UIZH19JHU`BFUYD4UIBB19FBT0>DT8d4Thb:1969Q@B?QH44
SH5m18]mN0>8N7<4QWA]189^I`AnJ5l4P6aU189`J@B3Lfd3Q7Ia18EhM0B6NWH4Qgah18MmNPB8Og`3
R81m18V2O`B9Ph04RXB218Z5P`B;QhD4RhR65Oooo`005?ooo`B<RXT4S8^:18f<R`B=S8`4SXf=0hj>
SPB?Shl4Si6@192AT@B@TY<4T9>C0i6DU@BAUIH4TIJG19:GV0BBV9X4TYVK19:JW0>BVid4TYbO19:M
X0BBWZ84TYnT196QYPBAWZ43TIbN19:JV`BBVIX4TiVJ19BIV@BEVIT3UYZI19FJV@BEVYP4UYRG19JF
U@BEU984UI:@0iB@S@BCS8X4THV518n5P@B=PGd4Rgeh0hQhL`B6M6d4PViW17iXG`B0K6D4PW1Y18=c
K@>4MW44QGQd18IjMPB7O7P4Qgej18QoO0>8P7d4RH9o18V3P0B:Q884RXF318^7Q@B;R8HEoooo000D
oooo18b:R@B=RhX4SHf<18j=S@B>Shh3Si2@192AT@B@TY<4TI>D196EU@BBUYL3TYNH19>HVPBCVI/4
Ti^M19BLWPBDWJ04U9jQ0iBOX`BDX:@4U::V19BSY`BCXjT4TZF[19:QY@>BWj84TijO19>MWPBDW9d4
UIbL1iJLW0BGWI`4UibK19RKVPBGVIL4UiJD19JDT@>FT8h4UHf:19:8Q@B@Pgl4SGmk18YjM@>7MFl4
QG1X185YH@AmI5/4OfUP185/I@B2L6T3Pg=]18AeL0B5Mg84QWUe18IkM`B7OGT3R7ik18R0O@B9PWl4
RH>118Z5PPB:QX@4RhN65Oooo`005?ooo`B<RXT4SH^:18f=S0B>SHd4SXn>0hn@T0B@TI44T9:C196C
U0BAUID4TYJG0i:GV0BCV9X4TiVK19>KW@BDW9h4U9fP19BNX@>DWj<4U:2T19BRYPBDXjL4Tj>Y19:U
Z`BBXJD3TYnR19>NW`BCWIh4U9bM19FLW0NFW9`4UifL19NLV`BHViX4UiVG19NFU0BFU943UY2>19F=
RPBBR8D4T8=o18eoN`B:NWD3QgE_18E`J0B1JF44OFAK17mYH0B1K6D4PW1Y0h=cK@B4MG04QGMb18Ii
M@B6NgL4Qgei0hQnN`B8P7d4RH9o18V3P@B:QH84RXJ418^7QQGoool001Coool4S8Z918f;RPB=SH`4
SXf=18j?SP>?T904T96A192BT`BATi@4TIFE19:FU`>BUiP4TiRJ19>IV`BCVid4U9bN19BMX0BDWZ43
U9nS19BPY0BDXZH4U:>W19>SZ@BBYJ/4TZ6U0i:OXPBCWYl4TifN19BLW@BEW9`7UYbL19NMW0BGW9/4
V9^J19NIU`BGUY@4UYBA0iJ@SPBESHX4TXR51923O`B=Og/4RWYe0hMeK`B5L6P4PFUQ17eTF`AoJF04
PFaU189`J@>3Lfd4Q7E`18EgLPB6NGD4QW]g18MmN@>8OW/4R81m18V2O`B9Ph44RXF218Z6Q0B;QhHE
oooo000Doooo18b:R@B=RhX4SHf<18j=S@B>Shh3Si2@192AT@B@TY<4TI>D196EU@BBUYL3TYNH19>H
VPBCVI/4Ti^M19BLWPBDWJ04U9jQ0iBOX`BDX:@4U::V19BSY`BCXjT4TZF[19:QY@>BWj84TijO19>M
WPBDW9d4UIbL1iJLW0BGWI`4UibK19RKVPBGVIL4UiJD19JDT@>FT8h4UHf:19:8Q@B@Pgl4SGmk18Yj
M@>7MFl4QG1X185YH@AmI5/4OfUP185/I@B2L6T3Pg=]18AeL0B5Mg84QWUe18IkM`B7OGT3R7ik18R0
O@B9PWl4RH>118Z5PPB:QX@4RhN65Oooo`005?ooo`B<RXT4SHb;18j=S0B>SXh4Si2@0i2AT@B@Ti<4
TIBE19:FUPBBUiP4TiRJ0i>JV`BDVid4UIfO19FNX@BEX:84UZ6T19JRYP>FY:P4UZFZ19JVZ`BEYjd4
U:N]19>X[PBCY:T3Tj:U19BQX`BEX:44UInP19JOW`BGWil7V9nN19VNWPBIWI`4VI^J19VHUPBHUI<3
Ui6>19J>RPBDR8D4TH=n18inN@B:NG<3Qg9[18=/I0AoI5/4OF9H17mVG@B0JF44PFeU0h9`J@B3LV`4
Q7E_18EgLPB6NG@4QW]f0hMmN@B8OW/4R81m18V2O`B:Q844RXF318^7QAGoool001Coool4S8Z918f<
R`B>SH`4SXj>18n@T0>@TI44T9>C196DU@BBUYH4TYNH19>HVP>CVY/4U9^M19FMW`BEWZ44UJ2R19JQ
Y0BFXZH3UZBX19JUZPBFYZ/4UJN]19BW[@BCZ:h4TjBY0i>RY@BDXJ<4UJ2Q19FOX0BFWil4UinO1iRO
WPBIWYh4VIfL19VKVPBIV9H4V9FC0iNASPBFSXX4U8R51963OPB>OWT4RWUc0hMbJ`B3K6@4OfAK17eR
F0AoIUd4P6UQ185]I@>2L6T4Pg9/18AeK`B5Mg84QWUd18IkMP>7OGT4R7ik18R0O@B9PWl4RXB118Z5
P`B;QhDEoooo000Doooo18b:R@B=S8/4SXf<18j>SPB?T903T96A192CT`BAU9D4TYJF19:GV0BCV9X3
TiZK19BKW@BEWIl4UIjQ19FPXPBFXJ@4UZ:V0iJTZ0BFYJX4UZJ[19FW[@BDYjd4TjR^19>TZ@>CXZD4
U:6S19FPX@BEWj04UYnO19NOW`NHWih4VIjN19VMW0BIViX4VIRF19RET`>GTHh4UXj:19B8Q@BAPgh4
SWii18YiL`>7LV/4PfaT17mTF`AmHUP4OfIM181YH@B1KFD3PW1Y18=bK0B4MFl4QGMb18IiM0B6NgH3
Qgei18QnN`B8P7d4RH9o18Z4P@B:QH<4RhN55Oooo`005?ooo`B<RhT4SHb;18j>S@B?Shl4T96A0i2C
T`BAU9D4TYJG19>HV@BCVI/4U9^M0iFMW`BEWZ44UZ2S19NRY@BGXjL4V:FY19RWZ`>IZ:d4VJZ_19V[
/@BH[;84UJbc19>Y/0BCYZ/3U:FX19FTYPBFXj@4Uj:S19RRXPBHXJ83VJ6Q29ZQX0BKWih4VifL19ZJ
V0BJUY@3VI:?19N>RPBER8D4TX=n18mlM`B;Mg43QW1X18=XH0AnH5H4OF1F17iTFPB0Ieh4PFYR0h5]
I@B2KfT4Pg9/18AdK`B5Mg44QGQd0hIkMPB7OGT4R7ml18R1OPB9Ph04RXF318^7QAGoool001Coool4
S8^918f<R`B>SXd4Shn?192AT@>@Ti<4TIBE19:FU`BCV9T4TiVK19BKW@>EWIl4UIjQ19JPX`BGXZD4
Uj>W19RUZ@BHYj/3VJR]19VZ[`BIZk44V:bb19F//`BCZK04TjJ[0iBUZ0BEY:H4UZ>T19NRX`BHXZ84
V:6R0iVQX@RJXJ04VinN19^MW0BJVYP4VYJD0iVBS`BGSXX4UHR519:3OPB?O7L4RgMa0hI`J0B3J604
OV1F17ePEPAnI5X4P6MN185ZHP>1KFD4PVmY18=bK0B4M6l4QGMa18EhM0>6NgH4Qgei18QoO0B8PGh4
RH>018Z5P`B;QhDEoooo000Doooo18b;R@B=S8/4SXj=18n?S`B@TI43T9>C196DU@BBUYL4TiRI19>I
V`BDVid3UIfO19FNX@BFX:<4Uj:U19NSY`BHYJT4V:N[0iVX[@BIZZl4VJ^a19R//PBE[;<4TjV`19>V
Z`>DYJP4UJBV19JSY0BGXZ<4V::R19RQXP>IXJ48VZ6P19^OWPBKWI`4VYZH19ZFU0>ITXl4Uhj:19F8
Q@BBPgh4Sgag18]gL@>6L6P4PfQP17iPEPAmH5H4OVAJ181WGPB1JV83PFeU189_J@B3LV`4Q7A_18Eg
L@B5N7@3QW]f18MmN@B8Og`4R85n18V3P0B:QH<4RhN55Oooo`005?ooo`B<RhT4SHb;18j>S@B?Shl4
T96A0i2CT`BAU9D4TYJG19>HV@BCVI/4U9^M0iFMW`BEWZ44UZ2S19NRY@BGXjL4V:FY19RWZ`>IZ:d4
VJZ_19V[/@BH[;84UJbc19>Y/0BCYZ/3U:FX19FTYPBFXj@4Uj:S19RRXPBHXJ83VJ6Q29ZQX0BKWih4
VifL19ZJV0BJUY@3VI:?19N>RPBER8D4TX=n18mlM`B;Mg43QW1X18=XH0AnH5H4OF1F17iTFPB0Ieh4
PFYR0h5]I@B2KfT4Pg9/18AdK`B5Mg44QGQd0hIkMPB7OGT4R7ml18R1OPB9Ph04RXF318^7QAGoool0
01Coool4S8^:18f=S0B>Shh4Si2@192BTP>AU9D4TYJG19>HV@BDVY/4UIbN19FNX0>FX:84Uj6T19RS
Y`BHYJT4VJN[19ZY[PBJZk03Vjfc19^_]@BL/KL4W;>j19>/]0BAZ:l4TjR]0iFWZ`BFYZT4UjFW19RT
YPBIYJD4VZBT0i^TY0BKY:<4W:>R19bQX0BLWid4W9bI19^GU@>JTi04V8j;19J8Q0BCPWd4Sgaf18]e
KP>6KFD4PVIM17eND`AmGeD4OV9H17mTF`B0Iel3PFYR189]I@B2KfT4Pg9/18AdK`B5Mg43QWUd18Ik
M`B7OWX4R81m18V2O`B:Q884RhN55Oooo`005?ooo`B<RhX4SHf<18j?SPB?T904T9:B0i6DU@BBUYL4
TiRI19BJV`BEW9h4UIjP0iJPXPBGXJ@4V:>W19RUZ@BIYj/4VZV^19Z[/0>K[K<4Vjne19ba]`BL/kX4
Tjbd196X[`BCZ:d3UJN[19JVZ@BGYJL4V:BV19VUY@BJY:@3VjBT19^TX`BLXj84W:6P19bOW@BLW9T4
ViNE0iZCT0BHSX/4UXR419>2O@B?O7H4RgE^0hI]I@B2IUd4OEiC17eOE@AnHUP4OfAK181WG`>1JV84
PVeU189_J@B3LV`4Q7A_18EgL@>6NG@4QW]g18MnNPB8P7d4RH9o18Z4PPB;QhDEoooo000Doooo18b;
RPB=SH`4SXn>18n@T0B@TY83TIBE19:FU`BCV9T4U9ZK19FLWPBEWZ03UZ2R19NQY0BHXjL4V:FY19VW
Z`BJZJh4VZ^`0i^]/`BK[kD4W;6g19bc^PBC[;@4TJR_19>X[@>EYj/4UZJY19NUY`BHY:H4VJFU19ZT
Y0>KY:@4VjBS19bSXPBLXJ04W9nM19bLV@BKUiD3VY>@19R>R`BFR8@4Th9m18mlMPB;MFh3QVeU189V
G@AmGU<4OEmE17iRF0AoI5/4P6MO0h5ZHPB2KFD4PVmY18=bK0B4M6l4QGMa0hIiM0B6NgL4Qgij18R0
O@B9PWl4RXB218^7QAGoool001Coool4S8^:18f=S0B>Shh4Si2@192BTP>AU9D4TYJG19>HV@BDVY/4
UIbN19FNX0>FX:84Uj6T19RSY`BHYJT4VJN[19ZY[PBJZk03Vjfc19^_]@BL/KL4W;>j19>/]0BAZ:l4
TjR]0iFWZ`BFYZT4UjFW19RTYPBIYJD4VZBT0i^TY0BKY:<4W:>R19bQX0BLWid4W9bI19^GU@>JTi04
V8j;19J8Q0BCPWd4Sgaf18]eKP>6KFD4PVIM17eND`AmGeD4OV9H17mTF`B0Iel3PFYR189]I@B2KfT4
Pg9/18AdK`B5Mg43QWUd18IkM`B7OWX4R81m18V2O`B:Q884RhN55Oooo`005?ooo`B=RhX4SXf=18n@
S`B@TI44TI>D0i:EUPBCV9T4U9ZK19FLWPBFWZ04Uj2S0iRRY@BIYJP4VJN[19ZY[@BKZk04W:fb19b_
]@>M/[P4W[Bk19ng_PBO^<04SJRa196Y/0BDZJh3UZV]19NXZ`BHZ:X4VJNX19ZWZ0BKYjL3W:NV19fW
YPBNYZD4WZ>S19jPW`BMW9X4W9NE0i^CT0BISX/4UXR319>1O0B?NgD4Rg=/0hI/I0B2IE/4OEaA17eN
D`AnH5H4OV9I17mUG0>0Iel4PFYR185]IPB2KfT4Pg9/18AeK`>5Mg84QWYe18MlN0B8Og/4RH5n18Z4
P@B;QX@Eoooo000Doooo18f;RPB>SHd4Si2?192AT@BATi@3TYFF19>HV@BDVY/4UIbN19JNX0BGX:<3
V::U19VUZ0BIYj/4VZV]19^[/0BL[K84W:ne0ifb^0BN];/4WkNn19nh`0B=Z;44TJV`19BY[P>FZJd4
UjR[19RXZPBIYjP4VZNX19^WY`>LYjH4WJNV19jVY@BNXj<4WZ2O19fLVPBLUiD3Vi>@19V>R`BFR8<4
Th5l18mkM@B;Lf`3QVaT189UF`AmG544OEiC17iPEPAnHUT4OfEL0h1WG`B1JV84PFeV189_J@B3LV`4
Q7E_0hEgLPB6NWD4Qgah18QoN`B9PGh4RXB118^6Q1Goool001Coool4SH^:18j=S@B?T8l4T96A196C
U0>BUIH4TiRI19BJV`BEW9h4UYjP19NPX`>HXZD4VJFX19VWZ`BJZJd4Vj^`19b]/PBL[kD3WK:h19jd
^`BO]kh4WkS018fX/@BAZK04U:V^0iJY[@BGZ:/4V:RZ19VWZ0BJYjP4VjNW0ibWYPBMYjH4WZJU19jS
X`BNX9l4WIbJ19bGU@>KTi04VHj;19J8P`BCPG`4Sg]e18]cK0>6K6@4PVEK17eLD@AmGU<4OV1F17iR
F@AoIE`3P6MO185ZHPB1KFH4PVmY18=bK0B4MFl3QGMb18IjM@B7O7P4R7mk18V1OPB:Q844RhJ45Ooo
o`005?ooo`B=RhX4SXf=18n@S`B@TI44TI>D0i:EUPBCV9T4U9ZK19FLWPBFWZ04Uj2S0iRRY@BIYJP4
VJN[19ZY[@BKZk04W:fb19b_]@>M/[P4W[Bk19ng_PBO^<04SJRa196Y/0BDZJh3UZV]19NXZ`BHZ:X4
VJNX19ZWZ0BKYjL3W:NV19fWYPBNYZD4WZ>S19jPW`BMW9X4W9NE0i^CT0BISX/4UXR319>1O0B?NgD4
Rg=/0hI/I0B2IE/4OEaA17eND`AnH5H4OV9I17mUG0>0Iel4PFYR185]IPB2KfT4Pg9/18AeK`>5Mg84
QWYe18MlN0B8Og/4RH5n18Z4P@B;QX@Eoooo000Doooo18f;RPB>SXd4Si2@192BTPBAU9D3TiNH19BI
V`BEW9d4UYjP19NPX`BHXjH3VJFY19ZX[0BKZZh4W:ba19f_]0BN/KL4WkBj0inf_@BP^L04Xkg419Nc
_0B>ZK84TZ^b19F//0>G[;04V:^^19Z[[@BKZZ/4W:ZZ19fZZP>NZZX4WjZY1:2YY`BPYJ@4X::P19nL
VPBMUiD3W9:@19Z=RPBFQh<4Th1k18mjM0B;Lf/3Qf]S189TFPAmG504OE]@17eMD`AnH5D4Of9I0gmU
G0B0Iel4PFYS185]IPB2L6T4Pg=]0hAeL0B5N7@4QW]g18MnNPB8P7d4RH>118Z6Q1Goool001Coool4
SH^:18j>S@B?T904T9:B196DU@>CUiP4U9VK19FLW@BFWZ04Uj2S19RSYP>IYJT4VZR/19^Z[PBL[;44
WJnd19ja]`BO];X3WkJm1:2i`0BS_L@4Uk>l18jY/PBBZk84UJb`0iN//0BHZjh4VZ^]19^ZZ`BLZZX4
WJZZ0ijZZPBOZZT4X:VW1:2UY0BPXZ04WibJ19fGU@>LTY04VXf:19J7P`BCP7/4SgYd18]cJ`>7Jf<4
PVAJ17eLD0AmFe04OEeC17iPE@AoHUT3OfEL181WG`B1JV<4PFeV189`J@B3Lfd3Q7E`18EhM0B6NgL4
Qgij18R0O@B9Ph44RXJ45Oooo`005?ooo`B=RhX4SXj=18n@T0B@TY84TIBE0i>GV0BDVI/4UIbM19JN
X0BGX:<4V:>V0iVUZ@BJZ:`4VjZ^19b//@BM[k@4W[6g19nd^P>O][d4X;W01:>ma0BG/k`4SZVb19:[
/PBE[;03Ujb`19R[[PBJZjd4VjZ[19bZZPBMZZX3WZZZ19nZZ@BPZJL4X:FT1:2RX0BOW9X4WINE0ibB
T0BJSHX4UXN319>0N`B?NW@4Rg=[0hM[H`B2I5X4OEa@17eKD0AmGE<4OV1E17mRF@=oIE`4P6MO185Z
H`B1KFH4PW1Y18=cK@>4MG04QGQd18IkM`B7OWX4R81m18V3P@B:QX@Eoooo000Doooo18f;RPB>SXd4
Si2@192BTPBAU9D3TiNH19BIV`BEW9d4UYjP19NPX`BHXjH3VJFY19ZX[0BKZZh4W:ba19f_]0BN/KL4
WkBj0inf_@BP^L04Xkg419Nc_0B>ZK84TZ^b19F//0>G[;04V:^^19Z[[@BKZZ/4W:ZZ19fZZP>NZZX4
WjZY1:2YY`BPYJ@4X::P19nLVPBMUiD3W9:@19Z=RPBFQh<4Th1k18mjM0B;Lf/3Qf]S189TFPAmG504
OE]@17eMD`AnH5D4Of9I0gmUG0B0Iel4PFYS185]IPB2L6T4Pg=]0hAeL0B5N7@4QW]g18MnNPB8P7d4
RH>118Z6Q1Goool001Coool4SHb;18j>SPB?TI44TI>D19:EUP>CV9T4UI^M19JMX0BGX:<4V:>V19ZU
Z@>KZ:`4W:^_19f]/PBN/;D4Wk>i1:2e_0BQ^;l3X[_21:Boa`BL^<44T[2i19>_]PBE[[@4Ujnc0iV^
/PBJ[[44Vjf_19b/[@BM[:`4WZf/0j2][0BQ[Zd4XJ^Y1::WYPBQXj44X9fK19nGU@>MTY04VXb919J6
PPBCOgX4SWQb18YbJP>7Jf84PVAJ17mMDPAlFDd4OE]?17eMDPAnGeD3OV9I17mUG0B0J604P6]S185^
I`B2LFX3PgA^18AgLPB5NWH4Qgai18R0O0B9Ph04RXJ45Oooo`005?ooo`B=S8/4SXj>18nAT@BATi@4
TYFF0i>HV@BEVid4UYfP19NPX`BHXjH4VZFY0i^X[0BLZjl4WJfb19j`]@BO/kT4X;Fl1:6h_`>R^l84
Y;o719bh`@BB/;T4Tjnf19F^]0BG[k<3VJjb19Z^/@BK[Jl4W:b]19f/[0BN[J`3X:f/1:6^[@BQZjT4
XZNV1:6SX@BPWI/4WiNE0ifBT0BJS8T4UXJ219=oNPB>N784RW9Z0hM[HPB2I5X4OeeB17aIC@AmFdl4
OEeB17iOE@=nHUT4OfEL181XH0B0Jf<4PFiW189aJP>3M6h4Q7Mb18EjMPB7O7T4R81l18V3P0B:QX@E
oooo000Doooo18f<R`B>SXh4Si6A196CU0BBUIH3TiRI19FKW@BFWJ04Uj2S19RSYPBJYJT3VjR/19b[
[`BM[K84W[2e19nc^@BP]K`4XKRo0j:k`PBT_lL4W;S119:`^@BC[kH4UJjd19N_/`>I[[84VZja19^]
[`BL[:d4WJb/19j][0>P[J`4XJj]1:6[Z@BRYjH4XJ>Q1:2MV`BOUiD3WI:@19Z<R@BFQX84Tgmj18ih
LPB:LVX3Qf]R189TFPAoGE84O5U=17eKC`AmGE84OUmE0giRF@AoIE`4P6QP181[H`B1KVL4PW5Z0h=d
KPB4Mg84QGYf18MlN@B8P7`4RH>018Z6Q1Goool001Coool4SHb;18j>SPB?TI44TI>D19:EUP>CV9T4
UI^M19JMX0BGX:<4V:>V19ZUZ@>KZ:`4W:^_19f]/PBN/;D4Wk>i1:2e_0BQ^;l3X[_21:Boa`BL^<44
T[2i19>_]PBE[[@4Ujnc0iV^/PBJ[[44Vjf_19b/[@BM[:`4WZf/0j2][0BQ[Zd4XJ^Y1::WYPBQXj44
X9fK19nGU@>MTY04VXb919J6PPBCOgX4SWQb18YbJP>7Jf84PVAJ17mMDPAlFDd4OE]?17eMDPAnGeD3
OV9I17mUG0B0J604P6]S185^I`B2LFX3PgA^18AgLPB5NWH4Qgai18R0O0B9Ph04RXJ45Oooo`005?oo
o`B=S8/4SXn>192BTPBAU9@4TiNH0iBJV`BFW9h4UinR19RRY@BJYJP4VjR/0ib[[`BM[[<4Wk6f1:2d
^@BQ][d4X[W01:>la0>S_lL4X;k719Bc_@BE/k`4U[:j19Nb]`BI/[L3Vk:f19ba/`BM[k44WZn_19n^
[PBO[jh3XJn^1:>`[PBS[:/4XjRV1::RX0BRWY`4X9NE0inBS`BKRhP4UhF1199nN@B=Mg44RW5Y0hM[
HPB3IE/4P5iC17eHC@AlEd/4OEY?17eMDP=mGeD4OV9I17mUG@AoJ604P6]T185_J0>2LV`4Q7E`18Eh
M0B6NgP4Qgml18V2P0B:QX@Eoooo000Doooo18f<R`B>Shh4T9:B196DU0BCUiP3U9ZK19JLWPBGWj84
V::U19ZUZ0BKZ:`3W:^_19f^/`BO/KH4X;Bi1:6f_@BR^L04Xkc40j>oa`BP_/L4U;>m19Fc_0BF/[X4
Uk:g19Vb]`>K/[H4W;6c19f_/@BN[jl4Wjj^19n_[P>Q[jh4Xk2^1:>/Z`BSZ:H4XZ:P1::NW0BPUiD3
Wi:?19^;R0BGQH44TWii18egL@B:LFT3Qf]R18=UF`B0GU<4OEQ=17aGB`AmFTl4OEeB0geOE@AnHUT4
OfEM17mXH0B0Jf@4PFmX0h9bK0B4MG04QGQd18IkN0B7Og`4RH:018Z6Q1Goool001Coool4SHb;18j?
SPB@TY84TIBD19>GV0>DVY/4UYbN19NOXPBHXZD4VZFX19^X[0>LZjl4WJjc19na]PBP];T4XKJm1::i
`0BS_<@3Xko71:2na`BD/kd4UK>l19Jb^PBG/[L4VK:g0i^b]PBL/K<4WJna19j_[`BO[Zh4Wjn^0j6_
[PBS/:h4Xjb[1:>XYPBRXZ04XYjL1:2GU@>OTXl4Vh^819N5P@BBOWT4SGMa18YaJ@>7Jf84PfEK181N
D`AmF4d4O5M;17eJC`AmGE83OEmE17iRF@AoIEd4OfQP181[I0B1KfP3PW9/18AeL0B5N7@4QW]h18Mo
O0B9PX04RXJ45Oooo`005?ooo`B=S8/4Shn?192BTPBBUIH4TiRI0iFKW@BFWZ04V:6T19VTZ0BKYj/4
W:^_0ij^/`BO/KH4XKBj1::g_PBS^/44Y;g51:G0b0>V`ld4UkS219Jf_`BG]Kd4V;Bl19Zd^PBK]KX3
WKFi19jd]PBN/K84Wk2`1:2`/0BP/Jl3XZn^1:>][0BU[:/4Y:JU1:BSX@BTXIl4XYVG0j2BT0BKRhP4
UX>0199mN@B=MW04RG1X0hMZHPB4IE/4PEmD17iJCPAkEDP4O5M;17aJCP=lGE84OEmF17eRF@AnIUd4
OfUQ181/IP>1L6X4Pg=^18AgLPB6NWH4Qgik18V2O`B:QH<Eoooo000Doooo18f<R`B?Shl4T9:B19:E
UPBCV9T3UI^M19JNX0BHXJ@4VJBX19^WZ`BLZjl3WZjc19na]PBQ];X4X[Nn1:>j`@BT_LD4YL380jK3
c@BG^<84U[Jo19Ne_@BH];`4V[Bj19^e^P>M]KT4W[Bf19ja/PBO/;04X;2`1:2a[`>R[jh4Xjf/1:F/
Z`BTYZD4Y:>Q1:BQW`BRVIL3X9:@19^;R0BFPh04TWei18efL0B9L6P3QfYR18AUF`B1Ge@4OUY>17]E
B0AlEd/4O5Y>0gaMDPAmGeH4OF9I17iVG@AoJF44P6aV0h5`JPB3Lfh4Q7Mb18IjMPB7OW/4RH9o18Z5
PaGoool001Coool4SHb;18n?S`B@TY84TYFF19>HV@>EVid4UYjP19RQY0BIY:P4VjN[19b[[`>N[[<4
Wk6f1:6d^PBR]kh4Xk[11:Bma@BU`<P3Y/?=19Nh`PBF][l4UkFm19Rd_0BJ];X4VkFj0ife^@BN];H4
W[6b19n`/0BP/;04X;6_0j:_[PBS[J`4YJb[1:BVY@BTXj44Y:6O1::IU`>PTY04Vh^819J3P0BBOGT4
SGI`18U`J0>7JV84Q6EK185OE0AnFTh4NeE817aGB`AlFTh3O5eB17eOEPAmHUT4OVIM17mYH@B0K6H3
PG1Z18=cKPB4Mg84QWYf18MnN`B9PWl4RXF35Oooo`005?ooo`B=S8/4Shn?192BTPBBUIH4TiRI0iFK
W@BFWZ04V:6T19VTZ0BKYj/4W:^_0ij^/`BO/KH4XKBj1::g_PBS^/44Y;g51:G0b0>V`ld4UkS219Jf
_`BG]Kd4V;Bl19Zd^PBK]KX3WKFi19jd]PBN/K84Wk2`1:2`/0BP/Jl3XZn^1:>][0BU[:/4Y:JU1:BS
X@BTXIl4XYVG0j2BT0BKRhP4UX>0199mN@B=MW04RG1X0hMZHPB4IE/4PEmD17iJCPAkEDP4O5M;17aJ
CP=lGE84OEmF17eRF@AnIUd4OfUQ181/IP>1L6X4Pg=^18AgLPB6NWH4Qgik18V2O`B:QH<Eoooo000D
oooo18f<R`B?T8l4TI>C19:FU`BDVY/3UYbN19NPXPBIXjH4VjJZ19bZ[PBN[K83Wk6f1:6d^PBS]kh4
Y;_21:FnaPBV`LX4Z<G>0j;2c0BC]L04U[Jo19Rf_`BI][`4VkNl19jh_@>P^K`4XKNh1:2c/`BQ/[84
Xk:a19j/Z`>Q[:`4XjZY1:FYZ0BUZ:L4YZFS1:NRX0BTViP3XYFB19^<R@BFPWl4TGah18aeKPB9KfL3
QVYQ18EUF`B2H5D4P5]?17eFB@AlE4L4O5M:0g]JCPAkG584O61F17eSFPAnIel4OfYS0h1^J0B2LV`4
PgIa18EiM@B7OGX4R85n18Z5PaGoool001Coool4SHb;18n@S`BATi<4TYJG19BJV`>FW9h4Uj2R19VS
YPBKYZX4W:Z^19j]/P>O/KH4XKBj1:>g_PBT^l84YKk61:K1bPBXaLh3X/;<19>e`0BF][l4V;Jo19Vf
_0BK]k`4W[Rm0j2i_0BQ]kP4X;>c1:6b/PBS/[44WZb[0j6/[0BSZZT4YJVX1:FXY`BVYJ<4Yj:P1:BK
V0>RUI84Vhb919J2O`BAO7P4S7E^18U_I`>6JV44QFEK189PE@B0Fdl4OEI917aDA`AlEdX3NeY>17]L
DPAlH5H4OF=J17iWG`AoJV<3P6iX189bK0B3MW44QGUe18MmNPB8PGh4RXF35Oooo`005?ooo`B=S8/4
Si2?196CT`BBUYL4U9ZK0iJLWPBGX:84VJ>V19^VZPBLZZh4WZfb0ina]PBQ];X4XkNn1:Bk`PBU_/H4
Y/7:1:S5cP>R`/`4TkG019Jf_`BH][l4VKJl19^g_0BN^;d3X;Vl1:6g^0BP/k<4XK:b1:>b/@BN[:/3
XJb/1:>ZZ@BUZJP4YJRW1:JUX`BWXZ04Y9^H0j:ETPBKS8T4UX9o195lN0B<MFh4RFmW0hIZH@B5IE/4
PV1E181KC`AmETT4O5A717aGBP=kFTh4NeaB17aPEPAmHeX4OVMO17mZH`>0KVP4PW9/18=fL@B5NGD4
Qgej18R1OPB:QH<Eoooo000Doooo18f<R`B?T8l4TI>C19:FU`BDVY/3UYbN19NPXPBIXjH4VjJZ19bZ
[PBN[K83Wk6f1:6d^PBS]kh4Y;_21:FnaPBV`LX4Z<G>0j;2c0BC]L04U[Jo19Rf_`BI][`4VkNl19jh
_@>P^K`4XKNh1:2c/`BQ/[84Xk:a19j/Z`>Q[:`4XjZY1:FYZ0BUZ:L4YZFS1:NRX0BTViP3XYFB19^<
R@BFPWl4TGah18aeKPB9KfL3QVYQ18EUF`B2H5D4P5]?17eFB@AlE4L4O5M:0g]JCPAkG584O61F17eS
FPAnIel4OfYS0h1^J0B2LV`4PgIa18EiM@B7OGX4R85n18Z5PaGoool001Coool4SHf<18n@T0BAU9@4
TiNH19FKW0>GWZ04V:6T19ZUZ0BLZJ`4WJba19n`]@>Q/kT4XkNm1:Fk`PBV_/H4Z<;:1:W5cPBZbM<3
V;_719Bf`0BF]l04VKS019Zg_@BM^Kl4X;_00j>l_`BS^KX4XkFe19n][PBP[:d4W:NW0j2ZZ@BSZJP4
YJVX1:N[ZPBXY:84Z::O1:NNVP>VVYL4WY2<19F3P0B?NWH4RgA^18Q]IP>6JF44QFIL18AREPB1GE44
OeM:17aCA@AkE4L3NUI:17YICPAjG5<4Nf1G17aTG0AnJ643OfaV185`JPB3M6l4Q7Qd18IlN@B8PGh4
RXF35Oooo`005?ooo`B=SH`4Si2@196DU0BCUiP4UI^L0iNNX0BHXJ@4VZFX19bY[0BM[;44Wk2e0j6c
^@BS]kd4YK_21:JnaPBX`/X4ZLG>1:[9d`>H^lL4U;K019Jg`0BI^<04V[Nm19fi_`BP^l03Xkbo1:>i
^PBS]KD4Wjf^1:2/[@BLYjL3X:ZY1:>YZ0BUZJP4Yj^Z1:RTXPBXXYl4YijJ0jJJU`BNT8`4UH>018mj
MPB;M6h4R6eV0hIYH@B5IU`4Q69F185MD@AoEdX4O5=517]DA`=jETX4NUU>17YLD`AkH5L4O6AL17iX
H@=oK6H4PG1Z18=dK`B4N7@4QWai18R1OPB:QH<Eoooo000Doooo18f=S0B?T904TIBD19>GV0BEVi`3
UijP19RQY0BJYJP4W:V/19f//@BO/;D3XK>i1:>g_@BU^l84Y[k61:S2bPBYaLh4Z/WC0iRka`BD]/04
U[O019Vh`0BJ]kd4WKVo1:2k`0>S_;l4XkVj1:>e]@BO[Jh4X:b]19bWY`>PZZT4XjVX1:FYZ0BWZjX4
Z:BR1:RRW`BWWYX3YYZG19j@S0BEPh04SgYf18]dKPB8KFH3QVUQ18EVG0B4HUH4PEeA17mGBPAlDdD4
NeA70gYFBPAjFDh4NUaC17]PE`AlI5`4OVQQ0gm/IPB1L6X4PgA_18AhM0B6O7T4R85n18Z5PaGoool0
01Coool4SHf<18n@T0BAU9@4TiNH19FKW0>GWZ04V:6T19ZUZ0BLZJ`4WJba19n`]@>Q/kT4XkNm1:Fk
`PBV_/H4Z<;:1:W5cPBZbM<3V;_719Bf`0BF]l04VKS019Zg_@BM^Kl4X;_00j>l_`BS^KX4XkFe19n]
[PBP[:d4W:NW0j2ZZ@BSZJP4YJVX1:N[ZPBXY:84Z::O1:NNVP>VVYL4WY2<19F3P0B?NWH4RgA^18Q]
IP>6JF44QFIL18AREPB1GE44OeM:17aCA@AkE4L3NUI:17YICPAjG5<4Nf1G17aTG0AnJ643OfaV185`
JPB3M6l4Q7Qd18IlN@B8PGh4RXF35Oooo`005?ooo`B>SH`4T96@19:EU@BDV9T4UYbM0iNOXPBIXjH4
VjNZ19f[[`BO[[<4XK:h0j>f_0BU^/44Ykk61:W3bPB[a/l4ZlSA1:W9e0>A]L84U;K119Ng`@BJ^<04
W;Rn19nj`0BR_L83YKg01:Bj^PBU]KD4VZRY19fYZPBOZZX3XJVY1:B/Z`BVZj/4Z:bZ1:RVX`BYY:44
Z9nK0jNLV0BQTXh4V8R418ikM`B:LVd4QfaU0hIXH0B6IUd4QF=H18=NDPB0F4/4OUA517]CAP=hDdH4
MeE:17QIC`AiGE@4Nf5I17aVGP=nJV<4P6iY189cKPB4Mg<4QWah18R0O@B:Q88Eoooo000Doooo18j=
S0B@TI04TYFE19BHV@BFW9d3UinR19VSYPBKYjX4WJ^_19n^/`BQ/[P3XkJl1:Fj`@BW_/H4ZL?:1:_6
c`B[b=44ZLWD0i6e`PBD]/44UkO119Zh`0BL^;h4Wk[01::m`P>U_L04Y;Zj1:Fe]@BJZ:T4WJVZ19nZ
ZP>QZJT4Y:b[1:J[Z`BX[:X4Z:JS1:VTX@BXWi/3YibH1:6BSPBHR8@4SW]g18YbK@B7K6D3QVQP18IV
G@B5HeP4PeiB181HB`AnE4D4Ne=60gQCAPAgEDX4N5U?17UME0AkHET4O6IN0giZH`B0KVT4PW=^18Ag
L`B6O7P4R81m18Z4PQGoool001Coool4SXf<192AT0BBUID4U9RI19JLW@>GWj84VJ>V19^WZPBMZjl4
Wjjc1:6b^0>S][`4YK[11:NnaPBY`lX4ZlK?1:_8d@BYbM@3TKG219Bf`@BG]l44V[S019bh_PBO^/04
X[g20jFm`0BT^[X4YKFe19ZXZ@BMZJX4WjZZ0j6YZ@BT[:/4YZ^[1:R/ZPBXYZ<4ZJBQ1:ROV`>WW9P4
XI:>19R8Q0B>NgL4RW9]18M/I@>6J604QVIM18ESF0B3GU84P5Q;17iDA@AkDdH3N5=617MEBPAhFDl4
NEeD17]QF@AlIUh3OVYS181^J@B2Lfh4Q7Mc18IlN0B8P7d4RXB25Oooo`005?ooo`B>SH`4T96@19:E
U@BDV9T4UYbM0iNOXPBIXjH4VjNZ19f[[`BO[[<4XK:h0j>f_0BU^/44Ykk61:W3bPB[a/l4ZlSA1:W9
e0>A]L84U;K119Ng`@BJ^<04W;Rn19nj`0BR_L83YKg01:Bj^PBU]KD4VZRY19fYZPBOZZX3XJVY1:B/
Z`BVZj/4Z:bZ1:RVX`BYY:44Z9nK0jNLV0BQTXh4V8R418ikM`B:LVd4QfaU0hIXH0B6IUd4QF=H18=N
DPB0F4/4OUA517]CAP=hDdH4MeE:17QIC`AiGE@4Nf5I17aVGP=nJV<4P6iY189cKPB4Mg<4QWah18R0
O@B:Q88Eoooo000Doooo18j=S0B@TI44TYFF19BIVPBFWIl3V:6S19ZUZ0BLZJd4WZfa1:2a]PBR]KX3
Y;Vo1:Jma0BY`/T4[<O?1;7=ePB[b]<4Wl7=0i2d`0BD]/44V;S119^h`0BM^Kl4X;_01:>n`P>T^[h4
X[Jg1:6a/PBKZZ/4WjZ[1:6[Z`>SZj/4YJj]1:R][0BY[J/4ZJRU1:VTXPBWWIX3YibH1:>DSPBMS8L4
TX1j18QaJ`B6JV@3QVQO18MWGPB7I5T4QF1C189JC0AoEDL4Ne930gQA@`AdD4H4MUE;17MJD@AiGeH4
Nf=L0geXH@AoKFL4PG5/18=fLPB5NgL4Qh1m18V4PQGoool001Coool4SXf<192AT@BBUIH4U9VJ19JM
W`>HXJ<4VZFX19bY[@BN[K44X;6f1::e^P>T^Kl4Y[g41:W2b@B/all4/LgF1:_:d`BO`Ld3T;C019Bf
`@BH^<44VkS019fi_`BP^l04Xkk20jBj_PBR][L4XK6b19^ZZ`BOZZ/4XJ^[0j>[Z`BU[Zd4Z:f/1:V]
Z`BYZ:D4ZJBR1:NMVP>WW9P4XiB>19f<Q`BBP7X4R75[18IZI0>6J5l4QfMN18MTF@B5H5<4PUY<17mE
A`AkDT<3N55317A@APAfED/4MeYA17UOEPAkHe`3OFQQ17m]I`B1LF`4PgIb18EkM`B7P7d4RHB25Ooo
o`005?ooo`B>SH`4T96A19:EUPBDVIX4UYfO0iRQX`BJYJP4W:V]19j]/@BP/KH4X[Fj0jBi_`BV_L@4
ZL;91:c7c`BacMH4Zl[C19o1c@>@]<04U;K119Rh`@BK^<04WKVo1:2k`0BS_/83Y;Zn1::f]`BQ/K84
VjZ[19nZZ`BQZj/3Xj^[1:F^[@BX[J`4ZJf[1:VXY@BYY:84YifJ0jNLV0BSU8h4WHb719:0NPB8LF/4
QVYT0hIXG`B7Ieh4QfAI18EPD`B2FT`4OeE717]B@`=hDD<4M51617IEB`AgFU44NEmF17]SG0=mJ644
OfeW185aK0B3MW84QG]g18N0O@B9Q88Eoooo000Doooo18j=S0B@TY44TiJF19FJV`BGWZ03VJ>U19^V
ZPBMZjl4Wjnd1:6c^0BS]kd3YK_21:O0a`BZaLd4[l_C1;GAf`BVam44TkO30i>e`@BF]l44VKW119bh
`0BN^Kl4XK_01:Bm`@>T^K`4X;:d1:2_/@BP[Zh4XJf]1:>/[@>U[Jd4Yjj^1:V^[@BZ[:/4ZZVV1:VT
X@BXWY/3YIbF1::DSPBNS8L4UX9l18UbK@B5JF@3QVQP18QXGPB8IEX4QV5D18=KCPB1EdT4OeA50gA<
?`AbCD84Le9717EGC@AgG5<4NF5I0gaVG`AnJfD4P71[189eL0B5NWH4Qgml18V4PQGoool001Coool4
SXf<192BT@BCUYH4UIZK19NNX0>IXjD4VjJZ19f[[`BO[k@4XK>h1:>g_@>U^l84Yl371:[5c@B_bm<4
]M7K1:K7d@BC]l<3TkG119Jg`@BI^L44W;S019ji_`BQ^l04Y;g10jBi_0BP/[@4X:na1:2^[PBQ[Jd4
Xjb]0jF][@BW[Zh4ZJj]1:Z/Z`BZZJH4ZJBQ1:RNV`>UW9H4XYB>19j<Q`BFPW`4RG9]18EYI0>6J604
R6QN18QUFPB6HE@4Pe]>185GB@AoE4D3M4`o179=@PAcDTL4MEM=17MLD`AiHET3O6IO17i[I@B0L6/4
PWE`18EjMPB7Og`4RHB25Oooo`005?ooo`B>SH`4T9:A19>FUPBEVY/4UijP0iVSY@BKYZX4WJ^_19n_
]0BQ/kP4XkNm0jFk`PBW`<L4Z/G=1:o;d`BedM/4Y/OA19>g``>C]L44U[O119Vi`@BL^<04W[Vo1:6k
`0BT_L43Y;Vl1:2b]0BP[k44X:j^1:6][@BS[:d3YJf]1:N^[PBY[Zd4ZZb[1:ZYYPBYY:44Z9jK0jFL
UPBRU8h4WXb719J2O0B9LVd4QFUT0hIXH0B8J5h4R6EJ18IQE0B3Fdh4PEM917mDA@=dC3l4LTe217=B
A`AeEdd4MeaC17UQF@=lIUl4OV]U181`J`B2MG04QGYf18MoO0B9Q88Eoooo000Doooo18j=S0B@TY44
TiJF19FJV`BGWZ03VJ>U19^VZPBMZjl4Wjnd1:6c^0BS]kd3YK_21:O0a`BZaLd4[l_C1;GAf`BVam44
TkO30i>e`@BF]l44VKW119bh`0BN^Kl4XK_01:Bm`@>T^K`4X;:d1:2_/@BP[Zh4XJf]1:>/[@>U[Jd4
Yjj^1:V^[@BZ[:/4ZZVV1:VTX@BXWY/3YIbF1::DSPBNS8L4UX9l18UbK@B5JF@3QVQP18QXGPB8IEX4
QV5D18=KCPB1EdT4OeA50gA<?`AbCD84Le9717EGC@AgG5<4NF5I0gaVG`AnJfD4P71[189eL0B5NWH4
Qgml18V4PQGoool001Coool4SXj=196BTPBCUiL4UY^M19RPXP>JY:L4W:R/19n]/@BQ/KH4X[Fk1:Bi
`0>V_LD4Z<;:1:[6c`B^c=D4[/gH1:72cPBD]l<3U[O219Rh`PBJ^<04WKW019ni_`BQ^l04Y;c00jBi
_0BP/K<4XJn`1:6^[`BS[Zl4Y:j^0jJ_[`BX/;04Zk2_1:^]Z`B/ZZL4ZZFR1:VPW0>UViD4XY>>19f;
Q@BFPG/4SWI_18M[I@>7JF44RFQO18UVF`B8HUD4QEe?18AIBPB3ETH3KdLi16m:?@A`CT<4LeA:17EI
D0AhGeL3NVAM17eYH`AoKfT4PWA_18AiM@B7OW/4RHB15Oooo`005?ooo`B>SXd4TI:B19>GU`BFVid4
V:2R0iZTY`BLZ:`4Wjfa1:6a]PBR]K/4Y;W00jJma@BX`/X4Z/K?1:k<e@B^cMP4XL;>19Bg``>F]l84
V;S219Zh`0BM^L04WkVo1:6k`0BT_<03Y;Vl1:2a/`BQ[k04XJj_1:>^[`BT[Zh3YZn_1:R`/0B[/:l4
Zjf[1:bZY`BZYJ84ZJ2L0jFKU@BRThh4WH^519J1N`B>MVl4Qf]U0hMYH@B9J5l4RFIK18QRE@B5GDl4
Q5U:18=FAP=_AcT4KdXm171>@`AcE4X4MEU@17QOE`=jI5d4OFUS17m_J@B2M6l4Q7Ue18MnN`B9Q84E
oooo000Doooo18j>S@BATY84TiNG19JKW@BHX:83VZBW19bX[0BO[K44XK6f1::e^`BT^L03Y[g51:S2
bPBZa/l4[/cE1:k=f0BQ`/h4U;O30iJg`PBH^<84V[S019fi`0BO^Kl4XK_01:Bl`0>T^K`4X;6c1:6_
/0BQ[Zl4Xjj_1:B^[P>V[jl4Z;2`1:^`[`B[[J/4[:ZW1:ZUXPBYX9`3YI^E1::CSPBMRhD4UX5k18if
K`B7JfD3QfUQ18UXG`B9IU/4R69E18EMC`B4FDX4PeI60fm7>@A_BSd4L4i317=DBPAeFE04N5mG0gYT
G@AmJF<4OfmY189dK`B4NGD4Qgik18V4PAGoool001Coool4SXj=196BTPBCUiL4UY^M19RPXP>JY:L4
W:R/19n]/@BQ/KH4X[Fk1:Bi`0>V_LD4Z<;:1:[6c`B^c=D4[/gH1:72cPBD]l<3U[O219Rh`PBJ^<04
WKW019ni_`BQ^l04Y;c00jBi_0BP/K<4XJn`1:6^[`BS[Zl4Y:j^0jJ_[`BX/;04Zk2_1:^]Z`B/ZZL4
ZZFR1:VPW0>UViD4XY>>19f;Q@BFPG/4SWI_18M[I@>7JF44RFQO18UVF`B8HUD4QEe?18AIBPB3ETH3
KdLi16m:?@A`CT<4LeA:17EID0AhGeL3NVAM17eYH`AoKfT4PWA_18AiM@B7OW/4RHB15Oooo`005?oo
o`B>SXd4TI>C19BGV0BFW9h4VJ6S0i^VZ@BNZZh4X:nc1::c^0BT]kd4YKc30jO0a`BXa<`4Z/OA1:[;
e@BWb=@4X/;=19bla`>J^L<4V[S119bh_`BN^Kl4WkRo1:6j`0BT^l03Y;Vl1::c]PBQ[k04XZj_1:B_
[`BV/;03Z;2`1:Za/@B//K04[Jn]1:fZZ0B/YZ<4ZZ6L0jFJU@BPTX`4VhZ419J1NPB@N744RfmX0hU[
HPB:JV04RfQL18USEPB6GU04QUY;18EGA`=]ACL4JdHj16i;@0AaDDL4LeM>17IME0=iHU/4NfQQ17i]
J0B1Lfh4Q7Qd18InN`B9Ph4Eoooo000Doooo18j>S@BATi<4U9NH19JLWPBIXJ<3VjJY19jZ[PBP[k<4
X[>h1:Bg_@BU_<<3Yl371:S4c0BZam44Z/_E1:O8e0BR`/d4W;c70iZi``BJ^<44W;Ro19ji_`BO^;l4
XK[01:Bk`0>T^K`4X[>f1:6_/0BR[Zl4Y:n_1:J`/0>X/;04Z[6a1:ba/0B][jd4[JZX1:bVX`BZXI`3
YIZE1:2BS0BKRX@4UX5j191hL@B;KfP3RF]R18YZH0B;J5`4RF=F18IND0B6FT/4QEM70fe5=`A[ASX4
KT]0175AA`AcEdh4MUeD0gURF`AkJ644OVeX185cKPB4N7@4QWik18V3PAGoool001Coool4SXj=196C
T`BDUiP4UYbN19VQX`>KYZT4WZZ^1:2_/`BR/kP4Y;Nm1:Fl``>W`<L4Z<C<1:[7d@BZbmD4YlSD1:;2
c@BL_<L3V[W319Zh`@BL^;l4W[Vo19nh_`BQ^/04Y;_00jBi_0BR/kH4XJn`1::^[`BT[jl4Y[2`0jR`
/0BZ/K44[;6`1:f_[@B]ZZP4[:JS1:ZQW0>UVYD4X9:<19^:Q0BFPGX4T7Qa18]_J0>9Jf84RVYP18]X
G0B9HeH4QUi@18IJB`B5EdL3KDDg16]6>PA^Bd04LE5717=GCPAfGE@3NF9K17]XH@AnKFP4PG=^18Ah
M0B6OW/4RH>15Oooo`005?ooo`B>SXd4TI>C19BGV0BFW9h4VJ6S0i^VZ@BNZZh4X:nc1::c^0BT]kd4
YKc30jO0a`BXa<`4Z/OA1:[;e@BWb=@4X/;=19bla`>J^L<4V[S119bh_`BN^Kl4WkRo1:6j`0BT^l03
Y;Vl1::c]PBQ[k04XZj_1:B_[`BV/;03Z;2`1:Za/@B//K04[Jn]1:fZZ0B/YZ<4ZZ6L0jFJU@BPTX`4
VhZ419J1NPB@N744RfmX0hU[HPB:JV04RfQL18USEPB6GU04QUY;18EGA`=]ACL4JdHj16i;@0AaDDL4
LeM>17IME0=iHU/4NfQQ17i]J0B1Lfh4Q7Qd18InN`B9Ph4Eoooo000Doooo18n>S@BBTi<4U9RI19NM
W`BJXZD3WJNZ19n//0BQ/KD4XkFk1:Fj`0BW_/D3Z<;:1:W6c`BYbM<4Z<[F1:O7dPBS`/d4Wkg70i^j
``BK^<04WKNo19jh_`BP^Kl4X[Zo1:>k`0>T^Kd4Y;Fh1::_/@BS[Zl4YJn_1:Na/@>Y/K44Zk:a1:jc
/@B^/:h4[ZbY1:fVXPBZXI`3Y9VD1:2AR`BKRH<4UX5j195iLPB=LVT3S6mU18a/H@B<JEd4RFAG18QO
D@B7Fd`4R5U80f]4=PAY@cL4JdPm16i>A0AaE4/4M5YB0gMPF@AjIUl4OFaV181bK@B3N7@4QWej18V3
PAGoool001Coool4Shj=19:CT`BDV9T4UifO19ZRY@>MYjX4Wjb`1:6a]@BS]K/4YK[01:Nna@>X`/X4
ZLK?1:W9d`BXb]H4YlOB1:?2c@BO_LL3Vk[319^h`0BM]kl4W[Ro1:2i_`BR^[l4Xk_00jBi_@BT]KP4
XZna1:>^[`BU[jl4Yk6a0jVa/@B[/[44[[>a1:j`[PB^[:T4[JJR1:ZQW0>TVI@4X96;19^9P`BFPGX4
TGUb18ebJ@><KfD4S6aQ18aYG@B9I5L4R5mA18MKC0B8FDP3Jd@f16U3=`A[B3d4KTi4175DB`AdFU83
Mf1I17YVG`AmK6H4P79]18=hM0B6OGX4RH>15Oooo`005?ooo`B?SXd4TY>C19BHV@BGWIl4VZ:U0ifW
ZPBO[;04XK6e1:>e^`BU^/04Ykk50jS2bPBYa/l4ZLWC1:S:ePBWam84Xl;=19nma`>K^/<4VkS019fg
_`BN^;l4X;Vo1::j_`BS^l03Y;Vm1:Be^0BR[k44Xjj_1:F_[`BW/K43ZK6a1:^b/@B^/k44[[2^1:j/
Z@B]YZ84ZZ6L0jBIU0BPTH/4VhV319J1NPBANG84SG9Y0ha_I@B<K644S6UM18UTE`B8Ge44Qe]<18QI
B0=[A3H4JD<g16]8?@A^CT@4LEA;17AJDP=gH5T4NVIO17e/IPB0LVd4PgQd18ImNPB9Ph4Eoooo000D
oooo18n>S@BBTi<4U9RI19NMW`BJXZD3WJNZ19n//0BQ/KD4XkFk1:Fj`0BW_/D3Z<;:1:W6c`BYbM<4
Z<[F1:O7dPBS`/d4Wkg70i^j``BK^<04WKNo19jh_`BP^Kl4X[Zo1:>k`0>T^Kd4Y;Fh1::_/@BS[Zl4
YJn_1:Na/@>Y/K44Zk:a1:jc/@B^/:h4[ZbY1:fVXPBZXI`3Y9VD1:2AR`BKRH<4UX5j195iLPB=LVT3
S6mU18a/H@B<JEd4RFAG18QOD@B7Fd`4R5U80f]4=PAY@cL4JdPm16i>A0AaE4/4M5YB0gMPF@AjIUl4
OFaV181bK@B3N7@4QWej18V3PAGoool001Coool4Shj>19:DU0BEVIX4V9nP19^TYP>NZJ`4XJjb1:>c
^0BU^;h4Ykc31:S1b0>Ya<d4Z/SB1:[;ePBXb]H4YlOB1:?1b`BO^l@3W;W219fg_`BN]kh4WkRn1:2i
_`BR^[l4XkZo0jFi_@BU][X4Y;:c1:B^[`BV[k04Z;6a0jZa/@B//[44[kBb1;2a[`B_[JX4[JJR1:ZQ
W0>TV9<4Wi2:19Z8PPBFPGX4TWYb18mdJ`>?LFL4SViS18aYGPB:IEP4R5mB18ILC@B8FTX3KdLi16E0
<`AXACT4K4]1171BB0AcF4l3MUmG17UUGPAlJfD4Og5/189gL`B5OGX4R8>15Oooo`005?ooo`B?SXh4
TYBD19FIVPBHWj04VjBV0ijY[0BQ[[84Xk>h1:Fh_PBW_<<4Z<780jW4c@BZb=84Z/_F1:S:ePBWam84
Xl7;19nka0>L^L84WKNo19jg_PBO^;h4X;Vo1::j_`BS^[l3YKVm1:Ff^PBT/[<4Y:j_1:J_/0BX/K43
Z[6a1:bb/@B_];84/;6_1:n]ZPB]YZ84ZZ6L0jBHT`BOT8X4VXR219J1NPBBNW84SgA[0hmaI`B>KV<4
S6UN18YUF0B8Ge84QUa=18QJBP=_AcT4ID0c16Q5>@A/Bd44L59817=HC`=fGeL4NFEN17a[I@AoLF`4
PWMc18EmNPB8Ph4Eoooo000Doooo18n>SPBBU9@4UIVJ19ROX0BKY:H3WZV/1:6^/PBS/kP4YKRn1:Nl
``BX`LP3ZLC=1:[8dPBZbmH4Z<[F1:O7dPBS`L/4Wk_40ibi`PBM]kl4W[Nn19nh_PBP^Kl4X[Zo1:>j
_`>U^Kd4YKJj1:Bb/`BT[Zl4YZn`1:Ra/@>Z/K44[;:a1:nd/PB`/Jl4[jfZ1:fVXPBZXI`3Y9RC19n@
RPBJR884UX5j199jLPB?M6/3Sg5W18i^H`B<JEh4RVEH18QODPB6G4d4R5Y:0fm7>@AU@3<4J4Di16a;
@@A`DTP4LeQ?0gIOE`AiIEh4O6]U17maK0B2Mg<4QGej18R3PAGoool001Coool4Shj>19:DU0BEVIX4
V9nP19^TYP>NZJ`4XJjb1:>c^0BU^;h4Ykc31:S1b0>Ya<d4Z/SB1:[;ePBXb]H4YlOB1:?1b`BO^l@3
W;W219fg_`BN]kh4WkRn1:2i_`BR^[l4XkZo0jFi_@BU][X4Y;:c1:B^[`BV[k04Z;6a0jZa/@B//[44
[kBb1;2a[`B_[JX4[JJR1:ZQW0>TV9<4Wi2:19Z8PPBFPGX4TWYb18mdJ`>?LFL4SViS18aYGPB:IEP4
R5mB18ILC@B8FTX3KdLi16E0<`AXACT4K4]1171BB0AcF4l3MUmG17UUGPAlJfD4Og5/189gL`B5OGX4
R8>15Oooo`005?ooo`B?Shh4TiFE19JJV`BIX:84WJJX0j2[[PBR/;@4YKFk1:Nj`0BY_lH4Z/?;0j_7
d@B[bmD4ZlgI1:W:e@BWam84XKk819fj`P>M^<04WKJn19jf_PBP]kh4XKVo1::i_`BT^[l3YKVm1:Jg
^PBU/kD4Y:n_1:J`/0BY/K43Zk:a1:jc/PB`];84/K:_1;2]Z@B]YZ84ZZ2K0jBHT`BOT8T4VXN019F1
N@BCNg84TWM^0i5cJ@B?Kf@4SFYN18YUF0B7H584Q5]<18=HB@=dBc`4Id0c16A0=0AZB3d4KU16179F
C@=eGED4N6=L17]ZH`AoL6/4PWIb18ElN@B8Ph0Eoooo000Doooo18n?SPBCUID4UYZK19VPXPBMYZP3
X:^^1::`]0BU]K/4Yk[01:VoaPBZ`l/3ZlOA1:_;e@B[cMT4ZL[E1:O7dPBQ_/P4WK[20ifh`0BM][h4
W[Jn1:2g_PBQ^Kl4X[Vo1:Bj_`>U^Kd4Y[Nj1:Fc]@BT[jl4Y[2`1:Va/@>[/[44[[>b1;2d/PBa/Zl4
/:fY1:fVXPBZX9/3Y9RC19n@R@BJQh04UH5i19=kLPBBMfh3TG=Y18m_I0B=JUh4RVEH18MPDPB4Fd`4
PeQ90gA;?0AW@3<4I40d16Y8?@A^D4H4LUI=0gEME@AhHe`4NfYS17m`J`B2MW84QGai18R3P1Goool0
01Coool4Shn>19>EU@BFVY/4VJ2R19fVZ0>PZjh4X[2d1:Fe^`BW^/04ZKo61:[3b`>[am44Zl_E1:_=
f@BYb]D4YlOB1:6nb0BM^/83WKS019ff_PBN][h4X;Nn1:6i_`BR^Kl4Y;Zo0jFi_@BV]kX4YK>e1:B_
[`BV/;04ZK6a0j^b/@B^/k84/;Bb1;6b[`B`[JT4[JJR1:ZPV`>TV9<4Wi2919Z7P0BEPGT4Tg]b199g
KP>ALfT4SfmT18eZGPB:IEP4Qf1B18AKC0B3F4T3M4/l16M0<`AT@3@4JTPm16i@APAbETd3MEeE17QS
G0AkJV<4Og1[189fLPB5O7T4R8>05Oooo`005?ooo`B?Shh4TiFE19NKW0BKXJ<4WZNZ0j:]/0BT/kL4
YkRm1:Vm``B[`/T4[LO?0jg;e0B]cmX4[M3K1:_;ePBV`lh4X;[319bh`@>M][l4W[Jn19nf_@BP]kh4
X[Vo1:>i_`BT^Kh3YKRm1:Jg^PBU/[D4YK2a1:N`/0BZ/[83[;:a1:ne/`Bb]K<4/k>`1;6]Z@B^YZ84
ZInK0jFHTPBOShP4VHMo19J1N@BDO7@4U7U`0i9eJ`B?LFD4SFaO18YVF@B6H584PUU;17iEA`=eC3d4
JT0b16<n<@AYAc/4KDi4175EB`=dFe<4Mf9K17YXHPAnKfX4PGEa18ElN@B8PX0Eoooo000Doooo18n?
SPBCUID4Ui^L19^QX`BNYjX3XZf`1:Bc]`BW^;d4ZKg31:_2b@B]all3[L_D1:g?fPB]d=/4Zl_F1:K3
cPBP^/<4W;S10iff_`BN][h4WkJm1:2g_PBR^Kl4XkVo1:Bi_P>U^;d4Y[Nj1:Fb]@BU/;44Yk2`1:Zb
/P>//[44[kFc1;:e/`Bc/k04/JfY1:jVXPBYWi/3YIRB19n?R0BIQgl4UX5i19AlM0BDNG03TWE[18ma
I@B=K5l4RVII18IPDPB2FD/4OUE70gE<?@AZ@384Hcha16U7>`A]CT@4LEE;0gAKD`AgHU/4NVQR17i_
JPB1MG44QGai18R2P1Goool001Coool4Shn>19>EU@BGVi`4Vj6S19jWZP>R[K04Y;>g1:Nh_@BY_L<4
Zl;91:g7c`>]bm@4[LoJ1:g@f`B[bmH4Y/?>1:2j``BL^<43WKJo19jf_PBO][d4X;Nn1::i_`BS^Kl4
Y;Vn0jFh_@BV]kX4YK:e1:F`/@BW/;04Z[:b0jbb/@B_]K<4/[Fc1;>c/0Ba[JT4[ZJR1:VOV`>UV984
Whn819V7O`BFPGT4U7ad19AiL0>BMF/4Sg5U18e/G`B:IUT4QV1B189IB`AnEDL3MD`m16Y0<PAS?S44
JDLk16e>A0AaED/3M5]C17MRF`AjJ684OVmZ185eL@B5O7T4R8:05Oooo`005?ooo`B?Shh4TiFE19NK
W0BKXJ<4WZNZ0j:]/0BT/kL4YkRm1:Vm``B[`/T4[LO?0jg;e0B]cmX4[M3K1:_;ePBV`lh4X;[319bh
`@>M][l4W[Jn19nf_@BP]kh4X[Vo1:>i_`BT^Kh3YKRm1:Jg^PBU/[D4YK2a1:N`/0BZ/[83[;:a1:ne
/`Bb]K<4/k>`1;6]Z@B^YZ84ZInK0jFHTPBOShP4VHMo19J1N@BDO7@4U7U`0i9eJ`B?LFD4SFaO18YV
F@B6H584PUU;17iEA`=eC3d4JT0b16<n<@AYAc/4KDi4175EB`=dFe<4Mf9K17YXHPAnKfX4PGEa18El
N@B8PX0Eoooo000Doooo192?S`BDUYH4V9bM19bSY@BPZJ`3Y:nc1:Ne^PBZ^l04[<371:k6c@B`b]<3
/<oH1;3Cg@B_dM`4Zl[D1:Bnb@BN]l44VkFn0ibe_PBN][d4WkJm1:6h_PBR^Kl4XkVo1:Bi_P>V^;`4
YKJi1:Fb]0BU/;44Z;6a1:Zc/P>]/k84/;Jd1;>e/`Bd/k04/ZfY1:jVXPBYWYX3YINA19j>Q`BJQgl4
Uh9j19InM@BENg43TgM/191bI`B=K604RFII18EPDPB0F4/4NeA60g=:>`AZ?c04JD8d16Y6>`A]CD84
L5=:0g=JD@AfHET4NVMQ17e^J@B1MG04Q7]h18R2P1Goool001Coool4T8n?19BFUPBHW9d4W:>U1:2Y
[0>T[k<4YkFj1:Zk`0B/`<L4[/K=1;3:d`>`cmP4/=?M1:oAg0B[b]@4Y;k919jg`@BK]Kh3W;Fn19jf
_@BO][d4XKRn1::i_`BS^Kl4Y;Vn0jJh_0BU][T4YK:d1:F`/@BX/K44Z[>b0jfc/PB`][@4/kFc1;Bc
/0Bb[JT4[ZJR1:VNVP>UUi44WXj719Z7O`BGPWX4UWie19EkL@>CMf`4T79W18e/H0B9IUT4QF1B181H
B`AkE4H3LdXk16Xo<0AY@S@4JTHk16e=@PA`DdX3LeYA17IQF@AjIf44OFiY185eL0B4NgP4R8:05Ooo
o`005?ooo`B@Shl4U9JF19RLW@BLXjD4X:V/0jB_/`BW]KX4Z[_01:c0a`B^a/d4/<[C0k3?f0B`dmd4
[m7L1:_:e0BT_/T4W[O119^e_P>L]Kh4W[Jm19nf_@BQ^;h4X[Vo1:>i_`BT^Kh3Y[Rl1:Ff^@BU/[@4
YK2a1:Ra/@BZ/k83[K>b1;2f]0Bc]K<4];>`1;:]Z@B^YZ84ZIjJ0jFGT@BNSXL4VXMo19N2NPBFOWD4
UG]a0i=gK0B@LVL4SFaP18UVF@B5H584P5Q;17]DAP=cBS/4JSl`16U2=0AZAS/4KDe2171CBP=cFU44
MV5I17YWH@AmKVT4PGE`18AkN0B8PX0Eoooo000Doooo192?S`BDUYH4V9bM19bSY@BPZJ`3Y:nc1:Ne
^PBZ^l04[<371:k6c@B`b]<3/<oH1;3Cg@B_dM`4Zl[D1:Bnb@BN]l44VkFn0ibe_PBN][d4WkJm1:6h
_PBR^Kl4XkVo1:Bi_P>V^;`4YKJi1:Fb]0BU/;44Z;6a1:Zc/P>]/k84/;Jd1;>e/`Bd/k04/ZfY1:jV
XPBYWYX3YINA19j>Q`BJQgl4Uh9j19InM@BENg43TgM/191bI`B=K604RFII18EPDPB0F4/4NeA60g=:
>`AZ?c04JD8d16Y6>`A]CD84L5=:0g=JD@AfHET4NVMQ17e^J@B1MG04Q7]h18R2P1Goool001Coool4
T92?19FGU`BJWYl4WZFV1::[[P>V/[D4Z[Rl1:fn``B`a<X4//WA1;??e`>ddmd4/mGO1;7Af`BZam84
XK[519^d_PBJ];`3W;Bl19ff_@BO]kh4XKRn1:>i_`BT^Kh4YKVm0jJg^`BU]KP4YK6c1:F`/0BX/;44
Z[:a0jfd/PBa][@4]KJd1;Fc[`Bc[JT4[jJQ1:ZNV0>TUY04Whj719^8P@BIQ7/4V81g19IlLP>DN6d4
TG=W18e]H@B9IeX4QEmC17mHBPAjE4H3LdTk16]0<@AY@C<4JTDi16a;@0A^DTP3LUQ@17EOF0AhIV04
O6eX181dL0B4NgP4R8:05Oooo`005?ooo`B@T8l4UING19ZNW`BNYJH4XZ^^0jJb]@BZ^;`4[Kk31;34
bPBbbM44/loG0kCCg@BceMl4/M7K1:[7dPBQ^/D4VkBn19Zd_0>L];`4WKJm19ng_PBQ^;h4XkVo1:Bi
_PBU^Kd3Y[Nk1:Fe^0BU/K<4YK2`1:R`/@BZ/[43[KBb1;6f]0Be][@4]K>_1;>]Z@B_YZ44ZYjH0jBF
T0BOSXL4VhR119V4N`BHP7L4UWab0iAhK@BALfL4SFeQ18UWFPB5Ge<4OeQ:17YDAP=cBC/4Jd0a16U1
<`AZACT4K4]016iBB0=bF504MEmH17QVH0AlKFP4P7A`18AkN0B8PX0Eoooo000Doooo192@S`BEUiL4
VYjO19jUYPBRZjh3Y[:e1:Zh_0B]_/<4/<C:1;;9d@BccmL3]=?M1;?Eg`BadM/4Z/OB1:6ja@BK];h4
V[Bl0ibd_0BM][d4WkNn1:6h_PBS^Kl4Y;Vn1:Fi_@>V]k/4YKFh1:Fa/`BU/;04Z;2a1:Zb/@>]];84
/KJd1;Ff]0Be/jl4/jfY1:nVX@BZWYP3Y9J@19n>Q`BKR844VHAk19R0M`BFO783U7Q]195cI`B=KF44
RFMJ18EOD`AoF4X4NUA60g=9>`A[@344JD4c16Y5>@A/Bd04KU980g9HD0AeGeP4N6IP17a]J0B0M704
Q7]h18R2P1Goool001Coool4T92?19FGU`BJWYl4WZFV1::[[P>V/[D4Z[Rl1:fn``B`a<X4//WA1;??
e`>ddmd4/mGO1;7Af`BZam84XK[519^d_PBJ];`3W;Bl19ff_@BO]kh4XKRn1:>i_`BT^Kh4YKVm0jJg
^`BU]KP4YK6c1:F`/0BX/;44Z[:a0jfd/PBa][@4]KJd1;Fc[`Bc[JT4[jJQ1:ZNV0>TUY04Whj719^8
P@BIQ7/4V81g19IlLP>DN6d4TG=W18e]H@B9IeX4QEmC17mHBPAjE4H3LdTk16]0<@AY@C<4JTDi16a;
@0A^DTP3LUQ@17EOF0AhIV04O6eX181dL0B4NgP4R8:05Oooo`005?ooo`BAT904UYRH19^OX0BPYZP4
Y:f`0jVd^0B]^kl4/<;71;?8cPBfc]D4^=?L0k[Ih`Bif>44]=7J1:S4cPBL]/44V;6k19Vb^`>J/k`4
WKFm1:2g_PBR^Kl4Y;Zo1:Fj_PBV^Kd3YKJj1:Fc]PBT/;84Y:n`1:N_[`BZ/K03[[>b1;:f]0Be][@4
][>_1;B]Z@B_YZ44ZYjH0jFFT0BPT8P4WHZ219^5O@BIPGP4Ugec0iEiKPBAM6P4SViQ18UWFPB4H5<4
OUU;17UEA`=bBC/4K4<d16Hm;`AX@cH4JTTn16e@AP=`Edh4M5iF17MUGPAkK6L4Og=_18=jM`B7PWlE
oooo000Doooo196@T0BFV9P4VinP1:2VZ0BT[K03ZKBh1:fk_`B``/L4/lS>1;K>e@Bhdm`3^]WS1;WH
h@BddMX4Z<C>19bf`@BH/K/4VK:k0iZc_0BM]Kd4X;Nn1::i_`BT^[l4YKZn1:Ji_@>U][X4YK>f1:B`
/PBT[k04Yjn_1:Za/0>^/k84/[Jd1;Ff]0Bf/jl4]:fY1:nVX@BZWYP3YIJ@1:2@R0BMRX84VhEm19V1
N0BGOG<3UGU^195dJ0B>KV44RFMJ18APD`AnFD/4NEE70g99>`A/@c@4ISd_16Q3=PAZBCh4KE160g1G
CPAdGUH4MfEN17]/I`AoLfl4PgYg18N2OaGoool001Coool4TI2@19JHV0BKWj04X:JX1:B]/0>Y];P4
[K^o1;32a`Bcb<h4]/kE1;SCg0>jfN<4^MSQ1;CAfPBXa<h4W;K119Ra^`BI/[/3V[>l19fe_@BP]kh4
X[Vo1:Bj_`BU^[h4Y[Vm0jFf^PBU/kH4Y;2b1:B_/0BW[jl4Z[6`0jjc/PBb][@4]KJd1;Jc[`Bd[JT4
[jJQ1:ZNV0>UUY04X92819f:PPBKQGd4VH5h19MmL`>ENFh4TGAX18i^H@B9IeX4Q61C17iIB`AiEDL3
LTTk16a3=0AV?Bl4J4<f16Y9?PA]D4H3L5M>17ANEPAgIEh4NfaW17mcK`B3NWL4Qh9o5Oooo`005?oo
o`BAT904UYRH19^OX0BPYZP4Y:f`0jVd^0B]^kl4/<;71;?8cPBfc]D4^=?L0k[Ih`Bif>44]=7J1:S4
cPBL]/44V;6k19Vb^`>J/k`4WKFm1:2g_PBR^Kl4Y;Zo1:Fj_PBV^Kd3YKJj1:Fc]PBT/;84Y:n`1:N_
[`BZ/K03[[>b1;:f]0Be][@4][>_1;B]Z@B_YZ44ZYjH0jFFT0BPT8P4WHZ219^5O@BIPGP4Ugec0iEi
KPBAM6P4SViQ18UWFPB4H5<4OUU;17UEA`=bBC/4K4<d16Hm;`AX@cH4JTTn16e@AP=`Edh4M5iF17MU
GPAkK6L4Og=_18=jM`B7PWlEoooo000Doooo196AT0BGVIT4WJ2Q1::XZPBW/;83[;Nj1;2n`PBdaLX4
^<cB1;_Bf@Bmf>03`=oX1<3Kh`Bdc]L4YL3:19Fa_0BC[[T4U[2i0iVb^`BL];`4X;Nn1:>i_`BV^[l4
Y[Zn1:Ni_@>U][T4Y;:e1::^/@BS[Jh4YJf]1:V`[`>^/k44/kJd1;Jg]0Bg];04]JfY1;6VX@B[WYP3
YiN@1:>ARPBPS8<4WHMn19^2N@BHOW<3UWU^199dJ0B>KV84RFQK18AQD`AoFTd4NUI80g59>`AZ@S@4
I3T[16I0<`AXAc`4Jdi40fiEC0AbG5D4MV=M17Y[IPAnLVh4PgYf18N1OaGoool001Coool4TI6@19NI
V@BMX:44XZRZ1:N`/P>/]kX4/;k21;C5bPBhc=84^m;I1;gHh0?0gnP4`=_S1;C>e`BU`<X4UK6l19>^
^@BF/;T3VK:k19bd_0BP]kh4XkVo1:Jj_`BV^[h4YkVm0jFf^@BT/[D4XZja1:>][PBU[Jd4ZK2_0jjc
/@Bc][@4][Nd1;Nd/0Be[JT4/JJQ1:^NV0>WUi04Xi6:1:2<P`BMQgh4Vh9i19QnL`>FNFh4TWAX18i^
HPB9J5/4Q65C17mJC@AjETP3LDTk16Y2=0AT>B/4IT0c16Q7?0A[CT@3KUE<179LE@AfHed4NV]V17ib
KPB3NWH4Qh5o5Oooo`005?ooo`BATI04UiVI19fPX@BRZ:X4Yk2b0jbg^PB`_/84]<G:1;S<dPBkd]T4
_MSP0l3Oj0C0fn<4]<kG1:G0bPBE/K`4Tjji19J`^@>I/[/4W;Bl1:2g_PBS^Kl4Y[Zo1:Jj_PBW^Kd3
YKJi1:Bb]@BR[[44Xjf^1:F][@BY/:l3[[>a1;>f]0Bf]k@4]kB`1;F]Z@BaYZ44ZijH0jNGT0BSTHX4
X8b319f7OPBKPWT4V7ic0iIiKPBBM6P4SViR18UXF`B4HE<4OeY=17YFB0=aBC/4JT8d16@i:`AV@3<4
J4Ll16]>A0=^ED`4LUaE17ISG@AjJfH4OW9^18=jMPB7PGlEoooo000Doooo19:AT@BHVYX4WZ:S1:BZ
[0BZ/[@3/;Zm1;G2aPBibLh4_M3F1;oFg@C2g>@3aN7Z1<CLi0BecMD4X[g718f[^0B?ZkH4Tjjh0iN`
^@BK];`4XKRn1:Fj_`BX_<04ZK^o1:Rj_@>U][T4X[2d1:2][`BQZZ`4XjZZ1:R][@>]/K04/kJc1;Rg
]0Bi];04]ZjZ1;>WX@B^WiT3ZYVA1:JCR`BRSHD4WhQn19b3NPBHOW<3UGU^199dJ0B>Kf84RVUL18ER
E0B0G4h4NeM90g1;?@AV?c44HCHX16<m<0AVA3T4JDa20faCBPA`FU<4M69L17UZI0AmLFd4PWUf18N1
OaGoool001Coool4TY6A19RJVPBNXZ<4Y:Z/1:Zb]0>`^[d4]L;61;W9cPBmd=H4_mKM1<;Li0?5hNX4
a=cT1;G=e@BR_LL4SJ^h18n[]PBC[[P3Uk2i19^d_0BQ^;h4YKZo1:Rl`0BY^kl4Z;Zm0jFf^@BR/;@4
X:f_1:6Z[0BSZZX4Z:f]0jfa/0Bc][<4^;Nd1;Vd/0Bf[ZX4/jNQ1:jOV@>ZVI44YY>;1::=Q@BOR7h4
W8=j19QnL`>ENFh4TWAX18i_HPB:JE`4QF9D181LCPAkEdT3L4/m16Ho<@AQ=RP4Hcd`16I4>@AYC483
K5=:171JD`AdHU`4NFYT17eaK@B2NGH4Qh5o5Oooo`005?ooo`BBTI44V9ZJ19jRX`BTZZ`4Z[:d0k2j
_@Be`/H4^LW>1;g@ePBoe]d4`]cT0lGQjPC4g>@4]LgE1::ma`B=ZkP4Sj^f19>^^0>G/;T4VkBl1:6h
_PBU^[l4Z;c01:Vk_`BX^[d3YKJi1::`]0BP[Jl4XJZ/1:>ZZPBX[Jd3[K6`1;>f/`Bh]k@4^KB`1;J^
ZPBcYj44[YnI0jZIT@BVTh/4XXf519n8OPBLPgX4V7ic0iEiKPBBM6P4SVmR18YYG0B5HU@4P5a>17]G
B@=`Bcd4ISla164f:0AS?C04IT@i16U<@P=/DdX4L5YC17ARG0AiJV@4OG5]189iMPB7PGlEoooo000D
oooo19:AT@BHVYX4WZ:S1:BZ[0BZ/[@3/;Zm1;G2aPBibLh4_M3F1;oFg@C2g>@3aN7Z1<CLi0BecMD4
X[g718f[^0B?ZkH4Tjjh0iN`^@BK];`4XKRn1:Fj_`BX_<04ZK^o1:Rj_@>U][T4X[2d1:2][`BQZZ`4
XjZZ1:R][@>]/K04/kJc1;Rg]0Bi];04]ZjZ1;>WX@B^WiT3ZYVA1:JCR`BRSHD4WhQn19b3NPBHOW<3
UGU^199dJ0B>Kf84RVUL18ERE0B0G4h4NeM90g1;?@AV?c44HCHX16<m<0AVA3T4JDa20faCBPA`FU<4
M69L17UZI0AmLFd4PWUf18N1OaGoool001Coool4TY:A19VKV`BPY:@4Yjb^1:fe]`>d_/04^LK:1;k>
dPC2eMX4aM_Q1<OPj0?8h^T4bMkU1;K<e0BN^L<4QjNd18^X/`B?ZkD3U:jg19Zb^PBQ]kh4Y[_01:Zm
`@B/_;l4ZKVl0j>d^0BN[K44WZb^19jXZPBOYJH4YZZZ0jf`[`Bd]K<4^KNd1;^e/@Bi[jX4]ZVR1;2Q
V@>]Vi<4ZIF=1:F?QPBQRH04WHAj19MmL`>ENFh4TgAX18m_HPB:JE`4QF=E185MC`AlF4X3Kd/l168l
;PAM<R@4H3X^16=2=`AVBD03JU5916iID@AcHEX4MfQS17aaK0B1NGD4QX5n5Oooo`005?ooo`BBTY44
VI^K1:2TY0BW[:h4[KFg0kBn`0Bia/X4_/kB1<;EfPC5fn44an3X0lSRj@C9g^D4]/cD19ji``B7Yk@4
RjRc18n[]@>D[[L4V[:j1:6g_PBV^l04Z[g11:bl_`BY^K`3XkBh19j]/@BN[:h4WZRZ19nUYPBVZZX3
[K2_1;Be/`Bi]k@4^kFa1;V_ZPBfZJ84/:6I0jfKT`BYUHd4YHn61:69P0BMQ7X4Ugec0iEiKPBCM6P4
SfmR18YYG0B5HeD4PEe?17aHBP=_Bc`4HS`^15db90AP>Rh4Hd8g16I9@0=ZDDT4KUUA17=QFPAgJ6<4
O75/185iM@B6PGhEoooo000Doooo19:BT@BIVi/4X:BT1:N/[PB]]KL3];k01;W6bPBnc]84`]GJ1<GK
h@C7h>P3b>;Y1<WNi@Bfc=@4W[W318NW]0B;Z;<4Sj^e0iB^]`BJ/[X4XKNn1:Jk`0BZ_L44[;bo1:Vi
_0>S];P4WZfa19j/[PBNZ:X4WjFV1:JZZP>]/:l4];Fc1;Vg]0Bk]K44^JnZ1;JYXPB`XIT3[I^C1:VE
S@BUShH4XHV019f4NPBGOG<3UGU^19=dJ0B?Kf84RVUL18ESE@B1GDl4O5Q:0fm;?0AR?2h4GC8T160j
;PAS@SL4ITU00fYAB@A^FE44Lf5J17MXH`AlLF`4PGUe18J1OQGoool001Coool4TY:A19VKV`BPY:@4
Yjb^1:fe]`>d_/04^LK:1;k>dPC2eMX4aM_Q1<OPj0?8h^T4bMkU1;K<e0BN^L<4QjNd18^X/`B?ZkD3
U:jg19Zb^PBQ]kh4Y[_01:Zm`@B/_;l4ZKVl0j>d^0BN[K44WZb^19jXZPBOYJH4YZZZ0jf`[`Bd]K<4
^KNd1;^e/@Bi[jX4]ZVR1;2QV@>]Vi<4ZIF=1:F?QPBQRH04WHAj19MmL`>ENFh4TgAX18m_HPB:JE`4
QF=E185MC`AlF4X3Kd/l168l;PAM<R@4H3X^16=2=`AVBD03JU5916iID@AcHEX4MfQS17aaK0B1NGD4
QX5n5Oooo`005?ooo`BCTY44VibK1::UY@BZ[k04/KRj0kS1a0Boblh4aM?G1<[Kh0C;h>H4bn?[0l[Q
i`C:g>84]<WA19Ve`0B1X[04QZFa18bX/`>B[;D4V;2h19je^`BU^Kl4Z;Zn1:jm_`BY^K`3X;6f19^Z
[PBIZ:/4VZBV19bRX`BUZ:L3[Jn]1;Be/`Bj^;D4_KJb1;^aZ`Bj[JD4/Z6I0k6MU@B_VHl4ZI:91:::
P0BMQ7X4Ugec0iAiK@BBM6P4T71R18]ZG0B6I5H4Pem@17aHB@=/B3/4GST/15T_8PAL>2`4H3le16=7
?P=WCdL4K5M@175OF@AfIf84Ng1[185hM@B6P7hEoooo000Doooo19>BT@BKW9/4XZFU1:Z_/0Ba^;X3
^<741;o;cPC5dmL4b]_P1<_PiPC;hn/3b^7W1<[LhPBdbM44VKG0186R/0B6YK44S:Rc0i:/]@BH/;P4
W[Fk1:Fi_`BX^[h4[[fo1:Vi_0>P/KH4VjZ^19VXZ`BJY:H4W::S1:FXY`>][jd4];Fc1;Zh]@Bm][84
^k6[1;Z]Y@BbXIT3/IfE1:nIS`BYTXT4XXZ019f4NPBGOG<3U7U]199dJ0B@L684RfYL18ITEPB3Ge04
O5Q90fa8>`AN>B`4FBlR15`h;0AP?cD4HdLn0fM?A`A/Ee04LEmI17IWHPAkL6/4PGQe18J0OQGoool0
01Coool4Ti:A19^LV`BRYJD4ZZn`1;6h^P>h`L@4_l_>1<GCe`C:fn04bn3V1<_Sj`?:hNL4b]cR1;C9
d@BI]L04PJ:`18JU/@B<Z;<3TZbe19R`^0BN]K/4YKVo1:Rj_PB^_Kl4ZKVl0j2a]PBKZZh4VJR[19ZT
YPBLXZ<4YJRW0jf_[@Bd]K<4^[Re1;ff/PBk/J/4^ZfU1;:QV@>aWID4[iV?1:VBR@BRRX04WHAj19Mm
L`>DNFd4TWAX191`HPB;JU`4QVAF18=OD0AlF4T3K4Pk15hi;0AI;b84G3P/160o=@ASAch3Idm716aG
D0AaGeT4MVMR17]`J`B1N7D4QX1n5Oooo`005?ooo`BCTY44VibK1::UY@BZ[k04/KRj0kS1a0Boblh4
aM?G1<[Kh0C;h>H4bn?[0l[Qi`C:g>84]<WA19Ve`0B1X[04QZFa18bX/`>B[;D4V;2h19je^`BU^Kl4
Z;Zn1:jm_`BY^K`3X;6f19^Z[PBIZ:/4VZBV19bRX`BUZ:L3[Jn]1;Be/`Bj^;D4_KJb1;^aZ`Bj[JD4
/Z6I0k6MU@B_VHl4ZI:91:::P0BMQ7X4Ugec0iAiK@BBM6P4T71R18]ZG0B6I5H4Pem@17aHB@=/B3/4
GST/15T_8PAL>2`4H3le16=7?P=WCdL4K5M@175OF@AfIf84Ng1[185hM@B6P7hEoooo000Doooo19BC
TPBLW9`4Y:NW1:ba/@Be^k`3_LG71<G@dPC=f]d4dn?W1=OZk`C;h^T3b]kT1<KHgPBba/h4UK:m17bN
[0B2XJh4RJJ`0hnZ/`BE[[D4Vk6g1::f^`BU^;`4Z[Zm1:Jf^@>P/;@4VZV]19NUZ0BHXZ@4WZ>S1:FW
YP>][Zd4]KFc1;^h]@Bn]k84_K:/1;b^Y@BfXYX3]j6G1;FMTPBYThT4XXZ019j5N`BFOG<3TgQ]191c
I`B@Kf84SFYL18QVE`B6H544OEQ90fU6>@AH=RT4EBdQ15Te:PAL?C84H4@k0fA<A@AYEDh4KUeG17AV
H@AjKf/4P7Md18J0OQGoool001Coool4U9>B19bLW0BTYjL4[;6a1;Fk_0>maLL4aM3B1<gJg@CChnL4
en[_1<_Rj@?:g^@4a]SN1;;6cPBE/[d4O9j/18:Q[PB9Y[03SjZc19F^]@BK/KL4X[Jk1:Fh_0BZ^[d4
Y[Ji0j2`]0BJZJd4UjFX19RRY0BNXj<4YJNV0jf^[@Be]K<4^kRe1;jg/PBm/Z`4_:jU1;JRVP>gXIL4
]IfB1:VCR@BRRX04WXEk19ImL`>CN6d4T7=W191_HPB=JU`4R6IG18IPD@AmF4T3JDHi15Pf:@AE;B44
FCDZ15`m<PAPA3/3I4a516UECPA^GEL4M6IQ17Y_J`B0Mg@4QX1n5Oooo`005?ooo`BDTi84W9bL1:BW
Y`B//K44]K^l0kg5a`C5d=84cM[M1=?Si`CGj^l4bn;Y0l[Ni0C6f=h4//K>19Fb_@AlWZ`4PZ6^18VV
/0>?Z[<4UJje19^a]`BR][/4YKRl1:Zj_@BV][T3X;2d19ZY[@BGYJP4V::T19jSX`BUYjH3[Jj]1;Fe
/`Bk^;D4_[Nb1;fb[0Bl[ZD4]Z:J0kNQU`BeWI84ZI>91:::P0BNQG/4UWec0i=hK@B@LfL4T6mR18eZ
G0B8IUL4QV1A17eHB@=YAST4F3HY15D]8@AI=BX4G3db1614>`=TC4D4JEE>16iME`AdIV44NVm[181g
M0B6P7hEoooo000Doooo19BCTPBLW9`4Y:NW1:ba/@Be^k`3_LG71<G@dPC=f]d4dn?W1=OZk`C;h^T3
b]kT1<KHgPBba/h4UK:m17bN[0B2XJh4RJJ`0hnZ/`BE[[D4Vk6g1::f^`BU^;`4Z[Zm1:Jf^@>P/;@4
VZV]19NUZ0BHXZ@4WZ>S1:FWYP>][Zd4]KFc1;^h]@Bn]k84_K:/1;b^Y@BfXYX3]j6G1;FMTPBYThT4
XXZ019j5N`BFOG<3TgQ]191cI`B@Kf84SFYL18QVE`B6H544OEQ90fU6>@AH=RT4EBdQ15Te:PAL?C84
H4@k0fA<A@AYEDh4KUeG17AVH@AjKf/4P7Md18J0OQGoool001Coool4U9>B19fMW@BVZ:P4[k>c1;Rn
_`?2bL/4bmGG1=KQi0CQko84gnoc1<kRi`?7fMl4`]?I1:c2bPBA[[X4N9ZY17nNZ`B5Xjd3SJVa19>[
/`BG[K<4W[6g1::e^@BU][T4Xk>g0j2_/`BKZJd4V:BW19ZSY0BOY:@4YZRW0jf_[@Be]K<4^kRd1;jg
/PBn/Z`4_:fU1;VUW0>iXiT4^Z2E1:RBR@BSRh44WhIk19AlLP>BMf`4T79V195`HPB?K5d4S6MH18]S
D`AlEdP3ITDh15<c:0A@:Qh4E38W15Lj<0AL@ST3HDY216ICC0A/FeH4LVAP17Q]JPAoMg@4QH1n5Ooo
o`005?ooo`BDTi84WIfM1:JXZ0B_/k<4^;jo0l;9b`C;eML4e^7T1>7_lPCOko<4c^;W0lOIg`C2dmT4
[<;:196^^PAhVZT4Oij[18FS[@>=ZK44Tj^c19N]/`BN/KL4X[Fi1:Ff^@BS/kL3X:nc19^Y[@BHY:L4
VZ>T19nTY0BVZ:L3[Jn]1;Fe/`Bk^;@4_[Nb1;jb[0Bl[JD4^JFL0kVSV@BjX9D4Z9:91:>;P@BOQW/4
U7ab0i9gK0B@LVH4TG1R18m/G@B<IeP4Rf=C17aGB0=VACP4Dc<X150Z7PAD<RL4EcX`15a2>@=QBT84
IU=<16aKEPAbI604N6eZ17mgM0B5P7hEoooo000Doooo19BCTPBMWId4YZRX1:nc/`Bh_[l3`/W;1<_E
e`CFhN@4hNob1=o_l`C>h^L3amWO1<;Cf@B/`/X4TJjj17RJZ@AoWZ/4QJ>]0hfY/@BCZk<4Ujfc19ja
]`BR]KT4YKJi1:>c]`>P[k<4VjV]19RTY`BJXj@4WjBT1:JXY`>][jd4]KFc1;^h]0Bn]k84_[:/1;b]
Y@BiYI`3^J>I1;ZPU@BXTXT4Xh^119n6N`BDO783TWM/191bIPBAL684SfaM18aWF0B;He<4O5M80fI5
>0AC<bP4D2XN15@b9`AG>S04G48i0f5:@PAVDd`4K5]F179TH0AhKFX4OgMd18F0OQGoool001Coool4
U9>B19fMW@BVZ:P4[k>c1;Rn_`?2bL/4bmGG1=KQi0CQko84gnoc1<kRi`?7fMl4`]?I1:c2bPBA[[X4
N9ZY17nNZ`B5Xjd3SJVa19>[/`BG[K<4W[6g1::e^@BU][T4Xk>g0j2_/`BKZJd4V:BW19ZSY0BOY:@4
YZRW0jf_[@Be]K<4^kRd1;jg/PBn/Z`4_:fU1;VUW0>iXiT4^Z2E1:RBR@BSRh44WhIk19AlLP>BMf`4
T79V195`HPB?K5d4S6MH18]SD`AlEdP3ITDh15<c:0A@:Qh4E38W15Lj<0AL@ST3HDY216ICC0A/FeH4
LVAP17Q]JPAoMg@4QH1n5Oooo`005?ooo`BEU9<4WYjN1:RZZPBb]KD4_<710lK=cPCAfM/4g^OY1>gh
nPCPk_44dnCX0lKFg0BkcM@4Xk_518^Z]PAeV:H4Ni^X18:PZP>:YJh4TJR`19J//PBK[[@4X;6f1::c
]`BR/KD3Wjfa19bY[0BJYJP4Vj:T1:2UY@BVZJP3[Zn]1;Je/PBl]k<4_kNb1;nb[0Bm[JD4^JJM0kVS
V0BgWY<4ZiB:1:F=PPBOQW/4UGeb0iAhK@BDM6L4Tg5S199]GPB@JUX4SVIE17UEA`=R@cH4Cc<W14/V
6`A>;R@4DSH]15Ln=P=MAd04He1:16UIE0A`Heh4MfaY17ifL`B5OgdEoooo000Doooo19FDT`BNWYh4
Z:ZZ1;:e]@Bl`L43a/g>1=7If`CNinT4kOSj1>3^l@CCi>P3a]KL1;_=e0BS^lD4RjZf17FHYPAkVjP4
PZ2Z0hZU[PBAZ;04UZbb19^^]0BP/KH4X[>g1::a]@>O[K44W:V/19ZUZ0BKXZ@4X:FU1:JYZ0>^[jd4
][Fb1;bg/`Bo]k84_k:/1;f]Y@BiYYd3^J>H1;NNT`B[U8X4YHf219n6N`BEOG83U7Q]19AdI`BCLF<4
TVeN191ZFPB>IUD4NEE70f93=PA?<bL4BbHK14h^90AB=Rd4Echf0ee7@0ASD4X4JEUD171SGPAgK6T4
OWIc18EoOAGoool001Coool4UIBC19jNWPBXZZX4/[Fe1;c1`@?6cLh4dMWK1=kWj@C]n?X4h>ka1=?T
j0?6e]`4^lgD1:>ka@B;Z[H4MIRV17^KZ0B2X:X3RZF^196X/0BF[;84Vjjd1:2a]PBR/kL4X[6e0in]
/@BLZJ`4VZFX19^RY0BPYJD4YZVX0jj_[@Bf]K84_;Nc1;ng/PBo/Z`4_JfU1;VVW@>iXiP4]ijC1:^D
RPBUSH84WhIk19EmLP>DN6d4U7AW19=aH`BBKEh4T6YJ18iVE@AiEDL3HT<f14lc9`A;9Q/4CRhT158f
;@AG?SH3GDM016=@BPAYFE@4L6=N17M/J@AnMW<4QGmm5Oooo`005?ooo`BFU9<4X9nO1:Z[Z`Bd]kL4
_l?30l[@d0CFgMh4hn_]1?;ko@CUl?<4enCX0lOFg0BfbM04W[S218NV/PAcUZ@4N9RT17nLYP>6X:T4
SJF]19>Y[`BHZk04WJfa19b]/PBN[K43W:Z^19^XZ`BJYJL4Vj:T1:6VYPBXZjX3[k6^1;Jd/@Bl][84
_kNa1<6d[@Bo[ZH4^ZJM0kNRV0BcW984[IF;1:R?Q0BRQg`4Vh1d0iUkK`BHMfT4Ug=U19I`H0BFKE`4
T6MF17MDA@=K@3@4Cc<X14HT6@A8:R44C38Y158k<`=HA3d4Gdi816IGDPA^HEd4MF]X17aeLPB4OgdE
oooo000Doooo19JDT`BPWil4ZZ^[1;Bg]`Bo`l<3b]3@1=KMgPCSjnd4l__m1>G`l`CGi>P3amKL1;K9
d0BN^<84QjJb17>FY0AhV:@4OibV0hJPZ@B=YJd4TjV_19R[/0BM[K44W:fb19j]/@>LZZh4VjR[19ZU
Y`BKXZ@4XJJV1:R[ZP>_/Jh4][Ba1;bf/PBo]k44`KB]1;n^YPBjYYd3]j:H1;>LTPB]UH/4Z8n41::7
O0BKP7@3VG]_19QgJ@BGLfD4UW1P19I]G0B@IeH4MeA50e]0=0A?<bP4AR@I14PZ8@A<<RT4DS/c0eQ4
?@AOCTP4IUMB16iQG@AeJfP4O7Eb18AoOAGoool001Coool4UYBC1:2OW`BZZj/4];Ng1;o3``?:d=04
e]gN1>?[k@Cbnod4iO3c1=OTj0?7e]`4]/W@19jh`PB7Y[84LiJT17RHY0AoW:H3QZ2Y18fU[@BCZJl4
V:^`19f]/@BL[K84WZfa0ibZ[PBKZ:/4VZFW19^RY0BQYZH4Z:^Z0jna[PBf];44_;Jb1;ng/@C1]:d4
_jjV1;ZVW@>gXYP4/ibB1:fER`BXSh@4XXMl19^0M0>INfl4V7MY19McI@BFL604UVeL191WEPAgE4D3
Fd0d14lc:0A691T4B2XQ14`b:@AB>c<3F4@m15m>B0AVEe84KV5M17E[J0AlMG84Q7mm5Oooo`005?oo
o`BFU9<4X9nO1:Z[Z`Bd]kL4_l?30l[@d0CFgMh4hn_]1?;ko@CUl?<4enCX0lOFg0BfbM04W[S218NV
/PAcUZ@4N9RT17nLYP>6X:T4SJF]19>Y[`BHZk04WJfa19b]/PBN[K43W:Z^19^XZ`BJYJL4Vj:T1:6V
YPBXZjX3[k6^1;Jd/@Bl][84_kNa1<6d[@Bo[ZH4^ZJM0kNRV0BcW984[IF;1:R?Q0BRQg`4Vh1d0iUk
K`BHMfT4Ug=U19I`H0BFKE`4T6MF17MDA@=K@3@4Cc<X14HT6@A8:R44C38Y158k<`=HA3d4Gdi816IG
DPA^HEd4MF]X17aeLPB4OgdEoooo000Doooo19JEU0BQX:04Zjb/1;Jh^0C2aLD3cM;B1=[Oh0CWk^l4
m_gn1>[bm0CIi>P3amKL1;C8c`BL]/04QJB`17:FY0AdUJ44NiRS0h:LY@B9X:P4SjB[19FW[0BHZ:d4
V:V]19^Y[P>KZ:`4W:R[19bVZ@BOYZP4Y:VY1:Z^[@>`/Jl4][>`1;^e/0Bn]Jl4`KB]1<6`Y`BmZ9l3
^J>I1;:LT@B^UHX4ZY251:J:OPBQQ7L3WWma19ajJ`BJMVH4VW=S19]`G`B@IUD4M5940ePo=0A@=2T4
ARHK13hS6`A5;BD4C3L`0e=1>`AKBdH4HeEA16]PG0AcJVL4NgAb18=oOAGoool001Coool4UYFD1:6P
X0B[[:`4][Rh1<;5a@?=d]84f]oP1>O^k`CfoOh4j_;d1=WTj0?7e]`4]<S?19bf`0B5Y;04LYJT17BE
X@AkV:<3PYbU18VPZ0B?Y:/4UJN/19RX[@BHZJd4VjV^0i^X[0BLZ:/4W:JY19nVZ0BTZJT4ZZj]0k2a
[`Bf/k04^kF`1;je[`C1]:d4`K2W1;fXW`>iXiT4/YbA1:jERPBZT8D4YXYn1:64M`>NOg44W7Y[19Yf
IPBJLf<4Vg1O191VE@AdDT@3F3ld150d:@A69Q/4?R<K14D]9@A<=c03Dd4k15];APASEE44Jf1L17=Z
I`AkM784Pgmm5Oooo`005?ooo`BFUI@4XJ2P1:^/[0Bf^;P4`/G50lgBdPCJgn04ink_1?KmoPCZl_@4
fNCX0lOFg0Bdb<l4W;K018FT/0AbUZ@4M9FQ17^HX`>2W:D4RJ2X18nTZ`BEYj`4V:R]19RY[@BKZJh3
VjR/19bXZ`BLYZT4WjJX1:BYZ@BZ[Zd3/;6_1;Jc/0Bk]K04_[F_1<6d[@C1/:L4_JRO0kVSV@BbW944
[YF:1:Z@Q@BVRWh4XHAg0iioL@BLNV/4VWIV19YcH`BKL5l4T6IE17ABA0=H?c@4D3@Y14HV6`@n8a/4
ABdU14`g<0=C@C/4Fd]616=ED@A[H5`4LfYW17]dLPB3OgdEoooo000Doooo19JEU0BQX:04Zjb/1;Jh
^0C2aLD3cM;B1=[Oh0CWk^l4m_gn1>[bm0CIi>P3amKL1;C8c`BL]/04QJB`17:FY0AdUJ44NiRS0h:L
Y@B9X:P4SjB[19FW[0BHZ:d4V:V]19^Y[P>KZ:`4W:R[19bVZ@BOYZP4Y:VY1:Z^[@>`/Jl4][>`1;^e
/0Bn]Jl4`KB]1<6`Y`BmZ9l3^J>I1;:LT@B^UHX4ZY251:J:OPBQQ7L3WWma19ajJ`BJMVH4VW=S19]`
G`B@IUD4M5940ePo=0A@=2T4ARHK13hS6`A5;BD4C3L`0e=1>`AKBdH4HeEA16]PG0AcJVL4NgAb18=o
OAGoool001Coool4UYFD1:6QX0B][Jd4^;Vi1<C6aP?@dm@4gN7Q1>[_l0Cho_l4k??e1=_Uj@?8em`4
]<O>19^e_`B5Y;04LiJT17:BW`AhUIl3OiVQ18JLX`B<X:H4TJ>X19BUZ@BGYZ/4VJR/0i^X[0BMZJ`4
WjV/1:>[[0BV[:`4[;2^0k6b/0Be/k04^KB^1;fc[@C0/ZX4`[2W1;nZX@>lYI/4]IfC1;6GS0B/THD4
ZH]o1:B6N@>QPG<4WW]/19ehJ0BOMFD4X7=Q18eTD`AcDD<3G44f14dc:@A29A/4<a/D13dW80A5<R`3
CSdh15M8@`APDdl4JEiJ175YIPAjM744Pgil5Oooo`005?ooo`BFUI@4XJ6P1:f][@Bh^KT4a<K60m3C
e0CMhN44j^o`1?Sno`C/loD4fnGY0lSGg0Bdalh4VkFo18FT/0AcUZ@4LY:O17REW`=oVJ44QYbS18bP
YPBAXjP4U:FY19NVZ`BIZ:`3VjR/19fY[0BOZJ`4Xj^/1:J/[0B//:h3/K:`1;Fc/0Bi]:h4_K>]1<2b
ZPC2/:L4_jZQ0kbUV`BeWI<4/IN<1:bAQ@BYRgl4Y8Ii0j61L`BNNf`4WGQX19meI@BPLf44SFAC17=A
@`=L@CH4CC<Y148U6`@c6a@4?BLP14Db;0=>?CP4EdQ3161CC`AYGUX4LFUV17YdL@B3OW`Eoooo000D
oooo19JEU0BQXJ04[Jf]1;Ri^@C4a/H3d=?D1=gQh@CZko04n?ko1>ccm@CKiNT3b=OL1;C7cPBK]Kl4
QJB`17>FY0AbTYl4N9FO0gnIX@B6W:<4S:2V196SZ0BDYJT4UjJ[19VX[0>KZ:`4WJV/19nY[0BSZj`4
YZb/1:b`[P>a/[04]K>`1;Vd[PBm/jd4`;:Z1<:`Y`BoZZ43_:FK1;FMT`BaUh`4[9651:V;O`BTQWT3
XH5c19ikK0BMN6P4WgEU1:1cH@B=I5<4Le530ea1=PA=<bT4@RDK13<K50@m9b04AC8/0dhm>0AGB4<4
H5=?16UNFPAaJFH4NWAa18=nO1Goool001Coool4UYFD1:6QX0B][Jd4^;Vi1<C6aP?@dm@4gN7Q1>[_
l0Cho_l4k??e1=_Uj@?8em`4]<O>19^e_`B5Y;04LiJT17:BW`AhUIl3OiVQ18JLX`B<X:H4TJ>X19BU
Z@BGYZ/4VJR/0i^X[0BMZJ`4WjV/1:>[[0BV[:`4[;2^0k6b/0Be/k04^KB^1;fc[@C0/ZX4`[2W1;nZ
X@>lYI/4]IfC1;6GS0B/THD4ZH]o1:B6N@>QPG<4WW]/19ehJ0BOMFD4X7=Q18eTD`AcDD<3G44f14dc
:@A29A/4<a/D13dW80A5<R`3CSdh15M8@`APDdl4JEiJ175YIPAjM744Pgil5Oooo`005?ooo`BGUI@4
XZ6Q1:j^[@Bi^[X4aLO70m;Ee@COh^84k?3`1?[no`C]loD4g^OZ0lWHg0Beb<h4WKJo18NU/@AeUj@4
LY6N17JBW@=lUYh4PiVP18VLXPB>Wj@4TZ:W19JUZ@BIYj/3W:R/19jZ[PBQZjh4YJf^1:V_[`B]/K03
/[>`1;Fc[`Bh/jd4^k:[1;jaZ0C0[ZD4_jZQ0kjVW0BiX9D4/iV=1:jBQPBZS7l4YHMi0jB2L`BQOFd4
XWYZ1:=gIPBQLf44Rf9B17=A@`=M@CH4BC0W13XQ6@@[5a04=B8L13l^:@=9>SD4DdI115eAC@AVG5T4
L6QU17UcL0B2OW`Eoooo000Doooo19NEU0BRXJ44[Zj]1;Vj^PC5alL3d]GE1=oRhPC/l?04n_ko1>gc
m@CNinX3bMSL1;G8cPBM][l4QjFa17FGY0AbTIh4MY:M0gbFWPB3VJ04RIbR18jOY0BBXZL4UZFY19VW
Z`>LZ:`4WZZ^1:6[[PBU[Jh4ZJn_1:fa/0>b/k04]K>_1;Rc[@Bk/Z/4_[6X1<2^Y@BoZZ43_ZJL1;VP
U@BcVHd4[Y:61:Z<O`BUQgT3Y89c1:5mK@BRNVX4XgMV1:5cH@B;HU84Le530ee1=PA9<2L4>R4I12/G
40@e8Q`4?bhY0dTj=@ACAT44GE5=16ILF@A`J6D4NG=`189nO1Goool001Coool4UiFD1::QX@B^[Zd4
^KZj1<G7a`?BeMD4gn;R1>c`l0Cjo_l4kO?e1=kWjP?9f=`4]LS>19ff_`B7YK44MINT17:AWPAfTYd3
O9JN18>IX0B9W:84SYnT19:RY`BFYJT4VJN[0ibX[0BNZZh4XJ^^1:F][PBY[jl4[K6`0k:c/0Be/jl4
^;>]1;^bZ`Bn/JP4`:jU1;nZX@>nYY`4^J2E1;>IS@B^TXH4ZXao1:F7N@>TPW<4XGe]1:9jJPBSMfH4
XG=Q18]RDPAcDD<3GD4f14T`9`@j8AT4:aL@13DR70@o;RT3BCXe15=6@@AMDDd4IUaI171XI@AiLg04
PWil5Oooo`005?ooo`BGUI@4XZ6Q1:j^[@Bi^[X4aLO70m;Ee@COh^84k?3`1?[no`C]loD4g^OZ0lWH
g0Beb<h4WKJo18NU/@AeUj@4LY6N17JBW@=lUYh4PiVP18VLXPB>Wj@4TZ:W19JUZ@BIYj/3W:R/19jZ
[PBQZjh4YJf^1:V_[`B]/K03/[>`1;Fc[`Bh/jd4^k:[1;jaZ0C0[ZD4_jZQ0kjVW0BiX9D4/iV=1:jB
QPBZS7l4YHMi0jB2L`BQOFd4XWYZ1:=gIPBQLf44Rf9B17=A@`=M@CH4BC0W13XQ6@@[5a04=B8L13l^
:@=9>SD4DdI115eAC@AVG5T4L6QU17UcL0B2OW`Eoooo000Doooo19NEU0BSXZ44[Zj]1;Zk^PC7b<P3
dmGE1>3Sh`C]lO44nooo1>kdm@CPj>X3c=WM1;O9c`BQ^<04S:Nc17ZIYPAaTId4Li2J0gZCW0B1UYd4
QiVO18bMXPBAX:D4UJ>W19VVZP>LZJ`4Wj^^1:>][`BV[k04Z[6a1:jb/@>b];44]K>^1;Rb[0Bj/JX4
_JnW1;j]Y0BnZZ03_JFK1;ZPU@BeVXh4/YF81:f>P@BYRGX3Z8Ae1:N1L0BWOF`4YWYX19mbH0B9H544
LDm20e`o=0A5;RH4<alH12DD3`@/71L4>2TU0d@f<PA?@cl4FTm<16AKF0A^If@4N79`189nO1Goool0
01Coool4UiFD1:>RX@B^[Zd4^[^j1<O8b0?CeMD4h>?S1>gal@Ckool4k_Ce1>3XjP?<fMd4]lW?1:6h
`0B<Yk<4NYVV176AW@AcT9X3NY>L186FW@B7VIl4S9fR196PY@BEXjL4VJJZ0ibY[0BOZjh4Xjf_1:J_
/0BZ/K44[[:a0k:d/@Be/jh4^;:/1;ZaZPBm[jL4_ZfT1;jZX0>mYI/4^Z2E1;FJSPBbUHP4[Hj11:V9
NP>XQ7D4Yh5`1:MmK0BVNVP4Wg9P18UPD@AaCd83G3ld14D^9P@c7aP49A@?12`L5`@h:BD3A3Hb14m3
?`AJCd`4I5]H16iWI0AhLW04PWil5Oooo`005?ooo`BGUI@4Xj:Q1:j^[@Bj^kX4alS80m?Ee@CPhn<4
kO7a1?_oo`C^m?D4h>SZ0lcIg@BgbLl4XKS018bW/`AjVJH4LI6M17>@VP=jTi`4PIJM18NIW`B<WJ84
TJ2U19FSY`BIYZX3W:V/19n[[PBS[Jl4YZn`1:Za/@B^/[43/[Ba1;Fc[PBh/Z`4^[6Z1;f_Y`Bn[J@4
_ZZP0kfUV`BjX9D4]IZ>1;:ER0B]SX44ZHUj0jR4M@BWPG04Yge/1:IjJ0BOLV04RF1A175?@P=L?c@4
ABhV13<O60@U50l4;1`G13PY9@=4=S84Cd<o15Y?C0ATFeP4KVMT17QbL0B2OW`Eoooo000Doooo19NE
U0BSXZ44[jn^1;^k^`C8b<P3e=KE1>7Sh`C_lO44o?oo1>ocm0CQj>X3cm_N1;_;d@BU^l84TJ^e17jL
Z0AcTYh4LHjH0gRAV@AoU9/4QIRM18^KX0B@Wj@4UJ>V19VVZ@>MZJ`4X:b_1:B^/0BX/;44[;:a1;2c
/P>c];04]K:^1;Ra[0Bj/:T4_:jV1;f/X`BmZIl3_:BJ1;ZPU0BgVhl4]9J91;:AP`B_S7d3[HMg1:b3
L`B[P6h4ZG]Y19]_G@B4GDh4KTe00eTm<`A2;BD4;AdG11lB3P@S5Q84<RDR0cld<0A;@Ch4Edi;169J
E`A]IV@4Mg9`185mO1Goool001Coool4UiFD1:>RX@B_[jh4^k^k1<S8b0?De]D4hN?S1>oal@Clool4
ko?d1>7XjP??fmh4^l_A1:Fk`PBAZkD4OYbX17>BWPAaSYP3N96I17nDV`B5V9d4Ri^P192OY0BEXjH4
VJJY0ifY[0BP[:l4Y:j`1:R`/@B//[44/;>b0k>d/0Be/Zh4^;6/1;Z`Z@Bl[ZH4_JbS1;fYW`>lY9X4
^Z2D1;NKS`BdUXT4/Y631:n<O@>]QgL4[8=c1:^0KPBYNfT4VfmM18AMCPA^CD03FCdc148]9@@]7AL4
7a8>12<F4P@b9B83?c@`14]1?PAGCT/4HUYG16eVI0AgLW04PGel5Oooo`005?ooo`BGUI@4Xj:Q1:n_
[PBk^k/4b<S80mCFe@CQhn<4ko7a1?coo`C_lo@4hNSZ0loKgPBkbm44YK_2196[]@AnW:P4Li:N176>
V0=hTIT4OiBK18FHW@B;Vj04T9nT19FSYPBIYZT3WJV/1:2/[`BT[[04Z;2a1:bb/@B`/k83/kB`1;Fb
[PBh/J`4^[2Y1;b^YPBm[:<4_JVO0kbTVPBjX9@4]i^?1;BFR@BbTH<4[ham0jf7M`B/Pg<4Zh1^1:Uk
J@BKKed4Q5e>16i=@0=I?C<4@RdU12dM5`@O4Ph48aHB138U8P<o=304Bd4n15M>B`ARFUL4KFIT17Mb
L0B1OG`Eoooo000Doooo19NEU0BSXZ44[jn^1;^k^`C8b<P3e=KE1>7Sh`C_lO44o?oo1>ocm0CQj>X3
cm_N1;_;d@BU^l84TJ^e17jLZ0AcTYh4LHjH0gRAV@AoU9/4QIRM18^KX0B@Wj@4UJ>V19VVZ@>MZJ`4
X:b_1:B^/0BX/;44[;:a1;2c/P>c];04]K:^1;Ra[0Bj/:T4_:jV1;f/X`BmZIl3_:BJ1;ZPU0BgVhl4
]9J91;:AP`B_S7d3[HMg1:b3L`B[P6h4ZG]Y19]_G@B4GDh4KTe00eTm<`A2;BD4;AdG11lB3P@S5Q84
<RDR0cld<0A;@Ch4Edi;169JE`A]IV@4Mg9`185mO1Goool001Coool4UiFD1:>RX@B_[jh4_;bk1<S9
b0?Ee]D4h^CS1?3al@Cmool4l??d1>;XjP?Ag=l4_lkC1:^na@BF[[L4PinZ17NEX0A`SIP3MXnH17jC
VPB4UY`4RYZO192NXPBEXZH4VJJY0ifZ[@BQ[:l4YJn`1:Va/PB]/k84/;Bb0k>d/0Be/Zh4^;6[1;Z_
Z0Bk[JD4_J^R1;fXWP>lY9T4^YnD1;VLS`BgUhT4]I:41;>>O`>`RGT4/8Ed1:j1K`BXNVL4UF]J181J
C0AYBSh3DcX`13`Y8P@W6QD46@l<11`A3P@]8Ql3>c8_14To?@AECDX4H5UG16]UH`AfLFl4PGek5Ooo
o`005?ooo`BGUI@4Xj:Q1:n_[PBl_;/4b<W80mGFe@CRi><4l?7a1?goo`C`lo@4h^SZ0m7Lg`Boc]<4
Zkk519J^]`B3WjX4MiFP172=V0=fSiP4OY>J18BFW0B:VYl4T9jR19FRYPBIYZT3WJZ]1:6/[`BU[k04
ZK6b1:fc/PB`];83/kB`1;Fb[PBh/J/4^ZnX1;^]Y@BmZj84_JRN0kbTV@BjWi@4^Ib?1;NGR@BeTX@4
/hio0k29N@B`QG@4[X5_1:QjI`BEJeX4P5Y<16U:?P=C>S04?2TR12LJ5@@I3``4714>12dR7`<k<Rl4
BClm15E=BPAPFEL4JfES17IaK`B1OG/Eoooo000Doooo19NEU0BSXZ44[jn^1;bl^`C8bLP3eMKE1>;T
h`C`lO44oOoo1?3cm0CRj>X3dMcO1;o>d`B[_/D4UZjg18>OZPAgUJ04L8fH0gJ?V0AnTiX4Q9JL18ZJ
W`B@WZ84UJ:V19VVZ@>MZZd4XJb_1:F_/0BY/K84[K>b1;2d/P>c];04]K:^1;RaZ`Bj[jP4^jfU1;f[
XPBmZ9h3_:BI1;ZOU0BiW8l4]iN91;FBQ0BcSWl3/8Ui1;25M0B^PFl4Z7YW19E[FPB0FT`4JDXn0e<j
<0@l:B849aXE11T?30@L4@h4;B8O0c/b;`A9?cd4EDe:161IE`A[IF<4MW5_185mNaGoool001Coool4
UiFD1:>RX@B_[jh4_;bk1<S9b0?Ee]D4h^CS1?3al@Cmool4l??d1>;XjP?Ag=l4_lkC1:^na@BF[[L4
PinZ17NEX0A`SIP3MXnH17jCVPB4UY`4RYZO192NXPBEXZH4VJJY0ifZ[@BQ[:l4YJn`1:Va/PB]/k84
/;Bb0k>d/0Be/Zh4^;6[1;Z_Z0Bk[JD4_J^R1;fXWP>lY9T4^YnD1;VLS`BgUhT4]I:41;>>O`>`RGT4
/8Ed1:j1K`BXNVL4UF]J181JC0AYBSh3DcX`13`Y8P@W6QD46@l<11`A3P@]8Ql3>c8_14To?@AECDX4
H5UG16]UH`AfLFl4PGek5Oooo`005?ooo`BHUI@4Y::Q1;2_[@Bl^kX4bLW80mKFe@CSi><4l?7`1?ko
oPCam?@4h^SZ0mCMh0C3d=D4/L7819Za^PB8Xjd4NiRS17>@VP=fSYL4OI:I18BFW0B:VYh4T9jQ19FR
Y@BJYZT3WZZ/1:>][`BW/;44Z[:b1:jc/`Ba];83];B`1;Fb[@Bg/:X4^ZjW1;^]Y0BlZZ04_JNM0kbS
V0BkX9@4^Yb?1;VHRPBgU8D4]Hmo0kB;NPBcQgD4[X5_1:=fI0B?IUH4NUM91695>P=<=Bd4=BDN124F
4P@A2@H46Q4?12XR7`<i<Bh4Acll15=<BPAOFEL4JfES17IaK`B1OG/Eoooo000Doooo19REU0BTXZ44
/:n]1;bk^PC9bLP3e]KE1>?Th`C`lO04o_on1?7dm0CRj>X3e=gP1<?@e@Ba`LP4V[6j18RS[@AkV:<4
Li2J0gJ>U`AmTYT4Q9JL18ZJWPB@WZ44UJ:U19ZVZ@>NZZ`4Xjf_1:N`/@BZ/[84[[>c1;6d/P>d];04
]K:]1;N`ZPBj[ZL4^jfT1;bZX0BmYid3_:>H1;^PU0BjW8l4^IR:1;NDQ@BeSgl3]8]j1;>7M@B^PFl4
XgIT18mVEPAjEdT4HTDj0d`e;@@e9Ah48AHB11491P@J4@l4:R8O0cTa;PA7?c`4Dda:15mIE`A[IF<4
MW5_185mNaGoool001Coool4V9FD1:BRX@B`[jd4_;^j1<W9b0?Fe]D4hnCS1?3al0Cnooh4lOCd1>;X
jP?DgN04`m3E1;71b0BJ/KX4R:>]17^HX`AcT9X3MXjG17fBV@B4UY`4RYZN192NX@BEXZD4VZJY0ijZ
[0BS[Jl4Yk2a1:Zb/PB^/k<4/KBb0kBd/0Be/Zd4]k2Z1;Z^Y`Bk[J@4_:ZP1;fWW@>lXiP4^j2D1;ZL
S`BiV8X4]iB51;F?O`>dRgX4/hMe1:j1K`BSMV@4SfIF17YGB@ARACX3C3D]13DU7P@Q5Q844@T611XA
3`@Z8Ql3>C4^14Lo?0ACC4X4GeUG16]UH`AfLFl4PGek5Oooo`005?ooo`BHUI@4Y::Q1;2_[@Bl^kX4
bLW80mKFe@CSi><4l?7`1?kooPCam?@4h^SZ0mCMh0C3d=D4/L7819Za^PB8Xjd4NiRS17>@VP=fSYL4
OI:I18BFW0B:VYh4T9jQ19FRY@BJYZT3WZZ/1:>][`BW/;44Z[:b1:jc/`Ba];83];B`1;Fb[@Bg/:X4
^ZjW1;^]Y0BlZZ04_JNM0kbSV0BkX9@4^Yb?1;VHRPBgU8D4]Hmo0kB;NPBcQgD4[X5_1:=fI0B?IUH4
NUM91695>P=<=Bd4=BDN124F4P@A2@H46Q4?12XR7`<i<Bh4Acll15=<BPAOFEL4JfES17IaK`B1OG/E
oooo000Doooo19REU0BTXZ04/:j]1;bk^PC9b<L3e]KD1>?ShPCalO04ooom1?7dm0CSjNX3e]kQ1<SC
e`Bea<X4X;Fl18nW/0AoVjD4N9>M0gR?V0AnTYT4QIJK18^JWPBAWZ84UZ:U19^VZ@>PZZ`4Y:j`1:R`
/@B//k<4[kBc1;:e/P>d/jl4]K6/1;N_Z@Bi[JH4^Z^S1;bXW`BlYY`3_:>H1;^OT`BkVhh4^YR:1;VD
Q@BgT803]Xak1;:6M0B[OV`4W75P18UQD`AaDD@4Fd4f0d@`:@@^81/46Q4>10/40`@K4a84:R8P0cPa
;`A5?cd4DTa:15iIE`AZIF<4MG5_185mO1Goool001Coool4V9FD1:BRX0B`[Zd4_;^j1<W8a`?Fe]@4
hn?R1?7al0Coood4lOCd1>?YjP?Fg^44b=?G1;G4bPBP]K`4SjN`17nKY@AhTid3N8nH17jBV@B5UY/4
RiZN196NXPBFXZD4VjJY0j2Z[0BT[[04Z;2a1:bc/`B_];<4/[Fb0kBc[`Be/J`4]jnY1;V]YPBjZj<4
_:RO1;bVW0>lXiP4^inC1;^KSPBjV8X4^IB51;N@P0>fS7/4/XId1:]nK0BLLF04RF5C175AA0AK@CH3
A30Y12hP6`@J4@h42`@311/C4P@Z8R03>34_14Do?@ABC4X4GUUG16YUH`AeLFl4PGel5Oooo`005?oo
o`BHUI@4Y::P1;2^[@Bl^kX4bLS70mKFe0CShn84lO7`1?ooo@Cam?@4hnWZ0mKNh@C8dmL4]LC:1:2e
_0B?Yk04Oi^U17RCW@=hSiP4OY:I18FFV`B;VYh4TIjR19JRY@BKYZT3X:Z/1:B^/0BX/;44[;>c1:nd
/`Bb]K83];>_1;Fa[0Bg[jT4^JfV1;Z[X`BlZ9l4_:JL0kbSV0BkWi<4^i^>1;ZHRPBiU8D4]i200kJ<
N`BbQW@4Zgi/19aaH0B9HE<4LE5415]1=P=4<2T4;R0K11XA3P@;10<46a<B12XR80<h<Bl4AClm159<
BPANFEL4JVES17EaK`B1OG`Eoooo000Doooo19REU0BTXZ04/:j]1;bk^PC9b<L3e]KD1>?ShPCalO04
ooom1?7dm0CSjNX3e]kQ1<SCe`Bea<X4X;Fl18nW/0AoVjD4N9>M0gR?V0AnTYT4QIJK18^JWPBAWZ84
UZ:U19^VZ@>PZZ`4Y:j`1:R`/@B//k<4[kBc1;:e/P>d/jl4]K6/1;N_Z@Bi[JH4^Z^S1;bXW`BlYY`3
_:>H1;^OT`BkVhh4^YR:1;VDQ@BgT803]Xak1;:6M0B[OV`4W75P18UQD`AaDD@4Fd4f0d@`:@@^81/4
6Q4>10/40`@K4a84:R8P0cPa;`A5?cd4DTa:15iIE`AZIF<4MG5_185mO1Goool001Coool4UiFD1:>Q
X0B`[Zd4_;^i1<W8aP?FeM<4hn?Q1?7`k`Coood4lOCc1>GYjP?Hgn44bmGH1;W7c0BW^L04UZbd18JO
Z@AoV:43Ni:K17nBVPB6Ui`4S9^O19:OXPBHXjD4WJNY0j6[[@BU[k04Z[6b1:fc/`B`];84/[Ba0kBc
[`Bf/:/4]jjX1;R/Y@BiZZ84^jNN1;^UVP>kXYL4^ijB1;^KSPBjUhT4^YB51;V@P0>fRgX4/8Ab1:Ij
J@BDJe`4P5a>16U;@0AC>c83?B/U12HJ5P@B30X42@<311XE4`@Z8b83>38`14Do?PABC4/4GUUG16YU
I0AeLG04P7el5Oooo`005?ooo`BGUI@4Xj6P1;2^[@Bl^kT4bLS60mKEd`CShn44lO3_1?ooo@Cam?<4
iNWZ0mSOh@C;eMP4^LO<1:Ni`0BF[;@4QYnY17nHX@=kTY/4Oi:J18JGW0B<Vil4TYnR19RSY@BMYjT3
XJ^]1:F_/0BZ/K84[K>c1;2d/PBb];43];>_1;J`Z`Bg[ZP4^:bU1;VZXPBkYih4^jFJ0k^RU`BkWY84
^i^>1;ZGR@BjU8D4^I200kJ;NPB`Q784YWYY19A[G0B0G4h4JD]015<k<P<m:bD49QXF118<2P@90`<4
6QDC12XS8P<h<S04ACln159<B`ANFEL4JVET17EaL0B0OG`Eoooo000Doooo19NEU0BSXJ04/:j]1;bk
^@C9b<H3e]GC1>?Sh@Cal>l4ooom1?7dl`CUjNX3f=oQ1<_Ef0Bial`4YkW019J/]0B6WjT4OiRQ0g^B
V`AoTYX4QYNL18bKW`BBWj84V:>U19fWZ@>QZjd4YJn`1:Za/PB]/k<4/;Bb1;:d/@>d/jl4][2[1;N^
Z0Bh[:D4^JZR1;^WWPBkYIX3^j:G1;^NTPBkVhh4^YN91;ZDQ@BiT803]X]j1;24LPBVNVT4U6]L181L
CPAYBd04Dc/b0cd[9@@V6QH44P`:10T30`@J5A<4:R<R0cPb<0A5?ch4DTa;15iIE`AZIF@4MG5`181m
O1Goool001Coool4UiFD1:>QX0B_[J`4^kZh1<S7a@?Ee=84h^7O1?3_k@Coo_`4loCd1>OZjP?Kh>44
c]KI1;o;c`B]_L<4W[6g18nU[@B7WZL3OiJN186DV`B7V9d4SYbP19BPX`BIY:L4WZRZ0j>/[@BW[jl4
Zk6a1:jd/PBa];84/kB`0kBb[@Be[jT4]ZfV1;N[X`BhZJ04^ZJM1;ZTV@>kXID4^ifA1;^KS@BkUhT4
^i>41;V@O`>dRWP4Zh1_19edI0B:IEH4MEE91616>`A:=Rh3<bDP11/D4@@810<430L711`G5P@Z9B@3
>3<b14E0?`ABCD`4GUYH16YVI0AeLW04P7el5Oooo`005?ooo`BGUI@4Xj6P1:n][0Bk^[P4b<O50mGD
dPCRhMl4l>o]1?ono0Ccm?@4in[Z0m_Ph@C>e]T4_l_?1:fm``BN/KL4SjF]18NNY`=oUYh4PIBK18NH
W@B>W:04U:2S19VTY`BNZ:X3Xjb]1:N_[`B[/K44[[Bb1;6d/PBc];03];:]1;F_Z@Bf[JH4]j^S1;RY
X0BjYYd4^ZBI0k^QU@BkWI44^i^=1;^GR@BkTh@4^I1o0kB:N0B[P6l4WGAT18YUEPAeEDT4H4Hk14Xf
;P<c9B046a@A10P40`@<1`L471LF12XU90<h<c84AD0o159=C0ANFUP4JVIT17EbL0B0OG`Eoooo000D
oooo19NEU0BSXJ04[jf/1;^j^0C8alD3eMCB1>;Qg`C`knd4ookl1??dm0CWj^X3fn3Q1<kFf@Bobll4
[Kg319ja]`B?YJd4QijW0gnFWPB1U9/4QiRM18jLX0BDX:<4VJBW19jXZP>S[:d4Yjn_1:^a/@B^];84
/KBb1;>d/0>d/Zd4]JnY1;J]YPBgZj<4^:VP1;ZVW@BjY9T3^j6E1;^MT@BkVhd4^iN91;^CQ0BiT7l3
]8Yh1:^0K`BMM6@4RVEF17EEB@APAS/4BSH^0c<U80@K514420@310`71`@L5aH4:RDT0cPc<PA5@3l4
DTe<15iJF0AZIV@4MG9`181mO1Goool001Coool4UiFD1:>QX0B_[J`4^kZh1<S7a@?Ee=84h^7O1?3_
k@Coo_`4loCd1>OZjP?Kh>44c]KI1;o;c`B]_L<4W[6g18nU[@B7WZL3OiJN186DV`B7V9d4SYbP19BP
X`BIY:L4WZRZ0j>/[@BW[jl4Zk6a1:jd/PBa];84/kB`0kBb[@Be[jT4]ZfV1;N[X`BhZJ04^ZJM1;ZT
V@>kXID4^ifA1;^KS@BkUhT4^i>41;V@O`>dRWP4Zh1_19edI0B:IEH4MEE91616>`A:=Rh3<bDP11/D
4@@810<430L711`G5P@Z9B@3>3<b14E0?`ABCD`4GUYH16YVI0AeLW04P7el5Oooo`005?ooo`BGUI<4
Xj6O1:n]Z`Bk^KL4alG30mCBd0CQgmd4kng[1?glnPCfmO@4jN_Z0mgRhPCBfM/4a<k@1;G1aPBV]K/4
VJbb18nTZ`>6Vj<4QINN18ZJW`B@WZ84UZ6T19bUZ0BQZJX3YJb]1:V_[`B//K44/;Bb1;:d/@Bd/jl3
];6/1;B]Z0BeZj@4]ZVQ1;NWW`BiY9/4^J:G0kZOT`BkW904^iZ<1;^FQ`BjTX<4]him0k26M@BTNVX4
U6eN17mND@AZCT<4Eclf144`:@<Y7Q/44`h=10<000@@3@`47QXI12`X9`<i=C@4AT9115=>C@AOFeT4
JVIU17EbL@B1OG`Eoooo000Doooo19NET`BSXIl4[jf[1;^i]`C7aL<3e=;@1>7Og@C_kN/4oOcj1?Ke
m0CYjnX3gN;R1=;If`C4c]04]L761:Je^`BI[;84SjB[0hJKX`B5Uih4RYZO192NXPBFXJ@4W:FX1:6Y
ZP>U[:d4ZJn_1:ba/@B`];84/[Ba1;Bc[`>d/J`4]:fX1;F[Y0BfZJ44]jNO1;VTV`BiXYL3^YnC1;^L
T0BkVX`4^iJ71;ZBP`BgSWd3/8Ie1:AjJPBDKEh4OeiA16Y>@`AG?cH4@C0Y0bTN6`@C3Pd40`00110=
30@N6QT4;2PW0cTe=0A6@T44Ddi=15mKF@AZIVD4MG9a185mO1Goool001Coool4UiFC1:>QW`B_[J/4
^kVg1<O5``?Dd]04hMoM1>o]j`Cmo?X4m_Gd1>W[jP?Mh^84d]WK1<C>d0Be`LH4Y[Fk19V//PB?Y:/3
QY^S18FGWPB:VYl4T9jR19JQY0BLYJP4XJVZ0jF/[@BY[jl4[;6a1;2d/PBb];44];>_0kBa[0Bd[JP4
]J^T1;JYX@BgYil4^JBK1;VRU`>jWi<4^ib@1;^JS0BkUXL4^Y:31;N>O@>`QWD4Y7YZ19A]GPAoGU44
JTi315Lo=PA1<2T3:AhK11<>3@@3000440d<11hJ6@@/:2L3>CDd14I2@@ACCTd4Ge]I16YVI@AeLW44
PGel5Oooo`005?ooo`BGUI<4Xj6O1:n]Z`Bk^KL4alG30mCBd0CQgmd4kng[1?glnPCfmO@4jN_Z0mgR
hPCBfM/4a<k@1;G1aPBV]K/4VJbb18nTZ`>6Vj<4QINN18ZJW`B@WZ84UZ6T19bUZ0BQZJX3YJb]1:V_
[`B//K44/;Bb1;:d/@Bd/jl3];6/1;B]Z0BeZj@4]ZVQ1;NWW`BiY9/4^J:G0kZOT`BkW904^iZ<1;^F
Q`BjTX<4]him0k26M@BTNVX4U6eN17mND@AZCT<4Eclf144`:@<Y7Q/44`h=10<000@@3@`47QXI12`X
9`<i=C@4AT9115=>C@AOFeT4JVIU17EbL@B1OG`Eoooo000Doooo19NDT`BRX9h4[Z^Z1;Vg]PC5`l83
d]3>1=oMf`C]j^P4noWg1?Oel`C/k>/3hNCT1=KKg0C:dM<4^lG91:fj_PBR/KH4V:V`0hnRZ0B;W:<4
SYfR19>PY0BHXjH4WZNX1:>ZZ`>X[Jd4Zk2_1:jb/0Bb];84];Ba1;Ba[@>c[jX4/jbV1;>YXPBdYil4
]ZFL1;NSV@BhX9D3^IfB1;VJSPBjV8X4^IB61;N@P0BcRWX3ZH1`19YcI0B8IUP4M5M;1617?PA<>C44
=RTT0ahH5@@=2PX40P00118?3`@P7Ad4;R/Z0c/g=`A8A4<4E51?15mLF`A[IfH4MW=a185nO1Goool0
01Coool4UiBC1::PWPB^ZjX4^KNf1<G3`P?Bd<h4gmgK1>gZj0CknOL4moGc1>c/j`?Qi>@4e]_L1<[A
d`BkaLT4[KZn1::a]PBHZK03Sj:X18^LX`B>WJ84Tj2T19RSYPBNYjP4XjZ[0jR][@B[/:l4[[:`1;:d
/PBd];44];6]0k>_ZPBc[:H4/jVR1;BWW`BfYI`4]j>I1;RPU@>iWI84^IZ>1;ZHRPBiU8H4]i201;>:
NP>YP704VW=T18QVF0AdEd/4H4Ln14`i<@@f:B@37QPE10d:2P@200044Pl?120M7@@^:bX3>cLg14Q4
@`ADD4l4GeaK16]WIPAfLg44PGil5Oooo`005?ooo`BGU9<4XZ2N1:j[ZPBi]kH4aL?20m;@cPCOgM/4
kN[X1?_im`CgmO<4k>c[0n7Ti0CFfm`4b]7C1;_5b@B]^[h4X[6f19RY/0>?XZP4RibS18jMXPBCX:@4
V:>V19jWZ0BSZZ/3Z:f]1:^`[`B^/[04/[Bb1;Bd/@Bd/Jd3/jnZ1;>/YPBcZJ84]:NO1;JUW0BgXiT4
^:2E0kVMTPBiVXh4^YR:1;VDQPBgT804/hYj0jV0L0BJLf@4R6IH17AGB`APAch4C3Ta13HY90<N61D4
3@X:108000@B3`l481dM12h[:P<k=cL4B4A315A@C`AOG5/4JfMV17IcL@B1OW`Eoooo000Doooo19ND
T`BRX9h4[Z^Z1;Vg]PC5`l83d]3>1=oMf`C]j^P4noWg1?Oel`C/k>/3hNCT1=KKg0C:dM<4^lG91:fj
_PBR/KH4V:V`0hnRZ0B;W:<4SYfR19>PY0BHXjH4WZNX1:>ZZ`>X[Jd4Zk2_1:jb/0Bb];84];Ba1;Ba
[@>c[jX4/jbV1;>YXPBdYil4]ZFL1;NSV@BhX9D3^IfB1;VJSPBjV8X4^IB61;N@P0BcRWX3ZH1`19Yc
I0B8IUP4M5M;1617?PA<>C44=RTT0ahH5@@=2PX40P00118?3`@P7Ad4;R/Z0c/g=`A8A4<4E51?15mL
F`A[IfH4MW=a185nO1Goool001Coool4UiBB1::OW@B]ZZT4^;Jd1<C1_`?@cL/4g=[G1>WWi0Cgm?84
nOKd1>o^k0?Ui^D4fMcM1<oDe@C2bL/4];k11:Zf^PBQ[k@3VZV^19BSZ0BDXjL4Uj>W19bUY`BRZJX4
YZ^[0jZ^[@B]/:l4/;:_1;Bd/@Bf];04/k2/0k:]Z0BaZJ<4/ZNP1;:UW@BdXYX4]J2G1;JNT`>fVhl4
]iR;1;NEQ`BfTX<4/Ham1:b4M@>ONFX4SfaN17eNDPAYD4D4ED4i144a;0@Z8Ah35A4A10D410@610D4
5A<C12@Q8@@a;Rd3?CXj14Y6A@AEDU44HEeL16aXI`AfLg84PGim5Oooo`005?ooo`BGU984XYnM1:fZ
Z@Bh][@4a<6o0m3=b`CLf]L4jNOT1?OdlPCim_@4knk/0nGVi@CIg=d4cmCE1<;9b`Bd_/44Z[Jj1:6_
]0>JZJh4U:>X19BSY`BGXjL4W:FW1::YZPBVZj/3ZZj]1:f`[`B`/Zl4];Ba1;Jd/0Bc/:`3/ZfX1;6Y
X`BbYj04/ZFM1;BRVPBeX9L4]YjC0kJKS`BgV8/4]iF71;JBP`BaS7d4[8Ae0imiJPB?K5h4OEiB16U@
A@AE@CT4@C4/12XQ7P<E4A441@@410H41@@E4a<4924Q134^;@<m>SX4BTI515EBD@AQGE`4K6QW17Ic
LPB1OWdEoooo000Doooo19NDTPBRWid4[JZY1;Rf]0C4`Kl3d<g;1=cJe`CYin@4moCb1?Wfm0C_k^`3
iNKU1=WLg@C?e=D4`/W;1;Bn`@BZ][X4XJnd0iZY[PBDXjP4U:>W19NSY`BLYJL4XZVZ1:J[Z`>Z[Zd4
[K2_1;2b[`Bd];44][B`1;>`[0>b[JP4/JVS1;:WX0BbYId4]::J1;FPU`BfWY<3]Y^?1;NHR`BgUHL4
]Y:31;6<O@B/Q7D3WgUZ18m/GPAmGU84JE1515E1>@A1<B`4:R4N0aDA4@@510@41P@511DC4`@T8B44
<Bh]0cdj>PA:ATD4EE9A165MG0A/J6L4MW=b185nOAGoool001Coool4UiBB1::OW@B]ZZT4^;Jd1<C1
_`?@cL/4g=[G1>WWi0Cgm?84nOKd1>o^k0?Ui^D4fMcM1<oDe@C2bL/4];k11:Zf^PBQ[k@3VZV^19BS
Z0BDXjL4Uj>W19bUY`BRZJX4YZ^[0jZ^[@B]/:l4/;:_1;Bd/@Bf];04/k2/0k:]Z0BaZJ<4/ZNP1;:U
W@BdXYX4]J2G1;JNT`>fVhl4]iR;1;NEQ`BfTX<4/Ham1:b4M@>ONFX4SfaN17eNDPAYD4D4ED4i144a
;0@Z8Ah35A4A10D410@610D45A<C12@Q8@@a;Rd3?CXj14Y6A@AEDU44HEeL16aXI`AfLg84PGim5Ooo
o`005?ooo`BFTi84XIjL1:^YY`Bf];84`Knm0lg:b0CIe]<4iN;O1?7^j`Cjmo@4lo3^0nSWiPCMg]h4
e=OG1<S=cPBj`/@4/KZm1:Rc]`>T[k<4WZZ^19bXZ`BLZ:X4XJVZ1:N/Z`B[[Zd3[:n^1:n`[PBb/Jh4
][>_1;Jb[PBc[jX3/:ZV1:nWX@B_Y9h4/::K1;:PU`BbWYD4/Y^@0k>HS0BcUHP4/Y641;2=O`BZQWL4
XGa^0i=aI0B3I5P4LEM<15e8?`A:>C<4=BXV120K6@<>3@d4000110d<30@J6AT4:2DU13@b<@=0?Sd4
C4U815MDD`ARGeh4KFYX17MdL`B1OgdEoooo000Doooo19JCTPBQWY`4ZjVW1;Jd/PC1_kd3cL[81=WF
d`CUh]l4lNk[1?[gm0Ccl>h3j>OV1=gNgPCDemL4b<g>1;[2a0Ba^[d4Z;>g0jB_/`BNZZh4W:R[19bX
ZPBQZJX4Yjb[1:^^[@>/[jh4[k2^1;:a[PBf/jl4][:^1;>_ZP>`ZZH4[jNQ1:nTWPB`XY/4/Z2G1;:N
U@BbVi03/iR<1;>ER0BbTH@4/8eo1:Z6M`BQO6h3Tg5T18=TF0AaEd`4GDPo14Xi<`@e:RH481/I0`h=
3@@000443@`<11XI6@@X9BD4=38a0d0n?@A<BDP4EeAC169OGPA]JVP4MgAc185oOAGoool001Coool4
UY>B1:6NW0B[ZJL4][Bb1<6o_@?=b/P4fMKC1>GRg`Cak^/4n_Od1??`kP?XinH4gMkN1=CGe`C8cLh4
^/;41;6j_@BX/kL3Y:nc19jZ[PBLZ:/4W:RZ1:6YZPBW[:/4Zjj]0jb_[PB_/:h4/[6^1;Jc[`Bf/Zh4
/jnZ0k2ZYPB_Yj44[jBN1;2RV`BbX9L4/YjE1;:KT0>cV8`4/iF81;:AQ0B`SGl4ZXIg1:5lKP>CLF@4
PfAH175GC0AMB3l4BSTc13DZ9P@P6aT33Pd=10000@@=30`46QTI12PU9@@d<S43@3hm14a9B0AGE5<4
HUmN16eZJ0AgM7<4PGmm5Oooo`005?ooo`BFTi84XIjL1:^YY`Bf];84`Knm0lg:b0CIe]<4iN;O1?7^
j`Cjmo@4lo3^0nSWiPCMg]h4e=OG1<S=cPBj`/@4/KZm1:Rc]`>T[k<4WZZ^19bXZ`BLZ:X4XJVZ1:N/
Z`B[[Zd3[:n^1:n`[PBb/Jh4][>_1;Jb[PBc[jX3/:ZV1:nWX@B_Y9h4/::K1;:PU`BbWYD4/Y^@0k>H
S0BcUHP4/Y641;2=O`BZQWL4XGa^0i=aI0B3I5P4LEM<15e8?`A:>C<4=BXV120K6@<>3@d4000110d<
30@J6AT4:2DU13@b<@=0?Sd4C4U815MDD`ARGeh4KFYX17MdL`B1OgdEoooo000Doooo19JCT@BPWI/4
ZZNV1;Bb/0Bo_;X3b/O51=GBc`CPgMX4k>SU1?Sdl@Cfl^l3j^SW1>7Pg`CGf=P4cM3@1;o5a`Bf_Kl4
/;Rj0j^d]PBW/;84Y:f_1:F][PBX[Jh4[:n]1:j`[P>^/:d4/:n]1;:`[0Be/Jd4]:n[1;6/Z0>_Z:<4
[JFO1:bPV`B]WiP4[ifE1:jJT@B^Uhd3[I>81:f@Q0B[S804YhIj19mnL@BEM6P3QVQM17ILDPATCdH4
DD0i13da;@@Y8b0461DE0`L92@@30`D44Q8B120N7`@/:RX4>3Hf0dA1@@A?C4/4FEMF16AQH0A^JfX4
N7Ed189oOQGoool001Coool4UY>A1:2MV`BZYjH4];:`1;nl^P?:alD4eM;?1>3MfPC/j>D4n?Ca1?Kb
k`?Zj>L4hN3O1=OHf0C=d=04_lG71;Jm_`B`^;X3ZkBf1:N`/PBT[Jl4YJf^1:R][PB/[jd4[[2^0jj`
[@B`[jd4/[2/1;Fa[@Bd[j/4/JbX0jnXX`B]YIl4[:2K1:fOV0B_WID4[YZA1:jGS@>]ThP4[I241:^<
P0BWQWX4Wgia19EdJ0>6J5d4MUaB16A?APAA@3T4?C4]12TS80@H5AD31`T910<31@@B4Q8481hO12`Z
:P@h=SH3A45114m<B`AIEeH4I65P16i[JPAhMG@4PWmn5Oooo`005?ooo`BFTi44X9fK1:ZWYPBd/[04
_kbj0l[7a@CEd/l4h=gJ1>cXi@Chm?44m_;_0n[Xi`CQh=l4emSH1<g@d0BoaLL4][fo1;2h^P>[];H4
Yk2b1:B][`BU[Jh4Z:f^1:b_[@B^/:h3[[2]1;2_[@Bb/:`4]K6]1;B_Z`Ba[:P3[jRS1:fUW`B/X9/4
[InH1:nMU@B^VY44[YN=0jfCR0B]T8@4Zhb01:N6NPBOOW44UGAX0hIXG@AfG584I4m61550>@@m<Bd4
:B<P11PE5@<72@T40`<5118B4P@P7Ql4;2XZ13Pf=P=4@D44Cda;15UGEPATHF04KV]Z17QeM0B2OghE
oooo000Doooo19FBT@BOW9X4Z:JT1;:_[@Bl^KL3a/?11=7>b`CLf=D4in?P1?;^jPCglo03k^[X1>CR
h0CJf]T4d=;A1<C8b0Bl`L84]kbm0k>i^PB_]KH4[;>d1:ba/@B_/K08/K6_0k2`[@Bb[j`4/ZjZ1;B^
ZPBb[:P4/:ZU0jjUX@B[XY`4ZIjH1:VKU0BZVI44ZIJ=1:VCR@>VSX@4YHZ01:65NPBLOg<4TWI[18M/
HP=hH5L4JEA<15Q6@0A5>3<4<2TV120L6`@B414310H710`<3@@I6AX49RDU134`<0@m>cX3AdE5159?
C`ALFEP4IV=R16m]K0AiMWD4PX1n5Oooo`005?ooo`BETY44WibJ1:RVY0Bb[jd4_;Vg0lK3`@CAc//4
g=SE1>OSh0Cbk^X4mo?`0nkZj0CTh^04f][I1=3Bd@C4b<P4_<721;Nl_@>c^KX4[kFf1:bc]0B//K44
[k6`2;6a[`>`/:d4/Zn/1;:^ZPBd[ZX4/ZbX1;2ZY@>^YJ44Zj:L1:VNV0BYVi@4ZYVA1:VFS@BYThT3
YXj41:F:P0BQQGX4W7mc199fJ`B7K683N61G16UDC0AHAT04ACPc130Y9P@P71/44Q0A0`@61`@<30d4
6ATJ12HU9@@a<304?C/j0dM5A@ABCdl4G5UH16ISHPA_KF`4NGIe18:0OQGoool001Coool4UI:A19nL
VPBXYZ@4/Zn]1;bi]`?6`l44dLk;1=cHe@CWhn04l^kZ1?Ocl0?^j^P4i>;P1=[Jf@C@d]44a<S81;c1
`PBg_;d3/kVj1:ne]PB//k@4[;6a1:na/0Ra/Jl3/;2]1;:_[0Bb[ZX4]:jZ1;:/Z0B`ZZD3[ZFQ1:^R
W0BYWYP4ZI^D1:ZIT@BYUXd4ZI>90jJ>Q0BURX04XHEj19aoL`BBMV/4QfaR0gQPE`AYE4`4F4I014Dh
<`@`:BH481`K118@4@<41PL430`=11TI6P@V9BD4<C0`13dk>P=7ADD4DTm?15aIF0AVHf84Kfe/17Uf
M@B2P7hEoooo000Doooo19FBT@BOW9X4Z:JT1;:_[@Bl^KL3a/?11=7>b`CLf=D4in?P1?;^jPCglo03
k^[X1>CRh0CJf]T4d=;A1<C8b0Bl`L84]kbm0k>i^PB_]KH4[;>d1:ba/@B_/K08/K6_0k2`[@Bb[j`4
/ZjZ1;B^ZPBb[:P4/:ZU0jjUX@B[XY`4ZIjH1:VKU0BZVI44ZIJ=1:VCR@>VSX@4YHZ01:65NPBLOg<4
TWI[18M/HP=hH5L4JEA<15Q6@0A5>3<4<2TV120L6`@B414310H710`<3@@I6AX49RDU134`<0@m>cX3
AdE5159?C`ALFEP4IV=R16m]K0AiMWD4PX1n5Oooo`005?ooo`BETY04WY^I1:NTXPB`[J/4^KJd0l?0
_@C=bLH4em?@1>7MfPC[in<4mO3]0o7/j@CVhn44g=_I1=?CdPC9blX4`lG51;g0`0>j_Kd4]KVi1;:f
]PBc]K@4];Bb1;Bb[`Bd/Zh3/Jn/1;B`Z`Ba[:P4/JbW1;2ZY@B_Yj83Zj:M1:ROV@BUVYD4Y9NA1:BE
SPBSTHT4XHj50if9P0BKQ7/4UWid191gK@B6KVD4NVAK0f]HD@ALC4H4Bchj13P`;@@U8R0461LG10/;
30<;30d45QLG128Q8P@]:b`4=cHf1450?`=;BDT4EE=B15mLF`AXIF@4LFi]17YgMPB3P7lEoooo000D
oooo19FBT0BNViT4YjBR1;2]Z`Bi][@3`l2m1<g9aPCGdm04hMgJ1>_Wh`Cel>d3lNcY1>KSh@CLfmT4
dm?B1<W;bPC3aLD4_L300kZm_@Be^KT4/[Jf1;>e]0Bd];84];:_1;Bb[P>a[j`4];2[1;6/Z0Ba[:L4
/:ZU1:nWXP>[XYd4Z9nI1:FJU@BTUi44Y9F>1:>AR@BQSXD3WHV019^4N`BFOW@4T7M]18I^I@AjI5/3
JeQA15a<APA;?SX4>30]12DR80@H5aL42`/<0`/<3@@F5aL48R4R12d[;0@g=SH4@D0o0d]9B@AEDe84
GeaK16QUI0AaKVd4NWMf18>0OaGoool001Coool4UI:@19jKV@BWY:84/:f[1;Vf]0?3`;d4cLW61=OC
d0CQgMX4jnOS1?G`k@?ak>T4i^?Q1=cKf@CCdm84bL_:1<?5a@Bm`<03^[fm1;Fi^@Bb][H4/kFd1;Bd
/PBd/Zl4];:^0k6_[0Bd/:/4/JbX1;6/Y`B`ZZD4[jNR0j^RW@BXWiT4YIZE1:BGT@BTUHh4Xi691:6>
Q@>MRH04VhAk19InM0B@Mfd4QViU17YTF`=[F544G4a614/n>P@h<2d49B8P11PG5`@;2``32``=11HG
5`@R8B84;B//13Lf=PA1@3l3BdU915ECDPAOG5/4J6ET175^K@AjMgH4Ph1o5Oooo`005?ooo`BETY04
WY^I1:NTXPB`[J/4^KJd0l?0_@C=bLH4em?@1>7MfPC[in<4mO3]0o7/j@CVhn44g=_I1=?CdPC9blX4
`lG51;g0`0>j_Kd4]KVi1;:f]PBc]K@4];Bb1;Bb[`Bd/Zh3/Jn/1;B`Z`Ba[:P4/JbW1;2ZY@B_Yj83
Zj:M1:ROV@BUVYD4Y9NA1:BESPBSTHT4XHj50if9P0BKQ7/4UWid191gK@B6KVD4NVAK0f]HD@ALC4H4
Bchj13P`;@@U8R0461LG10/;30<;30d45QLG128Q8P@]:b`4=cHf1450?`=;BDT4EE=B15mLF`AXIF@4
LFi]17YgMPB3P7lEoooo000Doooo19BAT0BLVYP4YJ:P1:fZZ0Bf/k43_kbi1<S4`PCAcL/4fmKC1>CP
g0C_j^H3l^gZ1>SSh@COfmT4emCC1<k=c0C7alH4`L;10l30_`Bk_;/4^;Vh1;Vh]@Bg]K84][>`1;Jb
[P>c[j/4]:nZ1;6[Y`B`ZZD4[ZJR1:bSW`>XWiX4Y9^F1:6GT@BOThh4Wi2:19b<Q@BHR843U8=k199n
MPB<Mg04Q6mX17UVG`A]G5D3Ge5;14m4@0@n=S@4;2TW11dL70@@41443Ph@0aLG60@P8244:RTZ13@c
<`@m?3`4AdE50e1>C@AIEeH4HUmN16YXI`AcL6l4NgQg18>1OaGoool001Coool4U96@19bJV0BUXZ04
[JZX1;Jc/@>o_;T4b<C21=7=b`CKe]<4i>3L1>oZiP?bkNX4j>?Q1=oKf@CGe=<4c/g<1<O7aPC1`/43
`<2o1;^l^`Bh^KP4^KRe1;Ne/PBf/k04][:^0k>_Z`Bd[jX4/J^W1;2ZY@B^YZ84[:>O0jROVPBTViH4
XINA19nCSPBOT8X4W8b519R8P@>DPg/4TWif18agL0B4KfP4NFIO16eLE@=ODD/4CdA013hf=0@/:BL4
7A`L110@4@@>3Q035aLH120P8@@Z:BX4=3<c13dl?0A7ADD3D4i=15UGEPARGeh4JVQW17=`K`AkN7L4
Ph5o5Oooo`005?ooo`BDTI04W9ZH1:FRX0B]ZZP4][>a0knl^@C8a<84dLg;1=_Fd`CTh=`4kn[V0o;]
jPCXhn44gm_I1=ODd`C>cL`4alO61<72`@?0`;l4^kbk1;Ri^0Bi^;D4]kFb1;Jc/0Bf/Zh3/jn[1;B_
ZPBaZjL4/:ZU1:jVXPB/Xil3Z9nJ1:BKUPBQUi44Wi>>19n@RPBLS8D4V8R10iB3N`BBOWH4S7M`18A_
J0AiIUl4KEaE0emAB`A?A404?SHd12`Y9`@M71`4410A10h>40<G5aP4820Q12XY:P@d<c<4?C`l14M5
A@=@CTd4FEMF169OGPAZJ6L4Lg1_17]hM`B3PGlEoooo000Doooo19BAT0BLVYP4YJ:P1:fZZ0Bf/k43
_kbi1<S4`PCAcL/4fmKC1>CPg0C_j^H3l^gZ1>SSh@COfmT4emCC1<k=c0C7alH4`L;10l30_`Bk_;/4
^;Vh1;Vh]@Bg]K84][>`1;Jb[P>c[j/4]:nZ1;6[Y`B`ZZD4[ZJR1:bSW`>XWiX4Y9^F1:6GT@BOThh4
Wi2:19b<Q@BHR843U8=k199nMPB<Mg04Q6mX17UVG`A]G5D3Ge5;14m4@0@n=S@4;2TW11dL70@@4144
3Ph@0aLG60@P8244:RTZ13@c<`@m?3`4AdE50e1>C@AIEeH4HUmN16YXI`AcL6l4NgQg18>1OaGoool0
01Coool4Ti6?19^HU`BSX9h4ZjRV1;>`[@>k^;D4`l2m1<c8a@CDd<d4gMWE1>KQgP?_jNH4jN?P1>7L
f@CIe]<4dLo=1<[8a`C6aL<3a<;01<2o_@Bm^kT4_KVf1;Re/@Bh/jl4][6]0kB^ZPBb[JP4/:ZU1:jW
XPB[Xil4YinK0jBLU`BOUi84W9>>19V?RPBHS8H4U8N11922O@>=OWP4RWUb18=bJ`AhJF<4KUmJ165E
D0=CBDH4A3dk13@`;`@T8b<45ADF114B4`@J6Q/38B4R12XY:P@b<C84>cXj14=2@PA<BTX3E59B15eJ
FPAUHV84KFYY17AbL@AlNWP4Q8605Oooo`005?ooo`BCTHl4ViRG1:>PWPB[Z:H4/k2]0k^h]@C3`;d4
c<S51=C@c@CMfMD4i^7N0noYiPCYhn04hMcI1=WFd`CAcld4b/S71<K5``?4`/04`;nm1;fk^@Bm^KH4
^;Fa1;Rc[`Bf/Jd3]:jZ1;:]Z0B`ZZD4[ZNR1:^SW`BWWi/3Y9bG19nGTPBLThh4VHn:19R<QPBDQh44
T89m0henN0B:NG84Pg9[17QYH`A^GeX4HEE@0e=9APA4?C/4=30_12@S8`@E5AH44A8C11XJ6`<Q8B84
:RTZ138a<P@k>SX4@d9214a:BP=DDU84GEYJ16ERHPA]JVT4M79a17ajN0B4PH0Eoooo000Doooo19>A
S`BKV9L4Xj2N1:^XYPBc/:d3^kRe1<?0_@C<b<D4e=3=1=gIe@CVhMh3knWV1>WSh0CQg=T4fMKC1=7?
c@C:b<L4a/G30lC2`0C0_kd4_K^i1;fi]PBh]K44^;>_1;Ja[@>d[ZX4/ZfX1;2ZY@B^Yj84Zj>O1:NO
V`>TW9L4WiNB19bCSPBIShX4V8b619B7P@B@PWd3SGih18YiLPB3LV/4N6US16iOFPAQEE03DdU614@m
>`@d<2l492<S11DE5P@A4Q<46QXK0b4Q8P@Z:BX4<S4b13/j>PA3@T84C4Y:0eABDPAMFUX4IF9R16eZ
J@AdLW44O7Yh18B1P1Goool001Coool4Ti6?19^HU`BSX9h4ZjRV1;>`[@>k^;D4`l2m1<c8a@CDd<d4
gMWE1>KQgP?_jNH4jN?P1>7Lf@CIe]<4dLo=1<[8a`C6aL<3a<;01<2o_@Bm^kT4_KVf1;Re/@Bh/jl4
][6]0kB^ZPBb[JP4/:ZU1:jWXPB[Xil4YinK0jBLU`BOUi84W9>>19V?RPBHS8H4U8N11922O@>=OWP4
RWUb18=bJ`AhJF<4KUmJ165ED0=CBDH4A3dk13@`;`@T8b<45ADF114B4`@J6Q/38B4R12XY:P@b<C84
>cXj14=2@PA<BTX3E59B15eJFPAUHV84KFYY17AbL@AlNWP4Q8605Oooo`005?ooo`BCT8h4VYNE1:6N
W0BXYJ<4[jbZ0kNc/@Bn^kP4a/:o1<k9aPCFdLh4g]SE0nKPg@CXh]h4hmgI1=_Fd`CCcl`4cL[71<S5
``?6`l04`l2m1<2l^@Bn^KD4^[Fa1;Rc[PBe/:/3]:fY1;6ZY@B^Yj<4ZjBO1:NPW0BSW9P3WiRD19ZC
S`BGSh/4TXZ619:7PPB<PWd4RGij0hIjM@B2M6l4NFaX16iSG`ASFED4ETm<0dQ3@@@j>3L4;2`/11hO
80@D51D471`M12@S90<[:b/4<c8b13Xi>PA2@D44BTQ8159@C`=IEeL4HEiN16QVI@A_KF`4MWAc17ek
NPB5PX4Eoooo000Doooo19>@SPBJUiD4XIjL1:RUX`B_[:X3]k>a1;jk^0C6`[l4c/W61=KAcPCNf=D3
i^3M1>SRgPCSgMT4fmKC1=??c0C=b/L4b<G30lK3`0C3`;d4`;bi1;ji]@Bj]K44^;>^1;F`Z`>d[JT4
/JZU1:jWX`B[Y9l4Yj2L1:>LV0>OV9@4VY>?19N?R`BBRXH4TXN218b2O@B9OWX3QWYe189dK`AiK6P4
KV=O16=IE@AFCd`3B4=113Xh=`@/;2`47QlP11@D5@@L71d492<T0b/[:`@c<S84>STj1491@@A:B4P4
DU1?0eUGE`AQGUh4J6IU16m]K0AfM7<4OG]j18F2PAGoool001Coool4Ti2>19ZGU@BQWY`4Z:FS1:n/
ZP>g/k44_[^h1<K2_`C>bLH4e]7>1=kHe@?Vh=d4j>;N1>?Mf@CKe]<4dlo<1<g:a`C8aL<3a/?01<?0
_@C0_;T4_[Ve1;Ze/@Bh/jh4]K2[0kB]Z@BaZZD4[ZNS1:^TW`BWX9`4XibH0inHU0BJThl4Uhn;19::
QPBBQh84S89m18UnNP>6NWD4PWA_17U/J0A^Hel4HeUE15I?C0=8@d44>SPg12`/;0@N7b0451@E11`L
7@@T8b@3:b/[13<b<P@j>CX4@T5114Y8B0ABD4l3FEMG165NGPAXIVD4Kfe/17IdL`AmNgX4QH:15Ooo
o`005?ooo`BBShh4V9JD19nLVPBUXZ04[:VW0k>_[@Bi][<4`;bi1<O3`0C>bLH4eLo<0m_EdPCQfmP4
h]cI1=cFd`CEd<d4c/W61<W5`P?6`[l4a<2l1<2k^0Bo^K@4^kF`1;Na[0Bd[ZT3/J^V1:jWX`B[Y9l4
Z:6L1:>MV@BOV9D3ViBA19J?S0BARXL4S8F218V1O@B5OGX4Q7]h0h5fL`AjKf`4LFMT16ING0AJE584
CDU80d4o?P@d=3@49bPY11dN7`@O7Ql49bHW12h];P<e=3@4?3/k14=1@@A9B4P4D4m>15MEE@=NG5/4
IF=R16]YJ0AbL6l4N7Ie17mlN`B5Ph4Eoooo000Doooo19:?SPBHUY@4WibJ1:FRX0B/ZJL3/jn]1;Vf
/`C0_;T4al?01<k9aPCEcl`3fmGB1>7Kf0CRg=T4g=KC1=G@c@C>bLH4bLG20lK2_`C4`;`4`;^h1;ni
]0Bk]K04]k6/1;B^Z@>aZjH4[ZNS1:^TW`BXXI`4XifI19nHU@>KU944UXn<196:Q`B<QH84RH5m18Em
NPB4NgP3PGIc17Y_K0AaIf@4IUiL15YDDPA=BDP3@Cln13@d=0@W:2T47AhO11lN7`@W9RL4;Rd^0cDd
=0@l>c/4@d5114U8B0A@Cdh4EeEE0eiLF`AUHf84JfUX179`K`AhMWD4Ogak18F3PAGoool001Coool4
TXn>19RFU0BOW9X4YJ:P1:bYY`>c[jd4^KJc1<2l^@C7`l04c/W61=G?c0?KeM84hM_H1>;Lf@CLe]<4
eM3=1<k9aPC9aL83a/:o1<C0_0C0^kP4_kVd1;^e/0Bg/J`4]:jY0k6[YPB^Yj<4ZjBO1:RQW0BSWIT4
WiRE0i^DT@BFSh`4THZ718b5PPB9PGd4QGej18AkN0>1MW<4NVm/175WI0AVGU`4FUAB14e9B0=1?ch4
=3@d12LX:@@M7Ql47ahO12LV9`@^;Bh3=C@d13`k>`A3@D44BDQ8151?CPAGEED3GUaK16ESHPA[JFP4
LW1_17QfM@AoO7/4QH>15Oooo`005?ooo`BBShh4V9JD19nLVPBUXZ04[:VW0k>_[@Bi][<4`;bi1<O3
`0C>bLH4eLo<0m_EdPCQfmP4h]cI1=cFd`CEd<d4c/W61<W5`P?6`[l4a<2l1<2k^0Bo^K@4^kF`1;Na
[0Bd[ZT3/J^V1:jWX`B[Y9l4Z:6L1:>MV@BOV9D3ViBA19J?S0BARXL4S8F218V1O@B5OGX4Q7]h0h5f
L`AjKf`4LFMT16ING0AJE584CDU80d4o?P@d=3@49bPY11dN7`@O7Ql49bHW12h];P<e=3@4?3/k14=1
@@A9B4P4D4m>15MEE@=NG5/4IF=R16]YJ0AbL6l4N7Ie17mlN`B5Ph4Eoooo000Doooo196?S@BGU984
WIZH1:>OWPBXYJ<3[Z^Y1;B`[PBj][@4`;bi1<K1_`C<al@3dLc91=KAc@CKeM84g=KB1=K@c0C?bLH4
bLC00lC0_0C3_KX4`;Zf1;jg/PBj/jl4]JnZ1;:[Y`>^Yj<4ZjBP1:RRW@BTWYX4WiVF19^ETP>FTHd4
THb918b7Q0B6PGh4PWej17mjN@AoN7H3Ng=a17=[J@A[I684HEaJ15AAD0A7ATH3?3`l134b<`@U9RL4
9BDU12`[;0@b<C84>3Lh0chm?@A5@d<4BdU9155?C`AGEED4GE]J0f=QH0AYIfH4Kfe/17EbL@AjN7L4
P7il18J3PQGoool001Coool4THn=19NDTPBMVYP4XinN1:RUX`>^ZjT4];2^1;Zf]0C0_;T4a/6o1<c7
a0?Ac<T4e]7=1=_EdPCLe]84e]3<1<o9aPC9a<03a<2l1<>m^PC0^[H4_[Nb1;Zc[`Be[jX4/Z^W0jjW
X`B[Y:04Z::M1:BNVPBOVIH4ViFB0iJAS@BAS8T4S8N418J1OPB2OGX4OgYi17mhMP=kLg44Lf]Y16]T
HPAQG5X4E55@14M6AP<l?3`4<C8c12DV9`@U9BD4;2//138a<P@h=cP3?Sdm14E3@`A;BDT4DDm?15ME
E@AMFeX3Hf5P16UWIPA_KF`4MG9a17YhM`B0OW`4QX>25Oooo`005?ooo`BAShd4UiBB19fJV0BSWih4
Z:FS0jj[Z@Bd/:h4^[Jd1<2l^@C6`Kl4c<O40m7<b@CFdLd4fmGB1=cFdPCFd<`4clW61<W4`0?4`;`4
`kfj1<2j]PBn]k84^[>_1;F_ZPBbZjL3[ZNS1:^TX0BXXYd4Y9jJ19nIUPBKUI83UY6=196<R@B<Qh@4
QX5n189mNPAoNWT4OgQf0g]cL@AcJfT4JfAR165LFPADDE04AdI60c`l?0@a<S<49BHW12DU9@@/:b`4
<S4b13Pg>0<n?Cd4AD=314]9B@AACdl4EeEE15eKFP=SHF04JFMV16m]K0AeLW44NWQg181nO0B6Ph8E
oooo000Doooo196?S@BGU984WIZH1:>OWPBXYJ<3[Z^Y1;B`[PBj][@4`;bi1<K1_`C<al@3dLc91=KA
c@CKeM84g=KB1=K@c0C?bLH4bLC00lC0_0C3_KX4`;Zf1;jg/PBj/jl4]JnZ1;:[Y`>^Yj<4ZjBP1:RR
W@BTWYX4WiVF19^ETP>FTHd4THb918b7Q0B6PGh4PWej17mjN@AoN7H3Ng=a17=[J@A[I684HEaJ15AA
D0A7ATH3?3`l134b<`@U9RL49BDU12`[;0@b<C84>3Lh0chm?@A5@d<4BdU9155?C`AGEED4GE]J0f=Q
H0AYIfH4Kfe/17EbL@AjN7L4P7il18J3PQGoool001Coool4THj<19JCT@BKV9H4X9fK1:FRX0>ZYZ@4
[j^Y1;B`[PBi]K<4_[Zg1<>o_0?8`l04c<O41=3;a`CEcl`4eLo;1<o8a0C8`[h3`[fi1;nj]PBm]k<4
_;F`1;N`[0BbZjL4[jRT0j^UX@BXXId4YInJ1:2KU`BLUY<4Ui:?0i:=R`B>RXP4R8B3189oO@AnNgX4
NgQg17agM@=gLFl4KfYX16QSH@AMFET4D4i>14A4A@<i>SX4<C8b12d];@@c<S84>3Lg13dl?0A3@T83
B4M714e<C0ACDE44F5IF15eLF`ASHF03J6IU16e[JPAbL6l4MgEd17ajN@B2Ogh4QhB35Oooo`005?oo
o`BASX`4UY>A19^HUPBPWI/4YJ:P0jZVY0B_ZjT4];2^1;Ve/`Bn^[L4`knl0lS3`0C<al@4d<_71=G?
c0CEcl/4clS41<S2_P?2_KT4_kZf1;fg/`Bl]K04]k2/1;:[Y`B_Z:@3ZjFQ1:RQW@BUWiX4X9^G19bF
T`BGTXl3TXf;18j:R0B8Q8<4PWmm17ikNPAkN7L4O7Me0gMaK`A_JVP4J6=Q15eIF@A@CTh4A4A50cTj
>P@a<S84;Bd]13<b<P@h=cL4?C`l14=2@P=8AdL4CDa<15=AD@AHEUH4GEaK16=QH0=XIVD4KF]Z179`
K`AgMG@4O7Yi189oOPB7Q8<Eoooo000Doooo196>S0BFTi44ViRF1:2MV`BUXZ03ZZJT1:n[Z@Bd/:h4
^KFc1;jj]`C3_k`3b<?01<c7a0C@blL4eLo<1=G?b`C?b<@4b<:n0l:m^@Bo^[H4_KNc1;be/0Bg/:`4
/Z^W1:nXY0>[YJ44Z:6M1:FOVPBPViL4W9JC19NBS`>BSH/4SXZ818R4P`B2Ogd4OW]j17]hM`AlMgD3
Mg5_16mZJ0AXHf44GEUI151>CPA4A4D3>CXj134b<P@];Bd4<c8b13Pg=`@m?3`4@d920dQ7A`A=C4`4
De5A15QFEPAMG5/4Hf5P0fQVI@A]JfX4LW1_17MeM0AlNWT4PWmn18N4PaGoool001Coool4THj<19JC
T@BKV9H4X9fK1:FRX0>ZYZ@4[j^Y1;B`[PBi]K<4_[Zg1<>o_0?8`l04c<O41=3;a`CEcl`4eLo;1<o8
a0C8`[h3`[fi1;nj]PBm]k<4_;F`1;N`[0BbZjL4[jRT0j^UX@BXXId4YInJ1:2KU`BLUY<4Ui:?0i:=
R`B>RXP4R8B3189oO@AnNgX4NgQg17agM@=gLFl4KfYX16QSH@AMFET4D4i>14A4A@<i>SX4<C8b12d]
;@@c<S84>3Lg13dl?0A3@T83B4M714e<C0ACDE44F5IF15eLF`ASHF03J6IU16e[JPAbL6l4MgEd17aj
N@B2Ogh4QhB35Oooo`005?ooo`B@SH`4U96@19VEU0BMVYP4XIjL0jJRX0BZYZ@4[Z^X1;>_[0Bg/k04
^kNd0knj]`C3_[/4a/6n1<[4`@C>b<@4cLK21<O1_0?0^[H4^kFa1;Vb[PBg/J`4/jbX1:jXX`BZY:43
Yj6M1:FNVPBRW9L4WIRD19RCT0BCShd3SX^918^8QPB5PX84PWmn17YiN@AjN7L4N7Ed0g9^KPA[J6L4
Hf1O15QGE`A?CTh4@T=40cXj>P@i>3P4?3Xk140o?`A4@d<4BDM714e<C0=BD504EUED15]IF@AOGUd4
I69Q16QVIP=]JfX4LFm^17IdLPAjN7L4Ogak18>0O`B7QH<Eoooo000Doooo192=S0BDTI04VIFD19fJ
V0BQWY`3YZ:P1:ZVY0B^ZjP4/jn/1;Nc/0Bk]k@3_kZg1<>n^`C6`Kh4b/C11<k8a0C=a/84al6l0l2j
]PBk]K44^K:^1;Na[0Bc[:P4[ZRS1:ZTX@>WXId4YIjJ1::LU`BMV9@4V9>@19>?S@>>RhT4RhR618F2
PPB2Ogh4NWUi17YhM`AhMG@3LVi^16]XI`ASH5l4F5MG14m>CPA2@d@3>SXj13Th>0@l>S/4@3lo14A3
@`A9AdL4CDa<0e9@D0AFEE@4FeUI15mNG@ATHV44J6IV0fe[JPAaKfh4MWAb17YhM`AoO7/4Ph1o18N5
PaGoool001Coool4T8f<19BAT0BIUI@4WIZH1:6NW0>VXZ04ZZJT1:j[Z0Bc[j`4]k>`1;^g]0>o^[L4
`kjk1<K1_PC:a<44c/S41<g6`PC7`K`3`;Zf1;^e/@Bi/Zh4]k6/1;>/Z0B^Z:<4ZZBQ0jNQW@BUWYX4
XYbG19fHU0BHTi04Thn=0hj;R@B;R8H4QH:2189oOPAjNGT4NWQg17QeM0=bKVh4JfQW16=PG`AHEeL4
Cdi>1493A0<j>SX4>CPh13`j>`A0?cl4A4=314U7A`A=C4`3DU1@15IEE0AKFET4GeiM16ARH@AXIVH3
KF]Z175_KPAfM784NWQg17mlN`B3P7l4QhF35Oooo`005?ooo`B@SH`4U96@19VEU0BMVYP4XIjL0jJR
X0BZYZ@4[Z^X1;>_[0Bg/k04^kNd0knj]`C3_[/4a/6n1<[4`@C>b<@4cLK21<O1_0?0^[H4^kFa1;Vb
[PBg/J`4/jbX1:jXX`BZY:43Yj6M1:FNVPBRW9L4WIRD19RCT0BCShd3SX^918^8QPB5PX84PWmn17Yi
N@AjN7L4N7Ed0g9^KPA[J6L4Hf1O15QGE`A?CTh4@T=40cXj>P@i>3P4?3Xk140o?`A4@d<4BDM714e<
C0=BD504EUED15]IF@AOGUd4I69Q16QVIP=]JfX4LFm^17IdLPAjN7L4Ogak18>0O`B7QH<Eoooo000D
oooo18n<R`BCT8h4UY>B19ZGU@BNVYT3XIjL1:FQW`BXYJ<4[:RV1:n[Z@Bc[j`3][:_1;Ve/PBl]k@4
_kZg1<:l^0C4_[X4`K^g0kjg]0Bh/Zh4]:jZ1;6ZYPB]Yj<4Z:>O1:FOW0>SWIX4XIZG19bHU0BHU984
UY:?19:>R`><RXP4R8J418B2PPB1Ogl4NWUi17UhM`AeLg<3L6i]16YWIPAQGel4F5MH159AD@A4A4D3
@d9214M6A@A:B4P4CD];151?C`ADDU84F5IF0eaJF@AOGEd4Hf5Q16MUI0A[J6P4KVa[0g9`K`AfLg84
NGMf17ekN@B1OWd4Q8:118R5Q1Goool001Coool4Shb;19>@SPBFTi84VYNE19jJV@>QWY`4YJ6O1:RU
X`B/Z:H4[j^Y1;>_[0>f/Zl4^KFb1;bg]0Bo^[L4`[bh1<Bn^PC1^kL3_[Nd1;Rb[PBd[ZX4/JZV1:fW
X`BXXil4YInL0j>MVPBQVYL4W9RD19RDTPBFTXl4TXj;0hb:R0B8QX@4Q8:2185oO`AjNGT4NGQg17Ec
L`=`KVd4JVMV165OG`AHEeP4DU5A14A4A@=3@T84AdI514Y8B0A=Bd/4D4m?15ABDPAHEUH3G5YI15mM
G@ASHF44IfET16]XJ0A^K6/3LW1_17IcLPAiMgH4OG]i185nO@B4PX44R8F45Oooo`005?ooo`B?S8/4
Ti2>19JCTPBJUiD4WYZI0j6NW0BUXIl4Z:FS1:bXYPB_ZjT4/jn/0kJb[`Bi]K84_;Nd1;nj]`C2_;P4
a;jj1<6k]`>n]k@4^;:^1;B^ZPBaZZH4[JNS1:RSW`BUWi`3XifJ1:6JU`BLV9@4V9BB19JBS`BBSX/3
S8Z818R6Q0B4PX84PGmo17YiN@AiN7L4MG=c0g1^K@AZIfH4HEmO15QGF0ABDE44A4A50d=2@PA7ATD4
BTQ814e;B`A@Cdl4E59B15QFEP=LFUT4GeeM16=QH@AWIF@4JfQX16i/J`=bL6l4MW=b17UgMPAmNgT4
PGim18B2P@B8QH@Eoooo000Doooo18n<R`BCT8h4UY>B19ZGU@BNVYT3XIjL1:FQW`BXYJ<4[:RV1:n[
Z@Bc[j`3][:_1;Ve/PBl]k@4_kZg1<:l^0C4_[X4`K^g0kjg]0Bh/Zh4]:jZ1;6ZYPB]Yj<4Z:>O1:FO
W0>SWIX4XIZG19bHU0BHU984UY:?19:>R`><RXP4R8J418B2PPB1Ogl4NWUi17UhM`AeLg<3L6i]16YW
IPAQGel4F5MH159AD@A4A4D3@d9214M6A@A:B4P4CD];151?C`ADDU84F5IF0eaJF@AOGEd4Hf5Q16MU
I0A[J6P4KVa[0g9`K`AfLg84NGMf17ekN@B1OWd4Q8:118R5Q1Goool001Coool4SXb:196>S@BDTI04
UiBB19ZGU@>MVYP4X9bK1:>OW@BUXZ04Z:BR1:^WY@>]ZJL4/:bY1;:^Z`Bd[jd4][6^1;Nb[PBh/Zh3
]k6^1;F_Z`B_Z:D4ZZBO1:BPW@BRWY/4X9^H0inJU`BLUi<4V9BA19JCT0BETXl4T8f;0hf:R@B8QXD4
QH>3181oO`AlNg/4N7Qh17AcL`=`KVd4JFMW16=RHPAKFUX4EU=C14m>CP=BDE44EE=C15MEE@AJF5P4
G5]J15mMG@ARH603IF=S16QVI@A[JFP4KVa[175_KPAdLW43MgEd17YhM`AmNgT4P7el18>0O`B6Ph84
RHJ55Oooo`005?ooo`B>S8X4THj=19BAT0BGU984VYNE0ifJV0BPW9/4XinM1:FRX0BXY:84ZjNU0jfY
Y`B`[:T4/Zj[1;B_[@Bf/Jh4]k:^1;Rb[P>g/Jh4]Jn[1:nXY@BZY9l4Y:2M1::NV`BPViP3WiZG19bG
T`BHU944UY>@19FBS`B@SH/3SHZ918R6Q@B5Ph<4P7mo17akN`AhN7P4M7=c0g1^K@AYIfL4Hf9R15]J
FPAFDe<4Cdi>0e9AD@AEDe<4EeEE15YHF0ALFeX4GeeM169PH0=UHf<4J6IU16]YJ0A^K6/4LFm^17Ab
L@=gMG@4NWQg17ekN@B0OG`4Ph1o18J3PPB9QXDEoooo000Doooo18j<RPBASXd4U96@19NDTPBJUiD3
WIZH1:2LV`BSWid4YJ:P1:RTXPB[YjD3[JVW1;2/Z@Bb[Z/4]:n]1;Ja[PBg/Zh4^;:^0kNa[PBe[j/4
[jRU1:ZTW`BTX9d4XYjK1:2KV0>OVYL4W9NC19RDT@BFTi04UI:?192=R`>=RXT4R8J518F3P`B0Ogl4
O7]k17QhN0AdLg<3L6i]16UWI`ASHV84FeYJ15ICD`A?CTh3DU5A15ECD`AGEED4FUQH15aKFPAOGEd4
HV1P0fESH`AXIVD4JfUX16i/J`AaKfh4M79a0gMeM0AjN7L4OG]i181mO0B3P7l4QX>218V6QAGoool0
01Coool4SX^9192=R`BBShd4U96@19JCTP>IUI@4ViNF19fJV0BOW9X4XIfK1:>OW@>UXIl4Yj>P1:RT
XPBZYJ<4ZjJT2jbWY0B]Yj<4Yj6N1:>NVPBPW9T4W9RF19ZFT`>IUI<4V9BB19NCT0BETHl4TXn=18n<
RP><RHP4R8J518F3P`B1Ogl4OGal17YiN@AfM7@3LW1_16YXI`AWIFD4Hf5P15mMG@APGUh3HEmO16=Q
H0ATHf84IVAT16QVIPAZJ6P4KF]Z0fm]K0AaKfh4Lg5`17EcLPAhMG@4NWQg0gajN@AnO7/4PGim18>0
O`B5PX44QhF318V7QAGoool001Coool4SX^9192=R`BBShd4U96@19JCTP>IUI@4ViNF19fJV0BOW9X4
XIfK1:>OW@>UXIl4Yj>P1:RTXPBZYJ<4ZjJT2jbWY0B]Yj<4Yj6N1:>NVPBPW9T4W9RF19ZFT`>IUI<4
V9BB19NCT0BETHl4TXn=18n<RP><RHP4R8J518F3P`B1Ogl4OGal17YiN@AfM7@3LW1_16YXI`AWIFD4
Hf5P15mMG@APGUh3HEmO16=QH0ATHf84IVAT16QVIPAZJ6P4KF]Z0fm]K0AaKfh4Lg5`17EcLPAhMG@4
NWQg0gajN@AnO7/4PGim18>0O`B5PX44QhF318V7QAGoool001Coool4SX^9192=R`BBShd4U96@19JC
TP>IUI@4ViNF19fJV0BOW9X4XIfK1:>OW@>UXIl4Yj>P1:RTXPBZYJ<4ZjJT2jbWY0B]Yj<4Yj6N1:>N
VPBPW9T4W9RF19ZFT`>IUI<4V9BB19NCT0BETHl4TXn=18n<RP><RHP4R8J518F3P`B1Ogl4OGal17Yi
N@AfM7@3LW1_16YXI`AWIFD4Hf5P15mMG@APGUh3HEmO16=QH0ATHf84IVAT16QVIPAZJ6P4KF]Z0fm]
K0AaKfh4Lg5`17EcLPAhMG@4NWQg0gajN@AnO7/4PGim18>0O`B5PX44QhF318V7QAGoool001Coool4
SX^9192=R`BBShd4U96@19JCTP>IUI@4ViNF19fJV0BOW9X4XIfK1:>OW@>UXIl4Yj>P1:RTXPBZYJ<4
ZjJT2jbWY0B]Yj<4Yj6N1:>NVPBPW9T4W9RF19ZFT`>IUI<4V9BB19NCT0BETHl4TXn=18n<RP><RHP4
R8J518F3P`B1Ogl4OGal17YiN@AfM7@3LW1_16YXI`AWIFD4Hf5P15mMG@APGUh3HEmO16=QH0ATHf84
IVAT16QVIPAZJ6P4KF]Z0fm]K0AaKfh4Lg5`17EcLPAhMG@4NWQg0gajN@AnO7/4PGim18>0O`B5PX44
QhF318V7QAGoool001Coool4SHZ918j;RPB@SH/4THj=19>@SP>DTI04UY>A19NDTPBHUI@4VYNE19^H
UP>LVIL4WIZH19nKV@RPW9X;XIfJ1:2LV@BNVYL4WIRE19^GU0BETY04U96>0iFBS`BDT8l4U92>19B@
S@B@SH/4SX^:0hb9R0B8QXD4QhB418B2P@B1Ogl4OWak17IeM0=fM7<4LFm^271^K@Q_KF`3L6e]171^
K@AbKfl4Lg5`17AbL@AfLg84MgEd0gQfM@AjN7H4NgUh17ejN@AnO7/4P7el0h5oOPB3P7l4Q8:018J3
PPB7QH<4RHJ518Z7QQGoool001Coool4SHZ918j;RPB@SH/4THj=19>@SP>DTI04UY>A19NDTPBHUI@4
VYNE19^HUP>LVIL4WIZH19nKV@RPW9X;XIfJ1:2LV@BNVYL4WIRE19^GU0BETY04U96>0iFBS`BDT8l4
U92>19B@S@B@SH/4SX^:0hb9R0B8QXD4QhB418B2P@B1Ogl4OWak17IeM0=fM7<4LFm^271^K@Q_KF`3
L6e]171^K@AbKfl4Lg5`17AbL@AfLg84MgEd0gQfM@AjN7H4NgUh17ejN@AnO7/4P7el0h5oOPB3P7l4
Q8:018J3PPB7QH<4RHJ518Z7QQGoool001Coool4SHZ918j;RPB@SH/4THj=19>@SP>DTI04UY>A19ND
TPBHUI@4VYNE19^HUP>LVIL4WIZH19nKV@RPW9X;XIfJ1:2LV@BNVYL4WIRE19^GU0BETY04U96>0iFB
S`BDT8l4U92>19B@S@B@SH/4SX^:0hb9R0B8QXD4QhB418B2P@B1Ogl4OWak17IeM0=fM7<4LFm^271^
K@Q_KF`3L6e]171^K@AbKfl4Lg5`17AbL@AfLg84MgEd0gQfM@AjN7H4NgUh17ejN@AnO7/4P7el0h5o
OPB3P7l4Q8:018J3PPB7QH<4RHJ518Z7QQGoool001Coool4SHZ918j;RPB@SH/4THj=19>@SP>DTI04
UY>A19NDTPBHUI@4VYNE19^HUP>LVIL4WIZH19nKV@RPW9X;XIfJ1:2LV@BNVYL4WIRE19^GU0BETY04
U96>0iFBS`BDT8l4U92>19B@S@B@SH/4SX^:0hb9R0B8QXD4QhB418B2P@B1Ogl4OWak17IeM0=fM7<4
LFm^271^K@Q_KF`3L6e]171^K@AbKfl4Lg5`17AbL@AfLg84MgEd0gQfM@AjN7H4NgUh17ejN@AnO7/4
P7el0h5oOPB3P7l4Q8:018J3PPB7QH<4RHJ518Z7QQGoool001Coool4S8Z818f:R@B>RhT4SXb:18n<
R`>@SH`4THj<196>S@BBShh4Ti2>19>@S`>DTHl4UI6@19FBT0BETY4?UY>A19JBT0BETHl4U96>19>@
SPBASX`;T8f;196=R`B@SH/4SHZ918b9R0>:R8L4RHJ518R5Q0B6Q8<4QH>218:0O`AmNgX3Ogel17ml
N`AnO7/4OW]j27ekNP=nNgX4OWak17mlN`AoOG`4P7el185nO@B1Ogh3PWmn18>0O`B3PH04Q8:018F2
P@B6Ph83QXB318N5P`B8QH@4RHJ518V7Q@B:QhH4RhR75Oooo`005?ooo`B<RXP4SHZ918j;R@B>S8X4
Shb;0i2=S0BASX`4THj=19:?SPBCT8h4Ti2?0iBAS`BETI04UI:@19FBT@nFTi44UY:@19FAS`BDTHh4
Ti2>196>S0^@SH/4THf;192=R`B=RXT4S8V80hZ8Q`B9QXD4R8F418J4P`B5Ph84PX1o17ekNP=oOG`4
Ogak17ilN`AnNgX8OG]j0gikNPAnO7/4Ogak17mmO0B0OG`4PGim185oOP>2Ogh4Ph1o18>1P0B4PX04
QH:118J3PP>6Q8<4QhF318R5Q0B9QXD4RHN518Z7QPB;R8LEoooo000Doooo18b:R0B=RXT4SX^918j<
RPB?S8/3T8f<196>S0BASXd4TXn>19>@SPBCT8l3U96?19FAT0BETY04UI:A3iJCT@BFTY04UI6?19BA
SPBCT8h4THj<2i2=R`BASH/4T8f;18f:R@B<RHP3RXR718V6Q@B8QH@4QXB318F3PPB2P7l4OG]j0gmm
O0AoO7/4OWak17ikNPQmNgX3OW]j17ilN`AoO7/4Ogel181mO0B1OWd4PGmn0h9oOPB3P7l4Ph6018B2
P0B5PX44QX>20hJ4P`B7QH<4R8F418V6Q@B9QhD4RXN618^8QaGoool001Coool4S8Z818f:R@B>RhT4
SXb:18n<R`>@SH`4THj<196>S@BBShh4Ti2>19>@S`>DTHl4UI6@19FBT0BETY4?UY>A19JBT0BETHl4
U96>19>@SPBASX`;T8f;196=R`B@SH/4SHZ918b9R0>:R8L4RHJ518R5Q0B6Q8<4QH>218:0O`AmNgX3
Ogel17mlN`AnO7/4OW]j27ekNP=nNgX4OWak17mlN`AoOG`4P7el185nO@B1Ogh3PWmn18>0O`B3PH04
Q8:018F2P@B6Ph83QXB318N5P`B8QH@4RHJ518V7Q@B:QhH4RhR75Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00VOooo`<00024oooo002L
oooo00<0003oooooool0POooo`00Noooo`@00004oooo0`0000;oool200001?ooo`@00002oooo0`00
00?oool300000oooo`80001noooo001koooo00<0003oooooool01_ooo`040000oooooooo00000_oo
o`040000oooooooo00000_ooo`040000oooooooo00001Oooo`040000oooooooo0000Poooo`00O?oo
o`030000oooooooo00;oool5000000Goool0003oooooool000000_ooo`040000oooooooo00000_oo
o`@00002oooo00@0003oooooool00023oooo001moooo00D0003oooooooooool000000_ooo`040000
oooooooooooo0P0000Coool300000oooo`800004oooo100008;oool007_oool010000?ooooooo`00
00?oool00`000?ooo`000002oooo00@0003oooooool00005oooo00<0003oooooool0SOooo`00O?oo
o`800005oooo0P0000?oool200001Oooo`80002?oooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(270) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
848483858484858584858584858585858685868685868686868686868786868787868787
878887878888878888878989878989878989878A8A878A8A878A8B878B8B878C8C888D8F
878B8B878A8A878A89878A8A888989888A89888A89898A8A898B8A898A8A8A8B8A898A89
898A8989888789888688868587858487858386848286838185818084807D837E7C827C79
807975827D7A837F7D83807E84817F848180848180848280848281848281848381848382
848382848382848383848483
858484858585858685868686868786868787878888878988888989888A8A888A8A898B8B
898C8C898C8D8A8D8D8A8E8E8A8E8F8A8F8F8A8F908B90918B91928B92938B93958B9497
8A92938A91918A90908B90908B8F8F8C8F8F8C90908D91908D91918D91908E91908E908E
8D8F8D8D8D8B8C8B898B89878A878589858388848187827F867F7C847C7882787480746F
7E726D807773827A77827C79837E7B837F7C847F7D84807E84817F84817F848280848281
848281848382848382848383
858584858685868786878787878888888989888A8A898B8B898C8C8A8D8D8A8D8E8B8E8F
8B8F908C90918C91928D92938D93948D94968E95978E96988E97998E989B8E999D8E9B9F
8D989B8D97988D95968E95958E95958F9595909696919695909695919695919594919392
9092908F8F8D8F8E8B8E8B898D89868B86838A838088807D867C7884787481746E7D6E67
7D6F697F746F817773827976837B78837C79837E7B847E7C847F7D84807E84807F84817F
848280848281848382848382
858584868686878887878888888989898B8B898C8C8A8D8E8B8E8F8C90908C90918D9293
8E93958E95968F96978F979990989A90999C919B9D919C9F919DA0919EA291A0A491A1A6
909EA1909C9E909B9C919A9B919A9B929A9A939A99939A99929A99939998949897939695
92959292939091918E918D8A8F8A878D86838B837F897F7A867A7584767080706A7D6A63
7E6E6780716C81746F827772827975837A77837C78847D7A847E7B847F7C847F7D84807E
84817F848280848281848382
858585868786878888888989898B8B8A8C8D8B8E8F8C90908D91928E92948E94958F9697
90979991999B929A9D929C9E939DA0949FA294A0A494A2A695A3A894A5A994A6AB93A7AC
93A3A793A1A493A0A2949FA0949E9F959E9E959D9D969D9D969E9D969D9C979C9B969A98
95979595959394928F938F8C918B888F86828D837E8A7E7987797384736D806D667D6860
7F6C6580706981736D827570837772837974837A76847B78847C79847E7B847F7C84807D
84807F848180848281848382
858685878787888989898B8B8A8C8D8B8E8F8C90918D92938E94958F959790979991999B
929B9D939D9F949FA295A1A496A3A697A4A898A6AA98A8AD98AAAF98ABB097ACB196ACB2
96A8AD96A6A996A5A797A3A597A3A398A2A298A2A299A2A199A2A199A1A0999F9E999D9C
999B9998989697959296928E948C899287848F837E8C7E7988787285716A806A627E675F
806B64816F6782716B82746E837570837772837974847A76847B78847C79847E7B847F7C
84807E84817F848280848382
868685878888888A8A8A8C8C8B8E8E8C90918E92938F949690969891989A939B9D949D9F
959FA296A1A497A3A798A5A999A8AC9AAAAE9BACB19CAEB49DB1B69CB2B89BB2B998AFB6
98ACB198AAAD99A9AB99A8A99AA7A79BA7A79BA6A69CA6A59DA6A59DA5A49DA4A29DA2A0
9C9F9C9C9B999B9894999490978E8B94898591837F8E7E7989777185706881695F80685F
816B63826E6682706983726C83746E837671847873847975847A76847B78847D7A847E7C
847F7D84807E848180848381
868686878988898B8B8A8D8E8C90908D92938F949590979892999B939B9E959EA096A0A3
97A3A699A5A99AA8AC9BAAAF9DADB29EAFB59FB2B8A0B5BBA2B8BEA4BBC29BB5BD98B0B6
99AFB39AAEB19BADAF9CACAD9DABAC9EABAB9FABAB9FABAAA0ABAAA0AAA9A1A8A7A1A6A4
A1A3A0A09F9C9E9A979D96929A908D978A8693847F8F7E788B777087706882685F826960
826B63836D66836F6883716B84736D84756F847671847873847975847B77847C79847D7A
847E7C847F7D84817F848281
868686888989898C8C8B8E8F8D91928F949590969892999B949C9E959EA197A1A498A4A7
9AA7AA9BA9AD9DACB19EAFB4A0B2B7A1B5BBA3B8BEA4BBC2A6BFC6A7C0C896B2BA98B1B8
9BB1B69CB1B49EB0B39FB0B1A0AFB0A1AFAFA2AFAFA3B0AEA4B0AEA4B0ADA5ADACA5ABA8
A4A7A4A3A19FA29D99A098949D928E998B87968680917F788D787089716984695F846A61
846C63846D65846F6784716984726B84746E847570847772847874847A76847B78847D79
847E7B847F7D84817F848281
868786888A8A8A8D8D8C90908E929390959792989A949B9D959EA197A1A499A4A89BA7AB
9CABAF9EAEB2A0B1B6A1B4B9A3B7BDA5BAC1A6BDC4A8C1C8ABC5CD9EBBC494B1BA9AB4BA
9DB4B99FB5B8A0B4B7A2B4B6A3B3B4A4B3B3A5B3B3A6B4B3A7B5B3A8B4B1A9B1AFA8ADAB
A7A9A6A6A4A1A59F9BA39A969F938F9B8D889786819380798F79718A726A866B62866B61
856C63856D64856E6685706885716A84736C84746E847670847772847974847A77847C79
847D7B847F7D84817F848281
868787898A8A8B8E8E8D91918F9495919799939A9C959EA097A1A499A4A79BA8AB9DABAF
9FAEB3A1B2B7A3B5BBA5B9BEA6BCC2A8BFC6A9C3CBADC8D0A3C1CA98B7C09AB7BF9DB7BD
A0B8BDA2B8BCA3B8BBA5B8B9A6B7B8A7B7B6A8B8B6A9B8B7ABBAB7ABB8B5ACB5B2ABB0AD
AAABA8A9A5A2A8A09DA59B96A194909D8D8898878194807A917A738C746C8A6F65876B61
866C62866C63866E65856F6785706985726B84736D84756F847671847873847A75847B78
847D7A847E7C84807E848281
878787898B8B8B8F8F8E929290959792999B959C9F97A0A399A4A79BA7AB9DABAFA0AFB3
A2B2B7A4B6BBA6BABFA8BDC4AAC1C8ABC5CCADC8D0A8C6CF9CBCC59DBCC49FBBC3A1BBC1
A3BCC1A5BCC0A7BCBFA8BBBCA9BBBBAABBBAABBCBAACBBB9AEBCB9AEB8B5AFB4B2AEAFAC
AEABA8ACA6A3ABA19EA79B97A394909F8E8999878196817A927B738E766D8C7067896C62
886B61876C62876D63866E65866F6785716985726B84746D847570847772847974847B77
847C79847E7B84807E848280
878887898C8C8C8F908F9394919798949B9D969FA198A2A59BA6AA9DAAAEA0AEB2A2B2B7
A4B6BBA7BAC0A9BEC4ABC2C9ADC6CDAFCAD2B1CED7A3C3CEA0C0CAA0BEC7A2BEC6A4BFC4
A7C0C5A9C1C5ABC0C2ABBEBFACBEBDADBEBDADBEBCAEBBBAB0B9B7B1B6B5B0B0AFB0ADAB
B1ACAAB0A7A4AEA19EA99B97A59490A08E899B878197817A937C7491776E8E72688B6E64
886A5F886B60886C62876D63866E65856F6785716A84726C84746E847671847873847A76
847C78847E7B84807E848280
8788888A8C8C8D90918F949592999A959C9E98A1A39AA5A89DA9AC9FADB1A2B1B6A5B6BB
A7BABFAABEC4ACC2C9AFC7CEB1CBD3B3D0D8ADCCD79EBFCAA1C0CAA3C1C9A5C0C7A7C2C7
AAC4C8AEC5C8AFC4C5AEC1C0B0C1BFB2C0BFADB9B8AEB7B6AFB3B2B0B1B0B1B1AFB3AFAD
B4ADAAB3A6A3B2A39FAC9D99A69490A08E899B8780978179947C7492786F90736A8E7065
8B6C618A6A5F896B60886C62866D64856E66856F6884716A84736D84756F847772847975
847B78847D7A847F7D848280
8788888A8D8D8D9192909697939A9C969EA099A3A59CA7AA9FACAFA1B0B4A4B4B9A7B9BE
AABEC4ADC2C9B0C7CEB2CBD3B4CFD8B7D4DDA6C7D2A0C1CBA2C1CBA5C3CBA7C2C8AAC4C9
ADC7CBB1C8CBB2C6C7B3C4C3AFBBBBADB6B6A9B1B0AEB2B1B0B1B0B2B2B1B4B3B2B4ADAB
B4ABA8B4A8A4B4A6A2AF9F9AA79591A18D889C8780988079957C7494797093756B907267
8E6D628C6A5D8A6A5E886B60866B61856C63846E6684706884726B83746E837671837874
847A77847D7A847F7D848180
8889888B8D8E8E9293919798949B9D98A0A29BA5A89EA9ADA1AEB2A3B3B7A6B8BDA9BCC2
ACC1C8B0C6CDB3CCD3B7D1D9B8D4DCB6D5DFA0C2CEA1C2CCA4C2CBA7C3CBA9C3C9ACC5CA
B0C8CDB4C8CBB3C5C5B3C1C0A9B4B5ABB5B5AEB5B5B0B5B4B2B6B6B5B7B6B7B7B5B6B2AF
B7B0ADB5ABA7B3A7A4AE9F9AA99893A18E899C8680987F79977C74967A7195776D937368
916F638F6B5E8C6A5F89695E86695F846A61846C64836E6783706983726D837570837773
837A76837C79847F7C848180
8889898B8E8E8F9394929899969D9F99A2A49CA7AA9FACAFA2B1B5A6B6BAA9BBC0ACC0C6
AFC5CBB3CAD2B7D1D9BED9E1BBD8E1ACCDD99DBFCBA2C2CCA6C4CCA9C4CBABC4CAAEC6CB
B2C8CCB2C4C7B0BEBFADB8B9A8B2B3ADB4B4B0B6B6B3B7B6B5BAB9B8BAB8B9BAB7B9B6B3
B9B2B0B7ABA8B5AAA5B1A29CAC9B95A3918B9B857F987F78987C74987B7298796E96756A
937064916C608D695C89685B84655C83685E836A61836C64826F6882716B83746E837672
837975837C79847E7C84817F
8889898C8F8F90949593999B979FA19BA4A79EA9ACA1AEB2A4B3B8A8B8BDABBDC3AEC3C9
B1C8CFB4CDD5BAD4DDC0DCE5B3D2DCA0C2CEA0C0CBA4C3CCA8C4CCABC4CAADC4CAB0C7CB
B3C7CBB3C3C6B0BCBEAFB9BAAFB7B7B1B6B6B3B6B6B4B7B7B7B8B8B9B8B8BAB7B6BAB3B2
BAAFADB8ABA8B5A9A4B2A29DAD9B96A6938D9C857F997E78997C749A7C739A7A6F98766B
967266946F62936D5F88655983635982655B82685F826A62826D6682706982736D827571
837874837B78837E7C84817F
888A898C8F90909596949B9C98A0A29CA6A8A0ABAEA3B1B4A7B6BBAABBC1ADC0C6B0C5CC
B2CAD2B5CFD8B8D4DDB5D4DFA8C9D49FC0CCA4C3CDA7C4CCAAC4CBADC4CAAFC4CAB2C6CA
B4C6CAB4C3C6B1BCBEB2BBBBB2B9BAB4B9B9B6B9B9B8BAB9BABCBABCBBBABDB9B7BDB6B3
BCB2AEBBADA9B7A8A3B3A09CAD9893A68F899E857F9A7E789B7D759C7D749C7C709B786C
987367977062966E5F83605381605580625880665C816960816C64816E6882726C827570
827873837B77837E7B84817F
898A8A8D9090919697969C9D9AA2A49EA8AAA2ADB1A5B3B7A9B9BDACBEC4AFC3CAB2C8D0
B4CDD5B6D1DAB6D5DFB2D2DDAECCD7AAC7D1A9C5CEABC5CCADC4CAAFC5CAB1C4C9B3C6CA
B5C6CAB5C4C6B5BFC1B4BCBDB5BBBBB7BBBBB9BCBBBBBCBBBDBDBCBFBDBCC0BCB9C0B8B5
BFB4B0BDAFAAB8A9A3B4A19CAE9993A9918AA389829E827B9D7F769E7F749E7D719D796C
9A7467997163996F5F825E517E5D517F60567F635A80675E806A62816D6681706A82746E
827773837A77837D7B84817F
898A8A8E9191929798979D9F9BA4A6A0AAADA4B0B3A8B6BAABBCC1AFC1C7B2C7CDB4CCD3
B6D0D9B7D4DEB7D6E1B6D4DEB3D0D9B0CBD3ADC7CFAEC5CCB0C5CAB2C5CAB4C5CAB5C6CA
B7C7CAB8C5C8B7C2C3B7BDBEB7BCBCB9BDBCBBBFBDBEBEBDC0BFBEC2C0BDC3BEBBC3BAB6
C1B5B0BEB0ABB9A9A3B4A19AAF9992AA928AA58B83A1847BA08278A18176A07E729E796D
9B75689A72639B7060815D507D5B507D5E537E61577E655C7F6860806C65806F6981736D
827672827976837D7A84807F
898B8A8E9192949899989FA09DA5A8A2ACAFA6B2B6AAB9BDAEBFC4B2C5CAB5CAD1B7CFD7
B9D4DDBAD8E2B9D8E2B9D6DFB6D1D9B2CAD2AFC8CFB1C6CCB2C5CBB4C6CBB6C7CBB7C7CB
B9C8CBBAC6C9BBC4C5BAC0C0BABDBDBCBEBDBEC0BEC0BFBEC2C0BEC5C2BEC5BFBBC5BBB7
C2B5B0C0B0ABBAA9A2B5A19AB09992AB928AA78C83A4867DA4857AA38277A17E729F7A6D
9C75689A72639A70618460537B594D7B5B507C5F557D63597E675E7F6A63806E6881726C
817571827975837D7A84807E
8A8B8B8F929295999A9AA0A29FA7AAA4AEB1A9B5B9ADBCC0B1C2C7B5C8CEB8CED5BBD4DB
BCD8E1BDDCE6BDDBE4BCD8E1B7CFD6B3CAD1B2C8CEB4C6CCB5C6CBB7C7CBB8C8CCBAC9CC
BBC9CBBCC7CABDC6C7BDC2C2BCBEBDBEC0BEC0C1BFC3C1BFC5C3C0C8C3C0C9C1BDC7BDB8
C5B6B1C1B1AABCA9A2B7A19AB19991AC938AA98D84A98A80A8877CA58478A38073A07B6E
9C7568987062936C5E8561537C584C78574C7A5C527C61577E655C7F69617F6D6680716B
817570827875837C7983807E
8A8B8B909393969B9B9CA2A3A1A9ABA7B1B3ACB8BBB1BFC3B5C6CBB9CCD2BCD2D9BFD8E0
C1DEE7C2E1EAC1DEE6BED6DEB8CCD3B5C9D0B5C7CEB6C7CDB7C7CCB9C9CDBBCACEBCCACD
BECACCBFC9CBBFC7C8BEC3C2BEC0BFC0C1BFC3C3C0C5C3C0C8C5C1CBC5C2CCC3BECABEB8
C7B8B2C3B1ABBFAAA2B8A299B29990AF948AAD9086AC8D82AB8A7EA8867AA48175A17C6F
9C7668967062906B5D8660527A54477452467A5A4F7C5F557D645B7E68607F6C6580706A
81746F827874827C7983807E
8B8C8C919494979C9D9EA4A5A4ACAEAAB3B6AFBBBEB4C2C6B9CACEBDD1D6C1D7DEC4DDE5
C6E3EBC7E3EBC4DDE4BED1D9B8CAD1B5C8CFB7C8CDB8C8CDBAC9CDBCCACEBDCBCFBFCCCF
C0CCCEC1CACCC1C8C8C1C4C4C1C2C0C3C2C0C5C4C0C7C4C0CAC6C2CDC6C2CEC4BECDBEB8
C9B8B2C4B1AABFAAA1B9A198B49A91B2968CB09388B09085AE8C80AA887BA68376A27D6F
9D7769977061916B5D8761527E56477B574A7B5A4F7C5F547D63597E675F7F6B647F6F69
80736E817773827B7983807E
8B8C8C929595999D9EA0A6A7A6AEB0ADB6B9B3BEC1B8C6CABECED2C3D5DBC7DCE3CAE3EB
CCE7EFCCE4EBC7DBE2BECFD6B7C8CFB7C8CEB8C8CDBAC9CEBCCBCFBECCD0C1CDD0C2CED0
C3CECFC4CBCCC3C9C9C3C5C4C3C3C1C4C3C1C7C4C1C9C5C1CCC7C3D0C7C2D1C4BFCEBFB8
CBB8B1C6B1A9C0A9A1BBA299B89D93B6998EB5968BB39387B18F82AD8A7DA98477A47E70
9F776A987162926C5D8A625382594A7E584B7C5A4E7C5E537D62587D665D7E6A637F6E68
80726D817773827B78837F7E
8C8D8C9396969B9F9FA2A8A9A9B0B2B0B9BBB7C2C4BDCACDC3D2D6C8DADFCDE2E8D2EAF1
D5EBF2D3E6ECC9DAE1BCCDD3B7C7CEB8C7CDB9C8CDBBCACFBECCD0C1CED1C4CFD1C5CFD0
C6CFCFC6CCCCC5C9C8C4C5C4C4C3C1C5C3C0C8C4C0CBC6C2CFC8C3D2C8C3D3C5BFD1C0B9
CDB9B1C8B2A9C3ABA2BFA59BBCA096BA9C91B9988DB69588B49083AF8B7EAB8577A68071
A0796A9A7364946E608C6355845D4E7E56487D594C7C5C517C60567D655C7D69617E6D67
7F726C807672827B78837F7D
8C8D8D9497979DA0A1A4AAAAACB3B4B4BCBEBBC5C8C2CED1C8D7DACEDFE3D4E7ECDAF0F6
DEEFF4D6E5EAC8D8DDB9C9D0B6C6CCB7C6CCB9C8CDBCCACEC0CDD0C4CFD1C7D0D1C8D1D1
C9D0D0C8CDCDC7C9C9C5C6C4C5C3C1C6C3BFC8C4C0CCC6C1D0C8C3D4C9C3D5C6BFD3C0B9
D0BAB2CBB3AAC7ADA3C4A89DC1A398BF9F93BC9B8FB9978AB69284B28D7FAE8779A88272
A37B6C9D75669770618E6556855D4E7D53447C574A7C5B4F7C5F557C635A7D68607E6C66
7F716C807571817A77837F7D
8D8E8D9698989EA2A2A7ACACB0B5B7B8BFC1C0C9CBC8D2D5CEDBDFD4E4E8DAECF1DFF2F7
E1EFF2D6E2E7C6D4DAB3C4CCB3C3C9B6C5CBB8C7CBBDC9CDC2CED0C7D0D2CBD3D4CDD3D3
CDD2D1CACECDC7C9C8C5C5C4C4C2C0C5C1BDC8C2BECDC5C0D2C8C2D6C9C3D7C6C0D5C1BA
D3BBB2CEB5ABCCAFA5C9ABA0C6A69AC2A195C09D90BB978AB89385B48E7FB08879AB8373
A57D6DA077679B7262906858845B4C7C51427B55477B594D7B5D537B62597C665F7D6B65
7E706B7F7571817A77837F7D
8E8E8E979998A0A3A3AAAEAEB3B8B9BCC3C4C5CDCFCED7D9D5E1E4DBE9EDE0F1F5E5F4F7
E8F2F4DAE3E6C3D1D6AEC0C8AFC0C7B3C2C8B7C4C9BCC8CCC2CCCEC7D0D0CCD2D2D0D3D1
CFD1CFCACCCCC5C6C6C4C4C2C3C0BEC2BCB9C7BFBBCCC3BED2C7C2D7C9C3D9C7C0D8C2BA
D6BEB3D2B7ACCFB1A6CDADA1C9A99CC6A496C39F91BD988BB99485B68F80B28A7AAE8474
A87E6EA378689D73638F66568158497A4E3E79524579574B795B517A60577A655D7C6A63
7D6F6A7F7470807976827E7D
8E8F8E989A99A2A5A5ACB0B0B7BBBBC1C6C7CBD2D3D5DDDEDEE7E9E4F0F2E7F5F8E8F4F6
E9EFF1D5DEE2BECCD2A8BBC3ACBDC4B0C0C5B5C2C6BAC6C9BFC9CBC5CDCDC7CDCDCCCFCE
CACDCBC3C6C6BFC0BFBCBDBCBBB8B6BDB6B3C5BCB7CCC1BCD3C7C1D8C9C2DBC8C0DBC4BB
DBC2B6D5B8ACD5B5A9D4B2A4D0AD9FCAA598C59F92BE998BBB9486B79080B48B7BAF8574
AA806FA67B6AA074638F6555805546774B3C775043775549775A4F785E5579635C7A6962
7C6E687E736F807976827E7C
8F8F8F999A9AA4A6A6AFB1B1BABDBEC5CACAD1D6D7DDE3E4E9F0F1F3FCFDECF7FAEAF2F4
E7ECEDD5DCDFBBC9CFA4B7BFA8BAC1ADBDC2B3C0C4B8C3C6BDC6C7C2C9C9C4C9C9C7CACA
C1C5C5BBBFC0B8BABAB6B7B6B8B5B3BEB6B2C5BAB5CCC1BBD3C7C1D9CAC2DCC8C0DCC4BA
DBC0B4D6B7AADAB7A9DBB6A6D1AD9FCAA597C7A192BF9A8BBB9586B78F80B58B7AB18674
AD8170AB7D6BA375638F64547D5344754A3B754F4175534775584D765C5477625A796761
7B6D677D726E7F7875827E7C
8F8F8F9B9B9AA6A7A7B1B3B3BDC0BFCACDCDD7DADAE5E9E9F7FBFBFAFFFFEEF5F7EBEFF0
E6E9E9D1D8DBB6C5CC9FB3BCA5B6BDAABABFB1BFC2B6C1C3BAC2C3BFC5C5C2C6C6C3C6C5
C1C3C2BDBFBEB9B9B8B7B5B4BAB5B2BFB6B2C5BAB5CDC1BAD4C7C0DAC8C0DCC7BFDCC3B9
DABEB3D7B7ABD7B6A8D8B4A5CAA99BC7A395C39E90B99688B69183B58C7CB68A79B48775
B18371B1806DA374628D635379534473483A724C3F72514572554B735A5275605877655F
796B667C716D7E7774817E7C
908F8F9B9B9BA7A8A7B3B4B4C0C1C1CDCFCFDBDDDDEBEDEDFDFFFEF7F9F9EFF2F3E5E8EA
DDE1E2C6D1D5B0C0C79BB0B9A1B3BAA7B6BBADBABDB3BCBFB9C0C1BDC2C2C1C4C4C3C5C3
C2C2C1BFBEBCBCBAB8BBB7B5BBB4B1C0B6B2C6BBB5CEC1BBD5C6BFDAC7BFDDC8BEDDC4B9
DBBEB2D8B8ABD7B5A7D3AFA1C6A699C3A093BE9B8DB69385B69081B88D7CB88B79B78875
B68572B5826EA173608961517651436F45376E493D6E4E426F524970584F725E5674645D
776A657A706C7D7774817D7B
90908F9C9C9BA9A9A8B5B6B5C2C3C2D0D1D0DEDFDEEEEFEEFFFFFEF8F8F8EFF0F0E3E5E7
D4DADDC0CBD0ABBCC29AAEB69EAFB6A4B2B7AAB5B8AFB8BAB4BABBB8BCBCBCBDBCBABCBB
BABABAB8B7B6B8B5B4B8B3B1BAB2AFC1B7B2C8BCB6CFC2BBD5C5BDDAC7BDDDC7BCDFC5B9
DEC0B3DAB9ACD7B5A7D2AFA1CCA89AC7A294C19B8DBC9686BC9382BC907DBC8D7ABB8B77
BC8874B8836E9F715F835D4E7651436C43356A463A694A3F6A4F466C554D6F5B5472625C
756863796F6B7C7673807D7B
91908F9D9D9CA9AAA9B6B6B5C4C4C3D1D1D0E0E0DFEFEFEEFFFEFDF8F7F6ECEDEDDFE2E3
D0D7D9BCC8CDA8B9BF99ADB59BACB3A1AFB3A7B2B4ACB4B6B1B6B7B4B7B7B6B6B6B5B5B5
B7B5B4B7B4B2B8B4B1B9B3B0BEB5B2C4BAB4CBBFB9D0C3BBD6C4BCDAC5BCDCC5BADEC2B7
DEBFB2DCBAACDAB7A8D4B0A1CFAA9ACBA495C79F8FC39A89C29684C09380BF8F7BBF8D78
C28C76B7826C9C6F5C825D4E7953446E463864423663463B654B4267524A6B58526F5F5A
736662776E6A7B7572807C7B
91908F9D9D9CAAAAA9B7B6B5C5C4C3D2D2D0E1E0DEF0EEEDFFFDFBF7F5F4EBEBEBDCE0E1
CDD4D7B8C5CAA7B7BE98ACB499AAB09EACB0A4AFB1AAB1B2AEB3B3B2B4B4B5B5B4B7B6B4
B9B6B5BAB6B4BCB7B5BFB9B5C3BBB6C7BDB8CDC1BBD2C4BCD6C5BCD9C5BADBC3B8DCC1B5
DDBEB0D9B8ABD7B4A6D4AFA0D3AB9CCFA796CCA290C89D8BC59986C2937FC1907CC48F7A
C58D76B47F6A9B6D5B865F4F77524369433657382D5B40365E473E624E4767554F6B5D58
706560756C697A74727F7C7A
91908F9E9D9CABAAA9B8B7B6C5C4C3D3D1D0E1DFDEF0EDECFEFCFAF5F3F2EBEAEADBDFE0
CBD2D5B8C4C8A8B7BD9AADB499A9AF9DA9AEA2ACAFA8AFB0ADB1B1B1B3B2B5B5B3B8B6B4
BAB8B6BDB9B6C0BBB8C3BDB9C7BFBACBC1BBD0C3BCD4C6BDD7C5BCDAC5BADBC3B7DDC1B4
DDBEB1DBBAACD9B5A7D4AFA0D0A99ACCA494CAA08FC69B89C59784C4947FC6927DC8907A
C58C75B07C689A6B59855C4D714D3F603E324F3229533A3158423A5D4A4362524C685A55
6D635F736B687973717F7C7A
91908F9E9D9CABAAA8B8B7B5C5C4C2D3D1CFE1DFDDEFEDEBFEFBF9F5F2F1EAE9E9DBDEDF
CBD2D4BAC5C8ABB9BE9EAEB599A9AE9BA8ACA1AAADA7ADAEACAFAFB1B2B1B5B5B3B9B7B5
BDB9B7C0BCB9C3BEBBC7C0BCCBC2BDCFC4BED3C6BFD7C8BFD9C6BCDBC5BADCC4B8DEC2B5
DEBFB1DDBBADDAB6A7D7B1A1D2AB9BCFA695CBA08EC99C89C99985C99682CA947FCB917B
C38A73AD79659668568159496B493C573A304830264A342C503D365746405D4F4A645853
6B615D716A677872707E7B7A
91908F9E9D9CABA9A8B8B6B5C5C3C2D3D0CFE1DEDCEFECE9FDFAF7F4F0EEE9E8E6DBDDDE
CDD2D4BDC6C9AFBABFA1B0B59AA9AF9AA6AA9FA9ABA6ACACACAEAEB1B1B0B6B5B3BBB8B5
BFBBB8C3BEBBC7C1BDCAC3BECEC5C0D2C7C0D6C9C1D9C9BFDBC8BDDDC6BBDEC5B8DFC2B5
E0BFB1DFBCADDDB7A7DAB2A1D7AD9CD4A997D2A491D0A08CCF9C87CF9984CF9680CD927B
BF8670A875619164537B55466545394F362C402B233F2C2548373151423C594C47615651
685F5C6F686676726F7D7B79
91908F9E9C9BAAA9A8B7B6B4C5C2C1D2CFCDE0DDDBEEEAE8FCF8F5F2EFECE8E6E5DBDDDC
CED2D3BFC7C9B1BBBFA3B1B59CAAAF98A5A99FA7AAA6ABABACAEAEB2B2B0B8B6B3BDB9B6
C1BCB9C6C0BCCAC3BECEC5C0D2C8C2D6CAC2D9CBC2DBCAC0DDC9BEDFC7BBE0C5B8E1C3B5
E1C0B1E1BCADDFB8A7DCB3A2DAAF9DD8AB98D7A693D5A38ED39E89D29B85D29780CA8F78
B7806BA1705D8A5F4F734F425B3F33452F2736241D35241E41322C4B3E395549455D5350
665E5A6D676575716F7D7A79
91908F9D9C9BAAA8A7B7B5B3C4C1BFD1CECCDFDBD9EDE9E6FBF6F3F2EDEAE7E4E3DCDCDB
D0D3D3C3C8CAB3BCBFA6B2B79DABB099A6AA9FA7A9A7AAABADAFAEB4B3B1BAB6B4BFBAB7
C4BEBAC9C2BECDC5C0D1C8C2D5CAC4D9CCC4DCCDC3DECCC1E0CABFE1C8BBE2C6B8E2C4B5
E3C0B1E2BDACE1B9A8DFB5A3DEB09EDCAC99DAA994D9A48FD7A08AD69C85D1967FC48B74
B07B66996A5880594A68483C50372D3A28212819142D1F1B3B2E2A473B375147435B524E
635C596C666474706E7C7A79
91908F9D9B9AA9A7A6B6B4B2C3C0BED0CDCADEDAD7ECE7E4FAF4F1F0ECE9E6E3E2DCDCDB
D2D4D3C5C8C9B6BEC0ABB4B8A1ADB09EA9ABA1A7A9A8ABABAFAFAEB6B3B1BCB8B4C2BCB8
C7C0BCCCC4BFD1C8C3D5CAC4D9CDC6DCCEC6DFCFC5E1CDC2E2CBBFE3C9BBE4C6B8E4C4B4
E4C0B0E4BDACE3BAA8E1B5A3E0B19EDEAD99DDA994DCA58FDAA18AD69B84CD927BBC846F
A774618E63527652445E403546302730211A20130F2C201C382D294439364E454258514E
625B596B666473706E7C7A79
908F8E9C9B9AA9A7A5B5B2B1C2BEBCCFCBC8DCD8D5EAE5E1F9F2EFEEEAE7E6E2E0DCDBD9
D3D3D2C7C9CABBC0C1B0B7B9A6AFB2A4ACAEA5AAABAAACACB1B1AFB8B5B2BFBAB6C5BEBA
CAC3BED0C7C1D4CBC4D9CDC6DDCFC7DFD0C6E2D0C5E4CEC3E4CCBFE5C9BCE5C6B7E5C3B4
E6C0B0E5BDACE4BAA7E3B5A3E2B29EE1AE99E0AA94DEA58FDAA08AD49981C88D77B37E69
9C6D5A835B4B6C4B3D543A2F3A28202419141A100C291F1B362C294139354C454257504D
605B586A656373706E7C7A79
908F8E9C9A99A8A5A4B4B1AFC0BDBACDC9C6DAD5D2E7E2DEF6EFECEDE8E5E5E0DEDCD9D8
D4D3D2CACBCBBFC2C2B5BABBAEB3B5ABB1B2A8ADADADADADB4B2B0BBB7B4C2BCB8C8C1BC
CEC5BFD4C9C3D8CCC5DDCFC7E0D1C8E3D2C7E5D2C6E6CFC2E6CCBEE6C9BBE6C6B7E7C4B3
E7C0AFE6BDABE5B9A7E5B5A2E3B29DE2AD99E2A994DEA58ED99E87CE947DBD8671A77562
8F64537753455F42374631282C1E19160D09180F0C271E1B342C294038364B444255504D
5F5B58696563726F6E7B7A79
908E8D9B9998A6A4A2B2AFADBEBAB8CAC6C3D7D2CFE4DEDBF2EBE7EDE6E3E4DFDCDCD9D7
D6D3D2CDCCCAC3C4C3BBBDBCB5B8B8B1B4B4ADB0B0B1B0AFB8B4B2BFBAB6C6BEB9CCC3BD
D3C7C0D8CBC3DDCEC5E1D0C7E5D3C8E7D3C8E8D2C5E9CFC2E8CCBDE8C9BAE7C6B6E8C3B3
E8BFAEE7BCAAE6B8A5E5B4A1E4B19CE3AC97E1A892DCA38CD49982C58C77B27D699A6C5A
825B4C6B4B3E533A303928212117121008061B131127201D332C2A3F39364A444255504E
5F5B5969656472706E7B7A79
8F8E8D9A9897A5A3A1B0ADABBBB8B5C7C3C0D3CECBE0DAD6EEE7E3EBE4E0E4DEDBDDD8D5
D7D3D0D0CDCAC7C5C4BFBEBDB9BAB9B6B7B6B4B4B3B6B3B1BCB7B3C3BDB8CAC1BBD1C6BE
D7C9C1DDCDC4E1D0C6E5D2C7E9D5C9EBD5C8EBD2C5EBCFC1E9CBBCE9C8B8E8C5B5E8C2B1
E8BEADE7BBA8E7B7A4E5B39FE4AF9AE2AB95DEA58FD79E87CB927CB8836FA374618C6353
7552455F42374531282B1E19170F0D0B06041A141227211F332E2B3F3A384A454355504F
5F5B5968666472706E7B7A79
8F8D8C999796A3A19FAEABA9B9B5B3C4BFBDCFCAC7DBD5D1E7E0DCE9E2DEE4DDD9DED8D4
D6D1CFD1CDCAC9C6C4C1BFBDBDBBBABAB9B7BAB7B5BBB6B3C1BBB6C7BFB9CEC2BBD6C8BF
DCCBC2E1CFC4E5D1C6E9D3C7EDD5C8F0D6C8EED2C4ECCEBFEACABAE9C6B6E8C4B3E8C0AF
E7BDABE6B9A6E5B5A1E4B19CE1AC97DEA792D7A08ACE9680BD8874A97966946A597D594A
66483D4F382E3526201E15120B06040A06041A1514282321342F2D403B394B4645555150
5F5C5A69666572706F7B7A79
8E8D8C989695A29F9EACA9A7B6B2B0C0BCB9CBC5C2D5CFCCE0D9D5E8E0DCE4DCD8DDD6D3
D7D1CED2CCC9CBC7C3C3C0BDC0BCBABDB9B6BEB9B6BEB9B5C3BCB6C8BFB9D1C3BCDBC9BF
E1CDC2E5D0C5E8D1C5ECD3C6F0D5C7F1D4C5EED0C1EBCBBCEAC8B8E8C4B4E7C1B0E7BDAC
E7BAA8E4B6A3E2B19DE0AD98DCA893D6A18CCD9782C08B77AE7E6B9A6F5E845F506D4E42
563E343E2D26261C18120D0B0301000F0C0A1D1917292524353230413D3C4C4847565351
605D5C69676672716F7B7A79
8D8C8B979594A09E9CA9A6A4B3AFADBCB8B5C6C1BED0CAC6DAD3CFE4DCD8E3DBD6DCD4D1
D7CFCCD1CBC8CCC6C3C4BFBDC0BBB8BFBAB6C0BAB6C2BAB6C4BCB6CABFB8D3C3BBDBC8BD
E0CBC0E3CDC1E7CEC1EBD0C2EED1C2EDCFC0EBCBBCE8C7B8E7C4B3E5BFAFE4BCABE4BAA8
E2B6A3DFB19EDCAB98D8A793D2A08CCB9884BE8C79B0806E9C72628863547354475C4339
44322B2D221D19131007060402010012100F201D1C2C2928383433433F3E4D4A49575453
605E5D6A68677371707B7B7A
8D8C8B9594929E9C9AA7A4A2B0ACAAB8B4B1C1BCB9CAC4C1D3CDC9DDD5D0E1D9D5DBD3CF
D6CECBD0C9C6CBC4C1C3BEBBC1BBB8C1BBB7C3BBB7C5BCB7C7BDB7CCC0B8D3C3BAD9C6BB
DDC8BCDFC8BCE3C9BDE5C9BBE7CABBE7C8BAE5C6B7E4C2B2E1BEAEDFBAAADEB7A6DDB3A2
DAAF9DD7AB98D2A491CD9E8BC59684BC8D7BAD81719E75658A675876584B61483E4A3730
3226211E18150E0B090000000806061715142421202F2D2C3B38374542414F4D4B585655
62605F6B69687372717C7B7A
8C8B8A9493919C9A98A4A19FACA9A7B4B0AEBDB8B5C5BFBCCDC7C3D5CECADDD4D0DBD2CE
D4CCC8CEC7C3CAC3BFC5BEBAC4BCB8C3BBB6C5BCB7C5BBB6C7BCB6CDBEB6D2C0B7D6C1B7
D8C3B7D8C2B6DDC4B7DDC2B5DFC3B5DEC1B3DDBEB0DBBAABD7B6A7D4B1A2D2AE9ED1AA9A
CDA695C9A08FC29989BD9382B48A7BA981729A75678A695B775B4F644C424F3C35382C26
211B18120F0E020101030303100F0F1D1B1B2827263432313E3C3B484645514F4E5A5957
6361606C6A697473727C7B7A
8C8B899391909A9896A29F9DA9A6A3B0ACAAB8B3B0BFBAB7C6C0BDCEC7C3D6CECAD9D1CD
D2CAC6CDC5C1C9C1BDC6BDB9C3BBB7C1B9B4C5BBB5C5BAB4C7BBB4CDBDB4CEBDB3D1BDB3
D3BEB2D3BDB2D6BEB2D5BCB0D6BBAED5B9ACD3B5A8CFB1A4CBAD9FC8A99BC6A597C3A192
BE9B8DB89587B28F80AC887AA38072967568876A5E775D52654F4751403A3C302C27211E
1512110504040203030E0E0E1918182422222E2D2C38373642403F4B49495452515D5B5A
6563636D6C6B7574737D7C7B
8B8A8992908F9896959F9C9AA6A2A0ACA8A6B3AEACB9B4B1C0BAB7C7C0BDCDC6C2D4CBC8
D0C6C3CBC2BEC7BFBBC3BBB7C1B8B4C1B8B3C3B9B3C4B9B2C5B8B1C9B9B0C9B8AECBB8AE
CCB8ADCCB7ADCDB7ABCDB5AACCB3A7C9B0A4C6ACA0C3A99DBEA497BBA093B69B8EB3968A
AD9084A78A7EA284789C7E7292756A846A60765F5565524A53443E4036312D27251B1917
0809080404050E0E0E1717172120202B2A293433333E3C3C4645444F4D4D5756555F5E5D
6766656E6D6C7675747D7C7B
8A8988908F8E9694939C9A98A29F9DA8A5A2AEAAA7B4AFACBAB4B1BFB9B6C5BEBAC9C2BE
CAC2BEC8BFBBC4BCB8C1B8B4BFB6B1BDB4AFBFB5AFC0B5AEC0B3ACC3B4ACC2B2AAC4B2A9
C3B1A8C4B0A6C3AFA4C2ADA2C0AAA0BDA79CB9A399B6A095B09A90AC968CA69086A38C81
9C867C978077927B718B746B806A62725F5863534D534742423A36312D2A201F1E0F1111
0607070F0F0F1818182120202929293231313B3A394342414B4A495352515B5959626160
696867706F6E7776757E7D7C
8A89888F8E8C9493919A97969F9C9AA4A19FA9A6A3AEAAA7B3AEACB8B2AFBCB6B3C0B9B6
C3BBB8C3BBB7C0B8B4BEB5B1BAB2AEB9B0ABB9B0AABAAFAABAAEA7BCAEA6BBACA4BAABA2
BAAAA1B9A89FB7A69DB5A49AB4A298B09E95AC9A91A8978EA392899E8C8498867E938178
8C7B7489787084726B7B6A636F605B625651544A46443E3B3532302626251719190C0D0E
0F0F0F1919192221212A29293231313A3939414140494847504F4F5756565E5D5C656463
6B6A6A7271707877767E7D7D
8988878E8C8B92918F9795939C9997A09D9BA5A19FA9A5A3ADA9A6B1ACA9B5AFACB8B2AE
BAB4B0BCB5B1BCB5B1B9B2AEB7AFAAB5ACA7B3AAA5B3A9A4B2A8A2B3A7A0B2A59EB0A39C
B0A29AAD9F98AC9E96AB9C94A89991A4958EA0928A9B8D8697898291847D8A7E77857973
8075707D716C776B666C615D63595657504C4844413937362C2C2C1F2121121415131314
1C1C1C2424242C2C2B3333333B3A3A4241404848474F4E4E5655545C5B5A626160686766
6E6D6C7473727978787F7E7D
8888878C8B8A918F8E9593919996959D9A98A09D9BA4A09EA8A4A1ABA6A4AEA9A6B0ABA8
B2ACA9B4AEAAB6AFABB6AEABB2AAA6AFA7A2ACA49FABA39EABA19CABA09AA99E98A59A94
A39892A29790A1958E9F938C9C918A988D87948A848F85808B827D867D788078737C7470
77706D776E6A706764665E5C5C56534F4B49403F3E3233332528281C1E1E1A1A1B222222
292929302F2F3636363D3D3C4343424949484F4F4E5555545B5A5A61605F6665646B6A6A
70706F7575747A7A797F7F7E
8887868B8A898F8D8C92908F9693929996959C99979F9C9AA29E9CA5A19EA7A3A0A9A4A2
ABA6A3ACA7A4AEA8A4AEA8A4ADA6A2AAA39EA69F9AA39C97A29A95A299949F97919C948E
9A928C978F8A968D87948C869189848D868089827E847E7A817B787B7774797471716E6C
706C696D686664605F5C5957514F4E4545453A3B3B2D30312326262424242929292F2F2F
3535353B3B3B4141414746464C4C4B5251515756565C5B5A61605F6565646A69696F6E6D
7372727777767C7B7A807F7F
8786858A89888D8C8A908E8D93918F9593929895949A98969D9A989F9B99A19D9BA29E9C
A49F9DA5A09DA6A19EA6A09DA69F9CA19B979F99959D97929C959099928D958F8A918B87
8E88848E88838D868289847F85817D84807C817D7A7D7A787A77747674737471706C6B6B
6B6A686664645F5E5D5756554C4D4D4244443C3D3D2E30302E2F2E3434343838383D3D3D
4242424747474C4C4B5150505555545A59595E5E5D6262616666656A6A696E6E6D727171
7675747979787D7D7C81807F
8786858988878B8A898D8C8B908E8D92908E9492909693929895939996959B98969C9997
9D99979E9A989E9A979E9A979D99959C979399949197928E938E8A908A868C88848A8682
88848187838084807D827F7C817F7D817F7C7D7B797A7978787675757474706F6F6C6C6B
6768686263635C5C5C5454544D4E4E4546463F3E3E393A3A3F403F4444434847474C4B4B
504F4F5353535757565B5B5A5F5E5E6262616665646968686C6C6B6F6F6E737271767574
7978777C7B7A7E7E7D818180
8685848887868988878B8A898D8B8A8E8D8B908E8D918F8E93918F949290959291969391
97949297949297949297949196939095918F938F8D918D8A8A868487848086848183817F
817F7C817F7C807F7C807F7C807E7C7D7C7A7A79787978777474747272726E6F6F6B6C6C
6768686363625F5E5D5555555150504C4C4C4B4A4B4E4E4E5151505454535757565A5959
5D5C5C605F5F6262626565646867676B6A696D6D6C706F6E727271757473777676797978
7B7B7A7E7D7C807F7F828281
8584848785858887868988878A89888B8A898C8B898D8B8A8E8C8B8F8D8C8F8D8C908E8C
908E8D918E8D918E8D918E8C908D8C8F8C8A8E8B898C89878986848784828482817E7D7C
7E7C7B7F7E7C7E7D7B7F7D7B7F7D7B7D7B7A7C7A7A7A7978777676757575727272707070
6D6C6C6464646161615D5D5D5E5D5D5F5E5E5F5F5E606060626261646463666665686867
6A69696C6B6B6E6D6D706F6E7171707373727574747776757878777A79787B7B7A7D7C7C
7E7E7D807F7F818180838282
8584838585848685848686858786858887868887868988878988878988878A89878A8988
8A89888A89888A89888A89888A89878A8887898786888685878584858483848381828180
81807F81817F81807F81807F807F7E7C7C7C7B7B7B7A7A79787878777777767676747474
7272716F6F6E727171717170717170727171727171727271737372747473757574767675
7777767878777978787A79797B7A7A7C7B7A7D7C7B7D7D7C7E7E7D7F7E7E807F7E81807F
818180828281838281848382
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?ooo`B4Q8<4QHB428F5Q0B5QHD3QHJ518J6Q@R6QXH4QXN61hJ7
Q`B7R8L8QhR838N9R@N7RXX4QhZ;18N;R`B7S8`4R8f?18N;R`>7RXX4QhZ918N:RPB8RHT8R8Z90hV:
RPB9RhX4RHZ:18Z;RPR9RXT4RHR70hV8QPB8QXD4QhF418N5P`B6Q884QX>10hF1P0B4P7d4Pgil189l
N@B0NGD4PWej18=oO@>3P7h4Q85o28B1P0B4PX07Q8:118B3P@b4Ph84Q8>318B4PaGoool001Coool4
Q8B318F4Q0R5QH@4QHF50hF6Q@B6QXD8QXJ618J7QPN6QhL4QhR728N8R0b7RHT7QhZ:18N:R`B7Rh/4
Qhb<18R=S`B7Rh/3QhZ:18N:R@B7RXX4R8V928R:R@>9RXX4RH^:18V:RPB:RhX8RHZ918V8Q`>9R8H4
R8J518N5Q0B7QH<4QXB218J3P@>5PH04Q81m18=nO0B2O7T4P7Ue189mNPB3Ogd3Ph1n18B1O`R4PH04
Q8:01hB2P@B4Ph4<Q8>218B3P`B4Q8<Eoooo000Doooo18B4P`B5Q8@8QHF418F5Q@>5QXD4QXJ528J6
QPB6QhH7QXN718N8Q`R7R8P<QhV91hN:RPB7RX/4Qh^;18N<S0B8SHl4Qh^;0hN:RPB7RXT4QhZ:18R9
R@R8RXT3RHZ:18V;RPB9RXX4RX^:28V:R@B9R8L3RHR618R6Q@B7QH@4QhF318J4PPB6Ph43QH6018B0
O@B3OW`4PWai181iM@B2OGX4Pgmm0h>0OPB4PGl8Q86018B2P0N4PX44Q8>138B3PPB4Ph<4Q8B35Ooo
o`005?ooo`B5Q8@4QHF518F6Q@B6QXH4QXN60hJ7Q`B7R8P4QhV818R9R@R8RXX3RH^;18V<S0B9S8d4
RXf=18Z>SPB:SXl4RXn?0hZ?T0B;T944Ri6B18^BT`B;TiD4RiBG18ZBT`>:TI44RY2@18^@T0B;Shl4
S8n?18b@T0>=TI04SI6A18fAT0B>TI04SY2>18f?S@B=SH/3S8^918^9Q`B:QhD4RHF318R4P@B7PWl3
QWml18AlN0B2N7@4P7A_17ibK@B0Mg<4PWYg0h9lN@B3OW/4Pgml18AoO@B4P7h7Q85o18B2P0R4PX48
Q8>218B3PaGoool001Coool4QHB418F5Q@B5QXD4QXJ618J7QP>6QhL4QhR818N9R0B8RHT8R8Z:0hV;
R`B9S8`4RHb=18Z=S@B:SXh4RXj?18Z?S`>:Si04Ri2A18^ATPB;TY<4Ri>E18^DU`B:TY<3RY6A18Z@
T0B;T904Rhn?18b?S`B<T903SI6@18fAT@B=TI04SY6@18j@SPB=Shd4SHf;0hb;R@B;RHL4RXN518V5
P`B8Q844Qh9o0hIoO0B4O7P4PWQd181dK`AnLVd4P7Mc189jM`>2O7T4Pgik18=oO0B4Ogd4Q81n1hB1
O`B4PX08Q8:128B3PPB4Ph<Eoooo000Doooo18F4Q0B5QHD4QHJ518J6QPB6QhH3QXN718N8R0B7RHP4
R8V928R:RP>9Rh/4RHb<18V<S@B:SHd4RXj>18Z>S`B:Shl3RXn@18^@T@B;TI84Ri:C18^CU@B;U9L4
RY:C0hZAT@B:T904Ri2@18^?S`B<Shl4S92@0hfAT0B=TI44SI6@18jAT0B>T8h4SHn=18f=R`><RhT4
RhV718Z7Q@B9QH<4R8B118N2O`>6Og`4Q7ah189hM0B0M6l4OW9]181gL`B2NWL3PWai18=nN`B3Og`4
Q7mm18B0OPN4PGl4Q8:028B2P@R4Ph84Q8>35Oooo`005?ooo`B5Q8@4QHF518F6Q@B6QXH4QXN60hJ7
Q`B7R8P4QhV818R9R@R8RXX3RH^;18V<S0B9S8d4RXf=18Z>SPB:SXl4RXn?0hZ?T0B;T944Ri6B18^B
T`B;TiD4RiBG18ZBT`>:TI44RY2@18^@T0B;Shl4S8n?18b@T0>=TI04SI6A18fAT0B>TI04SY2>18f?
S@B=SH/3S8^918^9Q`B:QhD4RHF318R4P@B7PWl3QWml18AlN0B2N7@4P7A_17ibK@B0Mg<4PWYg0h9l
N@B3OW/4Pgml18AoO@B4P7h7Q85o18B2P0R4PX48Q8>218B3PaGoool001Coool4QHF418F6Q@B6QhH4
QhN718N8R0>8RHT4R8Z:18V;R`B9S8`4RXf=18Z=SP>;SXl4Rhn@18b@T@B<TI84SI:C18fCU0B=U9H3
SYFG18jFV0B>UiT4SYRK18jIW@B>Vil4SIRK0hfGV0B=UIH8SYFE18nEU@B@UYH3TIJE192FU@BAUYD4
TIFD196CTPB@TY04Shn=0hn>R`B>RhT4SHV618^6P`B:Ph04R81m0hIlN0B4N7@4PGA^17e^I`AmKfT4
OgA_185gL`>2NGH4Pg]h18=lN@B3OW/4Q7il18AoO@>4P7h4Q81o18B1O`B4PX04Q8:128B3PQGoool0
01Coool4QHF418F6Q@B6QhH4QhN718N8R0>8RHT4R8Z:18V;R`B9S8`4RXf=18Z=SP>;SXl4Rhn@18b@
T@B<TI84SI:C18fCU0B=U9H3SYFG18jFV0B>UiT4SYRK18jIW@B>Vil4SIRK0hfGV0B=UIH8SYFE18nE
U@B@UYH3TIJE192FU@BAUYD4TIFD196CTPB@TY04Shn=0hn>R`B>RhT4SHV618^6P`B:Ph04R81m0hIl
N0B4N7@4PGA^17e^I`AmKfT4OgA_185gL`>2NGH4Pg]h18=lN@B3OW/4Q7il18AoO@>4P7h4Q81o18B1
O`B4PX04Q8:128B3PQGoool001Coool4QHF418F6Q@B6QhH4QhN718N8R0>8RHT4R8Z:18V;R`B9S8`4
RXf=18Z=SP>;SXl4Rhn@18b@T@B<TI84SI:C18fCU0B=U9H3SYFG18jFV0B>UiT4SYRK18jIW@B>Vil4
SIRK0hfGV0B=UIH8SYFE18nEU@B@UYH3TIJE192FU@BAUYD4TIFD196CTPB@TY04Shn=0hn>R`B>RhT4
SHV618^6P`B:Ph04R81m0hIlN0B4N7@4PGA^17e^I`AmKfT4OgA_185gL`>2NGH4Pg]h18=lN@B3OW/4
Q7il18AoO@>4P7h4Q81o18B1O`B4PX04Q8:128B3PQGoool001Coool4QHF418F6Q@B6QhH4QhN718N8
R0>8RHT4R8Z:18V;R`B9S8`4RXf=18Z=SP>;SXl4Rhn@18b@T@B<TI84SI:C18fCU0B=U9H3SYFG18jF
V0B>UiT4SYRK18jIW@B>Vil4SIRK0hfGV0B=UIH8SYFE18nEU@B@UYH3TIJE192FU@BAUYD4TIFD196C
TPB@TY04Shn=0hn>R`B>RhT4SHV618^6P`B:Ph04R81m0hIlN0B4N7@4PGA^17e^I`AmKfT4OgA_185g
L`>2NGH4Pg]h18=lN@B3OW/4Q7il18AoO@>4P7h4Q81o18B1O`B4PX04Q8:128B3PQGoool001Coool4
QHF418J6QPB7R8L4QhR818R9R@>9Rh/4RHb<18Z=SPB;SXl4S92@18b@T@>=TY<4SY>E18jEUPB?UYL4
SiNI192HVPB@VI`3TI^M196LW`BAWJ04TIjR196PY0BAXJH4T9jQ0i2LWPB@Vi`8TIZK19:JVPNCVYT4
TYZI19>IV0BDV9L4TiJE19:ETPBBTi03TI6>196=RPB?RXL4SHJ318^3O`B9OgX3QWYe18AfL0B0L6X4
OFYS17i^I`B0LF`4PGA_0h9gLPB2NGD4PgYg18=lN0B4OGX4Q7ik0hAoO0B4Ogd4Q81n18B1O`B4PX04
Q8:118B3PQGoool001Coool4QHF418J6QPB7R8L4QhR818R9R@>9Rh/4RHb<18Z=SPB;SXl4S92@18b@
T@>=TY<4SY>E18jEUPB?UYL4SiNI192HVPB@VI`3TI^M196LW`BAWJ04TIjR196PY0BAXJH4T9jQ0i2L
WPB@Vi`8TIZK19:JVPNCVYT4TYZI19>IV0BDV9L4TiJE19:ETPBBTi03TI6>196=RPB?RXL4SHJ318^3
O`B9OgX3QWYe18AfL0B0L6X4OFYS17i^I`B0LF`4PGA_0h9gLPB2NGD4PgYg18=lN0B4OGX4Q7ik0hAo
O0B4Ogd4Q81n18B1O`B4PX04Q8:118B3PQGoool001Coool4QHF418J6QPB7R8L4QhR818R9R@>9Rh/4
RHb<18Z=SPB;SXl4S92@18b@T@>=TY<4SY>E18jEUPB?UYL4SiNI192HVPB@VI`3TI^M196LW`BAWJ04
TIjR196PY0BAXJH4T9jQ0i2LWPB@Vi`8TIZK19:JVPNCVYT4TYZI19>IV0BDV9L4TiJE19:ETPBBTi03
TI6>196=RPB?RXL4SHJ318^3O`B9OgX3QWYe18AfL0B0L6X4OFYS17i^I`B0LF`4PGA_0h9gLPB2NGD4
PgYg18=lN0B4OGX4Q7ik0hAoO0B4Ogd4Q81n18B1O`B4PX04Q8:118B3PQGoool001Coool4QHF418J6
QPB7R8L4QhR818R9R@>9Rh/4RHb<18Z=SPB;SXl4S92@18b@T@>=TY<4SY>E18jEUPB?UYL4SiNI192H
VPB@VI`3TI^M196LW`BAWJ04TIjR196PY0BAXJH4T9jQ0i2LWPB@Vi`8TIZK19:JVPNCVYT4TYZI19>I
V0BDV9L4TiJE19:ETPBBTi03TI6>196=RPB?RXL4SHJ318^3O`B9OgX3QWYe18AfL0B0L6X4OFYS17i^
I`B0LF`4PGA_0h9gLPB2NGD4PgYg18=lN0B4OGX4Q7ik0hAoO0B4Ogd4Q81n18B1O`B4PX04Q8:118B3
PQGoool001Coool4QHF518J7QPB7R8P4R8V918V;R`>:S8d4Rhj?18b@T0B=TI84SY:D18jDU@>?UYL4
T9NI196IV`BBVYd4TYbN19>MX0BDWj83U:2T19BRYPBEXjP4U:FY19BVZ`BCYj`4Tj>W0i>QY0BCX:84
U9nP19BNW`BEWYh4UIfM0iJMW@BFWYd4UYfL19NLV`BFVYP4UINE19FET`>DTXl4Thn<196;R0B?QX84
SH=n18YnN@>7NG<4Q7=]181]IPAmJ604OfaU181`J@B1Lfd3PWE`18=gLPB3NG@4PgYf18AkN0B4O7T3
Q7ik18AoO0B4P7d4Q81o18B1P0B4PX44Q8>25Oooo`005?ooo`B5QHD4QXN618N8R0B8RHT4RH^;0hZ<
S@B;SXl4S92@18fATPB>TY@4SYBE0hnFU`B@UiT4TIVK19:JW@BBW9h4TifP19BOXP>DX:@4U::V19FS
Z0BDYJT4U:J[19>W[0BCXjL3Tj6T19>PXPBDWj04U9jO19FNWPBEWId3UYfM19JNW@BFWI`4UibK19JJ
V0BEUiD4UIFC0iBBS`BCSh`4TH^818n6PPB=Pgh4RWii0hMiL`B4Lfd4P6eV17eXH0AoK6D4P71Y185c
K@>2MG04PgMb18=iM0B3NWH4Q7]h18AlN@>4OW/4Q7ml18B0O@B4P7l4Q86018B2P@B4Ph8Eoooo000D
oooo18F5Q@B6QhH4QhR818R9R@B9Rh/3RXb=18^>S`B<T904SI6B18jBU0B>U9D3SiJG192GV@BAVI/4
TYZM19:LWPBCWJ04U9nR0iBPY0BDXZH4UJ>X19BUZ@BDYZ/4TjN/19>SY`>CXJ@4Tj2R19BOX0BDWYl4
UIjN19FMW@>FWId4UYjM19JMW0BGW9/4UYZH19FGU@BEUI<3U9:?19>?S0BARhP4ShJ218f3OPB:OWT3
QgUc18AcK@B0KFH4OFQP17m/I@B0L6T4PG=]0h9eL0B3Mg84PgUd18=jMPB4NgP4Q7ai0hAnN`B4Og`4
Q81m18B0O`B4PH04Q8:118B3PQGoool001Coool4QHF518J7QPB7R8P4R8V918V;R`>:S8d4Rhj?18b@
T0B=TI84SY:D18jDU@>?UYL4T9NI196IV`BBVYd4TYbN19>MX0BDWj83U:2T19BRYPBEXjP4U:FY19BV
Z`BCYj`4Tj>W0i>QY0BCX:84U9nP19BNW`BEWYh4UIfM0iJMW@BFWYd4UYfL19NLV`BFVYP4UINE19FE
T`>DTXl4Thn<196;R0B?QX84SH=n18YnN@>7NG<4Q7=]181]IPAmJ604OfaU181`J@B1Lfd3PWE`18=g
LPB3NG@4PgYf18AkN0B4O7T3Q7ik18AoO0B4P7d4Q81o18B1P0B4PX44Q8>25Oooo`005?ooo`B5QXD4
QhN718R9R@B9Rh/4RXb=0h^>S`B<T944SI:C18jDU@B?UIL4T9NI0i6IV`BBVid4TifO19BOXPBEXJ@4
UZ>V19NTZ0>HYZX4V:R]19RZ[`BHZk04Ujba19J//PBFZ:d3UZJY19JUY`BGXjD4Uj>S29RRXPNIXZ44
VJ6P19VOWPBIWI`4VI^I19RHUP>GUI84UY:>19B<R@BBQh@4Sh=n18anN@>8N784QG5Z181ZHPAnIel4
P6]T185_I`B2LF/3PWA^18=eL0B3Mg84PgUd18AjMPB4NgP3Q7ai18AnN`B4Og`4Q81n18B1O`B4PX04
Q8>25Oooo`005?ooo`B5QXD4QhN718R9R@B9Rh/4RXb=0h^>S`B<T944SI:C18jDU@B?UIL4T9NI0i6I
V`BBVid4TifO19BOXPBEXJ@4UZ>V19NTZ0>HYZX4V:R]19RZ[`BHZk04Ujba19J//PBFZ:d3UZJY19JU
Y`BGXjD4Uj>S29RRXPNIXZ44VJ6P19VOWPBIWI`4VI^I19RHUP>GUI84UY:>19B<R@BBQh@4Sh=n18an
N@>8N784QG5Z181ZHPAnIel4P6]T185_I`B2LF/3PWA^18=eL0B3Mg84PgUd18AjMPB4NgP3Q7ai18An
N`B4Og`4Q81n18B1O`B4PX04Q8>25Oooo`005?ooo`B5QXD4QhN718R9R@B9Rh/4RXb=0h^>S`B<T944
SI:C18jDU@B?UIL4T9NI0i6IV`BBVid4TifO19BOXPBEXJ@4UZ>V19NTZ0>HYZX4V:R]19RZ[`BHZk04
Ujba19J//PBFZ:d3UZJY19JUY`BGXjD4Uj>S29RRXPNIXZ44VJ6P19VOWPBIWI`4VI^I19RHUP>GUI84
UY:>19B<R@BBQh@4Sh=n18anN@>8N784QG5Z181ZHPAnIel4P6]T185_I`B2LF/3PWA^18=eL0B3Mg84
PgUd18AjMPB4NgP3Q7ai18AnN`B4Og`4Q81n18B1O`B4PX04Q8>25Oooo`005?ooo`B6QXD4QhR818R:
RPB:S8`4Rhj>0hb@T@B>TY<4SiBF192FV0BAV9X4Ti^M0iBMW`BEWj84UZ6T19NSY`BHYJT4VJR/19ZZ
[P>K[;44W:jd19fa]PBL/[P4Vk:i19R_]PBH[;43V:Z]19VYZ`BIZ:T4VZNW19^WY`BKYZH3W:JU19fV
Y@BMYJ@4WJBR19fRX0BLWi`4W9^I0i^HU0BIU904Uhj;19B9Q@BAPgl4SWii0hUgL@B5L6P4PFUO181X
G`B1Jf<4PViV189`J@>3LV`4PgA^18=fL@B4N7<4Q7Ue18AjMP>4NgP4Q7ej18AnO0B4Ogd4Q81n18B1
P0B4Ph4Eoooo000Doooo18J6Q@B7R8P4R8Z:18Z<S0B;SXh3S92A18jBT`B?U9H4T9JH196HVPBCVid3
U9fO19FOXPBFXJ@4Uj>W19RUZ@BIZ:`4VZZ^0i^//@BL[[@4WK6f19bb^0BK/[T4V:nf19R//@>HZZd4
VJV[19VXZ@BJYjL4VjNW19^VYP>LYZD4WJJU19fUY0BMY:84WJ:P19bOW0BLViT3ViRD19VDT0BGSX/4
U8V51963O`B>OWT3RGMa18E`J0B1JEl4P6QO185[H`B2KVH4PW1Y0h=bK0B3M6h4PgIa18AhL`B4NGD4
Q7Yf0hAkN0B4OGX4Q7il18AoO@B4P7h4Q86018B3PAGoool001Coool4QXJ518N8R0B8RXX4RXb<18^>
SP><T944SY:C18nDUPB@UYP4TIRJ19>KW@>DWIl4UInR19JQY0BGXjL4V:FY19VX[0BJZZh3Vjba19b^
]0BM/KH4W;:h19^b^@BH[kH4V:ba0iRZ[@BIZJ/4VJRY19ZWY`BKYjL4VjJV0ibVY@BMYZD4WJFT19fT
XPBMXZ04W9nL19bKV@>KV9@4VIB@19N>R`BDRHD4TH=o18inN@>9Mg44QG1X185YG`B0J5l4PF]S189^
IPB2L6T3Pg9/18=dKPB3MW44Q7Qc18AiM@B4NWH3Q7]h18AmNPB4OW`4Q7mm18B0OPB4PH04Q8>15Ooo
o`005?ooo`B6QXD4QhR818R:RPB:S8`4Rhj>0hb@T@B>TY<4SiBF192FV0BAV9X4Ti^M0iBMW`BEWj84
UZ6T19NSY`BHYJT4VJR/19ZZ[P>K[;44W:jd19fa]PBL/[P4Vk:i19R_]PBH[;43V:Z]19VYZ`BIZ:T4
VZNW19^WY`BKYZH3W:JU19fVY@BMYJ@4WJBR19fRX0BLWi`4W9^I0i^HU0BIU904Uhj;19B9Q@BAPgl4
SWii0hUgL@B5L6P4PFUO181XG`B1Jf<4PViV189`J@>3LV`4PgA^18=fL@B4N7<4Q7Ue18AjMP>4NgP4
Q7ej18AnO0B4Ogd4Q81n18B1P0B4Ph4Eoooo000Doooo18J6QPB7RHP4RH^;18Z=SPB<T903SI:C18nD
U@B@UiP4TYVK19>KWPBEWZ03UZ2S19NSYPBIYJT4VZR/19^Z[`BM[K84WZne0inb^0BP]K/4X[Rn1:Bk
`PBK]Kd4V;2f19V_/`>J[[44Vjf_19b/[@BMZj`4WZ^[19n[Z`>OZjX4X:^Z1:2ZZ@BQZ:L4XJJT1:6S
X0BPWi`3WYZG19fFTPBJT8d4UhZ619>4O`B?OWP3RgM`18M`J0B2J5l4PVUP189[H`B3KFH4PfmX0h=a
J`B4Lfd4Q7E_18AfL@B4N7<4Q7Ue0hAkM`B4O7T4Q7ej18AnO0B4Ogd4Q85o18B2PAGoool001Coool4
QXJ618N9R0B9Rh/4RXf>18b@T0>=TY<4SiBE192GV0BBVI/4Ti^N19FNX0>FX:<4Uj>V19VUZ@BJZ:`4
VjZ_19f]/PBN[kD3Wk:h1:2e^`BR^;h4Y;_219^e_@BH/;H4VJnc0iZ^/@BK[Jl4W:b]19f[[0BNZj/4
Wj^[0in[ZPBPZjX4X:ZY1:6XY`BQYZ@4XJ>P1:2OW0>NVYL4WIJB19Z@S@BGRXH4ThAo18mnN0>;Mg04
Qg1X189XG`B2JF04PV]S18=]IPB3KfP3Pg5[18AcK@B4MFl4Q7Ia18AhL`B4NGD3Q7]g18AlN@B4OGX4
Q7il18AoO@B4PGl4Q8:15Oooo`005?ooo`B6QXH4QhV818V;R`B:SHh4S92@0hfBT`B?U9D4T9NH19:I
V`BCVih4UIjP0iJPX`BGXjH4VJFY19ZX[0BKZZl4WJfb19j_]@>O/[P4X;Fk1::h_PBT^l84VkFm19R`
]PBI[k<3VZja19^][`BL[:d4WJ^/19j[Z`BOZj/3Wj^Z1:2[ZPBPZZT4XJRW1:6VY0BQXj04X9nL0ijJ
U`BMUY84VY2=19N:QPBCQ7l4Sgih0h]gL0B7L6P4PVQO189YH0B2Jf<4PfeV18=_J0>3LF/4Q7=]18Ae
K`B4MW44Q7Qc18AiM@>4NgL4Q7ai18AmNPB4OW`4Q7mm18B1O`B4PX4Eoooo000Doooo18J6QPB7RHP4
RH^;18Z=SPB<T903SI:C18nDU@B@UiP4TYVK19>KWPBEWZ03UZ2S19NSYPBIYJT4VZR/19^Z[`BM[K84
WZne0inb^0BP]K/4X[Rn1:Bk`PBK]Kd4V;2f19V_/`>J[[44Vjf_19b/[@BMZj`4WZ^[19n[Z`>OZjX4
X:^Z1:2ZZ@BQZ:L4XJJT1:6SX0BPWi`3WYZG19fFTPBJT8d4UhZ619>4O`B?OWP3RgM`18M`J0B2J5l4
PVUP189[H`B3KFH4PfmX0h=aJ`B4Lfd4Q7E_18AfL@B4N7<4Q7Ue0hAkM`B4O7T4Q7ej18AnO0B4Ogd4
Q85o18B2PAGoool001Coool4QXJ618R9R@B9S8`4Rhj?18fATP>?U9D4T9JH19:IV`BDW9h4UIjQ19NQ
Y0>HY:L4VZNZ19^Y[@BM[;44WZnd1:2b]`BQ]K/3XkRn1:Bk`PBV_lH4Yl3819Jb^PBH/KP4Vk6f0iba
]0BN/;<4Wk2a1:2_/0BQ[jl4XZn_0j>`[PBT/:h4Y;2]1:F][0BUZjP4Y:NT1:>QW`>RWIT4X9RD19fB
SPBIRhL4UXJ0195oN0>=N704RG5Y18AYG`B4JV44Q6aS18A]I@B4KfL3Q75Y18AbJ`B4M6h4Q7E`18Ag
LPB4N7@3Q7Yf18AkN0B4OGT4Q7ik18AoO@B4PGl4Q8:15Oooo`005?ooo`B6QXH4R8V918V<S0B;SXl4
SI6B0hnDU@B@UYP4TYVK19BLWPBEWZ44Uj6T0iRTY`BJYjX4VjV]19f//@BN[k@4X;:g1:6e^`>S^;h4
Y;_21:JoaPBW`<P4U[:j19Ra^0BK/KH3W;6d19j`/`BO/;44X:n`1:6_[`BR[jl3Xk2^1:B`[PBT/:d4
YJf/1:F[Z0BTYj@4Xj6O0j:MV@BPV9@4WI:>19V;Q`BFQX04TGmh0hehL0B9LFT4Q6UO18AZH@B4K6<4
Q6eU18A_I`>4LFT4Q79[18AdKPB4MG04Q7Mb18AhM0>4NWH4Q7]h18AmN@B4OW/4Q7mm18B1O`B4PX4E
oooo000Doooo18J6QPB8RHT4RHb<18^>S`B=TI83SiBE192FV0BBVI/4U9bN19FNX@BGXJ@3V:BW19ZW
ZPBKZJd4WJba19j_]0BP/[L4XKFk0j>h_PBT^l84Y[o61:O0b0BF/[X4V;6h19^a]P>L/K@4W[2c19n`
/@BP[k04XJn_1::_[`>S/:h4Y;2^1:B`[@BU[J`4YJ^X1:BWY0BSXIl3XYfI1:2HU0BMTXh4VH^719J6
P0BAOgP3SGQ`18UaJ@B4JEl4Q6YQ18A/H`B4KFD4Q6mW0hAaJ@B4LV/4Q7A^18AeL0B4Mg84Q7Qd0hAj
MPB4NgP4Q7ei18AnN`B4Ogd4Q85o18B2PAGoool001Coool4QXJ618R9R@B9S8`4Rhj?18fATP>?U9D4
T9JH19:IV`BDW9h4UIjQ19NQY0>HY:L4VZNZ19^Y[@BM[;44WZnd1:2b]`BQ]K/3XkRn1:Bk`PBV_lH4
Yl3819Jb^PBH/KP4Vk6f0iba]0BN/;<4Wk2a1:2_/0BQ[jl4XZn_0j>`[PBT/:h4Y;2]1:F][0BUZjP4
Y:NT1:>QW`>RWIT4X9RD19fBSPBIRhL4UXJ0195oN0>=N704RG5Y18AYG`B4JV44Q6aS18A]I@B4KfL3
Q75Y18AbJ`B4M6h4Q7E`18AgLPB4N7@3Q7Yf18AkN0B4OGT4Q7ik18AoO@B4PGl4Q8:15Oooo`005?oo
o`B6QhH4R8Z:18Z=S@B<T904SY:C0i2EU`BBV9X4U9^M19FNX@BGXJ@4VJBX0i^WZ`BLZjl4WZjb1:2a
]PBQ];T4XkNm1:Fj`@>V_L@4Z<781:_5c@BN^l@4U;6j19Zd^PBM];T3WkFh1:2d]`BR];H4Xk>d1:Bc
/`BU/k<3Y[Bc1:Ne/`BX];44ZK6_1:R]Z`BWZJH4YZBQ0jFOV`BSVYH4Wi>?19^=R0BGQX44Th1i0hmi
L@B:LVX4QV]R18I[H@B5K6<4QFeT18E^IP>5L6P4QG5Z18AcK0B4M6h4Q7I`18AgLP>4NG@4Q7Yg18Al
N@B4OG/4Q7mm18B1O`B4PX4Eoooo000Doooo18J7QPB8RXX4RXf=18b@T0B>TY<3T9FG19:HVPBDVid4
UIjQ19NQY0BIY:P3VjN[19b[[`BN[[84X;6f1:6d^@BS]kd4YK[10jJma0BX`LP4ZlG=19jka0BD/KX4
V[Bj19fd^@>O]KP4X;Bg1::d]PBS/k@4Y;>c1:Fc/`>V];<4YkFc1:Rd/@BY/Jl4Z:f[1:NYYPBVY:43
YInK1:>JUPBOThl4Vhf819N6P@BCP7T3SgUa18YbJPB6Jf84QV]Q18E/H`B5KF@4QFiV0hE`J0B5LFX4
Q7=/18AdKPB4MW04Q7Mb0hAiM0B4NWL4Q7ai18AmN`B4Ogd4Q85o18B2PAGoool001Coool4QXN618R:
RPB:SHd4S92@18jBT`>@UIL4TYRJ19BKW@BEWZ44Uj6T19VTZ0>KYj/4W:^_19j^/PBP/KH4XKBi1:>g
_@BU^/43Y[g41:S1b0B[aLd4W[_419Ba^PBJ];X4WKBi0ine^0BP];L4X[Bf1:>c]0BT/k<4YK>c0jJd
/`BW]K<4Z;Ba1:Va[`BX[J/4YjVV1:JTX@>UWi/4XiZF19nCS`BKSHP4UhJ119>0N@>?NG44RW9Z18I[
HPB6Jf44QFaS18E]I0B5KVH3QG1X18EaJPB4Lf`4Q7A^18AfL0B4Mg83Q7Ud18AjM`B4O7T4Q7ek18Ao
O@B4PGl4Q8:15Oooo`005?ooo`B6QhH4R8Z:18Z=S@B<T904SY:C0i2EU`BBV9X4U9^M19FNX@BGXJ@4
VJBX0i^WZ`BLZjl4WZjb1:2a]PBQ];T4XkNm1:Fj`@>V_L@4Z<781:_5c@BN^l@4U;6j19Zd^PBM];T3
WkFh1:2d]`BR];H4Xk>d1:Bc/`BU/k<3Y[Bc1:Ne/`BX];44ZK6_1:R]Z`BWZJH4YZBQ0jFOV`BSVYH4
Wi>?19^=R0BGQX44Th1i0hmiL@B:LVX4QV]R18I[H@B5K6<4QFeT18E^IP>5L6P4QG5Z18AcK0B4M6h4
Q7I`18AgLP>4NG@4Q7Yg18AlN@B4OG/4Q7mm18B1O`B4PX4Eoooo000Doooo18J7Q`B9RXX4Rhj>18fA
T@B?U9D3TINI19>JW0BEWZ04Uj6T19VTY`BKZ:/3WJ^_19n^/`BQ/[L4XkFk1:Fi_PBV_<84Z;o60jW3
b`B]b=04Xl7:19Rg`0BJ]kl4WKNm1:2h_@>R^;`4XkRk1:Fh^@BV]kP4YkNf1:Rh]P>Y^;L4ZkZg1:^h
]@B/]K84Zk2]1:Z[Z0BYYJ83Z:2M1:FKUPBQU904WHf819R7P@BDP7X3TGYc18adK0B:KfD4Qf]Q18I/
HPB6K6<4QViU0hE_I`B5L6T4QG9[18AcK@B4MFl4Q7Ia0hAhL`B4NWD4Q7]h18AmNPB4OW`4Q81n18B2
PAGoool001Coool4QXN718V:RPB;SXh4SI6A18nDU@>AUiT4TiZL19FNX0BGXJ@4VJBW19^XZ`>MZjl4
Wjjc1:6b]`BS]K/4YKVn1:Jl`PBX_lH3ZL?;1:g8d0BS`LX4V;O019Zg_`BM]kd4X;Rm0j:h_0BS^;/4
YKRi1:Jg^0BW]kH4Z;Rf0jVh]`B[^[L4ZkRe1:be/PB[/:d4ZZ^X1:VUXP>XX9d4YI^F1:6DT0BMSHP4
V8N119B0NP>ANW<4S7A/18Y_I@B7Jf44QVaR18I/H`B6KVD3QFmW18E`J@B5LV/4Q7=]18AeK`B4MW43
Q7Qc18AjM@B4NgP4Q7ej18AnO0B4P7h4Q8:15Oooo`005?ooo`B6QhL4RHZ:18^>SPB=TI44SiBE0i6G
V@BCVY`4UIjP19NQY0BIY:L4VjR[0if[[`BO[[<4XK:g1:>e^`BU^Kh4Y[c21:RoaP>Y`l/4[LS@1:?1
bPBH]l04V[No19fg_@BP^;d3X[Rl1:>h^`BU^;T4Y[Nh1:Ng]PBX^;H3ZKRg1:^j]`B[^;D4[;Fb1:^`
[@BZZjP4ZJFR0jRPW@BUViH4XIB@19f=R0BHQh44U81j0i5jL`B<M6`4RVmU18M[H@B6K684QVaS18I^
I@>5KfL4QG1Y18EbJ`B4Lfd4Q7E_18AfL@>4N7<4Q7Ye18AkN0B4OGX4Q7il18B0OPB4PX4Eoooo000D
oooo18J7Q`B9RXX4Rhj>18fAT@B?U9D3TINI19>JW0BEWZ04Uj6T19VTY`BKZ:/3WJ^_19n^/`BQ/[L4
XkFk1:Fi_PBV_<84Z;o60jW3b`B]b=04Xl7:19Rg`0BJ]kl4WKNm1:2h_@>R^;`4XkRk1:Fh^@BV]kP4
YkNf1:Rh]P>Y^;L4ZkZg1:^h]@B/]K84Zk2]1:Z[Z0BYYJ83Z:2M1:FKUPBQU904WHf819R7P@BDP7X3
TGYc18adK0B:KfD4Qf]Q18I/HPB6K6<4QViU0hE_I`B5L6T4QG9[18AcK@B4MFl4Q7Ia0hAhL`B4NWD4
Q7]h18AmNPB4OW`4Q81n18B2PAGoool001Coool4QhN718V;R`B;Shl4SY:B192EU`>BVI/4UIbO19NP
X`BIY:L4VjN[19f[[`>P[k<4X[:g1:Bf^`BV^[l4Z;g41:[1b0B[aL`3[LS@1:S6c`BL_<D4WKc419nk
``BQ^l44Xkc10jFl`0BW_;l4Z;^l1:Vk^`BZ^kX4Zkbj0jbk^@B^_;T4[[Re1:nd/PB^[j`4[Z^X1:bV
X`>[XIh4Yi^G1:>DT0BOSXT4VHN119J1NP>BNg<4SWI]18a`I`B9K684R6]Q18M/HPB7KF<3QViU18I_
I`B5LFT4QG9[18AdK@B4MG03Q7Mb18AiM0B4NgL4Q7ai18AnN`B4P7h4Q8:05Oooo`005?ooo`B7QhL4
RH^;18^?S`B>TY84T9FG0i:IV`BEW9l4Uj2S19VTY`BKYj/4WJ^_0j2_/`BR/[L4Y;Jk1:Jj_`BX_L@4
Z/781:_5c0>]b=04Z<K?19bla@BM_<@4Wk_31:6k`@BS_<43YKc01:Nl_`BX^k`4ZK^k1:Zk^PB[_;X3
[;^i1:jl^@B^^;D4[kBb1:j_[0B^ZjP4[:JS0j^QWPBWViL4XiB@19n>R@BIQh44UX5j0i9kL`B>MVd4
S71W18U/HPB8Jf44QfaR18M]H`>6KVD4QVmW18EaJ@B5LV/4Q7A]18AeL0>4Mg84Q7Ud18AkM`B4O7T4
Q7ik18B0OPB4PX0Eoooo000Doooo18N7Q`B9Rh/4Rhn?18jBTPB@UIL3TYVK19FLW`BGX:<4VJBW19^W
Z`BMZjl3X:nc1::b]`BT][/4Y[Zo1:Rma0BZ`LP4ZlG<0jg8d0BXa/l4W;c519fla0BO^l<4XK_11:>l
`@>U_<04Ykbo1:Rk_0BY^k/4Z[^j1:^l^P>/^kT4[[bi1:jh]@B_];84[Zn/1:j[Z0B/YZ<3Zj6N1:NK
U`BSU904Whj919V7P@BFPGX3TW]c18ifK@B<L6L4RFaR18Q[H@B7K684QfeS0hI^I@B6KfL4QG5Y18Eb
J`B4M6d4Q7E`0hAgLPB4NG@4Q7]g18AlN@B4OW/4Q81n18B2P1Goool001Coool4QhR718V<S0B<Si04
Si>D196GV0>DVid4UYnQ19RRY@BKYZX4WJZ^1:2^/P>R/[L4Y;Jk1:Nj`0BY_/@4Zl;91:g6c@B_b]83
/LkG1:?3cPBP`<X4X;k71::naPBT_l@4Yl350jW1a@B[`<84Zkjo1:bn_@B]_[d4[Kjl0jjk^PB`^KL4
/KJe1;2`[`B`[J/4/JbZ1;2WY0>^XIh4ZI^G1:FDT0BPSXT4VhN119N1NP>CO7@4TGM^18ibJ0B;KV@4
R6YO18Q[H0B8K683QfeS18I^I@B5KfL4QG5Z18AbK0B4M6h3Q7Ia18AhL`B4NWH4Q7ah18AnN`B4P7h4
Q8:05Oooo`005?ooo`B7R8L4RHb<18b?T0B?Ti@4TINH0iBKW@BFWj44V::U19^VZPBMZZh4X:jb0j:b
]`BT][/4Yk[01:Vna0B[`/T4[LK=1:o:dP>ac]L4Xl?>1:30bPBP_/L4X[k61:Boa0BW`<D3ZL751:_0
`PB[_[l4[;jm1:fn_@B]_[`3[[^j1;2i]`Ba][D4/;2_1;2]Z`Ba[:X4/:NT0jjQWPBYViL4YIB@1:2>
R@BKQh44Uh5j0i=lM0BAMfh4SW9X18]^I0B8JUl4R6]P18Q/HP>7KF<4QViU18E_I`B5LFX4Q79/18Ad
KP>4MW44Q7Qc18AjMPB4O7P4Q7ik18B0OPB4PX0Eoooo000Doooo18N8Q`B9S8`4S8n@18nCU0BAUiP3
U9^M19JOX@BHXZD4VjJZ19fZ[PBP[[83X[:g1:Bf^`BW^/04ZKk41:_2b@B]a/d4[l[B0k7>e`BS`lh4
X<3:1:2na`BR_/H4Y;o41:O0a@>Y`LD4Zl321:^n_`B/_[d4[Kjm1:fn_0>^^kX4/;Vg1;6f]@B`/:l4
/:f[1;6/ZPB`Yj@3[Z6N1:VKU`BUU904X8j919^7P@BGPGX3Tgad195gKPB>LVP4RfiT18QZG`B8Jf04
R6aR0hM]H`B6KVD4QFmW18EaJPB4LV`4Q7A^0hAfL@B4N7<4Q7Yf18AlN0B4OW/4Q81n18B2P1Goool0
01Coool4QhR718V<S0B<Si04Si>D196GV0>DVid4UYnQ19RRY@BKYZX4WJZ^1:2^/P>R/[L4Y;Jk1:Nj
`0BY_/@4Zl;91:g6c@B_b]83/LkG1:?3cPBP`<X4X;k71::naPBT_l@4Yl350jW1a@B[`<84Zkjo1:bn
_@B]_[d4[Kjl0jjk^PB`^KL4/KJe1;2`[`B`[J/4/JbZ1;2WY0>^XIh4ZI^G1:FDT0BPSXT4VhN119N1
NP>CO7@4TGM^18ibJ0B;KV@4R6YO18Q[H0B8K683QfeS18I^I@B5KfL4QG5Z18AbK0B4M6h3Q7Ia18Ah
L`B4NWH4Q7ah18AnN`B4P7h4Q8:05Oooo`005?ooo`B7R8P4RXb<18f@T@B?U9D4TYVJ0iFLWPBHXJ<4
VZFX19fY[0BO[K44X[6f0jFf^`BW^[l4Z[k41:c2b@B_alh4/L_C1;?@f0>]c=L4W[o:1:70bPBS`LT4
YL371:O2a`BZa<P3[/G81:o4a@B^`L04/<6o1;;0_`B]^KP3[[Nf1:nc/PB`/K04/K6_1;>_[@Bd[JX4
/jJS0k:SW`B/WIT4YYB@1:2>R@BKQh04Uh5i0iAlM0BBN6l4T7=Z18i`I@B;K644RVYO18U[H0>8K684
QVeT18E^IPB5KfP4Q75Z18AcK@>4MFl4Q7Mb18AiM@B4NgP4Q7ej18AoO@B4PX0Eoooo000Doooo18N8
R0B:S8`4SI2A18nDU@BBVIX3UIbN19RQX`BJYJP4WJV/19n]/@BR/KH3YKJk1:Nj_`BZ_/@4[<;91:o7
cPBabm<4/m3H0jg<e`BN_lX4XL3:1:?1b@BU`<L4Yl;71:[4b0>^aLP4[lC51:k1`0B``Kl4//2o1:fi
^0>^]kH4[k>b1;2a/0Ba/Jl4/jn]1;B]ZPBcYZ<3/Z>O1:bMV@BVU904X8j919^7P0BGPGT3U7ad199h
K`B@LfX4SW1U18]/H@B:JUl4RF]P0hQ/HPB6KF@4QFiV18E_J0B4LFX4Q7=]0hAeK`B4Mg84Q7Ue18Ak
N0B4OGX4Q7mm18B2P1Goool001Coool4QhR818Z<S0B=T944SiBE19:IVP>EW9h4V:6S19ZUZ0BMZJ`4
Wjfa1::a]P>U][/4YkZo1:Zna0B/`/T4[lO>1;7;d`Bcd=P3[LcG19jobPBQ`<X4Xl791:G0a`BW`/L4
Z/C80jk5b0B_a<D4[/701;31_`Bb`;l4[KVh0jjg]PB_/k84/;6`1;6a[`Bc[jd4]:fZ1;>VX`>bXil4
[9fI1:JDT0BPSXT4VhN019N1N@>DO7@4TWQ_191cJPB>L6D4RfaQ18YZG`B9Jf03R6aR18I]I0B5KVH4
QFmX18AaJPB4Lfd3Q7E_18AgLPB4NGD4Q7]h18AmNPB4Ogd4Q8:05Oooo`005?ooo`B7R8P4RXb<18f@
T@B?U9D4TYVJ0iFLWPBHXJ<4VZFX19fY[0BO[K44X[6f0jFf^`BW^[l4Z[k41:c2b@B_alh4/L_C1;?@
f0>]c=L4W[o:1:70bPBS`LT4YL371:O2a`BZa<P3[/G81:o4a@B^`L04/<6o1;;0_`B]^KP3[[Nf1:nc
/PB`/K04/K6_1;>_[@Bd[JX4/jJS0k:SW`B/WIT4YYB@1:2>R@BKQh04Uh5i0iAlM0BBN6l4T7=Z18i`
I@B;K644RVYO18U[H0>8K684QVeT18E^IPB5KfP4Q75Z18AcK@>4MFl4Q7Mb18AiM@B4NgP4Q7ej18Ao
O@B4PX0Eoooo000Doooo18N8R0B:SHd4SI6B192FU`BCVY`3UYjP19VSY@BLYjX4Wjb_1:6`]0BT];T3
YkVn1:Zna0B]`/T4/<O>1;;;d`BdcmP4]mCM0jK7dPBP`L/4X/7;1:G3b`BW`/P4Z/C91:g7b`>ab</4
//K71;?4``B_^k/4[KJf1:Va/0>^/[44/;6`1;:b/@Bd/k84]:f[1;B[Z0BdZ:@3]:JR1:nOVPBWUI44
XHf819b7P0BHP7T3UGad19AiL0BCMF/4T79W18i]HPB<JUd4RVYN0hQ[H0B6Jf44QFaS18A^IPB4L6P4
Q79[0h=dKPB3MW44PgQd18AjM`B4OGX4Q7mm18B1P1Goool001Coool4QhR818Z=S@B=TI84T9JG19>J
W0>FWZ04VJ>U19bWZPBO[:l4XK2d1:Bd^@>W^Kh4Z[k41:g2b@B`alh4//_C1;C?f0Bge=d3Y/OB1:31
b`BR`L/4YL?;1:O2b0BZa<T4[LO;0k78b`Bba/L4/lC31:nk^`B]][H4ZK6`0jjb/@B`/K04/[:a1;Bc
/PBd[J/4]:^X1;BXY0>dYZ84[inJ1:NET@BQSHP4W8N019R0N@>EO7@4U7U`19=eJ`B@LVL4SVeR18aZ
G@B:JUh3R6]P18I[H@B5K6<4Q6iV18A`J0B4LV/3PgA^18=fL@B3N7@4Q7Yg18AmNPB4Ogd4Q8605Ooo
o`005?ooo`B7R8P4RXf=18fATPB@UYL4TiZL0iJNX0BIXjD4W:NZ19n/[`BQ/;@4Y;Bi0jNi_PBZ_/@4
[L;91;37cPBbbm<4]<oH1;ODg@>Vam84X<7;1:;1b`BU`l/4Yl;81:[4b@B]al/3/LS;1;;6a`Bca<<4
[k^k1:ff]PBY/K03[[:a1;2a/0Bb/[44];>b1;B]Z`BdZjP4]:RT0kBVXPB_WiX4YiFA1:6=R0BLQh04
V81i0iElM0BDNG04TgE[191bI`B>KF84S6YM18YZGP>8Jf04QV]Q18E/H`B4KVH4Q71X18AbJ`>3M6h4
PgIa18=hM0B4NWL4Q7ej18AoO@B4PH0Eoooo000Doooo18N8R0B:SHd4SI6B192FU`BCVY`3UYjP19VS
Y@BLYjX4Wjb_1:6`]0BT];T3YkVn1:Zna0B]`/T4/<O>1;;;d`BdcmP4]mCM0jK7dPBP`L/4X/7;1:G3
b`BW`/P4Z/C91:g7b`>ab</4//K71;?4``B_^k/4[KJf1:Va/0>^/[44/;6`1;:b/@Bd/k84]:f[1;B[
Z0BdZ:@3]:JR1:nOVPBWUI44XHf819b7P0BHP7T3UGad19AiL0BCMF/4T79W18i]HPB<JUd4RVYN0hQ[
H0B6Jf44QFaS18A^IPB4L6P4Q79[0h=dKPB3MW44PgQd18AjM`B4OGX4Q7mm18B1P1Goool001Coool4
R8V818^=SPB>TY<4TINH19BKW@>HX:84VjFX19jY[@BQ[[84Xk>g1:Jh_@>Y_<84[<781;36c@Bcc=<4
]m7I1;SDg0BfeMl3X<;>1:72c0BT`//4Yl?;1:W3b@B/aLX4/<S=0kC8b`BcaLD4/l701:Vd]@B[]KD4
[[Fe0k2e]0Bb][H4]KNf1;Ng]@Bf/Zl4]k2]1;F[Y`>cYj@4[YnJ1:VHT`BQSXT4W8J019QoN@>GO7@4
UWYa19EgK@BCLfP4TFmS18m[GPB<JUl3RFUN18IYG`B4JV44Q6aT18=^I`B3L6T3Pg9]18=eL0B3Mg<4
PgYf18=lN@B4Og`4Q8605Oooo`005?ooo`B8RHP4Rhf>18jBT`BAUiP4U9^M0iRPXPBKYJP4WZV]1:6^
/PBS/kL4Y[Rm0jVl`PB/`LP4/<K=1;?<d`BgdMT4^=CL1;KEg`>P`/h4XL;<1:C2b`BW`l/4ZL?91:c5
bPB`b<d3]<S;1;?5a@Bc`L04ZKBe1:^e]@B^]KD3/;Fd1;:f]PBe]kH4]kNe1;Jb[`Bg/:d4]J^W0k>W
Y0B^WiX4ZIRC1:6>R@BLQX04V7mi0iMlM0BFNW44UGM]19=cJ0BAKf<4Sf]N18aZG`>9JEh4QVUO18AZ
H@B4K6@4PfiW18=`J@>3LVd4PgE`18=gL`B3NWH4Pgai18AoO0B4PH0Eoooo000Doooo18R9R0B;SHh4
SY:C196GV0BDVid3V:2R19^UZ0BNZJd4XJjb1:>c]`BV^;d3ZKc21:c1b0B`a/d4/lcC1;OAf@Bhe=`4
]]GO0j32cPBQ`/`4Y<;;1:O3b`BY`lT4[<G:1;38c@>db</4/lG51;?1`0BY];D4ZkFe1:je]@>`]K@4
/[Jf1;Fg]PBg]kD4][:_1;N`[@BeZjL3/jNT1:jOVPBYV9<4XHj919b6P0BHOgT3Ugad19IjL@BEMfd4
Tg=X195_H`B?Jeh4S6YO0hUYGPB6JEl4Q6YQ18A/I0B3KVL4Pg1Y0h=bK@B3MG04PgMc18=jMPB3O7T4
Q7ml18B1P1Goool001Coool4R8V818^=SPB>TY<4TINH19BKW@>HX:84VjFX19jY[@BQ[[84Xk>g1:Jh
_@>Y_<84[<781;36c@Bcc=<4]m7I1;SDg0BfeMl3X<;>1:72c0BT`//4Yl?;1:W3b@B/aLX4/<S=0kC8
b`BcaLD4/l701:Vd]@B[]KD4[[Fe0k2e]0Bb][H4]KNf1;Ng]@Bf/Zl4]k2]1;F[Y`>cYj@4[YnJ1:VH
T`BQSXT4W8J019QoN@>GO7@4UWYa19EgK@BCLfP4TFmS18m[GPB<JUl3RFUN18IYG`B4JV44Q6aT18=^
I`B3L6T3Pg9]18=eL0B3Mg<4PgYf18=lN@B4Og`4Q8605Oooo`005?ooo`B8RHT4Rhj>18nCU0BBV9T4
UYfO0iVRY0BLYjX4Wjb_1::a]@BV][X4ZK_00jc0aPB_aL/4/l[B1;OAf@BnfN44^mSQ1:c=f@>M_l/4
X/;<1:K4c0BYa</4ZlC:1:k6b`Bbb<`3//C71;2n_`B]^;T4Z;:c1:fd]0B`][H3/kNf1;Fj^@Bh^[P4
^KZg1;Vf/`Bi/[04]j^X0kFZY@BaXY`4[9^E1:>AR`BKQGl4V7mh0iQlM0BHNg84V7U^19IeJPBCL6@4
TFaP18eYG0>9J5/4Q6EL18=XGPB3JV44PfaT189_J0>2LF/4PgA^18=fLPB3NGD4Pgai18AnO0B4PGlE
oooo000Doooo18R9R@B;SXh4Si>D19:HV@BFWIl3VJ:T19bWZPBO[:l4X[6e1:Jf^PBY^l03[<361:o5
b`Bcb]84]m7I1;kIh@Bkf>44[<gI0ifob`BR`/`4Y/C<1:W4b`B[a<X4[/K;1;;8c0>ba<L4/;jo1:fh
^@BX/[<4[KBd1;2f]P>c]kH4]KZi1;Rj^0Bi^[L4^KJc1;Vb/0BgZjP3]JZU1;6RW0B/ViD4Xi6;19^5
O`BHOgP3V7ad19QkLPBHNFh4UWEZ19=`I0BAK604SFUL0hUXF`B4IE`4PfQN18=ZH@B3K6@4PVmX0h9a
J`B3M6h4PgIb18=iM@B3O7T4Q7il18B1OaGoool001Coool4R8V918^>SPB?Ti@4TYRI19JMW`>IXZ@4
W:NZ19n/[`BR/KD4Y[Jj1:Vk`0>/`<H4[lG;1;?:dPBgdMT4_]WQ1;_Hh@B/cMT3WKo;1:;2c0BVa<`4
ZLC;1:_4bPB^a//4//S<0k;4a`B`_[l4[KRi1:Rb/`B]];@4/;Jf0k>g]PBe^[T4^;Zh1;Vj]`Bi][<4
^K:`1;N[Z0>eZZD4/J:L1:bKU@BSTH/4VhEo19QoN0>HO7@4V7]b19QiKPBFMFX4Tg1T195/H0B=JE`3
RFQK18AUG0B3J5h4PfYQ18=/I0B2KfP3PW5[18=dKPB3MW84PgUe18=lN@B4OW`4Q85o5Oooo`005?oo
o`B8RHT4S8n?192DU@BCVI/4UinQ0i^TY`BNZJ`4XJjb1:Bc^0BX^;d4Zkg30jk3b@Bab<l4]<gE1;[D
g@C0g>D4/m;L1:32cP>P`</4Y<?<1:S4c0B[a<X4[LC:1;37b`Bcal/3/l?61;2l_PB_^KX4[kNg1;6f
]PBc][H3];Ng1;Nh^0Bi^;P4^[Nf1;Zc/PBj[jd4^:^X0kFYY0BbXYd4[I^F1:JCS@BLQGl4VGih0iUl
M0BJO7<4VWY_19QfJ`BFLVH4U6mR19=]G`>8IET4Pf=I189UF`B2J5l4PVYR189]IP>2L6T4PW=]189e
L@B3N7@4Pg]h18=nO0B4PGlEoooo000Doooo18R9R@B<Shl4T9BE19>IV`BGWj43VjBW19jY[0BQ[[84
Y;>h1:Rh_@B[_L<3[/?91;78c`BdcMD4^]CM1<3Li@Bcd]`4X<;>0j30b`BT`l`4Z<C<1:_4bPB]a<X4
/<O;1;?7b`>c`lH4/;bn1:ni^PB_]kL4/KJf1;>f]P>d]kL4]kRh1;Vh^0Bj]kH4^[>b1;Z_[@BhZjP3
]JVT1;:RW@B]ViH4YY>=19b5O`BIOWP3VGad19YlL`BJNVl4V7I[19IbIPBDKf84TfeO0hQUF@B3HeT4
PVEK189XG`B2JV84PVeV0h9`J@B2Lfd4PWEa18=hM0B3NgP4Pgil18B1OaGoool001Coool4R8V918b?
S`B@U9D4TiVK19NOX@>KY:L4WZV/1:6^/PBT/kP4Z;Rm1:^m``>^`lT4/LS?1;C=e@Bje=d4`=cU1;?B
g0BP`/h3X<3;1:C3c0BXa<`4ZlC:1:g4bPB`al/4/lO;0k?3aPB`_;h4[kVj1:ng]`Ba][H4/kJf0kBg
]`Bg^;P4^KRh1;Zg]PBj/k84^Zn]1;R[Z0>eZJ@4/Z:M1:fKUPBVThd4W8Eo19UnN0>IO7@4VWac19Yj
K`BHMV/4UW9V19A_HPBCKEl3R6EI18=SF@B2IE/4PVQO189ZHPB2KFH3PW1Y189cK@B2MG44PgQd18=k
N0B3OW`4Q85o5Oooo`005?ooo`B8RHT4S8n?192DU@BCVI/4UinQ0i^TY`BNZJ`4XJjb1:Bc^0BX^;d4
Zkg30jk3b@Bab<l4]<gE1;[Dg@C0g>D4/m;L1:32cP>P`</4Y<?<1:S4c0B[a<X4[LC:1;37b`Bcal/3
/l?61;2l_PB_^KX4[kNg1;6f]PBc][H3];Ng1;Nh^0Bi^;P4^[Nf1;Zc/PBj[jd4^:^X0kFYY0BbXYd4
[I^F1:JCS@BLQGl4VGih0iUlM0BJO7<4VWY_19QfJ`BFLVH4U6mR19=]G`>8IET4Pf=I189UF`B2J5l4
PVYR189]IP>2L6T4PW=]189eL@B3N7@4Pg]h18=nO0B4PGlEoooo000Doooo18R:R@B<Si04T9FF19BK
W0BHX:83W:JX1:2[[PBS/K@4YkJk1:Zk`@B]`<H3/<G<1;;:dPBecmP4^=CM1;GDg`BXbM@4Wl3<0jC3
c@BWa<`4Z/C;1:g4bPB_a<X4//K:1;C6bP>d`lH4/Kbn1;:k^`Bb^KX4];Vi1;Ji^@>h^[T4^[bj1;bk
^PBm^KL4_KJc1;bb[PBk[JT3]jRS1;>PW0B]V9<4YXn919j5O`BJOWP3Vgee19amM0BLO704VgQ/19Qc
I`BGL684UViO0h=PD`B1H5D4P69H181VG0B1JF04PFaT0h5^J0B2LV`4PWE`189hL`B3NgL4Pgik18B1
OaGoool001Coool4R8Z918b?T0B@UIH4U9^L19RPXP>LYZP4X:^^1:>a]0BW][/4Z[_11:g0aP>`aL`4
//[B1;G?f0Bhe=d4]MCO1:S9e0BO`<`3Y<?=1:O4c0BZa</4[LC:1:o4bPBba/X4]<K:0kC3aPBa_;h4
/[^k1;:i^PBd^KT4][Vi0kRj^@Bj_;X4_;^j1;fi]`Bm][<4_;:^1;^]Z@>gZ:<4/j2L1:fHT`BVShT4
WXEo19YnN0>KOGD4W7ed19alL0BKN6`4V7=W19M`HPBFKUl3Pf1C185PE@B0HUP4P6IL185YH0B1K6@3
PFiX189bK0B2MG04PWQc18=kM`B3OW/4Q85o5Oooo`005?ooo`B8RXT4S8n@192EUPBDVi`4V:2R0ibV
Z0BPZjh4Xk6d1:Nf^`BZ^l44[L360k35c0Bbb]84]LoH1;SDg@Bee=l4Z<WD19o0c0>T`ld4YlC<1:[4
b`B]a<X4[lC:1;;6bPBda/X3]<?61;6l_PBb^k/4/[Vj1;Bi^@Bf^KT3^;Zi1;Zl^PBl^kX4_KVg1;ff
/`Bl/Zh4^jfY0kNXX`BcX9`4[IRC1:J?R@BNQGl4VWih0i]mM@BLOG@4W7a`19]hK0BHLfL4Ug1R19I^
G`>3H5<4PF1E181RF0B0IU`4PFUP185/I0>1KVP4PW9/189eL0B2N7<4Pg]g18=nN`B4PGlEoooo000D
oooo18R:R@B<Si04T9FF19BKW0BHX:83W:JX1:2[[PBS/K@4YkJk1:Zk`@B]`<H3/<G<1;;:dPBecmP4
^=CM1;GDg`BXbM@4Wl3<0jC3c@BWa<`4Z/C;1:g4bPB_a<X4//K:1;C6bP>d`lH4/Kbn1;:k^`Bb^KX4
];Vi1;Ji^@>h^[T4^[bj1;bk^PBm^KL4_KJc1;bb[PBk[JT3]jRS1;>PW0B]V9<4YXn919j5O`BJOWP3
Vgee19amM0BLO704VgQ/19QcI`BGL684UViO0h=PD`B1H5D4P69H181VG0B1JF04PFaT0h5^J0B2LV`4
PWE`189hL`B3NgL4Pgik18B1OaGoool001Coool4RHZ:18f@T0BAUYL4UYbM19ZRY0>NZ:X4XZfa1:Fc
]`BY^Kd4[;k41:o3bP>bb=04]<gE1;KAfPBfeMl4/];M1:k<e`BZam43ZLG>1:_5c0B]a<X4[lG:1;74
b@Bca/X4]LK:0kG4aPBe_l44];bm1;Fk^`Bg^k/4^Kbk0k^l^`Bm_K`4_kfl1<2l^@C0^;D4_kB`1;f_
ZP>hZJ<4]:6L1:jIT`BYTHX4XhV219j2N`>MOgH4WWmd19imL@BMNF`4VWAW19UaH`BIKel3PUiA17iM
D@AoH5H4Of=J181WGPB0JV83PFeV185`JPB2M6h4PWMc18=jM`B3OG/4Q85o5Oooo`005?ooo`B9RXX4
SI2@196FU`BFW9d4VZ:T0ijXZPBR[K44YK>g1:Vi_@B/_/@4[l?:0k;8d0BdcMD4]]7J1;KEg`Bbd]d4
[/cG1:[7d@>YaLh4ZlG<1:g4bPB_aLX4/LC91;?6bPBea/X3]LC61;Fo`@Bd_;d4]K^k1;Nk^`Bi_;/3
^kbk1;fm_0Bo_K`4`;bi1<2h]@Bo];04_JnZ0kRYX`BdXI`4[YVC1:VARPBSRH84WX9k0ieoMPBNOg@4
WWea19eiK0BJM6L4VG5S19U_G`>2GU44OUeA17mPEPAoHeX4P6MN181ZHP>1KFH4PG1Z189dKPB2Mg<4
PgYg18=mN`B4PGlEoooo000Doooo18V:RPB=T904TIJG19JLW@BJXZ@3WZRZ1::]/@BU/kL4ZKVm1:bn
a0B_`lX3//S@1;C=e@BfdMX4]]GO1;;Bg@B^c=L4Z/OA0jW5cPB[aL`4[LC:1:o5bPBaa<T4/lK:1;G6
bP>ea<H4]Ko11;Bl_@Be^k/4]k^k1;Vl^`>k_;/4_Kfl1;nm_0C0_;T4`;Re1;nd/0Bm[jX3^:VS1;BQ
W0B^VI<4ZI6:1:>9PPBNPW/3WGmf19ioM0BNOG44WGU/19YdI`BILF<4VFmO0h9ND@AnGE44Of1F17mS
FPB0Ieh4P6YR0h5]IPB1L6X4PWA^189gL`B3NWL4Pgek18B1OaGoool001Coool4RHZ:18f@T0BAUYL4
UYbM19ZRY0>NZ:X4XZfa1:Fc]`BY^Kd4[;k41:o3bP>bb=04]<gE1;KAfPBfeMl4/];M1:k<e`BZam43
ZLG>1:_5c0B]a<X4[lG:1;74b@Bca/X4]LK:0kG4aPBe_l44];bm1;Fk^`Bg^k/4^Kbk0k^l^`Bm_K`4
_kfl1<2l^@C0^;D4_kB`1;f_ZP>hZJ<4]:6L1:jIT`BYTHX4XhV219j2N`>MOgH4WWmd19imL@BMNF`4
VWAW19UaH`BIKel3PUiA17iMD@AoH5H4Of=J181WGPB0JV83PFeV185`JPB2M6h4PWMc18=jM`B3OG/4
Q85o5Oooo`005?ooo`B9RXX4SY6A19:GV0BGWIl4VjBV0j2Z[@BT/;<4Z;Jj1:^l`@B_`LL4//O=0kC<
d`Bfd=T4]mCN1;OFh@Bfe=h4/m3I1;3;d`>]all4[/G<1;35bPBbaLX4]<G:1;G6bPBgalX3^<G81;O2
``Bg_Kh4]kbl1;Vm_0Bk_kd3_[jm1<2o_PC2`;d4`kjk1<>j]PC1]K04_[2[0kVYX`BdXIX4[iVB1:ZB
RPBURh<4XHAk0j22N0BQPGH4X7ib19iiK@BKMFP4VW9S19]`H0>1GE04OE]@17eND`AnHEL4OVEL17mX
H0>0K6D4P6mY185cK@B2MW84PWUf18=mNPB4P7lEoooo000Doooo18V:RPB>TI44TYNH19NMW`BKY:H3
X:Z]1:B`/`BX][X4Zkc11:o1a`Bbald3]<cC1;K@f@Bge=h4]mKQ1;KDgPBcd=T4/<_C0jg7c`B^aL`4
/<G:1;;5bPBdaLX4]LK:1;O7bP>haLP4]l;31;Nm_PBg_;`4^Kfl1;^o_@>n_[d4`;nn1<;0_@C3_[/4
`kZf1<6e/0Bn/:/3^JVS1;BQVPB_VI84ZY::1:F;P`BQQ7/3X89h1:61MPBPOW84WWU]19]eJ0BJLV<4
Vg1P0h5MD0AmFe04OEiC17iQE`AnIE`4OfQP0h1/I@B0KfT4PG=]189fLPB2NGH4Pgej18B0OaGoool0
01Coool4RHZ:18jAT@BBUiP4UifO19^TYP>PZZd4Y;2c1:Rf^PB[_<44[l771;;7c@>dc=<4]]3I1;OD
gPBge^44]]CN1;?@f@B`bm<3[LO?1:k5c0B`aLX4//G:1;C5bPBea/X4]lO:0kS5b0Bg`/<4]kfn1;Nl
_0Bi_K`4^knm0kjn_@C0_kh4`/2m1<>n^`C3^[H4`KF`1;j`Z`>iZJ<4]:6J1:nITPBZTXX4YH^31:64
N`>PPWP4XH5f1:1nLPBNNFd4VgEX19YbH`BKL603PEe@17eKD0AmGU<4OV5G17iUG0AoJ603P6aU181_
J@B1Lfd4PWIb189iMPB3OGX4Q81o5Oooo`005?ooo`B9RXX4SY6A19:GV0BGWIl4VjBV0j2Z[@BT/;<4
Z;Jj1:^l`@B_`LL4//O=0kC<d`Bfd=T4]mCN1;OFh@Bfe=h4/m3I1;3;d`>]all4[/G<1;35bPBbaLX4
]<G:1;G6bPBgalX3^<G81;O2``Bg_Kh4]kbl1;Vm_0Bk_kd3_[jm1<2o_PC2`;d4`kjk1<>j]PC1]K04
_[2[0kVYX`BdXIX4[iVB1:ZBRPBURh<4XHAk0j22N0BQPGH4X7ib19iiK@BKMFP4VW9S19]`H0>1GE04
OE]@17eND`AnHEL4OVEL17mXH0>0K6D4P6mY185cK@B2MW84PWUf18=mNPB4P7lEoooo000Doooo18V;
RPB>TI84U9RI19ROX0BMYJP3XZb_1:Jb]PBZ^Kd4[[o41;;5bPBeb]43]loG1;WDg@Bjf>84^MSR1;WF
g`BfdMT4//[B0jo8c`Baa/`4//G;1;C6b`Bfal/4]lO;1;W8b`>ja/T4^lC51;[0`0Bj_Kd4_;jm1;k0
_P?0_kh4`/2n1<G2_PC5_k/4aK^g1<:e/0C0/:/3^ZVR1;FQVPB`VI84Zi::1:N<P`BTQWd3Y8Ej1:>2
M`BQOW84WgY]19aeJ0BJLV<4VW1Q0hAPD`AkFDd4Ne]@17aOE@AmHeT4OVMN0gmZH`B0KVP4PG9/185e
L@B2NGD4Pgej18B0OQGoool001Coool4RH^:18jATPBDV9T4V9nP19fUZ0>R[:l4Y[:f1:Zi_@B^_l@4
//G:1;G:d@>gcmL4^MCM1;[HhPBif>84^MKO1;KAf@Bbb]83[lS?1;76c0BbaL/4]<K;1;K7b`Bgal/4
^LS;0k[6b@Bka<D4^/301;Zm_@Bl_[d4_/2n0l2o_PC2`;h4aL:n1<Fo^`C5^kL4`[F`1<2`Z`>jZJ84
]J6J1;2ITPB[TXX4Yhb31:B6O@>TQGX4Xh9g1:5nLPBONVd4W7EX19YbH`BJL643Q61C17]IC@AkFe04
O5mE17eSF@AnIeh3OfYS181^J0B1LV`4PGEa189iM@B3OGX4Q81n5Oooo`005?ooo`B9RhX4SY6B19BH
V@BHWj04WJFX0j:/[`BV/[H4Z[Vm1:joa0BbaLX4]L[A0kO?e`Bie=d4^]SR1;WHhPBie]l4]]7I1;;:
dP>_b<l4/LK<1;;5b`Bda//4]/O;1;O7b`Bib</3^/K91;_4a@Bj`<04^[fm1;bn_@Bn`;h3`;nn1<;0
_PC5`[h4aKnk1<Fk]`C2]K04`;2[0kZYXPBeXIX4/9VB1:^BRPBWS8<4Y8Im0jB5NPBSPWL4XGib19mj
K@BLMFP4VW9S19Y`H@>4H5<4NeU=17]KD0AlGeD4OF=I17iWGP=oJV<4P6iX185bK0B1MG44PWUe18=m
NPB4P7hEoooo000Doooo18V;RPB>TI84U9RI19ROX0BMYJP3XZb_1:Jb]PBZ^Kd4[[o41;;5bPBeb]43
]loG1;WDg@Bjf>84^MSR1;WFg`BfdMT4//[B0jo8c`Baa/`4//G;1;C6b`Bfal/4]lO;1;W8b`>ja/T4
^lC51;[0`0Bj_Kd4_;jm1;k0_P?0_kh4`/2n1<G2_PC5_k/4aK^g1<:e/0C0/:/3^ZVR1;FQVPB`VI84
Zi::1:N<P`BTQWd3Y8Ej1:>2M`BQOW84WgY]19aeJ0BJLV<4VW1Q0hAPD`AkFDd4Ne]@17aOE@AmHeT4
OVMN0gmZH`B0KVP4PG9/185eL@B2NGD4Pgej18B0OQGoool001Coool4RX^;18nBTPBEVIX4VZ2R19nW
ZP>T[[44ZKFi1:fl`0Ba`/L4]LS>1;S>e@>ke=/4_=SQ1;gLiPBmfn@4_=SQ1;O?ePBcb]43//S>1;C6
c0Bea//4]lO;1;S8c0BjbL`4^lW;0kc7bPBma/L4_L;21;bn_@Bn`;h4`<6o0l?1_`C5`l04b<?01<W1
_@C7_KP4aKJa1<6aZP>lZJ84]j6J1;6IT@B/ThX4ZHf41:V:P0>XQg`4YHAh1:>0L`BPNfh4W7EX19Q`
HPBCK5h3QF5C17aHC0AhEd`4NUaB17aQE`AnIE`3OfUQ17m]IPB0LF/4PGE`189hM@B3O7T4Ph1n5Ooo
o`005?ooo`B:Rh/4Si:B19FIVPBJX:84WjNZ0jB^/@BY]KT4[Kc01;72a`Beb<h4^<kE0k_Df`Blf>44
_McV1;gKi0Blf>44]loF1;?:d@>bb<h4]<K<1;G6b`Bgal/4^<S<1;[9c0BkbL/3_<O:1;g6a`Bm`/84
_;jm1;k0_PC0`Kl3`l6o1<G3`0C8`l04bL6m1<Nm^0C5][44`K6Z0kbYXPBgXIX4/IVA1:bCRPBYSH@4
ZHZ00jR7O0BUQ7P4Xh1c1:1kKPBLMFP4V71R19=/GP>5HE<4O5Q<17QGC0AjG584O65G17iUG0=oJF44
OfeV181aJ`B1MG04PWQe18=lN@B3P7hEoooo000Doooo18Z;R`B?TY84UIVJ19ZPXPBOYjX3Y:ja1:Ve
^@B]_<04/L;71;G8cPBhc]D3^mCK1;cHh@Bmg>H4_M_T1;cHh@BgcmH4/l[A0k;8cPBda/`4]LK;1;O7
b`Bhb<`4^/W<1;_9b`>lalX4_LK71;g2`PBl_[d4_/2n1<31_`?3`Kl4aL?01<S3`0C9`Kd4akfh1<Ff
/@C1/JX3_:VR1;NQVPBaVI44[9>:1:V=Q0BYRX03Z8Ml1:F4N0BSP7<4X7]^19aeJ0BHL684TfaN0hEQ
D`AlF4`4N5M<17YLDPAlHEL4OVEL0gmYH@AoKFH4P75[185eL0B2N7D4Pgai18>0OQGoool001Coool4
RX^;192CT`BFVi/4W::S1:6YZ`>W/K<4[;Rk1;6o``Bea//4^LcB1;cBf@>of>04`MkW1<;QjPC1g^H4
_]KN1;S<d`BebM03]LO>1;K7c@Bgal`4^LW=1;_:cPBlb/d4_/[<0ko9b`BoalP4_/?21;k0_`C0`Kl4
`l?00lG3`0C8aL44blG21<c3_PC:_[P4akRb1<>aZ`>oZZ84^::I1;:IT0B_U8X4[I261:b=PP>[RWh4
Z8Ij1:B1M@BQO6l4W7IX19I`HPB@Jed3QV1B17YDA`AdDTH4NUY?17aOE@AmI5/3OVQP17m/I@B0L6X4
PGA_189hM0B2O7T4Ph1n5Oooo`005?ooo`B:Rh/4T9>C19JKV`BLXZ<4XJV[0jNa/`B/^;/4/Ko31;G6
b`Bic=84_=;I0koHh0C1g^L4`^7Z1<7NiPBne]h4^<cC1;G9d0>ealh4]/O=1;O7c0BibLd4^l[>1;c:
c@Bnb/`3_lW;1;o7b0Bn`l84_/2o1<31_`C3`l03aL?01<S5`@C;aL84c<>n1<Zn^0C7^;84`k6[0knZ
XPBhXYT4/YV@1:nDRPB]T8H4[8f20j^:OPBXQWX4Y85e1:5lK`BLMVP4UW1R191[G@>6H584NUA717AB
APAjFTl4O5mE17eTF`=nJ604OfaU181`JPB1M6l4PWQd189lN@B3P7hEoooo000Doooo18Z;R`B@Ti<4
UY^K19bRX`BQZJ/3Yk6c1:bh^`Ba_l<4]LK;1;W<dPBld]T3_mSP1<7Ni`C2hNX4`MkV1;kFgPBhc=<4
]LW@0kG7cPBfald4]lO<1;W9c@Bkb/h4_<[=1;k:c0>obL/4_lO81;k3`PBn`;l4`<6o1<?3`0?5`l04
b<G11<_5`PC<`kh4b[jh1<Nh/PC3/J/3_jZR1;RRV@BbVI04[iB:1:f@QPB/SH83ZhYn1:R6NPBTPGD4
XGa_19afJ0BFL684T6]M0hIPDPAjE4L4M59617YJC`AlGeD4OFAK0giXH0AoK6D4P71Z185dK`B2N7@4
PWai18>0OQGoool001Coool4RX^;192CT`BFVi/4W::S1:6YZ`>W/K<4[;Rk1;6o``Bea//4^LcB1;cB
f@>of>04`MkW1<;QjPC1g^H4_]KN1;S<d`BebM03]LO>1;K7c@Bgal`4^LW=1;_:cPBlb/d4_/[<0ko9
b`BoalP4_/?21;k0_`C0`Kl4`l?00lG3`0C8aL44blG21<c3_PC:_[P4akRb1<>aZ`>oZZ84^::I1;:I
T0B_U8X4[I261:b=PP>[RWh4Z8Ij1:B1M@BQO6l4W7IX19I`HPB@Jed3QV1B17YDA`AdDTH4NUY?17aO
E@AmI5/3OVQP17m/I@B0L6X4PGA_189hM0B2O7T4Ph1n5Oooo`005?ooo`B;S8`4TIBD19NLW@BNY:D4
Y:b^0jZc]PB_^kh4]<;61;W:cPBmdMH4`MON0lCMi@C6hn/4an?[1<CMi0BndMT4^<[A1;G8c`>gb<d4
^<S=1;[9c@Blb/h4_L_?1;o<c`C0c<h3`L[<1<78b0C1a<@4`L;01<?2`0C5a<03alC01<[6`PC=a/84
c/Bn1<fn^0C9^;84a;6Z0knZX@BiXIP4]9ZA1;:FS0B`ThP4/9250jj<P0BZR7/4YX=f1:9mK`BMMfT4
Ug1Q195[G@>7HE84OUI717]GBPAkFTl4O5mD17eSF@=nIel4Of]T17m_J@B0Lfh4PGMc189kN@B3P7hE
oooo000Doooo18^<S0BAU9@4UibM19jTY@BT[:h3Z[>f1:nk_PBd`/H4^L[>1;gAePC1emh3a=gU1<KS
j`C7hn/4a=gT1;kAf@Bhb]44]LS?0kO8c@Bhb<d4^/W=1;c:cPBmbll4_lc?1<3<cP?1b/`4`LS81<74
a0C1`/04`l;01<G4`0?7a<04b/K21<g6`PC>a;h4cKjh1<Vh/PC4/JX3_jZQ1;VQV0BdVY44/YJ<1;2C
R0B`T8D3[Xb01:Z8N`BVPgH4XWe_19egJ@BGL644TF]M0hMQDPAnETL4NeM:17]JC`AlGe@4OF=I0giW
G`AoJf@4OfmY181cKPB1Mg<4PW]i18>0OQGoool001Coool4Rhb<196DU0BGW9d4WZBU1:B/[P>Z/kH4
[k^n1;C2aPBib/h4_M7F1<7GgP?4gND4a^?[1<OSj`C4gN@4_]7I1;S:d@Beb<l3]lS=1;S8c@BjbLd4
_<[>1;g;c`Boc<l4`<c>0l7:c0C1b<P4`LC41<72`0C3`/04aLC00lO4`0C:a/84cLK21<k4_PC=_[P4
bKRb1<BaZP>oZZ44^J6H1;BJT@BbUX`4/9>81;2@Q@>^S804ZXQk1:J3MPBROFl4WGMY19M`H@BAJed3
Qf5B17iFA`AkEdX4NeY?17aOE0AmHeT3OVMO17m[I0AoKfT4P7=^185gL`B2NgT4Ph1n5Oooo`005?oo
o`B;S8`4TIBD19NLW@BNY:D4Y:b^0jZc]PB_^kh4]<;61;W:cPBmdMH4`MON0lCMi@C6hn/4an?[1<CM
i0BndMT4^<[A1;G8c`>gb<d4^<S=1;[9c@Blb/h4_L_?1;o<c`C0c<h3`L[<1<78b0C1a<@4`L;01<?2
`0C5a<03alC01<[6`PC=a/84c/Bn1<fn^0C9^;84a;6Z0knZX@BiXIP4]9ZA1;:FS0B`ThP4/9250jj<
P0BZR7/4YX=f1:9mK`BMMfT4Ug1Q195[G@>7HE84OUI717]GBPAkFTl4O5mD17eSF@=nIel4Of]T17m_
J@B0Lfh4PGMc189kN@B3P7hEoooo000Doooo18^<S0BBUID4VIfN1:2VY`BV[[03[KJi1;>n`@Bha/X4
_/kB1<?Ef`C7g><3b^?[1<cWk`C<i>/4am_R1;k?ePBgb<l4]lS>0kS8c@BjbLh4_<_?1;k<d0C1cM04
`/k@1<?>c`?4bl`4`lW91<?5a0C3`l44a<?11<O4`@?9aL44c<O31=37`PCAa;l4c[nh1<^h/@C6/JT3
`:VQ1;^RV@BhWI<4]YV>1;FFR`BcThL3/Hn21:f:O@BYQ7L4Y7i`19mgJPBHLF84TVaM0hYRD`B2FDX4
OUQ;17aJCPAlGU<4OF9H0geVG@AnJV<4OfiX181bK@B1Mg<4PW]h18=oOQGoool001Coool4Rhb<19:E
U@BIWIh4X:JW1:J^/0>]][T4/kk11;S6bPBnc]84`mGK1<OLh`?:hn/4c>O_1<cTj`C7fn84_/oF1;O8
c`Bgb<h3^<S=1;[9cPBlbll4_/c@1<7=d0C2c]04`lk?0lC;c0C3bLT4`lG41<?3`@C4`l44alC10lW5
`@C<al<4d<O21=74_`C>_kP4bkRa1<JaZ@?0ZJ44^j:I1;RMT`BfVHh4]IJ;1;>CQ`>aSh84[HYm1:V4
M`BTOW04WgMZ19QaHPBBK5d3RV9C189IBPAnF4/4O5Y>17aND`AmHUP3OFIM17iZH`AoKVP4P79]185g
L`B2NgP4Pgmn5Oooo`005?ooo`B;S8`4TYFE19VMWPBPYZL4YZj`0jff^@Bc_/44^<K:1;k>dPC3eM/4
amcS0l[Sj`C<inl4c>C[1<OKhPBncmH4]lS?1;O8cP>hb<d4^/W>1;c;c`Bnc=04`Lg@1<;>d0C3c/l3
a<_<1<?9b@C3aL@4`l?11<C3`@C7a<43bLG11<c7``C@al84dLBo1<jo^0C;^;44a[6Y0l2YX@BkXYT4
^9fC1;JISPBeUX/4/i>70k6?PPB]RWd4ZHAg1:AnL0BOMfX4V75R199/G@>:HU<4PUU:17iHB`AlFTh4
O5iC17eRF0=mIUd4OVYS17m^J0B0LVd4PGMc189kN0B3OghEoooo000Doooo18^<S0BBUID4VIfN1:2V
Y`BV[[03[KJi1;>n`@Bha/X4_/kB1<?Ef`C7g><3b^?[1<cWk`C<i>/4am_R1;k?ePBgb<l4]lS>0kS8
c@BjbLh4_<_?1;k<d0C1cM04`/k@1<?>c`?4bl`4`lW91<?5a0C3`l44a<?11<O4`@?9aL44c<O31=37
`PCAa;l4c[nh1<^h/@C6/JT3`:VQ1;^RV@BhWI<4]YV>1;FFR`BcThL3/Hn21:f:O@BYQ7L4Y7i`19mg
JPBHLF84TVaM0hYRD`B2FDX4OUQ;17aJCPAlGU<4OF9H0geVG@AnJV<4OfiX181bK@B1Mg<4PW]h18=o
OQGoool001Coool4S8f<19>FUPBKWil4XZRY1:V`/P>`^K/4]l;41;g:c@C3d]H4b=[O1<gRj0?Bj_44
eN_b1=?Vk0C9f^44_<gC1;O7cPBhald3^LS=1;_:c`Bnc=04`LkA1<C?d@C5cm04a/o?0lK<c0C5bLP4
a<G41<C3`@C5`l04b<C00l_6`PC?b<<4d/S31=?5_`CA`;T4cKVa1<RbZ@?3Zj84_jFK1;bPUPBjW944
^IR=1;JER0>dT8<4[h]n1:^5M`BVP744X7UZ19YcI0BDKV03S6=E18AMCPAnETP4OEU<17aLD@AlH5H3
OFEL17eYH@AnKFL4Og9/181fLPB2NgP4Pgmm5Oooo`005?ooo`B<SH`4TiJF19^OW`BRZ:T4ZK2b0k2i
^`Bg`/@4_L[=1<?BePC8f]l4cN;X0m;Zl@CEjo84dnK/1<WJh@BlcM<4]lO>1;S7c@>ib<d4^l[?1;k<
d0C1c]44a<oA1<G?d0C6cll3a/c<1<G9b0C4aL@4a<?11<G3`0C8a<03blK21<o8``CBb<<4dlFo1=70
^@C=^K44b;:Y0l>[XPBoYI/4_:2F1;ZLT@BiV8d4]YF80kB@P`B_Rgh4ZhEg1:J0L@BPNFX4VW=T19A^
H0><HeD4Q5e>17iFB0AmFD`4O5aA17aPEP=mIE`4OFUQ17i]I`AoLV`4P7Ib189kN0B3OgdEoooo000D
oooo18b=S0BCUYH4VinO1::XZ@BY/;83/;Vk1;O2a0Bmb/d4`m;F1<SJg`C=h^P3d^[a1=G[lPCCi^`4
bM[Q1;c=d`Bgalh4^<O=0kW8c@Bkb/l4_/c@1<7>d@C4cm44aLo@1<K?c`?6c<`4aLW81<C5a0C4`l44
aL?01<S4`0?;a/84clS31=;8``CCaKl4dL2i1<fi/@C8/ZT3`j^R1;nUV`BlX9H4^YbA1;VHS@BfUHP3
]9231:n;OPB[QGL4YX1a1:1iJPBJLf@4U6iP0haSE@B4GDh4OUI817eIC0AlG544O61F0geUG0AmJF44
OVeW17mbK0B0MW84PW]h18=oOAGoool001Coool4S8f<19>FUPBKWil4XZRY1:V`/P>`^K/4]l;41;g:
c@C3d]H4b=[O1<gRj0?Bj_44eN_b1=?Vk0C9f^44_<gC1;O7cPBhald3^LS=1;_:c`Bnc=04`LkA1<C?
d@C5cm04a/o?0lK<c0C5bLP4a<G41<C3`@C5`l04b<C00l_6`PC?b<<4d/S31=?5_`CA`;T4cKVa1<Rb
Z@?3Zj84_jFK1;bPUPBjW944^IR=1;JER0>dT8<4[h]n1:^5M`BVP744X7UZ19YcI0BDKV03S6=E18AM
CPAnETP4OEU<17aLD@AlH5H3OFEL17eYH@AnKFL4Og9/181fLPB2NgP4Pgmm5Oooo`005?ooo`B<SHd4
U9NG19fPX@BTZZX4[;>d0kBl_PBkaLP4`/kA1<SGfPC>gn<4e>O/0m[`mPCNko@4e^GZ1<SHg@BibM04
]/K<1;O6c0>ib<d4_<[>1<3=d0C4cm44am3A1<SAd@C9d=03b<g=1<O9b@C5a/@4aL?11<K3_`C8a<03
c<K11=38``CDbL<4eLJo1=?0^@C@^[84bk>Z0lN]X`C4Z9d4`J>H1;nOT`BlVhl4^IN:0kJBQ0BbSGl4
[XMi1:R2LPBSNf`4WGEV19M`H@>>IEH4QEe>17eCA0AlEdX4O5]?17aOE@=lHeX4OFQP17i/IPAoLF`4
P7Ea185jM`B3OgdEoooo000Doooo18b=S@BDUiL4WJ2Q1:BZZPB//k@3];bn1;_5b0C2c]44b=OJ1<kO
h`CDin`3f_3f1=k_m0CFiNX4b=SM1;W9d0Bfa/`4]lK<0kW8c@Blb/h4`<g@1<C?d@C7d=44b=7A1<W@
d0?8cLd4alW91<G6a0C5`l44a/>o1<S4`0?<a/44d<S31=C9``CEa[l4dl2i1=2j/PC;/jX3ajfS1<BX
W@C1XiP4_inC1;bKS`BiUhX3]Y:41;:=O`B^QgT4Z89b1:=kK0BMMFH4Ug1Q0hiUEPB5GDh4OE=417aG
BPAlFdl4O5mE0gaSFPAmJ604OVaV17maK0B0MG44PGYg18=oOAGoool001Coool4S8f=19BGU`BMX:44
Y:ZZ1:bc]0>d_;h4^lG81<;>d@C8emX4c]oS1=CWk0?Jl?H4g^od1=KUjPC8f=d4^LW@1;K6c0Bga/`3
^LS=1;c:cPC0cM04a<oA1<O@d@C8dM44bM3@0lS=c@C7bLT4aLK41<G3`@C6`kl4b<C00lc6`@C@b<<4
e<W31=G6_`CC`;T4d;Zb1<^cZP?7[J<4a:RM1<6SV0BoWi<4_9^?1;VGRP>fTX@4/Xeo1:j7N@BXPW84
Xg]/19eeIPBGL643SVEF18EMCPAmDd@4O5M:17aKC`AlGeD3O6=J17eXH0AnK6H4Og5/181eL@B1NWL4
Pgmm5Oooo`005?ooo`B=SXd4UYRH19jRXPBW[:`4/;Fg0kRo`@C0bL/4b=;E1<kKg`CDi>P4f^ca0mob
m`CQko84e^;W1<KDfPBca<`4/l?91;K5b`>hal/4_LW=1<;>d0C7d=84bm?D1<gCd`C=d]43b/k=1<O9
b0C5aL@4a<;01<G1_@C8`[h3cLG01=;8`PCFbL<4elK01=G1^PCC^k84c[F[0lb_Y@C9Zj04aZJJ1<:Q
U@C0WI04^iN:0kRCQ@BdSWl4/8Qi1:^3L`BUOFd4X7MW19]bHP>@J5P4Q5]<17aA@PAkEDL4NeU=17]M
D`=kHUT4O6IO17e[I@AnL6/4OgEa185jM`B3OgdEoooo000Doooo18f>S@BFV9P4WZ:R1:N/[0B`]KL3
^;o11<39b`C8d]D4c]_O1=CTj0CJk?43go;g1>7_lPCFh^L4a]CJ1;?4c0Bc`lT4]/G;0kS7b`BmbLd4
`/k@1<O@dPC;dm@4cM?C1<gBd@?:c/d4alW81<G5a0C4`/04aL6m1<S2_P?=aL04d/S21=K9``CGa/04
eL6j1=>k/PC>]J/3c:nU1<V[X0C6YYX4`Z6E1<2MT0BkUhX3^9>51;B>O`B`R7T4Zh=c1:EmK@BPMfL4
Vg9R0i1XF0B4Fd`4O55217]EA`AkFDd4NeeC0g]RF@AlIUl4OF]U17i`J`AoMG44PGYg18=oOAGoool0
01Coool4SHj=19JHV0BNXZ84Yjb/1;2e]`>h_l44`<W;1<SBe@C>fml4e>CX1=[/l@?Ol_L4hNob1=KR
i`C6e=X4/lC<1;?3b@BfaL/3^<O;1;g9c@C2c]04am3B1<_Ce0C=dm<4cM;A0l[>c@C7bLP4aLG41<C2
`0C5`Kd4b<:n0lg5`0CBb<84e/W31=O6`0CE`KX4dk^b1<jeZ`?<[jD4bJ^P1<JVVPC2XID4`9f@1;^G
RP>hThD4]8io1;28N@B[Pg<4YGe]1:1gI`BKLV83T6QH18AKC0AlDD84NeE717]IC@AkGE<3Nf9I17aV
G`AmJfD4OW1[17meL@B1NWL4Pgmm5Oooo`005?ooo`B=SXd4UYRH19jRXPBW[:`4/;Fg0kRo`@C0bL/4
b=;E1<kKg`CDi>P4f^ca0mobm`CQko84e^;W1<KDfPBca<`4/l?91;K5b`>hal/4_LW=1<;>d0C7d=84
bm?D1<gCd`C=d]43b/k=1<O9b0C5aL@4a<;01<G1_@C8`[h3cLG01=;8`PCFbL<4elK01=G1^PCC^k84
c[F[0lb_Y@C9Zj04aZJJ1<:QU@C0WI04^iN:0kRCQ@BdSWl4/8Qi1:^3L`BUOFd4X7MW19]bHP>@J5P4
Q5]<17aA@PAkEDL4NeU=17]MD`=kHUT4O6IO17e[I@AnL6/4OgEa185jM`B3OgdEoooo000Doooo18j>
SPBGVIP4X:>S1:Z^[PBc^;T3_<?41<G=c`C>emT4eN7T1=_Yk@CPlOD3iOCg1>Sbm0CJhnH4`m7F1:k0
b0B_`<L4/l;80kO4b@Blb<`4`/c>1<O@d0C<d]84d=?A1<oAc`?:c<`4aLK61<C4`PC3`;h4`[bi1<No
^`?<`kh4d/O21=O9``CIal04f<:j1=Jn/`CB]j`3ck6V1<f]X@C9ZI`4aZBF1<>OT@BmV8/3^IB51;J?
P0BbRWX4[XAd1:QnKPBSN6P4WG=S0hmVEPB1F4T4NThn17UBA@AiEd/4NE]A0gYPE`AjIEd4O6YS17e_
JPAoM704P7Uf189nOAGoool001Coool4SXj>19NIV0BPXj<4ZZj^1;>h^@>l`l@4aLg?1<kGf@CEhN@4
fnW]1>3am@?Um?L4j?;d1=[SiPC3dMH4[/381:o0a`Bc`/P3]lC91;c8c0C2c<h4am3@1<cBdPC@dm44
cm7?0l[<c0C5a/H4a<C21<?0_PC2_;T4aknk0lc3_PCBal84elW31=W7`0CH`[X4e[jc1=:g[0??/JH4
cJfQ1<VYW0C6Y9H4`inA1;fHR`>iU8D4]Xn01;::NPB^Q7@4Z7i^1:=hJ0BMLf<3SfIF185HB@AjCSh4
NE9517UGB`AiFe43NV1G17YUG@AlJV<4OFmZ17mdL0B0NGH4PWim5Oooo`005?ooo`B>SXh4UiVH1:2S
X`BZ[Zh4/kRi0kc3a0C5cLl4c]OI1=GQi0CKjNd4h?7e0nGdm`CXl_@4f^?V1<?AePB^`<P4[l371;?2
b0>ga<T4_<S<1<;<cPC7d=04c=;B1=3Cd@C?dLl3b/c<1<G6aPC4a<84`l2n1<:l^@C7_k/3c<>n1=;7
`PCGbL<4fLO01=S2^PCF_[<4d[N/0lnaYPC=[J44bJVL1<JTUPC3Wi44_IR;0kVDQ@BfSh04/XYj1:j4
M0BXOVh4XgQX19ecH`>?IUH4PEQ917Y>?PAiDTD4NEM;17UKD@=jH5L4NVEM17aZH`AmKfX4OgA`181i
MPB2OWdEoooo000Doooo18j>SPBGVIP4X:>S1:Z^[PBc^;T3_<?41<G=c`C>emT4eN7T1=_Yk@CPlOD3
iOCg1>Sbm0CJhnH4`m7F1:k0b0B_`<L4/l;80kO4b@Blb<`4`/c>1<O@d0C<d]84d=?A1<oAc`?:c<`4
aLK61<C4`PC3`;h4`[bi1<No^`?<`kh4d/O21=O9``CIal04f<:j1=Jn/`CB]j`3ck6V1<f]X@C9ZI`4
aZBF1<>OT@BmV8/3^IB51;J?P0BbRWX4[XAd1:QnKPBSN6P4WG=S0hmVEPB1F4T4NThn17UBA@AiEd/4
NE]A0gYPE`AjIEd4O6YS17e_JPAoM704P7Uf189nOAGoool001Coool4SXn>19RJV@BRYJD4[;2`1;Nk
^`?1a/L4bm;C1=GMgPCNinT4i?3b1>Oen0?Xm?H4jNoa1=GNhPBnc=84Z;_31:bma0B``<D3]L;61;[6
b@BobL/4aLg=1<O=c@C<clh4b/g;0l?6aPBo`;l4_;fl1;^h]PBm][<4aKbg0lc1_0CCal44f<W21=_8
`0CKa;/4fl:f1=Fh[0?E]JT4e;:T1=2]W`C:YIP4aInB1;jIR`>kU8H4]i201;B;N`B_QG@4ZX1_1:Ik
JPBPM6<3SfEE181EAPAgBc`4Me1317MEB@AgFTl3N5iE17USG0AjJF84O6iX17icK`B0NGH4PWil5Ooo
o`005?ooo`B>Shh4V9ZI1::UY@B//;04]k^k0l76a`C;d]<4eMgN1=kWj@CTl?84ioGh0nSdmPCYko44
eMkR1;k<dPBX^l<4[;g41;30a@>e`/H4^/K91;o9b`C5cLd4alg=1<c?cPC:cL/3`lK61;o0_`Bl_K`4
^kRf1;ff/`C5_;L3c<6l1=?7`@CHbL84flS01=_4^`CK`[H4eKR/0mFeZ@CD/Z@4d:fO1<ZUV0C5Wi84
_YV;0k^DQPBgT804]8]k1:n5M0BZP6l4YW]Z1:1dH`>?IED4P5E617M;?0AgD4<4MeE917MJC`=hGUD4
NF=L17YYHPAlKVP4OW=_181iMPB2OW`Eoooo000Doooo18j?SPBHVYT4XZFU1:b`/0Bg^k/3`LK71<_B
d`CEgMh4g^OY1>C`lPCWmOP3j?Cf1>W_l@CEg^84_/cB1:Rk``B/_L@4/<350kG2aPBja/T4_lW;1<G=
c@C7cLd4c<o>1<[=b`?3a/H4_l2o1;bm_0Bk^;H4_KJc1<Fl]`?<`K`4dlO11=S9`PCKb<04flBk1=_2
]PCE^:`3eKFY1=BbY0C@[Il4bZFH1<FOTPBnVH/3^iB61;N@P0BdRg/4[hEd1:Z0K`BVNfX4X7AS0hmU
E@B0EDH4Md/l17M@@`AgEDT4MeY?0gQNE@AiHe`4NVUR17a^J0AnLfl4P7Uf189nO1Goool001Coool4
SXn>19RJV@BRYJD4[;2`1;Nk^`?1a/L4bm;C1=GMgPCNinT4i?3b1>Oen0?Xm?H4jNoa1=GNhPBnc=84
Z;_31:bma0B``<D3]L;61;[6b@BobL/4aLg=1<O=c@C<clh4b/g;0l?6aPBo`;l4_;fl1;^h]PBm][<4
aKbg0lc1_0CCal44f<W21=_8`0CKa;/4fl:f1=Fh[0?E]JT4e;:T1=2]W`C:YIP4aInB1;jIR`>kU8H4
]i201;B;N`B_QG@4ZX1_1:IkJPBPM6<3SfEE181EAPAgBc`4Me1317MEB@AgFTl3N5iE17USG0AjJF84
O6iX17icK`B0NGH4PWil5Oooo`005?ooo`B?Shl4VIZJ1:BVYPB_/K44^[fn0lG:bPCAe]L4gN?T1>W`
l@Cco?d4k?Oj0n[bm0CWk>d4eMcO1;_9c`BT]kl4Z;[11:fm`P>c`<@4^<?61;g6a`C2bLT4a<W91<O:
bPC1aLD3^ko01;Rj^PBf]kH4^;Fc1;jf/PC5^[D3c<6k1=?7`@CIb/84g<S01=c4^PCK`;@4e[NZ0mZg
Z@CK]ZH4dJfO1<ZUU`C7XI84_iZ;0k^EQPBgSh04]H]j1;66M0B]PG04Zge[1:=eH`>?I5@4OE=417E:
>`AeCd44ME=717EHC@=fG5@4Mf9J17UWH@AkKFL4OG9^17mhM@B2OW`Eoooo000Doooo18n?S`BIVYX4
Y:JV1:na/@Bj_Kh3aL[:1=7Fe`CMhn@4jO3a1??lo@C/moX3j_;d1>O/k@CEg=l4^lW?1:Bg_`BX^/44
[Kg20k?0a0Bh`lH4_LK71<;9b@C4bLT4al[:1<75a@>k_l04^;Zj1;Jg]PBh]K<4_[Jb1<Fj]@?<`K/4
dlO11=W:`PCLb<04g<Bj1=_0]0CF]jX3f[NY1=^fYPCA[Il4bZFG1<NQTPBoVX/3^iF61;N?P0BeRgX4
/HId1:f1L0B[OF/4XgES0hmTE0AmDd@4MDXk17E?@@AeDdL4MEQ=0gILE0AgHUX4NFMQ17]]I`AmLVh4
OgQe189nO1Goool001Coool4Shn?19VJVPBTYZH4[k6a1;Zm_P?5b/X4dMKG1=gSi0CYl?44locm1>cg
nP?Zl_@4inc]1=GLg`BkbLl4Y;No1:Rj`@B]_L83/l341;S3aPBma/L4`/W91<C9b@C7b/X4`LG50k^o
`0Bh^[X4][Nf1;Re/`Bn][84aKZe0lc1^`CCal44fL[21=c8`0CLa;X4fl2d1=JgZP?J]jT4fkJV1=6]
W`C:YIL4aj6B1;nJR`>kUHH4]hn01;F;NPBaQW@4[H5`1:]mJ`BSMF<3SfAD17eCA0AeBS/4MDm117EC
A`AeF4d3MUaD17MRFPAiIf44NfeW17ebKPAoN7D4PWil5Oooo`005?ooo`B?Shl4VIZJ1:BVYPB_/K44
^[fn0lG:bPCAe]L4gN?T1>W`l@Cco?d4k?Oj0n[bm0CWk>d4eMcO1;_9c`BT]kl4Z;[11:fm`P>c`<@4
^<?61;g6a`C2bLT4a<W91<O:bPC1aLD3^ko01;Rj^PBf]kH4^;Fc1;jf/PC5^[D3c<6k1=?7`@CIb/84
g<S01=c4^PCK`;@4e[NZ0mZgZ@CK]ZH4dJfO1<ZUU`C7XI84_iZ;0k^EQPBgSh04]H]j1;66M0B]PG04
Zge[1:=eH`>?I5@4OE=417E:>`AeCd44ME=717EHC@=fG5@4Mf9J17UWH@AkKFL4OG9^17mhM@B2OW`E
oooo000Doooo18n?S`BKViX4YZNW1;6c/`Bm`;l3b/g=1=OJfPCUjNT4mo_k1?[oo`C^mOL3jno`1>KY
j@CAf=/4]/G<19nc_0BU][d4Z[Zo0k6o`PBf`L<4^/;31;o5a@C2a/H4`lK51<73`P>m_kh4^KVh1;Ne
]0Bj]K84_kJb1<Fj]@?=`KX4e<O01=[8`0CLakl4g<>i1=Zn/`CG]j/3ekJX1=RdY@C:ZI/4aj>E1<>N
T0BiUXP3]Y631;F<O0BfRWT4]8Me1;63L@BaP6d4XgAR0heSD`AiDd@4LdPj179<?`AbDDD4LUE;0g=J
DPAeH5P4MfEO17U[IPAlLFd4OWMd185nO1Goool001Coool4Shn?19^KVPBVYjL4/K>c1;g0_`?:cLd4
em[J1>GYj@Cgno/4n_oo1>kem`?[ko04i^WY1=7Hf`BfaL`4Wk>l1:Ff_@BZ^[l3/Ko21;K1``Bj`/<4
_lG51<;6aPC3a/D4`L?20kfo_PBi^KP4]kFd1;Ze/PBo][84aKZe0lg1^PCDal04f/S01=c7_`CL`kT4
f[jc1=NgZ`?G]ZP4f;BU1<ZYV`C7XiD4`ij@1;VFR0>fTH<4]Hal1;J:N@BdQgD4/H=a1;60K@BSM683
SF=C17UCA0AcB3X4LT`o179AA@AbED/3LeYB17EPF0AgIEl4NF]V17aaK@AnMg@4PGil5Oooo`005?oo
o`B?Shl4Vi^J1:JWY`Ba/k<4_L2o0l[=c@CGf]X4iNWY1?Okn`Cjool4k_Gg0n__l0CVjNT4dMSK1;K5
c0BO/k`4YKJm1:Zj_`>a_l84]/731;[2``BoaLD4`/K61<?6a@C1`l83_Knn1;Vi^0Bg]K@4^[Fb1;nf
/PC5^[D3cL6j1=C7`0CJb<04g<No1=c3^@CJ_[<4ekN[0mNfZ0CH]:D4bZVK1<NSU@C3WY04^IJ80kJA
P`BeS7`4]XYi1;B7M@BaPg44/H1]1:=dHP>=He<4NE=417=8>PAbC3l4LU55179EB`=cFU84MF1H17MU
G`AiJfH4O75]17igM0B1OW`Eoooo000Doooo18n?S`BKViX4YZNW1;6c/`Bm`;l3b/g=1=OJfPCUjNT4
mo_k1?[oo`C^mOL3jno`1>KYj@CAf=/4]/G<19nc_0BU][d4Z[Zo0k6o`PBf`L<4^/;31;o5a@C2a/H4
`lK51<73`P>m_kh4^KVh1;Ne]0Bj]K84_kJb1<Fj]@?=`KX4e<O01=[8`0CLakl4g<>i1=Zn/`CG]j/3
ekJX1=RdY@C:ZI/4aj>E1<>NT0BiUXP3]Y631;F<O0BfRWT4]8Me1;63L@BaP6d4XgAR0heSD`AiDd@4
LdPj179<?`AbDDD4LUE;0g=JDPAeH5P4MfEO17U[IPAlLFd4OWMd185nO1Goool001Coool4T8n?19^K
V`BWZ:L4/kBd1<31`@?=cll4fmgM1>_]k@Cmooh4moWi1>obl`?Uj>X4gN7R1<KAe@B``<L4Vk2i1:6c
^PBW][/3[KZm1;>l_`Bi`<44_L;21<74a0C3aL<4`/;10knn_0Bl^[P4^kNe1;^d/@C0][84a[^e0lk1
^`CEa[l4f/No1=g8_PCMa;T4fkjb1=RhZ`?G]JL4djnQ1<JVV@C3X9<4_Y^=1;JCQ@>fT844^8el1;R;
N@BgR7D4]XEb1;F2KPBQLf03RF5A17IA@`A_ACL4KTTm16i>@PA_DTT3L5Q?179NEPAdI5d4MfYU17Y`
K0AmMg@4PGek5Oooo`005?ooo`B@Shl4Vi^K1:NXY`Bc];@4`<710lg?c`CKgMd4jng]1?gooPCgnOT4
ko;c0nGXjPCMhN84a]7E1;30a`BK/;T4XK>j1:Nf^`>]^[d4/kbo1;W0`@Bm`/84`LC41<?5``C2`/43
_kjl1;bj^0Bk]kD4^kBa1<2f/PC6^kD3c/6k1=G6_`CJakl4gLRn1=g4^@CK_[84f;R[0mNeY`CC[j44
aZJI1<>PT`BnVhd4]Y>50kJ@P@BhSG`4^8]i1;N8M@BfQG84]H9^1:5cH0>9HE44MU5316m5=`A^BCd4
KTi216mBB@=`F4l4LUiF17ATG@AgJVD4NW1/17egM0B1OG/Eoooo000Doooo192?S`BKVi/4YjRW1;>d
]0C0`L43cLo?1=_Mg@C[kNd4oOon1?Oin@C_l_<3iNSZ1=gQhPC6dMD4/<3719^`^@BQ/kX4YkJk0jfj
_@Bc_;l4^L311;g2`PC1a<@4`lG31<;2`@>o_[`4_;Zh1;^g]@Bk];44`;Jb1<Jk]@?>`K/4eLJo1=[7
_`CMb;h4gLBi1=^n/PCH^:/3ekFW1=>_X@C6YYT4`j2C1;jKS@BfThD3]Y211;R=O0BhRgT4]hQe1;J5
LPBePVh4XG=P0hUQD@AfDD<4KdDg16i9?@A^CT84Ke990g1HC`AbGUH4M6AM17MZI@AjL6`4OGMd185m
NaGoool001Coool4T92?19bLV`BYZJP4]KJe1<;3`P?@dM04g]oN1>k_kPCoooh4n?Sh1>o`l0?SiNL4
e=[M1<3;d0B[_<84VZjf19j_]PBT/[L3Z[Fh1:nh^PBd^[/4^;bl1;bm_0Bj_;/4^[Zj0kRg]PBh]K@4
^;>a1;Zb[`C1]k84b;bf0lo2^`CEaKd4f/Nm1=g7_0COaKT4g/2c1=Zi[0?G]JL4dZnQ1<bXVPC7XY@4
`I^=1;bFQP>lTh84_91m1;b=NPBkRgL4_8Qd1;R3KPBOLEl3Pee>17IA@`A/@cD4JTHj16U:?`AZCdH3
K5E=16mKE0AbHU`4MFQS17U_J`AlMW<4P7ek5Oooo`005?ooo`B@T8l4W9bK1:VYZ0Be][D4`/?20m3A
d0CNgmh4k^o^1?oooPChn?P4ko3`0n?Ui`CDf]d4`<_@1:^l`PBJ[[H4WZnf1:Bb]`>Z]KP4[kRj1;Bj
^`Bh_;`4_;fl1;Zl^`Bj^[X3^;Nf1;Re]0Bh/k44^[:_1<6g/PC8_;H3cl:k1=G5_@CJakd4gLNl1=o5
^@CN`;<4f[V/0mNeY`CB[j44c:RJ1<NRU0C1Vhd4_9J60kbCPPBlT7d4_8ej1;^;M`BlR7@4^8=^19ma
G`>3GDh4MU5316a3=@AZASX4JDXo16Y?AP=/EDd4Ke]D179RG0AeJ6<4NFm[17afL`B0OG/Eoooo000D
oooo192@S`BLW9/4ZJVX1;Ff]@C2`l83d=7@1=kOgPC^knh4ooon1?Shn0C_l?03hnGW1=CJg@C0bm04
Zkc219Z^]PBN[kH4Y;:g0jZe^0B_^;X4];Zk1;Rl_0Bl_K`4^[bk1;Zj^P>h]kH4^;Fd1;Rc/@Bj/Zl4
`KNb1<Rl]P??`[/4eLFm1=[7_@CMak`4glFi1=k0/`CJ^J`3ekFW1=:_X@C<Z9X4aj:D1<6KS@BlUXH3
_9>21;b@O@BlSGX4^h]g1;b8M0BhPfh4Wg5O0h=MCPAfDD<4K4<e16Y6>PAYBSl4JTm60faEC@A_Fe@4
LV9L17EXH`AiKf/4O7Ic181mNaGoool001Coool4T92?19bLV`BYZJP4]KJe1<;3`P?@dM04g]oN1>k_
kPCoooh4n?Sh1>o`l0?SiNL4e=[M1<3;d0B[_<84VZjf19j_]PBT/[L3Z[Fh1:nh^PBd^[/4^;bl1;bm
_0Bj_;/4^[Zj0kRg]PBh]K@4^;>a1;Zb[`C1]k84b;bf0lo2^`CEaKd4f/Nm1=g7_0COaKT4g/2c1=Zi
[0?G]JL4dZnQ1<bXVPC7XY@4`I^=1;bFQP>lTh84_91m1;b=NPBkRgL4_8Qd1;R3KPBOLEl3Pee>17IA
@`A/@cD4JTHj16U:?`AZCdH3K5E=16mKE0AbHU`4MFQS17U_J`AlMW<4P7ek5Oooo`005?ooo`BAT8l4
WIfL1:VZZ@Bf][D4a<C30m7Ad0CPh=l4kno^1?ono@ChmoH4k>g]0moRh`C@emT4_<S=1:Ri_`BI[KD4
Vjbc1:6_/`>W/[@4[;Bf1;6f]`Bd]kL4][Jf1;Fe]@Bg]K@3]kBb1;Rd/@Bi/k04_[Fb1<Bj]0C;_kT3
d<>k1=K4_0CJaK`4g<Fj1=k2]`CN_k84g;Z/0mZgZ0CD/:44cjZJ1<^TU@C7Whl4`iZ90l:FQ0C0Th04
_hmk1;n=N0C2S7H4]h9/19a_G0>2GDh4NE=416i6>0AT@SH4HdHk16E;@P=WDTX4JeQB16mOFPAcIV84
MfiZ17]eLPB0O7/Eoooo000Doooo196@S`BMWI`4ZJZY1;Jf]@C4a<<3dM7@1>3Pg`C_knh4ookm1?Sg
mPC/kNd3gn;S1=3Gf@Blb<d4Z;Vo19V]]@BK[;<4XJnc0jNb]0B/];H4/KJg1;Bg]`Bf][H4]KFe1;Ne
]0>g];84^;Ba1;Vc/0Bn]K84a;Zd1<^o^@?@`k/4e/Bl1=[5_0CLaKX4g/:g1=jo/PCL^Z`3f[NX1=B`
X@C?ZYX4bjBE1<NOS`C3VXT3`YJ41<2CP0BoSg/4_heh1<:<MPBgPV`4W6mL0h9MCPAiDd@4KTHh16A2
=PASAS/4ID]20fMBBPA[F584KemJ17=VHPAgKVX4NgEb181lNaGoool001Coool4TI2?19fMW0BYZZT4
][Je1<C4``?AdM04h>3O1>o_kPCoo_d4n?Of1>c]k@?Oh^<4d=OI1;c8c@BX^Kl4VJfe19^//`BQ[k<3
Yk:d1:bd]PBa][L4];Ng1;Jf]PBe]KD4]kFd0kNd/PBh];44^K>`1;je/PC4^[@4bkni0m33^`CFa;`4
f/Fl1=c5^PCN`[L4g[nb1=bj[0?J]jP4e;2Q1<nZVPC;Y9D4ain?1<>JR@?2UX@4`9>01;n?N`BoSGP4
`Xaf1;N2K0BLKe`3PUe>17UCA0A^ASP4I48f16=6>`AUBd83Ie9:16]HDPA_GeX4LfIR17M^JPAkMG84
P7ak5Oooo`005?ooo`BAT8l4WIfL1:VZZ@Bf][D4a<C30m7Ad0CPh=l4kno^1?ono@ChmoH4k>g]0moR
h`C@emT4_<S=1:Ri_`BI[KD4Vjbc1:6_/`>W/[@4[;Bf1;6f]`Bd]kL4][Jf1;Fe]@Bg]K@3]kBb1;Rd
/@Bi/k04_[Fb1<Bj]0C;_kT3d<>k1=K4_0CJaK`4g<Fj1=k2]`CN_k84g;Z/0mZgZ0CD/:44cjZJ1<^T
U@C7Whl4`iZ90l:FQ0C0Th04_hmk1;n=N0C2S7H4]h9/19a_G0>2GDh4NE=416i6>0AT@SH4HdHk16E;
@P=WDTX4JeQB16mOFPAcIV84MfiZ17]eLPB0O7/Eoooo000Doooo196@S`BMWI`4ZZZY1;Nf]@C5a<<3
d];@1>7PgPC`k^d4oogk1?Oem0C[jn/3g>3Q1<gDe`BhaLX4YkNn19R/]0BIZ[04WZb`0jB_/@BZ/K84
[[>c1;:d]0Be]K@4]kJd1;Vf]@>j][@4_;Ne1;ni]@C3^kH4akfh1<g1^`?Ba;`4e/Fl1=W5^PCK`kP4
g<6e1=fn/0CI^:/3ekBV1=B_X0CCZi`4cjNF1<bRT0C8WH/3aIV61<:CO`C1T7`4a8mj1<F=MPBdOfX4
VfeK0hIOC`AgDT<4JD<f15Lh;@AK@3H4GTLn0f9>A`AWEDl4JeeH171UH0AeK6T4NWAb17mlNQGoool0
01Coool4TI2?19fMW0BZZZT4]kJe1<G4``?Bd]04hN3N1?3^k@CooO/4moGd1>_[j`?Lh>44cMCG1;S5
bPBW]kh4V:bd19VZ/0BN[;03Y:na1:Za/PB^/k<4/[Bd1;Fe]0Bg][@4^KJe0kZf]0Bl]kD4_kVe1<>k
]PC7_KP4cL6k0m;4_0CFaK`4fLFj1=_3^0CL`KD4gKj`1=VhZ`?G]:H4e:nP1=>[W0C?YiH4c::@1<RM
R`?5VHH4`Y=o1<6@O0C4SgX4aHef1;AoJPBKKE/3QUm?17MB@`AY@cH4EcP]15]0=PANAch3HTi716ME
C`A[GEP4L6EP17E/J@AjM784Ogaj5Oooo`005?ooo`BAT8l4WIfL1:ZZZ@Bg][D4aLC30m;Bd0CQh=h4
l>k]1?omn`CgmO@4jn_[0mcPh@C=e=L4^<G:1:Ng_PBH[;@4VJZ`19j//0>T[k44Z[6b1:jc/`Bb];@4
]KFd1;Nf]0Bi][D3^[Jd1;bg]@Bo^KD4`k^f1<Nm^0C=`K/3d/Bl1=K5_0CIaKX4fl>h1=c1]@CM_[04
fKR[0mNdYPCD[j04dj^L1<nWUPC<XY04b9f;0lFIQPC2Tgl4`I1l1<B?NPC5SGH4]7mZ19]]F`>6Gdl4
Me9316U3=PAG>2d4Fd0f15i7?P=RCTL4IeE?16]MF0A`IF04MFaY17YdLPAoO7XEoooo000Doooo196@
S`BMWI`4ZZZY1;Nf]@C5a<<3d];@1>7PgPC`k^d4oogk1?Oem0C[jn/3g>3Q1<gDe`BhaLX4YkNn19R/
]0BIZ[04WZb`0jB_/@BZ/K84[[>c1;:d]0Be]K@4]kJd1;Vf]@>j][@4_;Ne1;ni]@C3^kH4akfh1<g1
^`?Ba;`4e/Fl1=W5^PCK`kP4g<6e1=fn/0CI^:/3ekBV1=B_X0CCZi`4cjNF1<bRT0C8WH/3aIV61<:C
O`C1T7`4a8mj1<F=MPBdOfX4VfeK0hIOC`AgDT<4JD<f15Lh;@AK@3H4GTLn0f9>A`AWEDl4JeeH171U
H0AeK6T4NWAb17mlNQGoool001Coool4TI2?19jMW0B[ZZT4^;Nf1<G4``?CdM04hMoN1?3]k0Cno?X4
mO?b1>_ZjP?Kgn04bm;E1;S4b0BX]kd4VZfd19VY[`BMZJh3XZb_1:R_/0B]/K44/K>b1;Fe/`Bh][@4
^[Rf0kfi]PC0^kP4`kfi1<No^PC;`K/4d<>l0mC6_@CGaK`4f/Fj1=_3]`CM`K@4gKja1=^j[0?I]JL4
e:nP1=2YVPC<Y9@4bZ2?1<JKR@?5Uh@4a9Ao1<JBO@C8T7X4aHae1;1lJ0BJJeT3QEa=175=?`AP?S84
Cc8Y15<j<@AH@SX3GDY3169BC0AXFUD4KF=O17=[J0AiLg44Ogaj5Oooo`005?ooo`BAT8l4WYfL1:^Z
Z@Bh]kH4aLC30m?Ad0CQgmh4l>g/1?klnPCelo84jn[Z0m_Oh0C;d]D4^<C81:Rg_@BJ[K@4VJV_19fY
[P>R[:l4Z:n`1:fa/@Ba/k84]KFc1;Rf]0Bj^;H3_KVf1<2k^0C3_KT4aknj1<_1^`C@`k`3e<Jm1=O5
_0CJaKX4fl>g1=g1]0CM_[44fkZ/0mVeY`CD[j04d:VJ1<bTU0C:X8l4aY^90lFGQ0C4U7l4aY9m1<R@
NPC5S7D4/7aX19Y[F@>5G4d4LDdo160n<PA?<RT4DcXa15Q2>P=MBT<4HU9<16QJE@A]Hel4Lf]X17Uc
L@AoO7XEoooo000Doooo196@S`BNWI`4ZjZY1;Rg]PC5a<<3dm7@1>7OgPC`kN`4o_cj1?GclPC[j^X3
fmoP1<_Be@Bha<P4Z;Nm19Z]]0BIZJl4WJV^0j:/[`BX[k04[K6a1;6c/PBe]K<4^;Jd1;Zh]P>m^KH4
`;^h1<>m^@C7_kX4bl6k1=33_0?Da[d4elFl1=[5^PCK`kL4gL6d1=fn/@CK^Z`3fKFW1=B_X0C@ZIX4
c:BD1<ZPS`C6VhT3aIN41<BDO`C6TWd4b91j1<F<M@B`O6P4VV]I0hELC@AaCCl4H3hb14lb:@AC>S44
F48j0ee:@`ARDT`4J5YE16eSG`AcJfP4NG=a17mlNQGoool001Coool4TI2?19jMW0B[ZZT4^;Nf1<G4
``?CdM04hMoN1?3]k0Cno?X4mO?b1>_ZjP?Kgn04bm;E1;S4b0BX]kd4VZfd19VY[`BMZJh3XZb_1:R_
/0B]/K44/K>b1;Fe/`Bh][@4^[Rf0kfi]PC0^kP4`kfi1<No^PC;`K/4d<>l0mC6_@CGaK`4f/Fj1=_3
]`CM`K@4gKja1=^j[0?I]JL4e:nP1=2YVPC<Y9@4bZ2?1<JKR@?5Uh@4a9Ao1<JBO@C8T7X4aHae1;1l
J0BJJeT3QEa=175=?`AP?S84Cc8Y15<j<@AH@SX3GDY3169BC0AXFUD4KF=O17=[J0AiLg44Ogaj5Ooo
o`005?ooo`BAT8l4WYfL1:^ZZ0Bh]kD4aLC20m?Ac`CQgmd4kng[1?kkn@Cel_44j^WY0m_Ng`C;d]@4
^/G81:^i_PBN[[D4VJV^19^X[0>QZZd4Yjf^1:b_[`Ba/[44]KFc1;Vg]@Bm^KL3`;bi1<>n^`C7`;`4
bl:m1<o4_PCCa[l3elRo1=W6_0CKaKX4g<Bh1=k2]@CN_k44gK^]0mZfY`CG/J44dZ^K1<nVU@C;X8h4
bIb90lVIQ@C9UX84bYAo1<^AN`C3RW<4[GUU19IXEP>1FDT4JdTl15Lj<0A8<2H4BS@/150m=P=GAT04
GDm:16AHD`A[HEd4LFYW17QbL0AnNgXEoooo000Doooo196@S`BNWI`4ZjZX1;Rg]@C5a<83dm7?1>7O
g@C_kN/4o__i1?Gbl@CZjNT3fmkO1<_Be0BjaLP4ZkVn19j^]@BIZJh4VjR/0j6Z[@BW[Jh4[:n_1;6b
/@Be]K<4^KNe1;fi]`?0_;T4`kjk1<O0_0C;`[d4clBn1=?6_`?Gb;l4fLJl1=_5^PCLa;P4g/:e1=jo
/@CM^jd3f[JW1=NaX@CBZi/4cjJE1<^PSPC9W8T3bIV51<VFPPC:U7l4bi5k1<>:L`B]NFD4UVQF0h5I
B@A[BC`4EcX`14P`9PA:=2`4D3df0eM6@0AMCdX4I5QC16]QG@AaJVL4N79`17ikNQGoool001Coool4
TI2?19jMW0B[ZZP4^;Ne1<G4`P?CdLl4hMoM1>o]j`CnnoT4mO;a1>[Yj@?Kg]l4bm;D1;[5b0B[^Kh4
WZje19VY[PBKZ:`3XJZ]1:N][PB/[jl4/K:a1;Fe/`Bi]kD4_KVg0l2l^@C3_[/4al2l1<_2_@C?a;h4
dlJo0mO8_`CIa[`4flFj1=c4^0CN`[D4g[na1=fk[@?J]ZL4ek6Q1=:[V`C?YYD4bj2>1<VLR@?9VHD4
bIJ21<ZDO`C;TG/4`hYc1:eiI@BFJ5H3PEU916]9?0AG>S04B30V14Xd;0A@?CH3EdI015e?BPATF5<4
Jf5M175ZI`AhLW04OW]j5Oooo`005?ooo`BAT8l4WYfL1:^YZ0Bh][D4aL?20m?@c`CQg]`4kncY1?gj
m`Cdl>h4jNSV0m_MgPC=d]@4_LK91:nj_`BQ/;D4VZV_19ZVZP>OZJ/4YZb/1:b^[PBa/K04][Fc1;^h
]@Bo^kP3`kjk1<O1_@C:`kh4c/G01=;7`0CFbL43fLVo1=_8_@CMa[/4g/Fh1=o2]@CP_k44gkb]0mfg
Y`CJ/Z44ejfL1=BYU`CBY944d:2<0lnLQ`C?VH@4ciJ01<fBN`BoQW04Z7EQ195TD`=kEDH4IDDi14lf
;0A0:b<4?b`U14Pg<@=A@S`4FDa7165FD@AXGe`4KfQV17IbK`AmNgTEoooo000Doooo196@S`BNWI`4
ZjVX1;Rf]@C5`l83dm3?1>7Ng0C_k>T4oO[g1?C`kPCYj>H3fmgN1<gBe0Bma/T4[kZo1:6`]@BJZJl4
VZJZ0inYZ`BV[:`4[:j^1;6a/0Bf]K<4^kRe1;nk^0?3_[/4al6m1<[3_PC>aL04d/O01=K9`@?IbKl4
flRm1=g6^`CNaKP4gl:e1>2o/@CO_:d3gKNW1=ZbX@CG[I`4e:VG1=:TT@C@X8`3cib71<nIQ0C?UX04
cI9k1;n6L0BXMF44TFAC0g]EAPAUACT4CcH/140[8`@o;2D4B3La0e52?0AIC4L4HEIA16QOG0A_J6H4
MW9_17ekNAGoool001Coool4TI2?19jMW0B[ZJP4^;Je1<G3`P?Cd<l4hMkL1>o/j@Cmn_L4m?3^1>WX
iP?KgMh4cM;D1;g6b@B_^[l4XK2e19ZY[`BJYZX3WjV[1:J/[0B/[Zh4/K6`1;Je/`Bk^;D4_k^h0l>n
^`C7`Kd4b/>n1<k5`0CBal04e/W10mW9_`CKb;d4gLJk1=k5^0CO`[D4h;na1=nl[@?M]jL4f[:Q1=N]
W0CDZIL4dZBA1=2PS0??W8L4ciV41<nFP0C=TW/4_hI`1:QeH@BAI5<3NeE616E5>@A?=R`4@2/S13l/
9@A8=c43DD8l15U<A`AQEU44J5mL16mXIPAfLVl4OG]i5Oooo`005?ooo`BAT8l4WYfL1:^YZ0Bh][D4
aL?20m?@c`CQg]`4kncY1?gjm`Cdl>h4jNSV0m_MgPC=d]@4_LK91:nj_`BQ/;D4VZV_19ZVZP>OZJ/4
YZb/1:b^[PBa/K04][Fc1;^h]@Bo^kP3`kjk1<O1_@C:`kh4c/G01=;7`0CFbL43fLVo1=_8_@CMa[/4
g/Fh1=o2]@CP_k44gkb]0mfgY`CJ/Z44ejfL1=BYU`CBY944d:2<0lnLQ`C?VH@4ciJ01<fBN`BoQW04
Z7EQ195TD`=kEDH4IDDi14lf;0A0:b<4?b`U14Pg<@=A@S`4FDa7165FD@AXGe`4KfQV17IbK`AmNgTE
oooo000Doooo196@S`BNW9/4ZZVX1;Nf]0C5`/43d/o=1>3Mf`C^j^P4o?Se1?;_k0CXi^D3fmgL1<kB
d`BoalT4/K^o1:>a]@BLZZl4V:FY0inWZPBVZj/4[:j^1;:b/0Bh][<4_KVf1<6l^@?6`;`4b/>n1<k5
`0CBb<84e/[21=W;`P?Kb/04gLVn1=o7^`CPaKP4hL>e1>70/@CQ_:d3gkRW1=bcXPCJ[id4f:^H1=NV
T`CEXhh3dij91=:KQ@CBUh04bXmh1;N0J`BQL5d4RUm?0g=?@PAK?c<4ABlW13HT7@@e91h4@C8/0d/n
>@AEBDD4GE=@16INFPA]IfD4MG5_17ejNAGoool001Coool4TI2?19jLV`BZZJP4]kJd1<G2`@?Bcld4
h=gK1>kZj0Cln?D4l^o/1>SVi@?KgM`4c];C1;o7b@Ba^kl4Xk6e19bZ[`BHYJT3WjNZ1:J[Z`B/[Zh4
/[:`1;Rf/`Bm^KH4`Kbi0lK0_0C:`kh4c/G01=;8`PCFb/84fL_20m_:`0CMbKh4glNk1>35^0CQ`kD4
hL2a1>6l[@?O^:L4g;>R1=Z_W@CHZiP4ejJC1=FSSP?CWXT4dY^51=:GP0C:SgP4]h1[1:5`G@B:Gdl3
Ldm215/o<`A5;bL4=R@M13DT7PA1<R`3Bchi15E9A@AMDe04IUiJ16eWI@AeLFl4OGYi5Oooo`005?oo
o`BAT8l4WYbK1:ZYZ0Bg][@4aL;10m;?c@CPgM/4k^[X1?chm@Cbkn`4j>KU0m_Mg0C>d]<4_lO91;6k
_`BS/KD4W:Z_19RUZ@>OYjX4YZ^[1:b^[PBb/[04^;Jc1;fi]PC1_;T3a/2l1<[3_PC>aL04d/S21=K:
`PCIbl83fl[01=g9_PCOak/4h<Fh1>73]@CQ`;44hKb]0mnhY`CL/j84fZnM1=R[V0CGYY<4eJ>>0m>N
R@CBVhD4dYN01<Z?N0BgP6/4XG1M18YOC`=cCd84Fclc14D_9`@f91d4=B@N144b;0=;?ST4EDU515eC
D0AVGUX4KFMU17EaK`AmNWTEoooo000Doooo196@S`BNW9/4ZZVX1;Nf]0C5`/43d/o=1>3Mf`C^j^P4
o?Se1?;_k0CXi^D3fmgL1<kBd`BoalT4/K^o1:>a]@BLZZl4V:FY0inWZPBVZj/4[:j^1;:b/0Bh][<4
_KVf1<6l^@?6`;`4b/>n1<k5`0CBb<84e/[21=W;`P?Kb/04gLVn1=o7^`CPaKP4hL>e1>70/@CQ_:d3
gkRW1=bcXPCJ[id4f:^H1=NVT`CEXhh3dij91=:KQ@CBUh04bXmh1;N0J`BQL5d4RUm?0g=?@PAK?c<4
ABlW13HT7@@e91h4@C8/0d/n>@AEBDD4GE=@16INFPA]IfD4MG5_17ejNAGoool001Coool4TI2?19fL
V`BZZ:L4]kFc1<C1_`?Ac/`4gm_I1>gYiPCkm_<4l^gZ1>OTh`?Lg=/4d=?C1<?8bPBc_;l4Y[:g19f[
/0BIYZX3WjNY1:NZZ`B][jh4];>a1;Zf]0Bo^[L4a;jj0lW2_PC=aL04dLS21=G:a0CIc<@4g<g30mk<
`@CPb[l4hLRk1>;6^0CRa;D4hl2a1>:m[0?Q^JP4gkFS1=j`WPCL[9T4fZVD1=VTS`?GX8X4eYb51=6F
O`C4Rg@4/7]V19UZF0B0FDX3J4Pl150g;@@j:244:1TD12dO6`@k;RX3Ac/g1557@`AKDTh4HeaI16aV
I0AdL6h4O7Yi5Oooo`005?ooo`BAT8l4WIbK1:ZXY`Bg]K<4a<6o0m7>c0COfmT4kNWV1?_fl`CbkNX4
inCS0mcLf`C@dm<4`lS:1;>l_`BV/[L4WJ^`19VVZP>OYjT4YjZ[1:f_[PBd/k44^[Jd1;nj]`C4_[X3
bL:n1<g5`0CAb<84eL[41=W<a0CLcL<3g/c11>3:_`CQb;/4h/Jh1>;4]@CS`;44h[f/0n6iZ0CO]J<4
g[2N1=b/V@CJZI@4fJB?0mNPRPCFW8D4dIIo1<B;M0B`NfH4VFYH181IBP=XB3`4D3L]13XX8@@X6A@4
;AlK13/^:P=7>cL4DDM315]BCPASG5T4K6IT17A`KPAlNWTEoooo000Doooo196@S`BMW9/4ZZRW1;Ne
/`C4`Kl3dLk<1=oKf@C]jNH4noKc1?;]jPCWi><3g=cK1=3Cd`C3b<X4/kbo1:Jb]`BMZk04VJJZ0inW
Z@BWZZ/4[Jn^1;Bc/@Bj][@4_kZg1<Bn^P?9`[h4cLG01=78`PCEb/@4fLc41=c=``?Nc<44h<Zo1>78
^`CRa[P4h/Be1>?0/@CR_J`3hKVX1=neX`CN/9h4g:bI1=ZYU0CIY8l3ej2:1=JLQ@CAUWl4a8]d1;1k
IPBIJUP4P5U:0fQ8?0A@=bd4>RPQ12PI50@]7a/4>bhZ0dLk=`AAAd<4Fe9>16=LF@A/IV@4M71^17aj
NAGoool001Coool4TI2?19fLV`BZZ:L4]kFc1<C1_`?Ac/`4gm_I1>gYiPCkm_<4l^gZ1>OTh`?Lg=/4
d=?C1<?8bPBc_;l4Y[:g19f[/0BIYZX3WjNY1:NZZ`B][jh4];>a1;Zf]0Bo^[L4a;jj0lW2_PC=aL04
dLS21=G:a0CIc<@4g<g30mk<`@CPb[l4hLRk1>;6^0CRa;D4hl2a1>:m[0?Q^JP4gkFS1=j`WPCL[9T4
fZVD1=VTS`?GX8X4eYb51=6FO`C4Rg@4/7]V19UZF0B0FDX3J4Pl150g;@@j:244:1TD12dO6`@k;RX3
Ac/g1557@`AKDTh4HeaI16aVI0AdL6h4O7Yi5Oooo`005?ooo`BAT8l4WI^J1:VWYPBf];84`l2n0m3=
bPCNf]L4k>OT1?[dl@C`k>T4i^?R0mcLf`CBe=<4aLS91;Jn`0B[];P4XJf`19jYZ`>QYjT4Z:^[1:n_
[PBf/k44_;Rd1<:l^0C7`;`3c<Bo1=78``CEb/@4fLg61=c>aPCOclD3hLg21>;;_`CSbK/4i<Jh1>C4
]0CT`;04i;f/0n>jZ0CQ]J<4h;6N1=j]V@CMZI@4g:F?0mZQRPCFVh@4cI9k1;b4K`BWM644SV=B17IB
A0=N@3D4AS0W130Q6P@P4`l4;20L13P]:@=4>CH4CTE215QACPARFeT4JfIT17=`KPAlNWTEoooo000D
oooo196@S`BMViX4ZJNV1;Jd/PC3`;h3d<g:1=kJe`C/in@4n_Ca1?3/j@CVhn83g=cK1=;Dd`C5b<T4
][k01:^d^0BQ[K04WZV[0j6WZ@BXZj/4[jn^1;Jc/@Bl^;@4`[bh1<O0_0?<a;l4dLS31=G:a0CIcLH4
g<k61=o?a@?QcL84h/^o1>?9^`CTa[P4i<Bd1>C0/0CT_J`3hkZX1>6eX`CP/Ih4gZfI1=fYU0CLYHl3
fZ6:1=JKQ0C=TW/4_8A_1:MdH@B>He84MU940ei0=@A6<2L4<24J120C3`@/81`4>2dY0d@i=PA>AD84
F55>169KF@A[IV@4Lg1^17ajNAGoool001Coool4TI2?19fKVPBYYjH4][Bb1<?0_P?@cLX4g][G1>cW
i0Cjm?44l>cY1>KShP?Lg=/4d]CC1<G8b@Bf_/04ZkBh1:6]/0BNZJ/3XJNY1:R[Z`B_[jh4][>a1;bh
]0C2_;P4al2l0lc4_`CAb<<4eL[41=W=aPCLc/H4glo50n7=`PCRbkl4hlVk1>C6^0CTa;@4i<2`1>Bm
[0?S^ZP4hKFS1>2aWPCN[IT4gJVD1=bUS`?JXHX4eY^41<fBN`BlQ6l4YgAQ18iSDPAfDT@3GT0e14H`
9`@`8AX481<?12`P70@h;BT3A3Tf14i5@PAHDDh4HU]I16]VI0AcL6h4O7Yi5Oooo`005?ooo`BAT8l4
WI^J1:VWYPBf];84`l2n0m3=bPCNf]L4k>OT1?[dl@C`k>T4i^?R0mcLf`CBe=<4aLS91;Jn`0B[];P4
XJf`19jYZ`>QYjT4Z:^[1:n_[PBf/k44_;Rd1<:l^0C7`;`3c<Bo1=78``CEb/@4fLg61=c>aPCOclD3
hLg21>;;_`CSbK/4i<Jh1>C4]0CT`;04i;f/0n>jZ0CQ]J<4h;6N1=j]V@CMZI@4g:F?0mZQRPCFVh@4
cI9k1;b4K`BWM644SV=B17IBA0=N@3D4AS0W130Q6P@P4`l4;20L13P]:@=4>CH4CTE215QACPARFeT4
JfIT17=`KPAlNWTEoooo000Doooo192?SPBLViX4ZJNU1;Fb/@C2_[`3cl_81=cHe@CZiN44nO;_1>kZ
i`CVh^03g=_I1=?CdPC7bLX4^l311;2g^@BV[k84Y:b^0jFZZ`BZ[:`4/K6_1;Re/PBo^[H4aKjj1<[3
_P?@al44e<_41=W=aPCMclL4gm361>;@a@?Tc/<4i<bo1>G9_0CUa[L4iL>d1>K0/0CU_J`3i;ZW1>>e
X`CR/Yh4hJjI1>2ZU0CNYHl3fZ2:1=BIP@C8SGL4/giY19a]FPB3Fd/4K4/m0e@j;`@j:20491TD11X@
30@Y7a/4=R`Y0d4i=@A<AD84Ee1=161KF0AZIF<4Lg1^17ajNAGoool001Coool4T8n>19bKVPBYYjD4
]K:a1<:n_0??blP4g=SE1>[Uh@Cil^l4k^[W1>KRh0?LfmT4dm?B1<O9bPBk`<44/;Ni1:J_/PBT[:h3
YJZ[1:Z/[0Ba/Jl4^;Fb1;nj]PC5_[X4b/>n0m37`@CDbl@4fLg61=g?a`COd<H4h]350nC>``CTc;l4
iLVl1>G6]`CU`k@4i/2`1>Fm[0?T^ZL4hkFS1>:bWPCQ[YT4h:ZD1=jUS`?JX8X4e9V11<R=M`BcOVT4
W6eJ18=KB`A/Bcd3E3X_13XX80@T6A@46Q0<12TO6`@f;2T3@CTe14a5@PAGD4d4H5]H16YUH`AcL6h4
O7Yi5Oooo`005?ooo`B@Shh4W9^J1:VWY@Be/[44`[jl0lo;b0CLf=D4j^GQ1?Wbk`C^j^L4i^;P0mcK
f@CCdm84alW:1;_0`@B`]kT4YZnb1:B/[P>UZZ/4ZZb/1;6a[`Bh]K84_kZf1<Fn^PC:`kh3d<O11=C;
a0CIcLH4gLo71=o@aPCRd<D3i<k31>C<_`CUbK`4iLJg1>G3]0CV`;04iKf/0nBjY`CS]J<4h[:N1>6^
V@CPZY@4gZF?0mZPRPCDVH44b8eg1;=nJ@BLKEX4Pe];16a;?@=D>Rl4>RPP12@I50@J40`4:AlK13H/
:@=1>CD4C4E215M@C@APFeP4JVES17=`KPAlNWTEoooo000Doooo192?SPBLVYT4Z:FT1;Ba[`C0_KX3
cLW61=[EdPCWh]h4m^o/1>gXi@CUh=h3g=WH1=CCdPC:bl/4_l;21;Fj^`B^/kD4Zk6b0jR][@B][Jd4
];:`1;^g]0C2_;P4b<6l1<k5_`?DbL<4f<c51=g?a`CPdLP4hm;71>GBaP?Vcl84i/bn1>K9^`CVa[L4
ilBc1>O0[`CV_J/3iKVW1>FeXPCS/Yd4hZfI1>:YU0CNYHh3fIj71<jDO@BmQW44YgER18mTD`AgDdD4
Gd8g0dHa:0@/7QT45Pd911P?30@W7Q/4=2`Y0d0h=PA;A484EE1=15mKF0AYIF<4LVm^17]jNAGoool0
01Coool4T8n>19bJV@BXYJ@4];6_1<2m^P?=bLH4f]GB1>ORgPCfkn`4kNSU1>GPgP?LfMP4e=?B1<[;
b`Bo`/84]KZk1:jc]@B[/K83Z:f]1:f][@Bd/[04^kNd1<:l^0C8`K`4c/Fo0mC9``CHc<D4gLo71>3A
b0CSd/L4iM;60nK?`PCVc;h4i/Vk1>K6]`CWa;<4il2_1>JmZ`?U^JL4iKFR1>>bW@CR[IT4hZVD1=jU
SP?IWXL4cYAm1;f6L@BWMF84SfAC17MCA@AO@SL3AS4X12`N6@@F3@T460l<12LN6`@d;2T3@3Pf14]4
@PAED4d4Ge]H16UUH`AbKfh4NgYi5Oooo`005?ooo`B@Shh4W9ZI1:RUY0Bd/Jl4`;fj0lg9aPCJeM84
in;N1?K_k0C]j>D4iN3N0mcIf0CDdm84b/_;1;o2`PBe^[/4[[>e1:^a/P>X[Jd4[Jf]1;Bb/0Bk]k@4
`[bh1<S1_0C>aKl3e<W31=S<a@CMclL4h=781>?Ba`CUd/H3i/o21>K<_PCVbK/4i/Jg1>O4/`CW`:l4
i[f[0nFiY`CU]J84hk:M1>:]V@CRZI@4gZF>0mVNQ`C>U7d4_HIa1:MeHPB?I5<4Me=515m2=`=6<BP4
;1hI11H=2@@H3``49ahK13@/:@=0>3H4BdA215E@C@AOFeP4JFES179_KPAkNWTEoooo000Doooo192?
SPBLVYT4Z:FT1;Ba[`C0_KX3cLW61=[EdPCWh]h4m^o/1>gXi@CUh=h3g=WH1=CCdPC:bl/4_l;21;Fj
^`B^/kD4Zk6b0jR][@B][Jd4];:`1;^g]0C2_;P4b<6l1<k5_`?DbL<4f<c51=g?a`CPdLP4hm;71>GB
aP?Vcl84i/bn1>K9^`CVa[L4ilBc1>O0[`CV_J/3iKVW1>FeXPCS/Yd4hZfI1>:YU0CNYHh3fIj71<jD
O@BmQW44YgER18mTD`AgDdD4Gd8g0dHa:0@/7QT45Pd911P?30@W7Q/4=2`Y0d0h=PA;A484EE1=15mK
F0AYIF<4LVm^17]jNAGoool001Coool4T8j=19^IV0BVY:84/Zn]1;jj^0?:a/<4em;?1>CNf`CbjnL4
kNKS1>COg0?LfML4e]?B1<g<bPC3a<<4^kfl1;Fh^0Ba];@3[K2`1;6`[`Bh];84_kZf1<Jn^@C<`kd4
dlO00mS;``CMc/D4hM371>GCb0CWdlP4j=;50nW?`PCXc;d4j<Vj1>O6]PCX`k<4j;n^1>NlZP?V^:D4
iKBQ1>BaW0CS[9L4hJRB1=bSS0?DVH84aHag1;9mJ@BJK5X4PU]<16];?PAC>S03>BPQ124G4P@@20H4
6a<A12LP7@@c;2X3?cTf14Y4@PAED4h4Ge]I16UUI0AbL6h4NgYi5Oooo`005?ooo`B@SXd4ViVH1:JT
XPBb[jd4_[Zh0l[6``CGd/l4i=kK1?;[i`C]i^<4i=oL0mcIe`CFdm84cLc:1<?4``Bk_K`4]KRh1;6d
]0>]/;04/K2_1;Rd/PBo^[H4a[ji1<c3_@CCal03f<_31=g>a@CQd<L4iM?81>OCb0CXd/D3jLo21>S<
_@CXbKX4ilJf1>S3/`CX_jh4ikbZ0nJhY@CU]:44i;6L1>>/U`CQZ984g:><0mBIPPC5S7L4/WeY19Y/
FPB2Fd`4Jd/n15<j<0<i:2448ALB11081P@K4a449b0M13</:P<o>CH4BTA215E@CPAOFeT4JFET179`
KPAkNWTEoooo000Doooo192>S@BKVIP4YZBR1;:_[@Bn^[P3b/K31=OBc`CTg]/4l^_W1>gVh`CTgm`3
g=WG1=KCdPC=c<X4`lC31;^m_0Be^;P4/KBd0jf`/0Ba/:l4^;Bb1;nj]PC6_[T4c<>m1=?7`0?Hbl<4
gLk51>7@a`CUdlP4im?81>SBa@?Ycl84j<bm1>S9^PCWa[H4j<>c1>Ro[PCW_:X3i[RU1>FdX@CT/I`4
hjbG1>6XTPCLXh`3e9V21<F<M`BbOFT4VVaJ189KC0A[Bch4DcX`0cTX8@@Q5a8440P611/C4@@W81d4
<b`Z0cli=PA:A484EE1>15mKF@AYIF@4LW1^17]jNAGoool001Coool4T8j=19^IV0BVY:84/Zn]1;jj
^0?:a/<4em;?1>CNf`CbjnL4kNKS1>COg0?LfML4e]?B1<g<bPC3a<<4^kfl1;Fh^0Ba];@3[K2`1;6`
[`Bh];84_kZf1<Jn^@C<`kd4dlO00mS;``CMc/D4hM371>GCb0CWdlP4j=;50nW?`PCXc;d4j<Vj1>O6
]PCX`k<4j;n^1>NlZP?V^:D4iKBQ1>BaW0CS[9L4hJRB1=bSS0?DVH84aHag1;9mJ@BJK5X4PU]<16];
?PAC>S03>BPQ124G4P@@20H46a<A12LP7@@c;2X3?cTf14Y4@PAED4h4Ge]I16UUI0AbL6h4NgYi5Ooo
o`005?ooo`B?SXd4VYRG1:FSX@B`[J/4^kRe0lO3`0CCc//4h=[F1>kWh`C[i>04i=kK0mgHe@CGdm04
d<g:1<O5a0Bo_[d4^KZi1;Jg]P>d];<4][>a1;bg/`C3_KP4b/6k1=76_PCGbL43gLg41>7@aPCUd/L4
jMG91>_Eb0C[d/D3jlo11>W;_0CYb;P4j<Fe1>S2/@CX_Zd4ik^X0nNgY0CU/il4i:nJ1>:[U@CNYHl4
eij70l^BO0BhPfl4XgAQ18aSD`AeDTD4Gd8g14Da:0<[7QT45`l=10/610@J51849b4O13<^:`<o>SP4
BTE315E@C`AOFeT4J6IT179`KPAkNWTEoooo000Doooo18n>S@BJV9L4YJ>Q1;2]Z`Bk^;D3al?01=?>
b`CPf]H4k^OS1>_Th0CTg]/3gMSE1=OCd0C@cLX4alG41;nn_@Bi^[T4][Nf0kBd/`Bf/k44_;Nc1<>m
^0C:`K/4dLJn1=O9`@?McL@4hM361>GBa`CYeLT4jmG81>_Ba@?[cl44jL^l1>W8^0CXaKD4j<:a1>Rn
[@CW^jP3ikNT1>FcW`CT[iX4hZ^E1=jUS`CGWXL3bi9l1;R3K`BSM644S6=C17EBA@AO@SL4AC4X0b/N
6@@G3`d42`H411XD4P@W8Al4<bh[0clj>0A:AD<4EE1?15mKF@AXIV@4LW1^17]jNAGoool001Coool4
Shj=19ZHU`BUXj44/:f[1;^h]@?7`l04dlk;1>3JePC^in<4jnCP1>CNf`?Mf=D4em?@1=3=bPC7aL@4
_kjm1;Vj^@Bf]kH3];Bc1;Jc/@Bl]k<4`kfh1<[1^`CAa[h4elW10mg=a0CQd<H4iM;71>WEb@C[eLP4
jm;50n_?`@CYbk`4jLRh1>S5]@CX`[44j;j]1>NkZ0?W]j@4iK>O1>B_VPCRZiD4gZF?1=NNQ`?;TW`4
^8=_1:=dH@B<He<4ME9515m2=`A5<BP3:ahI11L?3@@;1P@46Q@B12LQ7`@c;R/3?cXh14Y5@`AED4l4
Ge]I16QVI0AbL6h4NgYi5Oooo`005?ooo`B?SXd4VYRG1:FSX@B`[J/4^kRe0lO3`0CCc//4h=[F1>kW
h`C[i>04i=kK0mgHe@CGdm04d<g:1<O5a0Bo_[d4^KZi1;Jg]P>d];<4][>a1;bg/`C3_KP4b/6k1=76
_PCGbL43gLg41>7@aPCUd/L4jMG91>_Eb0C[d/D3jlo11>W;_0CYb;P4j<Fe1>S2/@CX_Zd4ik^X0nNg
Y0CU/il4i:nJ1>:[U@CNYHl4eij70l^BO0BhPfl4XgAQ18aSD`AeDTD4Gd8g14Da:0<[7QT45`l=10/6
10@J51849b4O13<^:`<o>SP4BTE315E@C`AOFeT4J6IT179`KPAkNWTEoooo000Doooo18n=S0BIUiH4
Xj6O1:j[Z@Bi]K<3a;nm1<o:a`CKeM44in3L1>WRgPCTgMT3g]SD1=KAc`CAcLX4bLK41<6o_@Bm^kX4
^[Vg0kZg]@Bk][<4`K^f1<No^@C>`[/4e/Ro1=c;`P?Qcl@4iM761>WCa`C]eLP4l=K81>kBa0?/c[l4
j/Zj1>W6]PCXa;<4j<2_1>NmZ`CV^JH3iKFQ1>BaW0CQ[9L4gZNB1=NPRPC>UX03_HQd1:UiIPBDJUT4
OEU:16I8?@A?>2h4=BHP0ahE4P@;1P@42PH411XE50@X8b44=2l]0d0k>@A;ATD4EE5@15mLFPAYIVD4
LW1_17]jNAGoool001Coool4Shf<19VGUPBSXIl4[Z^Y1;Ve/`?4_kd4cl[71=_Ed@CWh=`4jN;N1>CM
f@?Nf=@4e]7?1=7=bPC9a/@4`Knm1;fk^PBj^KL3^[Ne1;^f/`C1^kH4akni1<k2^`CFb;l4g<_20n7?
a0CUdLH4jM?71>gEb0C`e/P4k];40nc>_`CZb[X4jLJf1>S4/`CX`:l4ikf[1>JiYP?U]J44i;6L1>6/
U`CNYi84ej2:1<jFP0>mR7@4ZGUV19AZF@AmFDX4ITPm14lh;P@e9R037QDB10/610@:1P@46QDD12PS
8@@d;bd3@3/i14]6A@AEDE04GeaJ16UVI@AbL6l4NgYi5Oooo`005?ooo`B?SH`4VINF1:>QW`B^ZjT4
^KFc0lBo_@C?b/L4fmGA1>OPg0CYh]h4i=gI0mkHe0CFdLl4dLg:1<W6a0C1_kd4_K^j1;Zi]`>j]kD4
^kJc1<6k]PC7_kT4c/:k1=K8_`CLbl83hLo41>GAaPCYdlL4kMG81?3Fb0C^d/@3k<jo1>[:^PCYa[H4
j<Bc1>S0[`CW_J/4i[VV0nFeX@CT/I`4hJbG1=jWTPCGX8X4cYJ00kf8M0BYNFH4U6YI17eIBPAVB3d4
CcP^13DV80<N5A842`H410X610@J5A@4:2<Q13@_;@=0>cT4BdI515EAD0AOG5X4JFIU179`K`AkNWTE
oooo000Doooo18n=S0BIUiH4Xj6O1:j[Z@Bi]K<3a;nm1<o:a`CKeM44in3L1>WRgPCTgMT3g]SD1=KA
c`CAcLX4bLK41<6o_@Bm^kX4^[Vg0kZg]@Bk][<4`K^f1<No^@C>`[/4e/Ro1=c;`P?Qcl@4iM761>WC
a`C]eLP4l=K81>kBa0?/c[l4j/Zj1>W6]PCXa;<4j<2_1>NmZ`CV^JH3iKFQ1>BaW0CQ[9L4gZNB1=NP
RPC>UX03_HQd1:UiIPBDJUT4OEU:16I8?@A?>2h4=BHP0ahE4P@;1P@42PH411XE50@X8b44=2l]0d0k
>@A;ATD4EE5@15mLFPAYIVD4LW1_17]jNAGoool001Coool4SXf<19RFU@BRWih4[:VW1;Jb/0?0_;T4
blG21=G?c0CPfMD4j>3L1>CLf0?Me]<4em7>1=;<b@C;al<4`l2m1<2l^PBm^KH3_[Vf1;ji]@C3_;H4
b;ni1=73_0CKbKl4hLg20nG@a@CXdLD4k=?61?3Ea`Cae<D4k]310n_;_0CZb;P4j<Bd1>O1/0CW_J`4
ikZX1>BfX`?R/Id4h:fH1=bXT`CFXH`4cIN21<2;M`>^OV/4VVmN18AOD0A]CT84EShd13h]9P@V71P3
4Pd;10<100@?30X47ATG12TU90@e<S03@Cdl14a8A`AFDe44H5eL16UWIPAbLFl4NgYi5Oooo`005?oo
o`B>SH`4V9JE1::OWPB/ZJL4][:`0l2l^@C;aL84eLo<1>3Ie@CXh=`4i=cH0mgFd`CGdLh4d/c91<_7
``C3`;d4`;bj1;fi]P>n^KH4_[Ve1<>l]PC8_kT4dL>l1=_9_`CQcL83iM351>SAa@C/dlH4l=G71?7D
a@C^d<43jl^l1>[8^0CXa;@4il6`1>Nm[0CW^ZP4i;JS0n:aW@CP[IP4g:RC1=JQS0C=Uh84`8]g0jin
J`BJKeh4Q5m@16e>@PAF?S@4?RdV12HL60<B3@/40`4010l<2P@M6AL4:BDT13Db<0=1?C`4C4Q715IC
D@APGE`4JFMV179aK`AkNWTEoooo000Doooo18j=S0BHUYD4XYnN1:bYY`Bf/[03`;bi1<_5`PCEcl`4
h=WE1>SPg0CTg=P3gMKC1=OAcPCBc<T4blO31<?0_@C0_;X4_KVf0kji]PBn^KD4`kbf1<Ro^@CA`k`4
flVo1>7=`P?Ud<D4j=751>cCaPC`eLL4lMC51>k@`@?[bk`4j/Rh1>S4]0CW`K04ikf/1>NjZ0CT]Z<3
h[6M1>2]V0CLZ9<4eZ6<1<fGPPC0RgL3[Wi[19Y_GPB4Ge04KDi215Hn=0@n;BH49Q`H0a8=2`@30@04
3``:11dI5`@Y9B@4=C8`0d4m?0A<B4L4EU=A161MG0AYIfH4LW5_17]jNAGoool001Coool4SXf<19RF
U@BRWih4[:VW1;Jb/0?0_;T4blG21=G?c0CPfMD4j>3L1>CLf0?Me]<4em7>1=;<b@C;al<4`l2m1<2l
^PBm^KH3_[Vf1;ji]@C3_;H4b;ni1=73_0CKbKl4hLg20nG@a@CXdLD4k=?61?3Ea`Cae<D4k]310n_;
_0CZb;P4j<Bd1>O1/0CW_J`4ikZX1>BfX`?R/Id4h:fH1=bXT`CFXH`4cIN21<2;M`>^OV/4VVmN18AO
D0A]CT84EShd13h]9P@V71P34Pd;10<100@?30X47ATG12TU90@e<S03@Cdl14a8A`AFDe44H5eL16UW
IPAbLFl4NgYi5Oooo`005?ooo`B=S8/4UiFD1:2NW0BYYZ@4/jn]0kbh]@C6`Kh4d<[61=[Cc`CTg=P4
hm_F0mcDd@CGcl`4dL_81<c6``C4_kd4`;^h1;nj]P?0^[H4`[Zf1<Bl]PC:_kP4dl>k1=_8_@CPbl03
hlg11>O>`@C[d<84k]721>g?`0C[bk`3j<Nh1>O4/`CU_jl4i;b[1>BjZ0CR]Z<4gk6N0mb[V0CHYi<4
dZ2<1<^HQ0BnS7T4/81^0iabHPB8He@4LeA715a3>@A4<R/4;B8M11TC40<71P@40P40118@3`@P7A`4
;2TX13Pd<`=3?ch4CDY915MDD`APGUd4JVQW17=aL0AkNgXEoooo000Doooo18f<R`BGUI@4X9jL1:VV
Y0Bc[jd3_;Re1<K1_PC@b/H4f]??1>CLf0CSfmH3g=CA1=O?c0CAblP4c<K31<Bo_@C0^kP4_kZf0l2j
]PC2^[H4a;bf1<Zo^0CC`k/4flRm1>3;`0?ScL44ilk11>_@`PC^dL84kLo01>_;_0?XakP4ilBc1>Fo
[`CT_:/4i;ZX1>:fX`CO/Ih3g:^H1=RWT`CBX8`4biR41;j<N@B`P6h3W79R18QSE0AcE4L4G4<i14@b
:`@]8Qd46A<@0`L610@20@044Q0?120M70@/:BP4>3@c0d<o?PA=BTT4EeAC161NG@AZJ6L4Lg5`17]k
NQGoool001Coool4SHb;19NEU0BPWY`4ZJJT1;>_[@>l^;D4a/6n1=3:aPCJdll4i=cH1>?KeP?Le=44
elo<1=7;b0C<a/<4a;nm1<2k^0Bo^[H3`;Zf1<:j]PC4_;H4b[nh1=?3^`CKb;d4h<_00n?=`@CWc/44
jm321>kA`PC]cl04jl^l0nS7^0CWa;<4iKn_1>BlZ`CT^ZP4h[JS1=naWP?LZiP4f:NC1=:PS0C;V8@4
_Xai1;20KP>LLV84R6=D17=DA`AL@cT4A38[12dR7@@I4a031`H4108100@B40l481dL12`Y:0@h=3<3
@cln14e:B@AGE5<4H5iM16YXI`AcLG04Ng]j5Oooo`005?ooo`B=S8/4UIBB19jLVPBWY:84/:bZ0kRd
/@C1_;T4b/C11=?=b@CMeM04hMWE0m_Cc`CFc//4d<W61<_4`@C3_[/4`K^h1<6k]`?3^kL4aKbg1<Nm
]`C<`;P4dl>j1=W6^`CMb;`3glRl1>?9_@CUbK/4ilZk1>O8^PCUa[L3i<:b1>6n[PCO^ZX4g[NV1=fc
XPCJ[id4ej^H0m:TT@C=WX/4aIJ41;b=N`B]PG44WWEU0hYWF0AfF4/4HDPn14Xg<0@b9R447QPE10h;
2@<0000420H611LE50@T8B04;bd/13/h=`=5@T44Cde;15QFE@ARH5l4JfUX17=bL@AlNgXEoooo000D
oooo18f<R`BEU984WYbJ1:NTXPB`[:X3^;Ba1<6l^@C:a<44dlg91=gEd0CQfMD3fm??1=K>b`C@bLH4
blC11<>n^`C1^kP4`K^g0l>k]`C5_;L4akfg1<c0^0CC`kX4fLJk1=g8_0?Ob;`4hlVm1>G9^`CWb[/4
ilRj1>G6]`?T`[84hKj^1=njZPCN]jH4gK>R1=Z_W@CGZiP3dZBA1<fNR`C5UX@4_8ek1:f1L@BNMFD3
RVMH17IHB`AQB3h4BSL`138V8@@N61D43P/90`0000@81PH45aDD12@Q80@_;B`4>cPg0dE2@@A?CD/4
F5IE169PG`A[JFP4Lg9a17akNQGoool001Coool4SHb;19FDTPBNW9X4YjBR1;2/ZP>h];44`Kbi1<[4
`@CCcLT4gMG@1>7Ie@?Kdll4e/k;1=39aPC;a<44`kjk1<6k^0C1^kL3`k^g1<Fl]`C7_KL4c<2h1=?3
^PCIa[/4gLRl0mo8_0CSbKd4iLVk1>O:^`CWb;X4iLJg0nC2/PCQ_Zh4gkZZ1=jgYPCM/j84fZnM1=N[
V0?BY944cIj;1<FFQ0BlSG/4[H5a19ieI@>:IeP4MUQ;1658?PA:=c04<RHQ11hH5@@>2`T3000010P6
1P@G5A@4924P12l];0@k>3L3AD9114m=B`AHEUD4HV1O16]YJ0AcLW44O7]j5Oooo`005?ooo`B=S8/4
UIBB19jLVPBWY:84/:bZ0kRd/@C1_;T4b/C11=?=b@CMeM04hMWE0m_Cc`CFc//4d<W61<_4`@C3_[/4
`K^h1<6k]`?3^kL4aKbg1<Nm]`C<`;P4dl>j1=W6^`CMb;`3glRl1>?9_@CUbK/4ilZk1>O8^PCUa[L3
i<:b1>6n[PCO^ZX4g[NV1=fcXPCJ[id4ej^H0m:TT@C=WX/4aIJ41;b=N`B]PG44WWEU0hYWF0AfF4/4
HDPn14Xg<0@b9R447QPE10h;2@<0000420H611LE50@T8B04;bd/13/h=`=5@T44Cde;15QFE@ARH5l4
JfUX17=bL@AlNgXEoooo000Doooo18b;RPBDTi44W9ZH1:BQW`B/ZJL3];2^1;fh]@C5_k`4cLO31=G>
bPCMe=03fm;>1=C<b0C>al<4b/>o1<Fn^PC4_;P4`k^f0lFl]`C5^kH4akbf1<fn]PCB`;L4e/6g1=S3
]`?H`[H4gLBg1=g2]@CO`kD4g/6c1=fn/0?K^Z/4ekJW1=BaXPCB[Yh4dJZJ1<fVU@C9X8l3`YV91;fC
PPBdRW/4ZH5b19YeI`B:JE/3Me]?16A<@PA??3D4>2`V124K60@B3`h40P410`<30`@@3`l47A/K12PW
9P@d<S44?S`k0dQ6A@AACdh4FUUG16=QH0A/JVT4M7=b17akNQGoool001Coool4S8^:19BCT@BLVYP4
Y:6O1:bYY`>d/:h4_KRe1<Fo_0C=al<4eLk:1=gDd0?Kd/h4e<c81<k7``C:`kl4aKjj1<Bl^0C3^kH3
aKbg1<Fk]PC7_;H4cKjf1=;0]`CF`KL4f<>g0mS2]PCMa;L4gL:e1=o3]@CN`K<4gKj`0m^jZ`CG]ZL4
e;6R1=:^WPCAZYX4cJJE1<VPS`?2VHT4_I>21;B:N`BYPG84VWEW18YYF`=gFdl4I4a214ll=@@h;2H4
8A/H118?3P@20@430`<3110?3`@M6a/4:2LV13@b<@@n?3/3B4I5155?CPAJFEL4Hf5P16aZJ@AdLg84
O7]j5Oooo`005?ooo`B<RhX4U9>A19bJV0BTXIl4[:VW0kB`[PBm^;D4aKnl1<g7``CEc/X4gMC@0m_B
cPCDc<P4c/O31<[3_`C5_[X4a;bh1<>k]P?5_;L4aK^f1<Nl]PC=_[H4d/2g1=K1]`CH`kL3f<:f1=g4
]`CM`[D4gl>e1=k1/`CM_[03fkZ[1=NfY`CD/J84dZjN1=6ZVPC=YYD4bJ2?0l:IR@BmTh84]8Yk1:V1
LPBJMFL4RVUK0gMKC`ATC484Cc`e13P/9P@Q6aP44Pl>10810@<30`<440l?11dK6`@X9bH4=38a13hl
>`=8ATD4DDm>15YIE`ASHF04K6YY17AcLPAlNgXEoooo000Doooo18b;RPBDTi44W9ZH1:BQW`B/ZJL3
];2^1;fh]@C5_k`4cLO31=G>bPCMe=03fm;>1=C<b0C>al<4b/>o1<Fn^PC4_;P4`k^f0lFl]`C5^kH4
akbf1<fn]PCB`;L4e/6g1=S3]`?H`[H4gLBg1=g2]@CO`kD4g/6c1=fn/0?K^Z/4ekJW1=BaXPCB[Yh4
dJZJ1<fVU@C9X8l3`YV91;fCPPBdRW/4ZH5b19YeI`B:JE/3Me]?16A<@PA??3D4>2`V124K60@B3`h4
0P410`<30`@@3`l47A/K12PW9P@d<S44?S`k0dQ6A@AACdh4FUUG16=QH0A/JVT4M7=b17akNQGoool0
01Coool4S8^919>AT0BJV9H4XYnM1:VVX`>`[:X4^;>`1;nj]`C6`;d4c/O31=K>bP?IdLd4d/[61<g5
`@C9`Kd4a[fi1<>k]`C1^K@3aK^e1<Fj]0C7^k@4cKfd1<jm/`CA_K<4dkjb0m>m/PCF_[84eKb`1=Jk
[PCE^J`4dkFX0lnaY0C;[Il4b:VK1<JUU`C3XI84_Y^=1;REQ`>bSh04[8Qj1:>0LPBFMFP4QfYN17MM
DP=UCdL4DD0j13``;0@W8Ah45A8A10D410@20`<33Ph>11TH60@T8R84;Rd/13Pg=PA2@3l3BdU915AB
D@AMFeX4IF=S16e/J`AeM7<4OGak5Oooo`005?ooo`B<RhT4Ti6@19ZHUPBRWid4ZJJS0k2/ZPBh/k04
_kZg1<K0_@C>al<4e/k:0mWAc@CBb/H4cLG11<W1_@C6_KT4`k^g1<6i]0?5^kD4aKZd1<Nk]0C=_K@4
c[fc1=6m/`CC_[83dkfb1=Jn/PCE_;04e[^^1=Fi[0CC]JP3ck6T1<^]W`C8ZI/4aZFG1<>QTPBnVhd4
^9F70k:?P0B/R7X4Xh1b19IeJ0B7JUh4MeeB0fE?A`AA@3X4?30/12LQ7P@E4Q441@@410830`<>3Ph4
6APH12@R8P@^;B`4>3Lf1490?`=;BDT4E59A15eKFPAUHf<4KFa[17EdL`AmO7/Eoooo000Doooo18b;
R@BCTI04VYRF1::OW@BYYZ<3/:bZ1;Rc/0Bo^[L4a/2m1<k7``CFc/X3fM7=1=;:aPC=aL44bL6m1<Jm
^@C3^kL4`KVd0lFk]@C5^[@4ak^d1<fm]0C>_K<4dKfc1=>n/P?C_K84e[jb1=Fl/0CF^jh4eKV/1=>e
Z0??/J@4bjfO1<RYV`C6YIL4`j6B1;jKS@BhUHL3/Xn01:b8NPBSP784UWEX18MZGPAgGE83IDm71550
>P@l<2`49b4N11DB4@@510@40P<30`h>3P@I61P4928R12h];0@h=cH4@T0o0d]9B@ADDU44GE]J16ES
H`A]K6/4MGAc17elNaGoool001Coool4S8^919>AT0BJV9H4XYnM1:VVX`>`[:X4^;>`1;nj]`C6`;d4
c/O31=K>bP?IdLd4d/[61<g5`@C9`Kd4a[fi1<>k]`C1^K@3aK^e1<Fj]0C7^k@4cKfd1<jm/`CA_K<4
dkjb0m>m/PCF_[84eKb`1=Jk[PCE^J`4dkFX0lnaY0C;[Il4b:VK1<JUU`C3XI84_Y^=1;REQ`>bSh04
[8Qj1:>0LPBFMFP4QfYN17MMDP=UCdL4DD0j13``;0@W8Ah45A8A10D410@20`<33Ph>11TH60@T8R84
;Rd/13Pg=PA2@3l3BdU915ABD@AMFeX4IF=S16e/J`AeM7<4OGak5Oooo`005?ooo`B;RXT4TY2?19RF
U@BOW9X4YZ:P0jbXYPBc[Z`4^KBa1<2j]`C7`;d4cLK20mC;b0C@a/<4bl:n1<No^`C3^kL4`KRd1<6h
/`?3^K<4a;Vb1<Fh/@C9^K04bKR^1<^h[PC<^:d3c;N]1<fgZ`C=]JX4c;>W1<V`Y0C6[:03`jVM1;jT
U`BkX9<4]Y^>1;>FRPB]T8@4YhYn0j:4N0BLOW84TWEZ18AZH0AfGeD4IE9:0e=4?PA0=S44;BLU11/I
5`@82@P410@510h>3P<G5aL48B0P12/Z:@@d<c<4?S`l14I5A0=?CDd4EeIE15mNG@AWIVD4KVe/17Ie
M0AmO7/Eoooo000Doooo18^:R@BBT8l4V9JE19nLVPBVXZ03[:RV1;>^[0Bi];44`;Zg1<O0_@C=a/83
e<_81=36``C;`[h4aknk1<>k]`C1^;@4`KRc0l>i/`C4^K84aKRa1<Vi/0C9^:h4bkR^1<bh[@?<]jd4
cKN[1<feZPC</jL4bK2T1<J/X0?3ZId4_ZBG1;^PT`BfVhh4/iJ:1:f@Q0BWRWh3XXAh19anLPBBMFX4
Q6YP17IOE@AUDTX3Dd@n140f<@@]9bD46aTG10P920@410D43Ph>0aLG5`@Q8204:bXY13@c<`@n?3`4
ATE40dm=C@AGEUD4GeiM16MVI@A^KF`4MWEd17elNaGoool001Coool4RhZ919:@S`BHUYD4WibJ1:JR
X0>/Z:H4/jj/1;Vd/@C0^[L4al2m1<g6`P?DblP4d<K31<_2_PC7_k/4`k^g1<6h]0C1^;<3`kVc1<Bi
/PC5^;44bKV`1<Vh[PC;^:h4c;R]0lbg[@C=]j/4cKFZ1<bcY`C9/:@4aZbP0l>YW@BnY9L4^j2C1;JK
SPBcUXX4[I241:N:OP>RQ7P4W7ib199eJPB4JV04MUmE16EBBP=CA3h4@3Ha12dW9@@K6AL420T810@4
1@@>3Ph35aLG124P80@[:RT4=3<c13hl?0A6AD@3Cde=15MFE@AOGUd4IfIU16i]K0AfMG@4OGak5Ooo
o`005?ooo`B;RXT4TY2?19RFU@BOW9X4YZ:P0jbXYPBc[Z`4^KBa1<2j]`C7`;d4cLK20mC;b0C@a/<4
bl:n1<No^`C3^kL4`KRd1<6h/`?3^K<4a;Vb1<Fh/@C9^K04bKR^1<^h[PC<^:d3c;N]1<fgZ`C=]JX4
c;>W1<V`Y0C6[:03`jVM1;jTU`BkX9<4]Y^>1;>FRPB]T8@4YhYn0j:4N0BLOW84TWEZ18AZH0AfGeD4
IE9:0e=4?PA0=S44;BLU11/I5`@82@P410@510h>3P<G5aL48B0P12/Z:@@d<c<4?S`l14I5A0=?CDd4
EeIE15mNG@AWIVD4KVe/17IeM0AmO7/Eoooo000Doooo18Z9R0B@Shh4UYBC19bJV0BRWid3Z:FR1:jZ
Y`Bd[j`4^[Ba1;ni]PC5_[X3bL:n1<[2_PC8_k/4a;bh1<6h]0Bo][44_KB_0kne[`C0]Jh4`;>/1<>d
[0C2/ZX4a;:Y1<>aZ0?4/:H4`jnT1<:]XPC0ZZ04_JNL1;VSV@>fX9D4/9Z@1:bFS0BVT8H4Xhb119b6
O0BGP7L3TW]a18]dJ`B0JV84LUmH16=CC@ACAd83@SXf134]:P@P7ah43a4A10H71`@?3`l461PH0b4P
80@Y:BT4<S4a13/j>@A3@T44BdY90e=BD@AKFET4HV5P16UXI`A`Kfh4MgIe17imO1Goool001Coool4
RXV8192?SPBFU9<4W9ZH1::OW@>XYJ84[ZZW1;B_[0Bj];44_kVf1<Fn^P?9`[h4b/:n1<Ro^`C4_;P4
`KRd1;nf/@Bm]:l3_kF_1<2e[PC0/j`4`kB/1<:bZPC4/ZT4`k6X0lB`YPC3[j@4`ZfR1<2ZX0BmYi`4
^J>I0kJPU@B`VY04[9J<1:J@QPBSS844W8Il19N0M`>BNg44RgA[181ZHPAbGeP4He==15=7@P=2>SH4
<BdZ120O7P@?4A441PL710l?3`@H61P38B0P12TY:@@b<C44>cXi14=2@@A;BTT3De9A15]IF@ARHF04
JFQW171_KPAgMWD4OWel5Oooo`005?ooo`B:RHP4T8n>19JDT`BLVYP4XYnM0jRUXPB^ZZL4]:n/1;Zd
/@Bo^KH4aKjj0lW2_PC:`[h4b;nk1<Bl^0C1^;@4_kJa1;fd[`>o]Jl4`;F^1<2c[0C3]:`4`[:Z1<Bb
Z@C3/JP3a;2V1<>_Y0C2[J84`:ZP1;fWW0BiXiT3]Z2E1;2JT0B/UX`4YY261:><P@BLQW`4Uh1g0i9k
L@B;M6/4P6YR179OF0ASDdd4DdM20d8j=P@a;BX481lN10lA4@@61`L43`l?11PH60<Q8204:BTY138a
<@@k>ST4@d9114]:B@=CDU44FeUI169QH0AYJ6L4L6m^17MfM@AnOG`Eoooo000Doooo18Z9R0B?SX`4
U9>A19ZGUPBOW9X3Y:6O1:VVX`B^ZZL4/jj/1;Rb[`Bl][<3`;Vf1<>k^0C3^kL4`;Rd1;je/@Bj/Zh4
^K2[0kV`ZPBj[jX4^ZjW1;b^YPBk[:@4^Z^R1;ZZX@>iZ9l4]jJM1;FTVPBdXYP4/9jE1:bJT@>XUhh4
Xi:919j<Q0BHQWh4Th5h18akM0B9N703Q79[17]ZH`A_H5/4HUIA15A:APA4?S/3=C8`12HV9@@G6AT4
30d>10l?3`@I6AT48R4Q0bXY:@@b<C44>STi1451@0A9B4L4D4m?0eMFEPANGE`4IFAS16]ZJPAbLG04
N7Mf17imOAGoool001Coool4RXV818n>S0BDTi44VYNF19nLVP>TXIl4ZJJS1:jZY`Bc[Z`4^;:_1;bf
/`?0^KH4`k^h1<>k]`C0^;@4_[Fa1;Zb[PBi/:/3^K2Z1;Z_ZPBj[ZL4_:jV1;^/Y0BjZj84^ZZQ0kVX
W`BgYYd4]JBJ1;BRV0B`WYD4[9ZA0jRGSPBSTXT4WXb419R6OPBCPGP4S7]d18UhL0>4LV/4NfYS16mP
F`AREU44E4Y614@n>`<e<S049RHU11LI6@@<3@h43`l?11TI6@@R8B43:RTY138a<@@j>CT4@D5014U8
A`A@Cdl3EeIF15iMG0AUI6<4JfYZ179aL0AhMgH4OWem5Oooo`005?ooo`B:RHP4Shj<19BCT@BJUiH4
WibJ0jBQW`BYYZ<4[ZZW1;>^[0Bh/Zl4_;Jc0l2i]PC3^kP4`k^g1<2h]0Bn]K44^[:^1;V`Z`>i/:X4
^ZnZ1;Z^Y`Bl[ZH4^jbT1;Z[XPBjZZ43^JRO1;NVW@BeY9X4]::H1;2NU@B/VY43Z9N>1:>BR@BNS8@4
V8In19>1N0B<Ng@4RGQ`0hAbJ`AkJV<4Kf1K169FD@ADBTH4A3hk0cDb<0@V9RD45aTI10`=3P@?3`l4
6ATI128Q8@<Z:BT4<S4a13Xi>@A1@D04BDQ7151?C`=GEUH4GUeL16ETH`A[JVX4LW5`17QgMPAnOGdE
oooo000Doooo18Z9R0B?SX`4U9>A19ZGUPBOW9X3Y:6O1:VVX`B^ZZL4/jj/1;Rb[`Bl][<3`;Vf1<>k
^0C3^kL4`;Rd1;je/@Bj/Zh4^K2[0kV`ZPBj[jX4^ZjW1;b^YPBk[:@4^Z^R1;ZZX@>iZ9l4]jJM1;FT
VPBdXYP4/9jE1:bJT@>XUhh4Xi:919j<Q0BHQWh4Th5h18akM0B9N703Q79[17]ZH`A_H5/4HUIA15A:
APA4?S/3=C8`12HV9@@G6AT430d>10l?3`@I6AT48R4Q0bXY:@@b<C44>STi1451@0A9B4L4D4m?0eMF
EPANGE`4IFAS16]ZJPAbLG04N7Mf17imOAGoool001Coool4RHR718j<R`BBTHl4UiFC19bIU`>PWI/4
YJ6O1:VUX`B]ZJH4/JbY1;F_[0>h/Zh4^[B`2;be/@Bi/Zh4]jnZ1;F/Y`>cZZD4/jVT1;:XXPBcYj04
/ZFN1;2SW0B`XYX3[InH1:bNUPB[W9@4Z9VA1:BESPBPTXX3Vhf619N9PPBAQ7d4RWig18EiL`B0MG04
OG5/0gM[IPA/HEd4HeUF15M@C0A8A444>CLf0b`/;0@O8B444Q@E11<C50@L71`492@T12`/:`<c<c<4
>cXj1491@0A8B4L4Cdi>15IEE0=LFeX4HV5P16QWIPA^KF`4M7=b17UhN0AoOWdEoooo000Doooo18V8
Q`B>S8/4TY6?19NET`BLVIL3X9fK1:FQW`BYYJ<4[JVV1;6/Z@Be[j`3^;:^1;Zd/0Rl]K44^K:^1;N_
ZPBe[:L3/jZU1;>YY0BbZ:84/jNP1;:UWPB`Xi`4/::J0jfOV0B/WYH4ZibD1:RIT@BTUHh4X9::0i^=
QPBGRH84THAm18YnM`B5NG<4P7E`17eaK0=gJfH4K65M16=IEPAGD4`4B4A113Tg=P</;2`47b4Q118D
5@@C4a@471`L12@T90@/;2/3<c<c13/j>PA2@D04B4Q714m>CPAFEE@3G5]J169QH0AXIfH4KVe/17Ac
LPAiN7P4Ogim5Oooo`005?ooo`B9R8L4SXb;19:AS`BGUI<4W9VG0j2MV`BUXIl4ZJFS1:fYYPBa[:T4
]Jn/0kRb[PBj];08_;Fa1;Vb[PBg[jX4]JbW0k>ZY@BcZJ@4/ZRR1;>WX0BbYIh4/:>L1;2RVP>]WiP4
[9jF1:^LU0BXVI44Y9F>1:2BRP>KSHH4UhV21964O@B:OWL4QGUc181eL0AmLF`3Mf]V16aQG@ASFEH4
Ee1<14Q4@@@i=cH3;2`/11lQ8@@B51D44a<D11`L70@T92@4;2`[0c<c<`@k>SX4@T5014Q8A`A?CTh4
EUED0eaKFPARHF04J6MV16i]K0AdLg84NGQh17mnOAGoool001Coool4RHR718j<R`BBTHl4UiFC19bI
U`>PWI/4YJ6O1:VUX`B]ZJH4/JbY1;F_[0>h/Zh4^[B`2;be/@Bi/Zh4]jnZ1;F/Y`>cZZD4/jVT1;:X
XPBcYj04/ZFN1;2SW0B`XYX3[InH1:bNUPB[W9@4Z9VA1:BESPBPTXX3Vhf619N9PPBAQ7d4RWig18Ei
L`B0MG04OG5/0gM[IPA/HEd4HeUF15M@C0A8A444>CLf0b`/;0@O8B444Q@E11<C50@L71`492@T12`/
:`<c<c<4>cXj1491@0A8B4L4Cdi>15IEE0=LFeX4HV5P16QWIPA^KF`4M7=b17UhN0AoOWdEoooo000D
oooo18R8Q`B<RhX4THn>19FCT@BIUYD3WIZH1:2MV`BTX9h4Z:BQ1:^VY0B^ZJH3/:^X1;:/Z@Bd[ZX4
]Zn[1;J^Z`BbZZH4[jNR0jbTW`B[Xih4Zj6L1:^PVPBYWYP4YIZD1:>HTP>RUi04XIF>19nCS0BLTHX4
V8f719B:Q0>?QH04Rh9m18ImN0B0N7<4O7A`17M`K@AgKVX3L6MT16ING0ALEU<4Cd]9140o?P@b<c<3
9BPX11`N7P@J6Q/48R8R12TY:@@`;bl4=SHf0cdm?0A3@d84BDU814m?CPAEEE@4FeYJ0f5PG`AVIF@4
JfYZ171`K`AeMG@4NWYi17moOQGoool001Coool4R8R718b;RPBAShh4UI>A19VFU@>MVYP4X9fK1:BP
WPBXY:44ZjJT1:jYYP>`ZjP4/ZbY1;B^ZPBf[j/4]Zj[1;:ZYPB_Yj83[:BO1:^SWPB[XI`4Zj2J1:VN
V0BUVY@4XiRB0j:GT0BQUHh4Wi><19bARPBHSHL4U8Z40hn5P0B;PWd4QWeh181hL`AlM704Mg1]17M^
JP=`If@4IUiL15aFD`A?BdT4@3ln138c<`<U:2P471hN11XJ6`@R8R84:BTY130_;`@f=SH3?Cdl14=3
@PA9BDP4Cdm>15EEE0AKFUX3HF1O16IUI0A[JVX4L71_17EeM0AjNWT4Ogmn5Oooo`005?ooo`B8R8L4
S8^:196?SPBETi44VIJE0ifJV0BPWI/4Y:2N1:RTX@B[YZ@4[ZVV0k2[Z0Bb[:T4]:jZ1;J_Z`Bf[Z/4
/ZZV1:nWXP>/Y9l4Zj>N1:^QW0B[X9X4ZIjH1:FJU0BSV983XYN@1:6ESPBOTh`4W96:19R=Q`BDRX@3
ShF018^2O@B6OGP4P7Qc17adL0AgL6d4MfiZ0g1WI0AVGU`4G5IC14m;B@A0?ch4<S<c0bDX:0@L7Qh4
6QXK128R8P@Y:BT4<2l_13Hf=P<m?C`4@d=214U9B0A?Cdh4EEED15]JFP=QH5l4IVET16]ZJPA`L6l4
MGEd17YjN@AoOghEoooo000Doooo18R8Q`B<RhX4THn>19FCT@BIUYD3WIZH1:2MV`BTX9h4Z:BQ1:^V
Y0B^ZJH3/:^X1;:/Z@Bd[ZX4]Zn[1;J^Z`BbZZH4[jNR0jbTW`B[Xih4Zj6L1:^PVPBYWYP4YIZD1:>H
TP>RUi04XIF>19nCS0BLTHX4V8f719B:Q0>?QH04Rh9m18ImN0B0N7<4O7A`17M`K@AgKVX3L6MT16IN
G0ALEU<4Cd]9140o?P@b<c<39BPX11`N7P@J6Q/48R8R12TY:@@`;bl4=SHf0cdm?0A3@d84BDU814m?
CPAEEE@4FeYJ0f5PG`AVIF@4JfYZ171`K`AeMG@4NWYi17moOQGoool001Coool4R8N618^:R@B?SH`4
TY2?19JCTP>IUYD4W9VG19nLVPBRWY`4YJ6N1:NSX0>YY:84ZjJS1:bWY0R^Z:@4[JJR1:ZSWP>VWiX4
XibG1::JU@BRVI@4WiNA19bDSPBJTX`3Uhn:19J=Q`BDS8H4THV418f6P0B9PWh3Q7ij185kN0AkMg@4
NGAa175^K0A`K6T4KFQV0fAPG`ALFEL4DDm>14E5A@@j>c/4;C0a0b<V9P@T92@4:BTY12l_;`@e=CD4
>c/k1451@@=7ATH4C4a;159AD@AGEUH4G5]J165PG`=UIF@4JVUY16m^K@AcLW84MgMf17akNPB0OglE
oooo000Doooo18R7QPB;RXT4Shf<19:@S`BFTi83VIJE19bIU`BOW9X4XYjL1:FQWPBWXj03ZJBR1:^V
X`B/Yj@8[ZRT1:fVXPBZXih3YYnJ1:>LU`BRVYD4XYVD19nGT@BLU8h4VY:<0iN?RPBFSHL4U8b61969
Q0B=QX04RH9n0hAnNPB1NgP4NgMd17UdL@AaKV`4L6aY16eXIP=TH5l4G5UG155?CPA5ADD4>S/k12d`
<@<S9RH492@T12TY:@@_;bl4=CDe13/k>`A1@D43AdI614a<B`ABDE44EeIF15aKFPAQH5l3IFET16YY
J@A_KVd4Lg9b17MgMPAlNgX4P7mo5Oooo`005?ooo`B8QhH4RhZ918n=S0BBT8l4UY>B0iVFU@BLVIL4
WibJ1::NW0BUXIh4Yj>P0jVTXPB[YZ<4[:NT2:jXY0B]YZ84ZZ>N0jJOVPBSW9L4XYZE1::IU0BOUi44
W9B>19ZBS0>GShX4UXf719B<QPBARH@4SHJ018V2OP>4OWX4PG]h17]gM0AiM744LFi/171/J@A]J6H3
I61O15aIE`AACdh4ADE513Xk>`@]<3438bHV12@T90@Y:BT4;bl_13De=@@k>c/4@D510dM6APA<C4/4
DU5A15MFEPALFeX4HF1O0fEUI0AZJFT4Kfi]17=bLPAgMgH4O7]j181oOaGoool001Coool4R8N618^:
R@B?SH`4TY2?19JCTP>IUYD4W9VG19nLVPBRWY`4YJ6N1:NSX0>YY:84ZjJS1:bWY0R^Z:@4[JJR1:ZS
WP>VWiX4XibG1::JU@BRVI@4WiNA19bDSPBJTX`3Uhn:19J=Q`BDS8H4THV418f6P0B9PWh3Q7ij185k
N0AkMg@4NGAa175^K0A`K6T4KFQV0fAPG`ALFEL4DDm>14E5A@@j>c/4;C0a0b<V9P@T92@4:BTY12l_
;`@e=CD4>c/k1451@@=7ATH4C4a;159AD@AGEUH4G5]J165PG`=UIF@4JVUY16m^K@AcLW84MgMf17ak
NPB0OglEoooo000Doooo18N6Q@B:RHP4SHb:192>S@BCTHl3UI>B19REU0BJV9H4WIZH19nKV@BQWI/3
XYjL1:BOW@BUX9d4YZ6N1:JPW@BVWi`4XI^G0inIU@BMUi84W9F@19VBS@BEShX4TH^718j8Q0>>R8<4
SHJ218V4O`B5PGd4Q81l185mNP=mNWP4NWMd17IdL`AdLG04K6][16]ZJ0AVI6@3GeiM15MFE@A<CDd4
@TA413`m?@@^<303;Rl^13@d=0@h>3P4?Cdm1492@PA7AdL4C4a;0e5@D0AEEE@4FUUI15iNG@ARHV44
IVIU0fYZJ@A^KVd4LW5a17IeM0AiNGP4OGel1860OaGoool001Coool4QhJ518Z9R0B=S8X4T8j=19>A
S`>ETi84V9FD19ZHUPBMVYP4Wi^I1:6MV`>RWY`4Y9nM1:FPW@BVXIh4YZ2M1:JOW0BQViL3WiVE19fG
TPBLUI04VI:=19F?RPBARhL4SXR40hj8P`B=QX84RHAo18F1O@B4P7`4PGej0gejN0AjMg@4MWAc17Aa
L0A/Jf/4JfYX16ITI0=OGUd4EeIE14a=C@A2A4@4?3dm12h`<0<^;bh4=3@d13Ph>0@m?Cd4@T9214M7
A`A<C4/3DE1@15EEE0AJFET4GUiM169RH@AVIVD3JVYY16i^K@AbLG44MWEd17UiN0AmOG`4PH1o5Ooo
o`005?ooo`B7QXD4RXV818f<RPB@SXd4Ti6?0iFCTPBHUI@4VYRF19fJV0BOViT4XIfK0j:NW0BTWid4
YJ2M1:JQWPBVX9d4YYnL1:6KU`>OVID4WINB19bET0BITXd4UHn:196;Q`B>R8@3SXR318f6PPB9Q7l4
QH5m18B0O0B1OGX3OGYh17YgM0AfM7<4M75`16a[J`A[JVP4IVAT0emNG@AGEUD4C4e=1494A0@l?Cd4
;S0`0bh_;P@d=3@4>3Ph13dm?@A2@T84AdM714a<B`=AD504EEED15YIF@ANGUd4HV9Q16IVI@=ZJVT4
KVi]179aL@AfMG@4NGUh17emO0B1P7lEoooo000Doooo18N6Q@B:RHP4SHb:192>S@BCTHl3UI>B19RE
U0BJV9H4WIZH19nKV@BQWI/3XYjL1:BOW@BUX9d4YZ6N1:JPW@BVWi`4XI^G0inIU@BMUi84W9F@19VB
S@BEShX4TH^718j8Q0>>R8<4SHJ218V4O`B5PGd4Q81l185mNP=mNWP4NWMd17IdL`AdLG04K6][16]Z
J0AVI6@3GeiM15MFE@A<CDd4@TA413`m?@@^<303;Rl^13@d=0@h>3P4?Cdm1492@PA7AdL4C4a;0e5@
D0AEEE@4FUUI15iNG@ARHV44IVIU0fYZJ@A^KVd4LW5a17IeM0AiNGP4OGel1860OaGoool001Coool4
QhJ518V8Q`B;RXT4SHb;192>S@>BT8h4U9:@19JCTPBHUI<4VIJE19^HUP>LVIL4WIVG19jJV0RNVYL4
WIVE19bGT`>IU944Ui:>19>>RPB@RXH4S8R418Z6PPB8Q843Qh>018B0O@B2Og`4PGmm185oO0AmNgT3
NWUh17QfM@AeM7@4L6m_16a/J`AWJ6P4HV=S0eaLG0ADE5@4CDi>14E6AP@o?Sh4>CXj0cm0?`A4A4<4
B4M714a;B`A@Cdl4De=C15MGEP=KFeX4GeiN169RH@AVIF@4JFQX16a/J`=_Kfh4Lg9a17IeM0AiN7L4
O7]j17inO@B1PH0Eoooo000Doooo18N6Q@B9R8L4RhZ918f<R`B@SXd3TY2>19BBT0BFTi84V9FC19VF
U@BKV9H3W9VG19fIU`BNVYP8WYZG19fIU@BLUi<3VIBA19NBSPBCSXX4T8Z618b8Q0B:QX84R8B10hN3
P0B4P7d4PWml185oO@B1Og`4OG]i0gYiN0AhMWD4MGAd171_K`A/K6/4IfQX169SH`=LG5`4E5AD14e>
CPA5ATH4?chn13Tj>P<o@3l4A4A314Q7A`A<Bd/4D4m?15=CD`AGEeH3Fe]J15mNGPARHV44IVET16UX
J0A/K6/3Kfm^17=bL@AfMG@4NGQg17akNPAnOWd4PH605Oooo`005?ooo`B7QXD4RHR718^:R@B=S8/4
T8j=0i:@SPBDTY04UY>B19RET`BIUYD4ViRF0ibIU`BMVIL4WYZH29jJU`BMVID4W9NC0iVDT@BGTXh4
Thj:192:QPB<R8@4RXJ218R4P@>7Ph04Q81m189oO0B1Ogd4PGml17ekN@=jNGP4N7Ie17EdM0A`Kfl4
K6a[16MXJ0ARHf<3G5aL15ADE0A=CTh4ADI613ln?P@i>SX3?d0o14A4@`A8AdL4C4];151?C`ACDe<4
EeMF0e]KFPAOGUh4HV9Q16IUI0AYJ6P4K6a[0fm_KPAcLW44MWEd17UhM`AlNgX4OWim1861P1Goool0
01Coool4QXF418R7QPB9R8L4RhZ918f;RP>>SH/4T8j=196?SPBCTHl4U9:@19FBT@>FTi4<UiBB19ND
T@BFTi04UI6?0i>?S@BASHX4RXJ418N4P0B6Q844Ph5o1h5oO0R0Og`4P7il17elNPAjNGP3NGQg17Ad
M0AbLW84KVm_16]/K0AWJ6P4Hf=R0emNG@AEEED4DE1@14a<C0A;BT/4CTi>0e5AD0ADE5<4EeMF15YI
F@AMG5`4H5mO169RHP=UIF@4J6MW16]ZJ@A]KF`4L6m^179bL@=eM7<4MgIf17UiN0AkNgX4OWel181o
O`B2PX4Eoooo000Doooo18J5Q0B8QhH4RHR718^:R@B=RhX3SXf;192>S@BAShh4Ti6?19BBT0BETY43
UY>A39NDTPBGU944UY>@19FAS`>CShd4THf:18Z6Q0B7Q804QXB118>1O`N1Og`8P7ml181nO0AmO7X4
NWUh0gUhM`AdM7@4LW9b16i_K`A[K6`4IfQX16=SHP=OGUd4EEEE155@D0A<C4`4BdY;14i>CP=ADE04
E5AC15MGEPAJFET4GEaL161OG`ARHV83IFET16QWI`A[JVT4KFe/171_KPAbLW43MGAc17MfMPAiNGP4
Ng]j17imO0B0Ogl4PX:15Oooo`005?ooo`B6QH@4R8N618V8Q`B;RXT4SH^:0hj=R`B@SXd4THn>19>A
S`BDTY04UI:A0iJCT@bGU984UiBA19JCT0BETHl3Thn=196=RPB:QX@4QhB018J4P@B3PGl7PGml281o
O0B0OW`4OGaj17YiN0=iN7L4M7Ad179bLPA^Kfl4Jfa/16MXJ0ASHf83GeiM15EEE@AAD504C4a<14]:
B`A>CTh3DE5@15ADD`AGEeH4FUUI15eLG0APGel4HV9R0fEUI0AXIfL4JfYY16e]K0A`Kfh4LW9a0gEd
L`AgMWH4NGUh17]kNPAnOG`4P7mo18:2PAGoool001Coool4QXF418R7QPB9R8L4RhZ918f;RP>>SH/4
T8j=196?SPBCTHl4U9:@19FBT@>FTi4<UiBB19NDT@BFTi04UI6?0i>?S@BASHX4RXJ418N4P0B6Q844
Ph5o1h5oO0R0Og`4P7il17elNPAjNGP3NGQg17AdM0AbLW84KVm_16]/K0AWJ6P4Hf=R0emNG@AEEED4
DE1@14a<C0A;BT/4CTi>0e5AD0ADE5<4EeMF15YIF@AMG5`4H5mO169RHP=UIF@4J6MW16]ZJ@A]KF`4
L6m^179bL@=eM7<4MgIf17UiN0AkNgX4OWel181oO`B2PX4Eoooo000Doooo18F4Q0B7QHD4R8N618V8
Q`B:RHP3RhZ918b;R@B=RhX4SXb;28n=S0>@SX`4T8j=296>S@BASX`4T8f<18n<RP>>RhT4S8V718V6
Q0B7Q884Q8:117imO0AnO7/3Ogil17imN`QoOG/4OG]j17ajNP=jNGP4MgIf17EeM@AbLW84L71`16e/
K0ATI6@3HF5Q15eMG@ANGEd4GeiN15mOGPAPH603HV9Q16ATH`AVIVD4J6QW16YYJ@A/Jf/4KVe]0g1_
KPAaLG04Lg=b17EdM0AgMWD4N7Qg0gYiN0AkNgX4OGal17inO@B0Ogl4PH6018>2PQGoool001Coool4
QHB418N5Q@B8QhH4RHR718Z9R0>;RXT4S8^918f;RPB>S8/8Shf<0i2>S0B@SXd8THj=196>S0B@SH`4
Shb:0hj;R@B<RHL4RHJ418N4PPB4PX44OWel17ilN`=oOW`4OWek27mmN`AmNgX4O7Yj0gYiN0AgMWH4
MGEe179bLPA`L704KFa/16ATI0=QHF44GEeM15iMG@AOGUh4GemN161PH0=RHV44I6AS16IVI@AXJ6L4
JVUY16a[J`A^KFd3L6m^175aL0AcLg84MGAd17MfM@AhN7L3NWUh17]kNPAmO7`4OWim181oO`B1PH04
Ph:25Oooo`005?ooo`B5Q8@4QhF518R7QPB9R8L4RXV80h^:R@B<RhT4SH^:18j<R`R?SH`3T8j<192>
S@RASXd4THj<192=S0B?S8X3SX^918b9Q`B9QX@4QhB218B2P@AnOG`4OWak0gmnO0AnOG/8Ogek17ek
NPAlNWX3NWUh17MfMPAeMGD4LW9b171`L0A]K6`4I6AT0f5QH@AMGEd4GUeM15mNGPAOGeh4H61P0f9R
H@ATI6<4IVIU16QXI`AZJFT4K6][16i]K@=`Kfh4LG5`17=cLPAeM7@4MgIe17QhM`=jNGP4Ng]j17el
O0AnOWd4P7mo1861P0B3PX8Eoooo000Doooo18F4Q0B7QHD4R8N618V8Q`B:RHP3RhZ918b;R@B=RhX4
SXb;28n=S0>@SX`4T8j=296>S@BASX`4T8f<18n<RP>>RhT4S8V718V6Q0B7Q884Q8:117imO0AnO7/3
Ogil17imN`QoOG/4OG]j17ajNP=jNGP4MgIf17EeM@AbLW84L71`16e/K0ATI6@3HF5Q15eMG@ANGEd4
GeiN15mOGPAPH603HV9Q16ATH`AVIVD4J6QW16YYJ@A/Jf/4KVe]0g1_KPAaLG04Lg=b17EdM0AgMWD4
N7Qg0gYiN0AkNgX4OGal17inO@B0Ogl4PH6018>2PQGoool001Coool4QHB318F5Q0B6QH@4QXJ518N6
Q@N8QhH<RHR718Z9Qa>:RHP4RXV718Z8Q`>9QhH4R8J518N5Q0B5Q8<4Q8>118:1P0B1P7l3PH5o2860
O`B0Ogh4O7al17]kN`=jNWT4N7Qh17MgM`AfMWH4M7Ad179bL@A_Kfh3LW5a275aL0QbLG44LW9a0g=c
LPAdM7<4MGEd17IfM@AgMgH4N7Qg17UhN0=jNGT4NgYj17akNPAmO7/4OGel17inO@=oOWh4P7mn1860
O`B1PH04PX:118>2P@B4Ph8Eoooo000Doooo18F4P`B5QH@4QXF418J6Q@B7QXD7R8N638V8Q`B:RHLC
RXV818Z9Q`B:R8L3RHN618R6Q@B7QH@4QHB318B3P@B2PH04PH1o0h61O`R1P7l4P7mn17alO0AkNg/3
NWYi17QhN0AgMgL4MWIf17AdM0AbLW44Kfm^0g9aL@QaLG08LW5a179bL@=cLg84M7Ac17EeM0AfMWD4
MgMf17QhM`AiN7P3NWUi17]jNPAlNgX4OGak17emO0AnOWd3Ogin181oOPB1P7l4PH6018:2P@B3PX44
Q8>25Oooo`005?ooo`B5Q8<4QHF418J5Q0B6QXD4QhJ51hR7QPb9R8L4RXV74hZ9R0B:RHL4RXR70hV7
QPB8QXD4QhF418F4P`B4Ph44PX601860O`>1PGl8PH1o181oOPAlO7`4Ng]k0gYjN@AhN7P4MgMg17If
MPAdM7@4LW9a16m_KP=bLG48LG5`279aL@AbLW43Lg=b17AdL`AeMG@4MWIe17MgMPAhN7L4NGQh0gYi
N@AkNWX4O7]j17elN`AmOG`4OWim0gmnOPB0Ogh4PH1o1861P0B2PX44Ph:118B3PQGoool001Coool4
QHB318F5Q0B6QH@4QXJ518N6Q@N8QhH<RHR718Z9Qa>:RHP4RXV718Z8Q`>9QhH4R8J518N5Q0B5Q8<4
Q8>118:1P0B1P7l3PH5o2860O`B0Ogh4O7al17]kN`=jNWT4N7Qh17MgM`AfMWH4M7Ad179bL@A_Kfh3
LW5a275aL0QbLG44LW9a0g=cLPAdM7<4MGEd17IfM@AgMgH4N7Qg17UhN0=jNGT4NgYj17akNPAmO7/4
OGel17inO@=oOWh4P7mn1860O`B1PH04PX:118>2P@B4Ph8Eoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo002Ioooo0`0008Coool009coool0
0`000?ooooooo`21oooo001koooo100000Coool00`000?ooooooo`02oooo0P0000Coool400000_oo
o`<00003oooo0`0000?oool20000O_ooo`00Noooo`030000oooooooo00Goool01@000?oooooooooo
o`000002oooo00@0003oooooool00002oooo00@0003oooooool00005oooo00@0003oooooool00023
oooo001loooo00<0003oooooool01?ooo`050000oooooooooooo000000;oool010000?ooooooo`00
00;oool00`000?ooooooo`0400000_ooo`040000oooooooo0000Poooo`00OOooo`030000oooooooo
00Coool010000?ooooooo`0000;oool010000?ooooooooooo`<00003oooo0P0000Coool40000P_oo
o`00Noooo`040000oooooooo00000_ooo`040000oooooooo00000_ooo`040000oooooooo00001Ooo
o`030000oooooooo08goool007coool200000oooo`@00003oooo0P0000Goool20000Soooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(292) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
6D7C7D6D7C7E6D7C7E6D7D7F6E7D7F6E7D7F6E7E806E7E806E7E806F7F816F7F816F7F81
6F80826F8082708083708183708183708184708284708285708285708386718387718588
708386708285708284718284718284718284718284718385728385728385728385728384
728283718182718081717F80707E7F707E7F6F7D7E6F7C7D6F7B7B6E79796D78786C7675
6A73726C76766C78796D797A6D7A7B6D7A7B6D7A7B6D7A7C6D7B7C6D7B7C6D7B7C6D7B7C
6D7B7D6D7B7D6D7B7D6D7B7D
6D7C7E6D7D7F6E7D7F6E7E806F7F816F7F81708082708183708184718284718385728386
72848772858773858873868973878A74878A74888B74898C74898D748A8E748B90748C91
748A8E748A8D74898B74898B75888B75898B76898C778A8C778A8C778B8C778A8B778A8A
778889768687768585748383748182738080727F7F717D7C707A796F77766D74736B706E
6A6E6C6B73726D76756D77776E78786E79796E797A6E7A7B6E7A7B6E7A7B6D7B7C6D7B7C
6D7B7C6D7B7C6D7B7D6D7B7D
6D7C7E6E7D7F6F7E806F7F8170808270818371828572838672848773858874868974878A
75888B75898C768A8E768B8F778C90778D91788E92788F9478909578919678939879949A
789297789094789093788F92798F92798F927A90927B90917A90917A90917B90907A8E8E
798C8C798A8A78888878868677858476828275807F747D7C7279787076746D726F6A6C68
6A6D6A6C716F6D74736E76756E77776E78786E79796E797A6E7A7A6E7A7B6E7A7B6E7B7C
6E7B7C6D7B7C6D7B7C6D7B7D
6D7D7E6E7E806F7F8170808271828472838573848774868874878A75888B76898D778B8E
788C90788E92798F937A91957B92967B93987C959A7C969B7D979D7D999E7D9AA07C9BA2
7C989E7C979B7C969A7C95987C95987D95977D94967D94957C94957C93947D92937C9192
7C90907B8E8E7B8D8C7B8A897A878678848377817F757D7B7379777175726E706D6B6B67
6C6E6A6D716E6E73716F75746F77756F78776F78786F79796F79796F7A7A6E7A7B6E7A7B
6E7B7C6E7B7C6D7B7C6D7B7D
6E7D7F6F7E8170808271818472838673858874878975888B768A8D778B8F788D91798F93
7A91957B92977C94997D969B7E989D7F999F809BA1809DA3819EA581A0A681A1A880A1A9
809FA5809DA2809CA0809B9E809A9D819A9C81999B81999A81989A819899819697809595
7F93937F91917E8F8E7E8C8C7C89887B8584798280777E7C757A777375716F6F6B6D6B66
6E6E6A6F716E7073707075737076757077767078777079787079796F7A7A6F7A7A6F7A7B
6E7B7B6E7B7C6D7B7C6D7B7D
6E7D7F6F7F8171818372838573858874878A76898C778B8E788D907A8F937B91957C9397
7D959A7E979C80999E819BA1829DA383A0A684A2A885A4AB85A6AD86A7AF85A8B084A8B0
83A5AB83A3A883A1A684A0A4849FA2849FA1859FA0859FA0859E9F859D9E849B9C849A9A
84989883959583939282908F808B8B7E88877C84827A807D787B77757571716E696F6C66
706F6B71726E717470717572717674717776717877717978707978707979707A7A6F7A7B
6F7B7B6E7B7C6E7B7C6D7B7C
6E7E7F70808271828473848774878976898C778B8F798D917A90947C92967D95997F979C
80999E819CA1839EA484A1A786A3A987A6AC88A8AF89ABB28BAEB58BB0B88AB1BA88AEB6
87AAB087A8AD87A6AB87A5A988A4A788A4A789A4A689A4A589A3A489A3A489A2A289A0A0
889D9D889A9A879797869493848F8F828B8A8087857D82807A7C78777671736F69726E69
73716C73736F737471737673737774737775727876727977717978717979707A7A707A7A
6F7B7B6E7B7B6E7B7C6D7B7C
6E7E8070818372838674868875888B778B8E798D917B90947C93977E959A80989D819BA0
839EA385A0A686A3A988A6AC89A9B08BACB38CAFB68EB2BA90B6BE93BAC38DB5BE89AFB7
89ADB48AACB18AABAF8BAAAE8BAAAD8CAAAC8DAAAC8DAAAB8EAAAB8EAAAA8EA8A98EA6A6
8EA4A38DA09F8C9C9B8B9897899392868E8C8389878084817D7E7A79787375716B75716C
75736E757470757572757673747774747875737876737977727978717978717A79707A7A
6F7A7A6F7A7B6E7B7C6D7B7C
6F7E8071818473848775878A778A8D798D907B90937C93977E969A80999D829CA1849FA4
86A2A888A5AB89A8AF8BABB28DAEB68FB2BA90B5BD92B9C295BDC696BFC989B3BC8AB1B9
8BB1B78CB0B68EB0B48EAFB38FAFB290AFB191AFB091B0B092B0B193B1B093AFAF94ADAC
93A9A892A5A491A09F909C9B8D97958A918F878C8A83868380817D7D7B7679756F787570
787571787671777773777773767874757875757876747977737978727978717A79717A7A
707A7A6F7A7B6E7B7C6D7B7C
6F7F8171828473858876888B788B8F7A8F927C92967E959A80999D839CA1859FA587A3A8
89A6AC8BAAB08DADB48FB0B891B4BC93B8C094BBC496BFC899C3CE8EBAC585B0BB8BB3BC
8EB4BB90B5BA91B5B992B5B893B4B794B4B695B5B696B6B697B6B698B6B598B4B398B1B0
97ADAC96A9A795A4A393A09E909A988D94928A8F8C86898583837F7F7E797C79737C7873
7B78737A7873797874787874787875777975767976757977747977737978727A79717A79
707A7A6F7A7B6E7B7B6D7B7C
6F7F8172838574868976898D798D907B91947E949880989C829CA0859FA487A3A989A7AD
8CAAB18EAEB590B2B992B6BE94B9C296BDC698C1CB9CC7D293C0CB89B5C08BB6C08EB7BF
91B8BF93B9BF95B9BE96B9BD97B9BB98B9BA99BABA9ABBBB9BBDBC9BBBBA9CB9B79CB6B4
9BB1AF9AACAA99A7A697A2A0949D9A9196948D908D898B8786868283827D817E797F7A75
7E7A757D79747C79747A7975797975787975777976767976757977747978737A78727A79
707A7A6F7A7B6E7B7B6E7B7C
6F7F8172838675878A778B8E7A8F927D93967F969B829A9F859EA487A2A88AA6AC8CAAB1
8FAEB591B3BA94B7BF96BBC398BFC89AC3CD9CC7D197C4CF8DBBC68FBBC690BBC592BCC3
95BDC497BEC499BEC39ABEC19BBDC09CBDBF9DBFBF9DBEBE9EBEBD9FBABAA0B8B79FB3B2
9FB0AF9EADAB9DAAA79BA4A2979E9C9398958F928F8C8D8988888485847F83807A827D78
807C767F7B757E7A757C7A757B7A757A7975787976777976767977747977737978727A79
717A79707A7A6F7A7B6E7B7C
70808273848675888B788C8F7B90947E959981999D849DA287A1A789A6AB8CAAB08FAEB5
92B3BA94B7BF97BBC49AC0C99CC4CE9EC9D3A2CED997C5D192C0CC93BFC994BFC896BFC7
99C1C89CC3C99EC3C79EC2C49FC1C2A0C1C2A0C1C1A1BEBFA2BBBBA2B7B8A2B2B3A1AFAF
A3B0AFA2ADACA1A9A89EA4A39A9E9C9699979193908E8E8A8B898588858086827C847F79
827C76827C76807B767F7B757D7A757B7A75797976787976767976757977747978727A78
717A79707A7A6F7A7B6E7B7C
70808273848776898C798E917D929680979B839BA086A0A589A4AA8CA9AF8FADB492B2B9
95B7BE98BCC49BC0C99EC5CEA0CAD4A3CFDA9ECCD891C0CD94C1CC96C2CC98C1CA9AC3CA
9DC5CCA0C7CCA2C7CBA2C5C7A4C5C6A6C5C5A2BDBDA1B8B9A1B4B5A1B1B2A1B1B1A4B1B1
A6AFAFA5AAA9A5A9A8A1A6A49DA09E989A989394908F8E8A8D8A858B878289847E88817B
867F78857E77837C76817C757F7B757C7A757A7975797975777976767977747977737978
717A79707A7A6F7A7B6E7B7C
708082748588778A8D7A8F927E949781989C859DA288A2A78BA7AD8EACB291B1B795B6BD
98BBC39BC0C89EC5CEA2CAD4A4CFD9A7D4DF9AC8D594C2CE96C2CD99C4CD9AC3CB9DC5CC
A0C7CEA4C9CEA5C9CCA8C8C9A4BFC1A0B7B99CB1B3A0B3B4A2B1B3A3B2B3A5B3B4A5AEAE
A4ACABA5ABA9A6ABA9A4A6A49FA09E9A9A97959590918E8A8F8B868D88838C86808B837D
898079887E75867D76837C75807B757E7A747B7975797975787975767976757977737978
727979707A7A6F7A7B6E7B7C
708083748688788B8E7C90937F9599839A9F86A0A48AA5AA8DAAB091AFB594B4BB97B9C1
9BBFC79EC4CDA2CAD4A6D0DAA8D4DEA7D5E096C5D296C3CF98C4CE9BC4CD9DC4CCA0C6CD
A3C9CFA6C9CEA6C6C9A6C2C49EB8BA9FB8BAA1B8BAA3B7B9A5B8BAA7B9BBA9B9BAA8B5B5
A8B4B4A7AFAEA4ABAAA1A4A29FA19E9B9C98979691938F8B918B87908A848F88818E857E
8C827B8B7F77897F78867D75817A747E79747C79747A7874787875767875757976737977
727978717A796F7A7B6E7B7C
718183758689798C8F7D919581979B849CA188A2A78CA7AD8FADB393B2B996B7BF9ABDC5
9DC2CBA1C8D1A6CFD9AED8E3ADDAE5A0CFDB92C1CE97C3CE9AC5CF9DC6CEA0C6CDA2C7CD
A5C8CEA5C4C8A2BDC09FB6B99CB2B5A1B5B8A4B8BAA6B9BBA8BDBEABBDBEACBDBDACBABA
ACB8B8AAB1B1A8AFAEA4A9A6A0A3A09C9D9A979591948F8B938C87938C86928A83918780
8F837C8D81798A7E76867C738178727F78727C78727A7873787874777875757876747977
727978717A796F7A7A6E7B7C
71818375878A7A8D907E939682999D869FA38AA4A98EAAAF92B0B695B5BC99BBC29CC0C8
A0C6CEA3CBD5A8D2DCAED9E4A5D1DD95C3D095C1CE9AC4CF9DC6CEA0C5CDA2C6CCA4C8CD
A7C8CDA7C4C8A4BEC1A3BABCA3B8BAA5B7B9A7B7B9A8B8BAAABABBACBABCADB9BAADB6B7
ADB3B3ABB0B0A9AFADA6AAA7A2A4A19D9D9A969390958F8B958D88958D87958B84948981
92857D91837B91837A887C748177707F77717C76717A7772797773777774757875747876
7279787179796F7A7A6E7B7C
71828476888A7B8E917F9498849A9F88A1A58CA6AB90ADB294B2B998B8BF9BBEC69FC3CC
A2C9D2A4CED7A6D2DCA1CFDC96C5D392C0CD99C4CF9DC5CFA0C6CEA3C6CDA4C6CCA7C7CC
A9C6CBA8C4C8A6BEC2A7BDC0A8BBBEA9BBBDABBBBDACBCBDAEBDBEB0BDBEB1BBBCB1B9B9
B0B6B5AFB3B1ACAEACA9A7A5A3A09E9D989597908D958C89978D88988E87978D85968A81
94867E93847B93827885776E81756E7E756E7C756F7A7670797672777773757774747876
7278777179786F7A7A6E7B7B
72828477898B7C8F92819699859CA08AA3A78FA9AE93AFB597B6BC9BBCC39EC1C9A1C7CF
A4CCD5A6D0DBA6D3DFA3D0DDA0CCD79EC8D39FC7D1A1C7CFA4C6CDA6C6CDA8C6CCA9C7CC
ABC7CBABC5C9ABC2C5ABC0C2ACBEC0ADBEC0AEBFC0B0BFC0B2C0C1B4C0C0B5BFBFB5BCBC
B4B9B8B3B5B3AFB0ADABA9A6A6A29FA19B989D9591998F8B998E889A8F879A8E85988B82
96877E96857B95837884756C80736B7E736D7C746E7A746F797570777672757673747775
7278767179786F7A7A6E7A7B
72828477898C7D909382979B879EA28CA5AA91ACB196B2B89AB9BF9EBFC6A2C5CDA5CBD3
A7D0DAA9D4DFA9D6E2A8D5E0A7D2DCA6CED7A4CAD3A5C9D0A7C8CEA9C8CEABC8CDACC9CD
ADC9CDAEC7CAAEC5C7AEC1C4AFC1C2B0C1C2B2C3C3B4C2C3B6C3C3B8C3C3B8C2C0B9BFBD
B7BBB8B4B7B3B0B0ADACAAA6A7A29EA39C98A097929C928C9C918A9D91899C8F869A8B82
98877E96857A97847884756C80736B7E726B7C736C7A736E78746F777571767672747774
7378767178787079796E7A7B
728385788A8D7E929584999C89A0A48EA7AC94AFB499B6BB9DBCC3A2C3CAA5C9D1A9CFD8
ABD5DEADD9E4ADDAE5AED9E3ACD4DDA9CFD7A7CCD4A9CAD1ABCAD0ADCACFAECACFB0CBCF
B1CACEB2C8CCB2C7CAB2C5C6B3C3C3B4C3C4B6C4C4B7C4C4B9C5C4BBC6C4BBC3C1BBC0BE
B9BBB8B7B8B4B3B1ADAEAAA5AAA39EA59E97A29891A0948DA0938CA092899E8F869B8B82
98877E96847A95837886776E7F71697D71697B716A7A726C78736E777470767572747673
7377757178777079796E7A7B
738385798B8D7F9396859B9E8BA2A691AAAE97B1B69CB9BEA1C0C6A6C7CEAACED5ADD4DD
B0DAE3B2DEE9B3DEE8B3DCE5AFD4DCACCFD7ACCDD4ADCBD2AFCCD1B0CCD1B2CDD1B3CDD1
B4CDD0B5CBCEB6CACCB6C7C8B6C4C5B7C5C5B9C6C6BBC7C6BCC7C6BEC8C6BFC7C4BFC3BF
BDBEBAB9B8B4B5B1ADB1ABA5ACA49EA89E97A69A92A59890A4968DA2938AA090879D8C82
99887E9483788E7E7482756C7E70677B6E667A6F6879716A78726C77736F767471747673
7377757178777079796E7A7B
7384867A8C8E819497879CA08DA4A894ADB19AB4B9A0BCC2A5C4CAAACBD2AFD3DAB2DAE2
B6E1EAB8E5EEB9E4ECB7DCE4B2D3DAB0D0D7B0CED4B1CED3B3CED3B4CFD3B6D0D4B7D0D3
B8D0D2B9CED1BACCCEB9C8C9B9C6C6BAC7C6BCC9C8BEC9C7C0CBC8C2CBC9C3C9C6C2C5C1
C0C0BBBCBAB5B9B4AEB4ADA6AFA59EACA099AA9D95AA9C93A89990A5978DA293889F8E84
9A897E9483788E7D7384736979685E75665D796D6579706879716B77736D767470747572
7376747178767079796E7A7B
7484867B8D8F829598899EA190A7AA97AFB39DB8BCA3C0C5A9C8CEAFD0D6B4D8DFB8DFE7
BCE6EEBEE7F0BDE3EAB9D9E0B4D2D9B2D0D6B3CFD5B5D0D4B6D0D5B8D2D6BAD3D6BBD3D6
BCD3D5BDD2D3BDCFCFBDCCCBBCCAC8BEC9C7BFCAC8C1CAC8C3CCC9C6CCC9C6CAC6C5C6C1
C3C1BBBFBBB5BBB4ADB5ACA5B2A79FB0A39BAFA198AE9F96AC9C92A9998EA5958AA19084
9C8A7F978478907F7488766B7F6C617C6C627B6D657A6F6879716A78726C76736F747571
7376737177767079786E7A7B
7484867C8E908397998BA0A393A9AC9AB2B6A1BBBFA8C4C8AECCD2B4D5DBBADDE4C0E6EE
C3EAF3C5E9F1C2E2E9BCD8DFB6D2D8B6D1D6B7D1D6B8D2D6BAD3D7BCD5D8BED6D9C0D7D8
C1D7D7C1D5D5C1D2D1C0CECDC0CCCAC1CCC9C2CCC9C4CCC9C6CECAC9CECAC9CCC7C8C7C1
C5C1BBC1BBB4BDB4ADB9AFA7B7ABA2B5A79EB4A59CB3A398B09F94AD9C90A9978BA59186
A08B809A857A9381758C786C867165816F657E6E657C6F677A706978716C76736E757470
7375737177757078786E7A7A
7585877D8E9185989B8DA2A595ABAE9DB5B8A5BEC2ACC8CCB3D1D6BADADFC1E3E9C8EDF4
CDF1F7CFEEF3C8E4E9BED8DDB9D2D8B8D2D6B9D2D7BBD4D8BDD5D9C0D7DAC2D8DAC4D9DA
C6D9D9C5D6D6C4D3D2C3D0CEC3CECBC3CDCAC4CDC9C6CDCAC9CFCBCBCFCACCCCC7CAC8C2
C8C2BCC4BCB5C1B7AFBEB2A9BCAFA5BBACA2B9A99EB7A59AB5A296B19D91AD988CA99387
A38E819D887C988579917B6F89756A826F647F6E647D6F667A706878716B76726D757370
7375727176757078786E7A7A
7585877E8F92879A9C8FA4A698AEB1A1B8BBA9C2C5B1CCD0B9D6DAC0DFE4C8E8EECFF2F8
D6F4F8D3EDF1CAE3E7BED6DBBAD2D6BAD2D6BBD3D7BDD4D8C0D6D9C3D9DAC6DADBC8DBDA
CADBDAC9D9D8C8D6D4C6D2D0C5CFCCC5CDCAC6CDC9C8CECACBD0CBCED0CBCFCEC7CDC9C3
CBC4BDC8BFB6C6BAB1C4B6ACC2B3A8C0B0A4BFACA1BCA99DB9A498B5A093B19B8EAC9689
A79083A28B7E9D877B957E718C776A846D60816D637E6E657B6F6779706977716C75736F
7374727176747078776E797A
7686887F9092889B9D92A5A89BB0B3A4BBBEAEC6C9B7D0D4BFDADEC7E4E8CEEDF2D5F4F9
D8F3F6D2EAEDC9E0E3BAD2D7B9D0D5BAD1D5BBD2D5BED4D7C3D8D9C7DBDCCCDEDECFDFDE
D0DFDDCEDBD9CAD6D4C8D3D0C6CFCCC5CCC8C7CCC8C9CDC8CDCFCAD0D0CAD1CEC8D0CAC4
CFC6BDCCC1B8CBBDB3CABAAFC8B6ABC5B2A7C3AFA3BFAA9EBCA699B8A194B49D8FB0988A
AB9384A68D80A28A7C9982738E7669856B5E816C607E6D637B6E66796F6876716B74726E
7374717176746F77776E797A
7686888091938A9C9E94A7A99EB3B5A8BEC0B2CACCBCD5D8C6E0E3CEEAEDD5F3F7DAF7FA
E0F7F8D8ECEDC8DDE0B7CED4B7CDD2B9CFD3BBD0D3BED3D5C2D6D7C7D9D9CCDBDAD0DDDA
D1DDDACED9D7CAD4D2C8D1CEC6CECAC4C9C5C6C9C5CACCC6CECEC9D1D0CAD3CFC8D3CBC3
D3C8BED0C3B9CFBFB4CEBDB1CCBAADCAB6A9C8B2A5C3AC9FBFA89ABBA395B89F90B49A8B
AF9485AA8F81A58B7C9980718D736585695B816A5E7E6B617B6D64786E6776706A74716D
7273707175736F77766E797A
7787888192948B9D9F96A9ABA1B5B7ACC1C3B7CDCFC3DADCCEE6E9D6F1F3DCF7FADFF8F9
E0F4F5D3E6E8C3D8DCB3CACFB5CACFB7CCD0BACED0BDD0D2C1D2D2C4D5D4C5D4D3C9D6D4
C8D5D3C4D0CFC2CBC9C0C8C6BEC3C0BFC1BDC4C5C0CAC9C3CECDC7D2D0C9D5CFC7D6CDC3
D7CCC1D4C5BAD5C3B7D6C2B5D4BFB1CFB9ABCBB3A5C5AEA0C1A99BBEA596BAA091B69B8B
B29686AF9282A98D7C9C7F708D716284665881695C7E6A607B6B63786D66766F6974706C
72726F7074726F77766E7979
7787898292948D9EA098AAACA3B7B8AFC4C5BCD1D3C9E0E1D7EEEFE5FEFFE4FDFEE3F7F8
E0F1F1D3E4E5C1D5D8B0C6CCB2C8CCB5CACDB9CCCEBCCECFBFCFCFC1D0CFC2D0CEC3D0CE
BDCAC9B9C5C5B7C2C1B7BFBEBABEBBBFC0BBC4C4BEC9C9C2CFCEC7D3D0C8D5CEC6D5CBC1
D5C8BDD3C1B5D8C3B6DCC4B5D5BEAFD0B8A9CEB5A6C7AFA0C3AA9BBEA596BCA090B99C8B
B59887B49584AE8E7D9E7F6F8E706184665881685C7D695E7A6A61776C64756D67736F6B
71716E7074726F76756E7979
7887898392948E9FA09AABACA6B8B9B2C5C7C0D4D5CFE4E5E3F8F9EAFFFFE6FAFAE7F7F6
E2F0EFD1E1E3BCD1D5ACC2C8AFC5C8B3C7C9B8CBCBBBCCCCBDCCCBC0CDCBC1CDCBC1CCC9
BEC9C6BBC5C2B9C0BDB8BDBABBBDB9BFBFBAC4C3BCCAC8C1CFCDC5D3CEC6D5CDC4D5C9BF
D3C5BAD1C0B4D1BFB3D3BEB0CAB7A9C9B3A5C6B0A1BFA99BBDA596BBA191BC9F8EBB9C8B
B99A88BA9885AF8E7C9D7F6F8C716284675880675A7C675D79685F766A62736C66726E69
70706D6F73716E76756D7879
7887888393948F9FA19BACADA7B9BAB4C7C7C2D5D6D2E5E6E3F7F7E3F6F6E1F3F2DEEDEC
D9E7E7C8DADCB7CCD0A9BFC4ACC1C5B0C3C5B4C5C6B8C6C6BCC9C8C0CCCAC2CDCAC3CCC8
C2C9C6BFC5C1BDC2BEBCBFBBBDBDB8C0BFB9C5C3BCCBC8C1D0CCC4D4CDC4D6CDC3D6CABF
D5C6BAD3C1B4D0BEB1CBB8ABC1B0A3C0AC9FBEA99CB9A496BAA293BDA090BE9F8EBE9D8B
BE9B88BD9985AE8C7A9B7D6D8B6F618264567E65587A655B77665D746860726A64706C68
6F6F6C6E72706D75746D7879
7887898493958FA0A19BACADA8B9BAB5C7C7C3D5D5D2E4E4E2F4F4E1F2F1DEEEEDD8E7E7
CFDFE0C1D3D6B3C7CBA7BDC1AABEC1AEBFC1B1C1C1B5C2C1B7C2C0B9C3C0BCC3C0BAC1BE
B8BEBBB6BBB8B7BAB6B7B9B4BAB9B4C0BEB7C6C4BCCCC9C1D0CCC3D4CCC2D6CDC1D8CBBF
D8C8BAD5C3B5D2BFB0CEB9ABC8B3A5C4AEA0C1A99ABEA596C0A493C0A390C1A18EC19F8C
C39E8AC09A85AD8B789679698A6E5F8263547D635778635874645B71655E6F68626E6B66
6D6E6A6D716F6D74746D7878
78878984939590A0A19CACADA8B9BAB5C6C7C3D4D4D1E2E2DFF1F0DDEDEDD8E8E7D2E1E1
CADADBBDCFD1AFC4C7A6BBC0A8BBBEACBCBEB0BEBEB3BEBDB5BFBDB6BEBBB6BBB8B4B9B6
B5B8B5B5B7B3B6B7B2B8B8B2BEBBB5C3C1B9C9C6BECEC9C1D1CBC2D3CBC1D4C9BED4C7BA
D5C4B6D6C2B3D6C1B1D2BCACCDB6A6CAB1A2C7AD9DC5AA99C4A795C4A592C4A28FC4A18C
C7A18BBF9983AA88759679698E71628667587A6054745F557060586E625B6D655F6C6864
6C6C696C706E6C73736C7778
788789849394909FA09CABACA8B8B9B5C5C5C2D2D2CFE0E0DDEEEDDAE9E8D4E3E3CDDDDD
C3D5D6B7CBCDADC1C4A5BABEA6B9BBAABABBAEBCBBB2BCBBB4BDBBB6BDB9B7BCB8B8BCB7
B9BCB7BABCB6BCBDB7BFBEB8C3C1BAC7C4BDCCC8C0CFCBC2D2CCC2D4CBC0D4C9BDD4C6B9
D3C2B4D0BDAFCFBBACCFB9A9D1B7A7CFB5A3CDB19FCAAD9AC8A996C5A591C5A38EC8A28D
C9A08ABC9580A987739A7B6A8E70608162546F564B6D59506B5C546A5F5869625D696662
696A676A6E6C6B72726C7777
7887888493948F9FA09BABABA7B7B8B4C4C4C0D1D0CDDEDDDAEAE9D5E5E5D1E0E0C9D9D9
C0D1D2B5C8CAACC0C3A6BABDA7B8BAAAB9B9AEBABAB1BCBAB4BDBAB7BDBAB9BEBABBBEBA
BDBFBABFC0BAC2C2BCC4C4BDC8C6BFCBC9C1CFCBC2D3CDC3D4CDC2D6CCC0D6CABDD6C8BA
D5C4B6D3C0B2D0BBADCCB6A7C9B2A2C8AF9EC8AC9BC5A996C5A692C5A48FC9A38FCBA28C
C99F88B8917CA7837198776688695A785C4E68514666544B65574F655B54655F5A66635F
676865686D6B6A72716B7677
7887888392948F9E9F9AAAAAA6B6B6B2C2C2BFCFCECBDBDBD8E8E7D4E3E3CFDEDDC6D7D6
BECFD0B5C7C9AEC0C3A8BBBDA7B8B9A9B7B8ADB9B8B1BBB8B5BCB9B8BEB9BBBFBBBEC1BC
C1C3BDC3C5BFC6C7C1C9C9C2CDCBC4D0CDC5D3CFC5D6D0C6D7CFC4D8CEC1D9CCBFD9CABC
D8C7B8D6C3B4D3BEAED0B9A8CCB3A3C9AF9EC7AB99C7A995C8A793CAA691CCA48FCCA38D
C69C86B58D79A27F6C91716180635570574B624D435F4E465F514A5F5650615B5663605D
646663666B6A6871706A7677
7887888392938E9D9E9AA9A9A5B5B5B1C1C0BDCDCCC9D9D8D6E5E4D1E0DECCDAD9C5D4D4
BECECEB7C6C7B0C0C2AABBBCA7B8B9A9B6B6ADB8B7B2BBB8B6BDB9BABFBABEC1BCC1C4BE
C4C6C0C8C9C2CBCBC4CECDC5D1CFC7D4D1C8D8D3C8DAD3C7DBD2C5DCD0C3DCCEC0DCCCBD
DCC9B9DAC5B5D8C0AFD4BBAAD2B7A5D0B3A1CEAF9CCEAC98CFAA95CFA892D0A68FCFA28B
C39881AF88749D7A678B6C5C795E5067504559463D54453D574B4459514C5C57535F5E5A
626461646A6867706F6A7576
7786888291928D9C9D99A8A8A4B3B3AFBFBEBBCACAC7D6D5D3E2E1CEDCDBC9D7D6C3D1D1
BCCBCBB5C5C5AFBFBFA9B9BAA7B6B7A7B5B4ADB8B6B2BBB7B7BEB9BCC1BCC0C3BEC4C6C0
C8C9C2CCCCC5CFCFC7D3D1C9D6D3CAD9D5CBDCD6CBDDD6C9DED5C7DFD3C4E0D0C1E0CEBE
DFCBBADEC7B6DBC2B1D9BEACD7BAA7D5B6A2D4B29ED3AF9AD2AC96D2A993D1A78FCB9F88
BA917BA8826F9574628265566E55495B473D4D3C34493B344F443E534C475854505B5B58
5F6260636867666F6E697576
7786878290928C9B9C97A6A6A2B1B1AEBCBCB9C8C7C5D4D2D1DFDDCCD9D8C6D4D3C1CFCE
BCCAC9B7C5C4AFBEBEA9B9BAA6B6B7A7B5B5ADB7B5B4BBB7B9BEBABFC2BDC3C6BFC8C9C2
CCCCC5D0CFC8D4D2CAD7D5CCDBD7CDDDD8CEE0D9CDE2D9CBE3D7C9E3D5C5E3D2C2E3D0BF
E2CCBBE1C8B6DFC4B2DDC0ADDBBDA9DAB9A4D8B5A0D7B19BD5AE97D5AA93D1A58DC59A83
B38B76A07C698B6B5B765B4E614C414E3D353D2F283F332D483F3A4E484453504D585856
5D605E616766656E6E697475
7785878190918B9A9B96A4A5A1AFAFABBAB9B7C5C4C3D1D0CFDCDACAD7D5C4D2D0C0CDCC
BCC9C8B5C3C2AFBDBCABB9B9A9B6B6AAB6B4AFB7B4B5BBB7BCC0BAC1C4BEC7C8C1CCCCC4
D0D0C8D5D3CBD9D7CEDCD9CFE0DBD1E2DCD1E5DDD0E6DBCDE6D9CAE7D6C7E7D4C3E6D1BF
E5CDBBE4CAB7E2C6B3E1C2AEDFBEA9DDBAA5DCB6A0DAB29BD9AE97D4A891CCA089BD937D
AA836F9473617F62546A524656433943342D3428223B312C433B37494541504E4B555654
5A5E5D5F6665646D6D687475
768586808F908A999994A3A39EADADA9B7B7B4C2C1BFCDCBCBD8D6C6D3D2C2CFCDBECBC9
BAC6C5B5C1C0B0BDBCADB9B9ABB7B5AFB8B5B2B9B6B8BCB8BEC1BBC5C6BFCACBC3D0CFC7
D5D4CBD9D7CEDEDBD1E2DDD3E5DFD4E7E0D2E9E0D1EADECFEBDBCBEAD8C8EAD5C4E9D2C0
E8CEBBE7CBB7E5C7B3E3C2AEE1BFAAE0BBA5DFB7A0DDB39BD9AE96D3A68EC89B84B58C76
A07B688A6B5A755B4C604A3F4A3A31362B242C221D362E2A3E393546423F4C4C49535453
585D5B5E6564636C6D687475
7684867F8E8F89979892A1A19CAAAAA6B4B3B0BEBDBBC9C7C6D4D2C2CFCEBFCBC9BCC8C6
B9C5C3B6C2C0B2BDBBB0BAB8B0B9B6B3BBB7B5BBB7BBBEB8C1C3BDC8C9C1CFCEC6D4D2CA
DAD7CEDFDBD1E3DED3E7E0D4EAE2D5ECE3D4EEE3D3EFE0D0EEDDCBEEDAC8EDD6C4ECD4C0
EBD0BCE9CCB7E7C8B3E6C3AEE4BFA9E2BBA4E1B79FDEB29AD8AC93CEA189BE937DAA826E
9372607E61516951445240363B2E27261C18261D19322B283B363343413E4A4A48505352
575C5B5C6464626C6C677475
7584857E8D8E879696909E9F9AA7A7A3B1B0ADBAB9B7C4C2C1CECCBFCBC9BCC8C5BAC5C3
B8C3C1B5C0BDB3BCBAB2BAB7B3BAB7B6BCB7B8BCB7BEC0BAC5C6BECDCCC3D3D1C7D9D5CB
DFDACFE4DED2E9E1D4ECE3D5F0E5D6F2E6D6F3E4D4F3E2D0F2DECCF1DBC8F0D7C4EFD4C0
EDD0BBEBCCB7EAC7B2E8C3ADE6BFA8E4BAA3E1B59DDCB097D3A68EC59982B38A749D7966
8768577257495C473C45352D30252021181427201D302A27383533403F3D4849474F5251
555B5A5B6363616B6C677374
7583857D8C8D8694948E9C9C97A4A49FADACA8B6B4B2BFBDBCC9C7BCC7C5B9C4C2B8C2BF
B7C0BDB5BEBBB3BCB8B2B9B6B3B9B5B6BBB6BBBEB8C1C1BAC9C8BFD1CEC5D8D3C9DFD9CD
E5DDD0EAE1D3EEE4D5F2E6D6F6E8D7F8E8D7F8E6D4F7E3D0F5DFCCF4DBC7F2D8C3F1D4BF
EFD0BAEDCBB6EBC7B1E9C3ACE7BEA6E3B9A1DEB29AD7AA92CA9E86B88F79A47F6B8F6E5C
795E4E654D414E3C32362A24241C181A1310241F1C2E2A273635323F3F3D4649474D5251
545B5A5B6363616B6C677374
7483847C8A8B8492938C9A9A94A1A19CA9A8A4B1B0ACB9B7B4C0BEB7C2BFB6C1BEB5BFBC
B3BCB9B2BBB8B1B9B6B0B7B3B2B8B3B6B9B4BBBDB6C2C1B9CCC8BFD4CFC4DBD5C9E4DBCD
EAE0D1F0E3D4F4E6D6F7E8D6FBEAD7FEEAD7FDE7D4FBE3CFF8DFCAF6DAC6F4D7C2F3D3BD
F0CEB9EECAB3EBC5AEE8C0A8E4BAA2DFB59CD8AC94CDA189BC937DA9836F9573617F6252
6A52455441363D3028281F1A160F0C150F0C221E1B2C2A283535333E3F3E4549484D5251
545A5A5A6363606B6C667375
7482847B898A829091899797919E9E98A5A59FACABA6B3B1ADB9B7B4BFBDB3BDBBB2BBB8
B1B9B6B1B9B5B0B7B2AEB5B1B0B5B0B3B6B0B9BAB3BFBEB6C8C5BBD1CCC0DCD3C6E7DBCC
EFE0D0F3E4D4F7E6D5FBE8D5FFEAD6FFE8D4FEE5D0FBE1CCF9DDC7F7D9C3F5D4BFF3D0BA
F1CDB6EEC8B0E9C2AAE5BCA4E0B69DD8AE96CDA38BBF957FAD87729977648467566F5648
59453A43342C2D231E1B15120F0A08171311211F1D2B2A293535343D3F3E4549484C5252
535B5B5A6364606B6C667375
7382837A8889808E8F8795958E9B9B94A1A19BA8A6A1AEACA8B3B1AFBAB7AFB9B6ADB7B4
ADB5B2ACB4B1ACB3AFABB1ADACB1ACB0B3ADB6B7B0BCBBB3C3C1B7CDC7BCD9CFC1E3D6C6
EADBCBEFDFCDF4E1CEF8E3CFFBE4CFFBE2CDF9DFCAF8DBC6F6D8C2F4D3BDF3D0B9F1CCB5
EDC7B0E9C2AAE4BBA3DEB59DD6AD96CCA38CBE9680AE88759B7967866A5972594B5C483D
46372E3026201E18140E0B080A070517151322211F2C2C2B3537363D4140454A494C5353
535B5C5A6464606C6D667375
7381827987887F8D8D8592938B9898919E9D96A3A29CA8A7A2ADACA7B2B0ABB5B3A9B3B0
A9B1AEA8B0ACA7AEAAA5ACA8A9ADA8AEB1ABB4B5AEBBBAB1C1BFB5C9C4B9D3CABDDBCFC0
E2D3C3E6D5C4ECD8C6EFD9C6F2DAC6F2D8C4F1D6C2F1D3BEEFD0BAEDCCB6EBC8B2E8C4AD
E4BFA8DFB9A2D9B29BD1AA94C8A18BBC9681AD89769C7B6A886C5C745C4E5F4B40493A31
3229221F1916100C0A0402010B09081817162323222D2E2E3639383E4242464B4B4D5454
545C5D5A6465606C6D667475
7280827886877D8B8C8290908895958D9A9A929F9E97A3A29CA8A6A0ACAAA5AFADA5AEAC
A4ADAAA3ABA8A3AAA6A3A9A5A7ABA6ABAEA8B1B2ABB6B5ADBCB9AFC4BEB2CDC3B5D3C6B8
D7C9BADACBBAE0CEBCE2CEBCE4CFBCE5CEBBE5CBB8E3C8B4E0C4B0DDBFABDBBBA7D9B8A2
D4B29DCEAC97C6A48FBE9C88B4927FA88776987A6A866C5D735D50604E434B3D35352C26
201B18110E0C02000003020210100F1B1C1B2527272F3131373B3B3F4444474D4D4E5556
545D5E5A6566616D6E677475
7180817685867B898A808E8E8592928A97968E9B9A929F9E97A2A19BA6A49FAAA7A1ABA9
9FA8A59EA6A39FA6A2A0A6A2A2A7A2A5A8A2ABACA6B0B0A8B6B4ABBFB9ADC4BBAFC8BEB0
CDC0B1D0C2B2D4C4B3D5C3B3D6C3B2D7C1B0D6BEADD3BBA9CFB7A5CCB2A0CAAE9CC6AA97
C1A491BA9D8BB29584AB8E7DA0847493796A836C5E725E52604F454C3F38372F2A221E1B
11100E0201010000000B0C0B1516161F2121292C2B313535393E3E414747484F504F5758
555F5F5B6667616D6E677476
717F817584857A88887E8C8C8290908693938A97968E9A99919D9C95A09E97A2A19BA5A3
99A29F98A19E99A09D9AA09C9CA19CA0A39EA5A7A1AAAAA3AFADA4B6B0A6B9B2A6BDB4A8
C1B6A9C3B7AAC6B8A9C7B8A9C8B7A7C6B4A5C4B1A1C1AE9EBDA999BAA595B6A090B19B8B
AB9485A48D7E9D8778967F718B76687E6A5E6F5E535E50474B413A38322D272320151513
040404000000090A0A1214141B1E1E2427272D3131353A3A3C4242434A4A4A525250595A
5660615C6768626E6F677576
707F807483847886877C8A8A808D8D8390908693938A96958C98978F9A99919B9A919B9A
919A99929A98939A97939A97959B97979C979C9F99A0A29BA4A49CAAA69DADA89EB1AA9F
B3ABA0B5ACA0B7AB9FB7AA9EB6A99CB4A799B2A496AFA093AA9C8EA6978AA091849C8C7F
9585798F7F7389796D81716776675E675C53584F4848423C383430272624161817070A0B
000102080A0A111313191C1C212525292E2E313636383E3F3F4647464E4E4C5555525C5C
5862635D696A626F70677577
707E807382837785867A88887D8B8B808D8D8390908692928894938A95948B96958B9694
8B94938A94928B93918C94918D94918F95919297929698939999939D9C949F9D94A19E95
A39E95A59E94A49D93A49D92A49C91A29A8FA0978C9D9388988F8493897F8E8479887D72
7F766D7B7269766D646C645C605953544E4946433E3736332829281A1D1C0D1010030505
060707101213181C1C202425282C2D2F3435363C3D3D4344434B4B4951524F5859545E5F
5964655E6A6B637071687677
6F7E7F7281827583847886877B88897D8B8B808D8D828E8E84908F859190869190869190
86908F848E8D848D8B848D8B868E8B888E8B898E8A8B8F8A8C908B90918B91918B92918A
94928A949189949188949188938F86918C848E8A818B867E87827A827E767C777076726B
716E686C686365615C5A5853514F4B4645423839372A2D2C1D2121111616060A0A070A0A
111414191C1D212525282D2D2F3435353B3C3B424341494A474F504C5556515B5C566162
5B66685F6C6D647172687678
6F7E7F7280817482837684857986877B88897D8A8A7E8B8B808C8C818D8D818D8D828D8C
818C8B808B897F89887F88867E87857E86837F868381878282868284878283868182857F
82847F82847E83847E83847D82827B80807A7E7E777A7A7477777172726E6E6F6A6A6B67
6566636464605D5C59535351494A483C3F3D2D3232212727141B1C0C12120B0F10141718
1B1F20222728292F2F2F3636363C3D3B434341494A464F4F4B5455505A5B545F60596465
5D696A616D6F657274697778
6F7D7F717F807381827583847784857886877A87887B88897C89897D8A8A7E8A897E8989
7D88887C87867B858479838278807F78807E777F7C777E7B777E7A787E79777C78767B77
767B767479757478737478737377727075706E726E6B6F6C686D6A6469666267645C6160
5A5F5D565B594D5352454A4A3A41412E3637252C2D192223111718121717181D1E202526
262C2D2C333332393A383F403D4546424A4B4750504B55564F595A535E5F5763645B6768
5F6B6C626F71667375697779
6E7D7E707E807280817381827583847684857785867886867986877A87877A87877A8686
7A858579848477828276807F727C7B6D77756E77756F78757078756F76726C737068706D
676F6C68706C696F6C656D6A626B69626B69626B686069675E66655B64645A6262545D5D
525B5B4C5556464E4F3E4647343D3E2A3436242D2E1921221A2021212728262D2E2C3334
31393A363E3F3B444540494A444D4F4952534D5658505B5C545F605763645B66685E6A6B
616E6F6471736775766A787A
6E7D7E6F7E7F717F80728081738182748283758384768384768484778484778484778384
768383768282748080737E7D707B7A6D777669737268727066706E656E6C636D6B626B69
616B69606A685E68675D68675E69695F6A695C67675B66675A6566586365545F60515C5D
4D585A485254414B4D3A4344333D3E2D3536262D2E232A2C2A32332F3738343C3D394142
3D4647414A4B454E504952544C5658505A5B535E5F5661625964665B67695E6A6C616D6F
6370726673756876776A797A
6E7C7E6F7D7F6F7E7F707F80717F81728081738182738182748182748182748182748182
748181738080727E7F717D7D6F7A7A6C78786975746570705E69695C67665D69685D6868
5B66655A67665B67675C68685C68685B6767596566586465556163536062515D5F4E5B5D
4B5759485153434D4E3B4445353E3F323A3B323A3C3740413B44453E4849424C4D454F51
4953544C56584F595B515C5E545F615762645965665B67695E6A6B606C6E626F70647172
6573756775776977796B797B
6D7B7D6E7C7E6E7D7E6F7D7F707E7F707E80717F80717F80717F80717F80717F80717F80
717F7F717E7F707D7E6F7C7D6E7A7B6C79796A7677677374647071616E6E5E6B6C5A6668
5A66675B68695A67685B68675D69695C68695C686A5B6769586567576466556264546062
515D5F495455454F51424C4E444E504650514751534954554B56584E595A505B5D525E5F
5560625762645965665A67685C696A5E6A6C5F6C6E616E6F627071647173657374677476
6876776977796A797A6B7A7C
6D7B7D6D7C7D6D7C7E6E7C7E6E7D7E6E7D7E6F7D7F6F7D7F6F7D7F6F7D7F6F7D7F6F7D7E
6F7D7E6F7D7E6E7C7D6E7B7D6D7B7C6C7A7B6B797A6A7778687677677476657374647273
637172637172637072637071616E705E6B6E5D6B6D5C696C5B686A5A6769596668576567
5662645461635864665864665865665965675A66685B67695C696A5D6A6C5E6B6D5F6D6E
616E6F626F706370726371736472746573746674756775766775776876786977796A7879
6A787A6B797B6B7A7C6C7B7C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?ooo`A]O7d8KGan16emO`M^OGl<KWj02fmoP@Q_P884L8232721
P`A`PH@3L8:42722Q@A`PhH4LH>71765R0A`PhH3L8:51722Q11aPX@3LH>537:3Q@AbPh@4LX:31761
PP=aP844LGn0271nO`A_OGh4Kgam0fmkN`A^NGT4KGQh16afM@AZLg84K7If16ahN@=]NGX<KGYk16ej
O0m]Ng`@KG]m5Oooo`005?ooo`A]O7d8KGan16emO`M^OGl<KWj02fmoP@Q_P884L8232721P`A`PH@3
L8:42722Q@A`PhH4LH>71765R0A`PhH3L8:51722Q11aPX@3LH>537:3Q@AbPh@4LX:31761PP=aP844
LGn0271nO`A_OGh4Kgam0fmkN`A^NGT4KGQh16afM@AZLg84K7If16ahN@=]NGX<KGYk16ejO0m]Ng`@
KG]m5Oooo`005?ooo`A]O7d8KGan16emO`M^OGl<KWj02fmoP@Q_P884L8232721P`A`PH@3L8:42722
Q@A`PhH4LH>71765R0A`PhH3L8:51722Q11aPX@3LH>537:3Q@AbPh@4LX:31761PP=aP844LGn0271n
O`A_OGh4Kgam0fmkN`A^NGT4KGQh16afM@AZLg84K7If16ahN@=]NGX<KGYk16ejO0m]Ng`@KG]m5Ooo
o`005?ooo`A]O7h4KGeo16imO`A^OX07Kgn11720PPA`PH<4L8641762Q0AaPhD3LX>617:4Q`AbQHL4
LhF817>6R@AcQhX4M8N:0gB8R`AdRH`4M8V=17B:SPAdRi04M8bA17B:SP=dRXd8M8V;17F8R`AeRH/4
MXV<1gN:S0AgRh`4MhZ;17N:RPAgR8T4MXJ70gJ5Q@AdPh<4M86217>0P0AbOgl4LGel0g1jN@A_MgH4
KGAc16]`KPAZKV`4Jg=b16efM@=]MgL4KWQh16iiN@A^NGX;KWYk46ekO0Q]NgdEoooo000Doooo16el
OPA]OGl4KWeo16inP0M_Oh44L8221721P`A`PH@4LH:41763Q@=bPhH4LXB717:5Q`AcQHP4LhJ917>7
RPAdQhX3M8R;17B9S0AdRHd4M8Z>17B;T0AdS944M8Z>0gB:S@QdRH/4MHR;17F9R`AfRH`7MhZ<17N;
S0AgRX/4MhZ:17N8R@AfQXL3MXF517B3P`AdPH84Lh20179oO`AaOG`3L7Yi16mgMPA]M7<4Jg1^16Y^
K0A[Lg84KGIe0fegM`A^N7P4KWUi16iiNP]^NW/@KG]l26ekOAGoool001Coool4KGan16emO`A^OGl4
KWj01fmoP@A`P884L8631721Q0AaPX@4LH>50g:3QPAbQ8L4LXF717>5R0AcQXT4LhN:17B7RP=dR8/4
M8V<17B9S@AdRXh4M8^@17B<T@AdRXh3M8Z=27B9R`AeR8/4MHV;17J9S0MgRX`4Mh^<17N:R`AgRXX4
MhR917J6Q`=fQHD4M8>317B1PPAcP804LWmo175mO0=`NWT4KgMf16edL`A[L6h4JVi/16]cLPA]MWD3
KGMg16ihN0A^NGT4KWUj2fijNa1]Ng`8KG]m5Oooo`005?ooo`A]O7h4KGeo16imO`A^OX07Kgn11720
PPA`PH<4L8641762Q0AaPhD3LX>617:4Q`AbQHL4LhF817>6R@AcQhX4M8N:0gB8R`AdRH`4M8V=17B:
SPAdRi04M8bA17B:SP=dRXd8M8V;17F8R`AeRH/4MXV<1gN:S0AgRh`4MhZ;17N:RPAgR8T4MXJ70gJ5
Q@AdPh<4M86217>0P0AbOgl4LGel0g1jN@A_MgH4KGAc16]`KPAZKV`4Jg=b16efM@=]MgL4KWQh16ii
N@A^NGX;KWYk46ekO0Q]NgdEoooo000Doooo16elOPA^OGl4Kgj016moP@A`P883L8631762Q@AbPhH4
LXB717>5R0AdQXT3M8N:17F8R`AeRH`4MXZ>17J;S`AgS904MhfA0gR>TPAhSi@4N92E17RAUPAhTiP4
NIBJ17RBU`=hT9@4N92C17R?TPQiSi84NY2B0g^@T@QjT944Ni2@17Z>SPAiS8`4NHZ:0gR8R0AhQXH4
MhF417J2PPAeP7l4M7el0g9iN0A`MW@4KG9_16Y/J0AZKFX4K75_16edL`=^MWD4KWMg16ihN0A^NGT4
KWUj16ijNPM^NW/8KW]l26ekO0A]NgdEoooo000Doooo16elOPA^OGl4Kgj016moP@A`P883L8631762
Q@AbPhH4LXB717>5R0AdQXT3M8N:17F8R`AeRH`4MXZ>17J;S`AgS904MhfA0gR>TPAhSi@4N92E17RA
UPAhTiP4NIBJ17RBU`=hT9@4N92C17R?TPQiSi84NY2B0g^@T@QjT944Ni2@17Z>SPAiS8`4NHZ:0gR8
R0AhQXH4MhF417J2PPAeP7l4M7el0g9iN0A`MW@4KG9_16Y/J0AZKFX4K75_16edL`=^MWD4KWMg16ih
N0A^NGT4KWUj16ijNPM^NW/8KW]l26ekO0A]NgdEoooo000Doooo16elOPA^OGl4Kgj016moP@A`P883
L8631762Q@AbPhH4LXB717>5R0AdQXT3M8N:17F8R`AeRH`4MXZ>17J;S`AgS904MhfA0gR>TPAhSi@4
N92E17RAUPAhTiP4NIBJ17RBU`=hT9@4N92C17R?TPQiSi84NY2B0g^@T@QjT944Ni2@17Z>SPAiS8`4
NHZ:0gR8R0AhQXH4MhF417J2PPAeP7l4M7el0g9iN0A`MW@4KG9_16Y/J0AZKFX4K75_16edL`=^MWD4
KWMg16ihN0A^NGT4KWUj16ijNPM^NW/8KW]l26ekO0A]NgdEoooo000Doooo16elOPA^OGl4Kgj016mo
P@A`P883L8631762Q@AbPhH4LXB717>5R0AdQXT3M8N:17F8R`AeRH`4MXZ>17J;S`AgS904MhfA0gR>
TPAhSi@4N92E17RAUPAhTiP4NIBJ17RBU`=hT9@4N92C17R?TPQiSi84NY2B0g^@T@QjT944Ni2@17Z>
SPAiS8`4NHZ:0gR8R0AhQXH4MhF417J2PPAeP7l4M7el0g9iN0A`MW@4KG9_16Y/J0AZKFX4K75_16ed
L`=^MWD4KWMg16ihN0A^NGT4KWUj16ijNPM^NW/8KW]l26ekO0A]NgdEoooo000Doooo16emOPA^OX04
Kgn11720PPAaPX@3LX>517>4Q`AdQXP4M8N:17F8R`AfRHd3Mh^>17R<T0AhSY84NHnC17ZAU@AkTYH4
Ni>H0gbEVPAlUY/4OINM17fIWPAmVZ04O9^R17bHWP=lUi/4O9JJ27bEV0AmUIL4OIBF0gfDU@AlU9D4
O9>D17fBT`AlTI84O92@17^>SP=kSH`4NhZ917Z7QPAhQ8<4Mh5o17EmN`=cNGL4LGEb16i`K@A[JfL4
K6iZ16eaKPA^Lg43KgEd16mgM@A_N7L4KgQh26miN@=_NWX8KWYk26ikO0A]Ng`4KG]m5Oooo`005?oo
o`A]OGh4KWj016moP@A`P884LH:40g:3Q@AcQ8L4M8J817B7RPAeR8/4MXV=0gN;SPAhS904N8jB17V?
T`AjTID4Ni:F17^CV0=lUIX4O9JK17fGW@AmVIh4OIZP17bKXPAlV9h3O9NK17bFVPQlUIP4OIFG17fD
UP=mU9D4O9BE17bCU0AmTY<4O96B17b@T0AkSXh3Nhf<17^:R@AjQhH4N8B317N1O`AeOG/3LgUg175e
LPA^L6d4Jf]W16a^JPA]LFh4KW=a0fmeM0A_MgD4KgQg16mhN0Q_NGT3KgYj26ijN`Q^Ng`4KG]l16ek
OAGoool001Coool4KGen16inP0A_Oh44L8221762Q0=bPhD4LhB717B6R0AdQhX4MHR;17J9S@=gRhh4
N8b@17R>TPAiSi<4NY6E17^BUPAkTiP3O9FJ17bFV`AmUid4OIVN17fJX0AlVj84O9RN0gbGV`AlUYX8
O9FH17fEU`AmU9H3OIBE17bDU@AlTi@4OI:C17bATPAlT904Nhj>0g^=S0AkRXT4NXN617R4P`AgPGl4
MGek0g=iM`AaMG84KW1]16][I`A/KVX4KG5^16icL@=_MG@4KgMe16mhM`A_N7P8KgUi0fmjNPQ^NW/8
KW]l16ekO0A]NgdEoooo000Doooo16emOPA^OX04Kgn11720PPAaPX@3LX>517>4Q`AdQXP4M8N:17F8
R`AfRHd3Mh^>17R<T0AhSY84NHnC17ZAU@AkTYH4Ni>H0gbEVPAlUY/4OINM17fIWPAmVZ04O9^R17bH
WP=lUi/4O9JJ27bEV0AmUIL4OIBF0gfDU@AlU9D4O9>D17fBT`AlTI84O92@17^>SP=kSH`4NhZ917Z7
QPAhQ8<4Mh5o17EmN`=cNGL4LGEb16i`K@A[JfL4K6iZ16eaKPA^Lg43KgEd16mgM@A_N7L4KgQh26mi
N@=_NWX8KWYk26ikO0A]Ng`4KG]m5Oooo`005?ooo`A^OGl4Kgj11720PPAaPH@4LX>60g>5R0AdQhT4
MHR;17J:S@AgRhl4N8fA0gV?T`AjTID4Ni:G17bDV@AmUY/4OYRM17nIW`>0Vj44P9fS186NY@B1X:H4
PJ6X182QZ@B0WjD3P9fR182LX0B0Vih4P9ZM186JW0B1VI/3PIVJ186HVPB1V9T4PIJG182EU@AoTi<4
Oi6A0gj?SPAnS8`4O8V817^5Q0AiPX04Mgil0gEjM`AcMG44Kfm[16e[IPA^KVX4Kg5^171cL0=`MG<4
L7Ie171gMPA`N7L4L7Uh171iN@M_NWX4KgYk16ikN`A^Ng`4KG]l16ekOAGoool001Coool4KWeo16mn
P@A`P884LH6417:3QP=cQHP4M8N917F8R`AfRXd4Mh^?17R=T@=iSi<4NY6E17^BU`AlU9T4OIJK17jH
W@AoVIl3P9^Q182MX`B1WZD4PJ2V186QZ0B0XJT4P9nU0h2MXPB0W:04P9^N182JW@B1VY`4PIVK0h6I
VPB1V9X4PIRI186FU`B0UID4Oi>C17nAT@=nShh4OXb<17b9R0AkQH@4NH:017MnO0=eNWL4LgEa16m_
J`A]JfH4KViZ16maKPA`Lg03L7Ec171fM@A`MgH4L7Qg171iN0A`NGT7KgYj16mjN`A^Ng/4KW]l16ek
O0A]NgdEoooo000Doooo16imO`A_OX44L8221761Q0AbPhH3LhF817B7R@AeR8/4MXZ=17N;S`AhSI43
NHnC17ZAU@AkTYL4O9BI17fFV`AnV9d4OiVO0h2KX@B0WJ<4PIjU186PYPB1XJP4P:6Y182OY@>0WJ84
P9bP182KWPB0VYd4PIZL186IV`>1VIX4PIRJ186HV@B1UYL4P9FE17nCT`AoTI43OXn>17j<S0AlRHP4
NhF417V2P0AgOW`3MGYg17=eL@A_Kf/4KF]V16i^JPA_LFh4L7=`0g1eL`A`MWD4L7Mf171hM`A`NGP4
L7Ui1fmjNPA_NW/4KW]k16ikO0A]Ng`4KG]m5Oooo`005?ooo`A^OGl4Kgj11720PPAaPH@4LX>60g>5
R0AdQhT4MHR;17J:S@AgRhl4N8fA0gV?T`AjTID4Ni:G17bDV@AmUY/4OYRM17nIW`>0Vj44P9fS186N
Y@B1X:H4PJ6X182QZ@B0WjD3P9fR182LX0B0Vih4P9ZM186JW0B1VI/3PIVJ186HVPB1V9T4PIJG182E
U@AoTi<4Oi6A0gj?SPAnS8`4O8V817^5Q0AiPX04Mgil0gEjM`AcMG44Kfm[16e[IPA^KVX4Kg5^171c
L0=`MG<4L7Ie171gMPA`N7L4L7Uh171iN@M_NWX4KgYk16ikN`A^Ng`4KG]l16ekOAGoool001Coool4
KWeo16moP@AaPH<4LX>517>5R0=dQhX4MXV<17N;SPAhSI04NXnC17^AU@=lTiL4OIFJ17jGW0B0VIh4
PI^Q18:MX`B3X:H3Q::X18FTZ`B5YZd4QZN_18FX/0B4Z;04PjF[0h>SZ0B3XJH4Q:2T18BOXPB4Wj47
QInP18FNW`B5WIh4Q9^L18BJVPB4V9P4PiFE0h>CTPB2T8l4P8^;17j8Q`AlQ884NX1m0gQkM`AeMG44
LFiY16m/IPA`Kf/4LG9^175dL0=aMG84LGId175gMPAaN7L4LGUh171iN0=`NGT4L7Yj16mjN`A_Ng/8
KW]l16ekO1Goool001Coool4KWeo16moP@AaPH<4LX>517>5R0=dQhX4MXV<17N;SPAhSI04NXnC17^A
U@=lTiL4OIFJ17jGW0B0VIh4PI^Q18:MX`B3X:H3Q::X18FTZ`B5YZd4QZN_18FX/0B4Z;04PjF[0h>S
Z0B3XJH4Q:2T18BOXPB4Wj47QInP18FNW`B5WIh4Q9^L18BJVPB4V9P4PiFE0h>CTPB2T8l4P8^;17j8
Q`AlQ884NX1m0gQkM`AeMG44LFiY16m/IPA`Kf/4LG9^175dL0=aMG84LGId175gMPAaN7L4LGUh171i
N0=`NGT4L7Yj16mjN`A_Ng/8KW]l16ekO1Goool001Coool4KWeo16moP@AaPH<4LX>517>5R0=dQhX4
MXV<17N;SPAhSI04NXnC17^AU@=lTiL4OIFJ17jGW0B0VIh4PI^Q18:MX`B3X:H3Q::X18FTZ`B5YZd4
QZN_18FX/0B4Z;04PjF[0h>SZ0B3XJH4Q:2T18BOXPB4Wj47QInP18FNW`B5WIh4Q9^L18BJVPB4V9P4
PiFE0h>CTPB2T8l4P8^;17j8Q`AlQ884NX1m0gQkM`AeMG44LFiY16m/IPA`Kf/4LG9^175dL0=aMG84
LGId175gMPAaN7L4LGUh171iN0=`NGT4L7Yj16mjN`A_Ng/8KW]l16ekO1Goool001Coool4KWio1720
PPAaPX@4LhB717B7R@=fRH`4Mh^?17V=T@AjT9@4O9:F17fEV@=oUi`4P9VN186LX@B3WZ@4Q:6W18JS
Z@B7YZ`3R:R_18V[/PB;[[D4Rk2h18Za^PB8[[H4QjZ`0hNX[@B7YZ/4QjFY28RTY`B9Y:H3RJBU28VS
Y0B9XZ84RJ2P18RMW@B8VYX3QiNG18JDT`B4Shl4PX^:1827Q@AmPX03NWah17MfL@AcKfT4LViY17=a
K0AcLfl4LgAa0g=fL`AcMg@4LgMe179hMPAbNGL4LGUh0g5iN@Q`NWX4Kg]k16ikN`A^Ng`4KG]l5Ooo
o`005?ooo`A^OWl4L8221762Q0AcQ8L4M8N90gJ9S0AgRhl4NHfA17Z@U0AlTYH4OIFI0gnGW0B0VIh4
PIbQ18>NY0B4XJL4QZ>Y18NV[0>8Z:l4RJ^b18^^]@B;/;P4R[6j18R^]PB7Z[03QjR]18NVZ`B7YJT8
R:BW18VTYP>9Y:D8RJ>T18VRXPB9X:04R9fM18RJVP>7UiL4QYBC18B?S`B2RhX4P8N517f2P0=jO7P4
MgIa17=_J@AbKVT4Lg5/17=cK`AcM743LgIc17=gM0AcMgD4LWQf179iM`AaNGP3LGUi271jNPA_Ng/4
KW]k16ikO0A]Ng`Eoooo000Doooo16inO`A`P884LH:417>4Q`AdQhT3MXV<17N;S`AiSI44NY2D17bB
UPAmUIT3OiNL182IWPB1W:44PijT18BQY`B6XjT4QjJ/0hRX[`B9Zk84Rjje18^`^0B:/KX4R:jf18NZ
/0>7Z:d4QjJ[18NUZ@R8Y:L4RJBV0hVTY@R9Xj@4RJ:R18VPX0B8WId4R9ZJ0hNGU`B6U9<4Q8n?18:;
RPB0QhD4OH:00gYlN0AgMW44LfmY179^J@AcLF`4Lg=_17=dL@=cMW<4LgMd17=gM@AbN7H4LWUg175i
N0=aNGT8L7Yj16mkN`A^Ng/4KW]l16ekO1Goool001Coool4KWio1720PPAaPX@4LhB717B7R@=fRH`4
Mh^?17V=T@AjT9@4O9:F17fEV@=oUi`4P9VN186LX@B3WZ@4Q:6W18JSZ@B7YZ`3R:R_18V[/PB;[[D4
Rk2h18Za^PB8[[H4QjZ`0hNX[@B7YZ/4QjFY28RTY`B9Y:H3RJBU28VSY0B9XZ84RJ2P18RMW@B8VYX3
QiNG18JDT`B4Shl4PX^:1827Q@AmPX03NWah17MfL@AcKfT4LViY17=aK0AcLfl4LgAa0g=fL`AcMg@4
LgMe179hMPAbNGL4LGUh0g5iN@Q`NWX4Kg]k16ikN`A^Ng`4KG]l5Oooo`005?ooo`A^OX04L86317:3
QPAdQXP4MHR;0gN;SPAiSI44Ni2D17bCU`AnUIX4P9RM0h6KX0B3WZ<4QJ2V18JSZ@B8YZ`4RJV`18^/
/`><[kH4S[:j192f_PBC^/<4SKFn18V_]`B9[K@3RZba18Z[[`B;ZZh4RjZ]18bZ[0B=ZZ`3SJZ[18jZ
Z`B>ZZX4SZRY18jVYPB>Y:<4SJ2O0hbLV`B;V9L4RI>B18J>S0B3RHL4P8B10genNPAiN7<4MG5[17Ea
K0AeLfh4MGA`17EeLP=eMW<4M7Md17AhM@AcN7H4LgUg179iN0=aNGP4LGYi171jNPA_NWX4KgYk16ik
O0A]Ng`Eoooo000Doooo16inP0A`PH<4LX>617B6R0AeR8/3Mh^>17V=T@AkT9@4O9>G17jEVPB0V9d3
PI^P18>NX`B5X:H4QZ>Y18RV[0B9ZK04Rjbc0hb_]PB>/[X4T;Jn19>j``B=]Kh4RJng18V]]0>:[;44
RZ^_18^Z[PB;ZZd4S:Z/18fZ[0>=ZZ/4SZZ[18jZZPB>Z:T4SZJV18jTX`B=X9l3S9bK18^HU`B9Ti84
QXj<18>9Q`B0Q843OGij17UhL`AeLF/4MG5/17EcKPAeM704MGEb0gEfL`AdMg@4M7Qe17=hMPAcNGL4
LWUh0g5iN0AaNWT4L7Yj16mjNPA_NW/4KW]l16ekO1Goool001Coool4KWj01721P`AbPhH4M8J817F8
R`=gRhh4NHfA17^@U0AlTiL4OYFJ182HW@>1Vj04PijS18FPYPB6XjT4R:J/18VY/0B;[;<3S:nf18jb
^PB@][h4Tk[318fe_PB9[kL4RJfd0hZ//@B:Zjl4RjZ^18^Z[@B<ZZ`4SJZ/0hfZZ`B>ZZ/4SZZZ18jX
Z@B>YZH4SZBS18fPW`><W9/4RiRG18VCTPB6SX`4PhV71824P@=mOWX4NGQc17EaJ`AeLF`4MG=^17Ed
L0AeMG83MGIc17AgM0AdN7D4LgQf17=iM`AbNGP3LGUh175jN@A`NWX4KgYj16mjN`A^Ng`4KG]l5Ooo
o`005?ooo`A^OX04L86317:3QPAdQXP4MHR;0gN;SPAiSI44Ni2D17bCU`AnUIX4P9RM0h6KX0B3WZ<4
QJ2V18JSZ@B8YZ`4RJV`18^//`><[kH4S[:j192f_PBC^/<4SKFn18V_]`B9[K@3RZba18Z[[`B;ZZh4
RjZ]18bZ[0B=ZZ`3SJZ[18jZZ`B>ZZX4SZRY18jVYPB>Y:<4SJ2O0hbLV`B;V9L4RI>B18J>S0B3RHL4
P8B10genNPAiN7<4MG5[17EaK0AeLfh4MGA`17EeLP=eMW<4M7Md17AhM@AcN7H4LgUg179iN0=aNGP4
LGYi171jNPA_NWX4KgYk16ikO0A]Ng`Eoooo000Doooo16mnP0AaPH@4LhB717F7RPAgRXd3NHf@17^@
T`AlTiL4OYJJ182IW@B2W:43Q9nT18JRZ0B8YJ/4RJR_18^[/PB=[[H4Sk:j0i2e_@BB^L84UKg619Jo
b@B9/k`4R[6i18^a]`></;H4S[2d18j_/`B?[k84T:na196_/0>A/;04T[2a19>a/0BC[jl4U:f/19>Y
Z0BBYJ@3TJ2O192LV`B=UiD4RY6?18N<RPB3QX<3P85m17ekMPAiMFl4N7E`17QeL@AhMW47MgMc17Ih
M0AeN7D4MGQf17AiM`AcNGP3LWUh175jN@AaNWX4L7Yj16mjN`A^Ng`4KG]l5Oooo`005?ooo`A_OX04
LH6417>4Q`AeQhX4MhZ=0gV=T0AkT9<4O9>G17jFVPB0VId4PYbQ0hBOY0B6XZP4R:F[18VX[`B;Zk84
SJjf18nb^P>@]Kd4T[W219FmaPBF_lT4RK>l18Za^@B;/KL3S;2f18j`]0B>[k<4Sjnb192_/@BA[k03
TK2`19:`/@BC/K04Tjn_19B][0BCZJP4TZFT0i6PW`B@W9/4SINE18ZAS`B7S8X4PhJ30h21O@AmNgH4
NGE_17QeL0AhMG44N7Ia1gMgL`AfN7@4MGQe17EhMPAdNGL4LgUh0g9iN0AaNWT4LGYj171jNPA_NW/4
KW]l16ekO1Goool001Coool4Kgj01761Q0AcQ8L4MHN:17N:S@=iSI04Ni2C17bCU`AnUYX4P9VM18:L
X@>4Wj@4QZ:X18RUZ`B9Z:l4Rj^b18f^]PB?/[X3T;Fm19:i`PBE_LH4U[o918Vc_0B:/KT4Rk6g0hb`
]PB>/;@4SZnc18n_/PB@[k44TJn`0i6`/0BB/;44Tk6`19>_[`BD[J`4TjVX19:UY0>AX9l4T9bK18fG
U@B:THl4Qhb:18>6P`>0PGd4OG]f17UeK`AhMG04N7Ea17QfL@MgMg<4MWQd17EhM@AeN7H4M7Ug17=i
N0=bNGP4LGYi175jNPA`NWX4KgYk16ikO0A]Ng`Eoooo000Doooo16mnP0AaPH@4LhB717F7RPAgRXd3
NHf@17^@T`AlTiL4OYJJ182IW@B2W:43Q9nT18JRZ0B8YJ/4RJR_18^[/PB=[[H4Sk:j0i2e_@BB^L84
UKg619Job@B9/k`4R[6i18^a]`></;H4S[2d18j_/`B?[k84T:na196_/0>A/;04T[2a19>a/0BC[jl4
U:f/19>YZ0BBYJ@3TJ2O192LV`B=UiD4RY6?18N<RPB3QX<3P85m17ekMPAiMFl4N7E`17QeL@AhMW47
MgMc17IhM0AeN7D4MGQf17AiM`AcNGP3LWUh175jN@AaNWX4L7Yj16mjN`A^Ng`4KG]l5Oooo`005?oo
o`A_Oh44LH:417>5R0AfR8/4N8^?0gZ?TPAlTYH4OYFJ182IW@B3W:44QInU0hNSZ0B9YZ`4RjZ`18f]
]0B?/;P4TKBl19>h`0>D^l@4U[o819W3cPB>^/D4QK2k18^c_0B>];/3T;Fj196e^@BB]KP4TkBg19Bd
]PBE]KH3U[Jf19Nf]PBH][D4V;Bc19Ra/0BG[J`4UZVW0iFTX`BCX9h4T9ZH18fDTPB:Sh`4QXV50h>3
O`AoOWT4O7Uc17ahL`AkN7<4NWQc17UhM0=hN7@4N7Qe17MiM@AfNGH4MGUg17AiM`=cNGP4LWYi175j
N@A`NWX4KgYk16ikN`A]Ng`Eoooo000Doooo16moP@AaPX@4LhF817J8R`AhRhl3NXnB17bBUPAnUIX4
P9VM18>LX@B5WjD3Qj>X18VV[0B;Z[04SJfd18n`^0BA];`4TkS00iBka0BF_lP4VL?>18jja@B5/;/4
Rk>l18jd^`>@]KX4TKFi19:e^0BC];L4U;Bf19Fe]P>F][H4UkJf19Rf]@BH];<4V;6`19N][0BFZJL3
UJBS19>PWPB@VYP4SIBB18Z?S0B6RHD3Ph=o17mnN@AlNG<4O7Qc17]hL`AjN7<4NGQd0gQhM0AhN7D4
MgUe17IiMPAeNGL4M7Ug0g=iN0AbNWT4LGYi171jNPA_NW/4KW]k16ekO1Goool001Coool4Kgn11762
Q0AcQHP4MXR;17R;S`=jSi84O9:F17jEVPB0VId4PibQ18FOY@>7XjP4RJJ/18^Z/0B=[K@4Sk2h196d
_0BC^<03U;_419Job0BI`lh4S[[518F`^`B;/k`4S[Bk0i2e^PBA]KT4T[Fh19>d]`BD];H4UKFf0iJf
]PBG][H4V;Je19Rd/`BH/K04Ujf/19JYY`>EY:<4Tj2N192JV0B=U984RXn<18J9Q@>3Pgl4Ogii17ai
L`AlN7<4NgQc17YhL`AiN7@3N7Qd17QhM@AgNGD4MWUf17EiM`AdNGL3LgUh179jN@AaNWT4L7Yj16mj
N`A^Ng/4KG]l5Oooo`005?ooo`A_Oh44LH:417>5R0AfR8/4N8^?0gZ?TPAlTYH4OYFJ182IW@B3W:44
QInU0hNSZ0B9YZ`4RjZ`18f]]0B?/;P4TKBl19>h`0>D^l@4U[o819W3cPB>^/D4QK2k18^c_0B>];/3
T;Fj196e^@BB]KP4TkBg19Bd]PBE]KH3U[Jf19Nf]PBH][D4V;Bc19Ra/0BG[J`4UZVW0iFTX`BCX9h4
T9ZH18fDTPB:Sh`4QXV50h>3O`AoOWT4O7Uc17ahL`AkN7<4NWQc17UhM0=hN7@4N7Qe17MiM@AfNGH4
MGUg17AiM`=cNGP4LWYi175jN@A`NWX4KgYk16ikN`A]Ng`Eoooo000Doooo16moP@AbPhD4M8J917J9
S@AiSI03Ni6D17jDV0B0V9`4PYbP18FOY0B7XjT3RJN]18bZ/@B>[[D4T;:i19:f_PBD^L84U[g60iS1
b`BLam84Tl3;18Ve`0B;]/04S[No196h_`>C^Kl4UKVn19Ji_@BG^K/4V;Vj19Vj^P>J^k/4Vkfl19^k
^PBL^KL4W;Jd19^a[`BJ[:X3VJNV19NRX0BDWIX4TIJD18f@S@B9RhL3QXJ218>2O@B1OWT4OgYe17ij
M@AmNG@4O7Ud0gYiM@AiNGD4N7Ue17MiMPAfNGH4MGUg0gAiN0AcNWP4LWYi171jNPA_NW/4KW]k16ik
O1Goool001Coool4Kgn117:3Q@AdQXT4MXV=17V=T0=kTI@4OYBH182HW0B2W:04QInT18NSZ@>9Yjd4
S:Za18j^]@B@/[T4T[Jn19Bi`PBF_LH3V<7;19c7dPBC`</4RKG018^f`0B>]kl4TKRo0i>i_`BE^Kh4
U[Vm19Ni^`BH^KX4VKZj0iZk^`BK_K`4Vk^j19bi]`BL][@4Vk6_19Z/ZP>IYjH4Uj:P19BMVPBAUY@4
SI2=18V;Q`>6QX84Ph9m185nN@AoNWD4OWYe17eiM0AlNG@3NWUe17UiM@AhNGD4MgUf17IiMPAeNGL3
M7Uh17=jN0AbNWT4L7Yj16mjN`A^Ng/4KW]l5Oooo`005?ooo`A_Oh44LX>517B6R@AfRHd4NHf@0g^A
U0AnU9P4P9RL18:LX0B5Wj@4Qj>Y0hVW[@B<Z[44SZje192b^@BB][h4U;W219JmaP>H`L/4W<OB19?0
b`B9]L04RkK018jg_`BA^;l3TkVo19Fi_PBF^Kd4UkVk19Ri^PBI^[X3V[^k19^m_0BK^kX4W;Vg19bf
]0BK/Jl4VZbZ0iVWYPBGXZ04U9fJ196FU0B=T8d4RH^70hJ6PPB3PWd4PGii17mjM@AnNWD4OGUd17ai
M0=jNGD4NGUe17QiM@AgNGH4MWUf17EiM`=dNGP4LgYh179jN@A`NWX4KgYk16ikN`A^Ng`Eoooo000D
oooo16moP@AbPhD4M8J917J9S@AiSI03Ni6D17jDV0B0V9`4PYbP18FOY0B7XjT3RJN]18bZ/@B>[[D4
T;:i19:f_PBD^L84U[g60iS1b`BLam84Tl3;18Ve`0B;]/04S[No196h_`>C^Kl4UKVn19Ji_@BG^K/4
V;Vj19Vj^P>J^k/4Vkfl19^k^PBL^KL4W;Jd19^a[`BJ[:X3VJNV19NRX0BDWIX4TIJD18f@S@B9RhL3
QXJ218>2O@B1OWT4OgYe17ijM@AmNG@4O7Ud0gYiM@AiNGD4N7Ue17MiMPAfNGH4MGUg0gAiN0AcNWP4
LWYi171jNPA_NW/4KW]k16ikO1Goool001Coool4Kgn117:3QPAeQhX4Mh^>17Z?TP=mTiH4OiJK18:J
W`B5WZ@4Qj:X18ZV[0><Z[44Sjje196c^PBD]kl4U[_319Rob0BJ`ld3W<OA19O4c`B=^lH4Sk_6192k
a@BB_<<4UKg40iNna0BI_/<4V[k119^m`0BL_Kl4WKno0ifn_PBN_[d4WkZj1:2h]`BO/k84Wk2_19j]
Z`>MZZL4VjBR19NNW0BCV9D4Si:?18b=R@>8R8@4QHAo18>0NPB2OGP4P7af17mkM@AnNWD3O7Ye17]j
M@AjNGD4N7Uf17MiMPAfNGL3M7Ug17=iN0AbNWT4LGYi171jNPA_NW/4KW]l5Oooo`005?ooo`A_Oh44
LX>617F7RPAgRhh4NXnB0gfCUPAoUY/4PYZO18FNY0B7XZP4RZJ/0hbZ/@B?[[D4TK>j19Bg_`BF^l<4
V;o819[3c@>Lam44UlC?18fkaPB?^lH4T;_519:l``BE_L@3Ukk419Vn``BJ_/44Vkg019bm_`BM_kl3
WKjn19jn_@BO^[X4X;Rg19nc/PBO/:l4WZf[0ifZY`BKY:84UijL19>HU@B?TXl4S8f90hR8Q0B5Q7l4
Ph1j189mN0B0O7H4Og]e17ijM@=lNWD4NgYe17YiM@AhNGH4MgUf17IiM`=dNGL4LgUh179jN@AaNWT4
L7Yj16mjN`A^Ng`Eoooo000Doooo16moP@AbPhH4MHN:17N;SPAjSi83OI>F17nFV`B2VYl4QIjT18NR
Z0B:YZ`3S:Za18n^]@BA/kX4U;No19Jk``BH_lP4V/?=0ic7d@BGa<l4SK_618nkaPB@^lD4T[c319Fm
a0>G_/@4VKk319Zn`@BK_L04W;fo19fo_`>M_[h4W[jm19nj^PBP^;L4Wk>b19n`[`BN[J/3WJZW19^T
XPBGWY`4TiRE18nBS`B<SHT3R8R418F4O`B3P7X4PWeh181lMPAoNgD4OWYe0gajM@AkNWD4NWUe17Qi
MPAgNGH4MWUg0gAiM`AcNGP4LWYi175jN@A`NWX4KgYk16ikO1Goool001Coool4L82217>4QPAeR8/4
N8b?17^@U0=nUIT4PIVM18BMXPB7XJL4RJJ[18bZ/0>?[[D4T[>j19Bg_`BG^l@4V/3919c4cPBNbM<3
X/kI19O5d@BB`<`4Tko919Bob0BF_lL4VL780ic3b@BN`lL4W/;419o1`PBP`L84X<710j6n_`BR^k/4
X[Nh1::b/`BQ[jl4Xk2_1::][0>QZJP4WZBS19ZNW0BFVIL4TI>@18j>RP>;RHD4R8F018J2O0B4OgT8
PWaf181kMP=oNgD4OGYe17]jM@AiNGH4N7Uf17IiMP=eNGL4M7Uh179jN0AaNWT4L7Yj16mjN`A^Ng`E
oooo000Doooo1720PPAcQ8H4MHR;17R<S`AkT9@3OYFI186IW@B4WJ84Qj6W18VVZ`B<Z[03Sjje19:c
^PBD]kl4Uk_419[0b@BLa<h4W/WC0j;>f@BGaM44T/3<19>ob@BD_lP4U[o719W1b0>L`lT4W/?719k2
a0BO`L84X<721:31`@>Q_[l4X[^k1::g^0BR/[<4XJn_1:>`[`BR[J`3XJVX19jTX`BJWY`4UYVG196C
T0B>SXX3RhV518R5P0B6PW`4Q7mi289lMPB0NgH3Og]e17ejM@AkNWD4NGUf17QiMPAfNGH3MGUg17Ai
N0AbNWP4LGYi171jNPA_NW/4KW]l5Oooo`005?ooo`A`P884LhB617F8R`AhS8l4Ni2D0gjEV@B1VId4
Q9fR18NQY`B9YZ/4S:Z`0hn^]@BB/kX4U;No19Nka0BJ`<T4W<C>19k9d`>Rc]T4UlGA19;0c0BC_lT4
U;o819Joa`BI`LP3W<?919k3a`BN`/@4Wl721:31`PBP`L43XKjo1::k^`BR]kP4X[:c1:6_[`BS/:l4
XZf/0j6YZ0BNY:<4VYjL19JIU`BATi04SXj:0h^9Q@B8QH04QX9l18AoN@R2O7H4P7]f0gmkM@AmNWD4
NgYe17UiMPAhNGH4MWUf0gEiM`AdNGP4LWYh175jN@A`NWX4KgYk16ikO1Goool001Coool4L82217>4
QPAeR8/4N8b?17^@U0=nUIT4PIVM18BMXPB7XJL4RJJ[18bZ/0>?[[D4T[>j19Bg_`BG^l@4V/3919c4
cPBNbM<3X/kI19O5d@BB`<`4Tko919Bob0BF_lL4VL780ic3b@BN`lL4W/;419o1`PBP`L84X<710j6n
_`BR^k/4X[Nh1::b/`BQ[jl4Xk2_1::][0>QZJP4WZBS19ZNW0BFVIL4TI>@18j>RP>;RHD4R8F018J2
O0B4OgT8PWaf181kMP=oNgD4OGYe17]jM@AiNGH4N7Uf17IiMP=eNGL4M7Uh179jN0AaNWT4L7Yj16mj
N`A^Ng`Eoooo000Doooo1720PPAcQ8L4MXV<17V>T@AmTYH3P9NK18>KX0B6X:D4RJBZ18bY[`B?[K@3
T[:i19Fg_PBH_<@4Vl3919k5cPBPb]@4XloJ0ik<f0BA`<d4U<7<19K2c0BH`LX4V/?:19g5c0>Pal`4
X/O;1:;5a`BTaLH4Y/G51::m_@>Q^;T4XKBe1:6a/PBQ/K44Y;6a1:J_[`BUZZT3YJVX1:6VY0BMX9h4
V9ZH19>DT0B?SXX3SHZ518^7PPB9Q7h4R85k18IoN0B5OWL4Pgaf0h5lM@AoNgD4O7Ye17YiM@AiNGD4
MgUf0gIiM`AdNGL4LgUh175jN@A`NWX4KgYk16ikO1Goool001Coool4L82217>4Q`AfRH`4NHjA17fB
UP>0Ui/4Pi^P18JPY@B9Y:X4S:V_18n]]0>B/[T4UKNn19Rla0BK`<T4W/G>1:3:e0BScmX3W/cH1970
c@BD`L`4U/;<19S1bPBJ`lX4WLG<0j37c0BRal/4X/G71:C5aPBVaLD4X[fm0j6h^@BQ];D4XK6b1:6a
/@BT/K44YZn_1:FZZ@>UZJP4XJJT19fPWPBHVYP4TiB@18n>RP>=RXD4RhN218V4OPB8PG/4QWmh18En
M`B3O7H3PGae17mkM@AlNWD4NWUe17UiM@AgNGH3MWUg17AiM`AcNGP4LGYi171jNPA_NW/4KW]l5Ooo
o`005?ooo`A`P884LhB717J9S0AiSY44OI:F0h2GV`B3Vj04QZ2U18VTZPB<ZJl4Sjfd0i:b^@BE]kh4
V;c419_0b@BNaLh4X<[D1:??fP>Nc=P4TL3=19C1c0BF`/`4V<7:19[3bPBMaL`3X<O<1:;7b`BRaLL4
Y<G61:K5a@BR_Kd3XKRi1:6d]@BQ/K84XK6a1:Ba/@BV[jl4YJZY0jFYZ0BQYZ@4WJ2N19RJV0BCU904
Shj:0hf:Q@B;Qh84RHAn18R1N`B6OgP4QGig18=lMP>1O7D4Og]e17ajM@AjNGD4NGUe17MiMP=fNGL4
M7Ug17=iN0AaNWT4L7Yj16mjN`A^Ng`Eoooo000Doooo1720PPAcQ8L4MXV<17V>T@AmTYH3P9NK18>K
X0B6X:D4RJBZ18bY[`B?[K@3T[:i19Fg_PBH_<@4Vl3919k5cPBPb]@4XloJ0ik<f0BA`<d4U<7<19K2
c0BH`LX4V/?:19g5c0>Pal`4X/O;1:;5a`BTaLH4Y/G51::m_@>Q^;T4XKBe1:6a/PBQ/K44Y;6a1:J_
[`BUZZT3YJVX1:6VY0BMX9h4V9ZH19>DT0B?SXX3SHZ518^7PPB9Q7h4R85k18IoN0B5OWL4Pgaf0h5l
M@AoNgD4O7Ye17YiM@AiNGD4MgUf0gIiM`AdNGL4LgUh175jN@A`NWX4KgYk16ikO1Goool001Coool4
L82217B5R0AgRXd4NXnB17jDU`>1V9`4QIfR18RRY`B;Yjd4SZbb196a]`>E][d4V;_319_0b0BNaLh4
X/[D1:C?f@BWe=l3V/SE19C2cPBF`/d4VLC=19[3b`BMaL`4X<O>0jC9cPBUbL`4Z<S91:Bo`@BP]kT4
W;6c0j2c]0BR/K<4Xk:c1:Fc]0BU[Zh4Y:b[1:F[Z@>VZjT4Y:JT19nPWPBJVYL4UIF@196>RP>?RhH4
SHR318b6P0B;Pgd4RH1i18QnM@B6OGH3Pgae181kM@AnNW@4NgUe17UiM@AhNGD3MWUf17EiM`AcNGP4
LWUi171jNPA_NW/4KW]l5Oooo`005?ooo`A`P884M8F817N:S@AjSi84OYBG0h6HW0B5WJ84R::W18^W
[@B>[;84TK6g0iFf_@BH^l<4Vl3819k5cPBRb]@4Y<oI1:ODg`>Jb=D4U<;>19K2c@BIa<d4V/?;19g5
c0BPalh3Y<W>1:G9c0BXb<T4Y;o11:2g^@BL/K<3X;>d1::a/`BS/[<4YK>d1:F^[PBT[:/4YJ^Y0jJ[
Z@BTYZ@4Wj2N19ZJU`BEUI04THj:0hn;QPB=R8<4S8J018^3O@B9P7T4R7ie18ImMP>3O7D4P7]e17ij
M0AkNGD4NGUe17QiM@=fNGH4MGUg17=iN0AbNGT4L7Yj16mjN`A^Ng`Eoooo000Doooo1720PPAdQHP4
MhZ=17Z?TPAnU9L3PIRL18FMXPB8XZL4RjN]18j//PBA/KL3UKJm19Rk``BK`<P4W/G>1:;:e0BTcmT4
YmCO0i[8e@BD`/h4U/;=19W4c@BJ`l/4WLG<1:37cP>TbLh4YLW<1:S8b@BT_l44X;Ni19ba/`>P/k@4
X[6c1:>b/`BU/k@4YJj^1:B/Z`BUZjT3YZ^Y1:BVY0BOX9h4VYZG19FET0BASXX3Sh^618f8P`B<QX04
Rh=m18V0N@B8OWD4QWef0h=lM@B0NgD4OWYd17]iM@AiNGD4N7Ue0gIiMPAeNGL4LgUh179iN@A`NWX4
KgYk16ikO1Goool001Coool4L82217B5R0AgRXd4NXnB17jDU`>1V9`4QIfR18RRY`B;Yjd4SZbb196a
]`>E][d4V;_319_0b0BNaLh4X/[D1:C?f@BWe=l3V/SE19C2cPBF`/d4VLC=19[3b`BMaL`4X<O>0jC9
cPBUbL`4Z<S91:Bo`@BP]kT4W;6c0j2c]0BR/K<4Xk:c1:Fc]0BU[Zh4Y:b[1:F[Z@>VZjT4Y:JT19nP
WPBJVYL4UIF@196>RP>?RhH4SHR318b6P0B;Pgd4RH1i18QnM@B6OGH3Pgae181kM@AnNW@4NgUe17Ui
M@AhNGD3MWUf17EiM`AcNGP4LWUi171jNPA_NW/4KW]l5Oooo`005?ooo`A`P8<4M8J817R;SPAlT9<4
OiFI0h>JW`B6X:@4RZFZ18fZ/0BA[kD4U;Bk0iNi`@BK_lL4W/C=1:;:e0BVd=X4Z=CN1:OEh0>FaM84
U/??19S4cPBKa<d4WLC<1:36c@BSbLl3Y/W>1:K6b@BV`/@4W[Rj19nh^PBQ^;X3XkNi1:Fh^PBW^K/4
ZKVj1:Re]@BX];@4Yjn^0jB[ZPBQY:84Wj6N19^LV0BGUY44Thn;0i6;Q`B@RX@4ShR118j5OPB<PW/4
Rgmg18UoN0>6OGD4PGYd17iiM0AlNG@4NWQd17QhM@=fN7D4MGUf17=iM`AbNGP4LGYi16mjN`A^Ng`E
oooo000Doooo1720P`AdQXP4N8^>17b@T`AoUIT3PiZO18JPY0B:YJX4SJZ`196_]@BD];/3UkW119^o
a`BNa<d4X/[D1:K@fPBXe=h4YmGP0iK5dPBF`ll4V<C>19_4c@BMa<`4X<K=1:?9c`>VbLh4Y/K91:K2
a0BN^;X4WkRj1:6h^P>S]kT4YKRj1:Ni^`BY^KX4Z;Fe1:Rd]0BW[jh3Y:^Z1:6TXPBOXIh4VibH19NF
T@BCSh/3TH^7192:Q0B?R844SXEn18b2N`B;OgL4RGmh0hImM@B1NW@4OWUd17aiM0AjN7@4N7Qe0gIh
M@AeNGH4LgUg179iN0AaNWT4KgYk16ikO1Goool001Coool4L82317B6R0AhRhh4O92C17nEV@>3VYl4
QZ2T18ZUZPB=Z[04TJne19Bd^`>G^L44Vko719k4c@BRb]@4Y]3J1:SDgPBWeN03U/GB19K3c`BHa<h4
VlC=19g4c0BPa/d4XlW?0jK9cPBVa/T4Y/;419jh^PBO^;X4XKRj0j>g^@BU^;X4YkVk1:Vi^PBX]KD4
Z;Bd1:N_[P>TZjX4XJBR19nQWPBKW9P4UiJA19>?R`>ARhL4T8Z418n8P@B>QGh4S89k18]oM`B9OgP3
QWee185jM0AnNG@4O7Ud17YhM0AhN7D3MWQe17EiMPAcNGL4LWUh175jN@A_NW/4KW]l5Oooo`005?oo
o`A`P8<4M8J817R;SPAlT9<4OiFI0h>JW`B6X:@4RZFZ18fZ/0BA[kD4U;Bk0iNi`@BK_lL4W/C=1:;:
e0BVd=X4Z=CN1:OEh0>FaM84U/??19S4cPBKa<d4WLC<1:36c@BSbLl3Y/W>1:K6b@BV`/@4W[Rj19nh
^PBQ^;X3XkNi1:Fh^PBW^K/4ZKVj1:Re]@BX];@4Yjn^0jB[ZPBQY:84Wj6N19^LV0BGUY44Thn;0i6;
Q`B@RX@4ShR118j5OPB<PW/4Rgmg18UoN0>6OGD4PGYd17iiM0AlNG@4NWQd17QhM@=fN7D4MGUf17=i
M`AbNGP4LGYi16mjN`A^Ng`Eoooo000Doooo1761P`AeQXT4NHb?17fAU@B1Ui/3Q9bQ18RRY`B<Yjd4
Sjfc19>b^@BF]kl3V[g519g2b`BQb=44Y/oI1:kHh`B]f^D4X<oK0i;1cPBG`lh4V/G?19g6cPBPa/d4
X/O=1:G8cP>Ua<P4X[g019nf^@BL/[D4XKFh1:Bh^P>V^K/4Z;fn1:^m_PB/_Kd4[;Zj1:bh^0BZ/K43
Z:n^1:BYYPBPXj04W9fJ19NET@BDSh/3Thb719><QPBBRX<4THN018n3O0B=PGT4RWif0hIlL`B1N784
OgQb17ahLPAjN7<4N7Qd0gMhM@AeN7H4M7Ug179iN0AaNWT4KgYj16ikO1Goool001Coool4LH6317F6
R@AiS8l4OI6E186GV`>4W:44R::W18bW[@B?[K<4Tk:i19Jg_`>J_LD4WL;;1:78d@BVcmT4[]SS1:gJ
i@BPcm/3T/7>19O3cPBJaLl4WLK>1:36c@BRald4YLS>0jG4b0BR_L04WkJi19bb]@BQ]KP4Y;Rj0jJi
^`BX_Kh4Zkfn1:bm_@B/^[X4[;Rh1:Za/@>X[jh4Y:VV1:2SX0BLWIX4UiFA19B?R`>CS8L4Thb619::
P`BAQh04Sh=l18f1N@B:OWH3QWac185hLPAoN784O7Qb17YhL`AhN7@3MgQe17EhMPAdNGL4LWUh175j
N@A_NWX4KW]l5Oooo`005?ooo`AaPH<4MHJ917V<S`AmTID4PINK0hBLX@B8XZL4S:N]18n]/`BC/[T4
U[No0iZma@BM`//4XLSA1:K?f@B^f><4[M[U1:3?f`>B`Lh4Ul?>19[5c`BMa/h4X<K=1:;7c@BUb<h3
YLC81::m`0BO][T4W;:e1:6e^0BT^;X3Y[Vk1:Rm_PB[_Kh4[;fm1:bj^PB/^;P4Z[6a0jR_[PBTZJH4
X:>P19bMVPBGUI44U8n;0i><Q`BCS8H4TXZ31967P0B?Pg`4SH5i18YnMP>6O7<4PGQb17mhLPAlN784
NWQc17QhM0=gN7D4MGQf17AiM`AbNGP4LGYi16mjNPA^Ng`Eoooo000Doooo1761P`AeQhX4NXf@17jC
UPB2VId3QYnS18ZTZ@B>ZZl4T[2f19Fe_0BI^l83W<381:36cPBSbmD4Z=;L1:kIi0BUdMd4UL?@0iG1
cPBJa<l4WLK>1:35c@BRa/`4Y<S=1:O8c@>Wa<P4Y;k11:>j_0BS^;X4YKNi1:Ng^@>X^;X4Z[Zk1:bj
_0B]^KX4[KJg1:fc/`B[/;03ZJn]1:JZY`BRY:44WIfJ19JCT0BESh/3UHf819F=Q`BERh@4U8V119:5
O@BAPg/4TH=j0hQlM0B1Mg04OgMa17afL@AjMg84NGMc0gMgM0AeN7D4M7Qf179iN0AaNGT4KgYj16ik
O1Goool001Coool4LH6317F7RPAjSI04OY>F18:IW@>6Wj<4RZBY18jZ[`BB/;H4UKFl19Vk`P>L`<P4
X<K>1:?;e@BXd]`4[]WT1:GAg@BE`m03UL7>19[4c`BMa/h4X<G=1:;6c0BTb<d4YlS=0jO4b0BT_/44
XkZl1:>h^PBU]kT4YkNi0jRh^PBZ^[/4[;Zl1:fi^PB]][L4[K>c1:^`/0>Y[jd4YZZW1::TX@BMWIX4
UY>@19F?R`>ESHP4UHf719F;Q0BDRH44TXEm1963N`BAPgX3R7ad185gL0AoMg44O7Ia17YgLPAiMg<3
MgMd17EhM@AdN7H4LWUh175iN@A_NWX4KW]l5Oooo`005?ooo`AaPH<4MHN:17Z=T0AnTiH4PYVM0hJO
X`B:Y:T4SZZ_19:`]PBE]K`4VK_20ic0b0BPa/h4Xl_E1:SBg0B^fN@4YM7M19G3d0>E`Lh4V/C?19g6
cPBPaLd4X/K<1:C8c@BWb<d3YlC81:Bn`@BS^[`4XkRj1:Fg^@BW]kT3Z;Rj1:Zj^`B/^[`4[KVj1:ff
]`B]/k<4Zk2`0jV_[@BVZZL4XZBQ19fMVPBFTi04UHn;0iF=R0BESHL4UH^419B9P@BBQGd4TH=k1963
NP>8O7@4PGM`17mgL@AlMW44NWMb17UgL`=gMg@4MGQe17AhMPAbNGP4LGUi16mjNPA^Ng`Eoooo000D
oooo1761P`AeQhX4NXf@17jCUPB2VId3QYnS18ZTZ@B>ZZl4T[2f19Fe_0BI^l83W<381:36cPBSbmD4
Z=;L1:kIi0BUdMd4UL?@0iG1cPBJa<l4WLK>1:35c@BRa/`4Y<S=1:O8c@>Wa<P4Y;k11:>j_0BS^;X4
YKNi1:Ng^@>X^;X4Z[Zk1:bj_0B]^KX4[KJg1:fc/`B[/;03ZJn]1:JZY`BRY:44WIfJ19JCT0BESh/3
UHf819F=Q`BERh@4U8V119:5O@BAPg/4TH=j0hQlM0B1Mg04OgMa17afL@AjMg84NGMc0gMgM0AeN7D4
M7Qf179iN0AaNGT4KgYj16ikO1Goool001Coool4LH:417J8RPAkSY44OiBH18BJW`>8XJD4S:J[192]
/PBD/[T4V;Ro19^naP>O`l`4X/WB1:C>e`BVd]`4XLoL19K5d`BB`<d3VLC?19g5c`BPa/h4XlK=1:C6
c0BWal`4ZLK;0jS4b0BV_/84Ykg01:Rk_PBY^kd4Zk^m0jbl_@B^_Kh4/;fn1;6k_0Ba^KT4/;Je1:nc
/@>/[Z`4ZJNU1:>PWPBMV9D4Ui2=19F<R@>GSHP4V8j719N=Q@BFRX44U8In19>4N`BCPWP3QGM^185e
KPAnMFh4O7E_17YfL0AiMW83MgMc17EgM0AdN7H4LWQg175iN0A_NWX4KW]k5Oooo`005?ooo`AaPX@4
MXR:17^>T@AoU9P4Q9ZO0hRQY@B<YZ/4T:fb19Bb^@BH^;l4Vkk60io3c0BRbM84Y<kG1:KBg0BQcm`4
U/GC19;0c@>Ia<l4WLG?1:36cPBSa/d4Y<K<1:O7c0BYa//3Z<C81:Jn`PBW_L04Z;^n1:Vk_@B[^kd3
[;bm1:jm_PB`_Kh4/K^l1;6i^@B`][D4[k>a0jb^[0BYYjD4Xj2N19fHU@BGT8d4UHb90iN=R0BHSXL4
Uhf519J:P@BDQWh4ThAk19>2N0>5Mfh4PGE^17ieKPAlMFl4NWI`17UfLP=gMg<4MGMd17AhMPAbN7L4
LGUh16mjNPA^Ng/Eoooo000Doooo1762Q0AfR8X4NhjA17nDV0B4VYl3R:6U18bVZ`B@[K84U;:i19Rh
_`BK_/H3Wl?<1:;9dPBTc]L4Y];L1:7?g0BFaM<4T/3=0iW4c`BMaLl4X<K>1:?6c@BTa/`4YlO<1:W6
b`>Xa<P4Y[k21:Nm`0BX^kh4ZK^m1:^k_@>/_;d4[[fn1;2m_PBa^k`4/KVi1;2f]@B_/k43[:j/1:VW
Y@BSX9h4WIRE19N@S@BES8T3Uhf819R>Q`BGSHD4UXZ119B6OPBCQ7/4Th9h0hEgKPB1MFh4OWE^17ae
K`AjMW04NGIb0gMgL`AeMg@4M7Qf179hM`AaNGP4KgYj16ikNaGoool001Coool4LH:417J8RPAkSY44
OiBH18BJW`>8XJD4S:J[192]/PBD/[T4V;Ro19^naP>O`l`4X/WB1:C>e`BVd]`4XLoL19K5d`BB`<d3
VLC?19g5c`BPa/h4XlK=1:C6c0BWal`4ZLK;0jS4b0BV_/84Ykg01:Rk_PBY^kd4Zk^m0jbl_@B^_Kh4
/;fn1;6k_0Ba^KT4/;Je1:nc/@>/[Z`4ZJNU1:>PWPBMV9D4Ui2=19F<R@>GSHP4V8j719N=Q@BFRX44
U8In19>4N`BCPWP3QGM^185eKPAnMFh4O7E_17YfL0AiMW83MgMc17EgM0AdN7H4LWQg175iN0A_NWX4
KW]k5Oooo`005?ooo`AbPX@4MhV;17b?TPB1UYT4QIbP0hZSY`B?ZJh4Tjne19Nf_0BK_<<4W/790j77
c`BTc=D4Y]3K1:KCg`BSd=d4X<cG19k8d`>Oam44XLO?1:C6c@BVa/d4Z<K<1:W7c0B[al/3ZlG91:_2
a@B[`<84[;k01:fn`0B^_l03/;o01;;0`@Bd`<04]Kno1;Fl_0Bd^KP4/kFc0jn`[@B[ZJH4YZ:O1:6K
V0BMUI44VHn;0iV>R0BJShL4VXj519R;PPBFQgh4UXEk19F3N0>4MF`4P7=[17icK@AlM6h4NWA_17Ue
L0=gMW84MGIc17AgM@AbN7H4LGUh16mjNPA^NW/Eoooo000Doooo17:2Q0AgRH/4O8nB186FV@B5W:03
RZ>W18nY[PBC[kD4UkJl19^l``BN`LT3XLO?1:C<e@BVd=/4Y]?O1:?@g@BPc=L4W/SC0io7d@BQall4
Y<K=1:K6c@BXa/`4ZLO<1:_7b`>[aLT4Zl;51:_0`PB/_/04[Kk01:jo`0>`_l04//311;C0`0Be_kl4
]Kbl1;Bi^0Bc]K<3[k2]1:^YYPBVXYl4XI^H19fET@BISh/3VHj819Z?Q`BJSXD4V8^219J7OPBFQG/4
UH=h0hAeK0B0Lf/4OW=]17adKPAjM6l4NGE`0gMfLPAeMW<4M7Me179hMPAaNGP4KgYj16ijNaGoool0
01Coool4LX:417N9R`AlSi84PIJI18FLX0>:XjL4SjV^19>_]@BG][`4Vkc319k1b@>Qall4Y<cE1:K@
f`BVdml4Xm3M1:3<e`BNb=<3WlOA1:77c`BTa/d4Y/K=1:S6c0BYal`4ZlO;0j_5b@B[`/D4Zl321:bn
`0B]_/04[[o00k2o`0Bb`<44]<301;Fo_`Be_;`4];Vh1;>e/`>_/:d4ZjVV1:JRW`BQViP4WIFA19V?
R`>ISXP4VXn719Z>Q@BHRh84UXMn19J5N`BEPgP3Q7E/181cJ`AnLfd4O7A^17YdK`AiMG03MgIb17Ef
L`AdMgD4LWQf175iN0A_NWX4KWYk5Oooo`005?ooo`AbPX@4MhV;17b?TPB1UYT4QIbP0hZSY`B?ZJh4
Tjne19Nf_0BK_<<4W/790j77c`BTc=D4Y]3K1:KCg`BSd=d4X<cG19k8d`>Oam44XLO?1:C6c@BVa/d4
Z<K<1:W7c0B[al/3ZlG91:_2a@B[`<84[;k01:fn`0B^_l03/;o01;;0`@Bd`<04]Kno1;Fl_0Bd^KP4
/kFc0jn`[@B[ZJH4YZ:O1:6KV0BMUI44VHn;0iV>R0BJShL4VXj519R;PPBFQgh4UXEk19F3N0>4MF`4
P7=[17icK@AlM6h4NWA_17UeL0=gMW84MGIc17AgM@AbN7H4LGUh16mjNPA^NW/Eoooo000Doooo17:2
Q0AgRH`4OI2C18:GV`B7WZ83S:FZ196//@BF/[P4V[Vo19joaPBRaLd3YL_C1:O@fPBYe=l4ZMKR1:SE
h0BWd]`4Y/kG0jC:d`BUbM04YlS>1:W8cPB[b<d4[<W=1:g9c@>^alX4[/G71:k1a0B_`L84/<721;;3
``>d`/<4]/?31;S3``Bh`/04^Knm1;Nk^0Bd]k<3/;2]1:bZYPBWXYh4XibH1:2GTPBLTX`3W96:19fA
R@BLShH4VX^219R7OPBFQGX4UhAh0hAeK0B0Lf/4OW9[17acK0AjLfh4N7A_0gMeL@AfMW84M7Md17=h
MPAaN7P4L7Ui16ijNaGoool001Coool4LX:417N9S0AmT9<4PYNK18NNXP><YJX4TJba19Jb^0BJ^Kl4
W[o61:;5c@>Ubm<4Ym3J1:WDg`BYe^84Z=GP1:OBg0BVc]L3Y<[C1:G9d0BWb<h4ZLS>1:_8c@B/bLd4
[LW=0jk7bPB^aLL4[/741:o1`PB``L84//?30kC2``Bf`l<4^<?31;S2`0Bi_kd4]k^h1;Bg/`>`/:d4
[:ZV1:NRWPBSW9P4X9NB19bBS0>LTHX4WI6919b?QPBJRh84V8Mn19J5NPBGQ7P3Q7E/181cJ`AnLV/4
O7=/17YcKPAhM6l3MgEa17IfLPAdMg@4LgQf175hN0A`NGT4KWYk5Oooo`005?ooo`AbPX@4MhV<17f@
T`B2Ui/4QijR0hbUZPBA[;44U[:h19Zi_`BN_lH4X/G=0jG;d`BWd=X4ZMCO1:WFhPBXeN04Ym;L1:K>
e`>Tb]<4YLW@1:O8cPBYb<h4ZlS=1:c9c@B]bLd3[/O:1:k5a`B^`L@4[l721;31`PBb`l<3]<;31;K3
``Bh`l<4^<;01;Vo_@Bg^kP4];Nc0k2`[@B/ZZH4Yj:N1:>LV0BPUi84W9:<0ibARPBMTHT4W8n619Z;
PPBHQgh4UXEj19N4N0>4MF`4P7=[17ibJ`AlLf`4NW=^17QdK`=gMG44MWIb17AgM0AcN7H4LGQh171i
N@A^NW/Eoooo000Doooo17:2Q0AgRH`4OI2C18:GV`B7WZ83S:FZ196//@BF/[P4V[Vo19joaPBRaLd3
YL_C1:O@fPBYe=l4ZMKR1:SEh0BWd]`4Y/kG0jC:d`BUbM04YlS>1:W8cPB[b<d4[<W=1:g9c@>^alX4
[/G71:k1a0B_`L84/<721;;3``>d`/<4]/?31;S3``Bh`/04^Knm1;Nk^0Bd]k<3/;2]1:bZYPBWXYh4
XibH1:2GTPBLTX`3W96:19fAR@BLShH4VX^219R7OPBFQGX4UhAh0hAeK0B0Lf/4OW9[17acK0AjLfh4
N7A_0gMeL@AfMW84M7Md17=hMPAaN7P4L7Ui16ijNaGoool001Coool4LX>517R:S@AnTYD4Q9VL18VP
Y0>>Yj`4U:nd19Vf^`BM_<<4X/?:1:G9d@>YcmP4ZmGN1:gIi0B]f^D4[]WS1:cDg@BYcmL3YlcD1:W:
d@B[b]04[L[?1:k:c`B`bll4/L[>0k;8c0BbalX4//G61;?3``Bd`l@4]/C40kO4a0BiaL@4^lK41;_3
`@Bk`;h4^K^h1;Nh]0>c/Jd4[ZZU1:ZSWPBUWYL4XYRA1:2DS@>PTh`4X9:919j?QPBKRh84V8Mn19J4
NPBEPgP3QWM^17maJ@AmLFT4Ng5Z17YbK0AhLfh3MgA`17IeLPAdMW<4LgMe175hM`A`NGT4KWYk5Ooo
o`005?ooo`AbPhD4N8Z=17jBU@B4VI`4RJ2T0hjW[0BD[k@4VKJk19fl``BR`lX4YLWA0jW?f0B[eMh4
[MWT1:gJi@B^fN<4[=CM1:W?e`>Wc=@4ZL[A1:_:d0B]b/l4[/[?1;3;c`Bab/h3//S<1;;7bPBbaLH4
/l?31;C3a0Bfa<@3]lC41;W5a0Bka/@4^l?11;_0_PBi^kP4]kRd0k>a[@B^ZZD4ZZ>N1:FNU`BRV944
X9B=0j2CS0BPTXT4WXn619^;PPBHQgh4UXAj19F3N0>6Mfh4Og5Y17eaJ@AkLFX4NW9/17QcKP=gM704
MWEb17AfL`AcMgD4LGQg171iN@A^NW/Eoooo000Doooo17:3Q@AhRXd4OY:E18BIW0B9X:@3SZN/19B_
]0BI][/4WKc31:;3bPBUbM43ZLoH1:_EgPB]fN@4[M[U1:kIh`B/e=d4ZLoG0jO<e0BYb]44Zl[@1:g:
c`B^b/l4/<_?1;7:cP>bb<`4//O:1;;5aPBc`l<4]<?41;K4a0>ga<@4^LG41;_6a0Bk`l44^l2n1;Vk
^0Bg^;@3/k6]1:jZY@BZXih4YIjG1::HT@BPU8d3X9><1:2BR@BNShH4Vh^219R7OPBFQ7X4UH=h0hIg
KPAoLFT4OG5Y17]aJPAjLV`4N7=^0gMdL0AfMG84M7Ic17=gM@AaN7L4L7Ui16ijNaGoool001Coool4
LX>517R:S@AnTYD4Q9VL18VPY0>>Yj`4U:nd19Vf^`BM_<<4X/?:1:G9d@>YcmP4ZmGN1:gIi0B]f^D4
[]WS1:cDg@BYcmL3YlcD1:W:d@B[b]04[L[?1:k:c`B`bll4/L[>0k;8c0BbalX4//G61;?3``Bd`l@4
]/C40kO4a0BiaL@4^lK41;_3`@Bk`;h4^K^h1;Nh]0>c/Jd4[ZZU1:ZSWPBUWYL4XYRA1:2DS@>PTh`4
X9:919j?QPBKRh84V8Mn19J4NPBEPgP3QWM^17maJ@AmLFT4Ng5Z17YbK0AhLfh3MgA`17IeLPAdMW<4
LgMe175hM`A`NGT4KWYk5Oooo`005?ooo`AcPhD4NH^=17nCUPB5Vih4Rj:V0i6Z[PBG/KH4W;Vn1:70
aPBValh4Z/kE0jgDg@B`f^<4/]kY1;?Nj0Bcg>D4[mCL1:c?e`>/cM@4[L_B1:o<d@B`c=44//gA1;?=
d@BdcM03]L_>1;K:c0BfalP4]/C51;O5a@Bia/H3^lO61;c7aPBnb<H4_lO41;o3_`Bm_[X4^KRd0kFa
[@BaZjD4[:BN1:RNU`BVVY84YIR@0jBFS@BRThX4X92719f<PPBIR7h4U8=h18inM0>2MF`4OW1W17]^
IPAjKfP4NG5Z17QbK0=gLfl4MWAa17AfL`AcMgD4LGQg171iN@A^NW/Eoooo000Doooo17>3Q@AiRhd4
Oi>F18FKWPB;XZH3TJZ^19Na]PBL^Kh4XL361:K7cPBZc]D3[MCM1;3Jh`Bbg^T4/mkX1;?Li@B_e=`4
[<oG0jc=e0B]bm84[lcA1;3<d@BbcM44/lgA1;C=d0>eblh4]/[<1;K7b0Bfa<D4]lG51;W6aP>kalH4
_<O61;k8aPBoal@4_l>o1;fn^PBi^;@3]K6]1;6[Y@B/Y9h4Z9jG1:JJTPBUV903Y9J=1::CRPBPT8L4
WHb219V8OPBDPgP4SWid0h9eK0AnL6L4NfiV17Y_J0AiLFX4N79/0gMcK`AfM744M7Ic17=gM@AaN7L4
L7Ui16ijNaGoool001Coool4Lh>517V;S@AoTiH4QI^N18^RYP>AZZh4Uk6f19bi_PBQ`<H4Y/O>1:[>
e@>]e=d4/=[S1;;Nj@Bcg^P4/mcU1:oDg0B/cmL3[<gD1:g;dPB_c=44/<cA1;;=d@BccM44]<g@0kG;
cPBfb/`4]/O81;K4a@BgaLD4^LK60k_7aPBlalH4_/S61;o7a0Bo`kl4_Kjj1;Vh]0>e/Jd4/J^U1:bT
WPBXWYL4YYZB1:FHT0>TUXd4XY>:1:2@Q`BMS884VHQn19B3N0B>OW@3PWE/17i`I`AkKVH4NVmX17Ua
JPAhLV`3Mg=_17IdL@AdMW<4LgMe175hM`A`NGT4KWYk5Oooo`005?ooo`AcQ8H4NXb>186DU`B7W:04
SJBX0iB]/@BJ];T4X;c21:G4bPBZbm84[m?J0k;JhPBfhNX4^>G^1;WTk0Bgg>@4/]?J1;3@e`>`c]@4
/LkC1;?>d`Bdcm<4]]3D1;O@d`Bhd=83^LkA1;[<cPBib<T4^LK61;[7aPBlbLP3_/W71<3;b0C2blT4
`lW61<;5`@C0`;/4_;Ze0kVd[PBd[JH4[jFN1:bPV@BZWID4ZYbC0jRIT0BUUhd4XY>819n>Q0BJRGh4
U8=h18imL`>4LfT4NFQN17EVG@AiKFD4NG1X17UaJ`=gLfd4MWA`17AeLPAcMW@4LGQf171iN@A^NW/E
oooo000Doooo17>4QPAjS8h4PIBG18NLX0B=Y:P3U:fa19Zd^@BP_<84YLC:1:[;dPB_dmX3/][R1;KQ
jPBhiNh4^NC/1;OLi0BbdmX4/=3G0k3>e0Bac]<4/lkC1;C?d`Bfd=@4]m3C1;S@dP>ic]44^/c>1;W8
b@Bia/H4^/O61;c9b0>nbLL4`<_81<;;b@C3bLH4`/G11<30^`Bl^[D3^KB^1;B]YPB_YIh4[:2I1:ZM
U@BZW9<3Z9V@1:FGS@BRThP4Whj419Z9OPBDPgP4SWec0hAcJ@AiJ5h4MFIM17U]I@AiL6P4NG5[0gMc
K@AfM704M7Eb17=fM0AaN7H4L7Ui16ijNaGoool001Coool4LhB617Z<SPB1U9L4QibP18fTZ0>D[K44
V[Bi1:2l`PBUa<X4Z/_B1:oCfP>bf^84]^7Z1;SUkPBii>`4]mcT1;;CfPB`d=L3/<kD1;7>d`Bcc]<4
]<oC1;K@e0Bgd=<4^=3B0kW>d@Bjc<h4^LS91;W6aPBjalH4_<W80kk9a`C0blP4`/_91<?9aPC2aL44
`<2k1;bj]@>i]:h4]:fV1:nUWPB/X9T4ZYfE1:ZLT`>XVI04YIN=1::CR0BOSX@4VXUn19B3N0B>OG<3
Q7=Y17UXGPAeIUd4NFeU17U`J0AiLF/3Mg=]17IdL0AdMG84LgId175hMPA`NGT4KWYk5Oooo`005?oo
o`AcQ8H4NXb>186DU`B7W:04SJBX0iB]/@BJ];T4X;c21:G4bPBZbm84[m?J0k;JhPBfhNX4^>G^1;WT
k0Bgg>@4/]?J1;3@e`>`c]@4/LkC1;?>d`Bdcm<4]]3D1;O@d`Bhd=83^LkA1;[<cPBib<T4^LK61;[7
aPBlbLP3_/W71<3;b0C2blT4`lW61<;5`@C0`;/4_;Ze0kVd[PBd[JH4[jFN1:bPV@BZWID4ZYbC0jRI
T0BUUhd4XY>819n>Q0BJRGh4U8=h18imL`>4LfT4NFQN17EVG@AiKFD4NG1X17UaJ`=gLfd4MWA`17Ae
LPAcMW@4LGQf171iN@A^NW/Eoooo000Doooo17B4QPAkSHl4PYFH18VNX@B@YjX3Ujnc19fh_0BS`<D4
ZLS>1:o@ePBdf=l3^=oW1;cVkPBnio04_N?Z1;WIh0Bdd]T4/]3F0k??e@Bed=@4]]3E1;SBePBjdmH4
^m?F1;cCe@>md]<4_Lo?1;g<b`Blb/P4_/W71;o:b0?1b/P4`lc91<K<b@C6b/H4aLK11<?1^`Bo^kD3
^kB]1;F/Y@BbYil4/:>K1:nQV0B^WiH3[9bB1:VISPBUUHX4XI2419b:O`BGQ7P4T7md0hQfJ`AoK644
O6aR17]]I@AjKfP4NG5Z0gQbK0AfLfl4M7Ea17=fL`AaMgH4L7Uh16ijNaGoool001Coool4M8B617^=
S`B2UIP4RIjQ192WZP>G[k<4WKRl1:?0a@BYb<h4[m3F1;CHg`>hgnL4_>K^1;kWl0BmhnX4^MWP1;CB
f@Bbd=H3/loE1;G@e0Bfd=D4^=;F1;[CePBkdmH4_=?E0kgBd`Bmcll4_Lc;1;c:b0BnbLL4_l[80l7:
b0C3c<T4a/c91<K:aPC5a/44`l6k1;nk]@>k]:d4]JbU1;:WW`B`Xi/4[j6H1:jOUP>/W984ZIV>1:FE
RPBQT8@4W8Yo19N4N0B@Og@3R7I[17m/H@AlK684NfeU17Y_J0AiLFX3N79/17IcK`AdMG44LgIc175g
MPA`NGP4KWYk5Oooo`005?ooo`AdQ8H4Nhf?18:EV0B9WZ44T:NZ0iN_/`BM^;`4Xl351:W8cPB_d=H4
]=SO0kSOi`Bli^h4_^O`1;gSjPBifN04]=;I1;;@eP>ccmD4]M3D1;K@e@Bhd]H4^]?F1;_CePBldmD3
_M;C1;g?c`Bmc</4_<[81;k9a`Bob/P3`L[81<?<b@C6c<T4a/[61<G6`@C3`K/4_k^e0k^d[@Be[:D4
/ZNO1;2SV`B_XIP4[YnF0jbLTPBYVHh4YIF:1:6@Q0BLRWl4UhAh191oM0>8MV/4OfaQ17a/HPAkKFD4
NVmX17UaJP=hLV`4MW=_17AeL@AcMW<4LGMf171iN0A^NW/Eoooo000Doooo17B4QPAkSHl4PYFH18VN
X@B@YjX3Ujnc19fh_0BS`<D4ZLS>1:o@ePBdf=l3^=oW1;cVkPBnio04_N?Z1;WIh0Bdd]T4/]3F0k??
e@Bed=@4]]3E1;SBePBjdmH4^m?F1;cCe@>md]<4_Lo?1;g<b`Blb/P4_/W71;o:b0?1b/P4`lc91<K<
b@C6b/H4aLK11<?1^`Bo^kD3^kB]1;F/Y@BbYil4/:>K1:nQV0B^WiH3[9bB1:VISPBUUHX4XI2419b:
O`BGQ7P4T7md0hQfJ`AoK644O6aR17]]I@AjKfP4NG5Z0gQbK0AfLfl4M7Ea17=fL`AaMgH4L7Uh16ij
NaGoool001Coool4M8B617b>T0B3UiT4Rj2S19>Y[0>J/[H4XK^o1:S4b0B^c=84]=GK1;[Mi0?0i^h4
`n[c1<GYl@C2h^T4_=SO1;KBf0BfdMH3]m7F1;SBePBjdmL4_=GH1;kFf@C0emP4`MOG0l7Ee@C1d]44
`<k=1<3<bPC1c<T4`/c90lC<b@C6c/X4bLk:1<W<a`C8al44aL6k1<6k]0>m]:d4^JnW1;N[XPBeYih4
]:FL1;>SV0>`Wi@4[Ib@1:VGR`BUTHH4X8^019Z5NPBCPGD3S7Q/18IaI@B1KfD4OViU17a_I`AjL6T3
N75/17IcKPAeM704LgEc175gM@A`N7P4KWYj5Oooo`005?ooo`AdQ8H4O8j@18>GV@B;X:<4TjV/0iZb
]PBQ^kl4Z<C81:k<dPBdeM/4^]gT0l3VkPC3j_<4aNWa1<;Rj@Blf=l4]];H1;KAeP>gdMH4^=;F1;[C
e`BleMP4_]KI1<3Gf0C1emL3`MGE1<7Bd@C0c/d4`<c:1<7<b@C2c<T3a<c91<K>bPC9c/X4bLc71<S7
`@C5`K/4`K^d0kfd[@Bi[jL4]j^R1;FWWPBdYI`4/j>H0k2OU0B]W904ZIN;1:FAQPBPRh04VXEj19>1
M@><N6`4QW5U185_I@AnKVD4O6mW17Y`J@=hLF`4MW=^17EdL0AcMG<4LGMe171hN0A^NWXEoooo000D
oooo17B4QPAlSY04PiNI18^PX`BCZJ`3V[:f1:6k_`BXa<P4[/cB1;CEf`BjgN@3`>K^1<?Zl`C5jO44
`^;Y1;cHg`Bfd]P4]]7F0kOAePBhd]H4^]?G1;cEf0Bne]T4`=OH1<7Ge`?1eMD4`M;A1<3>c@C0c<X4
`Lc91<;<b@?4c<T4a/k:1<W>bPC9c<L4b<O11<G1^`C1^k@3_KB]1;V_Y`BgZj84]JNN1;BUW0BcXiP3
/9nD1:fLT0BYUh/4YI661:2;P0BJQGX4Th5e0hahK0B6LFD4PFmU17i^I@AlKfL4NW1Y0gQaK0AfLfh4
MGA`17=eL`AaMgD4L7Qh16ijNQGoool001Coool4M8B617b>T0B3UiT4Rj2S19>Y[0>J/[H4XK^o1:S4
b0B^c=84]=GK1;[Mi0?0i^h4`n[c1<GYl@C2h^T4_=SO1;KBf0BfdMH3]m7F1;SBePBjdmL4_=GH1;kF
f@C0emP4`MOG0l7Ee@C1d]44`<k=1<3<bPC1c<T4`/c90lC<b@C6c/X4bLk:1<W<a`C8al44aL6k1<6k
]0>m]:d4^JnW1;N[XPBeYih4]:FL1;>SV0>`Wi@4[Ib@1:VGR`BUTHH4X8^019Z5NPBCPGD3S7Q/18Ia
I@B1KfD4OViU17a_I`AjL6T3N75/17IcKPAeM704LgEc175gM@A`N7P4KWYj5Oooo`005?ooo`AeQHL4
OHjA18FHV`B=XZD4UJ^^0ife^0BU_/84[<S<1;?AePBjf]l4`N?Y0lS]m0C=lOL4cnkc1<STj@Bnf=d4
^M;H1;SBeP>id]L4^mCH1;gEf@C0emX4`]SJ1<CIfPC6fMT3aMKF1<CCdPC3d<h4`lk;1<?=bPC4cLT3
a/g:1<W?b`C;clX4c<c71<[8`PC8`[`4a;be0l6g[`Bn/ZT4_:nU1;^/XPBiZIh4]jFJ0kFRUPBaWI44
[IR<1:VCQ`BSSX44WHQl19R5N@>ANfl4RGEZ189_I0AoKV@4OFmV17Y`J0=hLF/4MW9]17EcL0AcMG84
LGIe171hN0A^NWXEoooo000Doooo17F5Q`AmSY44QIRK18fRY@BEZjh3WKFh1:Fn`PB/b<`4/m7F1;[J
g`C1hnT3b>gd1<gam`C?k_<4b>CY1;kHg@Bid]P4^=;F0kWBe`Bke=P4_MGI1<3GfPC2f=X4a=WJ1<KI
f@?5e]H4a=?B1<?@cPC3c//4`lg:1<C=b@?6cLX4bLo;1<_?bPC<c<L4b/S21<S2_0C4_;D3`KN_1;jb
Z@Bl[jD4^jbR1;VYWPBgYIX3]J:F1;6MT@B]V8`4ZI>71:>>P@BMR7`4V8Ei0i5kK`B9MFX4PVmT17m^
I0AmKfH4NW1X0gQaJ`AfLVd4MG=`17=eLPAaMWD4L7Qh16ijNQGoool001Coool4MHF717f>T@B5V9/4
SJ:U19F[[P>M]KP4YKk21:c8c0BcdMH4^][O1<7Sj@?8kO@4cO7g1<o^l`C8i>T4_]SM1;WBf0Bhd]H3
^M;G1;_Df0BmeMT4`=OJ1<;HfPC4fMX4a]WI0lGFePC4dm84`m3>1<?>b`C3cLX4a<g90lK=bPC9cl/4
blo:1<c<a`C:b<84b<:l1<Bl]@?1]jl4_[:Y1;b_Y@Bk[:84^JVN1;NUVP>eXYH4/IfA1:fHS0BYThL4
Xhj119f8O0BHQGT3TG]_18UeJPB2Kf@4OfiT17e_IPAjL6P3N75[17IbK@AeLg04LgEb175fM@A`N7P4
KWYj5Oooo`005?ooo`AeQHL4OHjA18FHV`B=XZD4UJ^^0ife^0BU_/84[<S<1;?AePBjf]l4`N?Y0lS]
m0C=lOL4cnkc1<STj@Bnf=d4^M;H1;SBeP>id]L4^mCH1;gEf@C0emX4`]SJ1<CIfPC6fMT3aMKF1<CC
dPC3d<h4`lk;1<?=bPC4cLT3a/g:1<W?b`C;clX4c<c71<[8`PC8`[`4a;be0l6g[`Bn/ZT4_:nU1;^/
XPBiZIh4]jFJ0kFRUPBaWI44[IR<1:VCQ`BSSX44WHQl19R5N@>ANfl4RGEZ189_I0AoKV@4OFmV17Y`
J0=hLF/4MW9]17EcL0AcMG84LGIe171hN0A^NWXEoooo000Doooo17F5Q`AnSi84QiZL18nTYPBH[[43
XKRk1:W2a@Bac=04^MKJ1<3Oi0C8j>h3co;h1=Kdn0CCkO44b^?W1;kFf`Rjd]H3^m?G1;gDf0C0e]T4
`mWJ1<KJf`C8fmX4b]_J0lWIf0C8e]@4a];@1<G?c0C5cLX4a/g90lS>bPC;d</4c]3;1<o>a`C=bL<4
blBm1<Ro]P?6^[44a;J/1<:cZ0C0/:@4_jbQ1;bYW@>iY9P4]J2C1;6KSPB/UXT4Yi231::;OPBMQg/3
UGia18agJPB4KF04PFeS17i^I@AkKfL3NG1Y17MaK0AeLfl4LgAb175fM0A`N7L4KWUj5Oooo`005?oo
o`AeQHL4OXnB18NJW0B?Y:H4V:ja0j6h^`BY`/D4/Lc@1;WFfPC0gn@4b>S^0lobn0CFm?P4dnga1<[S
i`Bne]/8^];F0k_Ce`Bme=P4`=KI1<?IfPC6f]/4b=_J1<[KfP?9fMP4b=KD1<KBd0C5cl`4aLg:1<K=
b@?8c/X4bm3;1<k@b`C?c/L4cLW31<_4_@C8_kH3a[Za1<Bf[0C2/jP4`;2T1;n/X@BlZId3^JBH1;FP
T`BaVhh4[9J91:N@P`BRRgh4WHMk0iEnL@B<MfX4Q6eP185]H`AnKVD4NfmW0gU`J@AgLF`4MG=_17=d
LPAaMW@4L7Qg16iiNQGoool001Coool4MHF717j?TPB7VY`4SjBV19R^/@>Q^;/4ZL;51;7<d0Bie]X4
`=oT1<SXkP??l_P4e_Ch1=?]l@C:hnL4_]KK2;[BeP>kdmL4_MCH1<3Ff@C3fMX4a][K1<SKfPC:fmX3
bMWH1<SFe0C6d]04aLo<1<G=bPC6cLT3b<k:1<_@b`C>d</4clk71<g9``C;a;d4b;nf0lJj/@C4]Z`4
`[>X1<2`Y0Bo[:44_:VM0kVTV0BeX9<4/I^>1:bFR@BWT8<4XX]n19f7N`>EOW44S7MZ18A]H0B1KF<4
OViU17]_I`=iL6T4Mg5/17EcK`AcM784LGId171hM`A^NGXEoooo000Doooo17J6R0AoT984R9^M19:U
Z0BK/;<3Y;^n1:k6b@Bgd=@4_m[N1<OTj0C>kO83eOCi1=ScmPCBj^d4bN3S1;[Be`Bid=D4^]7E0k_B
e@Bne=L4`mSI1<OKg0C<g]h4cmoN1=3Og@?>fmT4b]KD1<SCd0C6cl`4aLc81<O<b0?9cLP4cLo:1=3@
bPCAc/P4d<[41<o6_@C<`KP3bkfc1<Zj[`C8]Z/4aK:W1<>_X`BoZYh3_:JI1;RQU0BdWHl4/9R:1:^C
Q0BVSH04XXYl0iV2L`B>MVT4QF]N185/H0AnKF<4NfiV0gU_J0AfLF/4M79^17=dL@AaMW@4KgMg16ii
NQGoool001Coool4MXJ817n@TPB8Vid4TZFX19^`/`>T^kh4[/K91;O@e0Bof]h4anCX1<k]lP?Em?T4
f??f1=;Zk@C9h><4^];G1;W@e@BjdMD3^m;E1;kDe`C3f=T4am_L1<cNgPC?gmh4d=oM0lkKf@C:e]@4
b=?@1<K?c0C5c<P4alc80lW=b0C=clX4d=3:1=7>b0C@b/@4clJm1<c1^0?;_K<4b[Z_1<RfZ`C5/ZL4
`jnS1;nZWP>lYYT4^:6D1;BMS`B`V8X4Zi>41:J=P0BRRW`3VH9c18ifJ@B5Jeh4PFaP17i]H`AkKVH3
NFmX17IaJ`AdLVh4LgAa175fM0A_MgL4KWUj5Oooo`005?ooo`AfQXP4Oi2B18RKW@BBYJP4Vk2c0jBk
_PB^a/T4]m3D1;oJgPC7i>P4c^gb0mGdn@CHloH4d^[]1<WPh`Bjd]L4^M3E1;[Ae@>kd]D4_]CG1<?H
f@C7fm`4c=kN1<oOgPC@gmd3c]_I1<[Fe0C8dm04a/o<1<G<b0C7c<P3bLg81<g?bPC@d<X4dLk81=3:
a0C?a[d4c<6h0l^m/`C:^Zl4b;J[1<FbY`C3[j<4_jZN0kbVV@BhXI@4]9f?1;2HRPB[Th@4YXf01:::
O0>IPW<4SWIY18E[GPB1K604OVeS17]^IP=iKfP4MW5[17AbKPAcM744LGId16mgM`A^NGXEoooo000D
oooo17J6R0AoT984R9^M19:UZ0BK/;<3Y;^n1:k6b@Bgd=@4_m[N1<OTj0C>kO83eOCi1=ScmPCBj^d4
bN3S1;[Be`Bid=D4^]7E0k_Be@Bne=L4`mSI1<OKg0C<g]h4cmoN1=3Og@?>fmT4b]KD1<SCd0C6cl`4
aLc81<O<b0?9cLP4cLo:1=3@bPCAc/P4d<[41<o6_@C<`KP3bkfc1<Zj[`C8]Z/4aK:W1<>_X`BoZYh3
_:JI1;RQU0BdWHl4/9R:1:^CQ0BVSH04XXYl0iV2L`B>MVT4QF]N185/H0AnKF<4NfiV0gU_J0AfLF/4
M79^17=dL@AaMW@4KgMg16iiNQGoool001Coool4MXJ8182AT`B:W9h4U:NY19jc]@>X_/04//[<1;cE
f0C6h><4c^[]1=Gcm`?JmoX4h?Oh1=S/k@C8gN04]lkD1;O=dPBicm<3^m3C1;kCe@C2e]L4amWI1<cK
fPC@gMX4dMgJ0lkIe`C:e=84b=7>1<K>bPC4bLD4a/W50l[<aPC>c/T4dM3:1=??b0CCbl<4dlRn1=33
^@??_k@4c[fa1<bj[@C:]ZT4b;:U1<>/W`>oZ9X4^j>E1;ROT0BdVX/4[iB51:Z?P@BURg`3VH1a18ec
I@B5JE/4PFYN17i[H@AkKF@3N6iW17I`JPAdLFd4LW=`175eL`A_MgH4KWUj5Oooo`005?ooo`AfQXP4
P96C18ZLWPBDYjT4W[>e0jRn`0Bbb/`4_=GH1<KPh`C>j^d4eO?g0m[gnPCPmoP4f>c]1<SMh0Bgc]@4
]lgB1;W?d`>kd=<4_]?E1<;Fe`C7fMT4c=_J1=3MfPCAgMX3c]WG1<[DdPC8dLh4a/k:1<C9a@C6bLD3
b/c61<k>b@CAd<X4dlo81=?;``CCb;h4d<>i0lno]0C>_K44c;Z]1<ZfZ@C8/ZD4`jbO0knXVPBkXiD4
^9n@1;BJR`B_U8D4ZXn11:F;O0>IP744SG=U18EYF`B1JUh4OV]Q17]]I0=hKVL4MW1Z17AaK@AbLg04
LGEc16mgMPA^NGXEoooo000Doooo17J6R0B0TI<4RYbN19BWZ@BN/kD3Z;k01;;:c0BleMP4a^3S1<kZ
k@CEloL3f_Oj1>3gn0CHk>d4b=gP1;O>e0BgcM84^LoC0k_@d`BndmD4`]KG1<OIf@C<fmX4d=gJ1=7M
fP?>fML4b]CB1<SAcPC6c/X4a<W51<K9a@?:c<H4c/k91=7@bPCCclP4dl_31=?8_PC@`kT3cknd1<jm
/@C<^Zd4b[JY1<RbY@C3[9l3_jRJ1;^SU@BhWi04]9Z;1:nDQ@BZSh44YH]l0iV0L@B=LfD4QFUK185Z
GPAnJf44NfeT0gQ^I`AfL6X4M75]179cL0AaMG<4KgMf16iiNQGoool001Coool4MXJ8182AT`B:W9h4
U:NY19jc]@>X_/04//[<1;cEf0C6h><4c^[]1=Gcm`?JmoX4h?Oh1=S/k@C8gN04]lkD1;O=dPBicm<3
^m3C1;kCe@C2e]L4amWI1<cKfPC@gMX4dMgJ0lkIe`C:e=84b=7>1<K>bPC4bLD4a/W50l[<aPC>c/T4
dM3:1=??b0CCbl<4dlRn1=33^@??_k@4c[fa1<bj[@C:]ZT4b;:U1<>/W`>oZ9X4^j>E1;ROT0BdVX/4
[iB51:Z?P@BURg`3VH1a18ecI@B5JE/4PFYN17i[H@AkKF@3N6iW17I`JPAdLFd4LW=`175eL`A_MgH4
KWUj5Oooo`005?ooo`AgQhP4PI:D18^MW`BFZJ/4XKFg0jc1``BgcLl4`m[L1<kVj@CFlO<4g?Oj0moh
n@CPm?D4dnKX1<?Hg0Bcb/l4]L[?1;O<d0>jc]04_M3B1<7BdPC4eM@4aMCC1<WFe0C8eM<3a=3?1<;;
b@C0b<H4_/?01;o1_@C4aL03b/W31<k=a`CBd<T4eLo71=K=``CGc<44e<Fj0mG3]`CF`[D4e;na1<ni
Z`C;/jD4aJjP0l6YV`BnYIH4^Z2A1;JKR`BbUXH4[i:21:V=O0>LOg04SG5R18AVF0B1JE`4OVYP17][
H`=hKFH4MVmY17A`K0AbLVl4L7Ab16mgMPA^NGTEoooo000Doooo17N7R0B1TY@4RifO19JYZ`BQ]KL3
[<731;O=c`C3f]`4c^KY1=Kal`CLmoX3goSi1>3dm@CCi^P4`mSL1;?:c`Beb/l4]lc@0k[>d0Bmd=84
`M;B1<CEe0C5e=<4bMKD1<SEd`?4d<l4`/_91<38aPBn`l04_l6m1<C5`0?:bL<4c/g71=;@b@CEclL4
e/g31=O<`@CDaKX3eL>g1=K2]@CD_k44ckV[1<^cY@C5[Z03`JVK1;jUUPBjX944]Y^;1;:FQPB_TX84
ZHel0iaoL0B=LF84Q6IH185YG0AnJV04Nf]S0gQ]IPAfKfT4M71/179bK`A`M784KgMf16iiNAGoool0
01Coool4MhN8186BU0B;WIl4UZV[1:6e]`>/`L<4]lg?1<?Jg0C>i^T4e_7c1=cgnP?On?T4h?Ce1=?V
j0C3f=`4/l[?1;G:c`Bgc=03^/k@1;g@dPC1d]84a=GD1<GDd`C9e]@4b=GC0lC@c`C2blT4`<S61;k3
`0Bo`Kd4a<G00l[9``C>cLL4d]391=G?a`CFcL<4elc11=C5^P?E`kL4e/:e1=Bo/@C?^J/4bk>U1<F^
X0?1ZI/4_ZFF1;ZPT@BfVh/4/YJ61:nBPPBYSG`3W7m`18eaHPB4IUP4PFUL17iZH0AkJf<3N6eV17I_
J@AdL6`4LW9_171dLPA_MgH4KWUi5Oooo`005?ooo`AgQhP4PI:D18^MW`BFZJ/4XKFg0jc1``BgcLl4
`m[L1<kVj@CFlO<4g?Oj0mohn@CPm?D4dnKX1<?Hg0Bcb/l4]L[?1;O<d0>jc]04_M3B1<7BdPC4eM@4
aMCC1<WFe0C8eM<3a=3?1<;;b@C0b<H4_/?01;o1_@C4aL03b/W31<k=a`CBd<T4eLo71=K=``CGc<44
e<Fj0mG3]`CF`[D4e;na1<niZ`C;/jD4aJjP0l6YV`BnYIH4^Z2A1;JKR`BbUXH4[i:21:V=O0>LOg04
SG5R18AVF0B1JE`4OVYP17][H`=hKFH4MVmY17A`K0AbLVl4L7Ab16mgMPA^NGTEoooo000Doooo17N7
R@B2TY@4SIjP19RZ[0BS]kP3[lC51;cAd`C9h>44enk_1>Gno`CToOh3hoOh1>3al@CCi>D4`MGH1;36
c0Bbb<`4]L[=0kW<cPBlc/l4_lo?1<7@c`C2d<h4`m3>1;g:b@>iaLD4]l;11;No_PBj_[/4_l2k1<C4
_P?9bL84clk71=?@b0CEc/H4eL_11=G8_@CC`KD3f<>f1=c4]@CE_Zl4d;RY1<jeYPC7[j03`jZK1;jU
UPBlX904^Ib;1;FHQ`BdUH@4[Xim0iioK`B>L644Q6IH185XG0AmJEh4NVYQ0gM/I0AeKFL4Lfm[175a
KPA`M784KgIe16iiNAGoool001Coool4MhN918:BU0B=WZ04V:Z/1:>g^0>_a<D4_=7C1<WPh@CGk^l4
iOko1>CmoP?SmoP4h?7a1=?Ti@C1eMP4/<K<1;;8c0Beb/d3^Lc>1;c>c`Bocll4`M3?1<;@cPC3d<h4
_L[90kW5a@Bg`/44]knn1;Zn^`Bo`;/4a<Bn0lW9`PC?c/L4dm381=G>aPCEbl44eLRm1=?1]@?H`kH4
g<Be1=Fn[`C@^:T4c[FV1<N_X0?3ZY/4_ZFF1;bPT0BiW8/4]IR71;BEQ0B^SWd3WWm_18i`H@B4IUP4
PFQL17eYGPAjJV43MfaT17E]I`AcKf/4LG5^171dLPA_MWD4KWUi5Oooo`005?ooo`AgQhT4PY:D18fN
X0BHZZ`4XkNh0jo4a@BldM<4bN3Q1=O^k`CUo_l4i?gn0n?gn0CPlO44dnCU1<7Ef0B`a/`4//S<1;G:
c@>ic<h4_<k?1;o?c`C1d<l4`]3>1<?@cPBmb/T3^LG51;O2`@Bg_kh4^[jk1;o0^`C4a;h3bLW21<o>
a`CCd<P4eLk61=G;`@CEb;d4dl6e0mS3]PCLa;D4eKj_1=2hZ@C>]JH4ajnP0l>ZV`BnYIH4_:2@1;VL
R`BeV8L4]9F41:j>O@>NOfl4SW1Q18AVF0B1J5`4OFUN17YZH@=gK6@4MFeW17=_J`AaLFh4L7Ab16mf
M@A^NGTEoooo000Doooo17N7R@B2TY@4SIjP19RZ[0BS]kP3[lC51;cAd`C9h>44enk_1>Gno`CToOh3
hoOh1>3al@CCi>D4`MGH1;36c0Bbb<`4]L[=0kW<cPBlc/l4_lo?1<7@c`C2d<h4`m3>1;g:b@>iaLD4
]l;11;No_PBj_[/4_l2k1<C4_P?9bL84clk71=?@b0CEc/H4eL_11=G8_@CC`KD3f<>f1=c4]@CE_Zl4
d;RY1<jeYPC7[j03`jZK1;jUUPBlX904^Ib;1;FHQ`BdUH@4[Xim0iioK`B>L644Q6IH185XG0AmJEh4
NVYQ0gM/I0AeKFL4Lfm[175aKPA`M784KgIe16iiNAGoool001Coool4N8N918>BU0B>Wj04VZ^/1:Jh
^@>baLL4`=CE1<oTi@CSn?T4j_oo1>KjnP?WmoH4h_3_1=7Qh`BldMD4[<;81:o5b0BcalT3^<_;1;_<
c0Bmc</4`<g;1<7=b`C1c<T4_/W60k_5`PBi`;d4^;fj1;^m^@Bo_kX4a<>l0l[8`@C?cLD4dlk61=G=
a0CEbKl4dlFj1=70]0?A_k<4dkj`1<ZgZ@C9/jD4a[2Q1;nYV`>mYIH4^j6A1;bOSPBkW8/4^IZ81;ZH
Q@B_SW`3WGm_18aaHPB4IeP4P6MJ17aWG@AiJ5l3MVYR17=/IPAbKVT4L71]16mcL@A^MWD4KGQi5Ooo
o`005?ooo`AhQhT4Pi:D18jOX0BJZj`4Y[Ri0k;5a`C0e=D4cnCU1>?hn@CZool4i_[j0nOgmPCRl>l4
dN7S1;cAe@B/`/P4[lG81;?7b@>hbl/4^lc<1;g<b`C0cL/4`Lg;1<7<b@BnbLH3^lG21;W0_@Bh_KX4
^kfi1;no^PC4`k`3b/S11<o=a@CCc/H4eLg41=G9_`CCaKX4dL2d0m6o/`CC_[04b[NY1<VcY@C6/:44
_jVK0kfUUPBkXI44_9n>1;^LR`BiVXP4^YR51:n>O0>MOfl4S75R18AWF0B0IeX4O6MM17UXG`=fJV84
LfaV179^J@A`L6d4Kg=a16ifM@A]N7TEoooo000Doooo17R7R@B3TY@4SYnP19Z[[0BV^;T3//G71<3D
e@C?i>D4hoSi1>[oo`CVn_X3ioOf1>;`k`CAhN<4_=7E1:c2b0B_aLP4/lO90kS;b`Bkc<`4_Lc;1<3=
b`C1cL/4`Lc91;k9aP>kaL84^L2m1;Rm^PBk_KT4_knj1<C3_0?:b<44clg51=?>aPCEcL@4eLVo1=?5
^PCA`;@3dKnc1=>n/0C:]jT4bK>U1<J`X@BoZI/3_JFF1;^QT@BlWhh4^ib;1;VJR0BjV8D4[hil0ieo
K`B<LF84Q6MH181WFPAlIed4NFQO0gIZHPAcK6H4LViY171`K@A_Lg44KWIe16ehNAGoool001Coool4
N8N918>BU0B>Wj04VZ^/1:Jh^@>baLL4`=CE1<oTi@CSn?T4j_oo1>KjnP?WmoH4h_3_1=7Qh`BldMD4
[<;81:o5b0BcalT3^<_;1;_<c0Bmc</4`<g;1<7=b`C1c<T4_/W60k_5`PBi`;d4^;fj1;^m^@Bo_kX4
a<>l0l[8`@C?cLD4dlk61=G=a0CEbKl4dlFj1=70]0?A_k<4dkj`1<ZgZ@C9/jD4a[2Q1;nYV`>mYIH4
^j6A1;bOSPBkW8/4^IZ81;ZHQ@B_SW`3WGm_18aaHPB4IeP4P6MJ17aWG@AiJ5l3MVYR17=/IPAbKVT4
L71]16mcL@A^MWD4KGQi5Oooo`005?ooo`AhQhP4Pi>D18nOX@BK[:d4YkVj0kC7a`C2eMH4d^GV1>?g
m`CSm_H4hO?b0mk]k0CIinL4b=[L1;O<d0BY_l@4[<751;33a@>daLH4^<K61;c9b0C0c<X4`/g:1<?<
b0C2bLH3_lG11;g2_PBl_k/4_Kfh1<2o^@C5`k`3blS11=3<a0CDcL@4e/g31=K:_`CEa[X4dl6d0m2n
/@C;^:/4`K2S1<2/W`BnZI`4^JBF0kZRT`BmX904_Yn>1;jMR`BnVhP4_IV51:j<NP>KOFd4RfmQ189T
EPAnIEP4NVEK17MVG@=dJ604LVYT171/J0A_Kf`4KW9`16eeM0A]N7TEoooo000Doooo17R7R0B3Ti@4
SinQ19^/[@BW^KX3]<O71<;EePCBiNH4hoOg1>?fmPCQlo83g^g/1=WWi`C8f]`4]lc@1:Voa0B/`LD4
/<?50kC5aPBha/H4_<W81<3<bPC2cLX4`lc81<;9aP>oaL44_L:n1;bo^`Bm_KP4`;ni1<G3_0?;b<44
d<c41=C=a0CFcL<4e/Zo1=G6^PCC`K@3d;ja1<^hZ`C1/:<4`:bO1;jYW0BiY9H3^Z:C1;fPT0BnWhh4
_Yf;1;jKR0BmVHD4[Xaj0i]mK@B;Kf44PVAF17iUF0AjIE/4MfIM0gAXH0AbJV@4L6aX16m_K0A^LW04
KGEd16ehNAGoool001Coool4N8N818>CU0B?Wj44Vjb]1:Ni^P>dalL4`]GF1=;UiPCSmoL4hoKf1>7c
lP?NkN`4fNOW1<SJg0Bgc=04ZKo41:c1a@B``lD3]<G61;S6aPBlbLP4`<c:1<;=bPC3c<P4`/W60ko5
`@Bm`[h4_;nk1;fm^0C0_kT4aL>l0l_8`@C@c<@4e<g41=K=``CFb[l4eLJj1=?1]0?@_[44bkR[1<6`
X`C0[9l4_ZVL1;VTUP>jXY<4_J2@1;jOSPBnWH/4_Y^81;fIQ@B^S7X3Vge]18]_H@B2I5H4OVEH17YU
F`AgIUd3M6QP179ZI0A`K6P4Kfm/16ibL0A]MG@4KGQi5Oooo`005?ooo`AhQhT4Q9>E18nPX@BK[:d4
Z;Vj0kG7a`C3eMD4d^CT1>;dm0CQl_44g^k]0mSWi`C?gn04`M?F1;?7b`BW_L44Z[k11:jo`@>a`L44
]L;11;O2`0Bi`l04_<?01;[1_PBh_[/3][^h1;Nj]PBg^K@4^[Vd1<2n]`C6a;`3c<W11=3<``CDc<84
e/g11=S;_`CHb;X4eL>e0m:o/0C>^J/4b;>U1<B^X0C1ZIX4_ZFF0l2TT`C0Xi04`J6>1<6OS0C3WXX4
`9Z51:f;N0>FNFT4RViO189SE0AmHeL4N6=H17ATF`=aIEh4KfQR16i[IPA]KVX4KG5_16edM0A]N7PE
oooo000Doooo17R7R@B4TiD4Sj2Q19^/[@BX^KX3]LO71<?Ee@CBi>@4h_Cd1>7bl@CNk^d3f>OW1<oO
h0C1dmH4/lO;1:Nm`@BZ_/44[[o10k71`@Be`/44]l;01;W3`0Bl`l04^/6n1;Rn^`>f^kP4]kZf1;Ni
]0Bj^K@4`;jg1<K4_0?<bL44d<c31=C<`PCFcL44f<^o1=S8^PCE`kD3d[n`1<jiZ`C8/jD4a:jP1<6Y
VPBnYIH3`:BC1<2ST0C1XHh4`In<1<>NRPC0VXD4[H]h0iIiJ@B:KUl4PV=D17eSE`AhHeP4M6AK0g5U
GPA_J684KV]V16e^JPA]LFl4KGAd16ehN1Goool001Coool4N8N918BCU@B?X:44Vjb]1:Ri^P>ealL4
`mGE1=;Ti0CRm?@4hO;a1=k^k@?HinL4cmoP1<7CePBcal/4Ykg11:Zn`@B^_l43/L711;G2`@Bg`/04
^L?01;c3`0Bj`Kh4^;jk0kJk^0Bg^[H4]kVd1;Zi]0C0_[L4a/Bl0lc9`@C@c<<4e<c21=K=`@CHbkl4
f<Rj1=G3]@?B_k04c[V[1<RcY@C4[Z04`JVJ1;jUUP?0Y9<4`:>@1<6QSPC1Wh`4`ij:1<2JQ@B]RgP3
UWUY18Y^G`B2He@4OF=G17QSF0AdI5/3LFEN16mXHPA^JfH4KFiZ16eaK`A]M7@4KGQh5Oooo`005?oo
o`AhQhT4Q9>E18nPX@BK[:d4Z;Vj0kG7a`C3eMD4d^CT1>;dm0CQl_44g^k]0mSWi`C?gn04`M?F1;?7
b`BW_L44Z[k11:jo`@>a`L44]L;11;O2`0Bi`l04_<?01;[1_PBh_[/3][^h1;Nj]PBg^K@4^[Vd1<2n
]`C6a;`3c<W11=3<``CDc<84e/g11=S;_`CHb;X4eL>e0m:o/0C>^J/4b;>U1<B^X0C1ZIX4_ZFF0l2T
T`C0Xi04`J6>1<6OS0C3WXX4`9Z51:f;N0>FNFT4RViO189SE0AmHeL4N6=H17ATF`=aIEh4KfQR16i[
IPA]KVX4KG5_16edM0A]N7PEoooo000Doooo17R7R@B4TiD4T:2Q19b/[@BX^KX3]LK71<?De0CAh^84
go7`1=g]k@CHj>L3d^7Q1<[Jf`Bmcm44[lC71:Jk`0BX^kh4[;bn0k2n_PBc_[d4]Knm1;Jn^`Bf^kP4
];Vf1;Fh]@>e]k<4][Nb1;Rh/PBn^kD4`l6i1<W6_P?>bL44dL_21=?;`@CDbKh4e<Nj1=G4]PCF`[<3
e/6a1=:l[0C=]ZH4b[6R1<N]W@C5ZYT3a:NE1<BUTPC4XXl4a:6<1<NQR`BoVH<4ZXQe0iIiJ@B>LF84
QVMH17YPE0AdGeD4L61H0fiRF`A]IEl4K6QT16a/J@A/L6h4K7=c16agN1Goool001Coool4N8N918BC
U@B@X:44W:b]1:Ri^P>ea/L4`mCD1=7RhPCOlO04gNg]1=SXi`?BhN44b][K1;g?d@B_a<L4Y[_01:Rk
_PB/_;h3/;jn1;>n_@Be_kd4][jk1;Jk^0Bd^KH4]KRe0kFg/`Bf]k84^;Rb1;jk]@C3`KT4bLJn0lk9
`@CAbl84dl_11=C9_PCDakX4eLBf1=K2/`?F`K44d[b/1<ffYPC:/J84ajfM1<FZV@?4YiD4a:FB1<BR
S`C4XH`4aj6;1;nIP`BZR7D3UWUY18iaHPB6IeP4NV1D17AOE@A`H5P3KV9K16eUG`A/J6@4K6aY16a`
KPA/Lg<4K7Mh5Oooo`005?ooo`AhQhT4Q9>E192PX@BL[:d4Z;Vj0kG6a`C3e=@4dN;R1=oal0CMkNd4
f>SW0m;Qh@C:f]/4_LoA1:o4a`BV^l04Z;^n1:bl_P>`_[h4/kjm1;Fo_@Bf_[/4][^h1;Bi]PBe^;D3
]KNc1;Jg/PBh^;84_[^e1<?1^@C9a[h3c/W11=7;`PCCbl44e<Vn1=C7^PCEa;H4e/:c0mK1/@CB_:`4
cKJV1<ZaXPC7[Id4aJZI0lBWU@C4YI84a::?1<BQS0C7XH/4_iV31:Z8M@>FNFT4SW5R18IWF0AjH5@4
M5mE171PF0=^HU/4KFEO16aXI0A/K6T4K71^16acL`A/MgPEoooo000Doooo17R7R@B4TiD4T:2Q19b/
[@BX^KX3]LK71<?De0CAh^84go7`1=g]k@CHj>L3d^7Q1<[Jf`Bmcm44[lC71:Jk`0BX^kh4[;bn0k2n
_PBc_[d4]Knm1;Jn^`Bf^kP4];Vf1;Fh]@>e]k<4][Nb1;Rh/PBn^kD4`l6i1<W6_P?>bL44dL_21=?;
`@CDbKh4e<Nj1=G4]PCF`[<3e/6a1=:l[0C=]ZH4b[6R1<N]W@C5ZYT3a:NE1<BUTPC4XXl4a:6<1<NQ
R`BoVH<4ZXQe0iIiJ@B>LF84QVMH17YPE0AdGeD4L61H0fiRF`A]IEl4K6QT16a/J@A/L6h4K7=c16ag
N1Goool001Coool4N8N918BCU0B@Wj04W:^/1:Rh^@>eaLD4`];B1<oPh0CMk^d4f^WX1=CSh`?=gMd4
`mGF1;O;c@B]`L@4YKZn1:Ji^`BZ^[/3[[bk1;:l^`Bd_K/4][fi1;Nl^0Bh_;L4^Kbg0kZl]PBl_KL4
_kjh1<?1^PC7a;d4c<S00lo;`PCBc<84e<_01=C9_@CDa[T4dl:d1=2m[`??^j`4ckVY1=6gY`C?]J<4
cK6O1<Z]VP?8ZIH4aJFA1<FSSPC8XXd4bJ2:1;bEP0BYQg<3VW]Z18i`H0B1HU@4KeI;16eID0A[G5@3
JUmH16URG@AYIV84JFYW16Y^K0A[LW84K7Mg5Oooo`005?ooo`AhQhT4Q9>D192OX0BLZj`4Z;Ri0kG5
a@C2d]84cn3P1=g^k@CJjNP4e>?S0lgMg@C3eMH4]l_=1:g1a0BU^[h4Y[Vk1:Zj^`>^_;/4/[bk1;Bm
^`Bf_KT4]kbh1;Rl]`Bi_;L3^[bf1;bm]`Bo_[P4`l6j1<O4_@C<b<03cl_21=;<`PCDbl04e<Vm1=C6
^@CC`[@4d;f_0lnk[0C?^JT4dKNW1<neX`C=/Il4bZfJ0lRYUPC5YI44aJ>>1<RRS@C9X8X4_9F01:V7
L`>JNfX4SW1P185RE0A_ET/4KEU@16]LE0=ZGeP4JF9M16UVHPAYJVL4JVi/16]bLPA/MgLEoooo000D
oooo17R7R@B4Ti@4T9nP19b[[0BX^;T3]LG51<;BdPC?h>04gNk]1=[Yj0CDhn<3cMgM1<?EePBgbld4
[L741:Fj_PBV^K/4Z[Zk0jjl^`Bb_;/4];fk1;Jm^@Bg_;P4^;bg1;Vl]`>j_;H4_;fg1;nn^0C3`KX4
alBm1<c8`0??bl84d/c21=C;`0CDbKd4e<Ji1=?2]0C@_Jl3ck^/1<niZ@CA]jL4ckFS1<faW`C:[IX3
b:VF1<FUT@C5Xhh4b::=1<VPRPBlUH04ZHMc0iYkJPB>L604PF9D16mFB`A]FE04JeaD0fYOF0AYHUd4
JFIR16UZI`AZKV`4Jg9b16agMaGoool001Coool4N8N918BCU0B@Wj04W:^/1:Rh^@>eaLD4`];B1<oP
h0CMk^d4f^WX1=CSh`?=gMd4`mGF1;O;c@B]`L@4YKZn1:Ji^`BZ^[/3[[bk1;:l^`Bd_K/4][fi1;Nl
^0Bh_;L4^Kbg0kZl]PBl_KL4_kjh1<?1^PC7a;d4c<S00lo;`PCBc<84e<_01=C9_@CDa[T4dl:d1=2m
[`??^j`4ckVY1=6gY`C?]J<4cK6O1<Z]VP?8ZIH4aJFA1<FSSPC8XXd4bJ2:1;bEP0BYQg<3VW]Z18i`
H0B1HU@4KeI;16eID0A[G5@3JUmH16URG@AYIV84JFYW16Y^K0A[LW84K7Mg5Oooo`005?ooo`AhQhP4
Q9>D18nOX0BKZj/4YkNh0kC4a0C0dM04cMkM1=[Zj@CEiND4dN3P0lWIf@C0dM84]LS:1:c0``BV^[d4
YkRj1:Zi^@>^^[X4/Kbj1;Bm^PBg_KX4^Kjj1;^n^PBm_kX3_l2j1<;2_0C4a;d4b<Jo1<_9`@C?bl83
dlg31=C=`PCFc<04e/Zm1=K8^PCEa;H4dl2b0m2k[@C<]ZL4bK:R1<R_WPC8[9/4aJVF0lFVTPC5Y8l4
bJ>?1<^RS0C9WhP4^95l1:N3L@>HMfH4R6UJ17QLCPAXDDH4IUA;16EGC`=UFe@4IEmJ16ISG`AWJ6D4
J6e[16YbL@A[MWLEoooo000Doooo17R7R0B4Ti@4SinP19^[Z`BW]kP3]<C41<3Ad0C=g]d4f^[Y1=GU
i@CAh>03bMWI1<3AdPBeb<X4[<331:Jj_@BW^;X4Z[Vi0jjj^PBa_;X4];fj1;Nm^PBi_[X4^kjj1;fo
^P>o`;X4`/:l1<C4_@C8a[l4blW11<o;`P?CcL<4e<g21=K<`0CFb[d4e/Rj1=G4]PCC`;83d;^]1<bf
Y`C9/Z84b:nN1<R/V`C5ZIH3aJJB1<FTS`C9Xhl4bj:<1<VOR0BhTG`4Yh=a0iQgIPB8JEX4N5a>16QA
APAVE4/4IEM?0fEKE0AUGeX4IV=O16MXI@AXKF/4JW9a16]fMaGoool001Coool4N8N818BCU0B?Wj04
Vj^[1:Ng^0>da<@4`=7@1<gNg@CJj^T4eNGU1=7Ph0?9fMT4`=7B1;G8bPB/`<<4Y[Zm1:Nh^PBZ^KT3
[[Zj1;6l^PBd_KX4]kfj1;Vn^PBk_[X4_Knj0ko0^PC2`[`4a<Bm1<S6_`C;bL44cl_20m?=``CDcL84
e/c01=K:_@CFb;X4eLBf1=?0/P?@^jd4c;JW1<VbXPC8[ih4b:bK1<FYUP?5YY84aJB?1<VSS`C;XX`4
bIn81;RAO0BWPg43V7MV18QYFPAhG4h4J55616IDB`AUEdl3IE]D16EOFPAVHel4IfQU16Q]J`AZLW44
JgIg5Oooo`005?ooo`AhQhP4Q9>D18nOX0BKZj/4YkNh0kC4a0C0dM04cMkM1=[Zj@CEiND4dN3P0lWI
f@C0dM84]LS:1:c0``BV^[d4YkRj1:Zi^@>^^[X4/Kbj1;Bm^PBg_KX4^Kjj1;^n^PBm_kX3_l2j1<;2
_0C4a;d4b<Jo1<_9`@C?bl83dlg31=C=`PCFc<04e/Zm1=K8^PCEa;H4dl2b0m2k[@C<]ZL4bK:R1<R_
WPC8[9/4aJVF0lFVTPC5Y8l4bJ>?1<^RS0C9WhP4^95l1:N3L@>HMfH4R6UJ17QLCPAXDDH4IUA;16EG
C`=UFe@4IEmJ16ISG`AWJ6D4J6e[16YbL@A[MWLEoooo000Doooo17R7R0B3TY@4SijO19ZZZPBV][H3
//;21;o?cPC;fm/4f>SW1=CSh`C?g]d3a]OF1;k?d0BealT4[/331:Rk_@BW^;T4ZKNh0jfi^0Ba^kP4
]Kbi1;Rn^@Bk_k/4_/6l1<73_@?3aKl4a/O11<W9`PC=bl@4d<g51=??a@?Fd<H4elo41=S>`@CIc;l4
fLZl1=S7^0CF`k@3dkj^1=2iZ0C</j<4bJnN1<N[V@C7ZID3b:NC1<ZVT@C<Y8l4c:>=1<JLQPBeSGT4
XWm/0i5aH@B0HeD4L5M;169=@`AOCTH4Ge5:0emFD0AQFeH4Hf1M16AVH`AVJfX4J75`16YfMaGoool0
01Coool4N8N818>BU0B?WYl4VZZZ1:Jf]P>b`/84_lo>1<_Kf`CHj>L4e>?S1<oNg@?6emH4_/o@1;G7
b@B^`<<4Z;^m1:Nh^@BY]kP3[KVh1;6k^0Be_;T4^;ji1;^o^`Bn`K`4`L>m0l?5_`C6al44bLW21<g;
a0C@cLD4dlo50mK@aPCGcl@4f<k11=W<_`CIb[`4f<Nh1=K3]0?C_Zh4d;VX1<bcX`C9[ih4aj^I1<NY
U@?8Yi<4bZJA1<bTS`C<Xhd4aYb61;F=N@BROf`3TG5Q181SE@A`Ed/4HTe315m>APAODDX3GeI@165K
EPASH5d4I6IS16I[JPAXLG04JWIg5Oooo`005?ooo`AhQhP4Pi:D18nNW`BJZZX4Y[Jf0k;2`PBoclh4
bm_K1=SXi`CDhn<4cmkM0lKGePBncm04]LO91:k0``BX^kd4YkRi1:Vg^0>]^KP4/K^h1;Fl^@Bh_[T4
^knk1;k1_0C1`kd3`lFo1<K7`@C9bL84cL_41=3=a@CCclD3e]361=O?a0CHc/44fLbo1=W:_0CHakP4
e/>d0m>n[PC@^JP4c;>S1<V_WPC7ZiT4ajVE0lRWT`C:YY44c:B?1<bSS@C6W8H4]Hei1:9oK0>ALF44
P6=E171GB`ARCD<4Gdi615mABP=OEU04HE]F16=PG@ATIV<4IV]Z16QaL0AZMWLEoooo000Doooo17R7
R0B3TY<4SYfN19ZYZ@BU]KD3/L701;g=c0C9fMP4e^GT1=7PgPC<f]T3aMCD1;k>cPBga/L4/<321:Zk
_0BW^;T4ZKJf0jfh]`Bb^kP4][fi1;Zo^PBn`K`4`LBn1<C6`0?8bL84bl_41<k=a@CAclL4e=781=SC
b0?JdlL4fm;51=c@``CLc/04g<bm1=c9^@CJaKD3f<2_1=BkZPCB]jD4d;>Q1<j_W0C>[9P3cjZE1<nX
TPC@YXl4cj:;1<>HP@B_R7@4WGYW0h]/G0AiGU04Ie1515U6?@ADACd4Ed]40eUAC0ALEe<4GeiJ169T
H@ATJVP4Ig1_16YeMQGoool001Coool4N8N818>BT`B>WIh4VZVY1:Fe]@>a`L04_Lg<1<WIf0CFiN@4
dN3N1<cJf@?5e=@4_/k>1;O6a`B``<84Z[^l1:Nh^@BY][H3[KRg1;:k^0Bf_KT4^[nj1;k1_0C1a;h4
a<K00lS9`PC;bl@4c/g51=7?a`CDdLP4f=?80m[Ca`CKd/D4g=331=c>`0CLc;d4g<Vi1=[5]@?H`:l4
e;^Z1=:gY@C@/j44cZnL1<j/V0??ZYD4cjRB1=2VS`C?XX/4`iR11:n8M0BMNVL3RfaL17UND0AWD4D4
FDHm15A5?@AGBd@3FE5<15aGD`AOGUX4HVAQ16AZJ0AWL6l4JWEf5Oooo`005?ooo`AhQhP4Pi:C18jM
WPBJZJT4YKFe0k71`0BmcL`4bMWH1=KUi0CAh=h4c=[I0lGDe0Bnc/h4]lK71;30`PBZ^k`4YkRi1:Vf
]P>]^;L4/[^h1;Jm^@Bj_kX4_/6l1<74_PC4a/03b<W21<_;a0C>cLD4dLo71=CAb0CHdlP3f]?71=_B
a@CLd<<4g<k01=c<_@CLbKT4f/Fe0mS0[`CD^jX4d[NU1=2cX@C>[i`4cZbH0lnZU@C?Z984d:J?1<nR
R`C3V844[hQd19ejI`>;K5`4NEi@16M@A@AIASd4E4Dm15M;A0=IDD`4G5MC15mNFPARI644I6YX16M`
K`AZMGHEoooo000Doooo17R7R0B3TY<4SYfN19ZYZ@BU]KD3/L701;g=c0C9fMP4e^GT1=7PgPC<f]T3
aMCD1;k>cPBga/L4/<321:Zk_0BW^;T4ZKJf0jfh]`Bb^kP4][fi1;Zo^PBn`K`4`LBn1<C6`0?8bL84
bl_41<k=a@CAclL4e=781=SCb0?JdlL4fm;51=c@``CLc/04g<bm1=c9^@CJaKD3f<2_1=BkZPCB]jD4
d;>Q1<j_W0C>[9P3cjZE1<nXTPC@YXl4cj:;1<>HP@B_R7@4WGYW0h]/G0AiGU04Ie1515U6?@ADACd4
Ed]40eUAC0ALEe<4GeiJ169TH@ATJVP4Ig1_16YeMQGoool001Coool4MhJ818:ATPB=W9d4VJRX1:Bc
/`>__kh4^l[:1<OFe@CCh^44c]cK1<WGeP?3dM44_<_;1;G5a@B__kl4ZKVj1:Nf]`BW]K@3[KRf1;:k
]`Bg_[T4_<6l1<33_PC4a/04b<W20lc<a@C?clL4dm791=KCbPCIeL/4g=K;0mgFb@CNeLL4gm?41>3@
`@CPc[h4gl^j1=k7]P?K`[44fKj/1=NjY`CE]Z84e;:N1=>_VP?B[9H4dZVC1=6WS`C;WhP4^Y5k1:R2
K`BEM683PVEF16iEB@AKAcd4CC`d14Tk=0A?A3h3Dda715QDD0AKFeP4Gf9P16=XI`AVKfh4JGEf5Ooo
o`005?ooo`AgQXP4PY6B18fLW@BIZ:P4Y;>c0jno_PBkb/X4amKE1=?Rh@C>g=/4bMOF0l?Ad@Blbl/4
]LG51:no_`BY^KX4YkJg1:Ne]0>]^;H4/[^g1;Nn^@Bl`K`4`<>n1<C6`0C8bL83c<c51<o?a`CCdLT4
e]?:1=WEb`CLe//3gMK91=kEa`COdl@4h=311>3>_PCObkX4g/Nf0m_2/@CI_Z`4ekZW1=FfXPCD/Yh4
djnJ0m:/UPCBZI<4dJN?1<^OR0BjTG/4Z89_19EdHP>2IEH4KUE915]7?@A=?3@4BC/d14m4?P=CC4L4
F5A@15]KF0AOHV04HfQW16I_KPAYMGHEoooo000Doooo17N6R0B2TI84SIbM19VXZ0BT/k<3[knn1;_:
bPC7e]D4dn;Q1<kLf`C9emH3`m7A1;c;b`BeaLD4[kno1:Vi^PBW][L4YkFd0jfh]PBb^kL4]kji1;c1
_0C0`kh4a<K01<S9`P?<c<D4clo71=?Ab@CFdlX4fMG;1=cFb`?Me/T4g]G71=oCa0CPd<44h<jn1=o;
^PCNakH3fl:a1=Vn[0CG^ZL4eKJR1=BbWPCC[iX3dZbF1=:YT`CAYhl4bin81;ZAN`BXPVl4UGAR0h9U
EPA^EDT4FdLm14dl=0A9>c@4Cd@n0e=<A`AHE504Fe]H15mRH0ASJ6L4IVm^16UeMQGoool001Coool4
MhJ818:ATPB=W9d4VJRX1:Bc/`>__kh4^l[:1<OFe@CCh^44c]cK1<WGeP?3dM44_<_;1;G5a@B__kl4
ZKVj1:Nf]`BW]K@3[KRf1;:k]`Bg_[T4_<6l1<33_PC4a/04b<W20lc<a@C?clL4dm791=KCbPCIeL/4
g=K;0mgFb@CNeLL4gm?41>3@`@CPc[h4gl^j1=k7]P?K`[44fKj/1=NjY`CE]Z84e;:N1=>_VP?B[9H4
dZVC1=6WS`C;WhP4^Y5k1:R2K`BEM683PVEF16iEB@AKAcd4CC`d14Tk=0A?A3h3Dda715QDD0AKFeP4
Gf9P16=XI`AVKfh4JGEf5Oooo`005?ooo`AgQXL4PY2B18bKW0BGYZH4X[6a0jjl_0Bib<L4aMCB1=7O
g@C<fMP4a]CC0l7?cPBlb/T4]lG41:nn_PBY^KX4Y[Jg1:Ne]@>]]kD4];^g1;Vn^PBo`[d4`lJo1<S9
`PC<c<D3d<o81=CBbPCGeL`4fmO=1=gHcPCPfLd3h]W;1>?Gb@CSeLD4hm;21>?@_`CRc;/4hLRf0mo4
/PCM`:d4fkfY1=ZiY0CH]J04ek6K0mF^U`CEZY<4dJF=1<FJP`BcRgH4X7aY18][F`=fFdh4HDa114hm
=@@m;bP4?c<]14Po>P=>B4@4De1=15QHEPAMH5h4HFMV16E^KPAYM7DEoooo000Doooo17N6Q`B2T984
S9^L19NVYPBR/K43[[bl1;W8a`C5e=84dMoM1<cIf0C6e=<3`Lo>1;c:b@BgaL@4[kjn1:Vi^PBV][L4
YkFe0jfg]@Bd^kL4^Kjj1;o2_@C3a[l4b<W21<c<a@?@clP4e=;:1=OEc0CKeld4gMS>1>3Ic@?RfL/4
hmO91>?Ea@CSd/84hm2o1>;<^`CQb;H3glBb1=g0[@CK_JT4f[VT1=ReX0CG/I/3eJjG1=FZT`CAYHd4
aIZ31;>;MPBPO6T4Rf]K0gIKCPAQC444CSde13d_:0@o<bd4B3lj0di8A0ACD4d4F5QF15ePGPAQIfH4
IFi^16UdMAGoool001Coool4MhJ718:@TPB<Vi`4UjJV1::a/@>^_;`4^LS71<GDdPCAgmd4c=WH1<KD
d`?1clh4_<[91;O5a0B__[h4ZKVj1:Jf]`BW]KD3[KNe1;Bk]`Bi_[X4_l:m1<?6_`C8bL84c<c50m3?
b0CDd/X4emG<1=_Gc@CMf<h4h=W=0n;Ib`CSelT4hmG51>?B`PCSd;l4h/bk1>78]P?Oa;84gL2]1=^m
Z@CJ^J@4f;FP1=NaV`?E[YL4eJZC1=6US@C5VX<4/h]f1:1lJ@B;Je/3MU]>165<@@A>?CD4?BlX13lc
;@A8?cX3CTQ415=@C@AHF5H4GF1N165WIPAUKVh4JGAe5Oooo`005?ooo`AgQXL4PY2B18bKW0BGYZH4
X[6a0jjl_0Bib<L4aMCB1=7Og@C<fMP4a]CC0l7?cPBlb/T4]lG41:nn_PBY^KX4Y[Jg1:Ne]@>]]kD4
];^g1;Vn^PBo`[d4`lJo1<S9`PC<c<D3d<o81=CBbPCGeL`4fmO=1=gHcPCPfLd3h]W;1>?Gb@CSeLD4
hm;21>?@_`CRc;/4hLRf0mo4/PCM`:d4fkfY1=ZiY0CH]J04ek6K0mF^U`CEZY<4dJF=1<FJP`BcRgH4
X7aY18][F`=fFdh4HDa114hm=@@m;bP4?c<]14Po>P=>B4@4De1=15QHEPAMH5h4HFMV16E^KPAYM7DE
oooo000Doooo17N5Q`B1T944RiZK19JTY@BQ[jl3ZkZi1;O5a0C3dM04cmcJ1<[Ge@C4d]03`<g<1;c9
b0Be`l84[kfl1:^i^@BY][H4Z[Jd0jng]0Be^kL4_<2j1<74_PC7b<44c<c41=3@b0?Edl/4fMO>1=cI
c`CPfm44h]cA1>GMd0?Vfld4i]W:1>OFa`CWe<<4i]6o1>G=^`CTb[L3h/Jc1>72[PCO_ZT4gKZU1=bf
X0CJ/Y/3fJjG1=BXT@C<X8T4_I=m1:Z3K`BDLf44Of9D0fYBAPAF@cT4@c@]13@X8P@k<B`4@c/g0dU5
@@A@CT/4EEID15YNG@AOIVD4I6e]16QdMAGoool001Coool4MhF7186@T@B;VY/4UZBU1:6_[`>[^[T4
]lG41<?Ad0C?g=X4b]OE1<CBd0?0cL`4_<W81;G3`PB__K`4ZkVi1:Vf]PBZ][@3[kNd1;Fk]`Bl`;X4
`LBn1<O8`@C<c<@4d=380mGCb`CIelh4g=W?1>3Kd@CRg=44iMg@0nKKc@CVfLX4imK71>OD``CVdKl4
iLfk1>C:]`?Ra[<4hL:^1=nnZ@CM^ZD4g;JP1=ZbV`?I[YL4e:RA1<bPR@BmTgd4ZX=_19AcH@AoHU@3
JU9615I3>@A3=2d4=2PR13/a;0A3>cL3BDE1151>B`AEEU@4FUiM15mVI@ATKFd4J7Ae5Oooo`005?oo
o`AgQHL4PI2A18^JV`BFY:D4XJn_0j^j^@BgaL@4`m7@1<oLfPC:emD4a=;@0l3=c0BlbLP4]L?21:nm
_0B[^KT4ZKJf1:Zf]0>_]k@4]K^g1;c0^PC1a;h4alS11<c<a0C@d<P3eM?;1=WGcPCLfLl4h=_A1>;L
d@CUgM03i]_=1>KIbPCWe/L4imC31>KA_`CUcK/4i<Zg0n;6/`CQ`Zh4gkjY1=fjY@CL]Z04f[:K0mV^
U`CDZ944c:291;fCO@BZPfl4U7=Q17mRE0=ZDTH4ET<i14<d;@@d:284>c4/14<k=`=9AD44D4i;15EF
E0AJGUd4GfIU16A]K@AXM7DEoooo000Doooo17N5Q`B1T944RiZK19JTY@BQ[jl3ZkZi1;O5a0C3dM04
cmcJ1<[Ge@C4d]03`<g<1;c9b0Be`l84[kfl1:^i^@BY][H4Z[Jd0jng]0Be^kL4_<2j1<74_PC7b<44
c<c41=3@b0?Edl/4fMO>1=cIc`CPfm44h]cA1>GMd0?Vfld4i]W:1>OFa`CWe<<4i]6o1>G=^`CTb[L3
h/Jc1>72[PCO_ZT4gKZU1=bfX0CJ/Y/3fJjG1=BXT@C<X8T4_I=m1:Z3K`BDLf44Of9D0fYBAPAF@cT4
@c@]13@X8P@k<B`4@c/g0dU5@@A@CT/4EEID15YNG@AOIVD4I6e]16QdMAGoool001Coool4MXF6182?
T0B:VIT4U:>S19j][@>Y]kL4]<;11;o=b`C;f=H4a]?B1<;?c@>nblT4^/K51;G1`0B`_K`4[KVi1:^g
]@B_^;D3/[Vf1;Rl^0Bn`K/4aLJo1<[;``C@clL4eMC;0mWGcPCNfm44h]gC1>GOe0CWh=84jN3A0n[N
c`C[fl/4j]S81>[Ea0CYd/04j<jk1>O;]`?Uak<4hl:^1>6oZPCP^jD4gkNP1=fcV`?I[YH4djJ>1<RK
Q0BeS7H4X7]X18Y[FPAeFd`3H4Xo14Xj<@@f:b@4;28M13H^:P@n>CD3AT8o14a<B@ACE5<4F5eK15iU
I0ASK6d4J7Ae5Oooo`005?ooo`AfQHH4P8n@18ZIV@BDXj<4WZf]0jVg]`Bd`/44_lg;1<_HePC6dm84
`/o=0kk;b@Bja/D4]L701;2m_0B]^KT4ZkNe1:nh]@>b^KH4^;bh1;k1^`C5a[l4b/_31=3?a`CEe</3
fMO>1=kKd@CRgM<4iMoD1>OPdPCYh=43j]k?1>_Kb`CZf<P4j]G41>WB`0CXc[/4il^g0nG7/`CS`Zh4
hKnZ1>2kY@CO]j04gK>K0mV^UPCCYXh4b9^41;F<MPBPNfP4RV]J17EKC0=PBSl4BSXa13H[90@/8Qd4
=RhZ13hi=@=6@Sl4C4a915=DD`AHGE/4GVET16=/K@AXM7DEoooo000Doooo17J5QPB0Si04RYVI19BS
X`BN[Jd3ZKNg1;C2`@BocL/4bmSF1<KCdPC2cld3_/_91;[6a@Be`L04/;fl1:fi^@B[]kD4[kRe0k:i
]PBh_;P4_/6k1<G6_`C:bl<4d<o71=GDb`?Ielh4g]_A1>;Md`CUgm@4in3B1>WPd@?Zg/l4jm_;1>[H
b0CZeL@4jM;01>S>^`CWbkL3iLNc1>?2[PCQ_jX4h;^U1=ngX0CM/i/3fJjF1=>VSPC8Vh@4]Haf1:1k
J0B:JeX4ME]<0f1:?`A:>S44=R/T12`R7@@f;RX4?STe0dI2?`A<C4T4DeAC15QMF`ANIF@4Hfa]16Qd
MAGoool001Coool4MXB617n>S`B9UiP4TZ6Q19bZZP>V];<4/;jm1;_9a`C6e=84`/o>1;o;b@>lb<H4
^LG31;K2`0Bb_K/4/;Zh1;2i]PBc^kL3]K^g1;^n^0C1`kd4b<W11<o>aPCDd/X4f]O>0moKd@CSg]<4
in3D1>[Re@C/hm@4k^?C0noPd0C^gL/4k][81>gFa0C/e<04jm2l1>W<]`?Wb;<4i/>^1>BoZ@CR^j@4
hKNO1=jbVP?H[9<4cZ691;jCO@BZPVh4Tg9P17iQD@AYDD@3DT0f13/^9`@V71P49QdI138[:0@k=S<3
@d4n14Y:B0A@De84EeaK15aTI0ARK6`4IgAe5Oooo`005?ooo`AfQ8H4Ohj?18VGV0BBXJ44W:ZZ0jJd
/`B`_[d4^lW71<KDdPC2clh4_l_90kc8aPBiaL<4]/;01;:m^`B`^[P4/;Vf1;>k]`>e^kL4^kjh1<73
_@C8bL44clk61=CBbPCJelh3gm_A1>?Nd`CWh=@4j^;E1>cSe0C^hm<3kn3@1>kMb`C^f/P4kMK41>cD
`0C[d;`4jLbg0nO8/`CV`jh4i;nY1>:kY0CQ]il4g[:J0mR/T`C>XHT4_Y=m1:Z2KPBCLV04OV5A16UA
A0=B@3H4>bhW12HL60@V7AT4<R/X13/f<`=3@Ch4BTY8151CDPAGG5/4G6AT169/K0AWM7DEoooo000D
oooo17J4QPAoSXl4RINH19:QX@BLZZX3Y[Bc1;2n_@BkbLL4a]CB1<;?cPBoblT3_<S61;W5``Bf`/04
/[fk1;2j^0B`^KH4/k^g0kFk]`Bk_[P4`L>m1<S9`@C?c/H4e=;:1=[GcP?Ofm44hmkC1>OPe0CZh]D4
k>?D1>kSd`?_h=04k]g;1>kJb0C]e/@4k=C01>_@_0CYc;L3ilRc1>K3[PCT_jT4h[^T1>6gW`CN/YX3
f:bC1<jQR@BnTgd4ZX9^19=bH0AnHE44JE540e90=P@k;RL49Q`H12HM6@@b:bP4>cHc0d=1?PA:BTP4
D5=B15MLF`ALI6@4HVa/16MdMAGoool001Coool4MXB617n>S`B9UiP4TZ6Q19bZZP>V];<4/;jm1;_9
a`C6e=84`/o>1;o;b@>lb<H4^LG31;K2`0Bb_K/4/;Zh1;2i]PBc^kL3]K^g1;^n^0C1`kd4b<W11<o>
aPCDd/X4f]O>0moKd@CSg]<4in3D1>[Re@C/hm@4k^?C0noPd0C^gL/4k][81>gFa0C/e<04jm2l1>W<
]`?Wb;<4i/>^1>BoZ@CR^j@4hKNO1=jbVP?H[9<4cZ691;jCO@BZPVh4Tg9P17iQD@AYDD@3DT0f13/^
9`@V71P49QdI138[:0@k=S<3@d4n14Y:B0A@De84EeaK15aTI0ARK6`4IgAe5Oooo`005?ooo`AeQ8D4
OXf>18NFUPB@WYl4VZNW0j>a/0B]^[T4]lC21<7>c0BoblT4_<S50k[5``Bh`l44]L2m1;>l^PBb^[L4
/kZg1;Jl]`>h_;L4_/2j1<G6_PC=c<<4dm771=WEb`COf/l3i=kB1>WQe0C/hmD4l>GF1?;VePCci=@3
ln;@1?;Nc0CaflP4l=O41>oD`0C]d;/4jlbg0n[7/PCX`jd4i[nX1>BjX`CQ]Id4g;2G0m>VSPC5VH84
/hYd19eiIPB7J5L4LUM915a7?0=5=Bd4<2DP124H50@W81d4<2XW13Pe<`=0?cd4B4U714mBD@AEFeX4
Ff=S165[K0AWLg@Eoooo000Doooo17F4Q@AnSHh4QiJF192NW`BJYjL3Xk6`1:fj^@Bga<84`Lk<1;o;
b@Blb<D3^/G31;S3`@Be`;d4/kbj1;:j]`Bc^[L4][bg0kRl]`Bn`;X4aLJn1<g<``CCdLL4fMG;1=oJ
c`?Tg]84jN7D1>cSe@C`iMH4l^KF1??Te0?ch]04l]k<1?7Kb0C`el@4kmC01>g@^`C[c;L3j/Nb1>S3
[@CV_jP4i;ZS1>6eW@CL/9L3djJ>1<FIPPBcRW@4WGUV18MXE`AbEdT4G4Ll0dDe;@@`9B048APD12LP
7@@`:RL4>3Dc0d0o?@A8BDL4Ce9A15EKFPAKHf<4HF]/16McM1Goool001Coool4MHB517j=SPB7UYH4
T9jO19ZWY`>S/K04[KZi1;O4`PC1c/`4_l_91;c8a@>jaL<4^<?11;G0_@Bc_;X4/[Zg1;>j]`Bf_;L3
^;bg1;k0^PC5a[h4cLc31=?Aa`CIeL/4gm[?0nCNdPCYhM@4k>?E1?3UePCbi]H4lnCD0o?Rd0Cbg/`4
lM_81?3Ga0C_e<04kM2k1>_<]`?Zak84j<>]1>JoZ0CT^Z<4hKFM1=b`U`?CYXh4aIV21;>:M0BMNFH4
QfQG179GB@ALAc`3ACD]130U80@Q61@49b0M130Z9`@h=C<3@3lm14Q9A`A?DU44EE]J15]SH`AQJf`4
Ig=d5Oooo`005?ooo`AeQ8D4OXf>18NFUPB@WYl4VZNW0j>a/0B]^[T4]lC21<7>c0BoblT4_<S50k[5
``Bh`l44]L2m1;>l^PBb^[L4/kZg1;Jl]`>h_;L4_/2j1<G6_PC=c<<4dm771=WEb`COf/l3i=kB1>WQ
e0C/hmD4l>GF1?;VePCci=@3ln;@1?;Nc0CaflP4l=O41>oD`0C]d;/4jlbg0n[7/PCX`jd4i[nX1>Bj
X`CQ]Id4g;2G0m>VSPC5VH84/hYd19eiIPB7J5L4LUM915a7?0=5=Bd4<2DP124H50@W81d4<2XW13Pe
<`=0?cd4B4U714mBD@AEFeX4Ff=S165[K0AWLg@Eoooo000Doooo17F3Q@AmS8d4QYBD18jLW0BGY:@3
Wjf/1:Rf]0Bb_kd4_<W71;c7a@Bia<83^<:o1;O0_@Be_[/4/kbh1;:i]PBc^KD4][^f0k^n^0C1`KX4
bLRo1=7>a@CHdlT4gmW=1>GMd0?ZhM<4k^CE1?;VePCfj=L4n>SG1?SVe0?ghm04mMo<1?CKa`Cbf<<4
lMBo1>o@^PC]bkH3jlNa1>W3[0CW_ZH4hkVQ1=jbVPCGZY83bYj61;R?N@BTOf/4SfiL17UNCPAUCD44
CS`b0cHZ90@T71P46Q<@12@O70@^:RL4=SDb0clo?@A6BDL4CE9A15AKFPAKHf<4HF]/16McM1Goool0
01Coool4MH>517f<S@B6U9@4SYbL19NTY0>O[J`4Z;Jd1;:o_@BlbLL4_<O51;W4`P>h`[l4]l2m1;Fn
^`Bc_;P4/[Vf1;>i]@Bf^kH3^kjh1<71^PC9b;l4dLk51=SCb@COfLd4iMg@0n[Qd`C^i=D4l^KF1?KX
e`Chj=L4n>KD0oOSd0Cegl`4m=_71?;H``Cae;l4km2j1>g;]P?[ak44jL>/1>NnYPCS^J44g[:J1=NZ
TP?:WXH4^8mi1:AoJ`B?KU`4NEi>16E=@@A>?383=RXT12@L60@J4a0491lL12hZ9`@f=C83?clm14I9
A`A=DU44E5]J15]SH`AQJf`4Ig=d5Oooo`005?ooo`AePhD4OHb=18JDU0B>W9`4UjBT0in][0BX][@4
/[nm1;c9a`BlalD4^LC20kS2_`Bg`;d4]Kjk1;>l^0Bb^KH4/kVe1;Jk]P>k_[P4`L6j1<W8_`CAc/D4
f=?91=oIc@CUgM03j^7C1>kTe@Cbi]H4m^SG1?SXe`Chi]@3mn?@1?GOc0CdflL4l]S31?7D_`C_d;X4
kL^f0n_7/@CY`j`4ikjV1>>iX@CN/YX4ejZB0lZNQPBhSgT4Y7m[18m^G0AiGTh4IDe114hl<P<f:R@4
91`H11XC40@T7a`4;RXW13He<P<o?cd4ATU714eBD@ADFeX4Ff=S165[K0AWLg@Eoooo000Doooo17F3
Q@AmS8d4QYBD18jLW0BGY:@3Wjf/1:Rf]0Bb_kd4_<W71;c7a@Bia<83^<:o1;O0_@Be_[/4/kbh1;:i
]PBc^KD4][^f0k^n^0C1`KX4bLRo1=7>a@CHdlT4gmW=1>GMd0?ZhM<4k^CE1?;VePCfj=L4n>SG1?SV
e0?ghm04mMo<1?CKa`Cbf<<4lMBo1>o@^PC]bkH3jlNa1>W3[0CW_ZH4hkVQ1=jbVPCGZY83bYj61;R?
N@BTOf/4SfiL17UNCPAUCD44CS`b0cHZ90@T71P46Q<@12@O70@^:RL4=SDb0clo?@A6BDL4CE9A15AK
FPAKHf<4HF]/16McM1Goool001Coool4M8>417b:R`B4TY<4S9ZJ19BQX@>LZJP4Y;6`1:bi]`Bd`;h4
]l:o1;K1_P>e_k`4/kbi1;:k^0Ba^KH4/;Nc1;:h/`Bf^K@3^kff1<;1^@C<b;l4e<o41=_Eb@CTfld4
j^3A0o3Se0Cdi]H4mnSF1?_Ze`Cnj]L4oNOD0o_Sc`ChglX4m][61?CG`PCcdkd4l<ji1>k:/`?[aJh4
j<2X1>BjXPCO]I`4f:bD1<fQR@>lTgd4ZH=_19EcH@AoHU84JU9515A1=P@m<2P3:1lJ11H?30@E3``4
8QhK12`Z:0@e=C<3?Sln14E9B0A=DU44E5YJ15YSH`APJf`4IW=e5Oooo`005?ooo`AdPh@4O8Z;18BB
T`B<VYX4U:6Q0ibYZ0BT/K04[;Vg1;C0_PBg`[l4]/6n0kFo_0Bc_;T4/[^h1;6i]PB`]k<4/[Rc1;Ji
]0>k_KH4`/6i1<c8_`CDcl@4fmG91>CKc@CZh=43l>?D1?CVePCgj=H4nn[G1?kZe`Cmim@3nn??1?SO
bPCff/H4m=O21??C_@C`c[T4k/Zc0n_5[PCX`:P4i;ZR1=neW0CH[9@4cJ690kbCO@BYPfl4UG=Q17mR
DPAZDTD4E44f13d`:0<X7aX45Pl<11D?30@R7Q/4;2XX13De<`<n?ch4ADU814eBD@ADFUX4FV=S161[
K0AVLgDEoooo000Doooo17B3Q0AlRX/4Q9:C18bJVPBDXJ43W:VX1:Ba/0B/^KL4]<2n1;O2_`Bf`Kh3
]Knl1;>l^@Bb^kP4/KVf1;2g/`Bb^;<4][Vd0k^m]PC2`KT4c<Ro1=C?a0CKeLT4i=_=1>[Pd@?`hm@4
m>KF1?OXePCkj]L4o^[G1?gWe0?khll4n=o:1?KJaPCdel84lm>m1?3>^@C^b[<3jlF^1>S0Z0CT^Z84
gkFL1=R/U0C=XHT3_9=m1:V3K`BELf44Of9B16YBA@AD@CH4?C0X0bPO6P@F3``45@l<128N6`@/:RP4
=CDc0cho?PA5BDP4CE9A15AJFPAJHf<4H6]/16IcMAGoool001Coool4M8>417b:R`B4TY<4S9ZJ19BQ
X@>LZJP4Y;6`1:bi]`Bd`;h4]l:o1;K1_P>e_k`4/kbi1;:k^0Ba^KH4/;Nc1;:h/`Bf^K@3^kff1<;1
^@C<b;l4e<o41=_Eb@CTfld4j^3A0o3Se0Cdi]H4mnSF1?_Ze`Cnj]L4oNOD0o_Sc`ChglX4m][61?CG
`PCcdkd4l<ji1>k:/`?[aJh4j<2X1>BjXPCO]I`4f:bD1<fQR@>lTgd4ZH=_19EcH@AoHU84JU9515A1
=P@m<2P3:1lJ11H?30@E3``48QhK12`Z:0@e=C<3?Sln14E9B0A=DU44E5YJ15YSH`APJf`4IW=e5Ooo
o`005?ooo`AdPX@4NhV:18:@T@B9UiL4TIjN0iRUY@BO[:/4Y[>a1:fi]`Bd_kd4/kfk0k:k^0Ba^KH4
/KVe1;2g/PB^]K44/;F`1;>f/0>i^[<4_kjf1<S5^`CAc<04g=?61>OKc0C_h=03lnCD1?OVe@Ckj=D4
on[F1?oXe0CniM03nn7<1?WMa`CgfL<4mMBo1??@^PCacKH4k/R`0nW2ZPCU_:@4h;JM1=R^UPC=Xh/4
_iEo0jf7LPBIMf@4Q6MF16mFB0AIACX4@c@/12dS7P<K5A843`X811LC4@@Q7ad4:bXY13De=0<m?ch4
ADU814aBDPACFe/4FV=T161[K0AVLgDEoooo000Doooo17B2Q0AkRHX4PY2A18VGU`BAWYh3V:FU19n/
Z`BV/k44[KVg1;Bo_@Bc_K/3/[^h1;6i]PBa^KD4/;Nb1:je/@B`]K04/kJ`0kVj/`Bo_[H4b<Fk1=7<
`0CLdlH4im_<1>oPd0?ci=@4mnKE1?_Xe@Coj]H4onSD1?kUd0?khL`4nMg71?OI``Cee;l4lm2j1?7=
]PC^b;03jL:Z1>FlY0CP]Yd4f:jF1<fSR`BoUGl3[HMb19UgI0B4IeH4KeI815U5>PA3=2`4;B<N0a/E
4P@?2PP45a<A124O7@@[:RT4=CDd0cdo?PA5BDP4C59B15=KF`AJHf@4H6]/16IcMAGoool001Coool4
M8:417^9RPB2T944RING196NWP>HYJD4Wjb[1:Jc/@B]^KL4];nm1;>m^`>b^kP4/KVf1;6i]@B`]k84
[[Fa1;2e/0Bc][03^KZc1;nn]PC8aK/4dLc01=cCaPCWfl`4kn3@0o?Te0Cgi]D4nnSE1?oZePCoj=@4
o^G@0o_Qc0CigLL4mmW31?GD_`Ccd;X4lLff1>k8/0?Y`ZX4iKbT1>2fW@CH[YH4cJ>;1;nEO`>]Qg84
VGMT18AWEPA_ETP4FDDj14<d;0@]8ah36aDB10l:20@G4a448AlM12/Z:@@e=C@3?Cln14E9B0A<DU84
De]K15YSI0APJf`4IW=e5Oooo`005?ooo`AdPX@4NhV:18:@T@B9UiL4TIjN0iRUY@BO[:/4Y[>a1:fi
]`Bd_kd4/kfk0k:k^0Ba^KH4/KVe1;2g/PB^]K44/;F`1;>f/0>i^[<4_kjf1<S5^`CAc<04g=?61>OK
c0C_h=03lnCD1?OVe@Ckj=D4on[F1?oXe0CniM03nn7<1?WMa`CgfL<4mMBo1??@^PCacKH4k/R`0nW2
ZPCU_:@4h;JM1=R^UPC=Xh/4_iEo0jf7LPBIMf@4Q6MF16mFB0AIACX4@c@/12dS7P<K5A843`X811LC
4@@Q7ad4:bXY13De=0<m?ch4ADU814aBDPACFe/4FV=T161[K0AVLgDEoooo000Doooo17>2P`AjR8T4
P8j?18NEU@B>Vi/3U:6Q19^XYPBQ[Z`4Z;>a1:nj]`B_^KH3[KNd1:fe/PB/];44[;>_1:^a[@B//J`4
/;>]0kJg/0Bl^k<4`l6g1<g7_0CIcl44hmK61>[Kb`?_gld4m>7>1?SSc`Cki<l4nn;=1?WObP?hflH4
m]S21?CC_@Ccd;T4lLbe1>g7/0CY`ZX3i;^S1=jeW@CF[IH4c:><1;jFP0B^R7D3VgUW18IZF@AbFD/4
G4Pm14Hg;P@`9R047QPD0`h;20@:1`D45aDC128Q7`@/;2/4=CLf0ce1@0A5BTT4C5=C15=KG0AJI6@4
H6a]16IcMAGoool001Coool4Lh:317Z8R@B0SXl4QiFE18jKV`>DXJ44VjRV1:6^[0BX/k44[kZg1:ni
]P>]]k@4[KFb1:bd/@B//jl4Zk6]1:ba[0B`/jd3][N`1;bk/`C3`KL4cLNl1=W?`@CSe/H4j]_;0noO
c@CdhLh4n>??1?_Tc`Ckh/d4nMo:0oSKaPCff<84m=>m1??@^@Cac;D4kLN`1>W2ZP?T^j<4g[FM1=J]
UPC<Xh`4_YJ01:j8M@>KNFL4QVYI179IB`ALB3d4ASL^130V80@N61@33P/810X71@@G5A<48R4O12`/
:`@e=cH3?D5014E:B@A<De<4De]L15YTI0APK6d4IW=e5Oooo`005?ooo`AcPX<4NXR9182>S`B7UID4
SY^K0iBQX@BKZ:H4XJj/1:Rc/@B_^[L4[kVf0jfg]0B]]K84[;Ba1:bc[`B[/Jd4[;6/1;2c[@>f]k04
_;^c1<?1]`C=ak`4fLo11>?FaPCZfl/3kmo=1?CQcPChhll4nnC?1?_Rc@CiglX3n=_61?KH`PCddkd4
lm2i1?7<]@C]ak04jL:Z0nBkX`CN]Id4eZfF1<bSS0BnUX04[XQe0i]iI`B6JUT4LUU;15a8?@A6=bh4
<2HP11hH50<>2`P42PL511LE4`@R8Al4;2`[13Dg=P<m@D04ADY914aCD`ACFe`4FVAT161/K@AVLgDE
oooo000Doooo17>1PPAiQhP4Ohf=18FBT`B;V9P3TIjM19JSXPBLZ:L4XZf/1:Nb/0B[]K<3ZK>`1:Va
[PBX/:`4YjjZ1:F/Z0BY[JP4[[6[0kBe[PBk^[44`Kne1<W4^@CCb[d4flo01>;C``?VeL@4k=S61>oI
aPCbf/H4l]S41?7F`P?adkh4km2j1>g<]PC[b;84j<B]1>BoZ0CO^J83fK:K1=6ZU0C8XH/4_9J11:f9
MPBLNfX3R6aL17ALCPAOBd04BCXa138Y8P@O6AH440`:0`@20@@;2@P461LF12<S8P@];Rh4=STh0ci2
@PA6Bd/4CEAD15ALG@AJI6D4H6a]16IdMAGoool001Coool4Lh6217V7R0AoSHd4QI:C18^HV0>AWYd4
UZ>R19bXY`BR[J`4Yk:`1:^e/`>Y/k04ZK6^1:R`[0BW[ZX4YJbX1:V]Z0B^/J/3];F^1;^j/@C1_kD4
bLBi1=?:_@CKcl04h]?30nKEa0C/f<H4kmW61?;JaPCbf<@4lMK20o7C_PC_d;X4kLbf1>_8/PCXa:d4
i;nX1=niXP?I/Y/4dJZD1<RQR`BlUX44[HUf19akJP>8K5`4M5a>15m;@0A9>S44<RTR11lI5P@@30X3
108110/920@H5aH48b<R12d^;P@f>CP3?T9214I;B`A=E5@4E5aM15YTI@APK6d4IWAe5Oooo`005?oo
o`AcPH84NHN817n=S@B5TY<4RiRH0i6NW@BFXj84W:RW1::][0BW/[04ZkFc0jVc/0BY/Jh4Z;2/1:N^
ZPBU[:P4ZJfX1:jaZ`>d]Jh4^kZa1<6o]@C9a;T4dlZm1=_?`0CRdl<3i]G41>cHaPC_fLH4l][61?;H
a0Cae/83lM>n1>o@^PC]c;H4jlRb1>S4[@CT_jP4gkVR0mVbV`CAZY@4b:6;1;bFP@B]RGH4W7]Z0hQ/
G0AdG4h4Gd]014Tj<@@b:B847aTF110<2P<40P442`T811PG5P@S8b84;Bh^13Hi>0<n@T84AT];14eD
E0ADG5d4FVAU161/K@AVM7DEoooo000Doooo17>1PPAiQhP4Ohf=18FBT`B;V9P3TIjM19JSXPBLZ:L4
XZf/1:Nb/0B[]K<3ZK>`1:Va[PBX/:`4YjjZ1:F/Z0BY[JP4[[6[0kBe[PBk^[44`Kne1<W4^@CCb[d4
flo01>;C``?VeL@4k=S61>oIaPCbf/H4l]S41?7F`P?adkh4km2j1>g<]PC[b;84j<B]1>BoZ0CO^J83
fK:K1=6ZU0C8XH/4_9J11:f9MPBLNfX3R6aL17ALCPAOBd04BCXa138Y8P@O6AH440`:0`@20@@;2@P4
61LF12<S8P@];Rh4=STh0ci2@PA6Bd/4CEAD15ALG@AJI6D4H6a]16IdMAGoool001Coool4LX2217R6
Q`AmRh`4PY2@18REU@>=VYX4TYnN19NSXPBLZ:H4X:bZ1:F_[@>U[Z`4Y:fZ1:>[Z0BSZZH4XjVU1:N[
YPB[[ZP3/K:[1;Je[@Bl^Jl4a;jb1<g3]@CCa[P4elVj0m[;^PCPc[`4h/jl1>C?_0CUc[/4iL^h0n?8
]0CPa;04gKn[1=^kY`CI^:84e;:M1<j/U`?6Y8l4_Yb81;BBO`BXQgH4V7YZ18I/G@=cGE04H4i314/m
=@@e;2H481/H114>30@200030`82110@3`@K71/49BLW12la<@@g>c/3?dA414M=C@A>EEH4E5eN15YU
IPAQKFh4IgAe5Oooo`005?ooo`AbP884N8J717f;S0B2T904R9FE0hfJVPBBWih4Uj>R19bXYPBP[:X4
YJn]0jF^[0BT[JX4Xj^X1:>ZYPBSZJD4Yj^V1:^^Z0>a/Z/4][F]1;bi[`C4_[84cL>e1=?6^0CGbKX3
f/^j1>3>_0CRc[`4i<nl1>G>^`CUbkP3hlRd1>34/0CM_j/4fk^W1=VhXPCD/Yd4cZbG0lJTS`BnW8P4
]99o1:R7MPBHNVX4QVaM0g=MD0APCT<4Bcde13D/9P@P6aP44@h<108000<30P84410?11/L6`@U9bL4
;c4a13Lk>`<oA4@4Ade=14iEEPADGEh4FVEV165]KPAWM7DEoooo000Doooo17:0PPAhQXL4OH^<18:@
T0B8UID3SIZJ19:OWPBGXj84W:RV1:2/ZPBU[jd3YJj/1:B]ZPBSZjP4XjZV1:>YY@BWZjH4ZjjX0k6b
Z`Bf]Jd4_;V_1<Bn/PC=`kD4dlJh1=O9^P?JbkX4h<jl1>;>_0CTck`4iLjk1>G;^0?Sb;@4h<B`1=fo
Z`CK^jL4fKRR1=BbW@C>[9L3aZB?1;jLR0BdTWl4Z8Mf19QjJPB6K5d3Lee@161>@`A;?CD4=B`V120K
60@A3P`40P000`<20P@@40l46a`K12DW9`@_<C44=c/k0cm4A0A7CDd4CUEF15AMGPAJIFH4HFe^16Md
MAGoool001Coool4LX2217R6Q`AmRh`4PY2@18REU@>=VYX4TYnN19NSXPBLZ:H4X:bZ1:F_[@>U[Z`4
Y:fZ1:>[Z0BSZZH4XjVU1:N[YPB[[ZP3/K:[1;Je[@Bl^Jl4a;jb1<g3]@CCa[P4elVj0m[;^PCPc[`4
h/jl1>C?_0CUc[/4iL^h0n?8]0CPa;04gKn[1=^kY`CI^:84e;:M1<j/U`?6Y8l4_Yb81;BBO`BXQgH4
V7YZ18I/G@=cGE04H4i314/m=@@e;2H481/H114>30@200030`82110@3`@K71/49BLW12la<@@g>c/3
?dA414M=C@A>EEH4E5eN15YUIPAQKFh4IgAe5Oooo`005?ooo`AaP844MXF617^9RPB0SXh4QI:B0hZG
UPB>ViX4TYnN19NRX@BKYZ@4WjZW0j6[Z@BOZ:D4WZJS19nVXPBPYZ84XZNR1:FXXP>[[:H4/;2X1;Jd
Z`Bo^Jd4a;^_1<Rn/0C=`;43d<:b1=C4/`CE`k<4e/>b1=O1/0CF_Zd3dk^Y1<ngY@C</Z04bZjL1<JZ
U`C1Y944^Yf;0k:EQ0B[SWd4X8Ad19=iJPB3K5h4LUiB0f1?A@A<?cP4=blZ128N6`@A40h40P411000
00<;30/45AHF11lQ8@@Y;2/4<CDe13Tn?P=1AdL4B4m@14mGF0AEGel4FfIW165]KPAWM7HEoooo000D
oooo1760P@AfQHH4NhV:182>SPB5TY83RYNF18jKVPBBWih4Uj:Q19^VY0BOZZL3XJ^Y19nXY@BNYZ<4
WjJR1:2VXPBRYj84YJRR0j^/YPB`/:P4][B[1;ni[@C4^jl4b;j`1<g0/@?@`[84e<Bc1=G3/`CF`k84
el6`1=Jn[@?C^jT4ckNU1<bbX0C:[Y`4aZZG1<6TT@BjWH/3/YF41:^>O@BPQ7@4TgUZ18=/GPAbGU83
H4m514`o>0@g;bX48QhK114@3P@20@4400000`/<2`@E5QH47b4Q12T/:`@a=CD4>Chn0d57A`A8Ce04
CeMH15EOG`AKIVL4HFe^16MdMQGoool001Coool4LH2117J5QPAkRHX4P8j>18FBTP>:UiH4SY^J19:O
WPBGXZ44VjJT19nZY`>QZjT4WjRU19jVX`BOYZ84X:JR1::WXPBUZ:83ZjbV1;2`Z0Bf]:/4_kV]1<Bk
[`C8_[04cL2a0m32/PCDa;<4eL>c1=K3/PCG`K04e[j]0m>kZ@C?]jD4c;:P1<Z^W0C6ZYL4`JBA1;ZM
R`>bUH@4Zhim1:24M0BCNFX4PfaN179NDP=PCdD4C3lh13L_:P@R7Q/44A0>10810@@000032``;11DF
5P@O8B44:B`[134e=@@i?Sh3@DM714Q?D0A?EeP4EEmO15]VI`AQKFh4IgAf5Oooo`005?ooo`AaP844
MXF617^9RPB0SXh4QI:B0hZGUPB>ViX4TYnN19NRX@BKYZ@4WjZW0j6[Z@BOZ:D4WZJS19nVXPBPYZ84
XZNR1:FXXP>[[:H4/;2X1;JdZ`Bo^Jd4a;^_1<Rn/0C=`;43d<:b1=C4/`CE`k<4e/>b1=O1/0CF_Zd3
dk^Y1<ngY@C</Z04bZjL1<JZU`C1Y944^Yf;0k:EQ0B[SWd4X8Ad19=iJPB3K5h4LUiB0f1?A@A<?cP4
=blZ128N6`@A40h40P41100000<;30/45AHF11lQ8@@Y;2/4<CDe13Tn?P=1AdL4B4m@14mGF0AEGel4
FfIW165]KPAWM7HEoooo000Doooo175oP@AeQ8D4NXR817j<S0B2T903QY>C18ZGUPB>VYT4TIfL19FP
WPBGXZ43VjFS19VRW`BHXIh4VJ2M19ZPW0BLXI`4X:>N0jFWX@BZZZ<4[jfT1;J`YPBi/ZH4_KBX1<6f
Z@?3]jX4a[RY1<NhZ@C8]jL4a[BU1<BaX@?1[Yh4_JVI1;ZUU@BfX904/I^;1:^DQ@BTSGh3WHMh19Io
L@B;MVP4OVYN16mND`AND4L3Bd4j13Pb;@@W8b045ADC10@410@000042@X:0a8D50@K7Qh492LW12da
<@@e>SX4?4920d=:BPA:DU84D5UJ15IPH@ALIfP4HVi_16MeMQGoool001Coool4LGn117F4Q@AjR8P4
OXb<18:@T0>6Ti<4RYNF18jJV@BAWI`4UJ2N19NRX@>KYJ<4VJ:O19RQWPBIX9d4VZ2L19bQW0BPXih3
YJNQ1:ZZX`B_[J@4][2V1;VbYPBm]:P4`KJY0l>gZPC6^:T4akRY1<RgY`C6]:D4a;6Q0l6^WPBmZIT4
^ZFE1;JPT0BaVh/4ZiB51:B=OP>MQgP4UWma18]fJ0AnJUh4KeiC15i@A`=;@CX4>38]12LS80@E5A<4
10@4100000@92PX34Q@D11/N7P@T9bL4;C4a13Dj>P@l@T83@dY:14YBDPA@FEX4EV1Q15aWJ0ARKVl4
IgEf5Oooo`005?ooo`AaOh44MHB517Z8R0AnS8`4PY2@0hJCT`B:UiH4SYZI196MW0BEX9h4Uj:Q0i^U
X`BIXYl4V:6N19VPW@BJX9`4W:6L1:2SWP>UYj44ZZZS1:n]Y0Bf/:H4^K:V1;fdZ0C1]ZT3`kNZ1<Jh
Z@C7^:T4b;NW1<JdY@C4/J43`JjN1;fYV@BjYID4]Z2@1;6KR`B[U8D4Y8en0if7N0BFOg44RgIX17iZ
GPA_GU<4GU170d]1>P@h<Rd49b<P11DE4`@410@4000010T:2P<B51@46ahN12@W9`@]<C44=CXj13a2
@P=3BTX4BU9B151IFPAFH644G6MX169^K`AWMGHEoooo000Doooo175oP@AeQ8D4NXR817j<S0B2T903
QY>C18ZGUPB>VYT4TIfL19FPWPBGXZ43VjFS19VRW`BHXIh4VJ2M19ZPW0BLXI`4X:>N0jFWX@BZZZ<4
[jfT1;J`YPBi/ZH4_KBX1<6fZ@?3]jX4a[RY1<NhZ@C8]jL4a[BU1<BaX@?1[Yh4_JVI1;ZUU@BfX904
/I^;1:^DQ@BTSGh3WHMh19IoL@B;MVP4OVYN16mND`AND4L3Bd4j13Pb;@@W8b045ADC10@410@00004
2@X:0a8D50@K7Qh492LW12da<@@e>SX4?4920d=:BPA:DU84D5UJ15IPH@ALIfP4HVi_16MeMQGoool0
01Coool4L7n017B3Q0AhQXL4O8Z:182=S@>3T904QY>C18ZFU@B<V9L4SiZI1i6KVPBAVYT4TYZH29>J
U`BEViL4UibG0ibOV@BPXY/4Y:BL1:ZVW@B]Z9h4/JZO1;>[X0>e[:04]j^O1;NZWPBfZI`4]:NI1;:T
UP>_X9<4ZYb>1:JGRPBPTH@4W8ao19F5N@B?Og<3RGU]185aI`AfIeh4IeaC15Q?B0A8@S`3>3@`12LV
90@F61L41`X;10010P@82PX44A<C0aTL70@Q9BD4:Bh^134f=P@h?Sl4?dI70dI>CPA<EED4DUaL15QR
H`AMJFX4HVm`16MeMaGoool001Coool4L7n017B3Q0AhQXL4O8Z:182=S@>3T904QY>C18ZFU@B<V9L4
SiZI1i6KVPBAVYT4TYZH29>JU`BEViL4UibG0ibOV@BPXY/4Y:BL1:ZVW@B]Z9h4/JZO1;>[X0>e[:04
]j^O1;NZWPBfZI`4]:NI1;:TUP>_X9<4ZYb>1:JGRPBPTH@4W8ao19F5N@B?Og<3RGU]185aI`AfIeh4
IeaC15Q?B0A8@S`3>3@`12LV90@F61L41`X;10010P@82PX44A<C0aTL70@Q9BD4:Bh^134f=P@h?Sl4
?dI70dI>CPA<EED4DUaL15QRH`AMJFX4HVm`16MeMaGoool001Coool4L7n017B3Q0AhQXL4O8Z:182=
S@>3T904QY>C18ZFU@B<V9L4SiZI1i6KVPBAVYT4TYZH29>JU`BEViL4UibG0ibOV@BPXY/4Y:BL1:ZV
W@B]Z9h4/JZO1;>[X0>e[:04]j^O1;NZWPBfZI`4]:NI1;:TUP>_X9<4ZYb>1:JGRPBPTH@4W8ao19F5
N@B?Og<3RGU]185aI`AfIeh4IeaC15Q?B0A8@S`3>3@`12LV90@F61L41`X;10010P@82PX44A<C0aTL
70@Q9BD4:Bh^134f=P@h?Sl4?dI70dI>CPA<EED4DUaL15QRH`AMJFX4HVm`16MeMaGoool001Coool4
L7j017>2P`AgQHH4NXR817f;R`>0SHd4Pi2@18JBTPB8U9<4RYFD18^FU@>;UY@4RiBC18ZDTPB;Ti44
S9BA18fDT@B?UI43TYNB19JHT`BIVI<4WIbD19nMU0BQWYD4XijE0jFNU0BTWI<4Y9fB1:BLT@BRVXl4
X9N<0ifCR0BHSh@4ThUo18j4N@B8OG84OgI]17]bJ@=fKF@4K6AL161ID`ADCTT4AT<n13Lf<`<X:BP4
6QdL10d@40@31@D41PL7110B4`@H71`382@U12P/;@@_=3D4=S`m13e3A0A3Bd/3BE5B14mHF@ADGUl4
FFAU15iZJ`ASL744J7Ig5Oooo`005?ooo`A`OX04Lh:317N5QPAjR8P4OH^;0h2=S@B3T904QY:B18RD
T`B:UI@4RiJE0h^FU0B;U9<4RYBB18^CT@B<U944SIBA18nET@>BUi84UYRC19VIT`BMW9@4WifD1:6N
U@BSWYD3YIjD1:BMT`BTWI84Y9bA1::JS`BPUh`3WI>819R?Q0BCRGl4SXAi18QmLPAoMVd4Ng9Y0gI]
I0A/I5`4H5UC15A>B@A6@ch4=cHc0bPY:0@J7A`43A0@10<51@@61`L4418C11PL70<P92D4:2`]12ld
=@@f?3d4?D=414=;B`=9DE84CeQI15ANG`AII6D4GVY[16=`L@AXMWLEoooo000Doooo171nP0AcPX<4
MhF617Z8R0AmRh/3P8f=18>@T0B6TY84R9BC18ZEU0B;UYD3RiJD18^DT`B:U984Ri>A18bDT@B=U944
SiFA0i:GTPBFV9<4VIVC19fLU0BOWI@4XIjE1:>NU@>UWY@4Y9fC1:BMTPBTW944XYZ?1:2GS0>MThP4
V8n419>9O`B>Q7T4R7eb17mfK@AkLVT3MVeT16aTG0APFE<4E4i914I3?P@g=S<3:2TX11XM70@=4104
0`D510H71`@@4Q<461`L0b0T9@@X;2d4;c@e13Hl?@@m@d@4@d];0dUADPA?F5T4E5iO15UTI@ANJV/4
Hg1a16QfMaGoool001Coool4L7j017>2P`AgQHH4NXR817f;R`>0SHd4Pi2@18JBTPB8U9<4RYFD18^F
U@>;UY@4RiBC18ZDTPB;Ti44S9BA18fDT@B?UI43TYNB19JHT`BIVI<4WIbD19nMU0BQWYD4XijE0jFN
U0BTWI<4Y9fB1:BLT@BRVXl4X9N<0ifCR0BHSh@4ThUo18j4N@B8OG84OgI]17]bJ@=fKF@4K6AL161I
D`ADCTT4AT<n13Lf<`<X:BP46QdL10d@40@31@D41PL7110B4`@H71`382@U12P/;@@_=3D4=S`m13e3
A0A3Bd/3BE5B14mHF@ADGUl4FFAU15iZJ`ASL744J7Ig5Oooo`005?ooo`A_OWl4LX6217F3Q0AhQXL4
NhR90gf;R`B0SHd4PXj>18B@S`B5TI07QY6@18J@S`B4SXd8Q8f;18J>R`B8SX/3RHj:18^?RPB<T8/4
T96;196AR`BBTHX4U9::0iBAR@RDTHP4Thn6196<Q0B>RX43RhIn18N2NPB2OWH4O7M`17IbJ`AaKVP4
K6QS0fEQG0AJF5<4DDm;14I5@P@h>CL4:Rd/0adQ8@@A5QH41PX:10L:2P@A51@46A`M124U9@<X;Bd4
;c@e13Dk?0@k@T<4@DU:14M?D0=<EEH4DE]L15IQHPAKIVP4Gfa]16AaLPAXMWPEoooo000Doooo16mn
O`AbPH84MH>417R6Q`AkR8T3OH^;182=S@B2SXh4Q92?18FAT0N6TI04QY2?18B>S@R4SH/4QXj;18R>
R`>9SXX4Rhn:18b@R`B@TH/4TI6;19:ARPBDTXX3U96929BAR0BCShH4THb418j:P@>;QWh4Qh9j189n
MPAlMg04MW9[175^J0A/J6<3IF5L15YHD`AACd/4ATE213Pi=`@Z;B`37B4Q114F5P@62PX41`X:114D
50@I71d48BDU0bP];@@_=3D4=C/l13]2@`A1BDX4Adm@0daEEPAAFe`4EV5R15]VJ0AOK6d4I75b16Qf
N1Goool001Coool4Kgio17:1PPAePh@4N8J717^8R@=mRh/4P8f=18:>SPB4T8l4QI6@1hJAT0B6T8l4
Q8j=28B=R`B6SX/4R8j;0hV>RPB;ShX4S92;192AR`BATH/4TY6:19BBRP>DTHT8U96819>?QPBAS8@4
SXZ10h^6OPB7PWX4PWif17agL0AfLV/4LFiX16aXH`=UHE`4FUQC155?B`A6AD84>3Tg12X];0<M8B44
4AHF10H:2P@72PX44A@D11TL7@@Q9BD3:2d]12ld=@@e>c`4>d931459BPA7Ce03C5EF155KG0AFHF84
FfIX15m/K@ATLG84J7Ih5Oooo`005?ooo`A_OWl4LX6217F3Q0AhQXL4NhR90gf;R`B0SHd4PXj>18B@
S`B5TI07QY6@18J@S`B4SXd8Q8f;18J>R`B8SX/3RHj:18^?RPB<T8/4T96;196AR`BBTHX4U9::0iBA
R@RDTHP4Thn6196<Q0B>RX43RhIn18N2NPB2OWH4O7M`17IbJ`AaKVP4K6QS0fEQG0AJF5<4DDm;14I5
@P@h>CL4:Rd/0adQ8@@A5QH41PX:10L:2P@A51@46A`M124U9@<X;Bd4;c@e13Dk?0@k@T<4@DU:14M?
D0=<EEH4DE]L15IQHPAKIVP4Gfa]16AaLPAXMWPEoooo000Doooo16mnO`AbP844M8:317J4Q@AiQXL3
NhR917f:RPAnRh/4P8b<286=S@>2SH`4PHb;182;R@AoRHP4OhR617j7Q@AnQX<3OhJ31867PPB2QX84
Q8N218>6P@B2QGl4PXAo0h:4OPB3Q7h4PhAm18:2N`B0P7X4OWig0gYjM0AgMg44LW9^16i_JPAZJfL4
IFIS16ATH0=MG5T4De=A14U:B0@l?cd4;C8b124W9`<D6a`4318B10/?40@D5aP46alP128W:0@Y;bl3
;cHf13Hl?@@k@d<4@DU:14I?C`A;E5D3D5YK15AOH0AII6D4GFUZ165]K`AULW@4JGMh5Oooo`005?oo
o`A_OWl4LX2117B2P`AfQ8D4NHJ70g^8R@AmRXX4OX^;182<S0R1SHd3PXf<186<R`B0RhT4OhV817n8
QPAnQhD4OXJ30gn6P`B1Qh84PXJ218B7PPB3QX44PXEo18:4O`>2Q7h4PhAn18>4O@B2PW/4P81j17in
M`=jNW@4MgMa179bKPA^KfX4JV]W16EVH`ATI603GEaI15=CD@A9BTP4?3lm12db<P@Q9bL351/L10`B
4P@;3a0451LH11/O80@R9bP4:Bl_0blf=P@f?3d4>d=31459BPA6Cdl4BeAE0e1JF`ADGf04FFAU15eY
JPAQKFl4IG9d16UgN1Goool001Coool4Kgio17:0P@AdPX<4MXB517V6Q`=kR8T4OHZ:17j;R`B0S8`8
PHf=0h:=S0B1S8/4P8^917n9R0AoR8H4OXN517j6P`=oQX<4PHN218:6PPB4Qh84PhJ118:5O`B2Q7l3
PXAn18>4OPB3Q7d4PX9k1820NPAnOWL3NWYd17MgL@AbLVh4KVmZ16Y[I`AUIV<4I6AP0eeLF@ACDe44
BDY813`o?@@]<S848BLW0a@K70@<4Q842`l@11@G60@K7b048RLX12T_;`<_=SH4=S`m13]3@`A1BDX4
ATm?14]DE@=@FU/4E5mP15UTI@AMJFX4HFe_16EbM0AYMgPEoooo000Doooo16mnO`AbP844M8:317J4
Q@AiQXL3NhR917f:RPAnRh/4P8b<286=S@>2SH`4PHb;182;R@AoRHP4OhR617j7Q@AnQX<3OhJ31867
PPB2QX84Q8N218>6P@B2QGl4PXAo0h:4OPB3Q7h4PhAm18:2N`B0P7X4OWig0gYjM0AgMg44LW9^16i_
JPAZJfL4IFIS16ATH0=MG5T4De=A14U:B0@l?cd4;C8b124W9`<D6a`4318B10/?40@D5aP46alP128W
:0@Y;bl3;cHf13Hl?@@k@d<4@DU:14I?C`A;E5D3D5YK15AOH0AII6D4GFUZ165]K`AULW@4JGMh5Ooo
o`005?ooo`A_OGl4LGn017>1PPAePh@4MhB50gR6Q`AjQhP4NhR917b9R@AmRXX4OXZ90gj9R@AmR8P4
O8N617^5Q0AiPh84N81o17R0OP=gOg`4Mgik17MnNPAhOWT4Mgah17IkM`AfNgH3M7Ue27AhL`AcMg84
L7E`16ibKP=[Kf`4J6eZ16AYIPARIf@4G65P15YOG@AFFeT3CE=B14E:BP@j@D44;SHg12D/;@@I8R<3
4ALH118G5`@H7Ah482DV12H/;@@/<c<4<STj0cPo@0@mADH4@TY;14M@D0A;EEH4CeUJ0e=NG`AGHf@4
FfMX15m[K0ARKg44IW=e16UgNAGoool001Coool4Kgeo175oP0AcPH84MH>417N4Q@=hQXL4NXN817^8
R@AlRHT4OHZ:17j:R@=nRHT4OHR817b7QPAkQH@4NH>217R0O`AhP7h3Mgml17MnN`AgOWX4N7ii17Ml
N0AfNgL4MW]f0gAiM@QdN7<4LgMb171eL0A^LVh3Jfm/16Q]JPATJFH4HVMT15aQH0AJGed4EU]I0deC
DPA5BTX4>T5112hf=`@U;2d46B8S0a4G60@B5aL461dN120U9P@V;2d4;3<c138i>P<h?d04?DE6149:
B`A7D504BeEF14mIFP=CGUl4Ef=T15]WJ0AOJf`4HVma16IcM@AYMgTEoooo000Doooo16mmO`AaOh04
Lh6217F3Q0AgQ8D3N8J717Z7R0AkR8T4O8V917f:RPAnRXT3OXV917f8R0AlQhH4NhF417V3PPAhP7l4
N81n0gMoO0AgOW/4Mgij17QnN@AgO7P4MW]g17IkMP=dNGD8M7Qc17=gLPA`MG04KW9^0f]_K0AXKFX4
I6UV169WI0ALHF04FUmM15IKF@==De84ADY:13Y1@@@^=SL49B`]11TR8`<A5aP44QLG11PM7P@P9BH4
9R`]12`c<`@b>CX3>3m013e5APA2BT/4Ae1@14]EEPA?FEX3DeiO15MSI0AKIfP4Gf]/169_L@AVLgD4
JGMi5Oooo`005?ooo`A_OGl4LGn017>1PPAePh@4MhB50gR6Q`AjQhP4NhR917b9R@AmRXX4OXZ90gj9
R@AmR8P4O8N617^5Q0AiPh84N81o17R0OP=gOg`4Mgik17MnNPAhOWT4Mgah17IkM`AfNgH3M7Ue27Ah
L`AcMg84L7E`16ibKP=[Kf`4J6eZ16AYIPARIf@4G65P15YOG@AFFeT3CE=B14E:BP@j@D44;SHg12D/
;@@I8R<34ALH118G5`@H7Ah482DV12H/;@@/<c<4<STj0cPo@0@mADH4@TY;14M@D0A;EEH4CeUJ0e=N
G`AGHf@4FfMX15m[K0ARKg44IW=e16UgNAGoool001Coool4KWen171nP0AbP844Lh6217F3Q0=fQ8D4
MhF617R6QPAiQXL8NXN70gZ6QPAjQHD4NHB417N2PPAfP7l4LWak16egM@=^MgD4KgQe171hM@A_MW84
K7=`16Q`K@AWKf`3J71/16U_K0AUKFX8HV]Y169[J0=PJFL4GVIU15]TI0AJHV84E5eM159KF`A<EEH3
ATi?13i6A`@d?Ch4:S@f12@];P@I8B836R0Q124W:0@V;Bh4;3<d134i>P@f?Sl4>dA50d19BPA4CDl4
BE9C14eFF0A@Fe`4E5mP0eMSI0AKIVP4GVY[165^K`ATLG<4IgEf16YhNQGoool001Coool4KWen171n
P0AbP844Lh6217F3Q0=fQ8D4MhF617R6QPAiQXL8NXN70gZ6QPAjQHD4NHB417N2PPAfP7l4LWak16eg
M@=^MgD4KgQe171hM@A_MW84K7=`16Q`K@AWKf`3J71/16U_K0AUKFX8HV]Y169[J0=PJFL4GVIU15]T
I0AJHV84E5eM159KF`A<EEH3ATi?13i6A`@d?Ch4:S@f12@];P@I8B836R0Q124W:0@V;Bh4;3<d134i
>P@f?Sl4>dA50d19BPA4CDl4BE9C14eFF0A@Fe`4E5mP0eMSI0AKIVP4GVY[165^K`ATLG<4IgEf16Yh
NQGoool001Coool4KWen171nP0AbP844Lh6217F3Q0=fQ8D4MhF617R6QPAiQXL8NXN70gZ6QPAjQHD4
NHB417N2PPAfP7l4LWak16egM@=^MgD4KgQe171hM@A_MW84K7=`16Q`K@AWKf`3J71/16U_K0AUKFX8
HV]Y169[J0=PJFL4GVIU15]TI0AJHV84E5eM159KF`A<EEH3ATi?13i6A`@d?Ch4:S@f12@];P@I8B83
6R0Q124W:0@V;Bh4;3<d134i>P@f?Sl4>dA50d19BPA4CDl4BE9C14eFF0A@Fe`4E5mP0eMSI0AKIVP4
GVY[165^K`ATLG<4IgEf16YhNQGoool001Coool4KWen171nP0AbP844Lh6217F3Q0=fQ8D4MhF617R6
QPAiQXL8NXN70gZ6QPAjQHD4NHB417N2PPAfP7l4LWak16egM@=^MgD4KgQe171hM@A_MW84K7=`16Q`
K@AWKf`3J71/16U_K0AUKFX8HV]Y169[J0=PJFL4GVIU15]TI0AJHV84E5eM159KF`A<EEH3ATi?13i6
A`@d?Ch4:S@f12@];P@I8B836R0Q124W:0@V;Bh4;3<d134i>P@f?Sl4>dA50d19BPA4CDl4BE9C14eF
F0A@Fe`4E5mP0eMSI0AKIVP4GVY[165^K`ATLG<4IgEf16YhNQGoool001Coool4KWen16mnO`AaOh04
LX2117>1PP=dPX<4MH>417J3Q0AfQ8@8MhB40gN3Q0AfPh<4MX:217B0P0AcOWd4L7]j16egMP=YLg84
J79`16I`KPAUKV`4Hfe[169[J@AQJfT3H6YX15iXI`AMJ6L4GVUY15mZJ@ALIfL3FfIW15YUIPAHHfD4
E5mP155LG@A=F5X4B59D0d5;C@@j@d@4<cdn12de=P@V;Bh48bX/0bXb<`@_=cP4=3`m13U1@P@mATL4
@DY;14E>D0=9DU@4C5IH151JF`ACGUl4EV5R15UTIP=KIfT4GVY/165]K`ASL784IW=e16QfM`AZNGXE
oooo000Doooo16imOPA_OWl4LGn017:0P@AcPH83M8:317F3Q0AfPh@4MXB427N4Q0=gPh@4MX>317J2
PPAdP804Lgim171kNPA]MgH3JG=b16QbL0AVL6h4IFi/16=]J`ARJfT4HF]Y0f1ZJ0ANJ6L4GFQW15iY
J@AOJVT4G6MW0e]VI`AJIFH4F6=U15AOH0AAG5d4CEQJ14QBE0=1Bdd4>T=413<m?P@]=CH49Rd^12<Z
;0<Z<S<4;cLh13@l?@@i@D84?DI7145:B`A5CU03BE9D14aFF0A@FU/4DeiO15IQHPAII6H3FfMY15iZ
K0AQKFl4Hg1b16IcM@AXMWL4JWUj5Oooo`005?ooo`A^OGh4Kgio175oP0AbP844Lh620gB2P`AePh@4
MX>417J4Q0QgQ8@3Mh>417J3P`AfPX84M82017=nO@A`NgX4KGMf0fUcLPAXLW04IW1^16E^K0ASKF/4
HV]Y165[J@=PJVP4GVQW15eXI`ANJFT4GfYY15aWI`=KIVL4FVEV15QSI@ADGf04DEaM14eHFPA8DU@3
@D]=13Y3A0@c?Ch4;CDf12H];P@S:R`3:S8c12lg>0@d?3d4>D5213e6A`A1BT/4ADi@0dUBE0A<EUP4
D5YK15=NG`AFHF84FFAV0e]WJ@ANJV`4HFe_16=`LPAVLgD4J7Ig16YiNQGoool001Coool4KWan16mm
O`A_OWl4L7n0175oP@=bP848Lh623gB1PPAdPH44Lh20179nO`AaOGd4KgYj16ahN0=YMG@4IG1`15iY
J@ALIfH4GFUX15eXJ0AKIVD3FVMV15]WI`QLJ6P4FfMW15UUIP=HI6D4EF5S15=PHPAAGEl4CU]M14]G
F@A8DE<3@de>13]4A@@e?Sl4<SXk138j?0@g@443>dA513i8B@A2C4d4ADmA14UCE0A<EUP4CeUK0e5L
GPADGf44Ef9T15UUIPAKIfT4GVY[0f1/KPARKg04I75b16EcM@AWMGL4JGMi16]iNaGoool001Coool4
KWan16mmO`A_OWl4L7n0175oP@=bP848Lh623gB1PPAdPH44Lh20179nO`AaOGd4KgYj16ahN0=YMG@4
IG1`15iYJ@ALIfH4GFUX15eXJ0AKIVD3FVMV15]WI`QLJ6P4FfMW15UUIP=HI6D4EF5S15=PHPAAGEl4
CU]M14]GF@A8DE<3@de>13]4A@@e?Sl4<SXk138j?0@g@443>dA513i8B@A2C4d4ADmA14UCE0A<EUP4
CeUK0e5LGPADGf44Ef9T15UUIPAKIfT4GVY[0f1/KPARKg04I75b16EcM@AWMGL4JGMi16]iNaGoool0
01Coool4KWan16mmO`A_OWl4L7n0175oP@=bP848Lh623gB1PPAdPH44Lh20179nO`AaOGd4KgYj16ah
N0=YMG@4IG1`15iYJ@ALIfH4GFUX15eXJ0AKIVD3FVMV15]WI`QLJ6P4FfMW15UUIP=HI6D4EF5S15=P
HPAAGEl4CU]M14]GF@A8DE<3@de>13]4A@@e?Sl4<SXk138j?0@g@443>dA513i8B@A2C4d4ADmA14UC
E0A<EUP4CeUK0e5LGPADGf44Ef9T15UUIPAKIfT4GVY[0f1/KPARKg04I75b16EcM@AWMGL4JGMi16]i
NaGoool001Coool4KWan16mmO`A_OWl4L7n0175oP@=bP848Lh623gB1PPAdPH44Lh20179nO`AaOGd4
KgYj16ahN0=YMG@4IG1`15iYJ@ALIfH4GFUX15eXJ0AKIVD3FVMV15]WI`QLJ6P4FfMW15UUIP=HI6D4
EF5S15=PHPAAGEl4CU]M14]GF@A8DE<3@de>13]4A@@e?Sl4<SXk138j?0@g@443>dA513i8B@A2C4d4
ADmA14UCE0A<EUP4CeUK0e5LGPADGf44Ef9T15UUIPAKIfT4GVY[0f1/KPARKg04I75b16EcM@AWMGL4
JGMi16]iNaGoool001Coool4KG]m16ilOPA^OGh4Kgeo171nO`=`OX0GLGn0175oO`AaOWl4L7en16ml
O@A^NW/4K7Ui0fYfM`AWLg@4I71a165^KPANJf`4FVIX15YVI`=KJ6T4FVMX15]XI`AMJFT4G6QY15aX
JP=KIfT4F6EW15MTIPAEHV@4E61R155MG`A9E5D3ADmA149<CPA4CU04AU1A14MAD`A9E5D3BeIH14iI
FPA@Fed4DUiO15EPHPAGHV@4FFEV0eYWJ0ALJFX4GVY/15m/KPAQKVl4HW1a0fAaL`AULg@4IgAf16Qf
M`AYMgT4JWUj16]jO1Goool001Coool4KG]m16ilOPA^OGh4Kgeo171nO`=`OX0GLGn0175oO`AaOWl4
L7en16mlO@A^NW/4K7Ui0fYfM`AWLg@4I71a165^KPANJf`4FVIX15YVI`=KJ6T4FVMX15]XI`AMJFT4
G6QY15aXJP=KIfT4F6EW15MTIPAEHV@4E61R155MG`A9E5D3ADmA149<CPA4CU04AU1A14MAD`A9E5D3
BeIH14iIFPA@Fed4DUiO15EPHPAGHV@4FFEV0eYWJ0ALJFX4GVY/15m/KPAQKVl4HW1a0fAaL`AULg@4
IgAf16QfM`AYMgT4JWUj16]jO1Goool001Coool4KG]m16ilOPA^OGh4Kgeo171nO`=`OX0GLGn0175o
O`AaOWl4L7en16mlO@A^NW/4K7Ui0fYfM`AWLg@4I71a165^KPANJf`4FVIX15YVI`=KJ6T4FVMX15]X
I`AMJFT4G6QY15aXJP=KIfT4F6EW15MTIPAEHV@4E61R155MG`A9E5D3ADmA149<CPA4CU04AU1A14MA
D`A9E5D3BeIH14iIFPA@Fed4DUiO15EPHPAGHV@4FFEV0eYWJ0ALJFX4GVY/15m/KPAQKVl4HW1a0fAa
L`AULg@4IgAf16QfM`AYMgT4JWUj16]jO1Goool001Coool4KG]m16ilOPA^OGh4Kgeo171nO`=`OX0G
LGn0175oO`AaOWl4L7en16mlO@A^NW/4K7Ui0fYfM`AWLg@4I71a165^KPANJf`4FVIX15YVI`=KJ6T4
FVMX15]XI`AMJFT4G6QY15aXJP=KIfT4F6EW15MTIPAEHV@4E61R155MG`A9E5D3ADmA149<CPA4CU04
AU1A14MAD`A9E5D3BeIH14iIFPA@Fed4DUiO15EPHPAGHV@4FFEV0eYWJ0ALJFX4GVY/15m/KPAQKVl4
HW1a0fAaL`AULg@4IgAf16QfM`AYMgT4JWUj16]jO1Goool001Coool4KG]m16elO@A]O7h4KWan1fim
OQA_OGl;Kgen16ilO@A^Ngd4KG]l16ajN`=[NGX4JWMh16QfM`AWM7H4IG=d16AbL`MSLG84Hg1b16=`
L@AQKW04GV]^15e[K@=LJF`4FfQZ15YWJ@AIIVP4EfEW15IRI0ADHF<7F6AV15QUIPAIIFL4FVIX15]W
J@=LJFX4GFY/15i[K@AOKFh4HFi_169_L0ASL783Hg5c16AbM0AULg@4IWAe16MeMPAWMGL3J7Ih16Ug
N@AZN7T4JWQj16]iN`A[NW`4K7]l5Oooo`005?ooo`A]Ngd4KGam16elOPA^O7h7KWen56mmO`]_OGh4
KWam16ikO@A]Ng`4K7Yk0f]iNPAZMgP4J7Ig16MdMPAULg@4I79c1f=aLPASL784Hg1a165^L0ANJfh4
GF]]0eaYK0AKJ6X4FVMY15UVJ0AGIFL4EV9T15AQH`MHI6H4F6EV15UUI`AJIVP4FfMY0eaYJPAMJV`4
GV]]15m]KPAQKVl4HVm`16=`LP=SLG<4I79d16EcM0AVM7D4IgEf16MeM`=XMWP4JGMi16YhN@AZN7X4
JgUk16]jO0A/Ng`Eoooo000Doooo16ekO@A]O7d4KGan16ilOPM^OGhDKgeo2fmmOPA^O7d4KW]m16ek
O0A/NW/3JgUj16YgN0AXMWL4IgAf16EcM0ATLW<7Hg5b16=`LPASL744HFi`15i[KPAMJfd3G6U/15]X
JPAJIfT4FFIX15MUI`AFHV@4E65S1eQTIPAHIFH4FFEW15YVJ0AKIfT3G6UZ15eZK0ANJfd4Gfe^165^
K`ARKg04Hg1b0f=aL`ATLW@4IG=d16IdM@AWMGH4IgEg0fQfN0AYMgT4JWQi16YhNPA[NG/4JgYl16ak
O1Goool001Coool4KG]m16elO@A]O7h4KWan1fimOQA_OGl;Kgen16ilO@A^Ngd4KG]l16ajN`=[NGX4
JWMh16QfM`AWM7H4IG=d16AbL`MSLG84Hg1b16=`L@AQKW04GV]^15e[K@=LJF`4FfQZ15YWJ@AIIVP4
EfEW15IRI0ADHF<7F6AV15QUIPAIIFL4FVIX15]WJ@=LJFX4GFY/15i[K@AOKFh4HFi_169_L0ASL783
Hg5c16AbM0AULg@4IWAe16MeMPAWMGL3J7Ih16UgN@AZN7T4JWQj16]iN`A[NW`4K7]l5Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00VOoo
o`<00024oooo002Loooo00<0003oooooool0POooo`00Noooo`@00002oooo0`0000?oool400000ooo
o`@00002oooo0`0000?oool300000oooo`80001noooo001koooo00<0003oooooool01Oooo`050000
oooooooooooo000000Goool010000?ooooooo`0000;oool00`000?ooooooo`03oooo00@0003ooooo
ool00023oooo001loooo00<0003oooooool00oooo`<00003oooo00<0003oooooool00_ooo`040000
oooooooo00000_ooo`@00002oooo00@0003oooooool00023oooo001moooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`02oooo0`0000?oool200001?ooo`@00022
oooo001koooo00@0003oooooool00002oooo00@0003oooooool00002oooo00@0003oooooool00005
oooo00<0003oooooool0SOooo`00O?ooo`800004oooo0`0000?oool200001Oooo`80002?oooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(315) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
4E68734E69734E69744E69744F6A744F6A754F6A754F6B75506B76506B76506C77506C77
516C77516D78516D78516E79516E79526E7A526F7A526F7A526F7B52707B52707B52707C
52707B52707B526F7B526F7B526F7A52707B52707B53707B53707B53717B53717B53707A
53707A526F79526E79526E78526D77516D77516C76516C76516B75506A734F69724F6770
4E666F4F68714F69734F69734F69744F69744F69744F69744F69744F69744F69734E6973
4E69734E68734E68734E6872
4E69734E6A744F6A754F6B76506C77506C77516D78516E79526E79526F7A53707B53707C
53717D54727E54737E557480557480567581567582567683567783567784577884567885
567784567783567783567783577782577783577884587984587984587984587984587983
58778157768057757F56747E56737D55727C55717B547079546E77526C7551697250666E
4F656D506871516A73516B75516B75516B75516B75516B75506B75506B75506A754F6A74
4F69744F69744E69734E6873
4E69734F6A74506B76506C77516D78526E79526F7A53707C54727D54737E557480567581
567682577783587884587985597A875A7B885A7C8A5B7D8B5B7E8C5B7F8D5B808D5B808E
5B808D5B7F8C5B7F8B5B7E8B5B7E8A5B7F8A5C7F8A5C7F8A5C7F8A5C808A5C7F895B7D87
5A7C855A7A8459798359798259788259778159757F58737D56717A556E77536B7351676E
51676F526A73536C75536D76536D77536D77536D77526D77526C77516C76516B76506B75
506A754F6A744F69744E6973
4E69744F6B75506C77516D78526F7A53707B54717D55737E567480577582587783597985
597A875A7C895B7D8A5C7F8C5D808E5E82905E83915F8593608694608796608897608897
5F87955F86945F86935F85925F85925F85915F848F5E838D5D828D5E828C5E818B5D818B
5D818A5C80895C7F885C7E875C7C865C7B845B79825A768059747D57717A566E76546B73
546C74556D76556E78556F79556F79556F79546F79546E79536E78536D78526D77516C76
516B76506A754F6A744E6973
4F6A74506B76516D78526E7953707C55727E5674805776825877845979865A7B885B7D8A
5C7F8C5E818E5F8290608493618695628897638A99648C9C648E9E658F9F6590A06590A0
648E9E648D9D648D9B648C9A648B98638B97638A9563899462889362879262869161858F
60848F60848E60828D5F818B5F818A5F7E885E7C865D7A845C78815B757E587179576E76
57707858717A58727B58727C57727C57717C56717B56707B55707A546F79536E79526D78
516C77506B764F6A744E6973
4F6A75506C77526E7953707B55727E5674805776825978855A7A875B7D8A5D7F8C5E818F
5F8391618694628896638A99658C9C668F9F6791A16894A46A96A76A98A96A99AA6A98A9
6996A66894A36893A26892A168929F68919E68919D68909C678F9B678E99668C97668B96
668B95658A9465889365879264859063848F62828C617F89607C865E79825B747C5A727A
5B747D5B757E5B757F5A757F5A757F59747F58737E57737D56727C55707B546F7A536E79
526D78516C76506A754F6974
4F6A75516D78526F7A54717D5674805776825979855B7B885C7E8B5E808E5F8390618593
628896648A99668D9C6790A06993A36A95A66C98A96D9BAD6F9FB171A2B471A4B76FA1B4
6D9DAD6C9BAA6C99A96C99A76C98A66C98A56C98A46C97A36C97A36C97A26C96A16C949F
6B939E6B919D6A909B6A8E99698B9768899567879365859063818B617D875F79825F7881
5E79835E79835E79845D79835C78835B77825A768159747F58737E57727D55717B54707A
536E79526D77506B754F6974
4F6B75516D7853707C55737F5776825978855B7B885C7E8B5E818E608491628695648998
658C9B678F9F6992A26B95A66C99AA6E9CAD709FB172A3B675A7BA79AEC276ABBF71A4B7
70A2B370A0B0709FAE709FAD719FAD719FAC719FAC719FAC71A0AC72A0AB729FAB729EA9
729CA7719AA57097A37095A16F929E6D8F9B6B8C98698A9567869165828D637F89637E89
627E89627E89617D88607C875F7B865E7A855C78835B77825A758058747E57727D55707B
546E79526D77516B764F6A74
506B76526E7954727D5675805878845A7B875C7E8B5E818E608492628795658A99678E9D
6991A06B94A46C98A86E9BAC709EB072A2B574A6B977AABE79AFC37BB2C674AABE73A7BA
73A6B774A5B674A5B575A5B475A5B475A5B376A5B276A6B377A8B477A9B578A9B578A8B3
78A5B177A2AD769EAA769CA87498A47295A170929E6E8F9B6C8D986A8A96688792678692
66859065838F64828E63808C627F8A607D885F7B865D79845B77825A758058737E56717C
556F7A536D78516C764F6A74
506B76526F7A55727E5776825979865C7D895E808D608391638795658A99678E9D6992A1
6C95A56E99AA709DAE72A0B274A4B776A8BB78ACC07AB0C57DB4CA75ACC36FA5BA74A9BC
76AABC77ABBC78ABBC79ABBB7AABBA7AACBA7BACBA7BADBA7CAFBB7DB0BB7DAFBB7DAEB9
7DACB77DA9B47CA6B27AA2AE799FAB779BA77498A47194A070929E6E909C6D8E9B6C8E9B
6A8B9869899568879366849064828E63808C617E895F7B875D79845B778259758057737D
55707B536E79516C774F6A74
506C76536F7B55737F5877835B7A875D7E8B608290628694658A98678E9D6A92A16C96A6
6F9AAA719EAF73A2B476A6B878AABD7AAEC27CB2C780B9CF79B2C871A8BE74ABBF77ADC0
79AEC17BB0C27CB1C27DB1C27EB1C17FB1C07FB2C080B4C080B6C181B7C281B6C181B5BF
81B3BD81AFBA81ACB77FA8B47DA4B07BA0AC789CA97699A67497A47296A37296A47094A2
6F919F6D8E9B6B8B9869899567869265838F63808C617E895F7B865D79845B768158747F
56717C546F7A526C77506A75
506C7753707B5674805978845C7C895F818E618592648997678D9C6A91A06C95A56F9AAA
729EAF74A2B477A7B97AABBE7CB0C47FB4C980B9CE7BB4CB75AEC477AFC579B0C57BB1C5
7DB3C67FB5C881B7C882B7C883B7C783B7C684B8C684B8C584B7C385B4C185B3C085B1BD
86B0BC86B0BC85B0BA84ACB782A7B47FA3B07CA0AC7A9DA9779AA77699A67598A67499A8
7398A77193A16F909D6D8D996A899668869266838F63808C617D885E7A855C778259757F
57727D556F7A526D77506A75
516C7754717C5775815A7A865D7E8B608390638795668C9A69909F6C94A46F99A9729EAE
75A2B478A7B97BACBF7EB1C480B5CA83BAD086C0D681BBD37CB5CC7CB4CA7DB4C97FB5C9
81B7CB84BACD86BCCD87BCCC88BCCB89BCCB88BBC988B9C688B4C288B0BD88ABB988A9B7
89ACB98AAFBB8AAFBB88ADB986AAB683A7B380A3B07D9FAD7B9DAA799BA9789BA9779BA9
769AA97598A77394A270919E6E8D996B899568869265828E627F8A607C875D79845A7681
58737E55707B536D78506B75
516D7854717D5876825B7B885E808D628592658997688E9D6B93A26F98A8729DAD75A1B3
78A6B87BACBE7EB1C481B6CA85BBD088C1D783BED67CB6CE7EB7CD80B7CC81B7CB83B8CB
85BBCE88BED18BC1D28CC1D08DC1CF8FC1CE8CB8C689B0BE88ABB987A7B387A8B48AABB8
8CA9B78DA8B58EABB88DAEBB8AADB987A9B683A5B280A2AE7E9EAC7C9DAB7B9DAB7B9DAB
7A9EAD799DAC7799A77495A271919D6E8C986A889467849064818C617D885E7A855B7782
59747E56717B536E78506B75
516D7855727E5978835C7D8960818E638694678C9A6A91A06E96A5719BAB74A0B178A5B7
7BABBD7EB0C382B6CA86BBD089C0D68CC5DB85BED67FB8CF81B8CE82B9CE84BACD86BBCE
88BDCF8BC0D18EC1D191C3D28FBCCB89AFBD86A9B788A9B689A8B58AA9B78AA9B78AA5B2
89A5B18BA6B28DAAB690ACB98EADBA8AABB786A7B383A3B081A1AD7F9FAC7F9FAD7EA0AD
7E9FAD7D9EAB7C9DAA7899A67494A0708F9B6D8A9669869266828E637F8A5F7B865C7883
59747F56717C536E79506B75
526D7855737E5978845D7D8A618390658996698E9C6C93A27099A8739EAF77A4B57AA9BB
7EAEC182B4C886BBCF8AC1D78DC6DC8CC6DD83BDD482BAD183BACF85BACE86BACD89BCCE
8BBECF8EBDCF8EBCCC8DB8C889B3C389B2C28BB2C28CB1C08DB1C18EB2C28FB2C18FB1BF
8EB0BE8CADBB8AA9B689A6B38CAAB58DADB88AAAB686A6B284A2AF83A1AE82A1AE81A1AF
81A1AF80A1AF7FA0AF7C9DAA7897A373919D6F8C986B889367848F64808B617C875D7883
5A758057727C546E79516B76
526E7956737F5A79855F7F8C638592678B996B919F6F96A5729CAC76A1B27AA7B87DACBE
80B2C584B8CC89BFD491C9E094CFE689C4DC7FB8CF83BACF86BCD088BCCF8ABCCE8BBCCE
8DBCCD8CB8C889B0BF86A8B885A7B78AADBC8DB1C08FB3C391B7C692B8C693B8C693B8C7
92B7C691B2C18FB0BE8CADB98AAAB68CABB78BABB688A7B387A5B186A4B185A4B085A3B0
84A2AF83A2B080A0AE7D9DAA7998A575939F708E9A6C899569859065818C627D885E7984
5B768057727D546F79516B76
526E795774805B7A8660818D648794698D9B6D93A27199A8759FAF79A5B57CAABC80B0C2
83B5C886BBCF8AC1D68FC7DD8AC3DA81B9D081B8CE85BBCF88BCCF8BBCCE8DBCCD8EBDCD
8FBCCC8FB9C98EB4C38CB0BE8DAEBC8EADBD8FAEBD91AFBE92B1C093B1C194B1C194AFBF
94AFBE93B0BE91B1BE8FAEBB8CABB98AA8B589A7B38AA7B389A6B289A6B288A5B187A5B1
87A4B186A5B189A8B583A2AF7B98A67694A0728F9A6E8A956A869166828D637E885F7A85
5B768158727D546F79516B76
526E795775805C7C8861828F6689966A8F9D6F95A4739CAB78A2B27CA8B97FAEC082B3C6
85B9CC87BDD188BFD482BAD179B2CA7DB4CB85BACF89BCD08CBCCE8EBCCD8FBCCD91BBCC
92BACA92B9C891B7C692B6C592B4C393B3C294B4C295B4C396B6C398B6C498B5C499B5C3
98B3C198B2C096AFBD93AAB98FA5B38AA0AD889EAB89A1AD8BA5B18BA6B18BA6B18AA5B1
89A5B189A5B088A4AF829EAA7D99A677939F738F9B6F8B966B869167828D637E89607A85
5C768158737D556F7A516B76
536F7A5876815D7D89628490688A986D919F7198A7769FAE7AA5B57FACBD82B2C486B8CA
89BDD08AC0D68AC2DA87C0D886BDD388BCD18BBED28EBFD190BECF92BDCE93BCCC94BDCC
95BCCB95BBC996BBCA97BBCA97B9C898B8C699B8C69AB9C79BB9C79CB9C79DBAC89DB9C7
9DB8C59CB6C29AB3BF97AFBC93AAB790A6B38EA4B08CA3AF8DA4AF8DA7B18DA7B18CA7B1
8BA5B08BA5B08BA5AF829DA87D98A37994A074909B708B966C879268838D647F89607B85
5D778159737D556F7A516C76
536F7A5977825E7E8A648592698C9A6F94A1749BA979A2B17EA9B982B0C086B6C88ABCCF
8DC2D58FC6DB90C9DF90C8DE90C8DD91C5D991C3D592C2D394C1D196C0D097C0CF98C0CE
99BFCD99BECC99BDCB9ABDCC9BBECB9CBDCB9DBECB9EBECB9FBDCBA0BDCAA1BDC9A1BDC9
A1BBC79EB8C49CB5C099B0BB96ACB793A8B491A6B190A5B090A7B090A8B190A8B18EA6B0
8CA5AF8BA4AE8BA4AE839EAA7F9AA77A95A175909B718B966D879269838E657F89617B85
5D778159737E556F7A516C76
54707B5A7783607F8B6587936B8F9C7196A4779EAC7CA5B481ADBD86B4C58ABBCC8EC1D4
92C7DB94CDE296CFE597CFE397CDE096C9DC95C7D997C6D699C5D59BC4D49CC4D39DC4D2
9DC2D19EC1CF9EC0CE9FC1CEA0C1CEA0C0CDA1C0CDA2BFCCA3C0CCA4C0CBA4BFCBA4BEC9
A3BCC6A2BAC49FB6C19DB2BC99AEB796AAB393A7B093A6AF94A8B193A9B192A8B08FA6AF
8DA4AE8AA2AC88A1AC839FAB809CA87A96A176909B728B966E87926A838D667F89627B85
5E77825A737E56707A526C76
54707B5A788461808C6788956D919E7499A67AA1AF7FA9B885B1C08AB8C98FC0D194C7DA
97CEE19AD3E89DD6EA9ED6E99DD0E39BCCDD9BCADB9DC8D99EC9D89FC8D7A1C8D7A2C8D6
A2C7D5A3C6D3A3C5D1A4C3D0A4C3D0A5C4D0A5C4D0A6C4CFA7C4CFA8C4CFA9C4CFA9C2CC
A8BFC9A6BCC5A3B8C1A0B4BD9DB1B99AADB498AAB298AAB298AAB296AAB295A9B192A7AF
8EA4AD89A0A9819BA57B96A27D99A47B96A1768F99728B956E87916B838D677F89627C85
5E78825A747E56707A526C76
54707B5B798462828D698A967093A0769BA97DA4B283ACBB89B5C48FBDCD95C5D69ACDDF
9ED6E9A2DCF0A4DFF1A4DAEBA2D2E3A1CEDFA1CCDDA2CCDCA3CDDCA4CDDCA6CEDCA7CDDB
A8CDDAA8CCD8A8C9D5A8C7D2A8C6D1A8C6D2AAC8D3AAC8D3ABC9D3ADC9D3ADC8D2ADC6CF
ACC3CCAABFC8A8BCC4A5B7BEA1B2BA9FAFB79EAFB69DAFB69CAEB69AAEB598ACB394A9B1
90A6AE8BA2AA849CA57C949D748A94728A93758D97738B946F87916C848D678089637C85
5F78825B747E56707A526C76
55717C5C7A8563838E6B8C987295A1799EAB80A7B587B0BE8EB9C894C2D29ACBDCA0D3E5
A5DBEEA9DFF1AADEEFA8D8E9A6D4E4A5D1E1A6D0DFA7D0DFA8D1DFA9D2E0ABD3E0ACD3E0
ADD3DFADD1DDADCFDAADCDD7ACCBD5ADCAD4ADC9D3AEC9D3AFCAD4B0CAD4B1CAD2B1C8D0
B0C5CDAEC2C9ABBDC3A7B8BEA5B5BBA4B4BAA3B3BAA3B3B9A1B2B89FB1B79CAFB598ACB2
94A9AF90A4AB8AA0A88399A27D929B7A9099788E97758B957188916D848D688089647C85
6078825B747E57707A526C76
55717C5D7B8665848F6C8D997497A37CA0AD83AAB78BB4C292BDCC99C7D6A1D0E1A7DAEC
ADE1F3B1E2F4B2DFF0AEDAEAABD6E5AAD4E3AAD4E2ABD4E2ADD5E3AED7E4B0D8E5B2D9E5
B3D9E4B3D7E2B3D5DFB2D2DCB1D0D9B1CED8B1CDD6B2CCD5B3CDD5B4CDD5B4CCD3B4C9D0
B2C6CDB0C2C9AEBEC5ACBCC2ABBBC0AAB9BFA9B9BEA8B8BDA6B6BCA4B4BAA1B2B79EAFB5
9AABB194A7AE8FA3AA899EA5859AA280979F7B919A778D957389916E848D698089657C85
6078815B747E57707A526C76
56727C5E7B866685906E8F9B7699A57FA3B087ADBA8FB7C597C1CF9FCBDAA7D6E5AFE1F2
B8E9FABDEBFBBBE6F4B4DDECB0D8E7AFD7E5AFD7E5B0D8E5B1D8E6B3DAE7B5DBE8B7DDE8
B9DDE8B9DCE6B8D9E2B7D6DFB6D3DCB5D1DAB5D0D8B5CED6B6CED6B7CDD5B7CDD4B7CBD1
B6C8CEB4C5CBB2C3C8B2C1C5B1C0C4B1BFC4B0BEC2AEBCC0ACBABEA9B7BBA6B4B8A3B1B6
9EAFB39AACB196A9B090A4AB8AA0A8849AA27E939B798E967489916F858D6B8189667C85
6178815C747D57707A526C76
56727D5F7C8767869170909C799BA782A5B28AB0BD93BBC89CC6D3A4D0DEADDBE9B6E5F4
BFEDFAC2ECF9BFE7F4B9E0EDB4DBE8B2D9E6B2D9E6B3D9E6B5DBE7B8DCE8BADEE8BCDFE9
BEE0E9BEE0E9BEDFE7BCDBE4BAD7E0B8D4DCB7D1D9B7D0D7B8D0D7BAD0D6BBCFD5BACDD3
BACBD1B9C9CEB8C7CBB8C6CAB8C5C9B7C5C8B6C3C7B4C1C5B2BEC2AFBBBFABB8BBA7B5B8
A4B2B6A0AFB49CACB296A8AE8FA3A98799A081949B7C8F96768A9171858D6C8189677D85
6178815C747D57707A526C76
56727D5F7D8768879272929D7B9DA884A8B48EB3BF98BFCBA1CAD7AAD5E2B3DFEDBAE7F4
BFE9F4C1E9F4BFE5F1B8DEEAB5DBE7B5DAE7B4D9E5B5DAE5B8DCE7BCDFEAC0E3EDC4E6EF
C6E6EFC5E4ECC2E1E9BFDEE5BDDAE2BAD5DDB9D2D8B9D0D6BAD0D5BCCFD5BDCFD5BDCED4
BDCDD1BDCCD0BECBCFBFCBCEBECACDBDC8CBBCC7C9B9C4C6B6C1C3B3BDC0B0BBBDACB8BA
A9B4B7A5B2B5A2B0B49DADB094A5A98B9A9F84949A7E8F95788A9172868D6D8189677D85
6278815D747D587079536C76
57727D607D8869889373939E7D9EA987AAB592B6C29CC2CEA7CFDBB1DAE7B9E5F2C0EBF7
C8EEF8C8ECF5C1E4EFB8DCE8B6DAE5B5D9E4B5D8E3B6D8E3B8D9E3BBDBE4BFDEE6C3E1E8
C7E3EAC7E2EAC3DFE7C1DDE4BEDAE1BBD5DBBAD0D6BACED4BBCED4BDCFD4BECFD4C0CED3
C1CFD2C1CED1C1CDCFC2CDCFC3CECFC3CDCFC1CBCDBEC7C9BAC4C6B7C1C2B4BEBFB2BABC
AEB7B9AAB4B6A6B1B39EAAAC95A2A58D999D869499808F95798A9073868C6E8188687D84
6278815D747D587079536C76
57737D617E886A889374949E7F9FAA89ABB695B8C4A1C6D1ADD4E0B8E1EDC0EAF6C5EDF8
C7EBF5C3E5EFBDE0EAB6D9E4B5D7E2B5D7E1B6D7E0B6D7DFB7D6DEB7D5DCB6D3DAB9D4DB
BBD6DDBBD5DCBBD3D9B9D0D6B5CAD1B5C9CFB8CBD0BACCD0BCCDD1BECED2C0CFD2C1D0D2
C4D2D3C5D1D2C7D1D3CAD3D4CBD4D4C9D1D2C6CECEC2CACBBEC7C8BAC3C4B7BFC0B4BCBD
B2BABAB0B8B8ACB4B4A3ABAC98A0A28F989A889497818F947B8A9074868C6E8188687C84
6378805D747D587079536C76
57737E617E886B899375949E80A0AA8BACB798BAC5A5C9D4B4DBE5C6EFFACCF5FFCBEFF9
C9EAF3C3E4ECBCDDE6B5D6E1B4D6DFB5D5DEB5D5DDB7D5DDB7D4DBB6D1D7B5CFD5B2CCD2
ADC6CDABC4CBACC4CBAEC4CAB1C4C9B4C6CBB7C9CDBACBCFBCCDD0BECED0BFCDCFBFCCCD
BFCACBC1C9C9C8CECDCED3D1CCD3D1C9D0CEC9D0CEC5CDCCC1C9C8BCC4C4B9C0C0B7BDBC
B5BBBAB5BAB9B2B6B5A8AEAE9CA3A492999B8A95988390947C8A8F75858B6F8187697C83
6378805D747C587079536C75
57727D617D876B889276939D809FA98CACB699BAC4A8CAD4BBE1EBC8EDF7CDF0F8D2F3FA
CFEDF4C5E4ECBADAE4B2D3DDB3D3DCB3D3DAB5D4DBB6D4DAB6D2D8B6CFD4B5CCD0B3C9CD
B0C7CBAFC3C8ADC1C5AFC1C5B1C2C5B4C4C7B7C7CABACACCBCCCCEBECCCDBFCBCCBFC9CA
BDC7C8BCC5C5BCC5C6BEC6C6BEC6C5BFC6C5BEC6C4BBC3C2BAC1C0B8BEBDB9BDBCB8BDBB
B8BCBABABCBAB5B8B5A9AFAE9EA6A6959D9E8C96988490937D8A8F76858A6F8086697B82
63777F5D737B586F78536C75
57727C617C866B879175939C809EA88CABB498B8C1A6C7D0B5D7E0BDDEE7C2E1EAC7E3EB
C7E3EABEDCE5B6D5DEB0D0D9B1D0D8B2CFD7B2CDD4B3CCD1B6CFD4B8D0D5B8CFD2B8CCCF
B6C9CBB5C6C8B3C4C6B3C3C5B4C2C4B5C3C4B8C6C7BAC9CBBDCBCCBECBCBBFCACABFCAC8
BFC8C7BEC5C5BCC3C2B6BDBDB0B8B9B2BABAB2BABAB2B9B9B5BAB9B8BCB9BABDB9BABCB9
BBBDB9BCBCB8B4B6B3A9ADAB9EA5A4969C9D8D96988590937D8A8E7684896F7F85687B81
63767E5D737B586F78536B75
57727C617C866B879075919B7F9DA68BA8B196B5BDA3C1CAB0CED7B7D5DCBCD9E0BEDAE1
BCD9E0B8D5DDB3D0D8AFCDD5B0CED5B1CCD3B1CAD0B1C8CCB0C4C8B0C3C6B1C3C4AEBFC0
ABBABCAAB8B9ABB8B9ADB8B9B0BBBBB4C0C1B8C5C5BBC9C9BECACABFC9C9BFC9C7C1CAC6
C2CAC6C1C8C5BFC5C3BBC2C0B7BDBCB5BAB8B4B8B6B5B9B6B9BBB7BABDB7BCBEB8BDBEB9
BFBFB9BEBDB8B5B5B0A6A9A79DA2A1979C9C8F9798858F927D898C7583876E7E83687980
62757D5D727A576E77526B75
57727C607B856A868F7490997E9AA389A5AE94B0B99FBCC3AAC6CEAFCBD2B2CED5B5D0D7
B5D1D8B3CFD6AFCCD4AECBD3AFCCD3B0CBD1B1C9CEB1C6CAB0C3C6AEBEC0ACB9BAAAB6B7
A9B3B3A9B2B1AAB2B1ADB5B4B2BBBBB7C2C1BBC6C7BEC9C9BFC9C9BFC9C7BDC5C3BCC2BF
BDC2BDC1C6C0C4C8C3C2C6C2BEC2BEBCBFBBBBBEBABBBDB9BCBEB8BDBEB8BEBEB8BEBEB7
C2C0B8BEBCB5B2B2ADA8AAA7A3A6A49DA1A191999A848E907B868A7381856D7C8166787E
61747B5C7179576E76526B74
57717B607B8469848D738E977C98A086A2AA91ACB49BB6BDA5C0C6A9C3C9ABC5CBADC8CE
ADC8CFACC8CFACC8CFACC8CFAEC9D0B0C9CFB1C9CDB2C7CAB2C4C7B1C1C2B0BEBEAFBCBB
B0BABAB0BAB9B1BBBAB4BEBCB7C1C0BAC6C5BDC9C9C0CBCAC1CCCAC0CAC8BFC7C4BDC3BF
BABEBAB7BBB7B8BCB7BCBFBAC1C3BEC2C4BEC1C2BCC0C1BABFC0B9BEBDB6BEBCB5C0BDB6
C2BDB5BBB7B0B2B0AAABABA6A5A5A1989A998A8F9081898B788386717E826A797E65767C
5F72795B6F77566D75526A74
56717B5F7A8368838C718C947B959D849FA68DA8AF97B1B8A0BAC0A2BCC2A5BEC4A7C1C7
A7C2C8A8C3C9A9C5CBACC7CDAFC9CFB1CACEB2C9CDB3C8CBB3C7C9B4C5C6B4C4C4B4C2C2
B5C1C0B6C2C0B8C3C2BAC5C4BDC8C6BFCBC9C2CDCBC3CFCCC4CECCC4CDCAC2CBC7C1C7C3
BEC3BFBBBFBBB8BBB7B6B8B4B5B7B2B7B8B3B9BAB4B9B9B3BAB8B1BCB9B1C0BBB3C2BBB3
C0B9B1B8B2ABAFABA5A7A39F9E9B9892929184898A7C8486747F826D7A7E68767B627379
5E7077596E76556C74516A73
56707A5E798267818A708A9278929A819BA28AA4AB93ADB39CB6BC9FB8BEA1B9BFA2BBC0
A4BDC3A5C0C5A8C3C9ACC6CCAFC9CEB1CACEB3CACDB4C9CCB6C9CBB7C8C9B8C8C8B9C8C8
BAC8C8BCC9C8BECBC9C0CCCBC2CFCDC4D1CEC6D2CFC8D3D0C8D2CFC8D1CCC7CFCAC5CCC7
C3C8C4C0C5C0BDC1BBBBBDB7B8B9B3B7B7B0B7B6AFB9B7AFBCB8B0BEB9B1C1BAB2C2BBB2
BEB7AEB4ADA5A9A49D9F9B969594908B8C8B8086867780826F797C6975796472775F7075
5B6E74586C74546B73516973
56707A5E7781667F886E878F768F977F989F87A0A690A8AE99B1B69BB2B69CB3B79EB5BA
A1B8BCA4BBC0A8C0C4ACC4C8AFC8CCB2CACDB4CACDB6CBCDB8CBCDBACCCCBCCCCCBECDCD
C0CECEC2D0CFC4D1D0C6D3D1C8D5D2CAD6D3CCD8D4CDD8D4CDD7D2CCD6D0CBD3CECAD0CA
C8CDC7C6C9C3C4C5BEC1C1BABFBEB7BEBCB5BDBBB2BFBAB2C1BAB1C2BAB1C4BAB1C4B9AE
BCB2A8AFA79FA49E9699958F8D8C88828381777C7C6E7677687274646F73606D725C6C72
596B72566A72536972506972
556F795D767F647E866C858D748C947C949B849CA28CA3A994ABAF96ACB098AEB199AFB3
9CB2B69FB6BAA3BABDA7BEC1ADC3C6B1C8CAB4CBCDB8CCCEBACECFBDD0D0C0D1D1C2D2D1
C5D3D2C7D5D4C9D7D5CBD9D6CEDBD7D0DCD8D1DDD8D2DDD8D2DCD6D1DAD4D1D7D1D0D5CE
CED1CACBCDC6C9CAC2C7C6BEC5C3BBC4C0B7C3BFB5C3BDB4C3BCB2C3BBB1C4BAAFBFB5AA
B4AAA1A8A0979C968F8F8B8681807C7576746A6E6E63696A60696B5E696C5B686D59686E
56686F546870526871506871
556E785C757E637C846A838A72899079909781989D899FA491A6AA92A7AA93A8AC96AAAD
99AEB09DB2B5A1B6B9A4BBBEA9C0C2AEC5C8B5CACCB9CDCEBDD0D1C0D3D3C4D5D5C7D7D6
CAD9D8CCDBD9CFDDDAD1DFDCD3E1DDD5E1DDD6E2DDD7E1DBD7E0DAD7DED7D6DCD4D4D9D1
D2D5CDD0D1C9CECEC5CCCBC1CAC7BEC9C4BAC8C2B8C7C0B5C6BEB3C6BCB0C3B8ACBAAFA4
AEA49AA09890918B8583807B7574716769685A5C5C565B5C58606358626656646855646A
54656C52666E51676F4F6771
546E785B747D617A826880876F868D768D927D9398859B9F8DA2A58EA3A690A4A793A6A9
96A9AC99ACAE9DB0B2A3B7B8A9BDBEAFC3C4B6C9C9BCCECEC0D2D2C4D5D5C8D8D8CBDCDA
CFDFDDD2E1DFD5E3E1D7E5E2DAE7E3DBE8E3DCE8E2DCE7E0DCE4DDDCE2DADBDFD7D9DCD3
D7D8CFD5D4CBD3D1C7D1CEC3CFCABFCDC7BBCBC3B8CBC0B4C9BEB1C5B9ADBEB2A6B3A79C
A59B91968E8687817B7875716A69665C5E5D51555551565751595C525C60525F64516167
51626950646C4F656E4E6770
546D775A737B607880667D856C838973888E798E93809498889B9E899C9F8B9EA18EA1A3
91A3A595A7A89BADAEA1B3B4A9BABAB2C3C2B9CAC9BED0CFC3D4D3C8D9D7CCDDDBD0E1DF
D4E5E3D7E8E5DBEAE7DEECE8E0EDE8E2EDE7E3EDE6E3ECE4E3E9E1E1E6DDDFE3D9DEDFD5
DCDBD1D9D8CDD7D3C8D4CFC4D2CCC0D1C9BCCFC5B8CEC1B4CABDB0C5B7A9BBADA0ADA094
9D92898D857D7E78716F6B665F5E5B505250474B4B4A4F514C54564D575B4E5B5F4E5D63
4E60674E626A4E646D4E666F
536D7659717A5E767E647B82697F866F848975898D7B8E918194968395978797998A9B9C
8E9FA093A4A498A9A99FAFAFA8B8B6B3C2C0BACAC8C1D0CEC6D6D4CCDCDAD1E1DFD5E6E3
DAE9E7DEEDE9E1EFEBE4F0EBE6F2EBE8F3EBE9F3EAE9F1E7E8EEE3E6EADFE4E6DBE2E3D8
E0DFD3DDDACEDBD6CAD8D1C5D6CDC0D4C9BCD2C5B8CEC1B3CABBADC1B2A4B4A598A4968B
92887E817A72726D67615F5B50504E4040403D3F4043494A464E514853574A575C4B5A60
4C5D644C60684D636C4D656F
526C755770795C747C61787F667C826B808570848876888B7B8C8E7D8D8E819091859495
8A99998F9E9E96A4A39DABAAA7B5B2B1BEBBBAC7C4C3D1CECAD9D6D0DFDBD6E4E1DBE9E5
E0EDE8E4F1EBE8F4EDEBF6EEEDF7EFEFF8EEF0F6EDEFF4E9EEF1E6ECEDE2EAEADEE7E5D9
E4E1D4E1DCCFDED7CADCD2C5D9CEC0D5C9BAD2C3B5CDBEAFC5B5A6B9A99BAA9B8E998C81
877D74776F6866615C5553504646453B3D3D3C3F403E4446424A4D444F5347545948585E
4A5B624B5F664C626B4D656E
526B75566F775B727A5F757C63787E687B806C7E827081847585877786877B8989808D8D
8592918B9896919E9D99A5A3A1AEABACB8B4B8C4BFC4CFCACDD9D4D4E2DCDAE8E2E1EEE7
E6F2EAEAF5EDEEF8EFF1FAF1F4FCF1F6FCF0F7FAEEF5F8EBF3F4E7F0F0E3EEECDEEBE7D9
E8E2D4E5DDCFE1D8CADED3C4DBCDBED6C8B8D0C1B1C8B8A8BDAC9DAE9E909D8F838C8076
7B72696B645D595550474543393A39333435363A3B3A40423E4649414C5044515646555B
485A60495D654B616A4C646E
516B74556D765970785D737960757B64777C67797D6A7B7D6C7B7B6F7D7C7481817A8685
7E8A8984908F8B9695929E9B9BA6A3A6B0ABB2BBB5BFC8C1CCD6CED7E1D9DEE9E0E5EFE6
ECF5EBF1F9EEF5FCF1F8FEF2FBFFF2FDFFF2FDFDF0FBFAECF8F5E7F5F1E2F2EDDEEFE8D9
EBE2D4E7DDCEE3D7C7DED1C1D9CABAD2C3B2CBBAAAC0AF9FB0A091A091848F82767E7369
6C645C5B554F4946423A38372B2A29292929313436363C3F3A43463E494D414F5444545A
46585F485C644A60694C646E
516A74546C75576E765B70775E72786173786374786575776774756A75766E7979737E7D
7983827F8987858F8C8C9693949E9A9DA6A1A8B1ABB5BDB6C3CBC2CFD6CDDCE3D9E7EDE2
EFF4E8F5FAEEF8FDF0FCFEF1FFFFF0FFFEEEFEFBEBFDF8E8FBF5E5F8F0E1F4EBDBF1E6D6
EEE1D1E9DCCAE2D4C3DCCCBBD5C5B3CCBCAAC1AF9FB3A192A392859183777F74696E645B
5C544E4A45413A37352C2B2A24242427292A2D313332393C3741443B474C3F4D52425258
45575E475B634960684C646D
506A73536B74566D74596E755B6F755D70745F7074617072626F71646F6F67716F6B7574
717A7976807D7D8683848C898B948F959D989FA7A1ABB2ABB7BEB6C4CAC1D2D6CBDEE1D5
E6EADDEDF0E2F3F4E5F7F7E7FAF7E7FAF6E4FAF3E1F9F1DFF8EEDCF6EAD8F3E6D4F0E1CF
EADBC9E4D4C2DECDBBD6C5B3CCBBAAC1AF9EB3A191A392849283768073686E635A5C544C
49443F3735312928261E1D1C1B1B1C2326272A2F3130373A353F4339464A3D4C51415157
44565D465B63495F684B646D
506973526A73546B73576C73596C725A6D715C6C705D6C6E5E6A6C5D68685F6968646D6C
6972716E7775737C7979817E828A868D948F989F99A4AAA3AFB5ADBAC0B7C6CAC0D0D3C7
D9DACDE0DFD1E6E4D5EBE8D8EEE9D8EEE8D7EFE7D6F0E5D3EFE3D0EDE0CDEBDCC9E7D7C4
E2D0BEDBCAB7D3C2AFCAB8A7BFAD9CB2A090A291849283768073686E635A5C534C49433D
36332F2625221A1918121111171717202425282E302E363A333E4238454A3C4B51405057
43565D465A63485F684B646D
4F6972516972536A72556A71566A70586A6F59696D59686B5966685964645962615B6362
616967656E6B6B73707279767B827E858C878F9690999F98A3A8A0AFB2A9BABBB0C2C3B7
C8C9BCCECDC0D5D2C4D9D5C6DDD8C8DED8C8DFD6C6DED4C3DDD1C0DACDBCD8CAB8D5C5B3
CFC0ADC8B8A6BFAE9EB6A595AA9A8B9D8E808D80737D71666C62595B524B49423D36322E
2522211716150B09090C0B0B17191A202426272E312D363A323E4237444A3B4B513F5057
42555D455A63485F684B636D
4F687251687152697153697054686E55686D56666B566568566365556061545D5D555E5C
58605E5D6462636A686B716E7278747A7F7B8489838E938C989D96A3A69DABADA3B2B3A9
B9B9ADBFBEB1C4C2B4C7C4B6CAC6B7CCC5B6CBC4B4CAC1B2C8BEAEC6BAAAC3B6A6BFB1A1
B9AB9BB1A394A99B8CA0928495877B887B70786E63685F5658514946413C34312E232120
151413080605060505101112181C1D202628272F322D373B323E4337454A3B4B513F5057
42565D455A63485F684B636D
4F687250687151687052676F53676D53666B536469536266526062515C5E4F58594F5555
505654555B595A605E606663676D69707571797E798286808B8F8795978E9B9D94A2A399
A7A89EACADA2B1B0A4B4B2A5B7B3A6B7B2A5B6B0A2B4AEA0B2AB9CAFA799ABA294A69C8E
9F9587978D8191867A897E727E746972695F645C54544E48433F3A32302D242321161615
0706060302020C0C0D1316171B202222292C2831352E393D33404537464C3B4C523F5158
42565E455B63485F684B646D
4E68714F677050676F51666E51656C51646A516368516064505E614E5A5C4C5556474E4D
454A494A4F4D505553565B595D625F6368656B706B7277717A7E7883857E8A8C8490928A
95968E999A919D9C939F9D949F9E93A09E939F9C919D9A8F9A978B979387918D828C877C
8680757F796F787269706A6266605959554F4B48433D3B372F2E2B202120121413060708
02020309090A101214171B1D1D2427242C302A34382F3B4033414738474E3C4D543F5259
42575F455B644860694B646E
4E67714F67704F666F50666D50656B5063695061674F5F644E5C604C585B495455464E4E
4146463F44424449474B504E515654575C595D625E636763696D6870736D7679727C7E77
80827B83857D85867F888881898A82898A8189898087877E84847B807F777C7A71757269
6C6A6267655E6260595957524D4D4843423F3737352A2B2A1D1F1E121414080909010000
0403030D0F1014181A1B212421292C2630352C373C303E4335444A3949503C4E5640535B
435860465C654860694B646E
4E67714E67704F666F4F656D4F646B4F63694E61674D5E634C5C604A585B485456454E50
4148493C41403B3F3D3F4543464B494C514F515552545956595E5A5E635F636762676B66
6B6F696E726C71746E73766F74777073767073756F71736D6F716B6C6E6866686361635E
5B5E5B5457544D4F4C4446443B3D3C333534282A2A1C1F2012141507090A000000020101
0B0C0E121618191F221F272A242E322A353A2E3B4133414737474D3A4C533E505841555D
445961465D6649616A4B646E
4E67714E67704E666F4E656D4E646B4E62694D61674D5E644B5C6149585C475458445052
414A4C3D4545393E3D383C3B3B403F404543454A48484E4B4B504C4F534F515753535855
555A57585D5A5B605C5D625E5E635F5F64605E645F5C625D5A605C585D5A565B59525857
4E53534B504F4449483C4040333737272C2C1C2021121617080C0D0103030202030A0C0E
111618181E211E262A232D322834392D3A4031404635454C394A513C4E563F535B42575F
445A63475E6749616B4B656F
4E67714E67704E666F4E656D4E646C4D626A4D61684C5F654B5C6249595E47565A455255
424D503E48493A4242353A39343836373D3B3B413F3E4441404543414744434946454B48
474E4B474E4B484F4C4A514E4B53504B53504A5250495150485150464E4E444D4D414A4B
3E47483A4243323A3C2A323422292B181F21111618090E100205060405060B0E1012181A
1920231F272B242E3329353A2D3A4031404635454B3849503B4E553E525941555D435961
455C65485F684A626C4C656F
4E67714E67704E666F4E656E4D646C4D636B4C61694C60664B5E64495B6147585D455459
435054404C4F3C47493840413238382D32302F3534353B3A39403E39403D373E3B353C3B
363D3C39403F3B43413942413741413944443C46473C47483B46483A46483A4548374246
3540432F3B3E293437222C2F1A2326121B1E0D1417070C0D090C0D101517161C201B2428
212B2F2631362A373D2E3C4232414835464D384A513B4E553E525940555D435861455B64
475E6748606A4A636D4C6570
4E67724E67714E66704D656F4D656D4D646C4C626A4C61684B5F664A5D64485B6146585D
4454594251553F4C503B474A374143323A3C2D34342C33332F3636303838303938303938
303A39303A3A2F3A3B303C3E334042344144344145354247364448364349334045313E43
2E3B4029353A232E321C272A172124131B1D0E13150E1316161D201B2428202B2F253136
29363C2D3C4231404734454B3749503A4C543C50573F535B41565E435861455B64465D66
48606949626B4B646E4C6670
4E68724E67714D67704D666F4D656E4D646D4D646C4C626B4B61694A5F67495E65485B62
46595F44565C4252583F4F533C4A4E3845493440432E393C2832342731332B36382D393B
2B38392B38392D3B3D2F3E41314043314043303F44303F452F3E442F3E442E3D432D3B41
2B383D283338242E321E272A181F22151C1F1921251E292D232F3427353A2B3A402F3E45
32424935464D384A513A4D553C50583E535B40555E425860445A63455C65475E67486069
49626B4A636D4B656F4C6671
4E67714E67714D67714D67704D66704D666F4D656E4C646D4C636C4B626B4B61694A5F67
485E65475C6346596044575D41545A3F50563C4D5239494E36454A334247303E442D3B41
2E3C42303E432F3E42303F4232424534444835454A34454B34444B33434A324349324249
303F4629373C243034232E3426333829363C2B39402E3E4431424834454C364950394C54
3B4F573D51593F545C40565E425861435A63455C65465D66475F6848606949616B4A626C
4B646E4B656F4C66704D6771
4E68724E67724D67714D67714D67714D67714D66704D66704D656F4C656E4C646E4C646D
4B636C4A626B496169495F68475E66465C64455A6243586042575E40555D3F535B3E525A
3E525A3E525A3D51593D50583A4E56384B54384B53374A52374A5136495136485035474E
34454C35474E384B52394C543A4D553B4F573C51593E535B3F555D41575F425861435A63
445B64455D66465E67475F6848606948616A49626B4A626C4A636D4B646E4B656F4C656F
4C66704C66704D67714D6772
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?ooo`A>J7<4CVUc24iYM0A?JW@7CfYe14m[M@Q@JgH7D6ag155/
M`QAKGP8DFii159^NPMBKgX4DVmk259`N`ABL7`7DW1k259_N`ABKgX8DW1k1e=`N`QCLG/8Dg1j159_
N@=BKWT4DVih159]M`AAKGL8DFaf0e5[M@A@JW<4CfUb14mWL0A>IVl4CfQa1dmYLaM?JG@4CfUc24iY
L`Q>J7<4CVQb5Oooo`005?ooo`A>J7<4CVUc24iYM0A?JW@7CfYe14m[M@Q@JgH7D6ag155/M`QAKGP8
DFii159^NPMBKgX4DVmk259`N`ABL7`7DW1k259_N`ABKgX8DW1k1e=`N`QCLG/8Dg1j159_N@=BKWT4
DVih159]M`AAKGL8DFaf0e5[M@A@JW<4CfUb14mWL0A>IVl4CfQa1dmYLaM?JG@4CfUc24iYL`Q>J7<4
CVQb5Oooo`005?ooo`A>J7<4CVUc24iYM0A?JW@7CfYe14m[M@Q@JgH7D6ag155/M`QAKGP8DFii159^
NPMBKgX4DVmk259`N`ABL7`7DW1k259_N`ABKgX8DW1k1e=`N`QCLG/8Dg1j159_N@=BKWT4DVih159]
M`AAKGL8DFaf0e5[M@A@JW<4CfUb14mWL0A>IVl4CfQa1dmYLaM?JG@4CfUc24iYL`Q>J7<4CVQb5Ooo
o`005?ooo`A>JG<4CVYd14mZM@A?JgH7D6ag155]N0AAKWT4DVii159_NPACL7/3Dg1l15=aO@ADLWh4
E7=n25EdP0AFMH43EWF215IfP`AFMh<4EWN415MhQ0AFN8D4EWN42eIgP`AGMh84EgN315MhQ0mHNH@4
F7V315QgP@AGMX03EgEo15IdOPAFLgd4EG9l15EaN`ADL7T3E6ig159/M@AAJG84D6I^14mUK@A@J744
DFYc4e5[M@M@JgD4D6Ye14mZM0Q?JG@4CVUc14iXLaGoool001Coool4CVUc14iZM0A?JWD4Cf]f1e1/
M`AAKGP4DFii159^N@ABKgX4Dg1k0e=`O0ACLGd4E79n15AcOPQEM804EWF10eIePPAFMX<4EWN315Ig
Q0AGN8@4EWR515IgQ0]FMh<4EgN215MgP`AGN8@?F7V415QiP`AHMh44EgJ00eMeO`AFM7h4EW=m15Eb
O0AELG/4E71i0eA^M`ABK7D4DFUb151VKPA?IFd4D6Qa155ZLa=AJgD7D6]e151ZM@A?JW@8CfUd14iY
L`A>J7<Eoooo000Doooo14iYL`A>JW@4CfYe14m[MPM@K7L4DFeh155^N@ABKWT4DVmj15=`N`=CL7`4
Dg5m15AbOPADLgh8EGB015IeP@=FMH84EWJ315IgP`AFMh@4EgR415IhQ@AFMh@;EWN315MgPPAGMh<4
EgR43eQiQ0AHNH<4F7N115MfP0=GMGl4EWAn15IcO@AELW`4EG5k15A`N@=DKWL4DVae155YLPA@IVh4
CfE]151XL@AAJW<CDF]e1e1[M@A@JWD4CfYd24mYM0A>JG<4CVQc5Oooo`005?ooo`A>JG<4CVYd14mZ
M@A?JgH7D6ag155]N0AAKWT4DVii159_NPACL7/3Dg1l15=aO@ADLWh4E7=n25EdP0AFMH43EWF215If
P`AFMh<4EWN415MhQ0AFN8D4EWN42eIgP`AGMh84EgN315MhQ0mHNH@4F7V315QgP@AGMX03EgEo15Id
OPAFLgd4EG9l15EaN`ADL7T3E6ig159/M@AAJG84D6I^14mUK@A@J744DFYc4e5[M@M@JgD4D6Ye14mZ
M0Q?JG@4CVUc14iXLaGoool001Coool4CVUc14mZM0A@JgH4D6ag155]N0=BKWT4DVmj15=`O0ADLWd4
E7=n15EdP0=FMH44EWJ215MgP`AHN8@4F7V515UjQ`AJNhP3FWb:15]mR`AKOX`4Fgn=15^0S@AKP8h4
Fh2=0e]oS0AKOh/4Fgj;15]nRPAKOhX;G7n:15b0RPALOhT4Fgf715YlQ@AJNX@3FGV315UiPPAIN884
FGN115UeO`AHLgd3EW5j15E^M`ACJg<4DFM^155WK`ABJW<4Dfae0e=]MPaCKGL4DVeg159/M`=AK7H4
DF]f151[M@A@JWD4CfYd14mYM0A>JG<Eoooo000Doooo14iYL`A?JW@4D6]f151/M`AAKGP3DVii159_
NPACL7`4E79m15AcOPAEM803EWF115IfPPAGMh<4F7R415QiQ@AINXL4FW^80eYlRPAKOH/4Fgj<15]o
S@AKP8d4Fh2>15^0S@=KOh`4Fgn;15]nR`AKOXX4Fgn:2eaoRPALP8X4G7n915]mQ`AJO8D4FWZ40eUi
P`AINH84FGR215UgP@AIMGl4F7=m0eIaNPAEKWL4Df]c155WKPAAIfl4DVYc15=/M@=CKGH<Dfeg159]
M`ABK7L3DFaf155[MPA@JgD4D6Ye14mZM0A?JG@4CVUc5Oooo`005?ooo`A>JG<4CfYd151[MPA@K7L4
DFeh0e9^N@ABKgX4Dg1l15AbO@ADLgh4EGB00eIeP@AFMX84EgN315QhQ0AHNHD4FGZ715YkR0=JO8X4
Fgf;15]nS0AKOhd4Fh2=15^0SPAKP8d3Fgn<15]oR`AKOX/4Fgj:15]oRP]LOhX4G82:15aoR@AKOHL4
FWb515YjQ0=INH<4FGV215UhPPAIMh44FGEo15QcO@=FLGX4EFig15=[L`AAIfh4DFM_159ZL`ACK7D3
Dfef35=]M`ABKGL4DVag0e5/MPAAJgH4D6]e151ZM@A?JW@4CfUd14iYLaGoool001Coool4CVUc14mZ
M0A@JgH4D6ag155]N0=BKWT4DVmj15=`O0ADLWd4E7=n15EdP0=FMH44EWJ215MgP`AHN8@4F7V515Uj
Q`AJNhP3FWb:15]mR`AKOX`4Fgn=15^0S@AKP8h4Fh2=0e]oS0AKOh/4Fgj;15]nRPAKOhX;G7n:15b0
RPALOhT4Fgf715YlQ@AJNX@3FGV315UiPPAIN884FGN115UeO`AHLgd3EW5j15E^M`ACJg<4DFM^155W
K`ABJW<4Dfae0e=]MPaCKGL4DVeg159/M`=AK7H4DF]f151[M@A@JWD4CfYd14mYM0A>JG<Eoooo000D
oooo14iYM0A?JgD4D6ag155]N0ABKgX3Dg1k15AaO@AELgh4EWB015MePPAHMh<3FGV515UjQ`AJO8T4
Fgf:15aoS0AMP8h4GX:@0ej3T@AOQI<4H8JD1627UPQPR9L4GhNE0en6U0AOQY<8GhFB15n5T@AOQ8l3
GX>=15f2S@ANPX`4GX6;15f1R`AMPHX4G8290eaoR0ALOXL4G7b615akQ0AKNH84FWJ00eUdO@AGLGX4
EVif15A[L`ADK7@4EFef15E^N0]EKgT4E6mi15A^N@ACKWP3Dfeh159]M`AAK7H4DF]f151ZM@A?JW@4
CVUc5Oooo`005?ooo`A>JG@4Cf]e151/M`AAKGP4DVmj0e=`N`ADLGd4EG=n15IdP0AGMH84F7N30eUi
Q@AINXL4FWb915]mRPALOh`4GH2>15j2T0=NPi44GhFC1626U0APQiH8H8RG15n7U@=OQY@4GhJC25n5
TPAOQI44GhB?0ej3S@AMPXd4GX:<15j1R`AMPH/4GH6:15b0R@=LOhP4G7j715alQPALNh@4FgV215Yf
P0=IM7d4Eg5j15I^MPADJg<4E6ad15E]MPAEKWP;EFmi15A_N@ADKWT4Dfih0e=]N0ABKGL4DFaf155[
MPA@JWD4CfYd14iYLaGoool001Coool4CVUd14m[M@A@K7L4DFeh159_NP=CL7/4E75m15EcOPAFM804
EgF215QgP`=INHD4FGZ715YlR@AKOHX4G7n<15f0SPANPY03GX>A15n5T`APQY@4H8NF2628U`AOQiD3
GhJD15n6T`QOQI84GhFA15n4S`=NPhd4GH:=15j2S0ANPH/4GH6;15f1RPALP8T3G7n815anQ`ALO8H4
G7^415]iPPAJMX03FGAm15MaNPAFKWH4E6]c15A/M0AEKGH4EFih2eE_N@ADKgT4E6ii15=^N0=CKGP4
DVeg155/MPAAJgH4D6Ye14mZM0A>JG<Eoooo000Doooo14iYM0A?JgD4D6ag155]N0ABKgX3Dg1k15Aa
O@AELgh4EWB015MePPAHMh<3FGV515UjQ`AJO8T4Fgf:15aoS0AMP8h4GX:@0ej3T@AOQI<4H8JD1627
UPQPR9L4GhNE0en6U0AOQY<8GhFB15n5T@AOQ8l3GX>=15f2S@ANPX`4GX6;15f1R`AMPHX4G8290eao
R0ALOXL4G7b615akQ0AKNH84FWJ00eUdO@AGLGX4EVif15A[L`ADK7@4EFef15E^N0]EKgT4E6mi15A^
N@ACKWP3Dfeh159]M`AAK7H4DF]f151ZM@A?JW@4CVUc5Oooo`005?ooo`A?JW@4D6]f155]N0ABKWT4
Dg1l0eEbOPAFM804EgJ215QgQ0AINHH4FW^80e]mRPALOh`4GX6>15n2T0APQ9<4HHJE16:8U`=SRYT4
I8bL16B>WPAUSil8II2P16B>WP=TSId4I8fK16B<VPATRiP4Hh^G16>:U@=SRI@4HXRC16:7TPARQY44
HHF?1624S`APQ8h3H8:=15n1R`AOPHX4Ggj815ilQPAMNX@3G7R115]eOPAHLGT4Efif15M`N0AHLGX4
F79k0eQbO0AGLW`4Eg5l15IaN`AFL7/4EG1j0eA_N@ACKWT4DVeh155/M`A@JgH4CfYd14iYLaGoool0
01Coool4CfYd151[MPAAKGP4DVii15=`O0=ELWh4EWB015MfPPAHMh@4FGV615YkR0=KOHX4G7n<15j1
SPAOPY04H8BC1666U@ARR9L3HhZI16B<W0ATSYh4IHnO26F@X0ATSYh3I8fM16B=V`ATS9X4I8^H16>;
U`ASRYD3HhVD16:8T`ARQi84HXJA1665S`APQ8l4H8B>0f22S@AOPH/4Gh6:15mnR0ANO8H4GGZ40eah
P@AKMGh4F75i15M^MPAGL7P4F75j15QbN`=HLW`4Eg9l15MaO0AFLG/4EW1k15E`NP=DKgT4Dfii159]
N0AAK7L4D6]f14mZM0A>JG<Eoooo000Doooo14mZM0A@JgH4DFeh159^N@ACL7`3EG9n15IdP0AGMX84
F7N415UiQPAJNhP3Fgf:15aoS0ANPHh4Gh:@1624T`AQQYD4HXRG0f>:V@ATS9`4I8jN16F?W`QUT:04
I8jN0fB=W@ATSI/4I8bJ16B;V0ASRiL4HhZE0f>9U0ARR9<4HXNB16:6T@AQQHl4H8B?1624SP=PPXd4
Gh6;15n1RPAOOXP4GWb615ejQ0=LN844FgEn15QaN@AGKWH4Eg1h15QaNPAHLW/3F79l15MbO0AGLG`4
EW5k15I`N`AEL7X3E6mi15=^N@ABKGP4DFag151[MPA?JW@4CVUc5Oooo`005?ooo`A?JW@4D6]f155]
N0ABKWT4Dg1l0eEbOPAFM804EgJ215QgQ0AINHH4FW^80e]mRPALOh`4GX6>15n2T0APQ9<4HHJE16:8
U`=SRYT4I8bL16B>WPAUSil8II2P16B>WP=TSId4I8fK16B<VPATRiP4Hh^G16>:U@=SRI@4HXRC16:7
TPARQY44HHF?1624S`APQ8h3H8:=15n1R`AOPHX4Ggj815ilQPAMNX@3G7R115]eOPAHLGT4Efif15M`
N0AHLGX4F79k0eQbO0AGLW`4Eg5l15IaN`AFL7/4EG1j0eA_N@ACKWT4DVeh155/M`A@JgH4CfYd14iY
LaGoool001Coool4CfYe151/M`ABKWT4Dg1k15EbOP=FM804EgJ215UhQ@AJNXL4Fgf:15eoS0=NPHl4
Gh>A1666U0ARR9H4HhZI16F<W0AVSil3Ii6Q16RDY0AZUZL4JYRY16ZIZPAZV:T4JIJV0fRDX`AXTj84
J9:Q16RBW`AXTIh4J96M0fR@W0AWSi/4IhjI16J<U`AVRiH4IX^E16F:U0=UR9<4IHNB16B5T0ASQ8l4
HX:<165oR@=PO8H4GWV215]dO0AJLWX4FgAm15]eOPAKMGl7FWEo15UdO`AHLgh4Eg=m15IbO0=EL7/4
E6mj15=^N@ABKGP4DFaf151ZM@A?JG@Eoooo000Doooo14mZM@A@K7L4DVii15=`N`AELWh3EWB015Mf
PPAIN8D4FWZ715]mRPAMOh`3GX6?15n3T@AQQY@4HXRF16>:V@AUS9`4IXnO0fNAX@AXU:@4JYJW16ZH
Z@AZVJX4JYRY16VFYP=XU:<4J9>R16RBX@AXTYl4J96N16RAW@=XT9`4IhnK16N>V@AVS9L4IX^F16J;
U@AURY@3IHRC16F7TPATQI04HhB?16:2S0AQOhT3H7b615iiPPAKM7`4FW9j15]dO@AKMGh4FgEo1eYe
O`AIM7l4F7=n15McO@AFLW`3EG1k15A_NPACKWT4DVeh155/MPA@JWD4CfUd5Oooo`005?ooo`A?JWD4
D6ag159^N@ACL7/4EG9n0eIdP0AGMX84FGR515YjQ`AKOHX4GGn<0ej1S`AOPi44HHJD16:8UPASRYT4
IHbL16J?W`=WTJ44J9BT16ZFY`AZV:T4JYVZ16ZHZ@AYUZH3J9BS16RCXPAXTZ44J9:O16RAWPAXTId3
J92L16N?V`AWSYT4IXbG16J;UPAVRiD4IHZD0fF8T`AUQi84I8F@16>4S`ARPX`4HGn90f1lQPANNH84
FgAl15YbNPAKM7d4FgEn15]eO`MJMGl4FGAo15QcOPAGLgd4EW9l0eE`N`ADKgX4Dfii159]N0AAK7H4
D6Ye14mYM1Goool001Coool4CfYe155]N0ABKgX4E75m15IdP0=GMX84FGV515]kR0ALOX/4GX2>15n3
T0=QQI<4HXRF16B:V@AVSI`4Ii2P16VCX`AZUJH3K9RY16fK[@A_Wk44LJ:d176T]`A_XK@4KIf]0fbK
ZPA/VJT4K9VW16bHYPA/V:D4K9RT1fbGX`A/Uj84K9JQ16bDW`A[Tih4Ji6M0fZ@V`AZSYT4JH^G16R9
U@AWQi<4IHF@0f>1R`AQOHL4GgV215mhP@QNNH<4GWV40eeiP`ALN8<4FgN215YfP@AIM7l4F7=n0eMb
O@AELG/4E71j15=^N@ABKGL4D6]e14mYM1Goool001Coool4CfYe155]N0ABKgX4E75m15IdP0=GMX84
FGV515]kR0ALOX/4GX2>15n3T0=QQI<4HXRF16B:V@AVSI`4Ii2P16VCX`AZUJH3K9RY16fK[@A_Wk44
LJ:d176T]`A_XK@4KIf]0fbKZPA/VJT4K9VW16bHYPA/V:D4K9RT1fbGX`A/Uj84K9JQ16bDW`A[Tih4
Ji6M0fZ@V`AZSYT4JH^G16R9U@AWQi<4IHF@0f>1R`AQOHL4GgV215mhP@QNNH<4GWV40eeiP`ALN8<4
FgN215YfP@AIM7l4F7=n0eMbO@AELG/4E71j15=^N@ABKGL4D6]e14mYM1Goool001Coool4CfYe155]
N0ABKgX4E75m15IdP0=GMX84FGV515]kR0ALOX/4GX2>15n3T0=QQI<4HXRF16B:V@AVSI`4Ii2P16VC
X`AZUJH3K9RY16fK[@A_Wk44LJ:d176T]`A_XK@4KIf]0fbKZPA/VJT4K9VW16bHYPA/V:D4K9RT1fbG
X`A/Uj84K9JQ16bDW`A[Tih4Ji6M0fZ@V`AZSYT4JH^G16R9U@AWQi<4IHF@0f>1R`AQOHL4GgV215mh
P@QNNH<4GWV40eeiP`ALN8<4FgN215YfP@AIM7l4F7=n0eMbO@AELG/4E71j15=^N@ABKGL4D6]e14mY
M1Goool001Coool4CfYe155]N0ABKgX4E75m15IdP0=GMX84FGV515]kR0ALOX/4GX2>15n3T0=QQI<4
HXRF16B:V@AVSI`4Ii2P16VCX`AZUJH3K9RY16fK[@A_Wk44LJ:d176T]`A_XK@4KIf]0fbKZPA/VJT4
K9VW16bHYPA/V:D4K9RT1fbGX`A/Uj84K9JQ16bDW`A[Tih4Ji6M0fZ@V`AZSYT4JH^G16R9U@AWQi<4
IHF@0f>1R`AQOHL4GgV215mhP@QNNH<4GWV40eeiP`ALN8<4FgN215YfP@AIM7l4F7=n0eMbO@AELG/4
E71j15=^N@ABKGL4D6]e14mYM1Goool001Coool4Cf]e155]N0ACL7`4EG=o15MfPP=IN8D4Fg^815an
R`ANPHh4H8BA16:6U@=TRIP4IHbK16N?W`AYTZ84JiFV16bIZPA^W:d3L9na17:S]PAeYkX4NJk217J[
_`AaY;L4L::c0g2P/0A`Wjh4L9n]176O[@]aWj`4LJ2/17:PZ`AbWj/4LYjY17:LY`AaVZD3L9NS172E
X@A_TYh4KHnK16^<V0AYRYD3IhJA16F2S@ASOhT4Hgj9269nR@AQOHP3H7b715mkQPANNXD4G7R315]g
PPAJMH03F7An15MbO@AEL7/4E6ii159]M`AAJgH4CfYd5Oooo`005?ooo`A?JgD4DFeh15=`O0AELgl4
EgJ20eUhQ@AKNhP4G7j;15j1SPAPQ944HXJE0fB9V0AUS9/4IhnO16VBXPA[UJH4K9VZ16jL[@=`Wk44
LZ>f17FW^PAi[/84MZ^o176T]`A`X[<3L:2`172O[PA`Wjd4LIn]2g6O[0AaX:`4LZ2[17:OZ`AbWZT4
LYbW176JY@=`Uj<4L9FQ16nBWPA]Si/4JhbH16V:U@=WQY44IH:=16=oR@ASOXT8HWj9165mR0=PO8L4
Gg^615ijQ@ALN8<4FgN215YeP0=HM7h4Eg9m15E`N`ADKWT4DVeg155[MPA?JW@Eoooo000Doooo14m[
M@AAKGP4Dg1l15EcO`AGMX83FGR515]kR0ALOX/4GX6>1624T@ARQYD3I8VH16F<V`AWSil4JI:R16^E
YPA/VJX4KYb]0g2O/@AbXkH4MJNj17V^`PAfZkl4LJBg172R/`=`X;04L9n^172O[@AaWjd;LIn/176P
[0AbX:/4LYn[17:NZ@AbW:L4LIZU0g2GX`A`UJ44Ki:N16f?V`A[S9P4JHZE0fN6T@AUPXd4Hgn916=n
R@QROXT4HGf80f1lQ`AONhH4GWZ515ahP`AKMh84FWF00eQdOPAGLWd4EG1k15A^N@ABKGL4DF]f14mZ
M1Goool001Coool4Cf]e155]N0ACL7`4EG=o15MfPP=IN8D4Fg^815anR`ANPHh4H8BA16:6U@=TRIP4
IHbK16N?W`AYTZ84JiFV16bIZPA^W:d3L9na17:S]PAeYkX4NJk217J[_`AaY;L4L::c0g2P/0A`Wjh4
L9n]176O[@]aWj`4LJ2/17:PZ`AbWj/4LYjY17:LY`AaVZD3L9NS172EX@A_TYh4KHnK16^<V0AYRYD3
IhJA16F2S@ASOhT4Hgj9269nR@AQOHP3H7b715mkQPANNXD4G7R315]gPPAJMH03F7An15MbO@AEL7/4
E6ii159]M`AAJgH4CfYd5Oooo`005?ooo`A@JgH4DVii15AbO@AFMH04F7R40eYkQ`ALOX/4GX6>1624
TPARQiD4IHZI0fN>W@AYTJ04JiBT16bHZ0A^Vj`4L9j`17:R]@=dY[T4MjZn17V_``Ak//H4M:Zn17>W
^PAcY[L3M:Ff17BU]@QeYK@4MJFc17JU/P=fY[<4MjRd17NY]@AhZKD4N:Rc17RU/@AgXZd3MYjZ17JL
Z0AdV:@4LYFQ172BWPA^Si/3K8fH16Z:UPAXQi84IhJB16J5T0AUPhl4I8:>0f>0S0AROhX4H7f815mk
QPAMNH@4FgN20eYeP0AHLgh4EW5l15E_NPACKGP4DFaf14mZM1Goool001Coool4D6]f159^N@ADLWd4
EWF015QhQ0=JNhL4G7j;15j1SPAPQ984HXNE16F:V@=WSYd4JI6P16^DY0A/V:P4KY^/172N/0AbX[D3
M:Ji17NZ_PAi[l<4Nk;617BZ_PAcYkX4LjJg0gBU]PAdYKD8MJFd17FU/`AfYK83MZJc17NX]0AgZKD4
N:Ve17RX/`AhYK44Mj:]0gJNZPAfW:P4M9RT17:EX@A`TYh4KXnK0fb=V0AZRYH4J8NB16N6TPAVQI04
IH>?16B2SP=SP8`4HWn:161mR0AONhH4GGV415]gPP=JMH04F7=n15IaO0AEKgX4Dfeh155/MPA?JW@E
oooo000Doooo151[MPABKWT4E79m15IeP0AHN8@3FW^715anR`ANPHh4H8BB16:7U@AURYT3IhjM16VA
X0A[U:@4K9RX16jK[0A`W[04LZ:e0gBV^@AgZ[h4NJo317^baPAdZ[h4LjNj17>V]`=dYKH4M:Fe27FU
]0AeYK<4MZFb0gJV/`AgZ;@4MjVe17RY]@AhZ;<4N:Fa17NR[@=fWZX4MYbX17BHY0AbUJ44L9:N16j?
V`=/SIP4JXZF16R7TPAWQY84IXF@16F3S`ATPXh3Hh2<169oRPAPOHP4Gg^615eiQ0AKMh83FWF015Qc
OPAFLG`4EFmj15=]N0AAK7H4CfYd5Oooo`005?ooo`A@JgH4DVii15AbO@AFMH04F7R40eYkQ`ALOX/4
GX6>1624TPARQiD4IHZI0fN>W@AYTJ04JiBT16bHZ0A^Vj`4L9j`17:R]@=dY[T4MjZn17V_``Ak//H4
M:Zn17>W^PAcY[L3M:Ff17BU]@QeYK@4MJFc17JU/P=fY[<4MjRd17NY]@AhZKD4N:Rc17RU/@AgXZd3
MYjZ17JLZ0AdV:@4LYFQ172BWPA^Si/3K8fH16Z:UPAXQi84IhJB16J5T0AUPhl4I8:>0f>0S0AROhX4
H7f815mkQPAMNH@4FgN20eYeP0AHLgh4EW5l15E_NPACKGP4DFaf14mZM1Goool001Coool4D6]f159_
NPAELWh4EgJ215UiQP=LOHT4GX2=1623T@ASQiD4IHZI16N>W@=YTZ44K9FU16jIZPA`WJh4LZ2b17BT
]`AfZ;/3N:c017Z`a@Am]<X4MJc316nU^PAdZK`4MZZl0gN[_0AhZk`4NJ^k17Z[^PAj[;X4Njbj0g^]
^PAl[k/4OK2k17f_^`Am[[T4OJbg17fY]0=lY[84NZ:^17VOZ`AgVjL4M9RT176DX0=`TYh4KY2L16f>
V`A/SY/4JX^H16V9U@AXQi<3IXB@16B2SPASP8`4HGj915mkQ`AMNH@3FgN215UeP0AGLgd4EG1k15=^
N@AAK7L4CfYd5Oooo`005?ooo`A@JgH4DVmj15EbOPAGMX84FGV60eamR@ANP8d4H8>A16>7U@AURYT4
IhjM0fVBX@A/UJD4KYVZ172M[PAbX;84M:Bg17JX^`=h[<04N[3517fdbPAe[<<4KjFj17BY_0AfZ[`3
Mj^l17R[_0AiZk/4NZ^j17Z/^PAk[;X3Njfj17b_^`Am/;/4OJnk17f^^@Am[;L4OJVd0gbV/PAjXZh4
NIn[17NKY`AdV:@4LIBP0g2BWPA^T9`4KHjK16b>V`AZRiP4JHVE16R7T`=VQ904I8:>16>0S0AQOXT4
Gg^715eiQ0=KMh84FGF015McO@AEL7/4Dfii155/M`A?JW@Eoooo000Doooo151[MPABKgX4EG9n15Mf
PPAINHH3G7f915j0S@APPi44HhNE16F:V@AWSYd3JI:Q16bEY@A^VJX4L9f^17:P/PAdY;L4MZRk0gR/
`0Aj/<D4OKC:17F/``A_YKX4M:Vl17JZ_0=gZk`4N:^l17V[^`AjZkX4NZbj17^/^P=k[KX4O:nk17f`
^`Am[k/4OJji17f/]`AmZK@3O:Jb17ZR[PAiWj/4Mi^W17BHY0AaU:03L9:N16j@W0A]SY/4K8jK16Z;
V0AYRID4J8NC0fJ4T0ATPXh4Hh2<165nR@AONhL4GGV40e]gPPAIMH04Eg=m15E`N`ACKWT4DFag14mZ
M1Goool001Coool4D6]f159_NPAELWh4EgJ215UiQP=LOHT4GX2=1623T@ASQiD4IHZI16N>W@=YTZ44
K9FU16jIZPA`WJh4LZ2b17BT]`AfZ;/3N:c017Z`a@Am]<X4MJc316nU^PAdZK`4MZZl0gN[_0AhZk`4
NJ^k17Z[^PAj[;X4Njbj0g^]^PAl[k/4OK2k17f_^`Am[[T4OJbg17fY]0=lY[84NZ:^17VOZ`AgVjL4
M9RT176DX0=`TYh4KY2L16f>V`A/SY/4JX^H16V9U@AXQi<3IXB@16B2SPASP8`4HGj915mkQ`AMNH@3
FgN215UeP0AGLgd4EG1k15=^N@AAK7L4CfYd5Oooo`005?ooo`A@K7H4Dfmk15EcO`AHMh<4FgZ70een
R`APPY04HXJD16F:V0AWSYd4JY:Q0fbFYPA_VZX4LIj_17>R]0AfY[P4N:Zm17Z^`P=l//L4P;W?17Vb
b0AaZ;h4M:^o17N]`0Ai[/43Nk3217ba`PAm/L84O[7117na`0Ao//03P;C0182f`@B1]l84PKK1186e
_`B1/kd4PJnj0h6/]`AoZ;@4OJB`17^P[0AhW:T4MYVV0gBGY0AbUZ<4LYJT172DXPA_TIl4KHjK16^;
V0=YRID4IhJB16F3S`ASP8`4HGj915mkQP=MNH@4FgJ115QdO`AFLG`4E6mj159/M`A@JWDEoooo000D
oooo151/MPACKg/4EG=o15QgP`AKNXL3GGj;1622T0ARQY@4IHZH16N>W@AZTZ43K9JV16nJZPAaWZl4
Lj:d17JV^0AhZ[d4NZk20gbba`B0^Ll4NK;8176X_PAdZkl4Mjg017V^`@=k/<84O;7217fa`PAn/L44
Ok7017nb`0>0]<04P;K1186g`PB1]/44PKFo186c_@B1[kX3PJbg17nX]0AmY;04Nj2/17RLZ@AfVJH3
M9NT17:FX`AbUZ@4L9BR16nAW`A]SY/4Jh^H0fV9U@AWQY84IH>?16>0S0AQOXT4Gg^60eeiQ0AKMX44
F7Ao15IaO0ADKgX4DVag151ZMAGoool001Coool4D6af15=_N`AELgl4F7N315]jQ`=MOX/4H8:@16:6
U0AURYP4IhjM16ZBX@=/UZH4KiZZ176N[`AcX[@4MZJh17RZ_@Aj[/83O;;7182ic`Ai//P4LJRn17B[
_`Ag[L04NJk10g^``PAl/L84OK7217ja`@Ao/L04Ok;00h2d`0B0]/44PKO2186f`@B1]Kl4PK>m186_
^P>1[;L4OjRd17fT/0AkX:`4N9bY17JIYP=dUj@4LYJS17:FY0A`U:84Ki6O16f>V`A[RiP3JHVE16N6
TPAUPhl4Hh2<165nR@AONhH3GGV415]fP@AHM7l4EW5l15A_NPABK7L4D6Ye5Oooo`005?ooo`A@K7H4
Dfmk15EcO`AHMh<4FgZ70eenR`APPY04HXJD16F:V0AWSYd4JY:Q0fbFYPA_VZX4LIj_17>R]0AfY[P4
N:Zm17Z^`P=l//L4P;W?17Vbb0AaZ;h4M:^o17N]`0Ai[/43Nk3217ba`PAm/L84O[7117na`0Ao//03
P;C0182f`@B1]l84PKK1186e_`B1/kd4PJnj0h6/]`AoZ;@4OJB`17^P[0AhW:T4MYVV0gBGY0AbUZ<4
LYJT172DXPA_TIl4KHjK16^;V0=YRID4IhJB16F3S`ASP8`4HGj915mkQP=MNH@4FgJ115QdO`AFLG`4
E6mj159/M`A@JWDEoooo000Doooo151/M`ACL7/4EWB015UhQ0ALO8T3Gh6>1665TPATRIL4IhfL16ZA
X0A/UJD3KiZZ17:N[`AdX[@4MjNi17Z[_PAl/<@4OkC90h2icPAk]</4MJk417N_a@Ai/<D4Nk7517fc
aP=o]LP4PKO818:gb0B3]lL4PkO618BhaP>4^<D4Q;O318Fd`@B5/l04QK6m28J`_0>5/;X4Q:bg18:W
]0AoXk04O:2/17ZMZ@=gVZL4MYVV17FHYPAdVJP4LiRW176CX@A_T9d3KHfI16Z9UPAXQY84IX>?16>0
S0AQOHP3GWZ515agPPAIMGl4Eg9m15E_NPABKGL4D6Ye5Oooo`005?ooo`A@K7L4Dg1k15IdP0AIN8@4
G7b90en1SPAQQI84I8VG16N=W0AZTJ04K9FU0fnJZPAbWZl4M::d17NW^@AjZkh4O;3417ndb@>0^Lh4
NkC;17F^a0Ag[lD4NK3517^aa@Am/lH3OkG8186gb0B2]lP4PkO718>gaPB4^<H3Q;S518Bg``B5]<44
QK?018Fa_@R6/;`3QK2j18B/]`B2Yk@4Oj>`17bP[0AjWJT3MiZW17JIYPAeV:H4M9VX17>HY`AaTj44
Ki2M0ff=V@AZRIH4J8JB16J3S`ASP8`4HGf80eijQ@ALMh84FGEo15MbO@AEKgX4DVeg151ZMAGoool0
01Coool4D6ag15=`N`AFM804FGR415alR@=OPHh4HHFB16B9U`AWSI`4JY6P16bEY@=_VZX4LYj_17BR
]0AgYkT4NZ^n17b`a0Ao]<T3P;W>17^db`Ae[/@4Mjo517V`a@Ak/LD4OK?60gneb0B1]lP4P[O818>g
a`B3]lH4Q;S60hBha@B4]l<4QKC118Fc`0B5/Kd8Q[2l0hF`^PB4[;L4PZNd17nS/0AlX:`4NYfY0gNJ
Y`AfVJH4MIRV17BIZ0AcV:L4LI>Q16n@W@=]SIT4JXVF16R6TPAVPhl4Hh2<165mR0=NNXD4G7N215Ue
O`AGLWd4EFmj159]M`A@JWDEoooo000Doooo155/M`ADLG`4EgF115YjQPAMOX/3H8>@16>7U@AVS9X4
JI2O16bDY0A_VJT3LYj^17FR]0AhYkT4Njbo17jaa0B0]LX4Pk[@0hK0ePB1^m<4O;G<17bdbPAm]<T4
OkG9186gb`>4^/d4Q[c=18Nlc0B8_</4RKc;18Rkb@>8^LH4R;C218R`_@B8ZkT4R:Vg18V/^@N:[k/4
R:fi18JZ]PB3Yk<4P:>`17fO[@=kWJX4NI^Y17RKZ@AgVjT4MYZY17FHY`AcU:83L96N16j=V@A[RID4
J8JB16F2SPAROhX3H7b715eiQ0AJMX44F7=n15E`N`ACKGP4D6]e5Oooo`005?ooo`AAK7L4E75l15Me
P@AJNXH4GGj;0f23T0ASQiD4IXbJ16V@W`A/U:@4KiVY0g:N[PAeX[@4N:Ni17^/_`An/L@4P;G:18>j
d0>6`=H4PK_C17bec0Al]<X4OKC917neb@B1]l/3Q;[=18Jlc@B7_<`4R;c;18Vlb`B8^lT3R;W618Rd
`PB8/;d4R:^i18RY]`B9[;T7RZnk18R]^@B6Z[H4PjNc182S/0AmWjd3NifZ17VKZ@AhVjT4Mi^Y17JJ
Z@AeV:L4LiBR0g2AWPA^SIT4JhVE16R6TPAUPXh4HWn:0f1lQ`AMNH@4FWJ115QcOPAEL7/4Dfeh151[
MAGoool001Coool4DFag15AaO0AGMH44FWZ615enR`=PPi04HhNE16J<VPAYT9l4K9BT16nIZ@=bWZh4
MJ:d17RW^@Ak[;l4O[74182ebPB3^]03Q/3F186kd`Al]L`4O;C:17fdb@Ao]LT4PKO;0hBjc@B6_<d4
Qkc<18Rlb`B9_</4R;_90hRiaPB8]<84R;2m18R[^@B8ZKL4RJbi1hZ_^`B8[KT4QZZf18>W/`B0Xk04
OIn]0g^MZPAiVjT4N9^Y17NKZ@AfVZT4MIRW17>DXP=`TIh4KXfI16^9U@AXQY84IH:>169oRP=PO8L4
GGV415YfP@AHLgh4EG1k15=]N0A@JgDEoooo000Doooo155/M`ADLG`4EgF115YjQPAMOX/3H8>@16>7
U@AVS9X4JI2O16bDY0A_VJT3LYj^17FR]0AhYkT4Njbo17jaa0B0]LX4Pk[@0hK0ePB1^m<4O;G<17bd
bPAm]<T4OkG9186gb`>4^/d4Q[c=18Nlc0B8_</4RKc;18Rkb@>8^LH4R;C218R`_@B8ZkT4R:Vg18V/
^@N:[k/4R:fi18JZ]PB3Yk<4P:>`17fO[@=kWJX4NI^Y17RKZ@AgVjT4MYZY17FHY`AcU:83L96N16j=
V@A[RID4J8JB16F2SPAROhX3H7b715eiQ0AJMX44F7=n15E`N`ACKGP4D6]e5Oooo`005?ooo`AAKGP4
E75m15QfPPAKNhP4GX2=0f:5TPAURIL4J8jM16^CXPA_V:P4LYf]0gFQ/`AhY[P4Njbn17jaa0B1]/X4
QK_@18S1e`>3_]H4O;K>17jgc@B0]l`4PKO;18>hb`B5^lh3R;kA18_1dPB<`M04SL7?18o1cPB<^<H3
RK2n18R[^@B7Yk<4QjRd18Z[^0B<ZKL4SJRe0hj[^0B=[[/4RZfi18NY]PB3YK84P::^0gjN[0AlWJ/8
Nif[17ZN[@AiWJ`4MiVW0gBEXPAaTId4KXbH16Z8U0AWQ904I86<0f5mR0ANNXD4FgN215UdOPAFLG/4
Dfih151[MAGoool001Coool4DFeh15AaO@AHMX84Fg^815j0S@=RQI84IHVG16R>W@A[Tj84KiRX17:M
[@=eXK<4N:Jh17^/_PAn/L@4PKK:18Fkd0B8`ML3PkkF17bfcPAn]ld4P;O<186gb`B3^</4QK_>0hRn
d@B;`M84S<7@18g1c`B?`Lh4S;S60hV`_PB8ZkT4QjNc18NX]0B:ZkP4S:Vg18fX]@>>ZkP4SJjk18Z]
^@B7ZKH4PjFb182R[P=nWZ`4O9f[27^MZ`AjWZd4NIf/17NIY`=dUJ84LI6M16j<V0AZR9@4IhB@16B1
S0=QOHP4GWZ515]gPPAIM7h4EW5k15=^N0A@JgDEoooo000Doooo155]N0ADLGd4F7J215]kR0ANP8d3
HXFB16F9U`AXSYd4Ji>R16nHZ0AbWJd3MJ6c17RV^0Ak[;h4O[74186fbPB5^m04R<7G0h>nePAl]/h4
O[O=182gc0B1]l/4PkS;18FkcP>8_]44Rl7B18c1d0B=`Ll4Sl7>18bhaP>9/;h4R:^i18NW/`B7Z;@4
RZ^h18bY]`B=Z;D3SZ^h18f^^`B:[KT4QjVf18>U/PB0XZh3OYj/17bMZ`QkWJ/4NYj]17VM[0AgVJL3
M9FR176AW@A^S9P4JXRD16N4T0ATPH`3HGf815ijQ@AKMh84FGAn15IaN`ACKWP4D6]e5Oooo`005?oo
o`AAKGP4E75m15QfPPAKNhP4GX2=0f:5TPAURIL4J8jM16^CXPA_V:P4LYf]0gFQ/`AhY[P4Njbn17ja
a0B1]/X4QK_@18S1e`>3_]H4O;K>17jgc@B0]l`4PKO;18>hb`B5^lh3R;kA18_1dPB<`M04SL7?18o1
cPB<^<H3RK2n18R[^@B7Yk<4QjRd18Z[^0B<ZKL4SJRe0hj[^0B=[[/4RZfi18NY]PB3YK84P::^0gjN
[0AlWJ/8Nif[17ZN[@AiWJ`4MiVW0gBEXPAaTId4KXbH16Z8U0AWQ904I86<0f5mR0ANNXD4FgN215Ud
OPAFLG/4Dfih151[MAGoool001Coool4DFeh15EbOPAIN8<4G7f91621SP=SQY@4IhbJ16ZAX0A^UZD4
LI^[17BP/@=hYKL4Nj^m17j```B2]/X4Q[_@18W0ePB<aM/3QKkF17nhc`B1^<h4P[W>18Bjc@B6^lh4
R;g?0h_0d@B>`M44TL?B18nlb`B9[kd4QZVg0hRY]PB9Z;D8RZVg18ZU/PB9YK44RjJb0hfZ]PB@[;T4
SZfj18Z[]`B6Yk<4Pj>`0h6Q[@AoWj`4Oin]17jP[@AnWjd4OIj[17bMZP=hVJH4M9BP172?V`A]RYH4
JHJB16J2SP=SOhX4Gg^615ahP`AIM7l4EW5l15=^N@A@JgDEoooo000Doooo155]N0AELWh4FGR315am
R@APPHh3HhJD16N<VPAZTJ04KYJU176KZ`AdX;43N:Fg17^[_@An/<<4P[K:18Jkd0B9`=H4S<GK0hFn
ePAo^<l4PKS>18:icPB4^/d4Q[_>18Rmc`>;`=44S/7A1973dPB?_</4RJnm18JY]`>8ZKH4RJRe28ZY
]`B:YK84RJFa18^V/P>=Z[H4T:bi18j]^PB:ZkL4QZNc18>S/0>1XJd4Oin/17nO[@AnX:d4OYn]17fN
Z`AlWJX3N9VV17BDX0A`Si/4KHZF16V6TPAVPXh3Hgn:15mkQPALN8<4FGAo15IaO0ACKWT4D6]e5Ooo
o`005?ooo`AAKGP4EG9n15UhP`ALOHT4H86>0f>6U0AWS9X4JY6P16jFY@AaVj/4M:2a0gRU]`AkZkd4
O[3318:fbPB6^m04RL3F18c5f`>5_]H4OkS?186hcPB2^Lh4Q;[=18JkcPB8_Ll3Rl3A18k1d@BA`m84
Skc;18V__@B6ZKL3R:Vf18VX]@R:ZKL4RZFb18VU/@B;Y[83SJZf192/^@B>[KX4RZ^g18JW/`B3Xk03
PJ6]17nO[0AoWjd4OZ2]17jO[@AmWZ/4O9fZ0gRIYPAdU:04L8nK16f:UPAYQY84IX:>0f=oRPAONhH4
G7R315UdO`AFLG`4Dfii151[MAGoool001Coool4DFeh15EbOPAIN8<4G7f91621SP=SQY@4IhbJ16ZA
X0A^UZD4LI^[17BP/@=hYKL4Nj^m17j```B2]/X4Q[_@18W0ePB<aM/3QKkF17nhc`B1^<h4P[W>18Bj
c@B6^lh4R;g?0h_0d@B>`M44TL?B18nlb`B9[kd4QZVg0hRY]PB9Z;D8RZVg18ZU/PB9YK44RjJb0hfZ
]PB@[;T4SZfj18Z[]`B6Yk<4Pj>`0h6Q[@AoWj`4Oin]17jP[@AnWjd4OIj[17bMZP=hVJH4M9BP172?
V`A]RYH4JHJB16J2SP=SOhX4Gg^615ahP`AIM7l4EW5l15=^N@A@JgDEoooo000Doooo159]N0AELgh4
FGR415emRPAQPi03IHVF16V>W0A/Tj84L9VX17>N[`AgY;D3NZVk17j^`@B2]<P4Q[_?18[1e`B=a]`4
S<KM0h>me0B2^]44Pk[?18FjcPB6^/d4RKc>18^nc`>>_Ll4S[c<18fhb0B9/l<4RK;218^b`P></L04
SK7118jb`PB?//44Sk6o18j`_PB<[K/3RZVf18VV/`B<Z[D4SJfh18ZZ]PB6Y[83Q::_18>Q[PB2XJh8
PJ6_182Q[`AoX:l3O9fZ17RGX`AcTId4KhbH16^8T`AWQ8l3I82;165lQ`AMN8<4FWF015MbO0ADKWT4
DF]f5Oooo`005?ooo`ABKGP4EG=n15UhQ0AMOHX4HH>@0fF9UPAYSY`4K9>R172IZ0AcWZl4MjBe0gZY
^`An[/44P[C818Jkc`B:`ML4SLKL18c6g@>3_M@4P[[A18>jc`B5^/h4Q[[=18VlcPB;_/l3S[g?18jl
c0B=^<P4RK?318Vb`PB;//83S;7018fa`@B>//84Sk;118na_`B>/;h4S:fk0hZY]PB9Y[<4S:Ze18f]
^0B:Z[H4QZJb0hBR[`B3XJh4PZ6^286Q[`B0XJl4Oj2_0gbMZPAhUj<4Li6M16n<V0A[R9<4IhB?0fB0
R`AQO8L4GGR315YeP0AGLW`4E6ii155[MQGoool001Coool4DVeh15EcOPAIN8@4GGf:1663T0=URIH4
JHjL16bCXPA`VJP4Lij_17NT]@=jZK/4OZk118:db0B6^ll4R/7G18g6g0B<a]d3PkgD18:jd@B3^/l4
QK[>18Jjc@B9_<h4Rkk?0hjmc`B>_<`4SKS818Vc``B9//84Rk;20hba`0B=/L44S[;218nb`@B?/Kl4
S[2n18b]^`>:ZKH4RJJc18bZ]@B=[KP4RZZf18JV/P>4XZl4Pj6^18:Q[PR1XJl4P:6_17nP[`=lWJX4
N9NS17>AW@A_S9P4JhRC16N4S`=TP8/4HGb715ehP`AJMH04Eg9l15A^N@AAJgHEoooo000Doooo159]
N0AELgh4FGR415emRPAQPi03IHVF16V>W0A/Tj84L9VX17>N[`AgY;D3NZVk17j^`@B2]<P4Q[_?18[1
e`B=a]`4S<KM0h>me0B2^]44Pk[?18FjcPB6^/d4RKc>18^nc`>>_Ll4S[c<18fhb0B9/l<4RK;218^b
`P></L04SK7118jb`PB?//44Sk6o18j`_PB<[K/3RZVf18VV/`B<Z[D4SJfh18ZZ]PB6Y[83Q::_18>Q
[PB2XJh8PJ6_182Q[`AoX:l3O9fZ17RGX`AcTId4KhbH16^8T`AWQ8l3I82;165lQ`AMN8<4FWF015Mb
O0ADKWT4DF]f5Oooo`005?ooo`ABKWT4EW=o15YiQ@AOOh`4HhFB0fN;V@A[TIl4KiJU17:L[0AfXK84
NZNh0gf/_PB0//D4Q;S<18Voe0BAbN04U<oV18W4g0=o^<l4Pk[?18Jld0B8_<l4R[c>18^lcPB=_<d3
S;S818V`_`B6Z;P4QJNg18Z]_0B=/L03Sk?3196gaPBB^<H4TkS619>ha`BB]lH4TK;10hn`_PB<[KT4
RZZf18b[]`B;ZkH4R:Nc0hNU/@B6Y;44QJB`18FS/0B4XZl4Pj:`182P[P=mWJX4NIRU17FCW`A`SYX4
K8VE16V5T0=UPH`4HWf815iiQ0AKMX04Eg9m15A_N@AAJgHEoooo000Doooo159^N@AFLgl4FWV515mo
S0ASQI83Ih^I16^AW`A_UZD4LYb/17JQ/PAjYkP3OJbn182ba@B4^<`4RKoD1979h0BDcnH4RLCL0gnh
c`B3^/l4Q[c@18Rlc`B:_<h4Rkc>18flc@><^<P4RK2o18JX^0B5YkL4RZfl18fa`0>?/l<4TKO619:h
aPBC^<H4TkS719:gaPBA//43Sk2n18b]^@B:Z[H4S:^g18^[]PB8Yk<3QjFa18JT/@B5Y;04QJ>`18BR
[`B3X[04P:2^0gfMZPAiV:D4MI>O172>VPA/RID4JHF@0fF1S0AROHP4GWV415]fP0AGLWd4E6mi155[
MQGoool001Coool4DVii15IcO`AJNHD4Ggn<16>5TP=WRiT4Ji6O16nFY@AbW:`4MZ6b17ZW^0=m[;h4
P;;518Bhc0B9_m@4TLWP19C?iPB9a=`3OkS?18>jc`B6_=04R;c?18ZlcPB;_<h4SKc=0hbhb0B9/;l4
QZRh18FW]`B:[K`4SK700hnc``BA]lH4T[S619>haPBC^<L4T[O6196b`@>?/;h4S:fi18ZZ]PB<ZkL4
Rj^f18RW/`>7YK44QZBa18FT/0B5Xk04Q::_18>R/0B0X:h3OIfZ17VHY@AeTil4L8jJ16b9U@AYQI03
IH6<169mR0ANNH@4FgJ015MbO@ADKgT4DF]f5Oooo`005?ooo`ABKWT4EgB015]jQPAPPHd4I8ND0fV=
V`A]Tj84LIVX17FO[`AiYKD4O:Zl0h2``PB3]LP4Q[_?18[1ePB?amd4R/?J186id0>1^<h4QK_?18Rl
c`B;_<h4SKc=18jmc@B?_<`3SkW918jd``B</;h4SJjl18j]_@B?[[d3TJnn19:a`0BC/L44U;7119B_
_`BD[kh4Tk2n0i6a_PB?[[/4S:^i18ZX]@B9Yk<4RZNc1hVV/PB8YK44QjFa18NT/@B6YK44RJRe0h>R
[`AkV:H4MYBP17:?VPA^RYD4JXJA0fJ2S@ASOXP4GgZ515]fP@AHLWd4E6mi155[MQGoool001Coool4
DVii15MdP0AKNXH4H86=16B7U0=YSI/4KI>R176IZ0AeWjl4NJFe17bZ_0>0/<84PkG818Jkc`B:`MH4
SlOM18[3fPB1^M03PKS>18Fkc`B8_<l4Rkc>18flc@B>_Ld4Skc<0hnib@B>]<<4S;2n18f^_0B>[Kd4
Sjjm0i6__PBB/L04Tk7119Ba`@BD[kl4U:nn19>`_P>A/Kh4Sjjk18b[^@B:Z;D4RJNc18ZW/`N9Y[84
R:Fa18NU/@B7Y;44QZFa18VX]@>3XZl4NiRV17JDX0AbSiX4KXZE16Z6T@=VPXd4Hgj815mjQ@AKMX44
F79m15A_N@AAJgHEoooo000Doooo159^N@AGM804FgZ61621S@ATQi@3JHfK16fCXPAaVJP4MIn_17VU
]@AlZ[`3P;3218>eb0B6^ll4R/7F18o7g@B:`mX4PKW@0h6hcPB5^ll4R;c?18^lcPB=_<d4S[g=18nl
c0>?^LT4S[C318b`_PB=[[`4SZfm18n^_@>A[kh4T[7019>a`@BD/L44U:no19B__PBC/;h3TK6n18n^
^`B<ZkT4RZRe18VW/`B:Yk<7RJJb18RU/@B7YK44QjBa18JU/@B9Z;D3Pj:_17^HYPAfU:04LXnJ16j:
U@AZQY43IX:=16=nR0AONXD4FgJ115QbO@ADKgT4DF]f5Oooo`005?ooo`ABKWT4EgB015]jQPAPPHd4
I8ND0fV=V`A]Tj84LIVX17FO[`AiYKD4O:Zl0h2``PB3]LP4Q[_?18[1ePB?amd4R/?J186id0>1^<h4
QK_?18Rlc`B;_<h4SKc=18jmc@B?_<`3SkW918jd``B</;h4SJjl18j]_@B?[[d3TJnn19:a`0BC/L44
U;7119B__`BD[kh4Tk2n0i6a_PB?[[/4S:^i18ZX]@B9Yk<4RZNc1hVV/PB8YK44QjFa18NT/@B6YK44
RJRe0h>R[`AkV:H4MYBP17:?VPA^RYD4JXJA0fJ2S@ASOXP4GgZ515]fP@AHLWd4E6mi155[MQGoool0
01Coool4DVii15MeP0ALO8P4HH:?16J9UP=ZSid4KiFT17>LZ`AhX[84O:Ri17n^`0>2/lH4QKW<18Nm
d@B8_m@4P[[A17VbbPAm]</3QK[?18Vld0B<_<h4S[c=18nlc@BA^l`4T[[:0i:ib0BA]lH4T[K519:d
``BC/l84U;C20iFd``BF]/<4V;K419Rea0BI]L<4V;?119Rb`0>F[kd4TjZi18nU/`B:X:d4R9j[18VQ
[@>;YK48RjJa18ZU/@B9YK44RJF`18RT[`>2WZX4OIVV17NCW`AcSi/4Kh^F16^6T@=WPXd4Hgj9161j
Q@ALMX44F7=m15E_NPAAJgHEoooo000Doooo159^N@AGMH04G7b81662S`AVRIH3JXnM16nEY0AcW:/4
N::b17bX^@Ao[/03P[?618Fic0B7_M44R;oD18:jd@Ai//X4OKC;0hFjc`B9_=04S;c>18jlc@B?_<d4
TK_<19:jbP>B^LP4TKO619:fa@BB]<<4Tk?219Bd`P>E]<<4U[K319Rfa0BH]L@4VKG319Rc`@BH//03
UZnm19>Z^@B?YK<4RZ2]18RNZ`B9XJd3RjFa28^V/@B:YK44RJFa18VU/0B8Y:l3PYjZ17fIYPAgTil4
LhnK16n;UPA[QY43Ih:=16=nR@APNXD4G7J115QcO@AEKgX4DF]f5Oooo`005?ooo`ABKWT4EgF015al
R0AQPXl4IXVF0fZ?W@A_UJ@4Lib[17RR/PAlZ;T4Ojk00h:caPB5^L`4QkgA18Roe0B2^]44NK;:17fd
b`>5^/l4RKc@18blcPB>_<d4Skc=196kc0BB^/X3T[W8196gaPBB]/D4T[C319>c`PBD]<83UKC319Jf
``BH]/@4V;G419Ve``BH/l44V;;00iJ__@BCZ[T4SjFc18ZP[@B8WZ/4RJ6]0h^U/@R;Y[44RZFa18VU
/@B9YK04R:B_0h:NZPAmVJH4Mi>O17>?V`A_RiH4JhJA0fN2S@ASOXT4H7Z515afP@AHLgd4EFmj155[
MQGoool001Coool4DVii15MeP0ALO8P4HH:?16J9UP=ZSid4KiFT17>LZ`AhX[84O:Ri17n^`0>2/lH4
QKW<18Nmd@B8_m@4P[[A17VbbPAm]</3QK[?18Vld0B<_<h4S[c=18nlc@BA^l`4T[[:0i:ib0BA]lH4
T[K519:d``BC/l84U;C20iFd``BF]/<4V;K419Rea0BI]L<4V;?119Rb`0>F[kd4TjZi18nU/`B:X:d4
R9j[18VQ[@>;YK48RjJa18ZU/@B9YK44RJF`18RT[`>2WZX4OIVV17NCW`AcSi/4Kh^F16^6T@=WPXd4
Hgj9161jQ@ALMX44F7=m15E_NPAAJgHEoooo000Doooo15=_NPAHMX44GGf916:4T0AXRYP3KI6O176H
Y`AfWjh4NZFe17n/_@B2//@3Q[S:18Vmd0B:`=H4R/;J18O0f0B6_M<4R;cA0h^ndPB>_m44T;k?19:m
cPBC_<`4U;g<19Flb`>E^lT4U[_:19NkbPBG^LP4V;S619VhaP>J^LL4VkW719bia`BM^/P4WKW719fh
a@BL]/83V[>o19N__0BCZ[L4T:Jc18jT/0B<Xjl3SJB_28fW/@B<Yk48RjF`18^U[`>2WJP4OIRS17VD
X0AdT9/4L8^F16b7TP=XPhd4I7n9161kQ@AMMh44FG=m15E_NPAAK7HEoooo000Doooo15=_NPAHMX44
GGf916:4T0AXRYP3KI6O176HY`AfWjh4NZFe17n/_@B2//@3Q[S:18Vmd0B:`=H4R/;J18O0f0B6_M<4
R;cA0h^ndPB>_m44T;k?19:mcPBC_<`4U;g<19Flb`>E^lT4U[_:19NkbPBG^LP4V;S619VhaP>J^LL4
VkW719bia`BM^/P4WKW719fha@BL]/83V[>o19N__0BCZ[L4T:Jc18jT/0B<Xjl3SJB_28fW/@B<Yk48
RjF`18^U[`>2WJP4OIRS17VDX0AdT9/4L8^F16b7TP=XPhd4I7n9161kQ@AMMh44FG=m15E_NPAAK7HE
oooo000Doooo15=_NPAHMX44GGf916:4T0AXRYP3KI6O176HY`AfWjh4NZFe17n/_@B2//@3Q[S:18Vm
d0B:`=H4R/;J18O0f0B6_M<4R;cA0h^ndPB>_m44T;k?19:mcPBC_<`4U;g<19Flb`>E^lT4U[_:19Nk
bPBG^LP4V;S619VhaP>J^LL4VkW719bia`BM^/P4WKW719fha@BL]/83V[>o19N__0BCZ[L4T:Jc18jT
/0B<Xjl3SJB_28fW/@B<Yk48RjF`18^U[`>2WJP4OIRS17VDX0AdT9/4L8^F16b7TP=XPhd4I7n9161k
Q@AMMh44FG=m15E_NPAAK7HEoooo000Doooo15=_NPAHMX44GGf916:4T0AXRYP3KI6O176HY`AfWjh4
NZFe17n/_@B2//@3Q[S:18Vmd0B:`=H4R/;J18O0f0B6_M<4R;cA0h^ndPB>_m44T;k?19:mcPBC_<`4
U;g<19Flb`>E^lT4U[_:19NkbPBG^LP4V;S619VhaP>J^LL4VkW719bia`BM^/P4WKW719fha@BL]/83
V[>o19N__0BCZ[L4T:Jc18jT/0B<Xjl3SJB_28fW/@B<Yk48RjF`18^U[`>2WJP4OIRS17VDX0AdT9/4
L8^F16b7TP=XPhd4I7n9161kQ@AMMh44FG=m15E_NPAAK7HEoooo000Doooo15=_NPAIMh84GWj:16B5
TPAYS9X3KiBQ17BKZ@AiX[44OZVi18:``0B6]/P3R[c?18g2e@B?a]/4T<WO1938gPB@b=d4TLGI0i73
e@BB`]<4U<7A19K0d0BG`<l4V<3>19Voc@>I_/`4VKg;19Zmc0BK_//4W;g;19fnb`>N_//4Wkg;1:2m
bPRQ_LT4XK_719jha0>L]L04VK2k19J/]`BCZ;@4TJJa192U/0>@Yk08T:Ra18jV/0B<YJl8RjB^0h>N
ZPAoVZL4NYFQ17F@V`AaRiH4KHNB0fV3SPAUOhT4HG^515egP@AILgh4EFmj155/MQGoool001Coool4
Dfmj15UgPPANOXX4I8FB16V<VP=_U:44M9^Y17VR/@AnZKT4P[3018Jfb0>:_<l4SL;E18o6f`B@bMl4
T<SN1938g@BAaMT3TL?E19;2d`BD`M44U/3@19O0c`BH`<h4VKo=0iVnc0BI_L/4V[g<19^nb`BL_L/4
WKk;0ijnb`BO_L/4X;g:2:6mb@BQ^lL4W[S40ibe`0BI/;/4UZbg19>X]0BAY[44T:F`0i2W/0R@Z;44
SZJ`18bU[`R;Y:h3PijZ17nJY`AjUJ44MI2K176;UPA]Qi83JH>>16EoR@AQNhD4GGN115UcOPAEKgX4
DFaf5Oooo`005?ooo`ACKgX4FGN215inRPATQI84JHbJ0fnDX@AdVjT4NJ:a17jY^@B2/<04Q[K80hZl
c`B=`]D4SlKK1939g`B@b=h4T<SM1975f@>A`mD4T/;C19C1d@BF`=04Ul3?19S0cPBI_ld3VKk<19Vm
b`BJ_L`4Vkk;19bmb`BM_//3W[k;19nmb`BP_LX8XKg91:6ka`BN^<@3W;G019V`^`BF[;L4TjRd196V
/@B@YK03T:N`292X/@B>Y[04S:F_28^T[P>3WZX4OiZW17ZEX@AeT9/4LH^F16f7TP=YPhh4IGn9165k
Q@AMMh44FG=n15E_NPAAK7HEoooo000Doooo15=_NPAIMh84GWj:16B5TPAYS9X3KiBQ17BKZ@AiX[44
OZVi18:``0B6]/P3R[c?18g2e@B?a]/4T<WO1938gPB@b=d4TLGI0i73e@BB`]<4U<7A19K0d0BG`<l4
V<3>19Voc@>I_/`4VKg;19Zmc0BK_//4W;g;19fnb`>N_//4Wkg;1:2mbPRQ_LT4XK_719jha0>L]L04
VK2k19J/]`BCZ;@4TJJa192U/0>@Yk08T:Ra18jV/0B<YJl8RjB^0h>NZPAoVZL4NYFQ17F@V`AaRiH4
KHNB0fV3SPAUOhT4HG^515egP@AILgh4EFmj155/MQGoool001Coool4E71k15YgP`APOh/4IHNC16^?
W0=aUZ@4Mij/17bU]0B1[Kd4Q[C518Zkc0>>`M@4T/OK19C=hPBFcnD4UloS19O=h0BFbM`3ULOI19O6
ePBIaMD4VlCD19c4d`BMa=84WL;A0ik1c`BN`<h4Wl7>1:31cPBP`<d4XL3=0j:oc0BS`<`4Y<3;1:Bo
b`BT_/T4Xkc61::ja0>O]/44WK:l19V^]`BFZ[<4TjN`19>V[`>DZ;44TjVa19:X/0B?YZl4SJB^18ZR
[0B8XJ`3Pin[182LZ0AjUZ44MY2K17:;UPA^Qi83JX>=16IoR@ARNhD4GWN215YcOPAFL7X4DVaf5Ooo
o`005?ooo`ADL7/4FWN3161oR`AUQi<4JhnL0g6FY0AgWZ`4O:Fd186]_@B6]<D4R[_<0hk1e0BBam/4
U<gR19K?i@BGcn<4UlgP19K9g0>EamT4UlKF19W5e@BKa=@4W<CC19g4dPBM`]43W/7?19k0cPBO`Lh4
X<7>1:30c@BQ`<d3X[o<1:?0c0BT`</4Y;o;1:Bnb@BS_<H4X[[40inf`@BM/[`4VJjg19JZ/`BCYk04
TjJ_0iBX/@BCZK44TZR`18nV[`B=Y:h4RZ:/18RQ[0>3Wj/4P9bX17ZFX@AfT9/4LX^F16j7TP=ZPhd4
IWn9169kQ@ANMh84FW=n15I`NPABK7HEoooo000Doooo15A`N`AJMh<4H7n;16F7T`A[Si`3LIJT17NN
[0AlYK@4PJfm18Jda@B:^l`3S/7D19;7f`BDcN84U/oU19O?h`BGcN04U/WL0iG7f@BGa]H4VLGE19_4
e0BLa=<4WLCB19g2d@>N`Ll4W/3>19o1cPBP`Lh4X<3=1:70c@>R_l`4Xl3<1:C0b`BT_l/4Y;k91:>l
aPBR^/@3WkK119fb_0BI[[L4UZZc19>W/0BCYZl3U:Ra19>Y/@BBZ;04SjJ_18fT[PB:XZ`4R:6/0h>O
Z`B0W:P4NYJQ17J@V`AbRiH4KXNB0fZ3S@AVOhT4HW^515igPPAJLgh4EW1j159/MQGoool001Coool4
E71k15YgP`APOh/4IHNC16^?W0=aUZ@4Mij/17bU]0B1[Kd4Q[C518Zkc0>>`M@4T/OK19C=hPBFcnD4
UloS19O=h0BFbM`3ULOI19O6ePBIaMD4VlCD19c4d`BMa=84WL;A0ik1c`BN`<h4Wl7>1:31cPBP`<d4
XL3=0j:oc0BS`<`4Y<3;1:Bob`BT_/T4Xkc61::ja0>O]/44WK:l19V^]`BFZ[<4TjN`19>V[`>DZ;44
TjVa19:X/0B?YZl4SJB^18ZR[0B8XJ`3Pin[182LZ0AjUZ44MY2K17:;UPA^Qi83JX>=16IoR@ARNhD4
GWN215YcOPAFL7X4DVaf5Oooo`005?ooo`ADL7/4FWR41660S0AWR9D4KI6N0gBIYPAjXJl4OjVh18Fa
`0B:^<T4Sl3A0iC7fPBGc^44V]?X19gFjPBNe^T4WM3S19_<g@>Kb]/4WLSI19k9f0BOb=L4XLSG1:;8
ePBRamD3XlKC1:?5d@RT`m08YLC@0jK4c`BWa<l4Z<C?1:W4c`BY`/`4Z;o91:Jla@>S^<44X;Bm19fa
^@BJ[K@;V:Zb19JZ/PBEZK44TZN_18jT[@B9X:T4PI^U0g^FXPAmVJ@4NiJQ17J?V@AbRiD4KXNA0f^3
S@AWOhT4HWb515ihPPAJM7h4EW1j159/MQGoool001Coool4E71k15YhQ0AQP8`4IhRE16fAWP=dVJH4
NZ6_17nY^0B5/L04R[S918o0d@>DamX4UlkQ19[Cj0BMe^X4W]KY19g@h`BKc=d3Vl[K19g8f@BNbMP4
WlSG1:78e`BRb=H4X/OE0j?6d`BSaM48Y<?@2:G4d0>Va<l4YlC?1:S4c`BYa<l4ZL;<1:Rob@BV_<D3
XkS11:2d_@BM/KT4VZfd2iRZ/PBFZ[84UJVa19:W[`B>Y:d4RJ2Y186KY@=kUZ84OIVT17^FX@AfSiT4
LX^E16j7T@=[Phd4Ign9169lQ@ANN884FWAn15I`NPABK7HEoooo000Doooo15A`N`AJN8@4HH2<16N8
U@A]TIh3M9VV17ZQ[`AoZKP4QK7018Zhb@B?`=43U<OJ19O>h@BJdnP4WMKZ19kFj@BMd><4VlcM0i_:
f`BMb=T4W/WH19o8e`BQb=L4X/SF1:;7e@>Sa]<4XlGA2:C3d0RUa=03Y/C?1:O4c`BXa<l4ZLC?1:W2
c0BX_lT4Y[c50j>h`@BP];d4WK6i19Z]]0^HZ[84UZZb19FY/@BBYjl4SZB]18VPZ@B1VjD3NiJR17fI
Y0AkUZ44MXnI17:;U@A^Qi43Jh>=16MoR@ARO8D4GWR215YdOPAFL7X4DVaf5Oooo`005?ooo`ADL7/4
FgV416:2S@AYRYH4L9>P0gJKZ@AmY;84Pjbk18Vea0B?_Ld4ULGF0i[=g`BNe^T4X]c`1:COl@BTf^/4
X];S1:7>g`>Qc=d4X/cL1:?=g0BTcM`4Y/kL1:O=f`BXcMX3Z<cH1:S9e@BXam84Z<KA1:S6dPNZb=<4
ZlWC1:g9d`B]b=84[LK?1:c3c0BZ_lP3Z;c41:Fg_PBQ/[X4Wjng19j_]PBM[kH3W:jf19Z^]@BH[;<4
U:Va192V[PB;XZX4Q9bU0gbDW@AdRY@4LXZC17F=U`AcRi@4KhNA0fb4S@AWP8T4Hgb515mhPPAKM7h4
EW1j159/MQGoool001Coool4E71k15]iQ0ARPXd4JHZF172CX0=fVjT4OJBb18>/^`B9]L@4Skg=19G5
eP>JcMl4W]KY1:;Ll0BTgo44Y=[[1:;Bh`BQc]l3XLcM1:;<g0BScM`4Y<gL1:K>g0BWcM/4Z<gJ0jS<
f0BXbMD4Z<OB1:S6d@BXa]87Z/SC1:_9d`B]bM<4[LSB1:g6c`B/`l`4Z[o80jRla0BU]kh4XK:j19n_
]`BN[kH4WJnf0ib^]PBJ[[D4V:bc19BY/@B@YZh4Rj:Z18BLY@=lU9d4M8ZD17::T`AeSIL4Lh^D16n7
T@=/Q8d4Ih2916=lQ@AON884FgAn15I`NPABK7HEoooo000Doooo15A`N`AKNH@4HX:=16V:UPA`Tj03
MY^Y17fT/PB3[;/4RKG418nmc@BEaMH3V/gO19kFj@BRg?04Y=oa1:CJj`BRd^<4XLkO0j7<g@BRc=`4
XlgL1:C=g0BVc]`4YlgK1:S=fP>Xc=P4Z<WE1:S7dPBXa]44Z<KB1j[8d`B[bM<4[LWC1:g8dPB]a/l4
[<?<1:Zob0>X_<@4YKNn1:6b^PBO[kL4WZnf19f_]P>L[[H4VZje19R//`BDZK44T:J^18^RZPB4W:D3
O9BM17B:U0AbRY<4MHfG17>;U0A_Qi43K8B=16N0R@ASO8D4GgR215]dOPAFL7X4DVaf5Oooo`005?oo
o`ADL7/4FgV416:2S@AYRYH4L9>P0gJKZ@AmY;84Pjbk18Vea0B?_Ld4ULGF0i[=g`BNe^T4X]c`1:CO
l@BTf^/4X];S1:7>g`>Qc=d4X/cL1:?=g0BTcM`4Y/kL1:O=f`BXcMX3Z<cH1:S9e@BXam84Z<KA1:S6
dPNZb=<4ZlWC1:g9d`B]b=84[LK?1:c3c0BZ_lP3Z;c41:Fg_PBQ/[X4Wjng19j_]PBM[kH3W:jf19Z^
]@BH[;<4U:Va192V[PB;XZX4Q9bU0gbDW@AdRY@4LXZC17F=U`AcRi@4KhNA0fb4S@AWP8T4Hgb515mh
PPAKM7h4EW1j159/MQGoool001Coool4EG5l15ajQ@ASPhh4JhbH17:EX@=iWZ/4P:Ne18N`_PB>^LP4
U<;B19[;g0>PdnD4YM_^1:WOl@BZg^l4Z=SY1:KDi0BUdN43Y]3O1:O@g`BXdMl4ZM;P1:_Ch0B/dn04
[M?O0jgAg@B]cmX4[LgG1:c;e@B]b]@4[LWC0jk9d`B_b]@4/<[D1;7:dPBab=04/<G=1:k2b@>[_L<4
YkRn1:Fe^`BT];X4Xk>j1:>c^@>Q/[P4Wk6g19b_]@BH[;84U:V_192TZ`B:X:P3PiVR17fBV`AjT9T4
N8jG17F;U@AaR943KHB=16R0R@ATO8D4H7R215]dOPAGL7X4DVaf5Oooo`005?ooo`AELG`4G7Z516>3
SPA[S9P4LYFQ0gVNZ`B0YkD4Qk2n18jib0BD`]84V/_L0j3Ci@BUfnh4ZMoa1:[Nk`BXf>T4Y]CT1:GA
h@>Vd=l4Ym3O1:SAg`BYd^04Zm?P1:cCh0B]dml3[M7M1:g?fPB]cML4[<_E1:g:e0B]bM<3[/WC1:o:
e0B`b]@4/L[B1;78d0B`aLd4[/;90j^m``BW^;h4YKFk1:Bd^PBS/kX4Xk>i0j6b^0BO/KL4W:ne19R/
/PBDZJl4T:B[18ZPZ0>3VJ84OI:K17Z@V@AhSYL4MH^E1768T@=]Q8d4J82916AlQ@APN884FgAn15M`
NPABK7HEoooo000Doooo15EaO0ALNXD4Hh>>16^<V0AbUJ43NIj[182W]@B7/;h4S[W819C2dPBJbm`3
X=?U1:GKkPBYgo44Z]k_1:SHj@BVe>@4YM7Q0jK@g`BWd=l4Z=7O1:WBh0B[dn04[=?P1:gCg`>]dMd4
[LoJ1:g=e`B/bmD4[L[D1:g9d`>^bM<4[l[D1;3:e0Bab]84/LS@1;35c@B^`/T3Zkg31:Nh_PBU]K/4
Y;Bj1:>c^PBS/kT3XK:h19na]`BL[kD4V:bb19BY[`B@Y:/4RZ2X0h>IXPAmTY/4NY2I17R>U`AeRiD4
LHRA0ff4S@AXP8T4I7b5161hPPAKM7h4Eg1j159/MQGoool001Coool4EG5l15ajQ@ASPhh4JhbH17:E
X@=iWZ/4P:Ne18N`_PB>^LP4U<;B19[;g0>PdnD4YM_^1:WOl@BZg^l4Z=SY1:KDi0BUdN43Y]3O1:O@
g`BXdMl4ZM;P1:_Ch0B/dn04[M?O0jgAg@B]cmX4[LgG1:c;e@B]b]@4[LWC0jk9d`B_b]@4/<[D1;7:
dPBab=04/<G=1:k2b@>[_L<4YkRn1:Fe^`BT];X4Xk>j1:>c^@>Q/[P4Wk6g19b_]@BH[;84U:V_192T
Z`B:X:P3PiVR17fBV`AjT9T4N8jG17F;U@AaR943KHB=16R0R@ATO8D4H7R215]dOPAGL7X4DVaf5Ooo
o`005?ooo`AELG`4GG^616F4S`A/SIT4M9NS0gbP[@B3Z[L4RkC219:mc0BIamH4XM3Q0jOJk0B]hO<4
/N;d1;;Ol0B^f^X4ZmKU1:[Dh`>Ze>84ZmCR1:gEh`B^en@4/=SU1;;Ii@BcfN@3/mOR1;?Eg`Bbd]`4
/M3I1;7>f0BacMH3//cE1;?=e@BdcMD4]<cC1;C9d0Bba/d4/<;90jjna@B/_<84Zk_01:Zi_`BY^Kh4
Z;Rm0jJf_0BT];X4XK:g19j_]@BJZk44U:N^18nSZP>9WZD4QIZR182GW`AkTIX4MhfE17>9T@=^Q8d4
JH2916ElQ@APN844FgAn15M`NPABK7HEoooo000Doooo15EaO0AMNhH4IHB?16b=V@AdUj<3O:2]18>Z
]`B;]<84T[g<19W7ePBQd>43Ym[/1:gQl`Bah_@4/]o`1:kJjPB[e^D4Z]CS0j[DhPB[e>84[MGS1:kG
i0B`f>D4/]WU1;?Ii0>cen84/mGO1;;Bg0Bad=T4/LkH1;7=eP>bc=D4/lgE1;C=e@Bdc=<4]<W@1;;6
c@B``/T3[[k51:bl`PB[^l04Z[Vo1:Vi_PBX^;d3Y[Jl1:Bd^PBQ/[L4WZne19Z[/@BDYjh4Sj>Z0hVN
Y@B5VZ84P9NO17^AVPAgSID4LhVA0fj4S@AYP8T4IGb5161hP@AKM7h4Eg1j159/MQGoool001Coool4
EG5l15ekQPAUQ8l4K8fI17BGX`=lX:d4PjZg18^d`PBB_L`4VLOF1:7@h@>Wf^`4[N7c1;7Rm0Bbgo04
[][Z1:_Fi@BZe><3Z]CR1:_DhPB]eN<4[]OT1;3Hi@BbfND4/mWT0k?GhPBceMl4/];L1;7@f@Bac]P4
/LgF0k;<e@BccMD4]<gE1;C<d`BdbM04//K=1;32b@>^_/D4[;c21:^k`0BZ^Kl4ZKVn1:Rh_@>V][`4
Y;Bj1:6b]`BN[kD4VZ^a19BW[PB?XjX3RIjU18FJXPB0Uil4Ni6J17N=U@AcRI43KXB=16V0R@AUO8D4
H7R115]dOPAGL7X4DVaf5Oooo`005?ooo`AELG`4GG^616F4S`A/SIT4M9NS0gbP[@B3Z[L4RkC219:m
c0BIamH4XM3Q0jOJk0B]hO<4/N;d1;;Ol0B^f^X4ZmKU1:[Dh`>Ze>84ZmCR1:gEh`B^en@4/=SU1;;I
i@BcfN@3/mOR1;?Eg`Bbd]`4/M3I1;7>f0BacMH3//cE1;?=e@BdcMD4]<cC1;C9d0Bba/d4/<;90jjn
a@B/_<84Zk_01:Zi_`BY^Kh4Z;Rm0jJf_0BT];X4XK:g19j_]@BJZk44U:N^18nSZP>9WZD4QIZR182G
W`AkTIX4MhfE17>9T@=^Q8d4JH2916ElQ@APN844FgAn15M`NPABK7HEoooo000Doooo15IbO0ANNhH4
IXF@16j?V`AfVJD3Oj>`18N]^PB?]lD4Ul7?19o;fPBWe^D3[n7b1;SYnPBmjo/4^nKd1;CMk0B`f>L7
[mOU1;3Hi@Baf>H4/m[W1;GKj0BggNP4^MgX0kWLiPBhfN84]mKO1;KCg0BedMX4]M3H0kG>ePBfc]H4
]lgE1;O=e0Bgbm44]/S>1;C5b`>b`lP4//751;70a0Ba_l@4/;k21:jl`0>/^[h4ZKNk1:Jd^0BS/KH4
WZnc19Z//@BFZK03T:B[18ZPZ0B4VZ84OY>K17V>UPAdRI43KhF=16^1R@AVO8D4HGR115adO@AGL7X4
DVaf5Oooo`005?ooo`AFLW`4GW^616J5T0A^Si/4MYVU0gnS/0B7[KX4SkO519O1c`BObmX4YmKU0joQ
lPBhjOX4_N_k1;_Vm0BdgN`4/=SW1joGi@B`f>D4/MSV1;?Ji`BefnP4]mgX1;WMj0>ig>H4^=WR1;OF
g`Bfdm`4]M7J1;G@f0>ec]H4]/kF1;O=e@BgcM@4]l_A1;K8cPBdaL/3//?81;;1a@Ba`<@4/Ko41;2n
`PB^_<03[;Zn1:Vg^`BV];P4Xk6f19j_/`BJ[;44UZV`0i2TZ`B:X:P4Q9ZR17jCV`AiSYH4M8VA0fn5
S@A[PHT4IWb5165hP@ALM7d4Eg1j159/MQGoool001Coool4EW9l15ikQPAVQI04KXnK17JIY@=oXk04
Qjfj18nga@BG`Ll4Wl_J1:OFi@>_hO84^>Wj1;g[n`Bki_@4]=g/1;3Hi`N_enD4/=SU1;7HiPBcf^L4
]M_X1;OMj0BigNP3^McV1;SIhPBge]l4]]?L1;GAfPBed=P3]LkF1;K>ePBgcMD4]lgD1;O;d@Bfb<h4
]<G;0k;3b0Bb`LD4/L341;6oa0B`_/84[[c00jbj_PBY]k/4Y[Bh1:>a]PBN[k<4VZba19JY/0>@Y:/4
RZ2X18BJXPAnTi/4NHjF17B9T@=_QHd4Jh6916IlQ@AQN844G7Am15M`NPABK7HEoooo000Doooo15Ib
O0ANNhH4IXF@16j?V`AfVJD3Oj>`18N]^PB?]lD4Ul7?19o;fPBWe^D3[n7b1;SYnPBmjo/4^nKd1;CM
k0B`f>L7[mOU1;3Hi@Baf>H4/m[W1;GKj0BggNP4^MgX0kWLiPBhfN84]mKO1;KCg0BedMX4]M3H0kG>
ePBfc]H4]lgE1;O=e0Bgbm44]/S>1;C5b`>b`lP4//751;70a0Ba_l@4/;k21:jl`0>/^[h4ZKNk1:Jd
^0BS/KH4WZnc19Z//@BFZK03T:B[18ZPZ0B4VZ84OY>K17V>UPAdRI43KhF=16^1R@AVO8D4HGR115ad
O@AGL7X4DVaf5Oooo`005?ooo`AFLWd4Ggb716N6T@A`T9`4NI^W0h:U/PB:/;d4Tk_819c6d`BTd=h4
[M_Y0kKUm0BokOX4`^ci1;oWm0Bih>d4]=_X1k;IiPBcfNH4]M_W1;SLj0Bjg^P4_=oY1kkPj@BngnL4
_=_T1;[Gh0Bhe=`4]m7I0kO@e`Bhd=L4^]3F1;_?e@BjcM<4^/_A1;W9cP>hal/4^<K:1;S5b@BgaLP4
]/?71;C1a@>b_/84[k^o1:^h^`BW]KP4Y;:f1:2_]0BL[;83UZR^18nSZ@B7VJ04PIBK17b?UPAfRY43
LHF=16b1R@AWOHD4HGR115adO@AGL7X4DVaf5Oooo`005?ooo`AFLWd4Ggb716N6T@A`T9`4NI^W0h:U
/PB:/;d4Tk_819c6d`BTd=h4[M_Y0kKUm0BokOX4`^ci1;oWm0Bih>d4]=_X1k;IiPBcfNH4]M_W1;SL
j0Bjg^P4_=oY1kkPj@BngnL4_=_T1;[Gh0Bhe=`4]m7I0kO@e`Bhd=L4^]3F1;_?e@BjcM<4^/_A1;W9
cP>hal/4^<K:1;S5b@BgaLP4]/?71;C1a@>b_/84[k^o1:^h^`BW]KP4Y;:f1:2_]0BL[;83UZR^18nS
Z@B7VJ04PIBK17b?UPAfRY43LHF=16b1R@AWOHD4HGR115adO@AGL7X4DVaf5Oooo`005?ooo`AFLWd4
Ggb716N6T@A`T9`4NI^W0h:U/PB:/;d4Tk_819c6d`BTd=h4[M_Y0kKUm0BokOX4`^ci1;oWm0Bih>d4
]=_X1k;IiPBcfNH4]M_W1;SLj0Bjg^P4_=oY1kkPj@BngnL4_=_T1;[Gh0Bhe=`4]m7I0kO@e`Bhd=L4
^]3F1;_?e@BjcM<4^/_A1;W9cP>hal/4^<K:1;S5b@BgaLP4]/?71;C1a@>b_/84[k^o1:^h^`BW]KP4
Y;:f1:2_]0BL[;83UZR^18nSZ@B7VJ04PIBK17b?UPAfRY43LHF=16b1R@AWOHD4HGR115adO@AGL7X4
DVaf5Oooo`005?ooo`AFLWd4Ggf716R7TPAbTYd4NifX0hBX]0B>/kl4V;o;1:7:e`BZeN84/mo]0k[W
m0BojO@4`NWd1;oUl@Bhg^X4]M_W1;GJi`>dfND4]M[U1;SLi`BlgnX4`>?]1<CVk`C6i^l3aNC/1<;Q
j@Bog^D4_M[R1;[Eg@Bid]P3^M3F1;[@e@BlcmD4_LoE1;g>e0BmcM44_Lc@0kk;c`Boblh4_/[=1;g8
b`BlalT4^LC60kK1``Bc_L04/;^m1:bh^PBY];L4YK:e1::`]0>M[K04U:FY18^JW`B4U9X4OXnE17R:
T@=bQXd4KH6916MmQ@ARN844GGAm15Q`N@ACK7HEoooo000Doooo15IbO@AOOHL4J8NB17:BW@AkWJP3
Q:Rd18jc_`BH_l/4XL[G1:[EhPBcgnd3^^Od1;oYm0C1jO@4_nGa1;SNjPBefnL4]M[W0kCIi@Bef^D4
^=cW1;cOjPC0hnd4a>K_1<KVk`?5i>`4`^7Y1;oNi@Bmf^84^]GM1;WBf0>id=H4^]3E1;c?e@BmcmD4
_LkD1;g=d@Bmc=03_/_?1;o;cPBnb/d4_LS;1;c7b@Bia<H3]/731;>m`0B`^kd4[;Rj1:Vd]`BU/[D4
X[2d0if]/0BDYJT4RiZO18BDVPAnSiD4N8ZA0g:6S@A]PHT4Igf5169hP@AMM7d4F71i15=/MQGoool0
01Coool4EW9m15mmQ`AXQi84LY:M17^MZ0>4Z;@4S[>o19Rob`BQb]L4Z]GR1;?Ok@>jio@4_nWd1<7Y
m0BoiO44^=kZ1;GKi`Bef^L3]=WU1;GJi@Bhg>L4_=oZ1<3Sk@C4i^l4a^K_0lGTk0C2hNT4_mkU1;gJ
hPBjeMd4^M;H0kW@ePBjd=D4_<oE1;g?e@Bmc]@4_LgA1;g<d0>nbll4_l_>1;k:c@Bmb</4_<O91;W4
aP>f`L<4/kg01;2k_@B/^;X4ZKBg1:Fb]@BR/;@3WJf`19BUZ@B;VYl4Q9BJ17j?U@AhRY43LXJ=16f1
R@AWOHD4HWR115edO@AHL7T4Dfaf5Oooo`005?ooo`AFLWd4Ggf716R7TPAbTYd4NifX0hBX]0B>/kl4
V;o;1:7:e`BZeN84/mo]0k[Wm0BojO@4`NWd1;oUl@Bhg^X4]M_W1;GJi`>dfND4]M[U1;SLi`BlgnX4
`>?]1<CVk`C6i^l3aNC/1<;Qj@Bog^D4_M[R1;[Eg@Bid]P3^M3F1;[@e@BlcmD4_LoE1;g>e0BmcM44
_Lc@0kk;c`Boblh4_/[=1;g8b`BlalT4^LC60kK1``Bc_L04/;^m1:bh^PBY];L4YK:e1::`]0>M[K04
U:FY18^JW`B4U9X4OXnE17R:T@=bQXd4KH6916MmQ@ARN844GGAm15Q`N@ACK7HEoooo000Doooo15Mb
O@APOHP4JHRC17>CWPAmWZT3QjZe19:f`PBL`/h4YloK1;7Ji`BiiO83`>_g1<S^n0C8k?D4`NC_1;SL
j0Bff^D4]MWT0kGHh`Bff><4^=WS1;_Ki0Bog^H4`n7X1<OSjP?7h^X4`moW1<7Mi0Bnf^44^mGK1;[@
eP>jc]@4^lkD1;g?e0Bncm@4`<kC1<7?dPC1c]43`Lg?1<;=c`C3c/l4`lg?1<7;c@BnalT3^/C61;O1
`PBd_[l4/[Zl1:jg^@BZ];H4Y[6c0ijZ[0BEXZD4SIVM18JDV@B0SiD4NHZ@0g>6S0A^PHP4J7f4169h
P@AMM7d4F71i15=/MQGoool001Coool4Eg9m161mR0AYR9<4Li>N17fNZ@>7Z[D4T[K219c2cPBWcm/4
/M[W1;WUlP?0joL4b>kh1<S/m@C1i>l4^=cX1;KJi@BefN@3]MSS1;KHh`BhfN<4^m_T1;oNiPC3hNP4
an?Z0lORjPC3gnL4`MgT1;kJh@BkeM/4^]3F0k[>e0Bkc]@4_LoD1;k?e0C0c]<4`LoB1<7>d@?1cLl4
`/g?1<?>c`C3cLl4`L_=1;k7b@>ja<H4]l721;Bn_`Bb^[`4[[Ni1:Zd]PBV/K<3WZZ/19FRY@B=VId4
QYBI182?U@AiRY03LhJ<16j1R0AXOH@4HWR115edO@AHL7T4Dfaf5Oooo`005?ooo`AGLWd4H7f816V8
T`AcTih4OIjY0hNZ]@BB]/84W<;>1:O?f`Baf^L4^NGb0l3[m`C8k_P4b>ce1<7Tk`Bhg>P4]][U1;GI
i0>ef><4]]SS1;SIh`Bkfn@4_mkV1<?Qj0C7hnX3an;Z1<?Oi`C1gN@4_][Q1;_Ef`Bjd=H3^/kD1;_>
e0Bmcm@4_/oD1<3>d`C1cm84`LkA0l7=c`C2cLl4`lk?1<?=c`C1bld4_/O90k[4aPBg`L84];jo1;:j
_0B^]kT4Z[Bf1:Ja/`>NZZ`4UJ:U18fIW@B6U9T4P8nE17V:T0=cQX`4KX6816QmQ0ARN844GGAm15Q`
N@ACK7HEoooo000Doooo15MbO@APOHP4JHRC17>CWPAmWZT3QjZe19:f`PBL`/h4YloK1;7Ji`BiiO83
`>_g1<S^n0C8k?D4`NC_1;SLj0Bff^D4]MWT0kGHh`Bff><4^=WS1;_Ki0Bog^H4`n7X1<OSjP?7h^X4
`moW1<7Mi0Bnf^44^mGK1;[@eP>jc]@4^lkD1;g?e0Bncm@4`<kC1<7?dPC1c]43`Lg?1<;=c`C3c/l4
`lg?1<7;c@BnalT3^/C61;O1`PBd_[l4/[Zl1:jg^@BZ];H4Y[6c0ijZ[0BEXZD4SIVM18JDV@B0SiD4
NHZ@0g>6S0A^PHP4J7f4169hP@AMM7d4F71i15=/MQGoool001Coool4Eg=m165nR0AZR9<4M9BN17nO
ZP>9ZkH4UKS41:76d@B]e>04^>7]1<3ZmP?5kOP4an_e1<?Uk`Bmh>X4]]WT1;GGhPBeen43]]OP1;KG
g`Bge]h4]mGL1;KCfPBie=/4^mKM0k_Eg0BkdmT4^M3F1;G:d@BebLl4^<_@0k[<d0BlcM44_/kB1<3?
dPC1d=84a=;C1<GAdP?7dM<4b]?D1<_De0C9dM84a/k>1<;:b`>nalP4^/?41;No`0Bd_;d4/[Zj1;2h
^0B/];@3Xj^/19RPXPB?V9X4R9BG186?U0AkRY03M8J<16j1R0AXO8@4HgR015edO@AHL7T4Dfaf5Ooo
o`005?ooo`AGLgd4HGj816Z8T`AdU9h4OinZ0hV[]PBE^<@4XLKA1:gDh0BhhNd4`>[f0lG]n0C7joD4
`nG_1;gPjPBffN@4]MOR1;GGh@>fen04]]OO1;OFgPBgeM`4]]?J1;WDf`Bke]d3^mGL1;_Cf@Bid=H4
]L[A1;G9c`Bhbm03^/c@1;c=d@Bnc]84`<oB1<7@dPC4d]<4aM7B0lOAd`C:dm@4bmCD1<WAdPC6c/h4
`/[;0kk7b0Bj`l@4]ko01;Bl_@Bb^[X4/;Rh1:bd]0>SZj`4V:2R18nHVPB8U9L4PHnD17^:T0=dQX`4
KX6816QlQ0ASN804GGAm15Q`N@ACK7HEoooo000Doooo15McO@AQOXP4JXRC17BDWPAoWjX3RJ^f19Fh
a0BQa]44[MCP1;SQk@C0j_H3aNgh1<O[m@C3iNl4_N3Z1;KIi0Been84]MOQ0kKGh0Bfeml4]mKN1;OE
g0BfdmX4^MCK1;_Fg@>keM`4^m?I1;W@ePBeb]44]LW?1;S;d0>jc=04_<gA1;k>dPC0cm84`M3B1<CB
d`C5dM83am7C1<[Ce0C;e=@4bM7B1<K>cPC2b//3_/O81;[3a0Bg_l04];bm1;:j^PB`^;P4[;Bd0j>[
[0BHX:84SiRJ18RDU`B1Si@4NhZ@0gB6S0A^PHP4J7b416=hP0AMM7d4F71i15=/MQGoool001Coool4
Eg=m165nR0AZR9<4M9BN17nOZP>9ZkH4UKS41:76d@B]e>04^>7]1<3ZmP?5kOP4an_e1<?Uk`Bmh>X4
]]WT1;GGhPBeen43]]OP1;KGg`Bge]h4]mGL1;KCfPBie=/4^mKM0k_Eg0BkdmT4^M3F1;G:d@BebLl4
^<_@0k[<d0BlcM44_/kB1<3?dPC1d=84a=;C1<GAdP?7dM<4b]?D1<_De0C9dM84a/k>1<;:b`>nalP4
^/?41;No`0Bd_;d4/[Zj1;2h^0B/];@3Xj^/19RPXPB?V9X4R9BG186?U0AkRY03M8J<16j1R0AXO8@4
HgR015edO@AHL7T4Dfaf5Oooo`005?ooo`AGLgh4HGj816^9T`AeU9h4P:2Z0h^/]`BH^/D4YLWD1;CK
i@C6koX4c?Go0l__n@C9j_<4`nC/1;cMiPBee^44]=KO1;GEgP>eeMd4]mGM1;ODf`BfdML4]LoE1;;<
dPB]a/d3ZlC;1:c4b`B^a<X4/LC91;C6b`BgbLd3^/_?1;c=d0Bnc]04_lg?1;o<c@Bob//4`LW90lS>
c@C>dm44c=?A2<W@cPC5cL`3`LW81;c4a0Bi`<04]kfl1;Fk^PBe^[T4/[Je0jR^[PBLXj@4TYVK18ZE
V0B3T9@4O8Z?0gF5R`A_PHL4JGb316=hP0AMM7`4F71i15=/MAGoool001Coool4Eg=n165nR0A[RI<4
MIBN182PZP>;[;L4V;[51:G9e0BdfnD4a^oj1<ceo`?;koT4bN[c1<?Tk0BlgNH4]MKQ1;CFg`BeeMh3
]MGM1;OEg@Bge=/4]]7G1;G?e@Bbc=84[LK=0j_4b`B/a</4[/C:1;74b@Bda//4]lW=0k[;c`BlcM04
_/k@1;o=c`Boc<d4_l[;1<79b@?8c/d4c]?A1<cCd@S9d<h4aLg<0l79b0Bla<@4^L301;Nm_0Be^kX4
]KZi1;:f]@>X[Zh4W:>T19:IV`B:UIP4Pi2D17b:S`=eQH/4Kh6716UlP`ASN804GGAl15Q`N@ACK7DE
oooo000Doooo15McOPAQOXP4JhVC17FDWPB0X:X3Rjbg19Rja@BUbM@4]=_U1<K_nPC<mOl3bnoi1<WZ
l`C3i>`4_=gV1;GFh@Bde]l4]MGN0kGEg@BgeMd4]mCK1;KAe`BecmD4//cB1:g6c@>[a</4[<C;1:k4
bPBaa<T4]<K;1;O9c@>jbll4_<g@1;k>d0BocLl4_lc=1;o:b`C1bLT3b<k=1<kCd@C<dm48bM3>1<G=
c0?1bLP4_<C41;W0`0Bg_K`4]K^j1;Fj^@Bb][D3Z:j^19bSY0BBVI/4RYFH18>@U0AlRXl3MHF;16n1
Q`AYO8<4HgR015edO0AHL7T4Dfae5Oooo`005?ooo`AGLgh4HGj816^9T`AeU9h4P:2Z0h^/]`BH^/D4
YLWD1;CKi@C6koX4c?Go0l__n@C9j_<4`nC/1;cMiPBee^44]=KO1;GEgP>eeMd4]mGM1;ODf`BfdML4
]LoE1;;<dPB]a/d3ZlC;1:c4b`B^a<X4/LC91;C6b`BgbLd3^/_?1;c=d0Bnc]04_lg?1;o<c@Bob//4
`LW90lS>c@C>dm44c=?A2<W@cPC5cL`3`LW81;c4a0Bi`<04]kfl1;Fk^PBe^[T4/[Je0jR^[PBLXj@4
TYVK18ZEV0B3T9@4O8Z?0gF5R`A_PHL4JGb316=hP0AMM7`4F71i15=/MAGoool001Coool4Eg9m165m
Q`A[R984MY>M182OZ@><[;H4VK[41:S:e0BkhN/4b>gg1<g`n0?BloX4cngd1<GTk0Bjf^@4/]?M1;?C
g0BcdmX3]MCK1;KDfPBfd]P4]/oD1;G<d0BcbLd4/<O;0jo3b0B]`LD4[l751;72a@Bda<L4]lO:0k[:
c0Blc<h4_/c=1;o;c0BobLX4_LO81;c5a@>laLH4_/K61;k6a@Boa/D4_/K41;_3`P>j`L04^;jm1;Vm
_0Bh_K/4^;bj1;Zl^PBe^;D3ZJn^19jVYPBEWIh4S9JH18B@T`AmRXl3MXF:16n0QPAYNh84HgMo15ec
N`AHKgP4Dfae5Oooo`005?ooo`AGLWd4HGf716^8TPAfTid4P9nY0hb/]PBI^/@4Z<[D1;_Qj`C8kOL4
cO3h0m;cnPC?kO@4aNC/1;[Ji0Bbdmd4/m?L1;?CfP>ee=/4]]CJ1;KBf0Bfcm@4]Lc@1;?9c@B`al/3
[l?81:g1a@B_`LD4/L;51;C4a`BgalX3^/[<1;c<cPBnc<d4_l_<1;o9bPBmalP4_<G50kc5aPBna/H4
_/K51;o6a@Bna/@4^l?20k[1`0Bh_[d4^Kfl1;Rm^`Bh_;X4^[bj1;Fh]@>Y[jh4WZJV19FMWPB<UYP4
Q92C17f:S`=fQHX4Kh2616UkPPASMgl4GG=k15Q_N0ACK7DEoooo000Doooo15MbO@AQOHL4JhRB17JC
W@B0WjT3S:bf19Vja0BXb]@4^n7[1<S]m`C=l?P3d_?j1<o]m0C5i>`4^][T1;;Cg@Bcdm`4/m?J0kGD
f`Bfe=X4]];H1;K?e0Bec=04/lW=1;37b`>_`lP4[L751:o1a@Ba`/D4]<C71;O7bP>jb/`4_<c>1;k<
c@Bobl`4_lW:1;g7b0BlaLD3_<G61;k6aPBna/D4_lK51;k6a0Bk`l83^/701;Rn_@Bi_K`4^;fk1;Rl
^PBj_;X4]KRe0jV_[PBNYZH4UIfN18bFV0B4T9<4OHZ?0gJ5RPA_P8H4JG^216=gO`AMLg/4F6mh15=/
MAGoool001Coool4Eg9m165mQ`A[R984MY>M182OZ@><[;H4VK[41:S:e0BkhN/4b>gg1<g`n0?BloX4
cngd1<GTk0Bjf^@4/]?M1;?Cg0BcdmX3]MCK1;KDfPBfd]P4]/oD1;G<d0BcbLd4/<O;0jo3b0B]`LD4
[l751;72a@Bda<L4]lO:0k[:c0Blc<h4_/c=1;o;c0BobLX4_LO81;c5a@>laLH4_/K61;k6a@Boa/D4
_/K41;_3`P>j`L04^;jm1;Vm_0Bh_K/4^;bj1;Zl^PBe^;D3ZJn^19jVYPBEWIh4S9JH18B@T`AmRXl3
MXF:16n0QPAYNh84HgMo15ecN`AHKgP4Dfae5Oooo`005?ooo`AGLW`4HGb616^7T@AeTi`4P9jX0hb[
]0BH^<44Y/O@1;GGh0Bmg^L4`^7Z0lOSj`C7hnX4_]cU1;KEgPB`d=T4/M3H1;;?e`>bcM@4/lcA1;K?
e0Bhd=D4^<oB1;S<c`BfbL/3]LK81;?4aPBc`lD4]<;41;G3a0Bha/L3^/W;1;g;c0Bnbl/4_l[:1;o:
b0Bob<L4_/G50kc3`PBf_Kd4/;Ri2;:j^PBb^KT3]KZi1;Rl^@Bj_KT4^[bi1;^m^@Bl_;P4];Jc0jV]
Z`BNYJ@4UYbM18fFV0B5T9<4OHZ>0gJ4R@A_OhD4J7^116=fOPAMLg/4F6mh15=[MAGoool001Coool4
Eg9l165lQPA[Qi44MI>L182NZ0><Zk@4V;S11:K7d0Been04_MkW1<;QjP?7hn/4an?Z1;kLi@BfeMh4
/=3I1;7@f0BbcmL3//gD1;?<d@Bfcm@4^=3E1;S?dPBhc<l4]/W;0kG6b0Bca<H4/l?51;C2a0Be`l@4
^<K70k[9b`Bmbl`4_/_;1;o:bPBob/P4_lS71;k5a@>l`l84][fm1;2h^@Rb^[X4/[Vi0kFj^@Bh_;T4
^[fi1;Zl^@Bk_KT4_;bh1;Bf/`>Y[J/4WZFT19JLW@B=UYP4QI2C17f:SP=fQ8T4Kgn516QkP@ASMWh4
GG=k15Q_N0ACJgDEoooo000Doooo15MbO0AQO8H4JhNA17FCW0B0WZP3S:^d19Rh`@BVam04]MOP1;gN
i`C2hNX3an?[1<OSjPBng>D4]]GN1;3@f@Bad=P4//oG0k;=e0Bcc=44]/oD1;S@e@Bhcm84^<c?1;K9
b`>ea/P4/lC61;?3a@Bd`/@4]L?41;S6a`>jbL/4_L_<1;k;b`Bob/X4_l[81;o8a`BnaLD3_<?21;Jm
_@B`^;T8/[Zj1;:i^@>e^[T4^;bi1;Zm^@Bj_;T4^kfi1;bl^0Bd][<3ZJf[19jUY0BFW9d4SIJH18F@
T`AmRXh3MXB916moQ@AXNh44HgIn15ecN`AHKgP4Df]e5Oooo`005?ooo`AGLW`4HGb616^7T0AeTI/4
OifV0h^X/@BF]Kd4Xl7:1;3>e`BgeM`4_=WP0kkJh@BlfN04^=GM1;?@f0B_cMD4/<kE1;7<d`>ab]04
/LS<1;34b0B``lH4/L?41:jo`0B[^[`3Z[Ri1:^h^@B]^;T4/;^k1;C0`@BhaLD3^lW91;k:bPBobLT4
_lW71<7:aPC2b/H4`LS50ko5``Bk`/04]kfl1;Fj^0Bd^;H4]KVf0kVk]`Bj_KL4_;jh1;fn^@Bo_kT4
_[fh1;Fe/0>VZJL4WJ:Q19NLW0B?UiP4QHnB17f9S0=ePhL4KWj316QiP0ARMGd4GG9j15M^M`ABJgDE
oooo000Doooo15MbO0AQO8H4JhN@17FAV`AoWJH3RjRa19Je_@BS`LX4/<kG1;OEg0BlfN03_][Q1;cI
h0BheMd4/m3H1:o=e@B`c]D4/LcC0k7:d0Bab<`4/<C81;33aPBa`l@4[[o01:^j_0>Z^;T4ZkRi1:fh
^@B`^k/4]<311;S5a@>kbLT4_/[:1;o9b@BobLL4`L[61<;:aPC1b<D3_lG31;_2`0Bg_K`4]KZh1;Bh
]PBe^KH3^K^g1;Zm]`Bl_[P4_Kji1;no^@Bn_KP4]KF`0jJYY`BMXZ44UibL18nGV0B5Si84OHV<0gF3
Q`A^OX<4J7V0169eO@AMLWX4Efig159[MAGoool001Coool4Eg9l165lQPA[Qi04MI6K17nMYP>;Z;44
U[Fm1:?1bPB`c]L4]mGL1;cIh0>nf^44_=WP1;SEg@Bcd=P4[lgE1;3>e@Bac=<3/L[@1;78c0B`a<P4
/<?61;73a0B^_l04ZkZl0jZh^@B[^;T4[KRi1;2k^`Bd`<44^<G50k_9b@Bnb/X4_lW91;o9a`C1b/H4
`/[61<78a@>oaL<4^l;01;Nm_0Be^[P4];Rf1;Fi]P>i^kL4^[fg1;bn^0Bm_[T4_kni1;jm^0Be]K03
YZVW19fRX@BGW9`4SiNH18F?TPAmRH`3MH>716inP`AXNH04HWEm15ebNPAGKWL4DV]e5Oooo`005?oo
o`AGLW`4HGb616^7T0AeTI/4OifV0h^X/@BF]Kd4Xl7:1;3>e`BgeM`4_=WP0kkJh@BlfN04^=GM1;?@
f0B_cMD4/<kE1;7<d`>ab]04/LS<1;34b0B``lH4/L?41:jo`0B[^[`3Z[Ri1:^h^@B]^;T4/;^k1;C0
`@BhaLD3^lW91;k:bPBobLT4_lW71<7:aPC2b/H4`LS50ko5``Bk`/04]kfl1;Fj^0Bd^;H4]KVf0kVk
]`Bj_KL4_;jh1;fn^@Bo_kT4_[fh1;Fe/0>VZJL4WJ:Q19NLW0B?UiP4QHnB17f9S0=ePhL4KWj316Qi
P0ARMGd4GG9j15M^M`ABJgDEoooo000Doooo15MbO0APNhD4JXJ?17B@V@AnVZ<3RJF^19B`^@BO_<<4
Z/K>1:o;dPBbc]D3]M3G1;GAf0BccmH4[lcD1:k;d`B_c=<4/<_A0k79cPBaa/X4/<?61:jn`0B/^KX4
Z[Jg1:Vc/`>Y/[44Z[:a1:fe]0Bb^k/4]l;11;_6a`>nbLT4_lW91;o9a`BmaL<4_<:o1;g2_@C1a/03
a<S31<;6`PBn`[h4_;nk1;^n^PBk_KT3_;jh1;fn^0Bn_[P4_[jg1<;0^0Bn_;D4/[:]0jRZY`BSYZ@4
WJ6Q196IVPB4SY04NhJ:0g>1Q@A]O844IWQn165dN`ALLGT4Efif159[M1Goool001Coool4Eg9l161k
Q@AZQXl4M92I17jJX`>9YJh4U;2i19nl``BZa/h4[l_B1;;>e@>ed=L4]M7H1;??ePB_c=@4[/_C1:o<
d`B`bm43/LW>1;76bPB``lH4[[k01:bi^PBZ][L4ZK>c0jVb/@BZ/[44[KFd1;:k^`Bg`/44^lK70kk9
b@BobLT4_lW71;g5``Bl`[l4_L:m1<76`0?4b<<4`/K21;k2_PBl_k/4^kjj1;^m^@>l_[P4_Kjh1;jn
^0Bn_[L4`/2h1;jl]@Bb/Zd3Z:ZW1:>VY0BMXJ44TIVJ18B>T0AkQXX3Lh6516elP@AVN7h4HGAk15aa
N@AGKWH4DV]d5Oooo`005?ooo`AGLW`4H7^516Z6S`AdT9T4OYZS0hVU[PBD/;T4Wkc31:[6cPB_bm84
//kE0kG@e`BedMP4/loF1:o<e0B^bm<4[lcC1;3;d@>abLh4/LK:1;33aPB^_/04[;Vj1:Zf]`BY/k<3
ZK:a1:Zb/@B]]K@4/[^k1;O2`@Bka/L3_/W91;o9b@BobLL4_LG31;c2_`Bm`[d4`LK00lC8``C2a/84
_/:n1;bo^`Bk_[X4^kfi0kbn^0Bm_[P4_[jh1;jn]`C2`;P4_[be1;:b[@>XZZL4XjJT19fQX@BAVIX4
Q8j@17^6RP=cPHD4KGb116IhOPAQM7/4G75i15M^MPABJg@Eoooo000Doooo15MbO0APNhD4JXJ?17B@
V@AnVZ<3RJF^19B`^@BO_<<4Z/K>1:o;dPBbc]D3]M3G1;GAf0BccmH4[lcD1:k;d`B_c=<4/<_A0k79
cPBaa/X4/<?61:jn`0B/^KX4Z[Jg1:Vc/`>Y/[44Z[:a1:fe]0Bb^k/4]l;11;_6a`>nbLT4_lW91;o9
a`BmaL<4_<:o1;g2_@C1a/03a<S31<;6`PBn`[h4_;nk1;^n^PBk_KT3_;jh1;fn^0Bn_[P4_[jg1<;0
^0Bn_;D4/[:]0jRZY`BSYZ@4WJ6Q196IVPB4SY04NhJ:0g>1Q@A]O844IWQn165dN`ALLGT4Efif159[
M1Goool001Coool4Eg5k161kQ0AYQ8d4LhjG17bHX0>6XZX4TJbd19^f_@BU`<H4ZL?91:_5b`>]b<h4
[LS?3:c8c`B^bM04/<W?0k79c@BbalX4//C71;71`PB`_[h4[kbk1;2j^P>`^[T4/K^j1;Bn_0Bg`L04
^/K51;g9b@?0blX4`Lc:1<3:b0Boal@4_L>o1;Zn^PBg^kL3^;bg1;bo^PC1`kh4`/Bn1<72_0C0`KX3
_l2i1;jm]PBn_;D4`;ff1<:m]@Bk]k04/[2Z0j^[YPBUYJ44V9ZI18Z?T0B1RH/4N8>60g5nPPAZNGh4
IGIl15mbN@AKKgL4EVee159ZM1Goool001Coool4Eg5k161kQ0AYQ8d4LhjG17bHX0>6XZX4TJbd19^f
_@BU`<H4ZL?91:_5b`>]b<h4[LS?3:c8c`B^bM04/<W?0k79c@BbalX4//C71;71`PB`_[h4[kbk1;2j
^P>`^[T4/K^j1;Bn_0Bg`L04^/K51;g9b@?0blX4`Lc:1<3:b0Boal@4_L>o1;Zn^PBg^kL3^;bg1;bo
^PC1`kh4`/Bn1<72_0C0`KX3_l2i1;jm]PBn_;D4`;ff1<:m]@Bk]k04/[2Z0j^[YPBUYJ44V9ZI18Z?
T0B1RH/4N8>60g5nPPAZNGh4IGIl15mbN@AKKgL4EVee159ZM1Goool001Coool4Eg5k161kQ0AYQ8d4
LhjG17bHX0>6XZX4TJbd19^f_@BU`<H4ZL?91:_5b`>]b<h4[LS?3:c8c`B^bM04/<W?0k79c@BbalX4
//C71;71`PB`_[h4[kbk1;2j^P>`^[T4/K^j1;Bn_0Bg`L04^/K51;g9b@?0blX4`Lc:1<3:b0Boal@4
_L>o1;Zn^PBg^kL3^;bg1;bo^PC1`kh4`/Bn1<72_0C0`KX3_l2i1;jm]PBn_;D4`;ff1<:m]@Bk]k04
/[2Z0j^[YPBUYJ44V9ZI18Z?T0B1RH/4N8>60g5nPPAZNGh4IGIl15mbN@AKKgL4EVee159ZM1Goool0
01Coool4Eg5k161kQ0AYQ8d4LhjG17bHX0>6XZX4TJbd19^f_@BU`<H4ZL?91:_5b`>]b<h4[LS?3:c8
c`B^bM04/<W?0k79c@BbalX4//C71;71`PB`_[h4[kbk1;2j^P>`^[T4/K^j1;Bn_0Bg`L04^/K51;g9
b@?0blX4`Lc:1<3:b0Boal@4_L>o1;Zn^PBg^kL3^;bg1;bo^PC1`kh4`/Bn1<72_0C0`KX3_l2i1;jm
]PBn_;D4`;ff1<:m]@Bk]k04/[2Z0j^[YPBUYJ44V9ZI18Z?T0B1RH/4N8>60g5nPPAZNGh4IGIl15mb
N@AKKgL4EVee159ZM1Goool001Coool4EW5k15mjP`AXPh`4LHbD17^EW@>4WjH4SJR_19Na^0BP^/04
X[c21:Fna0>W`LL4Yl;81:S3b@BYaL/4[<O=1:o9c`Bab/h3//W=1;?8b`BcalT4]<G61;C4a0Bd`/84
]L700kK2`0Bh`l84^/G41;g8aPBoblT4`/g;0l??c0C4c/`4a<g:1<;;a`C1al<4_/>o1;^o^`>h^kL4
][Rd1;Fg/PBg^;<4^KZd1;Vi/`>j^;44_;Va1<2k/`C2^k<4`;Va1;RbZ`B_ZjD3Yj>O19jKV0BBTY44
Q8V:17b4QPAdOh83KGYn16QfN`ARLgT4GW1g15U^MPAEK7@4DFYc5Oooo`005?ooo`AFLG/4GgZ316R3
S0AaS9@4NiFM0hBOYPB=Z:l4Uk6h1:2j`0BR_<84YKk40jO1a`BW`/P4Z<?91:W5b`B/ald4[lW?1;7:
cP>bbLd4/lS;1;?7b@BdaLH4]<C41;C2`PBe`L03]/;01;S3`PBjaL@4_LS61;o;b@C2cL/3`lo<1<C>
c0C4cLX4`/_71<77``Bn`kl4^knk0kRk]`Bf^;@4]KNb1;Nh/`Bi^[@4^KVc0kZh/@Bl^K44`;^c1<:k
/`C0^K44^;:[1:n[Y@>WXil4WY^H19:BT@B4RHX4O8B617AoPP=]NWh4J7Ik169cN@ANL7L4FFif15E/
M0AAJW<Eoooo000Doooo15IaN`AONX<4J8><176<U0AkUId3Q9nV18fX[`BG/KP4X;[01::l`PBU_/@3
Yl771:O2b0BX`lT4ZLG;1:c7c@B_bLl4/L[>0k;9c@Bcb</4/lO91;C5aPBda<@4]<;21;G1`0>f`/04
^<?21;[5a0Bmb<H4_l_91<;=b`?3cl`4a<k<1<C=bPC2blL4`LO31;k3_`Bk_k/3^;^g1;Jh]0Be]k84
]kRc1;Vj]0Bi^K<3^[Ra1;bi/@C0^k<4`[^c1<2i/@Bh/Z/4[j^U0jNSW`BNViP4TY:A18B9RPAlQ8H4
M7n20fejOPAXMW/4HW=i15i`M`AIKWH4EFad155ZLaGoool001Coool4EW5k15mjP`AXPh`4LHbD17^E
W@>4WjH4SJR_19Na^0BP^/04X[c21:Fna0>W`LL4Yl;81:S3b@BYaL/4[<O=1:o9c`Bab/h3//W=1;?8
b`BcalT4]<G61;C4a0Bd`/84]L700kK2`0Bh`l84^/G41;g8aPBoblT4`/g;0l??c0C4c/`4a<g:1<;;
a`C1al<4_/>o1;^o^`>h^kL4][Rd1;Fg/PBg^;<4^KZd1;Vi/`>j^;44_;Va1<2k/`C2^k<4`;Va1;Rb
Z`B_ZjD3Yj>O19jKV0BBTY44Q8V:17b4QPAdOh83KGYn16QfN`ARLgT4GW1g15U^MPAEK7@4DFYc5Ooo
o`005?ooo`AFL7X4GWV216N1RPA`RY84N9:J0h6KXPB:Y:/4Tjfc19bf_0BO^;h4XKVo0j:k`0BT_L<4
YL351:S3b@B/a/`4[lW>1;7:cP>cb/d4]<W<1;K9b`Bgb<T4^<S81;W8b0Bjb<P3_<W81;k;b@C0c</4
`/o=1<CAcPC6d/l3b=?@1<SBc`C8dL`4alo:1<G<a`C3b<@4`<G00kg1^`Bk_KL4^;Vc1;Ng/0Bg]Zl4
^KN_0kbh/0Bn^K44`KZb1<:k/PBn]jh4]:fU1:VTW@>OViH4UIB@18^<R`B0QXH4Mh2216miO0=YMGT4
I79g15m`M@AKKW@4F6ad15A[L`AAJG<Eoooo000Doooo15I`NPANNH84Ih6:172:TPAhTYX3PI^R18ZT
Z`BC[K<4W;Jl19nh_PBQ^Kl3X[_01:Bm``BU`<D4Z<?91:c6c0B_bLh4/L[>0k?:c@BdbL`4]/W;1;O8
b@Bhb<P4^LS81;[8b0>lbLP4_/_91<3<b`C2cld4a=7>1<KBc`?8dm04b=;?1<SAc0C7clX4aLc71<?8
a0C0aL03_L6k1;^m]`Bh^K<4]kN`1;Nf[`Bi]jl3_;R`1;ji/@C1^[84`[^b1;jg[PBd[JD4ZJBM0inK
UPBEU904Rhb;1826QPAgP884KgUl0fUeN@ATLWL4Gg1e15]^M0AHK7@4E6]c155YLaGoool001Coool4
EW1j15iiPPAWPHX4L8ZB17RBVP>1Vj84RZB[19>]/`BL][`4WkRn1:6i_`>R^l04Y;g31:G0a@BX`lT4
[<K<1:o9cPBab/h3/l[=1;C9c0BfbL/4]lS91;S8b0Bib<P4^/S80kc9b0BnblT4`<c;1<;?c@C4dLh4
a];?0lSCd0C8d/l4b=7<1<O?bPC5c<L4`lS41<35`0>m`K/4^kfg1;Ri/`Bg]k04]kJ_1;Vg[`>l^;04
_[Va1<6j/PC2^k84_[N^1;B]Y@BYY9d3Wi^F19FDT0B;S8/4P8J617N0PPA_NG`3JGEi16AbM`AOL7D4
Ffid15Q/M0ADJg<4DFUc5Oooo`005?ooo`AFL7X4GWN116IoR0A^Qhl4MXnG0gnHW`B7X:H4T:R^19Va
]PBK/[H4W;>g0ije^PBQ^;`4Y;_01:S0a0B/a<P4[lS<1;;:c@>db/d4]/_=1;S;c@Bjc<`4_<c<1;k=
c@C0c/h3`]3?1<CAd0C6dm44b=GB1<[Fd`C<f=@3cMSD1<gGdPC<e]04bm?>1<[@bPC8cLL4a/W30lC5
_PC1`KX4_kjg1;jl]@Bm^k84_kZb0l6j/@C2^[44a;Za1<Bi[PBl/ZP4[jNO1:BNUP>IUHl4SHb818:3
P@AgO7`4KWIg16QbM0=TKg<4H6eb15a/LPAIJg84EVYb15=YLPA@JG8Eoooo000Doooo15I`NPANMh44
IWn816j7S`AfSiL3OiRO18NPYPB@Z:h4VK6f19^b]PBL/kL3W[Fj1:6h_0BT^l04Z<341:c4b0B_b<`4
//[=0kC:c@Bfbld4^<_=1;[<c0Blc<`4_/g=1<3>cP?2d<l4a=7@1<KCd@C8eM84b]KC1<cHe0?=f=@4
cMOB1<cFd0C;dlh4b]3:1<S=a`C6bL<3a<Fn1<71^PBo_[L4_[be1;fk/PBo^[83`KZa1<:j/@C4^[44
a;V^1;bbZ0B_Yil4Y9jF0iVES`B=S8P4PX>117MlO0A^MWL4J79d0fA_L`APKG84G6ab15U[LPAFJW84
DfUb151YLQGoool001Coool4EW1j15igP@AVOhP4KXN?17J?U`=oV9l4Qj2V192X[PBI/KH4Vk:f19bc
]`>N]KX4XKRl1:Bk`0BX`<@4[<C81:o8c0Bbb/d3]<[=1;K;c@Bhbld4^/c<1;c<c0BncLd4`<k>0l;@
c`C4dM04a]?A1<SEdPC:e]<4c=SD0lgHe0C=em84c=K@1<_CcPC:d<X4b<g71<K9``?4aKh4`L6j1;nn
]`Bn_;D4_K^b1;nj/P?1^[44`[Za1<Bj/@C4^Jh4_;:X1:nWW`BTWYH3VIF?18f<R0B2Ph44Mgal16if
M`AXLW@3I6mc161]LPALK784FF]b15IZLPACJG84D6Ub5Oooo`005?ooo`AFL7X4GWN116IoR0A^Qhl4
MXnG0gnHW`B7X:H4T:R^19Va]PBK/[H4W;>g0ije^PBQ^;`4Y;_01:S0a0B/a<P4[lS<1;;:c@>db/d4
]/_=1;S;c@Bjc<`4_<c<1;k=c@C0c/h3`]3?1<CAd0C6dm44b=GB1<[Fd`C<f=@3cMSD1<gGdPC<e]04
bm?>1<[@bPC8cLL4a/W30lC5_PC1`KX4_kjg1;jl]@Bm^k84_kZb0l6j/@C2^[44a;Za1<Bi[PBl/ZP4
[jNO1:BNUP>IUHl4SHb818:3P@AgO7`4KWIg16QbM0=TKg<4H6eb15a/LPAIJg84EVYb15=YLPA@JG8E
oooo000Doooo15E_N@AMMWl4I7j616b5S@AdS9@3O9BK18BLXPB<XjT4U:^_19J//0BH[[43VJnc19bb
]PBO][X4XkZm1:Nn`@B]`lH4/LS:0kC;c@Bhc<h4^/k?1;g@d0C0dM44`];A1<GCdP?7eM@4bMOE1<_I
ePC>fmL4d=cH1=7Mf0?BgMP4d]cF1=7Je0CAem44d=G>1<kAbPC;cLH3bL[21<O6_PC5`k/4a<2g1<>o
]@C3_K@3`kbb1<>k/@C4^Zl4_kFZ1;BZX@BXX9L4W9J?0hn;QPB1P7`4MGId16Y^KPASJFX4H6U[0eiY
K0AKJ6d4FFQ^15IXK`ADJ704DVQa151XLAGoool001Coool4EFmi15efO`ATOXH4K8F=17B<U0=lU9/4
Q9bR18bSZ@BDZjl4UZb`19R^/@>I[k<4W;:f19nf^PBS^[d4Ykk11:g3aPBab<X3]<_=1;S<cPBjc/l4
_M3@1<3Ad@C2d]44aM?B0lOEe0C9emD4bmWF1<kKe`C@g=P4dMgH0m;Mf0CBg=H4dM[D1=7Gd@C@eLh4
c]7:1<_=aP?9b/84alJn1<G3^`C4`;L4`kne1<>m]0?3_;84`k^a1<Bj[`Bo]JX4]:ZQ1:RPU`BLUXl3
Sh^61860O0AeMW@4JVi^16=YJPAPJF/3GVU/15]XK@AIJ6h4EVQ_15AXL0ABJ744D6Qa5Oooo`005?oo
o`AEKgT4GGIo16AnQPA/QHd4M8bD0gbDV`B4W:84S:>Y19B[[`BF[;04V:ja0iV_/`BL/[H4WkJj1:>j
_@BW_/44[L?61;78bP>dbld4^<c>1;[>c`Bmd=04`=7A1<;Bd@C5dm83amGD1<WGe@C;fMH4c]_G1=3L
f0CAgMP3d]gH1=;LePCAf]@4dMOA1=3EcPC>dLX4blg60lW:`PC7a[h4aL>k1<C0]`C3_kD4`kfd0l>l
/PC3^k44a;Z_1;neZPBdZZ44Z:2G19bFS`>?RhH4PH1l17EfM0AZKVh4HfUZ161YJ`=NJF`4FfQ]15UX
KPAFJ6l4E6Q`159XL@A@J74Eoooo000Doooo15E_N@AMMWl4I7j616b5S@AdS9@3O9BK18BLXPB<XjT4
U:^_19J//0BH[[43VJnc19bb]PBO][X4XkZm1:Nn`@B]`lH4/LS:0kC;c@Bhc<h4^/k?1;g@d0C0dM44
`];A1<GCdP?7eM@4bMOE1<_IePC>fmL4d=cH1=7Mf0?BgMP4d]cF1=7Je0CAem44d=G>1<kAbPC;cLH3
bL[21<O6_PC5`k/4a<2g1<>o]@C3_K@3`kbb1<>k/@C4^Zl4_kFZ1;BZX@BXX9L4W9J?0hn;QPB1P7`4
MGId16Y^KPASJFX4H6U[0eiYK0AKJ6d4FFQ^15IXK`ADJ704DVQa151XLAGoool001Coool4EFih15ae
OPASO8@4JX>:17:9T0=iT9L4PIRM18VOY0BAYZX4TZNZ19>X[0>FZZd4VJj`19fb]@BQ][T4Y;^n1:W0
`PB^aLP3]L[<1;W=cPBmd=44`=?C1<CEe@C7emH4b]WH0lcKf@C?gMX4dMoL1=?Qg@CEhMd4e^;M0mOQ
f`CGh=X4emkG1=KLe0CDfM44d]G=1=3Ab@?>c/D4c<_11<[7_PC9a;X4b<:h1<O0]@?6_[<4a[b`1<>h
[0Bj[j@4[ZBJ1:2HT0BARhD3Ph1k17EdL@AWJFP4FUaL15IKG0AHH6<3F69V15ITJ0AEI6X4E6E/159V
KPAAIfl4CfMa5Oooo`005?ooo`AEKWP4G7En16=lQ0AZPhX4LXV@0gV@U`B1V9d4RInT196VZPBBYjX4
TjR/0iJZ[@BI[[04WK:e1:6f^@BT^kh4ZL321:k5b0>eb/`4^Lg>1;g@d@C0dm<4a=GE1<OGePC:fMP3
c=_I1<oMfPCAgm`4dn7M1=GQg@CFh]d3en7K1=OPfPCGg]L4e]cD1=CId@CBeLd4d=790lk>a@C<bl44
b/Nn1<W4^PC8`[P4al2e0lJn/`C6_;04`kR/1;Z_Y0B^Y9X4X9R@196;Q@>3P7/4MGAa16MYJ0AJG5`4
EU]L15QPH`=HHVH4EVAX15ETJPADIF`4DVI^155WK`A?Ig4Eoooo000Doooo15E^N0ALMGh4Hgb416Z3
RPAbRI03NI2G186HW@B9Wj@4TJJZ19:WZPBCZ:`3UZZ]19V^/0BM/[D4XKJi1:Bk_PBY`<84[/G80kG:
c0BicLh4_M3A1<3Cd`C4eMD4amOF1<[If0?<fmT4cmgJ1=7Og0CChMd4eN7M1=KRg@?GhM/4en3J1=ON
e`CFg=@4e=WA1=;Ec@C@dLT3c/k51<c;`@C:akh4bLBj1<S2^0C7`;D3a[jc1<Jl/0C3^:`4^ZnT1:jT
VPBPV904TH^50h>0N`AeM744IfUX15YLG0AFFe`4F61S0eQRIPAFI6P4EFAZ15AUK0ABIVh4DFM_14mW
LAGoool001Coool4EFih15aeOPASO8@4JX>:17:9T0=iT9L4PIRM18VOY0BAYZX4TZNZ19>X[0>FZZd4
VJj`19fb]@BQ][T4Y;^n1:W0`PB^aLP3]L[<1;W=cPBmd=44`=?C1<CEe@C7emH4b]WH0lcKf@C?gMX4
dMoL1=?Qg@CEhMd4e^;M0mOQf`CGh=X4emkG1=KLe0CDfM44d]G=1=3Ab@?>c/D4c<_11<[7_PC9a;X4
b<:h1<O0]@?6_[<4a[b`1<>h[0Bj[j@4[ZBJ1:2HT0BARhD3Ph1k17EdL@AWJFP4FUaL15IKG0AHH6<3
F69V15ITJ0AEI6X4E6E/159VKPAAIfl4CfMa5Oooo`005?ooo`ADKWP4FgAm165jPPAXP8L4KhJ=0gJ=
TPAmTiP4QI^O18fRY@B>XjH4T:BW0i>VZ@BFZJ`4VJb^19f`/PBS]kP4ZKfn1:o3a0>fbLT4_<k>1<3B
dPC4eMD4b=SH1<_LfPC?gmd3d^7O1=GSh@CGiN84f^OS1=_Xh`CLj>83g>OP1=cTg@CLh]X4fmoG1=WL
d`CGf<l4eMC;0m?Aa`CAc/<4clZo1<g7^`C;`kP4bl2d0lVn/@C5^Jd4_[:V1;>WW0BUVi44UXj618N1
N`=hMG44JVUV15aNG@AAEED4DEIG155IG0=BG604DUmT155QI`AAHVT4D6A/14mUKPA>Ig0Eoooo000D
oooo15A^N0AKM7d4HGZ216R0Q`A_QXd3MXfB17fCV0B5Vil4SJ:U18jSYPB@Y:L3TjJY19JY[0BI[:h4
WK2b1:>g^0BY_Kh4[l?40kK9b@Blc/h4`=;B1<CEe@C8f=P4bmcJ1<oOg@?BhMl4eN?Q1=OUhPCJin<4
fnSS1=cXhP?Lin04g>CM1=cRfPCKgmL4fMcC1=OHc`CEe</3dm771=7>``C?b[l4cLNk1<_3^0C;`;@3
bKja1<Fi[@Bn/ZH4/jNL1:FKT@BFSXH4Qh5k0gQeL@AZJFH4G5iM155EE@AAEUL4DEUL0e9LH0ABGf@4
DF5W155RJ@A@I6`4CfE^14iWL1Goool001Coool4E6ih15]dO@AQNX84J82716n6S@=fSI84OI>H18FK
W`B=XZD4SZ>V192TY`>CYZT4UZV/19V/[PBM/;84XkNh1:Vm_PB_`l@3]/W91;c>cPC0d]84a=GE1<SH
f0C;g=X4cmoM0m;Qg`CEhn44enGR1=[Wh`CKj><4g>SR0mcWh0CLi=d4g>;J1=_Oe`CIg=<4emS?1=GD
b`?CdLL4dLk31<o:_`C=ak/4bl>h1<_0]0?9_[44aKV]1;jbYPBcYi`4YI^A19J>QPB7PG/3N7Ea16YY
IPALGUd4DEEE155FE`AAFE`3DUaP159OI0AAHFL4DF9Y151TK0A?IFh4CVM`5Oooo`005?ooo`ADKWP4
FgAm165jPPAXP8L4KhJ=0gJ=TPAmTiP4QI^O18fRY@B>XjH4T:BW0i>VZ@BFZJ`4VJb^19f`/PBS]kP4
ZKfn1:o3a0>fbLT4_<k>1<3BdPC4eMD4b=SH1<_LfPC?gmd3d^7O1=GSh@CGiN84f^OS1=_Xh`CLj>83
g>OP1=cTg@CLh]X4fmoG1=WLd`CGf<l4eMC;0m?Aa`CAc/<4clZo1<g7^`C;`kP4bl2d0lVn/@C5^Jd4
_[:V1;>WW0BUVi44UXj618N1N`=hMG44JVUV15aNG@AAEED4DEIG155IG0=BG604DUmT155QI`AAHVT4
D6A/14mUKPA>Ig0Eoooo000Doooo15A]M`AJLg/4H7R016ImQ@A/PhT3LhR>17V>T`B0U9P4R9^N18VL
W`B;WZ43SZ6S196SY@BEYjP4Vjf^1:6c]0BY^[X4//?20kW:b@Bnd<l4`mCC1<SIe`C<gM/4d>7O1=CU
h`?Gj>D4fn[W1=k/j0CPkNP4h^gW1>?]iP?Sk>@4hnWQ1>7Vg@COhmT4g]oE1=cKd@CIf<d3em?81=C?
a0CBc<04dLVl1<o5^0C>`K@3b[f`1<FgZ@Bk[J04[J2D19fBR@B=QGd4OWQa0fm[IPAOGU/4D59@14M;
B`A:Ce44C5AF0deGF`A>Fel4CUeS14iPI`A>HVX4CVA]14iVKaGoool001Coool4E6eg15YcN`APN804
IWf516b3R@=cR8h4NHjC182DV0B8Vih4RIbO18^NX@>>XJ<4TJ>U19FWZ0BK[Jh4XK>d1:Vj^PBb`l83
^L[91;k@c`C3e=<4b=WG1<cMf`C@hMl4e>GS0mOXi@CKj^L4g^cX1>3]j0CRkNL4hngV0n?/i0CSjN44
hNKM1=oSf@CNgmD4g=_A1=WHc@?GdlP4e<o41=;<`0CAbK`4clFh1<k1]0?:_K04aKNY1;^]X0B]X9@4
WI:918f5O@AnN743Kf]V15mNF`A@DU04Ad];14Y?D@A<E5H3CEMK14iKG`A>GF<4CV1W14iRJPA>I6d4
CVI_5Oooo`005?ooo`ADKGL4FW=k161hP0AVOHD4K8>90g>8SPAiSY<4P9BH18RKWPB9W9l4RijQ0hjQ
X`BAXjD4UJNX19^][PBQ/k@4ZKZj1;;3`P>ib/T4_]3?1<?Dd`C8fML4c=gK1=3Qg`CDiN<3enSU1=_Z
i`CNk>P4h>gX1>;]i`CSkNH3hncT1>?Yh@CQi]d4gn?I1=kOe@CLfm44fMS=0mOCb0CDcl@4d/c01=79
_0C?aKP4c/6d0lZm/0C5]jT4^jfP1:fPU0BMTXT4SHEm17ihL@=_JfH4GeiK151BD0A7Bd/4BTmA14aD
EP==Ee/4CU]O14iMH`A>H6L4CV9Z14iTK@A>IVlEoooo000Doooo15=]MPAILGX4GWIn16AkPPAYOhH3
KhB917F9S@AkSY44PIBF18>EU`B7UiT3RY^L18jOX0BCY:@4V:VY19n_[`BX^;H4/l;00k[:b0C1d<h4
a]KD1<cLfPCAhMl4eNKS1=[Yi`?NkNT4hNo[1>C`j`CVl^/4j??[1>WcjP?YlNL4j>kS1>KZg`CTi]/4
h^?H1>3Od`CMf/h3fmK:1=SAa@CFcL04e<Vl1=;5^0C>`K<3b[^]1<6bY0BdYIP4Y9J;19:8OPB1NW84
LVeW0f5OF`A@D4h4@41013do@0A3BDX4ATiA0dQCE`A:Ee`4BeYP14aMI0A<H6P4CF=/14eUKaGoool0
01Coool4Dfef15UaNPANMWh4I7^216UoQP=_Q8T4MHV=17^>T@B1U9H4PiFG18NGV@>:Vi`4SYnP19>T
Y0BHZJT4Wjn_1:Rh]PBc`/03^/[81<7@cPC6e]@4c=cJ1=7Qg`CEi^<4f^WW0mk]j@CQkn/4i?3[1>Kb
j`CXln/4jO?Z0nWai`CXk^<4i^[O1>CVf`CRhmP4h=oC1=gJcP?Ke/X4f=751=K=`0CDbK`4d/Fh1<k1
/`?:^jd4`K:T1;BUV0BTUX/4TXQn185jLPAbKFL3HEmK151@CPA0@404?Cm014=9BPA6CU43B5=G14YG
G0A;FV04C5eT14aPJ0A=Hf`4CFE_5Oooo`005?ooo`ACKGH4FG5j15ifOPATNh84JGn60fn4R@AeRHd4
NhjA186DUPB3UIL4QiNI0hZKW0B>Wj04TjBT19RYZ@BO[jl4Z;Rf1;?2`0>jb/P4`M3>1<KFe0C<g=X4
dN7O1=GVh`CJjNL3g^gY1>7_j`CTl>/4i_;[1>Scj`CYlnX3jO7W1>S^h`CVj]l4i>KK1>;Sf0CPgm<4
gM[>0m_FbPCHdLD4e/g01=C9_0CBaKP4c/6c0lZk[@C1/Z@4]:FH1:BFR`BBR7h4PGYb179]I`=QGe/4
D51>1410@0@m?d04@dU:14I>D@=8DeL4BUML14]JH0A<GF@4C61X14eSK0A=IFlEoooo000Doooo15=]
MPAILGX4GWIn16AkPPAYOhH3KhB917F9S@AkSY44PIBF18>EU`B7UiT3RY^L18jOX0BCY:@4V:VY19n_
[`BX^;H4/l;00k[:b0C1d<h4a]KD1<cLfPCAhMl4eNKS1=[Yi`?NkNT4hNo[1>C`j`CVl^/4j??[1>Wc
jP?YlNL4j>kS1>KZg`CTi]/4h^?H1>3Od`CMf/h3fmK:1=SAa@CFcL04e<Vl1=;5^0C>`K<3b[^]1<6b
Y0BdYIP4Y9J;19:8OPB1NW84LVeW0f5OF`A@D4h4@41013do@0A3BDX4ATiA0dQCE`A:Ee`4BeYP14aM
I0A<H6P4CF=/14eUKaGoool001Coool4DVae15M`N@ALM7`4HGQo16IlPP=[P8D4L8B817J8R`AkS8h4
OHf>186@T@>5U9D4RYVI18nNWPBFY:<4WJ^Z1:Ne/PBa_[/3^/O41<?AcPC:fMH4d=oK1=KTh@CKjND4
h>gX0nCaj`CXm>d4joK^1>ggk`C_n>h4l?K]0nodj@C^lNH4k>gR1>[ZgPCWiMT4i>7D1>7Lc`?NelX4
g=;51=W>`0CEbKX4d/>e1<fn[`?5]JH4^JVK1:ZKSPBIS844Qged17M_J0AVHE`3EE=@14I6A@@k?Cd4
?3m013i4APA2BTd3A4mC14MDF@A8F5h4BU]R14]OIPA<HV/4CFE^5Oooo`005?ooo`ABK7D4Eg1i15ad
O0AQN7l4IWb20f^0Q@A`Q8P4MXR;17^<SPAmSHh4PI2A0hFDU@B:VIT4SijN19JTX`BMZjX4YkFb1;6n
^`>jal@4`m7>1<[IePC@gm/4e^CQ1=_Yi@CPkNP3i?7[1>Sdk@C[m^h4kOO_1>ohkPC`m^d3koCY1>ka
iPC/kN84j^[N1>OUf@CThM@4hMc?0mkGbPCLd/D4fLk01=G9^PCB`kD4cKj_0lFeYPBiZI/4ZY^>19V<
P@B7OG@4MfmX16IQG0=EDe04ATI513/m?@@l?d04?TA6149:C@=4Ce<4AeAI14QHGPA:Ff84BemV14aR
J`A=IFhEoooo000Doooo159/M@AGL7T4G7Al165hO`AVO883Jh251724R0AfR8/4Nhb>17f=SPB1T943
QIBE18ZIV@B?WYh4UZBS19f[ZPBW]K84/Kjk0k[7a0C3dLh4b]WF1=3Of`CFi>44fnWU1>3]j0?TlN/4
j?C]1>_fkPC]mnl4koS^1?3fk@?_m>T4k_7V1>c]hPCZj]h4inGI1>CQe0CQg<l3g]O:1=cBa@CIc/04
eLVj1=;3]@C=_Zl3aKFV1;VYV`BZVhh4VHb118MmM0AgKfP4IV5L0eECD0A6ATD4>cdm13`o@0@nA4H4
@TY=0dA?D`A7E5T4B5QN14YKHPA;GfH4C69[14eUKQGoool001Coool4DVae15M`N@ALM7`4HGQo16Il
PP=[P8D4L8B817J8R`AkS8h4OHf>186@T@>5U9D4RYVI18nNWPBFY:<4WJ^Z1:Ne/PBa_[/3^/O41<?A
cPC:fMH4d=oK1=KTh@CKjND4h>gX0nCaj`CXm>d4joK^1>ggk`C_n>h4l?K]0nodj@C^lNH4k>gR1>[Z
gPCWiMT4i>7D1>7Lc`?NelX4g=;51=W>`0CEbKX4d/>e1<fn[`?5]JH4^JVK1:ZKSPBIS844Qged17M_
J0AVHE`3EE=@14I6A@@k?Cd4?3m013i4APA2BTd3A4mC14MDF@A8F5h4BU]R14]OIPA<HV/4CFE^5Ooo
o`005?ooo`ABJgD4EVmg15]bNPAOMG`4HgQn0fQkP0A/OX84L86417F5Q`AgQXL4NhV90h2=S@B5TY44
RiRF196NW@BIYJ<4XJj[1:bh]0>ha;l4a<o:1<gIe0CDh]`4f^SR1>7^i`CVl^X3j_G]1>khk`Can_44
m?ca1?Kll0Cgn^h3mOS[1??di`C`l><4k^cN1>_Wf@CXh]@4iMg?0n7HbPCNdl@4flfn1=K8^0C@`K44
b;RX0kf/W@B^WY04WHn318b0MPAkLVT4JfAM15UED0=7AD<4>CXi13<d=@@f>S/4>T1213i6B@=1C504
A55F14IEF`A8FV04BEeU14]QJPA<I6hEoooo000Doooo159[M@AFKgL4Fg9j15meO0ASN7h3J7^016an
PPA`PH@4MHF717N6Q`AkRHT3P8f=18FBT@B;V9H4TIjM19VUX`BQ[Z/4[;Rd0kS4_`C4clX4cMWD1=CR
g0CJj>84hNkW1>KbjP?ZmNd4k_S_1?7jl@Cdo?44m_c`1?OjkP?en>/4loCW1?3`h`C^k=h4jnOI1>SR
e0CUgLl3hMS:1=kCa0CKcKh4e/Rh1=31/@C8^:P3_JbM1:jNT0BMSh<4S81f17]bJ@A[I5d4FEE@0dM5
@`@i>ST4<c@e13Hj>`@j@484?TI90d5<D0A4DEH4AUEK14QJH0A9GFD4Bf5Z14aTKQGoool001Coool4
DV]e15I_M`AKLWX4GgEl16=hOP=XNh04K7j21721Q0AeQHL4MhJ717^9R@>0SHd4QI:A18^HUPBAWYd4
VJFS1:6^Z`B/^;@3^<Bo1<C?bPC=fM@4e>;L1=[XhPCQk^L4i_;Z0n[ek@C^n>l4lO[a1?Cll@Cfo?04
mo[^0oGhj`Ccm>L4l?3S1>k/gPC[imT4j>;D1>GMc`?Qf<X4g]?41=_=_PCFb;P4d<6a1<RhZ0>m[9d4
[Yj@19f?P`B<P7H4Ng9Y16]TG@AIEE03AdE313Tj>@@c=3D4=SXk13Y0@P@nATT3@Da@14AAEPA6EE/4
B5YP14UMI@A;HFX4C6A^5Oooo`005?ooo`ABJgD4EVmg15]bNPAOMG`4HgQn0fQkP0A/OX84L86417F5
Q`AgQXL4NhV90h2=S@B5TY44RiRF196NW@BIYJ<4XJj[1:bh]0>ha;l4a<o:1<gIe0CDh]`4f^SR1>7^
i`CVl^X3j_G]1>khk`Can_44m?ca1?Kll0Cgn^h3mOS[1??di`C`l><4k^cN1>_Wf@CXh]@4iMg?0n7H
bPCNdl@4flfn1=K8^0C@`K44b;RX0kf/W@B^WY04WHn318b0MPAkLVT4JfAM15UED0=7AD<4>CXi13<d
=@@f>S/4>T1213i6B@=1C504A55F14IEF`A8FV04BEeU14]QJPA<I6hEoooo000Doooo155[M0AEKGH4
FG1h15ecN@APMG/3I7Ml16MiO@AZNgd4K7]k16mmO0AdPH43NXJ517j:R@B4T8l4RiJE19:NV`BKYZ<4
Y[2[0k:k]@Bob<44c=K>1=OQf@CNjN04iNoV1>cej`?anNh4mOca1?SnlPCkoo84oOob1?gml0?kn^`4
n?GW1?GahPCbkMh4knSI1>_Re0CWgLh3hmO71=kA`@CIb[X4d/>b1<^jZPC0[il3/:2A1:2AQ0B?PWH4
OW=Y16aTG0AKEDl4BDI20cXh=`@[:RT4:BTY134d=P@f?3l4>T=60ci9C@A1Ce@4A5AJ14IHG`A8G6@4
BV1Y14aTKQGoool001Coool4DF]d15E]MPAIL7P4GG=i161eN`=TMg`4IgUm16YkO@A/Ng/4Kgel17B1
P@=jQXD4OXZ918B@S`B;UYD4TYjK19^VX`BV/:/3/[^e1;o8`@C<e/h4en7I1=kYh0CUknH4k?G[0o7i
kPCeo?44n?kb1?_olPCmoo84oOg`0o_jk0ChmNL4mO7R1?;]gPC_j=T4jn;D1>OMcP?SelL4g]711=W:
^PCB`k84bkZZ1<2_W`>`X944X96418n2MPAnLfT4K6AL15]EC`A9AT83>SPg12/Z:@@Y:BT4<C@f13Hl
?`@j@dH3?TU=145?E0A4E5X4AUQO14QLI0A:H6T4C6A^5Oooo`005?ooo`AAJg@4EFef15U`N0AMLgT4
H7Ek0fAgO0AWNGd4JW]m16akN`A_OG`4M8610gZ6Q@AnRXT4Q92?18^FU@BBWY/4VjJS1:J`Z`>b^kD4
_lS11<cFcPCGhMT4g^WP1>G_iPC/mN/3lOW^1?Gll@Cho_84noob1?golPCmoO03no[/1?Sei`CelN84
l^gN1>oXf@C[h]@4img>0n?Ga`CNdL44fLZj1=;3/PC;^ZX4`:nO0k2PT@BPTH@4Sh9f17icJ@A/I5`4
FeE?14U6@P<j>3L4:bXY12TY:@@a=3H4=S`o13Y3AP<nBDd4@DmD14ADFPA6F5l4B5aT14YPJ@A<I6hE
oooo000Doooo155[M0AEKGH4FG1h15ecN@APMG/3I7Ml16MiO@AZNgd4K7]k16mmO0AdPH43NXJ517j:
R@B4T8l4RiJE19:NV`BKYZ<4Y[2[0k:k]@Bob<44c=K>1=OQf@CNjN04iNoV1>cej`?anNh4mOca1?Sn
lPCkoo84oOob1?gml0?kn^`4n?GW1?GahPCbkMh4knSI1>_Re0CWgLh3hmO71=kA`@CIb[X4d/>b1<^j
ZPC0[il3/:2A1:2AQ0B?PWH4OW=Y16aTG0AKEDl4BDI20cXh=`@[:RT4:BTY134d=P@f?3l4>T=60ci9
C@A1Ce@4A5AJ14IHG`A8G6@4BV1Y14aTKQGoool001Coool4DFYd15A/M@AGKWH4Fg1g15ibN0=QLgP4
HgAh16EeM`AWM7D4JWEf16iiN@=cOWd4NH>217n9Q`B5Sh`4S9JC19BNVPBMYZ43Z;6[1;Fm]PC3bl84
cmK=1=cSf@CWkN84koCX0oGjkPChoO04o?ka1?ool0Coo^h4o__[0oghj0CkmND4n?3Q1?C[f`Cai]H4
k^7A1>WLbP?Re<<4g<bk1=G5/`C<_:X4`JnO1;>QTP>STXD4TH=g17mdJ@A^I5/4G5A>14Y5@@@j=cD3
;2/Z12@T90@W:BX4;C4c138i?0@g@D@3>dM<13m=DPA2DUP4AEMN14MKH`A9H6P4C6A]5Oooo`005?oo
o`AAJW@4E6ae15M^MPAKL7L4GW9h0f5cN0ASM7P4IGEg16MdM@AZMGH4KWUi0g=nO@AiPh84OhV718F?
S0B<UY<4U9jJ19fVX@>X/J/4]Kff1<?;`PC?e/d4g>?I1>O]hPC_m>P3mO[^1?Sml0Clo_44ooo`1?on
kPCnnn/3oOSX1?_ei@Chl>44m>_K1?7VePC^hM44jMc:0n;D``CLc;/4eLFc1<blZPC1[il4/j6B0j>B
Q@BAPgL4OgAY16iTF`ALE4h4BTE113Xg=@</:bX492@T12LY:P@]<C<4<STl13M1A0<kAd`4?deB149B
F0A5Eeh4Ae]S14UPJ0A<I6dEoooo000Doooo155ZM0ADK7D4Efif15]`M`ANLWP3HG=h16=dN0AUMGL4
IgAe16YeMPA^NGT3Lgim17V3PPAoRHL4QHn<18bFT`BDWYX4WJJQ0jRaZ`Be_KH4`l_21<oFc@CLhmT4
ingR1>odj0?en^h4n?g`1?cnl@Cooo04ook^1?kkj`?mn>P4noGU1?S`h@Cdjm/4lNKF1>kQd@CYg<X3
h]C31=c<^`CEaK<4c;bZ1<6_W`BcXI83Xi:51963M`AoM6T4KVAK15aDCPA:AD44>SLe0b`[:P@T92@4
9bTZ12da<`@b>C`4=d540c]7C0@oCE84@U9H14EGGPA7Ff<4BF1X14aTKAGoool001Coool4DFYd15A/
M@AGKWH4Fg1g15ibN0=QLgP4HgAh16EeM`AWM7D4JWEf16iiN@=cOWd4NH>217n9Q`B5Sh`4S9JC19BN
VPBMYZ43Z;6[1;Fm]PC3bl84cmK=1=cSf@CWkN84koCX0oGjkPChoO04o?ka1?ool0Coo^h4o__[0ogh
j0CkmND4n?3Q1?C[f`Cai]H4k^7A1>WLbP?Re<<4g<bk1=G5/`C<_:X4`JnO1;>QTP>STXD4TH=g17md
J@A^I5/4G5A>14Y5@@@j=cD3;2/Z12@T90@W:BX4;C4c138i?0@g@D@3>dM<13m=DPA2DUP4AEMN14MK
H`A9H6P4C6A]5Oooo`005?ooo`A@JW<4Df]d15I]M0AIKWD4Ffme0ee`M0AOL7@4HG1b169_L@ATKfl4
Ig5_0f]eM0AaNWT4MX1m17f6P`B4S8T4RiB?19FMV0>OYj44Zk:[1;Nn]PC4b/44d]K;1=kQe@CVj]d3
kO3R1??di@CgmnL4n_OW1?[fi0Cjln43nO7O1?S^g0Cfj]P4lnKD1?3Qc`CZflT4i=C20mk=^`CFaK<4
c;^Z1<6_WPBcXI44Xi:40i:3MPB0LfP4KV=J15aDC0A9A3l4=cDa12TX9P<N7A`46a/L12<V9`@Z;c44
<3Lj13Do@`<iATX4?DaA145AE`A4EUd4AU]S14UOJ0A;I6dEoooo000Doooo151ZL`ACJg@4EVed15U^
M@AKKgD3GG1d15m`M0AQL784HVma16A_K`AWLFl3JgEd175jN@AfP7d4OHJ318B<R@B;U8l4UIfH0inW
X@B[/Z/4]kjf1<C:`@CBe//4g^7E1>KZg@?]l>84loCU1?Ogi`CjmnL4n_KT1?[ch@?ilMl4n>kL1?KZ
f0Cci]@4l>7?1>[Kb@CTe<83g/fk1=K5/`C<^jX4`JnN1;>QT@BSTX@3TX=f181cJ0A^HeX4G5A<14U4
?`@g=C44:BPV0ahM70@K6a`48bHW12X_<@@`=cX4=Cm30cU6BP@mC544@E5G14AFG@A6Ff<4BEmX14]T
KAGoool001Coool4D6Yc15=[M0AFKG@4FFie15]_M@=ML7@4Gg1d165`LPARKg44I6m_16MaK`=[MG@4
LGYi17J0O@AmQX<4Q8b918^DS`BEWIP3WjNQ1:^bZ`Bg_[H4a<[11=;Fb`CNhMD4i^[M0ng`hPCcm>D4
moOW1?[gi`Cjm^@4n_?Q0oWag`Chk]`4m^[H1??Ve0C`hLl4j]_91>CD`P?NcK/4e/Fc1<bkZPC1[ih4
/j6A1:>BQ0>BPgH4P7=X16iSFPALE4`4BD@o13Le<@@Y:2H37QdL11/K70@S9RL4:Rla130g>P@e?d<3
>DI:13e<D@A1DEL4A5IM14IKH`A9GfP4BfA]5Oooo`005?ooo`A@JG<4DVYc15A[L`AGK7<4FFab0eY]
L@ALK704GFa^15iZK0AMJ6P4GfUX0fA]K0AYLW44KWMe17=lN@AiPGh4PXZ618fDS`>HWiT4Y:ZS1:ne
[@Bj`;L4a/[01=3Ca`CIf/d3h=oA1>KTe@C[j=P4k^WH1>kXe`C_imH3l>GC1>oSd0C]h<d4jmc91>OG
a0CRd;h4flZg0m?2[`C:^:L4_jfL1;:PT0BRTH@4TX=f0h1cJ0A^HeX4G5=<14U3?@@f<bl49RDR11XI
60<B4A445aLG120T9@@X;S04;SHj13<n@P<hADX4?4]A141@E`A3EUd4AUYS14QOJ0A;I6dEoooo000D
oooo151YL`ABJW<4E6]c15M/L`AIK783FVea15a/L0AMK6h4GVY/15eXJ0AOJFP3I6e/16UbL@A^MgD4
Lgai17V1OPB2RXH4SIB?0iROV@BTZZ<4[kF]1;[0]`C6b/04d=?71=WJc@?Pgm44i^CE1>_Xf0C^jMP4
k^SG1>oWeP?`iM<4kn?@1>gPc@C[g<T4imO41>;@_PCKb[L3dl:_1<ZhY`Bo[I`4/Z2@1::AQ0BBPgH3
P7=X16iSFPALDd`4BD<m13Hc;`@V9B846QTH0a8A4@@G5aL482@U12P^<0@^=SX4<ci20cQ5BP@lBe44
@51G14=FG@A6FV<4B5mX14]TKAGoool001Coool4D6Uc159ZL`ADJg<4Efac15U/LP=JKG44G6a`15e/
KPANJV`4GFQX15mYJ0=TKF`4JG9a16igM@AcO7T4NH5n18::QPB=U8l3V9nI1:BZX`B_]Jd4^/2g1<K:
`0C@dlL4fM[=0n3Od@CVi=D4jnSH1>kYf0C^j=L4knOF0o3Ud`C_hm04kN3=1>_Lb@CWel@4h]2n1=_:
]`?C`Zl4b[RW1;n]W0BbX904XY6419:3MP>0LfP4KV=J15aCC0A9@cd4=S<_12HU8P@J6AP34Q4A11LG
5`@P92D4:2h`12hf>P@c?T83>4E:13a;D@A0D5L4@eIM14IJH`A8GfP4BfA]5Oooo`005?ooo`A@JG<4
DVYc15A[L`AGK7<4FFab0eY]L@ALK704GFa^15iZK0AMJ6P4GfUX0fA]K0AYLW44KWMe17=lN@AiPGh4
PXZ618fDS`>HWiT4Y:ZS1:ne[@Bj`;L4a/[01=3Ca`CIf/d3h=oA1>KTe@C[j=P4k^WH1>kXe`C_imH3
l>GC1>oSd0C]h<d4jmc91>OGa0CRd;h4flZg0m?2[`C:^:L4_jfL1;:PT0BRTH@4TX=f0h1cJ0A^HeX4
G5=<14U3?@@f<bl49RDR11XI60<B4A445aLG120T9@@X;S04;SHj13<n@P<hADX4?4]A141@E`A3EUd4
AUYS14QOJ0A;I6dEoooo000Doooo14mYLPAAJG84DfYb15EZL@AFJW03F6Y_15UYK@AIJ6/4FFIX15UT
I0AIHV43Ff=R165YI`AUKV/4Jg=`179iMPAkPWh4QHb70hnFT0BIWiP4XjRP1:nbZ@Bj^k04`/>g1<S9
_0?>cL04eM;41=WEaPCMf<P4g]S81=oFaP?Ne<<4gM701=[=_0CHb[P4eLFc1<o0[@C8^:H3_jjN1;JU
U@BZVX/4WHj018f0L`AmLFH3K69I15]BB`A9@Sd4=S8^12DR8@@G5QD42`T90``;2`@G6AX482@V12L^
<@@]=SX4<Si20cM4BP@kBe44?e1G149EG@A5FV<4B5mX14]SKAGoool001Coool4CfUb155YLPACJW84
EFYa15IZL0=HJVl4FFU]15UXJ`AIIVP4FFAT15URH@=KHf84HFUW16E^J`A[Lg04LWUf17^2OPB5S8L3
SiJ@19VOV0BSZ:04[k:Y1;Zk/0C2`kL4b<Vl0lk=`0CEd/@4fMG61=gHb0CNf<P4gmK60mkD``CMdL04
f/fl1=S:^0CEaK<4cl2]1<RhYP>o[Yh4]ZFE1:ZJR`BMSX04SH1c17eaIP=/HUT4Fe9;14U2?@@f<Rh4
9B8Q11LF5@@;2@T330/;11LI6P@P92H49bha12df>P@b?T83=dA:13];D@@oD5L4@UEM14EJH`A8GfP4
Bf=]5Oooo`005?ooo`A?JG84DFUb15=ZLPAEJW44EVY`0eQZK`AIJFd4FFQ[15UVJ0AII6@4FF9Q0e]S
HPAQJFL4IFi[16]cL0AbNGH4Nh9n18F<Q`>?UY04VInH1:>XX0B_/ZT4^[^`1<;3]`C8bK`3c/g01=GB
a0CIeLH4gMS81=kHb0COe/H3g]C31=gA`0CJcK`4f<Zh1=G5/`C?`:d4b;RV0kn^WPBfYID4ZYZ;19f>
P0B=P7<4OG5V0faRF@AKDT/4BD8m13Hb;P@U8R445aHE10/92@<<2`/45aTJ120T9P@W;S44;CHj138n
@P<gA4X4>d]A13m@E`A2EEd4AEYS14QOJ0A;HfdEoooo000Doooo14mYLPAAJG84DfYb15EZL@AFJW03
F6Y_15UYK@AIJ6/4FFIX15UTI0AIHV43Ff=R165YI`AUKV/4Jg=`179iMPAkPWh4QHb70hnFT0BIWiP4
XjRP1:nbZ@Bj^k04`/>g1<S9_0?>cL04eM;41=WEaPCMf<P4g]S81=oFaP?Ne<<4gM701=[=_0CHb[P4
eLFc1<o0[@C8^:H3_jjN1;JUU@BZVX/4WHj018f0L`AmLFH3K69I15]BB`A9@Sd4=S8^12DR8@@G5QD4
2`T90``;2`@G6AX482@V12L^<@@]=SX4<Si20cM4BP@kBe44?e1G149EG@A5FV<4B5mX14]SKAGoool0
01Coool4CfQb155XL@ABJG44DfU`15AXKP=EJ6d4EVI[15IUJ0AFHfD4EF1Q15AMG@=EGU`4F61N15eT
HPASJVP4Jg5^179hM0AjOg/3Q8V318jCS0BHWIH4XjJM1:^]X`Bb/jT4^KV]0knn/@C4`[@4alBf1<[6
]`C<aKH4blBd0l[1/PC8_Zh4a[ZZ1<>fYPBo/J44^J^K1;6SU0>YVh`4X9:419F7N`B8Ng04N6iS16QO
EP=HDDT4AT4l13@a;P@S8B045A@C10P61@@61@D3414B11PL7@@P9RP49blb12dg>`@b?T<3=dE:13];
D@@oD5L4@UIM14EJH`A8GfP4Bf=]5Oooo`005?ooo`A?J784DFQa159YL@ACJG04E6Q^0eEXK@AFIV/4
EVEX15ISI@AEH644E5eM0eENG0AHH5h4GFAR16=ZJ0A[LFh4LWQd17YoN`>4RH<4SY><19RMUPBSYYd4
ZjfS1;:cZ@Bi^Jd3_kja1<C2]0C7a;H4b/Jg1<c5]PC;a;@3b/6b1<Rn[PC6^ZX4`kJV1;naX@BiZi/4
/J>D0jVKS0BPTX@4UHMk18QkL0AhKV<4J5mF0eQAB@A6@C`4=34^12<Q80@E51<420H510H51@<@4A84
61`M120V:0@W;c84;CLk138n@`<gADX4>d]A13m@E`A2EUd4AEYS14QOJ0A;HfdEoooo000Doooo14mX
LPAAJ744DVUa15=YL0ADJ6h3EFQ]15IVJ`AFIFP4EV=U15EPH@ADGEd3EEiL15QPGPAMI684HfYX16]a
KPAbN7@4NWmk0hB9P`B>Th`4V9fF1:>VW@B[[J<4/[>Y1;Vi[@>o_[44a<:d1<O4]PC:a[L4c<Ff1<_4
]0?:`K84b;j^1<JjZPC3]ZH4_k6Q1;V[V`BaXi@3ZI^<1:2BQ0BEQg/4R7]`17Q^H`AXGeH3F55914I1
?0@d<Bh48b4P11DD4`@81PD41PD50a0A4P@H71d482HX12L_<P@]=c/4<Si30cM5BP@kBe44?e1G149F
G@A5FV<4B5mX14]SKAGoool001Coool4CfQb155XL@ABJG44DfU`15AXKP=EJ6d4EVI[15IUJ0AFHfD4
EF1Q15AMG@=EGU`4F61N15eTHPASJVP4Jg5^179hM0AjOg/3Q8V318jCS0BHWIH4XjJM1:^]X`Bb/jT4
^KV]0knn/@C4`[@4alBf1<[6]`C<aKH4blBd0l[1/PC8_Zh4a[ZZ1<>fYPBo/J44^J^K1;6SU0>YVh`4
X9:419F7N`B8Ng04N6iS16QOEP=HDDT4AT4l13@a;P@S8B045A@C10P61@@61@D3414B11PL7@@P9RP4
9blb12dg>`@b?T<3=dE:13];D@@oD5L4@UIM14EJH`A8GfP4Bf=]5Oooo`005?ooo`A?J784D6Qa155X
L0ABIfl4DfM]0e=VJ`ACI6T4Df9V159PHPAAG5h4CeQI0dmEE@A@EU@4EE]I15YPGPAPIV<4IfeY171e
L@=iOWT4PXJ018^?Q`BEUhh4VifD1::SV@BWZ9h3[:fR1;6`Y0Bd/ZD4]k>V1;NbY@Bf/:83]:jP1;:[
W0B_YiT4Zj:D1:JLSPBOUHL4Uhf10i66NPB9OW84OWAY179YG`ATG5@4E4i80d<o>P@b<2d492<Q11HF
5@@71PH40`8210`<3@<C5QL46b0R128Y;0@X<CD4;STm13=0A@<gAT`4>daB13mAF0A2EUh4AE]S14QO
J0A;I6dEoooo000Doooo14mXLPA@J744DFQ`159WK`ACIfd3DfI[15=TJ@ACHVH4DV1R155LGPA?F5T3
CeEE151FE0AEFeT4FV1N161VH`AWKFT4L7Ea0gUnN@B2QX04Rhn719FGSPBKWI@4XZ>I1:NXWP>/[J84
/K2T1;BbY@Bg/jH4]k:U1;J`XP>d[Z04/Z^L1:nWV@B[XY@4YYb>19nEQ`BGSH43THIj18UnLPAnM6T4
LVUO16ALE0ADCTP3@clj138`;@@T8b445QHE10L61P@30P8430`=0a<F5`@K82848RT/12Pa=@@^>Cd4
<d150cM6C0@kC584?e5H149FGPA5Ff<4B5mX14]TKAGoool001Coool4CfQb151XL@AAJ704DVM_15=W
K@=CIV/4DfAY15=RIPABH684DEaN14mHF@=?EED4D5ID15EKF@AJH5h4H6IS16M]J@A`MG43NGii18:6
P0B;ShL4UIN>19^MU0BRXiT4YjRN0jb]XPBa/:@4];:U1;NcYPBg/ZD4][2R0kB^X0BbZi`4[jNI1:^R
U0BVW8h4WiF719N=P@>AQWX4RGib17idJ@AbJEl4I5aD15A>B0=3?cX4<S0]12@S8@@F5QD41`H610<2
0P@<30d34aHG11/P8P@R:B`4:34e12hi?@@c@4D3=dI<13]<DP@oDEP4@UIN14EKH`A8GfP4BfA]5Ooo
o`005?ooo`A?J784D6Qa155XL0ABIfl4DfM]0e=VJ`ACI6T4Df9V159PHPAAG5h4CeQI0dmEE@A@EU@4
EE]I15YPGPAPIV<4IfeY171eL@=iOWT4PXJ018^?Q`BEUhh4VifD1::SV@BWZ9h3[:fR1;6`Y0Bd/ZD4
]k>V1;NbY@Bf/:83]:jP1;:[W0B_YiT4Zj:D1:JLSPBOUHL4Uhf10i66NPB9OW84OWAY179YG`ATG5@4
E4i80d<o>P@b<2d492<Q11HF5@@71PH40`8210`<3@<C5QL46b0R128Y;0@X<CD4;STm13=0A@<gAT`4
>daB13mAF0A2EUh4AE]S14QOJ0A;I6dEoooo000Doooo14iXL@A?Ig04D6M_155VKPAAIF`3DFAZ155S
J0AAH6@4D5iQ14iJG0A<EEH3Adi=14E:B@A:Cdd4D5EC15IKF@AMHUl4HfQU0f]`J`AbMg44NWih18>5
OPB:S8@4T9::19FFSP>IVY44WIbC19nMU0BOWY<4X9jC19nLT@>MVXl4VYN;19NCQ`BASH84S8Ml18J0
M@AoNFl3N79Y171ZHPAVH5T4FEE?14]8@`@m>cL3;bh[120Q80@B51<41PL810820`@92@X4418D0aLK
7@@M92L492``12Xd>0@_>d04<d570cQ7CP@lCE@4?e9I149GG`A5Ff@4B61Y14]TKQGoool001Coool4
CVQa14mWL0A@Ifl4DFI^155UK0=AI6X4DF=X155PI0A@GV44CUYL14aEEP=7CTd4ADY914Y?C@A@EE<4
EU]I15eRG`ASJ6D3Jg1[179gL@AjOWP4PhEn18Z<Q0B@TXX4UIJ>0iVJT@BMW9<4WifD19nNT`BPWY<4
WibA0ifJS`BJUh/4Ui>7196=PPB<Qg`4QX1e17miK`=hLVT4L6YR16IPF@AIEDl4BdQ313dk=`<_;R/4
824P118D4`@61`P40P8310T92P@@4Q@35a/M11dT9`@T;304:S@h12lk@0@c@DL3>4M>13a=E0@oDUT4
@UMO14EKI0A8H6T4BfA^5Oooo`005?ooo`A>J744CfM`151WK`AAIVh4DFE/0e5TJPAAHfP4DF1T151N
H@A>FU`4C5EF0dM>C@A5BTT4BTm=151ED`AFFeT4GF9O16=XI@=[L6/4LWMa17YnN0B3QGh4RXb4192B
RPBEUXh3VIZA19fLT`BOWI@4WijC1:2NT`BOW943WIZ?19ZGR`BGThL4THf218b7O0B6P7D4OgU_0gQb
J@A`JV84IV1I15UEC`A;B4<4?C/g0bl^:`@P8B044Q@C10H720@20P<42@T:110B50<G6ad47B@W12@/
<0@Z=3P4;c]013=1A`<hAdh4?4eD13mBF@A2Eel4AE]T14QPJ@A;I6hEoooo000Doooo14iWL@A?Ig04
CfI_151VK@A@IF/3D6=Y151QI`A?Gf@4CUaP14aHF`A9E5D3ATi>1456AP@oA484A4U714]@CPAAEU@4
EeaI0eeRGPASIf<4JFeX171cK@AfNG84O7ig1822N`>3QGd4QHIo18R8P@B9RX84RHZ118V9P0>7Qgh4
Q8Ak181oM`AlNW44MG9Y16aZHPAWIEh3HV1I15UGDPA=CDP4@d8o13Lg=@@Z:bX37AlN118D50@82@T4
0@0010@30`@=3a0451PJ0a/Q90@Q:B`49S0e12`g?0@`?T<4=DA:0cU9D0@lCUH4@5=K14=HH0A6G6D4
B61Y14]TKQGoool001Coool4CVMa14mWL0A?IVl4D6I]151UJ`=@HfT4D65W14mOI0A>G604C5QK14UD
E@=6CTh4@DI613m4@PA4BDL4Be1>155FE0AGG5T3GF9N16=WH`AYKFP4L7=]17IiLPAlOWL4P89k0h>5
O@B5QWl4R8R118V:PPB9RX44RHV00hN7OPB4Q7/4P7mg17ajL@AeLVT4K6YR16MUGP=RH5T4FEMB14e=
B0A3@Sl4=cLe12X[:P<M7ah44Q@D10P92@@1000410<310d?40@D61X36b4T124Y;0@V<3D4;3Ll130n
@`@eA4X3>DU@13a>EPA0De/4@eQP14ILI@A8H6T4BfA^5Oooo`005?ooo`A>Ig44CfM`14mVK`A@IVd4
D6E[0e1SJ@A@HFL4CemT14iLH0A<F5/4BEAE0dI>CPA1ATH4?dA214A9A`A;D4h4DEID15MLF@=MHUh4
HfMS16U]J0A`Lfd4MWUb17anM`B0PW/3PhEm18F6O`B8R844RHZ218V:P@B9RH03QhMn18B4N`B0OgL4
O7Ya17EbJ@A/JV84IfEN0f9PF@AIEe84CDe814=2?`@g=cD4:R/Z0adO7P@B51@420T9104000@40`<4
3@l@11@H6P<K8B@48BT/12H`=@@/=c`4<3i313E4BP<iBE04?4iF141CF`A3F604AUaU14QPJ@A;I6hE
oooo000Doooo14iWL@A?Ig04CfI_151VK@A@IF/3D6=Y151QI`A?Gf@4CUaP14aHF`A9E5D3ATi>1456
AP@oA484A4U714]@CPAAEU@4EeaI0eeRGPASIf<4JFeX171cK@AfNG84O7ig1822N`>3QGd4QHIo18R8
P@B9RX84RHZ118V9P0>7Qgh4Q8Ak181oM`AlNW44MG9Y16aZHPAWIEh3HV1I15UGDPA=CDP4@d8o13Lg
=@@Z:bX37AlN118D50@82@T40@0010@30`@=3a0451PJ0a/Q90@Q:B`49S0e12`g?0@`?T<4=DA:0cU9
D0@lCUH4@5=K14=HH0A6G6D4B61Y14]TKQGoool001Coool4CVMa14iWL0A?IVl4CfE]14mTJ`=?HfT4
CV5W14eNH`A<G604BUQK14QDEP=5CU04@DQ913a1@0@k?cd4?dE314I;B@A<DDl3DEEB15AIEPAIGUX4
GV=O16=WHPAWJfH4JfmY0fibK0AaM6h4LgI_17AgL0AcMW04LgE_0g5cK@A_LF/4K6iX16IXH`AQHeh4
FeiK15AGE0==Cd`4A4I413/m?0@c=C@4:2XZ11`O80<B51D41`T:100000@20@442``>118F60@I7b83
7bLZ12@^<P@Z=CX4;S]113=1A`@gAdd3>TaC13i@F0A1EEd4A5UQ14IMIPA9HFX4BfA^5Oooo`005?oo
o`A>Ig44CVM`14mVK`A?IFd4CfA[0dmSJ@A>HFL4CEiS14aLH0A:F5/4B5AF0dE>D0A1B4T4?45013/o
?@@oAD<4AT]914aAC`=AEE84E5UF15UNFPANHel4HfMR16M[IPA[KfT3KW9/175dKPAcMVl4M7M`17=f
L0AcMFl3LG=]16maJ`A/KVP4IVQS165SGPAKGU/4E5MD0de?C0A4AT@4>cdl13<e=0@X:RX471lP0a8D
5@@72@X4000010810@@;30h44QHH11TO8P<O9bX492hb12Xe>P@^>d44<d5713M7C@<jC5<4?U1H145E
G@A4FF44AUeV14UQJPA;I6hEoooo000Doooo14iWL@A>Ig04CfI_14mUK@A?I6/3Cf=Y14iQI`A=GV<4
C5aP14YHF`A8E5H3ADi@1458B@@l@D04>clm13m5@`A6BdT4C55?0e5EDPADFEH4FEiJ15iSG`ASIf84
If]V16]_J@=^LV`4LGA^17=fK`AdMg04LgI`17=eK`=aLfd4Kg5[16a^J0AVJ6<4HF=N15]NF`ADEe@3
CDm<14A6A0@k?C`4<cDd12PZ:P@L7b034Q@E10L92P@000040P4110/<3P@B5QP46AlR0alW:P@T;S84
:SDj12hk@@@c@DL4=dM=0cY<D`@nD5P4@EEM14AIH@A6GFH4BF5Z14]TKQGoool001Coool4CVMa14iW
L0A?IVl4CfE]14mTJ`=?HfT4CV5W14eNH`A<G604BUQK14QDEP=5CU04@DQ913a1@0@k?cd4?dE314I;
B@A<DDl3DEEB15AIEPAIGUX4GV=O16=WHPAWJfH4JfmY0fibK0AaM6h4LgI_17AgL0AcMW04LgE_0g5c
K@A_LF/4K6iX16IXH`AQHeh4FeiK15AGE0==Cd`4A4I413/m?0@c=C@4:2XZ11`O80<B51D41`T:1000
00@20@442``>118F60@I7b837bLZ12@^<P@Z=CX4;S]113=1A`@gAdd3>TaC13i@F0A1EEd4A5UQ14IM
IPA9HFX4BfA^5Oooo`005?ooo`A>Ig44CVM`14iVK`A>IFd4CVA[0diRJ@A=HFL4CEiT14]LH@A9F5`4
AeAH0dA@DPA1BT`4?DE513Tn?@@h?3/4>d0o1415@`=5BTP4B4i;14]@C0A?Ddl4DEMC15=HE@AEFUL3
F5eJ15]PG0AMHUh4GV=O15mTH0ANI5l3G69M15YPG0AHGEX4EU]I159HE`A>De<4Be1?0dA9B0@l@404
<cLg12L/;0@L82444QHG0`P<3@@10`<40P8310X<3P@A5QP461hQ11hV:P<S;C84:3@i12dj@0@a@4H4
=DE<13U:D@<lCUH4?e=K149GG`A4FV<4AeiW14UQJ`A;IFlEoooo000Doooo14iWL@A>Ig04CVI_14iU
K@A>I6/3CV9Y14eQI`A=GV@4BeaQ14UHG0A7E5P3A51B145:C0@mADD4>Chm13Pl>`@k@3l4@4E30dE:
B0A8CT/4Be1<14mCC`AAEe<4DeQE15EJE`=HGEX4Ff1L15eRGPANHel4GfAP15iTG`=LHUd4FV1L15QM
FPAFFeT4DUQG14iCD`A;D4l3A4U813a0@0@c=cL49b`/11`P8@@B5QL320`=10430`@20P<42P`>114F
60@H7R447RHZ0b<]<P@X=3T4;CY01350AP@eAD`4>DYA0ca>EP@oDe/4@UMO14AJH`A7GVL4BF5[14]U
KaGoool001Coool4CVMa14iWL0A>IVl4CVE]14iTJ`=>HVT4CF5W14eNI0A;G644BEQL14MDF0=4D584
@DY<13e5A@@i?Sd4>3`k13]0?`A0AD<3ADY814Q>B`A;D4`4Ce=?155GD`ACF5D4EEYG0eQMFPAKH5`4
GF9N15iSG`AOI604GVAO0eaRG@AJH5`4F5eJ15IKF@ABF5L4CU=C14]@C`=4BDP4?41013<g=`@W;2`4
720Q118F5`<830d40@<310820`@:30h44AHH11PN8@@N9RX38bdb12Pd>@@]>T04<D1613E5C0@iBU43
?4iF13mCF`A2Eel4A5YS14MNI`A9HF/4BfE_5Oooo`005?ooo`A>Ig44CVM`14iVK`A>IFd4CVA[0diR
J@A=HFL4CEiT14]LH@A9F5`4AeAH0dA@DPA1BT`4?DE513Tn?@@h?3/4>d0o1415@`=5BTP4B4i;14]@
C0A?Ddl4DEMC15=HE@AEFUL3F5eJ15]PG0AMHUh4GV=O15mTH0ANI5l3G69M15YPG0AHGEX4EU]I159H
E`A>De<4Be1?0dA9B0@l@404<cLg12L/;0@L82444QHG0`P<3@@10`<40P8310X<3P@A5QP461hQ11hV
:P<S;C84:3@i12dj@0@a@4H4=DE<13U:D@<lCUH4?e=K149GG`A4FV<4AeiW14UQJ`A;IFlEoooo000D
oooo14iWL@A>Ig04CVI_14iUK@A>I6`3CF9Z14eQJ0A<GfD4BeaR14UIGPA7EUX3AE9E149=D0@nB4T4
>T9213Dj>@@d>3H4=cdk0c]1?`@nA444@4E31457A0A3BDH4AD]81dM>B`A8Cd`4BU5>24]CD0A:DU03
BE5@14QAD0A6CTh4A4e=145:B`@nAdP4>T930c8j?0@Z<S@48RT[11PO8@@A5QP42@h@0`851P@41@H4
2`h@118H6P@I82<47bL[12@^<`<Y=CX4;CY01350AP@eAD/4>4U@13]>E@<nDUT4@EEM14=IH@A5G6D4
B5mX14YRK0A<IFlEoooo000Doooo14iWL@A>Ig04CVI_14iUK@A>I6`3CF9Z14eQJ0A<GfD4BeaR14UI
GPA7EUX3AE9E149=D0@nB4T4>T9213Dj>@@d>3H4=cdk0c]1?`@nA444@4E31457A0A3BDH4AD]81dM>
B`A8Cd`4BU5>24]CD0A:DU03BE5@14QAD0A6CTh4A4e=145:B`@nAdP4>T930c8j?0@Z<S@48RT[11PO
8@@A5QP42@h@0`851P@41@H42`h@118H6P@I82<47bL[12@^<`<Y=CX4;CY01350AP@eAD/4>4U@13]>
E@<nDUT4@EEM14=IH@A5G6D4B5mX14YRK0A<IFlEoooo000Doooo14iWL@A>Ig04CVI_14iUK@A>I6`3
CF9Z14eQJ0A<GfD4BeaR14UIGPA7EUX3AE9E149=D0@nB4T4>T9213Dj>@@d>3H4=cdk0c]1?`@nA444
@4E31457A0A3BDH4AD]81dM>B`A8Cd`4BU5>24]CD0A:DU03BE5@14QAD0A6CTh4A4e=145:B`@nAdP4
>T930c8j?0@Z<S@48RT[11PO8@@A5QP42@h@0`851P@41@H42`h@118H6P@I82<47bL[12@^<`<Y=CX4
;CY01350AP@eAD/4>4U@13]>E@<nDUT4@EEM14=IH@A5G6D4B5mX14YRK0A<IFlEoooo000Doooo14iW
L@A>Ig04CVI_14iUK@A>I6`3CF9Z14eQJ0A<GfD4BeaR14UIGPA7EUX3AE9E149=D0@nB4T4>T9213Dj
>@@d>3H4=cdk0c]1?`@nA444@4E31457A0A3BDH4AD]81dM>B`A8Cd`4BU5>24]CD0A:DU03BE5@14QA
D0A6CTh4A4e=145:B`@nAdP4>T930c8j?0@Z<S@48RT[11PO8@@A5QP42@h@0`851P@41@H42`h@118H
6P@I82<47bL[12@^<`<Y=CX4;CY01350AP@eAD/4>4U@13]>E@<nDUT4@EEM14=IH@A5G6D4B5mX14YR
K0A<IFlEoooo000Doooo14iWL@A>Ig04CVI_14iUKPA=I6`3CF=[14aQJ@A<H6H4BeiT14UKH@A7F5d3
AEAI14=@E0A0C4l4?4M913Q0@@@b>3P4;C8`0ble=0@e>cX4>D0n13U0?@@g?S/4=C`k13Hm?0<i@3l4
>d=113U2@@@g@D44>DA413a6A`<lAdP4>dI813Y6B0@jADP4=d9613E0@`@_>ch3:C@g128/;`@J8bH4
4Q/N10dD5`@730d32@`=110E5`@F72046b@X124[;`@V<CH4:SLm0bhl@P@b@DP4=DI=13Q:D@@kCUD4
?U9I0d1EG@A3F644AE]T14MNI`A8H6X4BV=]14aUL1Goool001Coool4CVMa14iWL0A>IVl4CVE^14eT
K0==Hf/4C65Y14aPIPA;GV@4BE]Q14MHG@=5E5T4@e1D141<C`@lAdT4>411138h>0@]<S03;cDd13Dk
>P@i@3h4>D0m13Ln>`@e?3/4=Sdl0cU0?`@k@d44>D9113M1@@@iA4@4?4I70ca7B0@kATP4>TI813Y5
B0@g@TH4=D1312lk?P<Y=3L48R`_11XS9P@B6ah43A@G10L<3@<930d441DG11HL80@K92P48B/_12Ha
=P@Z=cd3;Sa21391B0@eATd4>4YA13]>E@@nDUT3@5EM14=HH@A5Ff@4AeiW14QPJPA:Hfd4C6E`5Ooo
o`005?ooo`A>Ig44CVM`14iVK`A>IFh4CFA/0deSJ`A<HFT4C61V14]NI0A9Ff44AeQM0dEDF@A3D5@4
@4a?13a7B@@h@444<SPh12db<0<_=C@4=C/j13U0?P@i@3d4=chk13Dl>`@f?C`3>D0o13]3@@@i@T44
=d5113U4A0@lATL3?4M813]6B0@jATP4>TE813M2AP@e@4<4;c/n0bTd=`@R;2l46R<V118K7P@=51L4
1``=0`T<3@@@5AL45Q`P11/T:0@Q:bl49S4f12Xg?@<^?484<T5813E6C@@hBU44>diE13iBF@=0EEd4
@eQQ14EKI0A7GVL4B61Z14YSK@A<IG0Eoooo000Doooo14iWL@A>Ig04CVI_14iUKPA=I6`3CF=[14aQ
J@A<H6H4BeiT14UKH@A7F5d3AEAI14=@E0A0C4l4?4M913Q0@@@b>3P4;C8`0ble=0@e>cX4>D0n13U0
?@@g?S/4=C`k13Hm?0<i@3l4>d=113U2@@@g@D44>DA413a6A`<lAdP4>dI813Y6B0@jADP4=d9613E0
@`@_>ch3:C@g128/;`@J8bH44Q/N10dD5`@730d32@`=110E5`@F72046b@X124[;`@V<CH4:SLm0bhl
@P@b@DP4=DI=13Q:D@@kCUD4?U9I0d1EG@A3F644AE]T14MNI`A8H6X4BV=]14aUL1Goool001Coool4
CVMb14iWL@A>IW04CFE_14eUK@==I6`4C69Z14aQJ0A;GfH4BUeT14QKH@=6F5d4A5AI149AE@@oC504
>dM:13M1@`@b>S`3;C@d12`c<`@_=SH4<3Ph230i>0@`>ST3<3Xj12lj>`@`?3h4<d1213A1A0@d@DD3
=D9713I4B0@f@dT4<d15134n@`@^>d04:CDj0b<^<P@L9bX45b4T11<K7@@>4aD43Q<F0aHM80@K92P4
82/_12Da=P@Y=S`4;Ca21350A`<dAD/4=dU@13Y<E0@lD5L4?e=K145FGP=3F644AE]T14IMIPA8H6T4
BF9[14]TKPA<IW0Eoooo000Doooo14iWLPA>Ig44CVI`14eUK`A=IFd3CFA/14aRJPA<HFP4BemV14YM
I0A8Ff43AUQM14ADF@A2DED4?da@13]7BP@g@D<4<SXl0bdd=0@/<c<4;cHf130h>0P`>CP4<3Xi0c0j
>P@_>S/4<3`n13=0@P@d@D@4=4550cE2A`@fA4P4=T=913=0A@@a?T<4;S]012Te>P<S;S8472LZ11LQ
90@C6ad43Q<E10hC5P<F7B046b@X120[;`@U<CH4:CHl12dl@P@a@4L3=4E;13M9D0@jC5@4?51G13mC
F`A1EUh3@eQQ14EKI0A6GFH4B61Y14URJ`A;I6h4C6I`5Oooo`005?ooo`A>Ig84CVMa14iVL0A=IFl4
CFE]0deTK0A<HVX4C65X14]OIPA:GF@4B5]Q0dIHG@A4E5T4@U5E13m<D0@kAdX4=d53138j?0<]=3@4
;3<c12lf=P@`>3P8<3Th130j>@<`>SX4;cXk130l?P@c@484=45413A1A@<e@TL4=TA813I3B@@c@4D4
<Ci312hk@0@Y=CX38bhb11`W:P@G8B@44a/M10hC5@@>4aH35QdP11/T:0@P:bl49C4f12Tf?0@]?484
<D170cA5B`@gBE04>TaD13a@E`@oDe/4@EIN0d=HH@A5Ff@4AUeV14QPJ@A9HV/4BfA^14aVL1Goool0
01Coool4CVQb14iWL@A=Ig04CFI_14eUKP==I6d4CFA/14aRJ`A;HFT4BUmW14UNI@=8Ff84AUUO14AF
G0A2DUP4?dmC13a:CP@hADT3=41312hi?0@X<S@49c4c12/f>0@]>C/7:cPi12dk?@@_?T48<D13130o
A0<`?dD8;ci412hm@`@]>d44:cPm12Pc>0<T;S847RLZ11PO8P@E71l46B4U11hY;@<S;c@49cDj12/j
@0@_?TD4<T9913E6C@@hBU43>TeE13a@F0@nDe/4@5EN149HH0A4FV<3AEaU14MNI`A8H6T4BF9[14YS
K@A;IFl4C6Ia5Oooo`005?ooo`A>J784CVMa14eWL0A=IVl4CFE^0deTK@A=I6`4C69[14]QJ@A:GfL4
BEiU0dQKHPA6FEl4A5IL149BF0@oCe<4?4Y>13Q5B@<d@4<4;STl12Pb=0@W<C<4:cHh12di>`L[>3T4
;C/m12ln@@Pa@4<4<3m40c0oA@P_?T@4;Se312dk@@@[>3d4:3<h0b@^<P@N9bX461lR11DL7`@I8BD4
7RT]0b<_=0@W=CX4:cY012lnA@@b@TT4=DI=13Q:D@<jCED4?51H13iCF`A0EEh4@UQP14AJH`=5G6D4
AeiW14QPJ@A9HV/4BV=]14]UK`A<IW4Eoooo000Doooo14iXLPA>Ig44CFM`14eVK`A=IFh3CFA]14eT
K0A<HV/4Bf5Y14YOI`A9GVD3B5]R14IIG`A4EU`4@U9H13m?D`@lBTh4>4E90cA0@`@^>C`4:38d12La
<`@[=SP4;CTk1b/h>@@]>cd4;ci12350@`@`?d@3<3m522lnA0@^?D<4;C]112/h?@@X<cP392hb11hW
:P@H7b845A`O11TQ9@@N:Bd38bld12Le>P@[>T04;ci51392B@@eATd4>4YA0cY=E@@lD5P4?U=K141E
GPA2F604A5YS0dELI@A7GVL4B61Y14URJ`A:Hfd4BfE_14aVLAGoool001Coool4CVQb14iWL@A=Ig04
CFI_14eUKP==I6d4CFA/14aRJ`A;HFT4BUmW14UNI@=8Ff84AUUO14AFG0A2DUP4?dmC13a:CP@hADT3
=41312hi?0@X<S@49c4c12/f>0@]>C/7:cPi12dk?@@_?T48<D13130oA0<`?dD8;ci412hm@`@]>d44
:cPm12Pc>0<T;S847RLZ11PO8P@E71l46B4U11hY;@<S;c@49cDj12/j@0@_?TD4<T9913E6C@@hBU43
>TeE13a@F0@nDe/4@5EN149HH0A4FV<3AEaU14MNI`A8H6T4BF9[14YSK@A;IFl4C6Ia5Oooo`005?oo
o`Q>Ig44CFMa14eWL0A=IW03CFI_14eUKPA<I6d4C6=/14]RJ`A;HFT3BUmW14QNI@A7G6<4AUUP14AG
G@A1E5X4?e1F0ca=DP@iBDh4=TE:13=2A`@`?T@4;C]112hl@P<`?T<4;ci2130o@P@b@TD4=4A813E5
BP<dAD/4=4A;13=3BP@b@dT4<T99130oAP@Y=c`3930d12<^=0@V<cP4:CHl12/i@0@^?T@3<D9813A5
C0@fBE04>DaD13]?E`@mDET4?eAL0d1FGPA2F644@eYS14ELI@A6GFH4AemX0dQPJ@A9HF/4BV9/14]T
KPA;IFl4C6I`14eWLAGoool001Coool8CVMa14eWL@A=Ig04CFI`0deVK`A=IFh4C6A]14aSK0A;HV/4
Bf5Y0dYOI`A8GVD4AeaS14IIH0A4Eed4@EAJ13m@EP<lCE84>DU>13I5BP@c@TL4<3i412dk@@@^?483
<3i312ln@P@`?d84<T9513A4B0@eADX3=4E;13A4B`@c@dX4<T=91392B@@`?dH4:CLl0b@`=0@S;S@4
9S<h12Tf?0@[>D04;Si40c52B0@dAD`4=TU@13U<E0@kCeL4?E5I13mDG0=0EUh4@UQQ14=JH`A5G6D4
AUeV14MOJ0=8H6T4BF5[14YRK0A;I6h4BfE_14aVL0A=Ig4Eoooo000Doooo24iWL@A=Ig44CFM`14eV
L0==IVl4CFE^14aTK@A<Hf`4Bf9[14]QJ@=:GfL4B5iU14MLH`A6FF04A5MM145DFP@oD5H3?4eB13U9
CP@fADX4<d97130nA0@]>d44;Sa20c0n@`@_?T84<3m21392A@@dA4P4=DE:0cA5B`@dA4/4<d=:1393
B@@b@TT4<3m612Tg?0<T<3@48bhd12Hc>0@Y=S`4:cU012hnA0<a@TP4=4E<13I9D0@iC5@4>dmG13eA
F@@oE5`3@5IN149HH@A3FV<4AEaU14IMIPA7GfP3B61Y14UQJ`A:HV`4BfA^14]UK`A<IW04CFMa5Ooo
o`005?ooo`Q>Ig44CFMa14eWL0A=IW03CFI_14eUKPA<I6d4C6=/14]RJ`A;HFT3BUmW14QNI@A7G6<4
AUUP14AGG@A1E5X4?e1F0ca=DP@iBDh4=TE:13=2A`@`?T@4;C]112hl@P<`?T<4;ci2130o@P@b@TD4
=4A813E5BP<dAD/4=4A;13=3BP@b@dT4<T99130oAP@Y=c`3930d12<^=0@V<cP4:CHl12/i@0@^?T@3
<D9813A5C0@fBE04>DaD13]?E`@mDET4?eAL0d1FGPA2F644@eYS14ELI@A6GFH4AemX0dQPJ@A9HF/4
BV9/14]TKPA;IFl4C6I`14eWLAGoool001Coool4CVQb14iWLPm=Ig48CFI`14eUK`A<IFh4C6A^0daT
K@A;Hf`4BV9[14UQJ@A9GfP4AeiV14ILI0=5FV84@eQP149GGPA0EEd4?e=K2ciBFP@mDET4?E1H13Y>
EP@hBe@4>4]C0cM:DP@gBU44=TUA13I8D0@eAdh4=4E<13E7CP<hBe84>DaD13Y=E@@kCeL4?55I13iC
F`<oEEd4@EMO149HH@A3FV<4A5]T14EMIPA6GVL3AemX14QPJ@A8HFX4BF9[14YRK0A:Hfd3BfA^14]U
K`A<IFl8C6I`14eWL@A=Ig8Eoooo000Doooo14iXLPA>Ig8?CFMa24eVL0A=IFl4C6E^14aTKP=<I6d4
Bf=/14YRJ`A9HFT4BEmX14MNIPA6G6@3AEYR14=HH0A2Eeh4@5EM13mCF`/nDUX4?E5I13e@F0@jCUH4
>4]D13Q;D`<gBU84=dYA13I9D@@fB504=DM>13A5C0@eAdh3>4]B13U<E0@jCED4>dmG13aAF@@nDe/3
?eEM145GG`A2F644@eYS14AKI0A5GFH4AUiW0dMOJ0A8H6T4B65Z14URJ`A:HV`4BV=]0d]TKPA;IFl4
C6E_24aVL0A=Ig44CFMb5Oooo`005?ooo`A>J784CVMb3deWL@Q=IW04CFE_14aUKPA<I6h3C6A]14]S
K0A:HV/4BF5Y14UOJ0A7GVH4AUaT0dEJHPA3F604@UMN141EG@@oDe/;?U9J13eAF@@mD5P4>TiF13Q;
E0@hBe<3=dYB13M:D@@fBE44=TQ@13E7CP@dAD`4=DM>0cQ;DP@iC5@4>TeE13]?E`@lDET4?U=K0cmE
G@A1Eel4@UQQ14=JH`A4Ff@4AEeV14INI`=7GfP4B61Y14QQJPA9HV/4BV9/14YSK@=;I6h4BfE_14aU
K`Q<IW04CFMa14eWLQGoool001Coool4CVQb14iWLPm=Ig48CFI`14eUK`A<IFh4C6A^0daTK@A;Hf`4
BV9[14UQJ@A9GfP4AeiV14ILI0=5FV84@eQP149GGPA0EEd4?e=K2ciBFP@mDET4?E1H13Y>EP@hBe@4
>4]C0cM:DP@gBU44=TUA13I8D0@eAdh4=4E<13E7CP<hBe84>DaD13Y=E@@kCeL4?55I13iCF`<oEEd4
@EMO149HH@A3FV<4A5]T14EMIPA6GVL3AemX14QPJ@A8HFX4BF9[14YRK0A:Hfd3BfA^14]UK`A<IFl8
C6I`14eWL@A=Ig8Eoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00oooo
ob7oool00?oooolQoooo002Ioooo0`0008Coool009coool00`000?ooooooo`21oooo001loooo0P00
00?oool500000_ooo`800004oooo100000;oool300000oooo`<00003oooo0P0007koool007_oool0
10000?ooooooo`0000Coool01@000?ooooooooooo`000002oooo00@0003oooooool00002oooo00@0
003oooooool00005oooo00@0003oooooool00023oooo001moooo00<0003oooooool00oooo`030000
oooooooo00Coool010000?ooooooo`0000;oool00`000?ooooooo`0400000_ooo`040000oooooooo
0000Poooo`00O_ooo`030000oooooooo00;oool00`000?ooooooo`02oooo0P0000Coool300000ooo
o`800004oooo100008;oool007_oool010000?ooooooo`0000Coool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`030000oooooooo08goool007coool200001?ooo`800004oooo0`0000Coool2
0000Soooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(338) show
81.000 12.813 moveto
(deg) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
3D596C3D596C3E596D3E5A6D3E5A6D3E5A6E3F5A6E3F5B6E3F5B6F3F5B6F3F5C70405C70
405C70405D71405D71415E72415E72415E72415E73415F73415F73425F73425F73415F73
425F73425F74425F74425F74416074426074426074426074426075426174426074426074
426073415F73415F72415F72415F72415F72415E72415E71415E71405D70405C6F405C6E
405C6F405C6F405C6F405C6F405C6F405C6F3F5B6F3F5B6F3F5B6E3F5B6E3E5A6E3E5A6D
3E5A6D3E596C3D596C3D596C
3D596C3E5A6D3E5B6E3F5B6F3F5C6F405C70405D71415D72415E72415F73425F74426075
43617543617644627744637845647945647A45657A46657B46667B46667C46667C46667B
46667B46677C46677D46677C46677C46677C46687D47687E47697E47697E47697D47697D
47677B46677A46667A456679456579456579456579456478446376446275436173435F70
435F70436073436074436074436074425F73425F73415F72415E72415D71405D70405C6F
3F5B6F3E5A6E3E5A6D3D596C
3E596C3E5A6D3F5B6F405C70405D71415E72425F73426075436176446277446378456479
46657B46667C47677D48687E49697F496A814A6B824A6C834B6D844B6D844B6E854B6E84
4B6E854B6E854B6E854B6E844B6E844A6E844B6E844B6E834B6E834A6F834A6F83496E82
496C80486B7F486B7F496C80496C804A6C804A6B7F496A7E48697C48677B476678456375
456275466478466579466579456478456378446377446276436175426074425F73415E72
405D703F5C6F3E5A6E3E596D
3E596D3F5A6E405C6F415D71425E7342607443617644627745637946657A47667C48687E
4969804A6B814B6C834C6D854C6F864D70884E728A4F738B50748D50758E50758E50758D
50758D50758D50758D4F758D4F758C4F748B4E73894C72874C71854C70854B71854B7186
4B72864B71854B72854B72864C71864C71854D70854C6F844C6E824B6D814B6C7F4A6B7E
4A6A7E4A6A7E496A7E49697E48687D48677C47667B46657A456479446377436176426074
415E72405D713F5B6F3E5A6D
3E5A6D3F5B6F405C70425E7243607444627645637846657A47667C48687E4A6A804B6C82
4C6D854D6F874E71894F738B50758D517690537892547A94557C96557D97567D98557D97
557C97557C96547C95547C94547B93537A9152799052788E51778C51768B50758A4F758A
4F758A4F768B4F758B4E768B4F778C4F768B50768B50758B50758A4F73884E71864E7085
4E70854D70854D6F854C6E844C6D834B6C814A6A8048697E47677C46657A456478446276
426074415E72405C703E5A6D
3E5A6D405C70415E7242607444627645647947657B48677D4969804B6B824C6D854D6F87
4F728A50748C51768F537892547A94567D97577F9A59819D5A84A05B86A25C87A35B86A2
5A84A05A839E59839D59829C58829A588199578198578097567F96557D93557C92547C92
547C92547C93547C93547C93547C93547D94547D94557C92557B92547A9053778C52768B
52768D51768C51758C50748A4F72894E70874C6E844B6D824A6A8048687D47667B456479
436276425F73405D713F5A6E
3F5A6E405D70425F7343617645637847667B48687E4A6A804B6C834D6F864F718950738C
52768F537892557B95567D9858809B5A839F5C86A25D89A6608CAA6290AE6392B16190AE
5F8CA85E8AA55E89A45D89A35D88A25D88A15C88A15C87A05C879F5B879E5B879D5A869D
5A859D5A859D5A859C5A849C59849D59849D5A849D5A849C59829A588198587F96577E95
567E95567D94557B9353799152778F51758C4F72894D70864C6D834A6B8148687E46667B
446478436175415E713F5B6E
3F5B6E415D7142607444637746657A48687D4A6A804C6D844D6F874F728A51758D537790
557A94577D9758809B5A839E5C86A25E89A6608CAA6290AE6594B46A9BBC6A9BBB6594B3
6391AF6290AC628FAA628FAA628FAA628FA96190AA6190AA6191AA6191AA6191AA6191A9
6190A8618FA7608EA7608DA6608CA65F8CA55F8BA55E8BA45E89A35D88A25C87A15C86A0
5B859F5A849D59819B577F98567C95547A9252778E50748B4E71874C6E844A6A8048677C
466479436175415E723F5B6F
3F5B6F415E7243617645647947677C4969804C6C834E6F8750728A52758E547891567B95
587E995A819C5C84A05E88A4608BA9628FAD6492B16696B6699BBC6B9EBF6A9CBC6797B6
6696B46695B26695B26695B16696B26696B16696B06798B16799B3679BB4679DB5689DB6
689BB46799B26797B16796AF6694AE6593AE6492AD6492AD6392AD6392AE6392AE6190AC
608EA95F8BA65D88A35B859F59829B577E97557B9353778F50748B4E70874C6D8349697F
47667B446277425F733F5C6F
3F5B6F425E7344627646657A49687E4B6B824D6E864F728952758D547891567B95587F99
5B829D5D86A25F89A6618DAB6490AF6694B46898B96A9CBD6C9FC36799BD6495B66899B9
699AB96A9BB96A9CBA6B9CB96B9CB96B9DB96B9EB96C9FB96CA1BB6DA2BC6DA3BD6DA3BD
6DA3BC6EA2BB6DA0BA6C9EB96C9CB76B9BB6699AB56899B56799B5679AB7689CBA679BB9
6597B46393B0618FAB5F8BA65D87A25B839D587F98567B9453778F50738A4D6F864B6B81
48687D456478426074405C70
3F5C6F425F7345637847667C4A697F4C6D844F718851748C547891567B95597F995B839E
5E86A2608AA7638EAC6592B06796B56A9ABA6C9EC06FA4C76A9EC16496B76899BB6A9CBD
6C9EBE6EA0C06FA1C16FA2C170A2C070A3C070A4C070A5C071A7C171AAC372ABC472ABC4
72ABC372AAC372A7C172A6C071A3BE70A1BD6FA0BC6D9FBC6C9FBD6CA1C06DA4C56DA4C5
6A9FBF689BB96696B46391AE618DA85E88A35B849D587F98557B9352768E4F72894C6E84
49697F46657A436175405C70
405C7043607445637848677D4B6B814E6F8651738B53778F567A94597E985B829D5E86A2
618AA7638EAC6692B16997B66B9BBC6E9FC170A3C66B9FC2689BBD6A9DBF6C9EC06EA0C1
70A2C372A5C673A7C874A8C875A9C775A9C775AAC675AAC575A8C375A7C276A7C276A6C2
76A8C277ABC577ACC678ABC577A8C475A6C274A5C272A4C171A3C170A4C370A7C771AACD
70A9CB6DA2C36A9DBC6898B56593AF628DA95F88A25B839C587E9755799151748B4E6F85
4A6A8047667B446176405D70
405C7043607546647949687E4C6D834F718852758D557992587D975B819C5E86A1618AA6
648EAB6693B16997B66C9CBC6FA0C272A5C876AACF75A9CE6FA3C76FA2C570A2C572A4C5
74A6C876A9CB79ADCD7AAECD7AAECC7BAECC7BADCB7AABC879A5C279A1BD789EBA789DB9
7AA2BE7CA8C37CABC77CADC87BACC87AAAC778A9C777A8C675A7C574A7C774A9CA74ACCE
74ADCF72AACB6FA4C46C9EBC6998B56692AE628CA75E87A15A819A577C9453768E4F7188
4C6C8248677C446276415D71
405D7044617547657B4A6A804E6F8551738B547790577C955A809A5D849F6089A5638DAA
6692B06A97B66D9CBC70A0C273A5C877ABCF74A9CD71A5C972A5C873A6C874A6C776A7C8
78AACB7AADCE7DB1D17FB3D27FB3D181B3D180ABC97BA1BE799CB87697B17799B3799EBA
7C9DBA7E9EBA81A5C182ADC981B0CC7FAECB7CADC97AABC878A9C777A9C977ABCC78AED0
78B2D578B1D475ABCC71A4C36E9EBB6997B46591AC618AA55D849E597E9755799051738A
4D6D8349687D456377415D71
415D7144627648677C4B6B814F6F8652748C567992597E975C839D6087A3638CA86691AE
6996B46D9BBA70A0C174A5C777AACD7AAED279ACD075A7CA75A7CA76A7C977A8CA79A9CA
7AAACB7DADCE7FB0D083B4D483AFCE7B9FBC799BB77A9AB57A98B37A9AB67A99B57997B3
7898B27A9BB67EA1BD84A9C586B0CC83B1CD81AFCC7EAECB7CACCA7BACCB7AADCE7BB0D1
7BB2D47CB3D47BB1D177ABCB72A4C26D9CB96995B0648EA85F87A15B8199577B9252758C
4E6F854A697E456378415E72
415D7145627749677C4C6C8250718854768E587B945B809A5F85A0628AA6658FAC6994B2
6C99B8709EBF74A4C678ABCE7CB0D47BB0D37AADD078A9CC78A8CB79A8C97AA8C97BA9C9
7DAACA7FAACA7FA9C97FA7C77EA7C67DA6C47EA4C37EA3C27EA3C17EA4C37FA4C27FA5C2
7EA5C37CA3C1799FBC7BA1BD82A9C487B3CE85B4D082B1CE80AFCD7EAECD7EAFCF7EB2D2
7EB4D67FB6D97FB5D87DB2D277A9C771A0BD6C98B46791AC628AA45D839C587D9554768D
4F70864A6A7F466479415E72
415D7145637749687E4E6D8452738A5678915A7E975D839D6188A3658DA96892AF6B97B5
6F9CBB72A1C276A8CA7EB2D683B9E07CB0D576A8CB79A9CB7BAACB7CABCB7DAACA7EA9C9
7EA8C77DA4C27B9DBA7795B27997B57D9FBC80A2C081A6C482A9C783AAC883AAC983ADCC
83ADCC82ABC980A8C67EA8C57EA8C484AFCB88B5D185B3D083B2CF82B1D081B2D282B3D4
82B5D681B7D980B6D87EB2D37AACCB75A4C16F9BB86994AF648CA65F859E5A7E9655788F
5071884B6B80466579425E72
415E724663784A697F4F6F8553758C577B935C80996085A0648BA66790AD6B95B36E9AB9
719FBF73A3C476A8CB79ADD07AADD178A8CB77A6C87BA9CA7DABCA7FABC980AAC881AAC8
81A8C581A7C481A4C17F9FBB809DBA819EBB829FBC83A0BD83A1BF84A2C184A3C184A2C1
84A3C384A7C683A9C781A9C780A9C780AAC785AFCC88B4D086B3D085B3D184B3D284B5D4
84B7D785B9DA88BEE186BADC7DAECE78A6C4719EBA6C96B1668EA86187A05C8098567990
5172894C6C8147657A425F72
425E724764794B6A8050708755768E597C945E829B6288A2668EA96A93B06E99B6719EBD
74A2C275A5C774A6C86D9FC2689ABD72A1C47BA8CA7FAACB81AACA82ABC983ABC884A9C6
84A7C484A7C385A8C586A7C586A5C286A4C187A5C287A5C288A6C388A7C489A7C589A8C6
89A8C689A9C789A8C787A5C484A3C181A1BE82A4C086ABC888B1CF87B3D087B4D287B5D4
87B6D687B8D886B8D887B8D881B1D07AA8C574A0BC6E98B36890AA6389A25D8199587A91
52738A4D6C8248667A425F73
425E7247657A4C6B8151728856788F5B7E9760859E658BA56991AD6D97B4719CBA75A2C1
77A6C779A9CB78AACF76A9CD77A7C97BA9CA80ADCD83AECD85ADCB87ACC988ABC788ABC6
88A9C588A9C58AACC88BAECB8BACC98BAAC78CAAC78CAAC78CA9C78DAAC78EACCA8EADCB
8EADCB8EADCB8DACCA8CABC989AAC788A8C687A9C788ACC889B0CB8AB3CF89B5D289B6D3
88B7D588B8D788B9D988B8D682B1CF7CAAC776A2BE709AB56A92AC648AA35E839B597B92
53748A4E6D8348667B425F73
425F7348667A4D6C8253738A587A915D80996387A1688EA86C94B0719BB875A1BF79A6C6
7CABCC7EB0D280B2D581B3D683B4D785B4D587B3D188B2D08AB1CE8BB0CC8CAFCB8DAECA
8DADC88DADC88DADC98FB0CD90B1CE90B0CD90B0CC91B0CC91AFCC91AFCB92AFCB92B1CD
92B2CD91B1CC90B0CB8FADC98DACC78BABC78BACC78BAEC98CB1CC8CB4CF8CB5D18AB5D2
89B6D388B6D487B7D68ABADA86B5D57FACCA78A3C0729BB66C93AD668BA460849C5A7C93
54758B4E6E8349677B435F73
435F7349667B4E6D8354748B5A7C9360839B658AA36B91AB7098B4759FBC7AA5C37EACCB
82B1D284B7D987BADD89BBDD8BBBDC8BB9DA8CB8D78EB7D58FB6D391B5D291B4D092B3CF
92B1CD92B0CC93B1CD94B3D095B5D195B4D095B2CE95B2CD95B2CD95B2CC95B2CD96B2CD
95B2CD95B2CD94B2CC93B1CB91AFC88FADC68EACC58EAEC78FB2CC8FB4CE8EB4D08CB5D1
8AB5D287B4D284B3D288B9D989B9D881AFCC7AA5C1739CB76D94AE678CA561859C5B7D94
55768C4F6E8449677B436073
43607349677C4F6E8456768C5C7D9562859D688CA66E94AF749BB779A3C07FAAC883B1D1
88B8D98CBEDF8FC2E492C3E592C0E191BDDC92BCDA94BBD995BBD896BAD697BAD598B9D5
98B8D398B6D198B5D099B6D19AB7D39AB8D49AB7D399B7D29AB6D19AB6D19AB7D29BB7D1
9AB6D099B5CF98B3CD97B3CD96B2CB94B0C893B0C893B1CA93B3CC92B4CE91B6D08FB6D1
8CB5D087B2CE7EACCB7CADCC84B4D384B1CE7BA5C0759DB76F95AE698DA663869D5C7E95
56768C506F844A677C436073
4360744A687C516F8557778E5E7F976487A06B8FA97197B2789FBB7EA7C484AFCD8AB7D7
8FC0E194C8E998CCED99CAE999C5E39AC1E099C0DE9AC0DD9BC0DD9CC0DD9DC0DC9DC0DB
9EBFDA9EBED89EBCD69DBAD49EBAD49EBBD59EBCD69EBCD69EBCD69EBCD69FBCD69FBBD5
9FBBD49FBAD39EB8D19DB7CE9BB4CC9AB4CC99B5CD98B6CE98B8D097B9D295B9D292B8D2
8FB7D28AB4CF84AFCB7DA9C578A3BF79A3BE7AA3BE769DB77096AF6A8EA664879E5E7F95
57778D516F844A687C436074
4460744B687D52708659798F6081986789A26E92AB759AB57CA3BE83ACC88AB4D290BDDC
96C5E59BCBEB9ECCEB9FCBE99EC8E69EC6E39FC5E1A0C4E0A0C5E1A2C6E2A3C6E2A4C6E2
A4C6E1A4C5DFA4C3DDA3C2DBA3C0D9A3BFD7A2BDD6A2BDD6A2BDD6A2BDD6A3BED6A3BED6
A3BED6A3BDD4A2BAD1A0B8CF9FB7CE9FB9D09FBAD19EBBD29DBCD39CBCD49ABCD497BCD4
94BAD390B8D18BB5CF87B1CC83ADC880A9C47DA5BF789FB87297B06C90A766889E5F8096
58788D5170854B687C446074
4460744B697E5371875A7A9061839A698BA47194AD789DB880A7C288B0CC8FBAD797C4E3
9FCBECA4CEEEA7CFEEA7CEECA6CCE9A5CAE7A5CAE5A5C9E5A6CAE6A7CBE7A9CDE8AACDE9
ABCDE7ABCDE6ABCBE4AAC9E1A9C6DFA8C4DDA7C2DBA6C1D9A6C0D7A6C0D8A6C0D8A6C0D7
A6BFD6A6BED4A6BDD3A5BDD3A6BED4A5BFD5A5C0D6A5C0D7A3C0D7A1C0D79FBFD79DBED7
9ABDD697BBD592B9D28EB7D18CB6D188B2CC81A9C27BA1B97599B16E91A867899F608196
59788E5270854B687C446074
4461754C697E5472885B7B9163849B6B8DA57397B07CA0BA84AAC58CB4D095BEDB9FCAE8
A9D4F4B1D9F8B4D9F5B1D4F0ADD1ECABCFEAAACEE9AACEE9ABCEEAACCFEBAED0EBB0D2EC
B2D3ECB2D2EBB1D0E8B0CDE6AECBE4ADC8E0ABC6DDAAC3DBA9C1D9A9C1D8A9C1D8AAC2D8
AAC2D8AAC2D8AAC2D7ABC3D8ACC4D9ADC5DBACC5DBABC4DAA9C4DAA8C2D9A6C1D8A3C1D8
A0C1D89DC0D89AC0D996BED892BCD78CB7D286ACC57FA3BB789BB27192A9698AA0628197
5B798E5371854C697C446074
4561754D6A7E5473885D7C9265859C6D8FA77699B27FA3BD88AEC891B8D39AC2DEA3CCE9
AFD7F3B7DCF7BADCF6B9DAF3B3D5EEB1D2ECAFD0EBAFD0EBB0D0EBB1D2EBB4D4ECB6D5ED
B8D6EEB9D8EFB9D8EFB7D5EDB4D1E9B1CDE4AFC8DFADC5DCACC4DAACC3D9ADC4DAADC4DA
AEC5DBB0C6DBB0C7DBB2C8DDB4CADFB4CBDFB3CBE0B2CBE0B0C9DEAEC7DDABC6DCA9C5DB
A6C4DBA4C4DCA2C3DB9FC3DC99C0D892B8D18AAFC682A5BC7B9CB27393A96B8BA0638297
5C7A8E5471854C697D456074
4561754D6A7F5573885E7D9366879D6F91A8799BB383A6BF8CB1CB96BCD69FC6E1A7CDE7
ADD2EBB6D8F1BBDBF4BBDAF2B7D6EFB5D4EDB3D2EBB2D1EAB3D2EBB6D5EEBAD9F2BEDCF5
C1DEF6C1DDF4BEDBF2BCD9F0B9D6ECB5D0E6B1CAE0AFC6DBAEC4D9AEC3D8AFC3DAB0C5DB
B2C7DCB4C9DDB7CBDFB9CDE1BACFE3BACFE4BACFE3B8CEE3B5CCE1B2CBDFB1C9DEAEC8DD
ACC7DDAAC7DDA8C8DDA6C8DEA0C3DA97BBD28EB0C786A7BD7E9EB37595AA6D8CA0658397
5D7A8E5572854D697D456174
4561754D6A7F5674895E7D9367879D7192A97B9DB586A9C191B5CE9BC0DBA5CBE6ACD1EC
B5D7F0BDDCF3BFDCF3BEDAF1B9D6EDB7D4EBB5D2E9B3D0E7B3CFE5B4D0E6B7D2E9BCD6EB
C2DAEFC4DBF2C2DAF0BED8EEBCD7ECB7D1E7B3C9DEB0C5D9AFC2D7AFC2D6B0C3D7B2C5D9
B5C8DDB7CBDFB9CDE0BBCFE2BED2E5C0D5E7C0D5E7BED3E6BAD0E4B7CEE2B6CDE1B4CBE0
B2CADEB0C9DEADC8DCA9C6DAA3C2D69BBBD092B2C689A8BD809FB37896AA6F8DA1678497
5E7B8E5672854D697D456174
4561754D6A7F5674885F7D9368879D7292A97D9EB589ABC395B9D2A2C7E0ABD0EAB1D4EE
B3D4ECB8D6ECBCD8EEBDD8EEBAD5EAB8D2E8B6D1E6B5CFE4B3CCE0B0C9DDAEC6DAAEC6DB
B2CADEB6CCE0B9CCE0B7CADDB3C5D9B2C4D8B1C4D7B0C2D5B0C1D3B0C1D3B1C3D5B3C6D8
B7CBDDBBCFE1BED1E3C3D5E7C7D9EBC7D9EBC5D7E9C3D6E8C0D4E7BCD1E4B9CFE2B7CEE0
B6CDDFB5CDDFB4CBDEB0C7DAA8C1D39FBBCD96B2C68DA9BD83A0B47A97AA718DA1688497
5F7B8E5672854E697D456174
4562754D6A7E5673885F7D9268869C7291A87D9EB58AACC49ABDD6ADD3EDB9DEF7B9D9F1
B8D5ECB9D5EABDD6EABED7EBBBD4E8B9D1E5B7D0E3B6CEE2B4CBDEB0C5D8ADC2D4A8BDD0
A3B8CBA4B7CAA8BBCEABBCCFAEBED0B0C1D2B0C2D3B0C1D3B0C1D2AFC0D1AFC0D1B0C1D2
B1C1D1B5C4D5BCCBDAC4D3E2C7D7E6C7D7E7C8D9E9C7D9EAC3D7E8BFD3E5BBD0E1BACEDF
BACEE0BACFE0BACEDFB7CCDDAFC5D7A5BED09AB5C790ABBE86A1B47C97AA738EA1698497
607B8E5772854E697C466174
4561744D697D5572865E7B8F67859A718FA57C9BB28AAAC19DBFD8ACCEE7B9D8EFC2DFF4
C1DBF0BED7EBBCD4E8BCD4E7BBD2E5B9D0E2B7CFE0B7CEDFB5CADCB2C5D6AFC0D0ABBCCB
A9BAC9A8B8C7A9B7C6ABB9C8AEBBCBAFBDCDB0BFCFB0C0D0B0BFCFAFBECDAFBDCCAFBDCD
AEBDCDAEBECFAEBFD0B0C2D2B7C7D7BACCDBBBCDDCBCCEDDBBCDDDBACCDCBACDDCBBCEDE
BCCEDEBED1E0BED1E0BACDDDB4CADBAAC3D59FB7C993ADBE89A2B47E98AA748EA06A8497
617B8E5872854F697C466174
455F734C687B5470845D798D6582976F8CA17997AC85A3B991AFC69FBCD3AAC5DBB5CDE2
BAD1E6B9D1E5B9D0E3BBD2E4BAD0E2B8CDDFB6C8D9B4C5D5B5C7D7B5C8D8B4C4D4B2C0CF
B1BDCAB0BBC8AFBBC8B0BCC9B1BCC9B0BBC9B0BDCCB0BFCEB0BECEAFBDCCAFBDCAAFBECB
B0BECCB0BECDAEBDCCA7B7C7A5B6C6AABBCBADBFCFB0C2D1B5C5D4B9C9D7BBCBD9BBCCDA
BECEDCBFCFDEBFCFDEBBCCDBB5C9D8ADC4D4A2B9CA96AEBF8BA3B48098AA758EA06B8496
617B8D5872844F697C466173
445F734C677A536F825B778B637F936C889C7591A67E9AAF87A3B995B0C5A2BACFABC2D5
AFC6DAB4C9DCB8CBDDBBCEDFBBCEDFB8CBDBB6C7D6B2C2D0AFBCC9ADB9C6ACB8C3A9B3BE
A5AEB8A4ACB6A6ADB7A8AFB9ABB3BEAEB8C3B0BBC8B1BECBB1BECBB0BCC9AFBBC7B0BDC8
B3C1CBB4C2CDB2C0CDAFBECCADBCCAACBAC8AEBCC9B2C0CDB7C4D0BAC8D3BCCBD6BECDD9
C0CFDCC1D0DCC0CEDBBAC9D6B5C6D4B1C5D4A6BCCB99AFBF8DA3B38198A9768D9E6B8495
617A8C5871834F697B466073
445F724B6679526D80597488617C8F688397708B9F7892A67F99AC8AA3B695ADC09FB6C8
A8BDCFAEC3D4B4C7D8BACCDCBBCDDDB9CBDAB7C7D6B4C2CFB1BCC8ADB5C0A8AEB8A5AAB3
A4A7AFA3A5ADA4A6ADA8AAB2ACB2BCB0B8C3B2BCC8B3BDCBB3BDCAB0BBC8ADB7C3AAB4BE
ACB6BFB2BDC6B7C3CDB7C4CEB5C2CDB4C1CCB4C1CDB7C3CFB9C6D1BBC9D4BCCAD5BDCCD6
C0CFD9C1CFDABECBD6BDCBD6BBCAD7B8CBD9ADC2D19BB0BF8DA2B28197A7768C9D6B8293
61798B5871824F687A466073
435E714A6477506A7D5771845E788B657E916C8598728B9E7990A38298AA8CA1B395ABBD
9EB3C4A7BBCBB0C2D2B7C9D8BACCDABACBD9B8C8D6B6C4D1B4C0CCB1BAC5AFB5BFADB2BA
ACB0B8ACAFB7ADB0B8AFB3BBB1B7C0B3BCC6B5BFCAB5C0CCB5C0CCB3BEC9B0BAC5ACB6C0
A8B1BBA5B0B9A8B3BCB0BBC4B7C2CCBAC6CFBBC6CFBBC7D0BCC7D1BBC7D0BBC7D1BEC9D3
BFCBD4BFCAD4BEC9D3C0CBD4BEC9D3B4C2CFA9BAC79AADBB8DA0AF8095A4758A9A6A8191
6178895770814E687A466072
435E704963764F697B556E815B7486617A8C677F916D849672899B7990A18399A98EA2B3
97ABBBA1B4C3ACBECCB6C7D5BCCCDABCCCDABBCAD8B9C7D5B7C4D0B6C1CCB4BEC8B3BBC4
B3B9C1B3B8C1B4BAC2B5BCC4B7BEC7B8C1CAB9C3CDB9C4CEB9C3CEB7C2CCB4BFCAB1BCC6
AEB8C2ABB4BEA8B2BCA6B1BAA8B2BCACB7C0B0BBC4B2BDC6B4BEC6B8C2CABCC5CEBEC7CF
BDC6CFBBC5CDBBC3CCBBC1CBB8BFC8B0BAC5A6B4C098A9B68B9DAA7E91A0738797697E8E
5F7686566E7F4E6778455F72
425D704862744D6679526B7D5870825D7587637A8B687E906D8394758B9C7D92A2879AAA
92A5B49DAFBEA9BAC8B5C5D2BCCCD9BECDDABDCCD9BCCAD6BBC8D4BAC6D0B9C4CEB9C3CD
B9C2CBBAC1CABBC2CBBCC4CCBDC6CFBEC7D1BEC9D2BEC9D3BDC9D2BCC7D0BAC5CEB7C2CC
B4BFC8B1BCC5AEB9C1ACB6BEAAB4BDAAB4BCACB5BDB0B9C0B4BDC4B8C0C8BBC3CBBDC5CD
BBC3CBB8BFC7B4BCC3B1B8C0AFB6BFAAB4BEA3B1BC96A6B28798A57B8D9B708492677B8B
5E7484556C7D4D6677455F71
425C6F4660734B647650687A556C7E5A71825E7585637989687D8D708392788A998193A1
8C9DAA9AA9B6A6B5C1B2C1CCBBCAD6BFCEDBBFCEDABECDD9BECCD7BECBD6BECAD4BFC9D3
BFC9D3C0CAD3C1CAD4C2CBD4C3CCD5C4CED7C4CFD8C4CFD8C3CED7C2CDD6C0CBD3BDC8D0
BBC5CDB8C1CAB5BFC6B3BCC3B2BAC1B2BAC1B3BBC1B5BCC3B8BEC5BBC0C7BDC2C8BDC2C8
BABFC5B4B9BFB0B5BBABB1B8A7ADB5A2AAB29AA5AF8F9CA882909C7787946D7F8D647886
5C7180546A7B4C6476445E70
415B6E455F714962744E657752697A566C7C5A707F5E73826276846A7D8B7283917B8B98
8595A191A1AC9FADB8ABB8C2B7C3CDBECCD6C0CFDAC1CFDBC1D0DBC2D0DCC3D0DBC4CFD9
C5D0D9C6D0DAC7D1DAC8D2DBC9D3DCCAD4DDCAD5DDCAD5DDC9D4DCC8D2DAC6D0D8C4CED5
C1CBD2BEC7CEBCC4CBBAC2C9B8C0C6B8BFC5B8BFC4B9BFC5B9BFC5BAC0C6BBC0C6B9BEC3
B3B7BCADB2B7A8ADB2A2A7AC9BA0A7949BA28E959E848E987A879271808C697A87617382
596E7D5268784B6374445D70
405B6D445D6F4860714B62734F6575526877566B7A5A6D7C5E707D6576836D7D89758490
808E998D9AA59AA6B0A6B2BCB1BDC8BAC8D2C1CFD9C3D1DCC5D2DDC6D4DFC8D5E0C9D6E1
CBD6E0CCD7E0CDD8E1CFD9E2D0DAE3D0DBE3D0DBE3D0DAE2D0DAE1CED8DFCCD6DDCAD3DA
C7D0D6C4CDD2C2CACFC0C7CDBFC5CABDC3C8BDC2C7BCC1C6BCC1C5BDC0C5BABEC2B4B8BC
AEB1B5A7A9AE9FA2A7979BA08F939A878D937D838A767D85717C866B78846474805D6F7D
566A79506676496172435D6F
405A6C435C6E465E6F495F704C61714F6372526574556876596B7860717D687783707F8A
7B889286929B939EA6A2ABB4AFB8C0B9C4CCC1CDD5C5D2DBC8D5DFCAD7E1CCD9E4CEDBE6
D0DDE7D2DEE8D4E0E9D5E1EAD7E2EBD7E2EBD7E2EAD6E1E8D5DFE6D4DDE4D2DAE1D0D7DD
CDD4D9CBD1D6C8CED3C6CBCFC4C8CCC2C6CAC0C4C7C0C2C5BFC0C3BBBDC1B6B8BBB0B1B4
A7A8AB9E9FA395979C8D8F9485888D7D8187767C826F767E6A747D64717C5F6E7A596B78
5367764E6373486070425C6E
3F596C425A6C445B6C465C6C485D6D4B5E6D4D5F6D4F606D52626F5A697562707B6A7781
737F887F8A938D979F9CA5ACABB3BAB9C1C7C3CDD4C8D4DCCBD7E0CEDBE5D1DEE8D4E1EC
D6E4EFD8E6F1DAE7F1DCE9F2DEE9F2DEE9F1DFE9EFDEE8EEDDE6ECDBE3E8D8DFE5D6DCE0
D3D8DDD0D5D9CCD1D5CACED1C8CBCEC6C9CBC4C6C8C3C3C5C0C0C2BCBCBDB5B4B5ABAAAC
A1A0A39697998D8E918486897B7D817174786B7075676E75636C755F6B755A6974556673
5064724C6170475E6F425B6D
3F596B40596A42596A445969455A68475A674859664A59654B5A6552606A5B6771647078
6F79827B858C889198979EA4A7AEB3B7BEC3C3CBD1CAD4DBCFD9E1D2DEE7D6E3ECD9E6F0
DCEAF4DFECF6E1EDF6E3EEF6E4EFF5E5F0F6E6F0F5E5EEF3E4EBEFE2E8EBDFE4E8DCE1E4
D8DDE0D5D9DCD1D5D7CED0D3CBCDCEC9C9CBC7C6C8C4C3C4C0BEBFB9B7B7AFACADA4A1A2
9896978D8C8E83838578797C6D6F726263665E60645E646B5C656D59656E55646F52626F
4E606F495E6E455C6D415A6C
3E586A3F586940576741576642566443556243546044535E44515B4A565E545E665D676F
677178737C8282898E91979CA1A7ABB2B7BAC1C5CACCD3D9D2DCE2D7E1E8DBE6EEDFEAF2
E2EEF6E6F1F8E9F3FAEAF4FAECF5FAEDF6FAEEF5F9EDF3F6EBF0F4E9EDF0E5E9ECE2E5E7
DEE0E2DADCDDD6D7D8D3D2D3CFCECFCBC9CAC7C5C4C2BFBFBCB8B7B3AEAEA8A4A39C9897
8F8D8C8482827978796E6E706565685F60645A5D62585E64565F67545F69515F6A4E5E6B
4B5D6B475C6C445B6C405A6B
3E57693E56673F55653F54633F52603F515D3F4E5A3E4C563E4A53434D554B545B565E64
61686D6C73787A8085888E92979CA0A8ACAFBABEC1CACED1D4DBDEDAE4E9DFEAEFE4EFF4
E9F3F8ECF6FAEFF8FCF2FAFEF4FAFEF5FAFDF6FAFCF4F8F9F2F5F6EFF1F2EBEDEEE7E8E8
E3E3E3DFDEDEDAD9D9D6D4D3D2CECDCDC9C7C6C3C1BEBAB8B5B0AEAAA4A29D9896918C8B
8682817A77766E6B6C62606258585A55565953565A52575D5059614F5A634D5B664B5B67
485B68455A69435A6A40596B
3D57693D55663D53633D51603C4F5D3C4D593B495439454F364047384147424A504D5459
575D6262686D6F75797E83868D91939DA0A1AEB0B1C1C3C3D0D4D5DBE1E3E2EAEDE8F0F3
EEF6F9F3FAFCF6FDFFF8FEFFFAFFFFFDFFFFFEFEFEFCFCFCF8F8F8F5F3F2F1EFEEECEAE9
E7E4E3E2DEDEDDD9D7D7D2D0D1CCC9CAC4C1C2BCB9B7B1AEABA4A19E9895918B89847F7D
7873726C6867605C5D5653544C48484846484B4D514B51574B535B4A555F495762475864
4658664458684158693F586A
3D56683C54653C52623B4F5E3A4C5A394955374550344049313A4131383E3A4045444A4F
4F54585A5E62676A6D74777A8184878F92939FA1A1B0B2B2C1C3C3D0D2D2DEE1E1E8ECEC
F1F4F5F7FBFBFAFEFEFDFFFEFFFFFEFFFEFCFFFCFAFFFAF8FDF8F5F9F4F1F4EEEBF0E9E6
EBE4E1E6DEDADED7D3D7CFCACFC7C2C5BDB8BAB1ADADA4A09F9793918A86837D7A76706E
6964625D5857514D4D49454545424243424444474B464B51464F5646515B46535E455561
4356644257664057683F586A
3C56683B53643A5060394D5C384A5736465234424C313D462E373E2B32362F3438393E42
44484B4E52555A5D60686A6C757778838485919393A0A2A2B0B1B1C0C1C0CFCFCEDBDCDB
E4E7E5EDEEECF3F4F1F7F7F3F9F6F2FAF5F0FAF4EEFAF3EDFAF1EBF8EEE8F4EAE3F0E4DF
E9DED8E2D7D1DBD0CAD2C7C1C7BCB7BBB0ABAEA39E9F9591908884817A77736D6A65605D
5853514B4746413D3C3A35353936363C3C3E3F424641474D424B52424E5742505B42525F
4154624055653F56673E5769
3C55673B5263394F5F384C5A364855344450313F4A2E3A432B333B262C31262B2F2F3337
393D4043474A4D5052595B5D686A6B767879858787959696A3A5A4B1B3B2BDBFBEC9CAC8
D3D2D0DCDAD6E3E0DCE9E5E0EBE6E0ECE6E0EFE6DFF0E5DEF0E4DCEFE2DAECDFD7E7D9D1
E1D3CBDACCC4D1C4BCC7BAB3BBAEA8ADA19B9F948F908681807873716A66635C59554F4C
46413F3A3634322D2B2D2726302C2C3636393A3D423C43493E474F3F4B55404E5940505D
4052603F54633F56663E5769
3C55673A5263384E5E374B5935475432424E2F3D482C374128313823292F1F2327242729
2E3134383B3D4345474F50525D5E5F6B6C6C787979868787939392A09F9EADABA9B7B5B2
BFBDBAC6C4C0CDCAC5D4CFCAD8D2CDDAD3CEDBD3CCDCD2CBDCD0C9DACDC5D7CAC1D3C6BD
CEC0B7C6B8B0BDAFA8B2A59FA79B959A8F898B817D7D746F6E6663605956514B49433D3C
36312F2B2624231C1A241E1D2C2A2B323336363A3F3940473B454D3D49533D4C583E4F5C
3E515F3E53633E55663D5768
3B55673A5162384E5E364A5934465331414D2E3C472A363F262F3721282E1C20241C1F22
2426282D2F3138393B4545475050515B5C5C68686876767684848390908F9B9A98A4A2A0
ACAAA7B4B1ADB9B6B2BEBAB5C2BDB7C5BEB8C6BDB7C5BCB5C5BAB3C3B7B0C1B4ACBCAFA7
B6A9A1AFA29AA699939C908A928781857B76776E6A69615D5B54514D47453E3938312C2B
2721201D15131C14122320202A292B2F313533383E363E4639434C3A47523C4B573C4E5B
3D505F3D53623D55653D5668
3B5567395162374E5E354A5933455330414D2D3B4629353F252F3720272D1A1D2216161A
191A1C2223242C2C2E3637384242434E4E4F595A5A6566657271707D7C7B8786848F8E8C
9695939D9C9AA3A19EA8A4A0ACA7A3ADA8A3ADA7A1ADA6A0ACA49DAAA19AA69D96A19790
9A918A9389838C827C847B757A716D706763635C58564F4D4742403A35342F2B2925211F
1A131117100E1D1919232223292A2D2D313631383E343E4637424C3947513A4A563B4D5B
3C505E3C52623D54653D5668
3B5567395162374E5E354A5933455330414D2D3B47293640242F371F272E191E23101114
0D0C0E1515161F1F202A292A3434343E3E3E4748475252515D5D5C67676572716F7A7978
817F7F8785848C8A88908D8B918E8B93908C94908C948F8A928D888F8A858B8580857F7A
80797479726D726C686B6461615B5957524F4B47453F3B3934302E2925241D1A19151010
140F0E1814141E1C1D232426282B302C3238303840333E4636424C384652394A563A4D5B
3B505E3C52623C54653D5668
3B5567395163374E5E354A5933465430414E2D3C482937412530392029301A202613161A
0B0A0C0807071110101C1C1C2626272F2F303737383F3F3F4848475151505A5A59626261
6868676D6D6C7170707574737977767A79777B7A777B79767A7774777471746F6C6C6864
64605C5F5B58595754514F4D4845453F3D3C3734342C2A2A221F1F1A1716130F0D0F0805
120C0A1917171F1F2124262A282D332C343B303942333E4835434E374753384A573A4D5B
3B505F3B52623C54653C5668
3B5567395263374E5F354B5A3347553043502D3E4A2A384426323C212B341C242B161B20
0F11150706070504040D0D0E18181922222329292A2E2F2F3536363C3D3E4344454B4B4B
5151515557565A5B5A5D5E5E60616062626163636263636162626061605F5D5C5B585857
5253534A4A4B4343433B3B3C3434352E2E2E2625261E1D1E1614140E0B0A0A04010D0704
1412121B1B1D202326252A2F2930372D363E303B4432404A35444F374754384A58394D5C
3A505F3B52633C54663C5668
3B5567395264384F60364C5C3348573144522E404D2B3B47273540232F391E2830192127
13181D0D10130605060403040B0B0C1414151C1D1D2222222626262B2B2B303132333636
373A3A3C3F3F414445454848484B4B4B4D4D4C4F4F4C4F4F4B4E4E4A4D4E4A4D4F484B4E
44464A4043453B3D3F3335382C2D2F2223251A1A1B1312130C0A0B0702010A0503110E0F
17181A1D202422272D262E342A343C2E3942303D4833424D354552374956384B5A394E5D
3A50603B52633C54663C5669
3B56683A5365385061364D5D344A593246553042502D3E4B2A394526343E222E371D272F
18202712181D0C0F130504050302020A0A0B1212131718181A1B1B1D1E1E202222252828
282C2C292E2E2C30312F343533373934393B353A3C373C3E373C3F363C3E363C3F353B3F
32383C2D3337262C30202529191D201214170D0E100908090501010703020F0D0E161619
1B1F2320262C252D3429323B2C38412F3C4731404C344450354754374A58384D5B394F5F
3A51613B53643C55663C5669
3C56683A5465395162374F5F354C5C3349583145542F424F2C3D4A29394526343F222E38
1D283118212813191F0D11150406070000000405050E0F10141617151818151717141718
161A1B1A1E1F1E23241D23251D232620282C252D31283034283035293136293138293137
272F35222A301C242A171D2211161A0B1013080A0D07050609070710101215181C1B2025
20272E242D3528333C2B38422E3C4731404C334450354754364958384C5B394E5E3A5060
3B52633B54653C55673C5769
3C56693B5567395264385061374E5E354B5B3349583146542F42502D3F4C2A3A47263641
23313B1F2B351A252D151E2510161C0A0E120406090406080A0D0F0D1214101415101516
12171912181B121A1D151E231822281B252B1C272E1F2932222D36232E37222C34212B33
1F29301B242B161E2411171C0D12160B0F110708090A0B0D121519181D221D242B212A32
25303928353F2B39442E3E4931414E334451344755364A58374C5B384E5E3950603A5262
3B53643B54663C56683C576A
3C576A3B56683A5466395264385061374E5F354C5D344A5A3247573045532E414F2C3E4B
293A4726364223313C1F2C361B262F162028111A210A1117060B10050B100B12170F171C
0F171B0F181C111C2114202618232A18242B18252D19262F1A26301B27311C28311C2730
1B242D1A2028161D2312171C0C0F120B0D1110151A171E241C252C202B3424303A273540
2A39452D3D4930414E324451334755354958364B5A374D5D394F5F3950613A52633B5364
3B54663C55673C56693D576A
3C57693C56683B55673A54663A5365395263385061374F5F364D5D344B5B334958314656
2F44532D414F2B3E4B293A4726374323333E1F2E391C293419263017232D131E29121D26
141F2915212A15212916222A19262E1D2A331F2C361F2D381F2E391F2D381F2D38202E39
1F2C361A242D141C24151D2519232B1C27301F2C3523313B263541293A462C3D4A2E404E
304351324654344857354A5A364C5C374E5E384F603951613A52633A53643B54653B5567
3C55683C56693C57693D576A
3D576A3C576A3C57693C56693B55683B55673A54663A5365395264395163385062374F60
364E5F354D5D344B5B3349593147573045552E43522C41502B3F4E2A3D4C283C4A283B4A
283B4A283B4A283A4927394724364523354323344223344123344123344122334022323E
22323D253642283A472A3B492B3D4B2D404E2E4250304453324756334958344B5A364C5C
374E5E384F603850613951623A52633A53653B54653B54663B55673C55683C56683C5669
3C57693C576A3D576A3D586B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181P00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`005?ooo`PmFF`4?UU]23iJK@<nFVh4?eY^13mKKPPoFfl4?ea`1d1L
L0Q0GG4<@Eib0d5NL`Q1Gg<8@Umc145OL`A2Gg<;@Umd145PM0]2H7@4@V1e149QM0Q2H7@4@V1c145O
L`m1Gg84@Eib1d5NL@A0GG04@5a_141LKQM0G6l8?e]_1cmKKP@nFVh8?UY]13iIK0PmFF`Eoooo000D
oooo23eIK0@nFFd8?UY]0ciJKP@oFVh4?e]^23mKK`@oG707@5a`241ML@a1GW83@Eic245OL`Q2Gg<4
@Emc149OL`]2Gg@4@F1d2d9PM0A2H7D4@V5d249PM0A2H7<4@Emc3d5OLPA1GW87@Eia141ML0A0G6l4
@5a^5d1LK`PoFfl7?e]^13iJKPPnFVd4?UU/23eIK1Goool001Coool8?EU/13iIK@PnFVd3?UY^13mJ
KP@oFfh8?e]_13mLL0M0G708@5ea345NLP=1GW<8@Emc249OL`A1Gg<4@Umc2d9OM0A1H7@;@V1d149P
M@A2HG@8@V1d149PL`A1Gg<?@Emb145NLPM1GW44@5e`141LK`A0G6hG@5a_23mKK`LoFfh4?UY^23iJ
K@@nFF`8?EU/5Oooo`005?ooo`@mFF`4?UY]13iKKP@oFfl4?ea_0d1LL0A0GG44@Eeb145NLPA1Gg<4
@Umd0d9PM@A3HGD4@f5f14ARM`A4HgP4AFAi14ETNP=5IGX4AVEk14IVN`Q6IW`8AVIk0dIWO0A6Igd<
AVMl14IXO@=7J7h8AfUn24MYO@A7Ig/4AVMj0dIVNPA5IWT<AFEi14ETN0=4HgH4A69e14=QL`Q3Gg04
@f1c2d=PM0Q2Gg<4@Emb145NLP=1GG44@5e`141LK`@oFfl4?UY^13iJK@@mFF`Eoooo000Doooo13eI
K0@nFVd4?U]^13mKK`@oG6l3@5a`141ML@A1GG84@Eib145OL`A2Gg@3@V1e14=QM@A3HGH4A69g14AS
N0A5I7T4AFAj0dEUNPA6IG/4AVIk24IVO0Q6IW/3AVMl14IWO@a6Ig`4AVQm0dMXOPQ7JGh8AfUm14MW
N`A6IgX3AVIj14EVN@a5IGT4AFAh0dASMPA4HWD4@f5c24=OL0A3H7<;@f1d249OL`A1Gg84@Eib0d5M
L@A0GG04@5a_13mKK`@nFVh4?UY]13eIK1Goool001Coool4?EU/13iJK@@nFfh4?e]_13mLK`=0G704
@5ea145MLPA1GW84@Emc149OM0=2H7D4@f5e14=QMPA4HWL4A6=h14ETN@A5I7X3AFEj14IUN`A6IW/8
AVIl24IVN`=6Ig`4AVMm34IWO0A6J7d3AfQn24MYOPQ7JGd4AfMk14IWNP=6IWX4AFIi34EUN@A5I7P3
A6=f14ARM@A3HG<8@em`14=PL`]3H7@8@Umc145OLPA1GW83@Eea141ML0A0G6l4?e]_13iJKP@nFVd4
?EU/5Oooo`005?ooo`@mFF`4?UY]13iKKP@oFfl4?ea_0d1LL0A0GG44@Eeb145NLPA1Gg<4@Umd0d9P
M@A3HGD4@f5f14ARM`A4HgP4AFAi14ETNP=5IGX4AVEk14IVN`Q6IW`8AVIk0dIWO0A6Igd<AVMl14IX
O@=7J7h8AfUn24MYO@A7Ig/4AVMj0dIVNPA5IWT<AFEi14ETN0=4HgH4A69e14=QL`Q3Gg04@f1c2d=P
M0Q2Gg<4@Emb145NLP=1GG44@5e`141LK`@oFfl4?UY^13iJK@@mFF`Eoooo000Doooo13iIK0@nFVd4
?e]_141LL0A0GG43@Eib149OL`A2H7D4@f5f14ARM`A4HgP3AFAi14IUN`A6IW`4AfMm14QXOPA9JGl4
BFZ10dY[PPA:K8<8Bff414]^Q@A;KX@;Bfj524]^Q0A:KX@4Bfj41d]^P`Q:Kh<4BFj214U/P0M8Jgl8
BFb014Y/P0A:Jgl4BFYn0dQYO0A8Ig/4AfIh14ESM@A5HWD4AVAh1dIUN@A5I7P4AF=h14ASM`A4HWH4
@f5e0d9PM0A2Gg<4@Eib141ML0@oG6l4?UY^13iIKAGoool001Coool4?UU/13iJK@@oFfl4@5a`141M
L@=1GW84@Umc149PM@A3HGH4A69g14ASN0=5I7T4AVEk14IVO0A7Igd4B6Qn14UYO`A9JX43BV^214Y/
P`Q;KH@4Bfj514]^Q0];KXD8Bfj414Y^Q0A;KX@7Bfj324Y_P`A9KX84BFb01dQ[O`Q9K804BVb014Y[
O`A9JWh3B6Ul14QWN`A7IWP4AF=e14ERM@A6I7P7AVEi14ETN0A5HgP4A6=g14ARMPA3HGD3@V1d149O
L`A1GW84@5e`13mLK`@nFVh4?UU]5Oooo`005?ooo`@nFF`4?UY]13mKK`A0G704@5ea0d5NLPA2Gg<4
@V1e14=QMPA4HWL4A6=h0dETN@A6IG/4AVIl14MWO@A8J7h4BFUo14UZP@=:Jh84BVb324]]Q0A;KXD4
Bfj42d]^Q@Q;KX@4BVj414]^Q0M;KX<8BVn314U^PPA9K807B6]o24U/P0A:K804BV]o14UZOP=8JG`4
B6Mk14MVN0A5HgD4AF9e14ITN0M6IGT4AFAh14ESN0A4HgL4A69f14=QM@=2H7@4@Umc145NLPA0GG04
?ea_13iJKP@nFFdEoooo000Doooo13iIK0@nFVd4?e]_141LL0A0GG43@Eib149OL`A2H7D4@f5f14AR
M`A4HgP3AFAi14IUN`A6IW`4AfMm14QXOPA9JGl4BFZ10dY[PPA:K8<8Bff414]^Q@A;KX@;Bfj524]^
Q0A:KX@4Bfj41d]^P`Q:Kh<4BFj214U/P0M8Jgl8BFb014Y/P0A:Jgl4BFYn0dQYO0A8Ig/4AfIh14ES
M@A5HWD4AVAh1dIUN@A5I7P4AF=h14ASM`A4HWH4@f5e0d9PM0A2Gg<4@Eib141ML0@oG6l4?UY^13iI
KAGoool001Coool4?UU]13mJKPA0G6l4@Eea149NL`=2H7@4@f5f14ARM`A5HgT4AVEj14MVO0=8J7h4
BFV014Y[P@A;K8<4C6f514a_QPA=L8P3CW::14mcR`A@M8d8D7F>3e1eS@A?MHd4CgF<14mdR`A>LhT3
C7:714aaQ@A<L8D4Bg6514]aQPA;LXH4Bg650d]bQ@A;LXH4C76614aaQ@A=L8D4C6n40da^PPA;KH44
Bfao14Y[OPQ:JWh4BFYn0dUYOPA8J7d4B6Ml14MVN`A6IGX4AFAi0dASM`A3HGH4@V1d145NLPA0GG44
?e]_13iJKAGoool001Coool4?UU]13mJKPA0G6l4@Eea149NL`=2H7@4@f5f14ARM`A5HgT4AVEj14MV
O0=8J7h4BFV014Y[P@A;K8<4C6f514a_QPA=L8P3CW::14mcR`A@M8d8D7F>3e1eS@A?MHd4CgF<14md
R`A>LhT3C7:714aaQ@A<L8D4Bg6514]aQPA;LXH4Bg650d]bQ@A;LXH4C76614aaQ@A=L8D4C6n40da^
PPA;KH44Bfao14Y[OPQ:JWh4BFYn0dUYOPA8J7d4B6Ml14MVN`A6IGX4AFAi0dASM`A3HGH4@V1d145N
LPA0GG44?e]_13iJKAGoool001Coool4?UU]13mJKPA0G6l4@Eea149NL`=2H7@4@f5f14ARM`A5HgT4
AVEj14MVO0=8J7h4BFV014Y[P@A;K8<4C6f514a_QPA=L8P3CW::14mcR`A@M8d8D7F>3e1eS@A?MHd4
CgF<14mdR`A>LhT3C7:714aaQ@A<L8D4Bg6514]aQPA;LXH4Bg650d]bQ@A;LXH4C76614aaQ@A=L8D4
C6n40da^PPA;KH44Bfao14Y[OPQ:JWh4BFYn0dUYOPA8J7d4B6Ml14MVN`A6IGX4AFAi0dASM`A3HGH4
@V1d145NLPA0GG44?e]_13iJKAGoool001Coool4?UU]13mJKPA0G6l4@Eea149NL`=2H7@4@f5f14AR
M`A5HgT4AVEj14MVO0=8J7h4BFV014Y[P@A;K8<4C6f514a_QPA=L8P3CW::14mcR`A@M8d8D7F>3e1e
S@A?MHd4CgF<14mdR`A>LhT3C7:714aaQ@A<L8D4Bg6514]aQPA;LXH4Bg650d]bQ@A;LXH4C76614aa
Q@A=L8D4C6n40da^PPA;KH44Bfao14Y[OPQ:JWh4BFYn0dUYOPA8J7d4B6Ml14MVN`A6IGX4AFAi0dAS
M`A3HGH4@V1d145NLPA0GG44?e]_13iJKAGoool001Coool4?UY]13mKK`A0G704@Uib14=PM0=4HWH4
AF=h14IUNPA7IW`4B6Qn14YZP0=;K884C6f514e_Q`A>LHT4Cg>;151eS@AAMY03DgRB15AjU0AEO9H4
EGfG15ImV0AEOIL4EGbG0eElUPADO9D4E7bD15AkT`ACNY44DWV@0e9hSPAAMh`4DGJ;151eRPQ?MHX4
CgJ;0dmeR`A>MX/4CgN<14mfR`A@MX/4D7F;0e1eRPA?LhP4CW6624i`Q@A=L8D4CFn50da^Q0A<KH<4
Bfb114YZP0A8JGh4AfMl0dIUNPA5I7P4A69f149PM0A1GW84@5a`13iJKAGoool001Coool4?UY]13mK
K`A0G704@Uib14=PM0=4HWH4AF=h14IUNPA7IW`4B6Qn14YZP0=;K884C6f514e_Q`A>LHT4Cg>;151e
S@AAMY03DgRB15AjU0AEO9H4EGfG15ImV0AEOIL4EGbG0eElUPADO9D4E7bD15AkT`ACNY44DWV@0e9h
SPAAMh`4DGJ;151eRPQ?MHX4CgJ;0dmeR`A>MX/4CgN<14mfR`A@MX/4D7F;0e1eRPA?LhP4CW6624i`
Q@A=L8D4CFn50da^Q0A<KH<4Bfb114YZP0A8JGh4AfMl0dIUNPA5I7P4A69f149PM0A1GW84@5a`13iJ
KAGoool001Coool4?UY]13mKK`A0G704@Uib14=PM0=4HWH4AF=h14IUNPA7IW`4B6Qn14YZP0=;K884
C6f514e_Q`A>LHT4Cg>;151eS@AAMY03DgRB15AjU0AEO9H4EGfG15ImV0AEOIL4EGbG0eElUPADO9D4
E7bD15AkT`ACNY44DWV@0e9hSPAAMh`4DGJ;151eRPQ?MHX4CgJ;0dmeR`A>MX/4CgN<14mfR`A@MX/4
D7F;0e1eRPA?LhP4CW6624i`Q@A=L8D4CFn50da^Q0A<KH<4Bfb114YZP0A8JGh4AfMl0dIUNPA5I7P4
A69f149PM0A1GW84@5a`13iJKAGoool001Coool4?UY]13mKK`A0G704@Uib14=PM0=4HWH4AF=h14IU
NPA7IW`4B6Qn14YZP0=;K884C6f514e_Q`A>LHT4Cg>;151eS@AAMY03DgRB15AjU0AEO9H4EGfG15Im
V0AEOIL4EGbG0eElUPADO9D4E7bD15AkT`ACNY44DWV@0e9hSPAAMh`4DGJ;151eRPQ?MHX4CgJ;0dme
R`A>MX/4CgN<14mfR`A@MX/4D7F;0e1eRPA?LhP4CW6624i`Q@A=L8D4CFn50da^Q0A<KH<4Bfb114YZ
P0A8JGh4AfMl0dIUNPA5I7P4A69f149PM0A1GW84@5a`13iJKAGoool001Coool4?UY]141LL0A1GW84
@V1d14ARMP=5I7T4AfEk14QWO@A9JH04Bf^214a]Q@==KhL4Cg::151dS0AAMXl4DgRB15AjU0AFOIL3
EgnJ15V1W@AJQ:04FhJR15b7X`AKQZ84FXBP0eZ3WPAIPid4FH:L15R2VPAHPIT4Eh6H0eN0U`AFOiH4
EGfC15ElTPQDO98?E7bC25AmU0AEO983EG^B15AjT0ACMh`4DWJ;159fS@AAMX`4DGF<0e1dRPA?LXT4
CW2714a^Q0A;KH84BVZ00dQXO@A7IW/4AFAi14=RMPA2Gg<4@5ea13mJKQGoool001Coool4?UY]141L
L0A1GW84@V1d14ARMP=5I7T4AfEk14QWO@A9JH04Bf^214a]Q@==KhL4Cg::151dS0AAMXl4DgRB15Aj
U0AFOIL3EgnJ15V1W@AJQ:04FhJR15b7X`AKQZ84FXBP0eZ3WPAIPid4FH:L15R2VPAHPIT4Eh6H0eN0
U`AFOiH4EGfC15ElTPQDO98?E7bC25AmU0AEO983EG^B15AjT0ACMh`4DWJ;159fS@AAMX`4DGF<0e1d
RPA?LXT4CW2714a^Q0A;KH84BVZ00dQXO@A7IW/4AFAi14=RMPA2Gg<4@5ea13mJKQGoool001Coool4
?UY]141LL0A1GW84@V1d14ARMP=5I7T4AfEk14QWO@A9JH04Bf^214a]Q@==KhL4Cg::151dS0AAMXl4
DgRB15AjU0AFOIL3EgnJ15V1W@AJQ:04FhJR15b7X`AKQZ84FXBP0eZ3WPAIPid4FH:L15R2VPAHPIT4
Eh6H0eN0U`AFOiH4EGfC15ElTPQDO98?E7bC25AmU0AEO983EG^B15AjT0ACMh`4DWJ;159fS@AAMX`4
DGF<0e1dRPA?LXT4CW2714a^Q0A;KH84BVZ00dQXO@A7IW/4AFAi14=RMPA2Gg<4@5ea13mJKQGoool0
01Coool4?eY^141ML0A2Gg<4@f5f14ESN0=7IW/4B6Qn14YZP0A;K8<4CFn614maR@=@Lh`4DWJ?15=h
TPAENiD4EWfH15R0V`AJPil3G8JR15f9YPAPS:X4HY2^16>B/@AQT:h4GhbX0ej:Y@ANRJ@4GHVS15f8
XPAMR:44G8RQ0eb7X0ALQil4FhNN15^7W@AJQYd8FXFM0eZ5W0AJQ9`8FHBM15Z4W@AJQ9`3FH:J15R1
V0AHOiH4EgjE15InU@AFOI@4EG^C0e=iT@ABMhl4DGF<14mbR@A=L8H4C6f30dY[P@A8J7h4AVIk14AT
N0A3HGD4@Eia13mKKQGoool001Coool4?eY^141ML0A2Gg<4@f5f14ESN0=7IW/4B6Qn14YZP0A;K8<4
CFn614maR@=@Lh`4DWJ?15=hTPAENiD4EWfH15R0V`AJPil3G8JR15f9YPAPS:X4HY2^16>B/@AQT:h4
GhbX0ej:Y@ANRJ@4GHVS15f8XPAMR:44G8RQ0eb7X0ALQil4FhNN15^7W@AJQYd8FXFM0eZ5W0AJQ9`8
FHBM15Z4W@AJQ9`3FH:J15R1V0AHOiH4EgjE15InU@AFOI@4EG^C0e=iT@ABMhl4DGF<14mbR@A=L8H4
C6f30dY[P@A8J7h4AVIk14ATN0A3HGD4@Eia13mKKQGoool001Coool4?eY^141ML0A2Gg<4@f5f14ES
N0=7IW/4B6Qn14YZP0A;K8<4CFn614maR@=@Lh`4DWJ?15=hTPAENiD4EWfH15R0V`AJPil3G8JR15f9
YPAPS:X4HY2^16>B/@AQT:h4GhbX0ej:Y@ANRJ@4GHVS15f8XPAMR:44G8RQ0eb7X0ALQil4FhNN15^7
W@AJQYd8FXFM0eZ5W0AJQ9`8FHBM15Z4W@AJQ9`3FH:J15R1V0AHOiH4EgjE15InU@AFOI@4EG^C0e=i
T@ABMhl4DGF<14mbR@A=L8H4C6f30dY[P@A8J7h4AVIk14ATN0A3HGD4@Eia13mKKQGoool001Coool4
?eY^141ML0A2Gg<4@f5f14ESN0=7IW/4B6Qn14YZP0A;K8<4CFn614maR@=@Lh`4DWJ?15=hTPAENiD4
EWfH15R0V`AJPil3G8JR15f9YPAPS:X4HY2^16>B/@AQT:h4GhbX0ej:Y@ANRJ@4GHVS15f8XPAMR:44
G8RQ0eb7X0ALQil4FhNN15^7W@AJQYd8FXFM0eZ5W0AJQ9`8FHBM15Z4W@AJQ9`3FH:J15R1V0AHOiH4
EgjE15InU@AFOI@4EG^C0e=iT@ABMhl4DGF<14mbR@A=L8H4C6f30dY[P@A8J7h4AVIk14ATN0A3HGD4
@Eia13mKKQGoool001Coool4?e]^145ML@A2H7@4A6=g14IUNP=8J7d4BVZ014a]Q0A=KhL4Cg::155e
S@=CMi04EGZD15MmU`AHP9/4FX>N15b6XPANRJH3H8bZ16:@[PAUU;@4JY^l16ZK^`AUU;<4Hi6_0f:@
[0aRSjX4HXnY1f6@ZPaQTJX4HI6Y166@Z0AQSjL3H8jW162=YPAPS:H4GhbU15n;Y@ANRj@3GXVS15f8
XPALQj44G8JP15^5W`AJQ9d4FH6K0eMoV0AFO9D4E7ZB159gSPA@M8/4CW670da^Q0A:JX04B6Ml14IT
N@A3HGD4@Eib13mKKaGoool001Coool4?e]^145ML@A2H7@4A6=g14IUNP=8J7d4BVZ014a]Q0A=KhL4
Cg::155eS@=CMi04EGZD15MmU`AHP9/4FX>N15b6XPANRJH3H8bZ16:@[PAUU;@4JY^l16ZK^`AUU;<4
Hi6_0f:@[0aRSjX4HXnY1f6@ZPaQTJX4HI6Y166@Z0AQSjL3H8jW162=YPAPS:H4GhbU15n;Y@ANRj@3
GXVS15f8XPALQj44G8JP15^5W`AJQ9d4FH6K0eMoV0AFO9D4E7ZB159gSPA@M8/4CW670da^Q0A:JX04
B6Ml14ITN@A3HGD4@Eib13mKKaGoool001Coool4?e]^145ML@A2H7@4A6=g14IUNP=8J7d4BVZ014a]
Q0A=KhL4Cg::155eS@=CMi04EGZD15MmU`AHP9/4FX>N15b6XPANRJH3H8bZ16:@[PAUU;@4JY^l16ZK
^`AUU;<4Hi6_0f:@[0aRSjX4HXnY1f6@ZPaQTJX4HI6Y166@Z0AQSjL3H8jW162=YPAPS:H4GhbU15n;
Y@ANRj@3GXVS15f8XPALQj44G8JP15^5W`AJQ9d4FH6K0eMoV0AFO9D4E7ZB159gSPA@M8/4CW670da^
Q0A:JX04B6Ml14ITN@A3HGD4@Eib13mKKaGoool001Coool4?e]^145ML@A2H7@4A6=g14IUNP=8J7d4
BVZ014a]Q0A=KhL4Cg::155eS@=CMi04EGZD15MmU`AHP9/4FX>N15b6XPANRJH3H8bZ16:@[PAUU;@4
JY^l16ZK^`AUU;<4Hi6_0f:@[0aRSjX4HXnY1f6@ZPaQTJX4HI6Y166@Z0AQSjL3H8jW162=YPAPS:H4
GhbU15n;Y@ANRj@3GXVS15f8XPALQj44G8JP15^5W`AJQ9d4FH6K0eMoV0AFO9D4E7ZB159gSPA@M8/4
CW670da^Q0A:JX04B6Ml14ITN@A3HGD4@Eib13mKKaGoool001Coool4?e]_145NLPA3HGH4AFAi14MW
O0=9JH04C6b314i_Q`A@LXX4DWF>15AhT@=FNiD4F7jI15Z1W0ALQ:04GXRT162;Z@ARSjd3I9:a16JF
]PAYVk`4Jijo16ZL_0AWUkH4IYJd1fJE/PAVUK44IYJb16JF/@AVU[03IiRa16NI/`AWVk@4Iife16RM
]PAXVk@4IiVb0fNG/@AWUZl4IYB^16FC[PQTTZd3Hi:]26>B[PAQT:`4H8jY15n;YPAMR:<3FhFO15V2
V`AGOYL4EG^C15=gS`A@M8/3CW2714a]P`A9JGl4AfIk14ARM`A2Gg<4?ea_5Oooo`005?ooo`@oFfl4
@Eib14=QMPA5I7T4AfMl0dUYP0A<K8<4CVn7151bRPABMHh4E7RA0eIkU@AHOYT4FX6L15b4X0ANR:@4
H8^Y16:?[@=TT[44IYJf16VK_0A[W[l4JYbl16NG]PAVU[@7IYFb16JE/@AVU[84IYJa16JF/0=WV;44
IiVc16NK]0AWWKD4J9ff16RK]0AWVK83IiNa16NF[`AVU:h4II>^26BB[@=STZd8Hi:^166@[0APSZT4
Gh^V15f8X`=KQIl4FH:K15MnU`AENi<4DgN?151dR`=>L8L4C6f314UYO`A7IW/4A69g149OL`@oG6lE
oooo000Doooo13mKK`A1GW84@f5f14ETN@A7Ig`3BFV014a/P`A>KhL4D7::159eSPADN943EW^E15Qn
V@AJPI`4G8BP15j8Y0APRjT4HXn]0fBB/@AVU[H4JI^l16^N_`AZW;`4IiNf16JF]0MVUK84IYFa16JF
/PAVU[44IYJ`0fNH/@AWVK<4Ii^d16NM]@AXWKH4J9^d16NI/P=WUk44IiJ_16JD[PAUTjh8I9:]0f>B
[@QSTZh4HI2/162>Z@AORjH4GHRS0e^5W`AIPY/4EgjG15EkT`ACMhl4D7B;0di`Q`A<KH<4BFUo14MV
N`A4HWL4@Umc13mLKaGoool001Coool4?e]_145NLPA3HGH4AFAi14MWO0=9JH04C6b314i_Q`A@LXX4
DWF>15AhT@=FNiD4F7jI15Z1W0ALQ:04GXRT162;Z@ARSjd3I9:a16JF]PAYVk`4Jijo16ZL_0AWUkH4
IYJd1fJE/PAVUK44IYJb16JF/@AVU[03IiRa16NI/`AWVk@4Iife16RM]PAXVk@4IiVb0fNG/@AWUZl4
IYB^16FC[PQTTZd3Hi:]26>B[PAQT:`4H8jY15n;YPAMR:<3FhFO15V2V`AGOYL4EG^C15=gS`A@M8/3
CW2714a]P`A9JGl4AfIk14ARM`A2Gg<4?ea_5Oooo`005?ooo`@oFfl4@Uic14ARMPA6IGX4BFQn0d][
PPA=KXH4Cg:9159eS@ADN944EW^E0eQoV@AKPYd4GHJR15n9YPAQSJ/4I92_16JD]0=XV;T4JYbm16bO
``AWVKd4I9Ff16RI^@AYV[T3JY^i16ZL^PQ[W;T4Jifi16^N^@=/WkT4K:6k16fR_0Q]Xkd4KJ>l16jR
^`=]X;X4K9ji16bL]`A[VkH4JIZe16RI]@=WVKD4IiZg16RL^PAWVkT4IINd16>C/0AQSj/3Gh^V15f7
XPAKPid4F7nH15IkU0ACMhl3D7>:14e_QPA;Jh44B6Qm14ETN0A2H7@4@5a`5Oooo`005?ooo`@oFfl4
@Uic14ARMPA6IGX4BFQn0d][PPA=KXH4Cg:9159eS@ADN944EW^E0eQoV@AKPYd4GHJR15n9YPAQSJ/4
I92_16JD]0=XV;T4JYbm16bO``AWVKd4I9Ff16RI^@AYV[T3JY^i16ZL^PQ[W;T4Jifi16^N^@=/WkT4
K:6k16fR_0Q]Xkd4KJ>l16jR^`=]X;X4K9ji16bL]`A[VkH4JIZe16RI]@=WVKD4IiZg16RL^PAWVkT4
IINd16>C/0AQSj/3Gh^V15f7XPAKPid4F7nH15IkU0ACMhl3D7>:14e_QPA;Jh44B6Qm14ETN0A2H7@4
@5a`5Oooo`005?ooo`@oFfl4@Uic14ARMPA6IGX4BFQn0d][PPA=KXH4Cg:9159eS@ADN944EW^E0eQo
V@AKPYd4GHJR15n9YPAQSJ/4I92_16JD]0=XV;T4JYbm16bO``AWVKd4I9Ff16RI^@AYV[T3JY^i16ZL
^PQ[W;T4Jifi16^N^@=/WkT4K:6k16fR_0Q]Xkd4KJ>l16jR^`=]X;X4K9ji16bL]`A[VkH4JIZe16RI
]@=WVKD4IiZg16RL^PAWVkT4IINd16>C/0AQSj/3Gh^V15f7XPAKPid4F7nH15IkU0ACMhl3D7>:14e_
QPA;Jh44B6Qm14ETN0A2H7@4@5a`5Oooo`005?ooo`@oFfl4@Uic14ARMPA6IGX4BFQn0d][PPA=KXH4
Cg:9159eS@ADN944EW^E0eQoV@AKPYd4GHJR15n9YPAQSJ/4I92_16JD]0=XV;T4JYbm16bO``AWVKd4
I9Ff16RI^@AYV[T3JY^i16ZL^PQ[W;T4Jifi16^N^@=/WkT4K:6k16fR_0Q]Xkd4KJ>l16jR^`=]X;X4
K9ji16bL]`A[VkH4JIZe16RI]@=WVKD4IiZg16RL^PAWVkT4IINd16>C/0AQSj/3Gh^V15f7XPAKPid4
F7nH15IkU0ACMhl3D7>:14e_QPA;Jh44B6Qm14ETN0A2H7@4@5a`5Oooo`005?ooo`@oG6l4@Umc14ES
N0A7IW`4BVUo0da]Q0A?LHP4DGB<15AhT@AFNiD4FGnI0e^3WPANQZ84H8ZW16>>[0AUT[04IiJe16ZJ
^P=/W/04KjC716ZN`@ATU[L4J9Vk16ZL_@A/W[h3KZ3016nQ`@A_X/44L:;0172S`0A`Y<03L:G0176W
`@AaZ/<8LZ_417:[``AbZ/<3LZO117:V`0AaXkh4L:6m16nP_0A]Wk`3K9nm16bQ`0Q]Y<D4JYno16RK
^@AVU[@3Hi6^166=Z0ANR:<4FhBM15QoV0AENi<3DWJ>14mbR@A<KX@4BFUo14IUNPA3HGD4@5a`5Ooo
o`005?ooo`@oG6l4@Umc14ESN0A7IW`4BVUo0da]Q0A?LHP4DGB<15AhT@AFNiD4FGnI0e^3WPANQZ84
H8ZW16>>[0AUT[04IiJe16ZJ^P=/W/04KjC716ZN`@ATU[L4J9Vk16ZL_@A/W[h3KZ3016nQ`@A_X/44
L:;0172S`0A`Y<03L:G0176W`@AaZ/<8LZ_417:[``AbZ/<3LZO117:V`0AaXkh4L:6m16nP_0A]Wk`3
K9nm16bQ`0Q]Y<D4JYno16RK^@AVU[@3Hi6^166=Z0ANR:<4FhBM15QoV0AENi<3DWJ>14mbR@A<KX@4
BFUo14IUNPA3HGD4@5a`5Oooo`005?ooo`@oG6l4@Umc14ESN0A7IW`4BVUo0da]Q0A?LHP4DGB<15Ah
T@AFNiD4FGnI0e^3WPANQZ84H8ZW16>>[0AUT[04IiJe16ZJ^P=/W/04KjC716ZN`@ATU[L4J9Vk16ZL
_@A/W[h3KZ3016nQ`@A_X/44L:;0172S`0A`Y<03L:G0176W`@AaZ/<8LZ_417:[``AbZ/<3LZO117:V
`0AaXkh4L:6m16nP_0A]Wk`3K9nm16bQ`0Q]Y<D4JYno16RK^@AVU[@3Hi6^166=Z0ANR:<4FhBM15Qo
V0AENi<3DWJ>14mbR@A<KX@4BFUo14IUNPA3HGD4@5a`5Oooo`005?ooo`@oG6l4@Umc14ESN0A7IW`4
BVUo0da]Q0A?LHP4DGB<15AhT@AFNiD4FGnI0e^3WPANQZ84H8ZW16>>[0AUT[04IiJe16ZJ^P=/W/04
KjC716ZN`@ATU[L4J9Vk16ZL_@A/W[h3KZ3016nQ`@A_X/44L:;0172S`0A`Y<03L:G0176W`@AaZ/<8
LZ_417:[``AbZ/<3LZO117:V`0AaXkh4L:6m16nP_0A]Wk`3K9nm16bQ`0Q]Y<D4JYno16RK^@AVU[@3
Hi6^166=Z0ANR:<4FhBM15QoV0AENi<3DWJ>14mbR@A<KX@4BFUo14IUNPA3HGD4@5a`5Oooo`005?oo
o`A0G704@f1d14ESN0A8Igd4Bf^10di_QPAALh/4DgN?15IjU0AIOYP4Fh:M0ej6XPAQRZL4Hhj/16JB
/@AYUkH4Ji^l16jO`@=`XlH4Jio216RK_@AZWKl4K9k016jP`@A`X/<3LZG617>Wb0AdZ<P8MJW717FZ
aP=eZ/D4MJS317FW`PAfYl84MZK217JX`PAgZlD3Mjc617R[a@AgZ<@4MJK217BU`PAbY<43LJ?1172T
``A`YlL4LJ[=172Yb`A]X/<4JYfl0fRH]@AUTjl4HXfY15n8XPAKPi`4F7jG0eEiT@AAM8/4CVn514YZ
P0A7IW/4A65f141ML1Goool001Coool4@5a`14=PM0A5HgP4B6Mm14][P@=>KhH4DG>;15=gS`AFNY@4
FGjH15^2W@=NQZ84HHZW16>>[0AVT[44JINf16^K_0A^Wl43L:?616^O`PAXVkd4JYfo16bN`0A^X<44
L:;30g:UaPAcYlP4M:S827FYa`AeZ/H3MJ[517FX``AeYl84MZO217JV`PAfZ<84Mj_50gN/aPAhZlD4
MjS417FV`PAdYL84LZC10g6S`@A`Y<<4L:O7176Zc@A`ZL/4KJ;316ZM_0=XV;D4II>_16:=Z@AOR:84
Fh>L15QnU`=ENI44DGB;14i_Q@A:JX04AfIk14AQMPA0GG0Eoooo000Doooo141LL0A3H7@4AF=h14QW
O@A;Jh43CVn6155cR`ACMhl4EWZD15UnV0AKPYd3GXJR166:Y`ASSZ`4IY:a16VG]PA[Vk`4KYo10g2S
aPA[Wl84J9^m16ZM_`A/W/04KZ31172R``=bYLH4LjO817BXb0QeZLL4MJ[60gFZa@AeZ<<4MJO217JW
`PAfY/84MZS217N[a@=g[<H4N:_517NXa0AeY/84M:G217:T`@=aXl44L:C3172Wa`AaZ/d4L:W;16fR
``AZWK`3J9Re16FC[`ARSJT4GhRR15^3W0AHOYL3EGVA155dR`A>KhD4BVZ014MVN`A4HGH4@5e`5Ooo
o`005?ooo`A0G704@f1e14ITN@A9J7h4C6f30dmaR0ABMHd4EGVB15QmU`AKPI`4GXJQ0f6:YPATSZ/4
IY>a16VG]PA/W;`4Kj3217:Ub0=fZ/l4MJW>16nSa`A_X/D4L:;517:Ta@AdY/P3MZW;17V]c@Aj[/d4
NZk<17^^c0Ak[L/3NZ_817VU`PAiXKd4N9jj17RM^@AjX[h4O:S30gb[a`Al[LP4Njc817ZZa`AhZLL4
MjS60gFWa@AdYlL4M:W:17B/cPAd[Ll4LZ[;16nTa0=/W[`4JIRe16JB[PARS:L4GXNQ15Z1VP=GO9@4
DgJ>14maR0A<K884B6Ml14ARMPA1GG4Eoooo000Doooo141LL0A3H7D4AVAi14UXOPA<KH<3Cg68159e
S@AENI84F7fG15^1W0ANQZ43HHZV16B>Z`AVTk44JINf16bL_0A_X<84LZG80gJZc`AeZLh4Kj?716nR
a@A`X/D4LZC517BVb0=fZL/4NJg=17Z^c@Aj[/`4Njk<17^]b`=jZlP4NJG217VQ_@AhW[X4N9fi17ZR
_PAlZ<<3O:_717b]b0Ak[<P4NZ[717RYa`AgZ<H3MJO517BWa`AdZLX4M:c>17B]c`AbZ//4KjC40fbN
_0AYV;D4IY:^16:<Y`ANQj44FX6J0eMlU0ACMXh4Cg6814a/PPA8Ig`4A69f145MLAGoool001Coool4
@5a`14=PM@A6I7T4BFQn14a]P`=?LHP4DWF=15EiTPAHOIL4Fh6L15j6X@=QRZH4I8j[16JC/@AYUkH4
K9bl16nP`PAbYLP3MZ[?17FYcPA_XlL4Kj;5172Ra@AbY<D4M:K80gJYb`Ai[Ld4NZk=17Z^c0Ak[/`4
Njg;0gZ[b0AiYL84NJ6m17RN^PAhWKT4NZ:n17bX``=lZlL4O:g817^/b0AjZ/L4N:W717NXaP=eYlD4
M:O717BYbPAd[<h4M:g?17:Zb`A_Y<@3K9jl16VH]@AVTZh4HXbW15j7X@AJPIX3EgbD15=fSPA?LHP4
C6b214QWO0A4HWH4@Eea5Oooo`005?ooo`A0G704@f1e14ITN@A9J7h4C6f30dmaR0ABMHd4EGVB15Qm
U`AKPI`4GXJQ0f6:YPATSZ/4IY>a16VG]PA/W;`4Kj3217:Ub0=fZ/l4MJW>16nSa`A_X/D4L:;517:T
a@AdY/P3MZW;17V]c@Aj[/d4NZk<17^^c0Ak[L/3NZ_817VU`PAiXKd4N9jj17RM^@AjX[h4O:S30gb[
a`Al[LP4Njc817ZZa`AhZLL4MjS60gFWa@AdYlL4M:W:17B/cPAd[Ll4LZ[;16nTa0=/W[`4JIRe16JB
[PARS:L4GXNQ15Z1VP=GO9@4DgJ>14maR0A<K884B6Ml14ARMPA1GG4Eoooo000Doooo141ML0A4HGD4
AfEk14YZP0A>KhD3DG>;15AgT0AGO9D4FX2J15f4W`APRJD3HhfZ16JB/0AZUkH4KIbl172P`PAcYLP4
Mj_?0gBYc@AaYLT4LZG817>Vb0AdY/L4MZO817RZb`=j[Lh4OK7A17ncdPAo/m44PK?A182[b@=kXKh4
NIbh17JG/@AgVK<4NIjj17bM^PAnW[X3PJG118:]b@B1/<`4Ojk;17b]b@AjZlP3N:W717NYb@AgZl`4
N:k@17Rbe@Ah/M@4MJ_<0g6T``A^W[/4JINd16FA[0AQRZD4GHBN0eUnU`AENI04DG>:14e]P`A9J7d4
AF=g145MLAGoool001Coool4@5e`14AQM@A7IG/4BVZ014i_Q@=ALh/4E7N@15MlU@AJP9X4GHBO1629
Y@=SSJX4IY:`16ZG]PA]W;`4L:3217>Ub0AgZll3M:W=176Ub@AbYLP4LjK817BVa`AfYlP4N:[;0gZ]
cPAm/M44Ok?B17ncd@B1/m44P:_90g^Q_PAiW;P4MYNa17NI/`AiW[X4O9fj17jN^P>1YL44PZg9186`
c0Ao[//4O:g917Z[b0=hZLL4MjW917N[c0Ah[]04N;;E17Rae0AeZl`3LJC316jN^`AYUk@4II6/166:
Y@AMQ9h3FGjG15EiT0AALhX4CFf314UXO@A5HgL4@Eea5Oooo`005?ooo`A0GG04A65e14MUN`A:JX04
CVn50e5cR`ADMi04EgbE15Z0VPAMQ9l4H8VU0f>=ZPAVT[04JYNf16fL_0A`X<84LjG817N[c`=dZLd4
LJG917:Ub0AcY/P4M:K717JWb0AhZ//3NZg>17fad@Ao/m84Ok?A186cd@B0ZlT3Nj6n17VL^0AfUk44
MiVc17VN^PAlWKX4OYjj0h6U`@B2[LT4PK3<17n^b`Al[LT4NZ_80gRYa`AgZLT4Mj_<17R^d0Ah/]D4
N;7D17F[c0=aY<<4KYjk16VG]0AUTJ`4HHZU15f4WP=IOYL4EGV@155cRPA=KH<4BFQm14ESM`A1GG4E
oooo000Doooo141ML0A4HGD4AfEk14YZP0A>KhD3DG>;15AgT0AGO9D4FX2J15f4W`APRJD3HhfZ16JB
/0AZUkH4KIbl172P`PAcYLP4Mj_?0gBYc@AaYLT4LZG817>Vb0AdY/L4MZO817RZb`=j[Lh4OK7A17nc
dPAo/m44PK?A182[b@=kXKh4NIbh17JG/@AgVK<4NIjj17bM^PAnW[X3PJG118:]b@B1/<`4Ojk;17b]
b@AjZlP3N:W717NYb@AgZl`4N:k@17Rbe@Ah/M@4MJ_<0g6T``A^W[/4JINd16FA[0AQRZD4GHBN0eUn
U`AENI04DG>:14e]P`A9J7d4AF=g145MLAGoool001Coool4@Eea14ARMPA8Ig`4Bf^114m_QP=BM8`4
EWVB15UnU`ALPid4H8NS16><Z0=VTJh4JIJd16fK^PA`X<44M:G717NZc@Aj[]83NJc@27FWbPAfYlT4
MjS:17VYbPAjZ//3OJg>17n`d0B3]=@4Pjo>17^O_0AiVkL3NYZe17ZH/`AjV[H4NYVe17VG/`AhV;84
NY^f0gjQ_@B4ZLD4Q[3<18>ac@B1[l`4OZk;0gb/bPAk[</4NZg>17^`d@Ak/]@4O;?D17^ad@=gZl/4
LZC216fL^@AYUK04I8jX15n7X@=KPIT4Eg^B159eS0A>KhD4BVUn14ESN0A1GW8Eoooo000Doooo145M
L@A4HWH4B6Ml14][P@A?KhH3DWB<15IiTPAIOYL4G8>M1627X`ASS:P3IY6^16VF]0A]VkX4L:3117BU
a`AgZ/d4NZkB0gV/d0QeYlX4MZO917NXbPAiZLX4NZ[;0gf]cPAo/=04PkCD18>_cPAkWk`4NI^g0gZJ
]@AjV;<4NYZf17ZI]@AiUk<4N9Rb17ZK]P=nXKd4Q:W518J`c0B3/Ld4PJo<17j^b`=l[<X4Njc;17Z]
cPAk/=44Nk;D17bce0Ak/M43Mj_;17:T`PA]W;T4JIF`16B>Z0AOQj43Fh6I15MkTPABMH`4CVn514YY
OPA5HgP4@Eib5Oooo`005?ooo`A1GG44A69f14QWO0A;Jh44Cfn60e9dS0AFNI84FGjG15b3W@APQj<4
HhbX0fJA[PAYU[@4KI^j172P`@AdYLL4Mj[=17Z^dP=i[=08MJO:17JWb@AgZ<X4NJW:17ZZb`=m[Lh4
Ok3@18>de0B3[lh4Ninl17VK]`=jV[D4NYRc17ZJ]PAjVKD4NINc17RH/PAjVkH3OZ6m18BYa@B6/<`4
Pk7=186_c0An[//3O:c:17^/b`Aj[Lh4Nk3A17^be0Al/m@4Nk7A0gN[b`AbY<84KIbi16VE/0ATSZP4
GhNQ0e^1V@AGNi84DWF<14i_Q@A:JGh4AF=h145NLQGoool001Coool4@Eea14ARMPA8Ig`4Bf^114m_
QP=BM8`4EWVB15UnU`ALPid4H8NS16><Z0=VTJh4JIJd16fK^PA`X<44M:G717NZc@Aj[]83NJc@27FW
bPAfYlT4MjS:17VYbPAjZ//3OJg>17n`d0B3]=@4Pjo>17^O_0AiVkL3NYZe17ZH/`AjV[H4NYVe17VG
/`AhV;84NY^f0gjQ_@B4ZLD4Q[3<18>ac@B1[l`4OZk;0gb/bPAk[</4NZg>17^`d@Ak/]@4O;?D17^a
d@=gZl/4LZC216fL^@AYUK04I8jX15n7X@=KPIT4Eg^B159eS0A>KhD4BVUn14ESN0A1GW8Eoooo000D
oooo145ML@A5HWL4BFMl14a/PPA@LHP3E7J>15QkU0AKP9X4GhFP16::YPAUSj`3JIBb16bI^0A`W[l4
M:C617R[cPAl/=@4Nk3C0gZ]d0AhZL`4N:S;17VXb@AjZ<T4NjW917fZbP=oZ/X4OjW917nWa`AnYlH4
OJK417jT``=nXl84OZ?117jT``AoY<84OjG217jU``AlXl43NInl17^Q_@B2ZL@4Qk?>18Fdd0B2/Lh3
P:o=17j^c@An[ll4O[;B17jdePAo]]T4OkGH0gfbdPAgZLL4LJ2m16bH]0AWTJ`4HXZT0ef3W0AHOID4
E7J=14m`QPA:JWl4AVAi145NLQGoool001Coool4@Eea14ERM`A9Ig`4C6b2151aR0=DMXh4F7^D15^0
VPAOQJ04HXZV16F?[0=YU;84K9Vh172N_`AdY<H4N:_>17b`e0Ak/=<3NZg@17RYc0AhZ</4NJS917ZX
b@AkZLT4OJ[:0gnZbPAoZLT4OjO717jWaPAmY/@4OZC30gjS`PAnXl44OZC317nT`PAoYL84OZG317bS
`@=iWk`4Nj6m18:Ya0B7/lh4QKC@18:acP>0[ld4OZk=17j_c`An/]84O[CF17nff@Ao]MP3OK;B17NY
a`AaX;d4K9Rd16NA[0ARRZ@3GH>L15QmU@ADMXd4Cg2614YZO`A6I7T4@Eib5Oooo`005?ooo`A1GG44
AF9g14UWO0A<K884D7680eAfSPAHNi@4Fh2J15n5X0ARRZH4IHn/0fVD/PA/VKP4L9jo17BTaPAhZlh4
O;3D17^`d`=j[M04N:W<17RXb`AiZ<T4NZS917^Yb@AmZ/X3Oj[:17nYb@AoYlL4OZO617fVa0AnY<<3
OZ?217jS`@AnY<<4OjC217nU`PAnYL<4O:?10gVO_0AkXKd4PZW418NccPB5]=04P[7>0h2_c@An[/d4
OZo?17jbdPAn]=H4OkKI17nef0=m/]84MjW7176P_@A/V;@4Ii6/16::Y0=MPi`4F7fE15AfS@A?L8H4
BVYo14ITN@A1GW8Eoooo000Doooo145ML@A5HWL4BFMl14a/PPA@LHP3E7J>15QkU0AKP9X4GhFP16::
YPAUSj`3JIBb16bI^0A`W[l4M:C617R[cPAl/=@4Nk3C0gZ]d0AhZL`4N:S;17VXb@AjZ<T4NjW917fZ
bP=oZ/X4OjW917nWa`AnYlH4OJK417jT``=nXl84OZ?117jT``AoY<84OjG217jU``AlXl43NInl17^Q
_@B2ZL@4Qk?>18Fdd0B2/Lh3P:o=17j^c@An[ll4O[;B17jdePAo]]T4OkGH0gfbdPAgZLL4LJ2m16bH
]0AWTJ`4HXZT0ef3W0AHOID4E7J=14m`QPA:JWl4AVAi145NLQGoool001Coool4@Eea14ESM`A9J7h4
CVf4159cRP=FN944FWjG15f3W@AQR:<4IHfY16RB[`=[UkD4Kibk17:Q`PAfZ<X4O[;F18>ih0Al/=D3
MZS;17VYb`AkZ//4O:_;17fZbPAnZLT4OZS70gfT`PAkWKX4MiFb17VG]@AmWk`4P:;00h6Va0B2ZLL4
Pj[818>Zb@R3[L`4PZ_90h2XaPAnZ<D4OZS418B_b`B8]M44QK?@0h>bc`B2/M04PK;B18:ce0B2]MH4
PKOI182ff0=n/]<4NZc;17FT`@A_VkP4JIB_16B<YP=OQIh4FWjF15EhS`A@LHP4Bf^014IUN@A2GW8E
oooo000Doooo145ML@A5HgL4BFQn14i]Q0ABLhX3EWRA15YnU`AMPid4HHRS16F=Z@AXTZl3JiNe16nL
^`AbXL84MZS:17jbePB3^N04O;3E0gJXb`AiZL/4Nj[;17b[b`AmZ/X4OZW917jXa`=mY<84Nifj17NE
/PAiUkD4OInl182R`0>1Y/@4PZW718>Zb0B3Z/T8Pjg<18:[b@>0Z<H4OZS517jXa0B4[l/4R;GA18Fc
d0>3//l4P[7@186bdPB2/m@4P[GF186gf@B0]]P3O[;C17Z/b`AeY<44Ki^h16VD[`ATS:H3GhFN15Yn
UPAEN8l4D76814][P0A6IGT4@Uib5Oooo`005?ooo`A1GG44AF=g14UXOPA>KH@4DW>:0eIhT@AJOYL4
GH>M1668X`AUSJT4J9:_0f^G]@A_W;/4LZ7217JXbPAn/]H4PkWP17b`e@=fZ</4NJW;17^Zb`AlZl/4
OJ[:17jYb@AnZ<L3OJC217^M^PAgUK84NINe17fO_0B0X/03PJK418:Ya`B3Z/P4Pj[928>]c0B2ZlT3
P:S617jXa@AnZ<@4Q:o;18Red@B5/m03Pk;?18:ad0B1/]84P[?D18:eePB1]mT4P;KH0gjbd`Aj[</4
MJC116nK^0AYU:l4I8bV0en5WPAJOYH4EGR?151aR0A;Jh04AVEi149NLQGoool001Coool4@Eib14IS
N0A:JGl4Cfn515=eS0=GNi<4G82I1625X0ATRjH4Ii2]16^E/`=^V[T4LIno17>Sa0AfZ</4NJg@17Z]
d@AhZ</3MjK817^YbPAmZlX4Oj_9182Zb0B1Z/P4PJS50h6Wa0B1Y<44Oink182M^PB1W[/4PYnl0h>P
_@B3XKl4Q:;118BS`@B4X/44Q:?318BWaP>3ZLL4PJW7182Ya`B0Z/L4QJo<18Rdd0>6/m04QK?A18Bc
dPB4]M@4Q;OG18FifPB8_^43Q[[L17f^cPAhY/@4LIjj16bF/@AVSZP3HHNP15b0V0AFNI04DG:914a/
P@A7IGX4@Umb5Oooo`005?ooo`A1GW84AV=h14YYO`A?KhD4DgF<0eMkT`ALP9T4H8FP16B;YPAWT:d4
JiFc0fjJ^@AaWkl4Lj?417JXb`Ai[M04NZgA17RXb`=gY/P4NjW:17f[bPAoZlT4P:[8186Zb0B1Z<D3
PJO4186T`@AoWk/4P9fj186N^`B2Wk`3Pj2m18>Q_`B4X/44Q:?118BR`@B4Xl<4Q:O60h>Ya`B1ZLL4
P:W7182Za`B5[l`4R;C@0hJcd0B5/m44Q;?B18Bee0B4]mL4QKWJ18Rnh@>6^]`4OJk>17RVa0AaW[X4
K9Ja16J>Z0=QQj04G82H15IiT0AALXT4C6b114MUNPA2Gg8Eoooo000Doooo145NLPA6HgP4BVUo14m_
Q@ACMH`3Eg^C15b0V@APQJ04I8^V16N@[@A[UK<3KYZi176O_`AcXl@4MZS;17V]d0Aj[M44N:S;0gNV
b0AkZLX4OJ_:17n[b@B0Z/P4PJ[8186Xa@>1Yl@4PJC117nO^`B0WKX4PIjk18:O_0>3X;d4Pj6o18BR
`@B4Xl44Q:;118BS``B4YlH3PjW7186Ya`B0ZLL4P:[718F_c0B8]=03Q[?@18Fcd@B4/m84Q;GD18Bg
e`B5^MX4R;kQ0hJjg0Am[/h4N:K4176N^PA/U[44IXjX0f67X0ALP9P4EWV@155bR@A<K844AfEj149O
LQGoool001Coool4@Eib14ISN0A:JGl4Cfn515=eS0=GNi<4G82I1625X0ATRjH4Ii2]16^E/`=^V[T4
LIno17>Sa0AfZ</4NJg@17Z]d@AhZ</3MjK817^YbPAmZlX4Oj_9182Zb0B1Z/P4PJS50h6Wa0B1Y<44
Oink182M^PB1W[/4PYnl0h>P_@B3XKl4Q:;118BS`@B4X/44Q:?318BWaP>3ZLL4PJW7182Ya`B0Z/L4
QJo<18Rdd0>6/m04QK?A18BcdPB4]M@4Q;OG18FifPB8_^43Q[[L17f^cPAhY/@4LIjj16bF/@AVSZP3
HHNP15b0V0AFNI04DG:914a/P@A7IGX4@Umb5Oooo`005?ooo`A2GW84AfAi14]ZP0A@L8L4EGJ>0eUl
U0ANPY/4HXRR16J>Z@AZTk04KYVf0g6N_@AdX/84MJG717BVb0A]Wl84J9Zm17:Qa0=kZ<X4Oj[;186Z
bPB2ZlT4Pj_818BYaPB4Yl@3Q:O318FXa@B6YlD4QZG218JT`@N7YL84R:K318RWa0B9YlD8RJS618VY
a`>9Z<L4QjG418BS`@B1XKh4PZC018J[b0>8/Ll4Qk?@18NddPB7]M@4QkKF18Nhf0B6^=P3QkSH186a
d0AjZ<D4M:2l16jH/`AXT:X3HhVR15f1V@AHNY44DW>:14e/PPA8IWX4@Umc5Oooo`005?ooo`A2GW84
AfAi14]ZP0A@L8L4EGJ>0eUlU0ANPY/4HXRR16J>Z@AZTk04KYVf0g6N_@AdX/84MJG717BVb0A]Wl84
J9Zm17:Qa0=kZ<X4Oj[;186ZbPB2ZlT4Pj_818BYaPB4Yl@3Q:O318FXa@B6YlD4QZG218JT`@N7YL84
R:K318RWa0B9YlD8RJS618VYa`>9Z<L4QjG418BS`@B1XKh4PZC018J[b0>8/Ll4Qk?@18NddPB7]M@4
QkKF18Nhf0B6^=P3QkSH186ad0AjZ<D4M:2l16jH/`AXT:X3HhVR15f1V@AHNY44DW>:14e/PPA8IWX4
@Umc5Oooo`005?ooo`A2GW84AfAi14]ZP0A@L8L4EGJ>0eUlU0ANPY/4HXRR16J>Z@AZTk04KYVf0g6N
_@AdX/84MJG717BVb0A]Wl84J9Zm17:Qa0=kZ<X4Oj[;186ZbPB2ZlT4Pj_818BYaPB4Yl@3Q:O318FX
a@B6YlD4QZG218JT`@N7YL84R:K318RWa0B9YlD8RJS618VYa`>9Z<L4QjG418BS`@B1XKh4PZC018J[
b0>8/Ll4Qk?@18NddPB7]M@4QkKF18Nhf0B6^=P3QkSH186ad0AjZ<D4M:2l16jH/`AXT:X3HhVR15f1
V@AHNY44DW>:14e/PPA8IWX4@Umc5Oooo`005?ooo`A2GW84AfAi14]ZP0A@L8L4EGJ>0eUlU0ANPY/4
HXRR16J>Z@AZTk04KYVf0g6N_@AdX/84MJG717BVb0A]Wl84J9Zm17:Qa0=kZ<X4Oj[;186ZbPB2ZlT4
Pj_818BYaPB4Yl@3Q:O318FXa@B6YlD4QZG218JT`@N7YL84R:K318RWa0B9YlD8RJS618VYa`>9Z<L4
QjG418BS`@B1XKh4PZC018J[b0>8/Ll4Qk?@18NddPB7]M@4QkKF18Nhf0B6^=P3QkSH186ad0AjZ<D4
M:2l16jH/`AXT:X3HhVR15f1V@AHNY44DW>:14e/PPA8IWX4@Umc5Oooo`005?ooo`A2GW84AfEj14a[
P@AALXP4EWR?0e]nU`APQIh4IH^U16VA[@A]Uk@4LIbj0gFR`@AgY/L4NJW;17RZc`AfZLd4MjO917^Y
bP>0[Ld4Pjk=18F]b`B7[<T4R:_718R[aPN8ZLD4RZc818^^b`B;[<T4Rj[71hbZa`B<ZLL4SJ[718j/
bPb>[L/3SJc:18b[b@B9Z/L4R:S618NYa`B8[<P3RK3;18Zcc`B9]M84RKKC18Rge@B8^=L4R;WI0hRh
ePB2/Ll4O:[717JR_PA`V[D4JY:/0fB:X`ANPi/4FG^B15=dRPA>KH<4B6Ik149OLaGoool001Coool4
@Uib14MUNPA<Jh44DG:815IhS`=KOYL4H8FN16F;Y@AYTJd4KINd176L^P=eX/44MjK717VYb`AhZ/l4
MZW=17NWb@AkZLX3P:g=18>^c@B5[L/4Qjc918R[a`B8ZlH7R:W518Z/b0B;[//4Rjc918^Za`N<Z/L4
S:W718fZa`B>[<X<SZg;0hf/bPB<ZlT4RJ[718RXaPB7ZLL4R:c80hV`b`B:/ll4RKGB18Vfd`B8]mD4
R;SG18Rif@>8^=H4P[7?17bZa`AfX[h4L9Ze16ZB[0=TRZ<4GX>K15UkTPACM8X4CVf314QVN`A2Gg<E
oooo000Doooo149NLPA7IGX4C6^1155bR0AFN8l3FgjG1625WPAURjD4JI6]16fG]0AaW;X3MJ;117NV
a`AiZL/4N:[?17JYc@AgYlT4NjW:0h2]c@B3[/d4QJg;18N/b@B8ZlL4R:_61hRYa@B:[<P4Rjk;18^/
b@B;Z/L7S:[718bYa`B=Z/L4SZc:38j]b`>=[<X4S:_918VZa`B8Z<H4QjW718R/b0>9/</4R[??18Ve
dPB9]]<4R;OE18Rhe`B8^MT3R;SF18:ac`AlZ/L4MZ:n172J]@AZTZ`3I8ZS15j3V`AINi84DgB:14i]
P`A8IW/4@Umc5Oooo`005?ooo`A2GW84AfEj14a[P@AALXP4EWR?0e]nU`APQIh4IH^U16VA[@A]Uk@4
LIbj0gFR`@AgY/L4NJW;17RZc`AfZLd4MjO917^YbP>0[Ld4Pjk=18F]b`B7[<T4R:_718R[aPN8ZLD4
RZc818^^b`B;[<T4Rj[71hbZa`B<ZLL4SJ[718j/bPb>[L/3SJc:18b[b@B9Z/L4R:S618NYa`B8[<P3
RK3;18Zcc`B9]M84RKKC18Rge@B8^=L4R;WI0hRhePB2/Ll4O:[717JR_PA`V[D4JY:/0fB:X`ANPi/4
FG^B15=dRPA>KH<4B6Ik149OLaGoool001Coool4@Umc14QVNPA=K884Dg>:15QjT@=MP9T4HhNQ16R>
Z0A/U;04LI^h17FQ_`=iY/H4O:_<17j`dPB0/]D4PK?F18>de`B5]=D3Qk?A18Rbd0B:/Lh4Rk3<18b_
b`B=[/X7SJg818f]b@B?/<d4T;7>192`c@B@/<`3TK3<196_c0BA[l/4TZo;19:ac@BB//d4TK7<0i2`
b`B?[LT4SJc718^[a`B;[<L4Rjk90hbac0B<]<l4S;GA18ZedPB9]]<4R;KD18NgeP>:^]X4Q[GE17n/
bPAhXl04LY^f16bC[@=VRj@4H8BL15YlT`ADMH/4CVj314UWN`A3Gg<Eoooo000Doooo149OL`A8IWX4
CFb215=cRPAHNY43GH2I16>7X@AXSZP4K9B`176K^0AeXKl3NJK617b[c0An/=84P;;E186cePB3]=L4
QKCE0hNcd@B8/]04R[7>18^`c0B<[l/4SJk:1hf]b0B=[LT4Sk3=192acPB@/<d4T;3<0i6`c0BA[l`4
TJo;19:_b`BB/Ld4T[;=196ac0>@/</4Sjg918f/a`B;ZlL4Rjc718^^b@></L`4S;C?18bed@B:]M84
RKKC18Rfe0B7]mH3R[[J18Jee@Ao[<X4N:?017:K]PA/Tjd3IX^T1624W0AJO9<4E7F;14i^P`A9Ig/4
@emc5Oooo`005?ooo`A2Gg<4B6Ij14e/PPACLhX4F7ZA0ef0V@ASQj44J8jX16bD/0AaVkP4MJ6o0gVV
aPAlZl`4O[3B182be@B1/mH4PkCG18Fde@>7/m44R;;@18ZacPB;/<`4S:o;18f^bPN=[LP4SJg918n`
c@B@/Lh4T;3=192`c0>A/<`4TJo<196_b`BB[l/4T[7=19:bc@BA/L`3T;3;18n]b@B=[<L4Rj_718^/
a`B;[/T3S;7<18bdc`B<]M44R[GB18Vfd`B8]]@4QkOF0hZjfPB6]MD4Ojc:17RS`0AbVkH4K9>]0fJ;
Y0APQ9`4FWbC15AeR`A>KX<4BFMk14=OLaGoool001Coool4@Umc14QVNPA=K884Dg>:15QjT@=MP9T4
HhNQ16R>Z0A/U;04LI^h17FQ_`=iY/H4O:_<17j`dPB0/]D4PK?F18>de`B5]=D3Qk?A18Rbd0B:/Lh4
Rk3<18b_b`B=[/X7SJg818f]b@B?/<d4T;7>192`c@B@/<`3TK3<196_c0BA[l/4TZo;19:ac@BB//d4
TK7<0i2`b`B?[LT4SJc718^[a`B;[<L4Rjk90hbac0B<]<l4S;GA18ZedPB9]]<4R;KD18NgeP>:^]X4
Q[GE17n/bPAhXl04LY^f16bC[@=VRj@4H8BL15YlT`ADMH/4CVj314UWN`A3Gg<Eoooo000Doooo14=O
L`A9IW/4CVf315AdR`AJO9<3H8>K16F:X`A[TJ/4L9Rd17FO_0AjYL<3OZc;18:adPB4]mT4Qk[M18Vk
g@B;^m`4RkWJ0hbhe`B>]mD4SkKC196edPBA]=04T[??19:ac@>B/<`4Tk7=19Bcd0BE]M44UKC@19Fb
cPNE//d4UK;<19Fbc@BF//d8UK;=0iBbc0BC/L/4TJo818n]aPB>[<D4SZk70hnbc0B?]<h4S[C@18be
d@B:]M84QkCB18BcdP>8^MT4RKWH186_c0AjYL44Libg16fD[P=WS:D4HHFL15]mU0AEMX`4Cfj414UW
N`A3H7<Eoooo000Doooo14=OL`A9IW/4CVf315AdR`AJO9<3H8>K16F:X`A[TJ/4L9Rd17FO_0AjYL<3
OZc;18:adPB4]mT4Qk[M18Vkg@B;^m`4RkWJ0hbhe`B>]mD4SkKC196edPBA]=04T[??19:ac@>B/<`4
Tk7=19Bcd0BE]M44UKC@19FbcPNE//d4UK;<19Fbc@BF//d8UK;=0iBbc0BC/L/4TJo818n]aPB>[<D4
SZk70hnbc0B?]<h4S[C@18bed@B:]M84QkCB18BcdP>8^MT4RKWH186_c0AjYL44Libg16fD[P=WS:D4
HHFL15]mU0AEMX`4Cfj414UWN`A3H7<Eoooo000Doooo14=OL`A9IW/4CVf315AdR`AJO9<3H8>K16F:
X`A[TJ/4L9Rd17FO_0AjYL<3OZc;18:adPB4]mT4Qk[M18Vkg@B;^m`4RkWJ0hbhe`B>]mD4SkKC196e
dPBA]=04T[??19:ac@>B/<`4Tk7=19Bcd0BE]M44UKC@19FbcPNE//d4UK;<19Fbc@BF//d8UK;=0iBb
c0BC/L/4TJo818n]aPB>[<D4SZk70hnbc0B?]<h4S[C@18bed@B:]M84QkCB18BcdP>8^MT4RKWH186_
c0AjYL44Libg16fD[P=WS:D4HHFL15]mU0AEMX`4Cfj414UWN`A3H7<Eoooo000Doooo14=OL`A9IW/4
CVf315AdR`AJO9<3H8>K16F:X`A[TJ/4L9Rd17FO_0AjYL<3OZc;18:adPB4]mT4Qk[M18Vkg@B;^m`4
RkWJ0hbhe`B>]mD4SkKC196edPBA]=04T[??19:ac@>B/<`4Tk7=19Bcd0BE]M44UKC@19FbcPNE//d4
UK;<19Fbc@BF//d8UK;=0iBbc0BC/L/4TJo818n]aPB>[<D4SZk70hnbc0B?]<h4S[C@18bed@B:]M84
QkCB18BcdP>8^MT4RKWH186_c0AjYL44Libg16fD[P=WS:D4HHFL15]mU0AEMX`4Cfj414UWN`A3H7<E
oooo000Doooo14=PL`A9Ig`4Cfj415IfS0ALOID3HXFM16R<YPA^U:l4M9^g17VS`0AoZ/P3Pk7A18Rh
f@B<_]l4Sl;T19;3i@BB`>44TKgL0i:lfPBD^mT4UK_H19JjePBG^]D4V;WE19Rhd`>H]]44V;G@19Vf
d@BJ]m<4V[SD19Zgd`>I]m88V[KA19ZgdPBK]m44V[K@19Vec`>H/ld4Uk?=19Jbb`BD/<P4Tk3819>a
bP>C/l`4T[C>196fd0B?]]44S;G@18NbcPAn[</3O:g<18Bdd`B4/Lh4NjG017FM]`A_UJh3JHfV16>6
W@ALOYD4EWJ<151_Q0A:Ig`4@f1c5Oooo`005?ooo`A3H7<4BFMl14m^Q0AFMX`4G7fE0f:5W@AXS:H4
KYB_17BK]`AiXl04Oj[80h>ad@B8^=T4S;kO18o2i0BB`nD4T/3Q196mg0>B_=X4U;_I19Fkf0BF^]H4
Uk[E19Rie@BH^=<3V;KA19Red0BI]]44V[OC19Zhe0BJ]m<3VKOB29Zfd@BJ]m84VkOA19Zfd0BI]Ll3
V;?=19Ncc@BF///4U;3819>`b0BC/LX3Tk?<19:dcPBA]]04SkKA18bed0B7//h4OZc;0gb]c0B4]=<4
Q;7>17^U`0AeWKL4KiF^0fV=YPASQYd4G7jE15IfS0A@Kh@4BVMl14=PLaGoool001Coool4@f1c14UW
O0A?KX@4EWJ<15amU@=RQId4J8bV16jD[`AdVkL4NJ?017nZb0>3/M44R;SI18bng`B?`^@4T/?U19;0
h@BA_M`3T[cJ19Bkf@BE^mP4U[[F19Nje@BH^MD4V;SC0iRfd@BH]M04VKKA19Zgd`BJ^=@4V[OC0iVg
dPRJ]]44V[OB19^gd@BJ]]04VKG?0iRcc@BG/ld4U[;;19B`b0BC/<P4Tk7:0i>cc0BB]<h4TKK@18nf
d@B<]M04Qk;>17j/b`=l[L`4Q;CC18BacPAkYL04MIfg16nE[P=YSJH4HhJM15anU@AFMX`4D6n414YW
O0A3H7<Eoooo000Doooo14=PM0A:J7`4DFn515MgSPANOiL3I8NP16^?Z@AaUk84N9nk17jWa0B4[ld3
R[OG18o0h@BDb>T4V<c]19W:j@BIaN<4V/7P0iW0gPBJ`=d4Vl3M19c0g@BM`=`4WL3K19jofP>N_]P4
W[cF19fje0BN^]@4W[_E3ijlePBO_=H4Wk_E19nke0BO^]<3W[SA19fgcPBK]<`4V[C<19Vec@BH]/h3
V;S@19NidPBE^M84T[SB18ngdPB:]<l4Q:o;0gfYa@AhXkl4NJ>n17ZS_PAfWKL4L9J_0fZ>YPATQih4
GWnE15MgS@AAKh@4BVQl14=PM1Goool001Coool4@f1d14YXO0AAKhD4EgN>15ioU`=TQj04JhnY176G
/PAhWk/4OZO418B_c@>:]mL4Sl3Q19C8j@BHc>d4VL[Y19W5h`BJ`N03VL3N19[0g@BK`=d4W<3M19g0
g0BM`=/4W[oJ0ijnf0BN_=H4WK[D19jje0BN^mD?W[cF19nlePBO^mD4Wk_D19njd`>N^=44WKO>19^d
c0BJ]<`4VKG=19RfcP>H^=04UkWB19FidPBB^=84SkOB18Zdc`B4[l/3OJW517RS_`AiXkh4NZ>n17JM
]`A`UZl3JXjV16B7WPANOiD4EgN=155_Q0A:J7`4@f1d5Oooo`005?ooo`A3H7@4BVQl155_Q@AGMhh4
GWnG0fB7X0A[SjT4LINb17RO^`AnYl@4Q:o=0hZge`B?`>44U<SY19S<k@BIb^T4VLGS19[1h0>I`=h4
V/3M19_0g@BL`=d4WL3L19g0f`BN_mX3W[kH19jlePBM^]@4W[[D19jke@nN_=H4WkcF19nke@BO^m@4
Wk[C0ijhd@BM]lh4VkC<19Zdc0BI]Ld4V;K>0iRhd0BG^M84UKWB19:hdPB?]m84R[C?18B_b`=mZLD4
N:>o17VS_PAjXkh4MYfg172F[`=ZSZH4I8NN15ioU@AGMhd4DFn414YXO0A3H7@Eoooo000Doooo14=P
M0A:J7`4DFn515MgSPANOiL3I8NP16^?Z@AaUk84N9nk17jWa0B4[ld3R[OG18o0h@BDb>T4V<c]19W:
j@BIaN<4V/7P0iW0gPBJ`=d4Vl3M19c0g@BM`=`4WL3K19jofP>N_]P4W[cF19fje0BN^]@4W[_E3ijl
ePBO_=H4Wk_E19nke0BO^]<3W[SA19fgcPBK]<`4V[C<19Vec@BH]/h3V;S@19NidPBE^M84T[SB18ng
dPB:]<l4Q:o;0gfYa@AhXkl4NJ>n17ZS_PAfWKL4L9J_0fZ>YPATQih4GWnE15MgS@AAKh@4BVQl14=P
M1Goool001Coool4A61d14]XO@ABL8H4FGV?1621V0=WRJ84KY:[17FJ]@AlXkh4Pjc818ZddP>@_M`4
U/GU19_;j`BNc>/4Wl_Y19k8iPBNa^<3WlGQ1:34h0BPaN44X/KR1:?6hPBTa^84Y<KQ0jC5g`BT`md4
Xl;K1:?0f@BS_mL?X[gF3:>nePBS_M@3X[[A1:2hc`BO]lh4WkW@19njd@BN^m83WKcC19ble0BJ_=@4
UkcD19Bjd`B@^=44RkG?0hNac0B3[LP4P:W417fU_`AhWkP4LYN`0fb@Y`AVR9h4Gh2F15QhS@AAL8D4
BfQl14APM1Goool001Coool4A61d14]XO@ABL8H4FGV?1621V0=WRJ84KY:[17FJ]@AlXkh4Pjc818Zd
dP>@_M`4U/GU19_;j`BNc>/4Wl_Y19k8iPBNa^<3WlGQ1:34h0BPaN44X/KR1:?6hPBTa^84Y<KQ0jC5
g`BT`md4Xl;K1:?0f@BS_mL?X[gF3:>nePBS_M@3X[[A1:2hc`BO]lh4WkW@19njd@BN^m83WKcC19bl
e0BJ_=@4UkcD19Bjd`B@^=44RkG?0hNac0B3[LP4P:W417fU_`AhWkP4LYN`0fb@Y`AVR9h4Gh2F15Qh
S@AAL8D4BfQl14APM1Goool001Coool4A61d14]XO@ABL8H4FGV?1621V0=WRJ84KY:[17FJ]@AlXkh4
Pjc818ZddP>@_M`4U/GU19_;j`BNc>/4Wl_Y19k8iPBNa^<3WlGQ1:34h0BPaN44X/KR1:?6hPBTa^84
Y<KQ0jC5g`BT`md4Xl;K1:?0f@BS_mL?X[gF3:>nePBS_M@3X[[A1:2hc`BO]lh4WkW@19njd@BN^m83
WKcC19ble0BJ_=@4UkcD19Bjd`B@^=44RkG?0hNac0B3[LP4P:W417fU_`AhWkP4LYN`0fb@Y`AVR9h4
Gh2F15QhS@AAL8D4BfQl14APM1Goool001Coool4A61d14]XO@ABL8H4FGV?1621V0=WRJ84KY:[17FJ
]@AlXkh4Pjc818ZddP>@_M`4U/GU19_;j`BNc>/4Wl_Y19k8iPBNa^<3WlGQ1:34h0BPaN44X/KR1:?6
hPBTa^84Y<KQ0jC5g`BT`md4Xl;K1:?0f@BS_mL?X[gF3:>nePBS_M@3X[[A1:2hc`BO]lh4WkW@19nj
d@BN^m83WKcC19ble0BJ_=@4UkcD19Bjd`B@^=44RkG?0hNac0B3[LP4P:W417fU_`AhWkP4LYN`0fb@
Y`AVR9h4Gh2F15QhS@AAL8D4BfQl14APM1Goool001Coool4A61d14]YOPACLHL4FWZ@1663VP=YRj@4
LIB]17RM^0B0Yl84R;3<18nje`>Ga><4Wl_/1:C>kPBWcnh4Ylk/1:K<j@BUb^L3YL[U1:G9i@BVb^H4
Yl_W1:W=j0BZcNT4ZlgW0j_=iPB[bn@4Z/WQ1:W6g`BXa=d4Yl;K0jK1f@BV`=L8Y/3H1:K0e`BV_mH4
Y[kD0jJmd`BU_M<4Y[kD1:Foe@BU`=H4YL3G0j?0e`BQ`=L4WkoG19fne`BJ_MH4Uk_E19:idP>>]m44
S;KA18Rbc0B1ZL84Nj6i17FI/@=^TJP4IhVO1621UPAIN8h4DW2514]XO0A4H7@Eoooo000Doooo14AP
M0A;JGh4Dg6715YjT0AQPiX3JH^T176D[@AhWKP4P:O218R`c0B?^]L3UlCS19o;k0BTc^h4Ylo^1:O>
k0BVc>T4YL[W0jG:i@BUbND4Y/[V1:O;i`BYcNP4Z/gY1:_=i`>[cNH4Zl_T1:[9h@BYa]l4Z<CM1:O2
f`>V`MT4Y/3G2:K0f0BV`=L4Y[oF1:Jne0>V_M<4YKgC1:Jne0BU_mD4YL3F1:G0e`>S`=L4XL3G19no
e`BM_]L4V[gF19Nke@BB^M83S[OA18bfd@B8//`4PJW217^Q^@AeVK43KY6X16N9W`APPIH4FGR>159`
Q@A;J7`4A61d5Oooo`005?ooo`A4H7@4BfUn15=aQ`AJNY04HH>J0fV;Y0AaU:d4N9fh182W`PB8/<`4
Sk[G0iO4h`BObn`4Y<k^1:O?kPBWc^`4Y/cY1:G:i`>Ub^D4YLWU1:K:iPBWbnL4ZLgX1:[=j@B[cNL3
ZlgV1:_;i0BZbN44ZLKO1:S4g@BW`]/3Y/7I1:K0e`RV`=P4Y/3G1:JoePBV_]@3Y[gC1:Fmd`BV_]@4
YKoE1:G0ePBU`=L3Xl3G1:70e`BO_mL4WKkG19ZmePBG^mD4T[WB0hjgd@B<]]44R;;<186Y`PAkXKT4
MIVa0fjAZ0AWRIl4H86F15UhSPABL8D4BfQl14APM1Goool001Coool4A61d14]YOPACLHL4FWZ@1663
VP=YRj@4LIB]17RM^0B0Yl84R;3<18nje`>Ga><4Wl_/1:C>kPBWcnh4Ylk/1:K<j@BUb^L3YL[U1:G9
i@BVb^H4Yl_W1:W=j0BZcNT4ZlgW0j_=iPB[bn@4Z/WQ1:W6g`BXa=d4Yl;K0jK1f@BV`=L8Y/3H1:K0
e`BV_mH4Y[kD0jJmd`BU_M<4Y[kD1:Foe@BU`=H4YL3G0j?0e`BQ`=L4WkoG19fne`BJ_MH4Uk_E19:i
dP>>]m44S;KA18Rbc0B1ZL84Nj6i17FI/@=^TJP4IhVO1621UPAIN8h4DW2514]XO0A4H7@Eoooo000D
oooo14AQM@A<JGh4E7:815]kT@ASQ9/3JhfU17>G/0AlX;X4Q:[518bdd0BE_]/3Wl[X1:WDm0BafOP4
]=We1;7Dl0B]dN`4ZloZ1j[>j@B[c^X4[<o[1:k@j`B`d^`4/]?/0k;Bj`Bad>P4/<gV1:k;i0B]b>04
ZlKM0j[3f`BY`MT8ZL7H3:[2f0>Z`]L4Zl?H1:c4f@B]aM/4[<GK1:_4fP>Ya=X4Z<;I1:K1f0BS`MP4
X<7H19g0f0BJ`=T3U[kH19:le`B<]m84QZc517nS^`AhVk83LI:Y16V:X0ARPIL4FgV>15=aQ@A<JG`4
A61d5Oooo`005?ooo`A4HGD4C6Un15AbR0AKNi44HhBK0f^=Y@AcUk04O:2j18BZa@B<]=04UKkK0io:
j0BYe?@4/MWh1;CIm@Bae?04[M7/1:_?jPNZc^T4ZlkZ1:c?j`B^d>/4/=;/1;;Ck0>bd^/4/M3X1;3=
iPB^bn@4[LSP1:_6g@>Z`m/4ZL7I2:W1f0bZ`]P3Z/;G1:_3f0B/a=T4[LGK1:c5f`B[a=X3ZLCJ1:S2
f@BV`MP4Xl7H1:31f0BM`=P4V/3I0iJnf0BB_=L4S;OB18J/a@AoXk/4N9^b0g6BZ@AYRZ04HX6G15]i
SPACLHD4C6Ul14APM1Goool001Coool4A65e14aYOPADLXP4Fg^A16>4V`=[SJD4LiN`17bP^PB4Z/D4
S;C@19Fnf`>Ob^P4ZMCd1;7In0BdfOD4/MC`1:gAk0B[cnX7Z/kY1:_>jPB/cn/4[]3[1;3Bk0Bbdn`3
/];[1;7@j0B`cNH4[/_T1:g8h0B[a]d3Z/?K1:W1f@RY`MP<Z/;H0j[2e`B[`mP4[<CI1:g5f`B/aM/4
ZlCJ0jW4fPBX`]T4Y/7H1:?1f0BP`MP4WL3H19[0f@>F_]P4T[cG18bgdPB6[<D4Oj>k17RK/P=aTZT4
JHZP16:1U`AKNHh4Dg6514aYO0A4H7@Eoooo000Doooo14AQM@A<JGh4E7:815]kT@ASQ9/3JhfU17>G
/0AlX;X4Q:[518bdd0BE_]/3Wl[X1:WDm0BafOP4]=We1;7Dl0B]dN`4ZloZ1j[>j@B[c^X4[<o[1:k@
j`B`d^`4/]?/0k;Bj`Bad>P4/<gV1:k;i0B]b>04ZlKM0j[3f`BY`MT8ZL7H3:[2f0>Z`]L4Zl?H1:c4
f@B]aM/4[<GK1:_4fP>Ya=X4Z<;I1:K1f0BS`MP4X<7H19g0f0BJ`=T3U[kH19:le`B<]m84QZc517nS
^`AhVk83LI:Y16V:X0ARPIL4FgV>15=aQ@A<JG`4A61d5Oooo`005?ooo`A5HGD4CFYn15AcR0AMO984
IHFL0ff?Y`AfVK84Oj>m18R^b0BA^=<4V/;N0j?<j@B_eo<4]mcg1;[LmPBif_<4/mG^1;7Bk0N_d>/4
/=3[1;7Bj`Bde>`4]]G]1;SFkPNif>l4]mG]1;CAj@BacN@4[lSO0jg5g0B/a=X4[<?I2:g4fPB^aM/4
/<KK0k37f`Bbb=d4]<[O1;C;g`Bcbn04//_P0k39gPB^amd4ZlKL1:W5f`BVa=/4Y<CL1:;3f`>O`m`4
VL3H19:hd@B:[lH4PZFl17^L/P=cTjT4Jh^P16>2U`ALNXh4E76514aYO@A5H7@Eoooo000Doooo14EQ
M@A=JWh4E7>815elTPAUQI`3KHnW17JI/PAoXkd4R:k8196hd`BJ`]h3XlcY1:oGl`Bgg?L4^]cf1;WJ
l`BceNh4/M;/1jo@j`B`d>/4/M;[1;CDk0BfeNd4^=K^1kWHk`BgeNd4]=7Y1;7=i0B_b=l3[LGL1:c4
fPB/`mT8[LCJ1:k5f`B`a]/3/<OK1;;8g@Bdb]l4]<_O1;?;h0Bbbn03/<WN1:k7g@B[a]`4ZLGK1:K4
f`BTa=`4X/?K0io3g0BI`=P4T[SA18Z_aPB2YK`4Nibb0g>CZ@A[Rj04Hh:G15ajSPADLHD4C6Um14EP
M1Goool001Coool4AF5e14eZOPADLhP4GGbB16F5W0=]SjL4MYVb17nS_@B8[/P4TKSC19[2gP>Sc>T4
[mOc1;OLm`Bjg?H4^M[c1;?EkPBad^`7[m3[1;3@j`Bad^/4]=C/1;KEk@Bhe^h7^MS_1;OEk@BddNT4
/LgT1:o8g`>]aM`4[<CJ1:c3f@R]a=X4[/GK1;36f`>`am/4//SM1;C:g`Bdbml4/l_P1;;;h0>`bMh4
[/OM1:_6g0BYaM/4Y/CK1:C4g0BR`m/3Wl?L19W0f0BB^=44RZo618:U_0AkW;83Li>Y16^;X0ASPYL4
G7Z>15AaQ@A<JGd4AF1d5Oooo`005?ooo`A5HGD4CFYo15EcR0ANOI<4IXNM0fnAZ0AiVk<4PjJo18ba
b`BF_=H4WlKQ0jO=i`B]d^/4]]Sa1;_Km0Bkf_84]mK_1;GDk@>cd^/4/]7Z1;?Bj`BfeNh4^]Wb1;kL
m@C1g_H3`Mgd1;kKlPBlfO04^MK/1;G@iPBab^03[lKK1:k4f@B^`mP4[l?J1;35f`Bbam`4]<WM0kO;
g`BicN44^/oS1;[?i0Bjcn<4^<kS0kG<h@Bbbml4/LWN1:k8g@B/amd4Z/OM1:S8g@>Vb=h4X<?J19Nk
dPB>/<L4QZNm17jN/`=eUJX4KHbP16F3U`AMNXh4EG:514eYO@A5HG@Eoooo000Doooo14EQM@A=JWl4
EG>815imT`AVQid3Ki6X17VK/`B3Y[l4S;7;19JlePBOa^43YlgW1:gBj`Bff?44^m_d1;_JlPBge^l4
]MC]0k?Bj`BbdNX4/m;[1;KEkPBjfO84_]ce1<7NmP?1gO@4_]_b1;cIl0Bie^`4]M3V1;7:h0>_a]/4
[/CI1:k3f0B_`mX4/<GK1;;7g0BdbMd3]l_O1;W=h@Bjcn<4^/oT1;[?h`Bhc^<3]LcQ1;;;g`BabMh4
[/SM1:c7g@BZamd4Z<SM0jK8gPBP`mX4Uk_B18j`a`B6Ykd4OYjc0gFEZPA]S:04IH>G15ejSPAELXD4
CFUm14EQM1Goool001Coool4AF5e14eZO`AELhP4GWfC16J7W@=_TJP4NI^c18>V_`B</L/4U[cF19o6
h@>WcNL4[M;[1;KHl@Bkfo@4^m[b1;OFk`Bee>d3/m;[1;;AjPBcd^/4]]G^1;[IlPBng?D4`Mkf0l7M
m0Bnfo84_=W`1;WFk0Bed>H4/L[P0jo6f`B^a=T4[/?H1:o3fPB`aM/4//OL1;C9g@>gbml4^LgQ1;[?
h`Bjcn@4^/oS1;S>h`>ec>44//_O1;79gPB^b=d4[<OM1:[7g@BXb=d3Y/SN1:33fPBG^m84S[3718JW
_@AnW[<3MIFZ16f<X0AUPiL4GGZ>15EbQ@A=JGd4AF5d5Oooo`005?ooo`A5HGD4CFYo15EcR0ANOI<4
IXNM0fnAZ0AiVk<4PjJo18bab`BF_=H4WlKQ0jO=i`B]d^/4]]Sa1;_Km0Bkf_84]mK_1;GDk@>cd^/4
/]7Z1;?Bj`BfeNh4^]Wb1;kLm@C1g_H3`Mgd1;kKlPBlfO04^MK/1;G@iPBab^03[lKK1:k4f@B^`mP4
[l?J1;35f`Bbam`4]<WM0kO;g`BicN44^/oS1;[?i0Bjcn<4^<kS0kG<h@Bbbml4/LWN1:k8g@B/amd4
Z/OM1:S8g@>Vb=h4X<?J19NkdPB>/<L4QZNm17jN/`=eUJX4KHbP16F3U`AMNXh4EG:514eYO@A5HG@E
oooo000Doooo14EQM@A=JWl4EWB915imT`AWQid3LI:Y17^M]@B6ZL44TKG>19_0f`BUbnH3[=7/1;GG
l0Bmg?<4_mcc1;kJl@Bie^d4]mC[0kGBj@Bcd>L4/loU1;C@iPBgd^T4_=K[1<;Jk`?4fo84`][`1;kH
kPBlen`4]m7W1;?9gP>`aMT4[l;G1:o2ePB``mL4//GI1;G8g@Bgbml3^LgP1;_?hPBnd^D8`=GW1;kC
iP>jd>@4]lkR1;K=h@Bdbn04//[N1;39gPB]b=`3ZLKJ1:?2ePBK^m04T[;618VX_@B0Wk<3N9JZ16n=
X@AWQ9L4GW^>15IbQ@A=JGd4AF5d5Oooo`005?ooo`A5HGD4CFYo15IdR@ANOI<4IhNM0g6BZ@AkWKD4
QZW1196ecPBK`=/4YL_V0jcAk0Beeo04_Mcc1;oLl`Bnf_44^MK]1;ODj`>ed^T4/m3W1;??i@Bdd>H4
]m;Y1;cFj`C2f^l3a=_b1<;Jl0Bnf>h4_=O/1;OAi`BcbMh3/<GI1:o2e`B_`]H4/<?G1;;5f@Beb=d4
]l_O0kW=h0Bkcn84_];U2<3Ei`BndnH3^]3T1;O>hPBfcN44]<_P1;;:gPB`bMh4[LSL0jW6fPBS`]H4
Vk_@19:baPB9Z;d4P9nc0gRFZPA_SJ44IhBG15ikSPAFLXD4CFUm14EQM1Goool001Coool4AF5e14eZ
O`AFM8T4GWfC16N7W@=aTZT4Nife18JY`@BA]Lh4Vl3K1:G;iP>/dN`4]MO`1;gLl`Bog?<4_][a1;WF
k@Bge>/3]M;Y1;?@i`BccnD4]=3V1;OBj@Ble^/4`][_0lCKlPC2f_04_]S^1;cGk0BgdNL4/lWN0k35
f@B_`]L4[l;F1;33e`BbaMT4]LSM1;O;g`>icN04^loR1;kBi@S0eNL4_]?V0k[@i0Bgc^84]/gQ1;C;
h0Bbb]h4/<WN1:g8g0>Ya]X4Xl;F19^kd0BB//H4RJRm182O/`=hUZX4KhfQ16N4U`ANNhh4EW:514eY
O@A5HG@Eoooo000Doooo14EQM@A=JWl4EWB915imT`AWQid3LI:Y17^M]@B6ZL44TKG>19_0f`BUbnH3
[=7/1;GGl0Bmg?<4_mcc1;kJl@Bie^d4]mC[0kGBj@Bcd>L4/loU1;C@iPBgd^T4_=K[1<;Jk`?4fo84
`][`1;kHkPBlen`4]m7W1;?9gP>`aMT4[l;G1:o2ePB``mL4//GI1;G8g@Bgbml3^LgP1;_?hPBnd^D8
`=GW1;kCiP>jd>@4]lkR1;K=h@Bdbn04//[N1;39gPB]b=`3ZLKJ1:?2ePBK^m04T[;618VX_@B0Wk<3
N9JZ16n=X@AWQ9L4GW^>15IbQ@A=JGd4AF5d5Oooo`005?ooo`A5HGD4CFYo15IdR0AOOI<4J8NM0g:B
Z@AmW[D4RJ_319FidPBRan04Zm3Z0k7DkPBce>`4^=K/1;cHkPBmf>h4^]GZ1;SBj0>fdNH4]LoT1;?<
h0B`bMd4[/KJ1:k6f`Bbb]h3]/cP1;W<h0Bgb]d4/lGI1;;4f0Baa=L3/<;E2;31d`Ba`mD4/lKH1;O;
g@Bkcn43_]7S1<?Ei`S7fN/4aMOY1<?Fj0?0e>L4_=7T1;W?hPBgc^04]/gO1;G=g`Bdbmh3/<OJ1:S1
d`BO^ld4U[;618fY_@B3X;@3NYNZ176=X@AXQ9L4Gg^>15IbQ@A>JGd4AF5d5Oooo`005?ooo`A5HGD4
CFYo15IdR0AOOI<4J8NM0g:BZ@AmW[D4RJ_319FidPBRan04Zm3Z0k7DkPBce>`4^=K/1;cHkPBmf>h4
^]GZ1;SBj0>fdNH4]LoT1;?<h0B`bMd4[/KJ1:k6f`Bbb]h3]/cP1;W<h0Bgb]d4/lGI1;;4f0Baa=L3
/<;E2;31d`Ba`mD4/lKH1;O;g@Bkcn43_]7S1<?Ei`S7fN/4aMOY1<?Fj0?0e>L4_=7T1;W?hPBgc^04
]/gO1;G=g`Bdbmh3/<OJ1:S1d`BO^ld4U[;618fY_@B3X;@3NYNZ176=X@AXQ9L4Gg^>15IbQ@A>JGd4
AF5d5Oooo`005?ooo`A5HGD4CFYo15IdR0AOOI<4J8NM0g:BZ@AmW[D4RJ_319FidPBRan04Zm3Z0k7D
kPBce>`4^=K/1;cHkPBmf>h4^]GZ1;SBj0>fdNH4]LoT1;?<h0B`bMd4[/KJ1:k6f`Bbb]h3]/cP1;W<
h0Bgb]d4/lGI1;;4f0Baa=L3/<;E2;31d`Ba`mD4/lKH1;O;g@Bkcn43_]7S1<?Ei`S7fN/4aMOY1<?F
j0?0e>L4_=7T1;W?hPBgc^04]/gO1;G=g`Bdbmh3/<OJ1:S1d`BO^ld4U[;618fY_@B3X;@3NYNZ176=
X@AXQ9L4Gg^>15IbQ@A>JGd4AF5d5Oooo`005?ooo`A5HGD4CFYo15IdR0AOOI<4J8NM0g:BZ@AmW[D4
RJ_319FidPBRan04Zm3Z0k7DkPBce>`4^=K/1;cHkPBmf>h4^]GZ1;SBj0>fdNH4]LoT1;?<h0B`bMd4
[/KJ1:k6f`Bbb]h3]/cP1;W<h0Bgb]d4/lGI1;;4f0Baa=L3/<;E2;31d`Ba`mD4/lKH1;O;g@Bkcn43
_]7S1<?Ei`S7fN/4aMOY1<?Fj0?0e>L4_=7T1;W?hPBgc^04]/gO1;G=g`Bdbmh3/<OJ1:S1d`BO^ld4
U[;618fY_@B3X;@3NYNZ176=X@AXQ9L4Gg^>15IbQ@A>JGd4AF5d5Oooo`005?ooo`A5HWD4CFYn15Ic
R0AOOI84J8JL0g:AZ0AmW[D4RZc419ZmePB]dnd4^Mkg0kWIl@BheN`4^MGZ1;gFjPBnen/4^mCX1;WA
i@>gd><4]/kR1;C;gPB`aMP4[L;D1:Rmd0BS^</3Y;O:1:RkcPB[_<l4[[k@1;31dPB``]<3/<7C1;31
dPR_`=44/<7B1;71d@Bea=D3_<_J1<CChPC7enH4amOW1<SIj@C7fNX3`mOX1;oCi@Bkd>44^/kO1;[>
h0Bjcn04^/kO0kO<g@B_aML4YKk@19Zea`B@Zkh4QZ6d0gbGZPAcSZ44JHBG161kSPAGLXD4CVUl14IQ
M1Goool001Coool4AF9e14eZOPAFLhP4GgfB16R6W0=bTJP4OIje18Z/a0BJ_MH4[M?]1;WNm`>ifO44
^=G/1;WEjPBme^X4_]O[1;_Dj0BidND3]m3S1;K>hPBdbmh4/<GH1:g2e0BX_M04XkS;0jBgbPBX^lh4
Zkc?1:jnd0B``M84/<;C0k31d`B``M88[l3A1;31dPBa`M44]LCE0kc;fPC4dn84amOV1<OGi`C8fNT4
amWZ0l?Gj0BodnD4^m3Q1;[>g`Bjc^04^/oP1;[>g`>gc=d4[lGG1:Fnd0BJ]LL4T:^n18JQ]0=lUjX4
LhjQ16V4U`APNhh4Eg:514iYO0A6HG@Eoooo000Doooo14ERM@A=JWh4EW>815mmTPAXQY`3LY6X17fN
]@B:[<@4V[gF1:gCk@Big_L3^MWa1;SEk0BieNX4_MKZ1;kGj`Bke>P4^M7U0kO@h`Bfc^84]<_N1;35
f0B]`]@4Z;g@1:>hb`>T]lX4Z;_>1:^lc`B^_]04/<7B1;32d`>``M<4/<7B2:o0d@B``M84/L7A1;G4
e@>lbmX4a=?R1<OGiPC7enL4b=WY1<OIjP?3enP4_m?U1;_@h@Bjc]l4^/kP1;[?h0Bjc]l3]lcM1:o5
e`BU_]04V[G7192[_PB6XK@3O9NZ17>>X@AYQ9L4H7^>15MbQ@A>JG`4AV5d5Oooo`005?ooo`A5HWD4
CFYn15IcR0AOOI84J8JL0g:AZ0AmW[D4RZc419ZmePB]dnd4^Mkg0kWIl@BheN`4^MGZ1;gFjPBnen/4
^mCX1;WAi@>gd><4]/kR1;C;gPB`aMP4[L;D1:Rmd0BS^</3Y;O:1:RkcPB[_<l4[[k@1;31dPB``]<3
/<7C1;31dPR_`=44/<7B1;71d@Bea=D3_<_J1<CChPC7enH4amOW1<SIj@C7fNX3`mOX1;oCi@Bkd>44
^/kO1;[>h0Bjcn04^/kO0kO<g@B_aML4YKk@19Zea`B@Zkh4QZ6d0gbGZPAcSZ44JHBG161kSPAGLXD4
CVUl14IQM1Goool001Coool4AF5d14eYO@AELXH4GW^?16N5VP=aSjD4O9^b18ZZ`@BM_mP4[<kW1;WH
k`?2go@4`M_`1;kGj`Ble>P4_=CW1;_Bi@Bid>83]loP1;O>g`Beb]`4//GF1:o0d0B[_</4ZK[90jRh
a`BY]lH4ZkW81:jkb`B__Ld4/;o?0k30d0B`_ll4[kk=1:nmc0B__Ld4[[g=1:jnc`>^_m04/<;B1;O7
e`Bjc=/4^lgL1;c>g@>kcMd4^/cL1;[=g0Bkc]h4_<kN2;kAh0>jcMd4]<[K1:[3e@BO]lT4Tjfn18VR
]0=nV:X4M8jP16Z4U`AQNhh4F7:514mYO0A6HG@Eoooo000Doooo14EQM0A=JGd4EG:615ikS`AWQIX3
LHnU17bK/PB:Z/44WKoH1:c>i`Bif>l3`]od1<7Kl0Bnen/4_=CX1;cDi`Bkd^D4^M3R0kO?h0Bgc]l4
]L[L1;;5ePB_`=04Zkc;1:Vjb@>X^<L4ZKO61:^ib0B^^l/4[kg=1;2oc`>``=04/;o?1:nnc@B__L`4
[kg=1:jmc@B^_/l3[[o@1;32dPBgamL4^/cK1;_=g0Blc]d3^lgM1;[<g0BjcM`4^lkN1;c>gPRndN03
^/gM1;C:f`BZ`mD4WkO919>]_PB9X[@3OYRZ17B>X0AZQ9L4HG^>15QbQ@A?JG`4AV5d5Oooo`005?oo
o`A5HG@4CFUm15EbQPANNhl4IhFJ0g6?Y@AlVk84RZ[119fof0B/c^L4^MS_0l;Om0C1fo04_]O[1;cD
j0Ble>L4^m;U1;W@hP>gcn04]lkO1;G:g0BbaMH4[l3@1:^lb`BY^/T3Z;S71:VgaPB[^LP4[[_;1:nm
c@B`_ll3/<3@1;2oc`B__/d4[kg<1:nmc@B^_Ld4[[k?0jjod0B``]84]lOG1;[<f`BkcM`4_<kM0k_=
g@Bjc=`4^/gL1;_>gPBlc]h8_]7P0k[=g@Bdb]/4Z/?E19ngb@BC[Kh4RJ:d0gjHZPAdSZ04JXBG165k
SPAHLXD4CfUl14IQM1Goool001Coool4AF5d14eYO@AELXH4GW^?16N5VP=aSjD4O9^b18ZZ`@BM_mP4
[<kW1;WHk`?2go@4`M_`1;kGj`Ble>P4_=CW1;_Bi@Bid>83]loP1;O>g`Beb]`4//GF1:o0d0B[_</4
ZK[90jRha`BY]lH4ZkW81:jkb`B__Ld4/;o?0k30d0B`_ll4[kk=1:nmc0B__Ld4[[g=1:jnc`>^_m04
/<;B1;O7e`Bjc=/4^lgL1;c>g@>kcMd4^/cL1;[=g0Bkc]h4_<kN2;kAh0>jcMd4]<[K1:[3e@BO]lT4
Tjfn18VR]0=nV:X4M8jP16Z4U`AQNhh4F7:514mYO0A6HG@Eoooo000Doooo14EOL`A<J7/4E72415ei
S@AUPYL3KhbQ17VG[0B5XkT4TJo619nld`BZaM/3]LgR1;[AiPBidND4^M3S1;_Bi0Bjd>84^<gO0kK8
f@BdaMD4]LOG1;G8f0Bda=@4//3?1;6mbP>`^lP4[k_81;2lb@Ba_<T4/;_91;2mc0>`_lh4/;k>1:nm
c0B__LX4[kk;1;2nc0B`_/d3[[g<1:Nga`BU]/H4Z[_;1:foc`B``]43]LGD1;W9e`BkbmT4^lcJ1;k>
g0Rocmh3^lcK1;G9f0B]a=@4X[W:19J^_`B;Xk@3P9RZ17F>X0A[Q9H4HG^=15QbQ0A?JG`4AV5c5Ooo
o`005?ooo`A5Gg<4C6Qk15A`Q0AMNHd4IH:G0fn<X@AiUj`4QJ>i196_aPBO_=<4Z/GK0kG=hPBjdNH4
^M7U1;W@h`Bkd^@4^]3R1;S=g`>fb=T4]<GE1;G7e`Beb=P4]<CD1;;0c`Ba_LX3/;_81:nkb0B`_<T4
/Kc91;2kb@B`_L`3/;o>1;2ncPB__L`4[kg:1:nnb`B`_/`4/;k=0jjmc0BW]lL4YKK61:Zkb`B]_ll4
/<;A0kG5e0BibML4^l_I1;_<fPBnc]`8_loN0k_<f`BebMP4[LCD1::ibPBF[[l4Rj>d0h2HZPAeSZ04
JhBF165kS@AHLX@4CfUl14IQLaGoool001Coool4AEmc14aXN`ADL8@4GGV=16F2U`=_S:44NIN/18FS
^@BA[lH4WkcC1:[5f`>ecN84^]7V1;WAi@Bid><4^m;T1;[@hPBhcMl3]/SI1;C5e@BeamL4]LSH1;C4
e0Bb`<l4/Kg:0k2kb0B_^lP4/;c91;6lb@B`^lT4/;g<0k2ocPB`_/h4[kg<1:nmbPB__//4/;k<1;2n
c@>^_L`4YkO71:FfaPBZ^l/4[Ko?1;32d@>eaM@4^LWG1;_;f@Bkc=X4_/kL2;o?gP>kc=/4]LWH1:g4
e0BR^LX4UZjo18^S]0>0V:X4MHjP16^4UPAQNhd4F7:414mYO0A6HG<Eoooo000Doooo14AOL`A<IgX4
Dfn215]gR`ASOi<3K8RL17FAYPAnVZl4Qj>i19F`a@BR^/l3Zl;E1:o6fPBdbM`4^<_M2;_>g`Bhbm/3
]/OF1;;2d0B__<T4[KW61:bh``BY/kh4YJjh0jB/]PBV[KL4Z:ni1:^c_PB^^<<4/;_81k6nb`B`_<T4
[k_71;2mb0Bc`L/4]<;=0k;0c@B__/`4[Kc:1:bjb0B^_<T4//3=0kO4d0Bjb=<4_<_F1;k=f@C0cm`4
`M3L1<3>f`>jbMH4]LKD1;75e0BV_</4VJno18fS/`>1V:T4MXfN16^4U@AQNX`4F76314mYN`A6H7<E
oooo000Doooo14AOL`A<IgX4Dfn215]gR`ASOi<3K8RL17FAYPAnVZl4Qj>i19F`a@BR^/l3Zl;E1:o6
fPBdbM`4^<_M2;_>g`Bhbm/3]/OF1;;2d0B__<T4[KW61:bh``BY/kh4YJjh0jB/]PBV[KL4Z:ni1:^c
_PB^^<<4/;_81k6nb`B`_<T4[k_71;2mb0Bc`L/4]<;=0k;0c@B__/`4[Kc:1:bjb0B^_<T4//3=0kO4
d0Bjb=<4_<_F1;k=f@C0cm`4`M3L1<3>f`>jbMH4]LKD1;75e0BV_</4VJno18fS/`>1V:T4MXfN16^4
U@AQNX`4F76314mYN`A6H7<Eoooo000Doooo14AOL`A<IgX4Dfn215]gR`ASOi<3K8RL17FAYPAnVZl4
Qj>i19F`a@BR^/l3Zl;E1:o6fPBdbM`4^<_M2;_>g`Bhbm/3]/OF1;;2d0B__<T4[KW61:bh``BY/kh4
YJjh0jB/]PBV[KL4Z:ni1:^c_PB^^<<4/;_81k6nb`B`_<T4[k_71;2mb0Bc`L/4]<;=0k;0c@B__/`4
[Kc:1:bjb0B^_<T4//3=0kO4d0Bjb=<4_<_F1;k=f@C0cm`4`M3L1<3>f`>jbMH4]LKD1;75e0BV_</4
VJno18fS/`>1V:T4MXfN16^4U@AQNX`4F76314mYN`A6H7<Eoooo000Doooo14AOL`A<IgX4Dfn215]g
R`ASOi<3K8RL17FAYPAnVZl4Qj>i19F`a@BR^/l3Zl;E1:o6fPBdbM`4^<_M2;_>g`Bhbm/3]/OF1;;2
d0B__<T4[KW61:bh``BY/kh4YJjh0jB/]PBV[KL4Z:ni1:^c_PB^^<<4/;_81k6nb`B`_<T4[k_71;2m
b0Bc`L/4]<;=0k;0c@B__/`4[Kc:1:bjb0B^_<T4//3=0kO4d0Bjb=<4_<_F1;k=f@C0cm`4`M3L1<3>
f`>jbMH4]LKD1;75e0BV_</4VJno18fS/`>1V:T4MXfN16^4U@AQNX`4F76314mYN`A6H7<Eoooo000D
oooo14AOLPA;IWT4DVf015UdR0AQO8l3J8>G172;W`AhTZH4OiV/18ZS]PBE[L03WkK81:Rmc`B^`m@4
]<OH1;[<g0BkcMd4^L_J0kO7ePBd`/l4/Kc81:fe`0BX[[P4YJZc1:BW[`>SYJd4Y:J]1:RZ/PB//[`4
/;S31;:lb0>c_L/4/kg:1;2kb0B]]l<4Z[Bn1:bf_`Bb_LH3]l?=1;O4cPBe`/d4]<7<1;C1c@Bg`ll3
^LKA1;_9e0Blb]D4_LcF1<3?f@C1cmX4_/_F0kg;ePBkb]L4^<_I1:g2d@BK/;l4SJ:b0h6GY`AfS9d4
Jh:C165iR`AHLH84CfQj14IPLaGoool001Coool4A5mb14]VN@ABKH04FGB8165lS`=XPiL4L8^O17RB
YPAoVJ`4RZ>f19F]`0>O]/P4Z;g?1:k3e0BdamP4^/cL1;_=g@BibmX3]lOF1;C2c`Ba_<P4[KG01:R^
^0BUZ[<4Y:N_0j>U[@BTYZd4Z:Zb1:bb_0B`^<<4/[c80k>mb`Bc_LX4/;_81:fg``BZ];h4[;Jo1;:m
aP>g`ld4]lC>1;G2c@Bd`L`4]<7=1;O3c`>ia]44^lWD1;c:e@Bmc=H4`<oI1<7?fPBnbmH3_L_F1;_:
e`BhbmT4[L;A19^`_`B=X[83PINW17J<W@A[PY<4HGV;15QaPPA?J7X4AV1c5Oooo`005?ooo`A4Gg84
BfIi159]P0AIM8P4HGb?0fR3U`A`Ril4N9:V17nI[0B:XkH4UJg00infb0BX_Ll4[/?D1;C7f0Bjc=`4
^lgM1;W;fP>gamH4]<;?1;6lb0B]]L04Z:jh1:FZ/`BTYjl3XjF]1:BV[@BXZ[84[;:l1;2h``Bb_<P3
/kg;1;>mbPB`^lP4[KO31:Zd_PB/][l4/[g60kO3c@Bga<h4]L;=1;C1c0Bd`Ld4]l??0kW6d@BkbM@4
_<[E1;g<ePC0cmT4`LoJ1;k;eP>mbmH4^l[G1;S;f@B]`]44Vk2o18fR/P>1UjL4MXbM16^2T`AQNH/4
F76214mXNPA6H7<Eoooo000Doooo14AOLPA;IWT4DVf015UdR0AQO8l3J8>G172;W`AhTZH4OiV/18ZS
]PBE[L03WkK81:Rmc`B^`m@4]<OH1;[<g0BkcMd4^L_J0kO7ePBd`/l4/Kc81:fe`0BX[[P4YJZc1:BW
[`>SYJd4Y:J]1:RZ/PB//[`4/;S31;:lb0>c_L/4/kg:1;2kb0B]]l<4Z[Bn1:bf_`Bb_LH3]l?=1;O4
cPBe`/d4]<7<1;C1c@Bg`ll3^LKA1;_9e0Blb]D4_LcF1<3?f@C1cmX4_/_F0kg;ePBkb]L4^<_I1:g2
d@BK/;l4SJ:b0h6GY`AfS9d4Jh:C165iR`AHLH84CfQj14IPLaGoool001Coool4@eia14YTM`A@JWd4
Eg6415ihR`=UOY44K8FH17:;WPAiT:<4PYRZ18bQ/`>EZkd4W[?41:Nkb`B``]84]lWH1;[<fPBjbmT3
^<SF1;K4d@Bd`<`4/K[51:ne_`B]/[X4[;2h0jb_]`B]/;P4[k>k1;6g`0Bc_<H4]Ko:1kG0c0Bc_/T4
/;[51:bf`0BX/K/4YK2i0jRc_0B`^l@4]l;<1;[6c`Bka/l4^lO@0kc7d@Bkam04^lOA1;k9d`Bobm@4
_l[D1;k9d`?0bm@4_/WC1;C2c`BY^/L4VZfk18fP[`>0UJ@4MHZJ16Z1T@AQN8T4Eg2114iXNPA6H78E
oooo000Doooo14=NL@A:I7L4D6Ym15MaQ0ANN8/3IGjA16b5V0AbRih4NI2S18:HZPB<XK<3UJ^m19jc
a0BW^l/4/<;B1;O9f0Bjc=X4^/_I0kS8ePBfa=44]<3<1;6ja@B_]Kl4[K:j1:b`^0>/[kL4[K2h1:nc
^`Ba]l04/kc61;FobPNe`<`4/kk91;2ja@B/]/04Z;6k1:F`^@>X/k`4/;_41;O2c0Bja/l4^lK?1;_7
d0>lam44^lO@1;_7d@BnbM<4_l_D1;o:e0BnbM<3`<_D1;k9d`Bd`/l4ZK[719Z]^`B=X:l3P9FT17F:
VPAZPI44HGR915M`P@A>J7X4AV1b5Oooo`005?ooo`A3GW44BVAg151ZO@AGLH@4GWR;0fEnT@A/QIP4
LX^N17V@X`B2V:X4S:6c0iF[_@BN/l@4Yk_;1;32dPBgbMP4^/cJ1;[;f@>hb=H4]/CA1;C0c0Ba^/D4
[kFo1:fb^PB//;P3[:ng1:f`^0B_/k/4/KO01;>laPBe_lX7]L3<1;>nb@B`^/D4[;K01:Ra^`BU/;T3
Z;>l1;2ka0Bg`/`4^/K?1;_6c`Bkam03_<OA1;_7d0Bkam44_/WC1;o;e0Bob]@4_/WC0l3;e0BnbM<4
]<;?1:Vja`BJ[K/4SJ2_0h2EY0AeRYX4JX6A165hR@AGL844CVQj14IPLQGoool001Coool4@eia14YT
M`A@JWd4Eg6415ihR`=UOY44K8FH17:;WPAiT:<4PYRZ18bQ/`>EZkd4W[?41:Nkb`B``]84]lWH1;[<
fPBjbmT3^<SF1;K4d@Bd`<`4/K[51:ne_`B]/[X4[;2h0jb_]`B]/;P4[k>k1;6g`0Bc_<H4]Ko:1kG0
c0Bc_/T4/;[51:bf`0BX/K/4YK2i0jRc_0B`^l@4]l;<1;[6c`Bka/l4^lO@0kc7d@Bkam04^lOA1;k9
d`Bobm@4_l[D1;k9d`?0bm@4_/WC1;C2c`BY^/L4VZfk18fP[`>0UJ@4MHZJ16Z1T@AQN8T4Eg2114iX
NPA6H78Eoooo000Doooo14=NL0A9HgH4CfUk15E^P@AKM8H3HGZ<16MoT@A]Q9H4LXVK17V@X@B3VJT3
SZ:c19N[^`BQ]<<4[;k<1;K7e@Rlc=X3^l[H1;W7e@Bga=04]/7<1;Bnb0Bc^l@4/kW10k>h`@Bd^/84
]Kc41;Nna`Bh`LX4^L?=0kW4cPBi`lh4]l;<1;BobPBa_<H4[[S21:^d_P>X/[`4Y[6j1:Rb_0B/]l04
/;_41;:maP>d_/H4^<;:1;c5cPBnall4_LK?1;_5c@Bk`l`3^l7;1;Rob0B`^/D4Y[C019RY]PB;WJX3
OY6P17>7U`AYOXh4GgJ615I^O`A>IgP4AEmb5Oooo`005?ooo`A3GW04BF=f14mYN`AEKX44FgB60f5j
S0AWOi44KHBF17:9V`AiT:44PiVY0hjR/`BGZk/4XKC31:bnc0BfamD8_<cJ0k_:f0BiamD4]lC@1;K1
c0Bd_/P4/k_41;>i`@>c^<44];[21;Fla0Bg_/L4^<7:1;W3c@>ia<h4^L?>1;O2c0Bd_lX4/Kc61:jh
`PB[];h3Z;:l1:Ja^PBX/[`4[;O01;2ka0Bb_LH3];k61;S2bPBlaLh4_/O?1;g6c`BkaLd4^l?<0k_1
b`Bh_lP4/;[51:Jd`0BHZKH4RifZ0gjAX0AcQiL4JGj>15mfQPAFKWl4CVMh14EOLQGoool001Coool4
@ei`14USMPA?JG/4EFj115]dQP=QNX`4IgnA16f4UPAbRI/4NI2Q18>IZ@>>X[<4Uj^k1:6d``B/_/`4
]/OE2;c<fP>kb]P4^LOE1;O4d0Bf`L`4];k81;>ka0Bc^L43/kS11;Bj`PBe_<@4]kk71;S1bPBi`ld3
^LC>1;W3cPBg`/`4];o:1;6laPB^^<84ZkBn0jRb_0BV/KX4Z;:l1:bg`0B`^l@4/[g60kBnaPBh`/X4
_<G>1;k7c`Bma/l4^lG=1;_3c0>k`L/4^;o81;2ja@BV]<04V:Vf18^MZP=nTJ04LhNG16UnSPAOMXH4
EVio14iWN0A5Gg8Eoooo000Doooo14=NL0A9HgH4CfUk15E^P@AKM8H3HGZ<16MoT@A]Q9H4LXVK17V@
X@B3VJT3SZ:c19N[^`BQ]<<4[;k<1;K7e@Rlc=X3^l[H1;W7e@Bga=04]/7<1;Bnb0Bc^l@4/kW10k>h
`@Bd^/84]Kc41;Nna`Bh`LX4^L?=0kW4cPBi`lh4]l;<1;BobPBa_<H4[[S21:^d_P>X/[`4Y[6j1:Rb
_0B/]l04/;_41;:maP>d_/H4^<;:1;c5cPBnall4_LK?1;_5c@Bk`l`3^l7;1;Rob0B`^/D4Y[C019RY
]PB;WJX3OY6P17>7U`AYOXh4GgJ615I^O`A>IgP4AEmb5Oooo`005?ooo`A2GG04B69d14eVN@ABJgd4
F7220eeeQ`ASNX/4J7j@16f3U0AeRi`4OI:R0hNJZPBBYK@4WJnn1:Vjb0BeaM84_<cI1;k=fP>mc=T4
_<[F1;_8e0Bja]04^LC>1;W3c@Bi`//3^/7:1;_2b`Bla<`4_LK?1;k7d@BnbM83_/WC1;g9dPBlam04
^/G>1;O2c0Bd_lP4/Kc50jji`@B/][h4Z[Bm1:Zd_0B/]Kd4/;W00kBma0Bh`<P4^l?;1;g5c@Bk`l/4
^;o71;Bl``>a^<04[kJo1:Zd_PBS/K`4UZJb18NHY@=kSI/4L8BB16MkR`ANM8@4EFam14eVM`A5Gg4E
oooo000Doooo149ML0A8HW@4CFIi159[O@AHL883GGF716=jR`AXOY04KH>D17F;W0AmTZ83QiZZ19:U
]0BM[kh4ZK[81;G5dPBlc=T4_/gJ0kg<f@Blb]H4^lSD1;[6d0Bia<h4^L?=1;W2b`>j`LX4^l;;1;c4
c0Bma/l4_/OA1;k9dP>nbM<4_LWB1;c7d0BjaLh4]l;<1;Bob0Ba_<D3[[W11:bf_PBZ];d4Z[Bl1:be
_@B`^L03];g41;S0b0Bk`l/4_LG=1;_3b`Bh_lL4];c30k6h`0B_][l4Z[Bn1:>a_0BFY[84QiRU0g^=
V`A`Q984Ig^;15idQ0AEK7d4CFIg14EOLAGoool001Coool4@Ue`14QRM0A=IWT4DV]m15Q`PP=MMHL4
HgZ;16QnT0A]Pi@4MH^L17fBXP>7VZX4TZFd19f__PBY^/P4]LGB1;c<f@BncMX3_LcI1;c:ePBkb=@4
^/K@1;W4cPBi`ld4^L;;0k[1bPBk`//4_<C<1;g6c`Bnam44_/WB0kk9d`BmbM84_<O@1;[5cPBg`/`4
];o81;6la@>^^L44[;Jn1:Zd_@BZ];`4[;Fm1;2i`0>d_L@4^<381;_3b`BmaLd4^l?;1;Roa`Bd_<<3
/KS01:nf_`BZ];h4Xk6l19JV/PB7V:D3NhfK1724TPAWNh/4GWB415E/O@A=IWL4AEma5Oooo`005?oo
o`A2G6l4AV1c14]TMPA@J7X4EFan0eYaPPANMHD4HgV916QmS@A`Pi84N8ZI0h6CX@B<WJX4VZVf1:Je
`@Bb`L`4^l[F1;o>f`>oc]X4_/gI1;k<e`BnbmH4_/[D2;o9d`?0b]<4`L[D1<;;e0C3c=D4a<kG1lC?
f0C3c]L4`/gF1<3;d`Bmb=04^lG=1;S1bP>e_lH4/kc32;:j`@Bc^l44]Kc30kRna@Bk`<L8_L;81;Zo
a@Bd^Kl4/;Fk0j^a^0BW[KD4XZZb19ZU[`B?W:P4PY2L0gN7U0A]Ohd4I7R615aaP0ADJW/4C6Af14AN
L1Goool001Coool4@Ua_14IPL`A;I7H4D6Qj15E/OP=JLH84GWF516=iR@AXOHd4L8>B17R:V@>1Tj44
S9fZ19ZY]PBV]L44//7<1;_:ePBoc]/3_lkJ1;k=f@Bnc=L4_/_F1;k:e0RobM<3`<[C1<7:e0C2bm@4
`lcE1<C>e`O4cmP4`lkG1<;=ePC0bm<4_LS@1;_5c@Bh`LX3]Ko61;>l``Rb^/44/k_11;Fl``>h_/D4
^l372;g2b0Bj_lD4];Vo1;2e^`>[/KP4Yjfe1::Z/PBJYJl4SibX18:@W0=gQi@4KGn=16AhQPALLH04
E6Yk14aTMPA4GW0Eoooo000Doooo149LK`A6H7<4BfAf151XNPAEK7h3FW6215ieQ@ASNHT4J7f=1723
TPAhRYT3PI>Q18bMZPBJZKH4Y[G11;;1c0Bkb]H4_lkK0ko>fPBncMT4_/cG1;k;ePBnb]@8_lWC0l3:
d`C1b]@4`/_D1<?<e@C4c]L7a<oH1<?>e`C2cMH4`<_C1;g8d0BkaLd4^<7:0kFoaPBc_<<8/[[11;>k
`@Be_<<3^;k51;_0a`Rm`/P4^[o51;Bi_`B`]K/3Zk6h1:N]]@BRZ[84VZF_18nLZ0B2T9`3MhND16eo
S@ATN8H4G76015AZN`A<I7H4A5i`5Oooo`005?ooo`A2G6l4AV1c14]TMPA@J7X4EFan0eYaPPANMHD4
HgV916QmS@A`Pi84N8ZI0h6CX@B<WJX4VZVf1:Je`@Bb`L`4^l[F1;o>f`>oc]X4_/gI1;k<e`BnbmH4
_/[D2;o9d`?0b]<4`L[D1<;;e0C3c=D4a<kG1lC?f0C3c]L4`/gF1<3;d`Bmb=04^lG=1;S1bP>e_lH4
/kc32;:j`@Bc^l44]Kc30kRna@Bk`<L8_L;81;Zoa@Bd^Kl4/;Fk0j^a^0BW[KD4XZZb19ZU[`B?W:P4
PY2L0gN7U0A]Ohd4I7R615aaP0ADJW/4C6Af14ANL1Goool001Coool4@E]^14EOL@A9HW@4CVEg159Y
NP=FK7`4FW1o15icPPARMX@4JWf;17:3T@=kRiP4QIFQ196Q[0BO[KP4ZkS21;O3c@Bnc=H3`<oJ1<7?
f`C1d=/4`]3L1<?@f`C4cmT4aM3I0lK@fPC7dMX4b=;K1<WCg0C:e=d7b]GM1<WDg0C8d]X4a]3H1<C>
e@C1bm84_/O>0kc4b`Bj`/T4^<361;Roa@Bh_l@7^Ko51;[0aPBk`<H4^Kk31;>g_0B]/[L4Z:fb0j:W
[0BKX:L4U9^R18jEWPB4SYP4NXNB0g60S0AYNXL4HG>215U^O@ABJ7P4Bf=d14AML1Goool001Coool4
@E]^14EOL@A9HW@4CVEg159YNP=FK7`4FW1o15icPPARMX@4JWf;17:3T@=kRiP4QIFQ196Q[0BO[KP4
ZkS21;O3c@Bnc=H3`<oJ1<7?f`C1d=/4`]3L1<?@f`C4cmT4aM3I0lK@fPC7dMX4b=;K1<WCg0C:e=d7
b]GM1<WDg0C8d]X4a]3H1<C>e@C1bm84_/O>0kc4b`Bj`/T4^<361;Roa@Bh_l@7^Ko51;[0aPBk`<H4
^Kk31;>g_0B]/[L4Z:fb0j:W[0BKX:L4U9^R18jEWPB4SYP4NXNB0g60S0AYNXL4HG>215U^O@ABJ7P4
Bf=d14AML1Goool001Coool4@E]^14EOL@A9HW@4CVEg159YNP=FK7`4FW1o15icPPARMX@4JWf;17:3
T@=kRiP4QIFQ196Q[0BO[KP4ZkS21;O3c@Bnc=H3`<oJ1<7?f`C1d=/4`]3L1<?@f`C4cmT4aM3I0lK@
fPC7dMX4b=;K1<WCg0C:e=d7b]GM1<WDg0C8d]X4a]3H1<C>e@C1bm84_/O>0kc4b`Bj`/T4^<361;Ro
a@Bh_l@7^Ko51;[0aPBk`<H4^Kk31;>g_0B]/[L4Z:fb0j:W[0BKX:L4U9^R18jEWPB4SYP4NXNB0g60
S0AYNXL4HG>215U^O@ABJ7P4Bf=d14AML1Goool001Coool4@E]^14EOL@A9HW@4CVEg159YNP=FK7`4
FW1o15icPPARMX@4JWf;17:3T@=kRiP4QIFQ196Q[0BO[KP4ZkS21;O3c@Bnc=H3`<oJ1<7?f`C1d=/4
`]3L1<?@f`C4cmT4aM3I0lK@fPC7dMX4b=;K1<WCg0C:e=d7b]GM1<WDg0C8d]X4a]3H1<C>e@C1bm84
_/O>0kc4b`Bj`/T4^<361;Roa@Bh_l@7^Ko51;[0aPBk`<H4^Kk31;>g_0B]/[L4Z:fb0j:W[0BKX:L4
U9^R18jEWPB4SYP4NXNB0g60S0AYNXL4HG>215U^O@ABJ7P4Bf=d14AML1Goool001Coool4@5]]14AM
K`A8H744Bf9c14mUM@=BJ7L4EV]j15Y]O0ANL7d4IGJ316emR@=eQ904P8jI18fJY@BJY[04Y[:l1;6m
b0Bjb=83`LoI1<?Ag0C5d]d4a]CO1<SEh0C9e^44bmKP0lcGh0C=f>44cmWR1=3Jh`S@fn<3d=[R1=3J
h@C>f=l4c=KM1<[CfPC7d=H4a<gB0l;:c`C0ald4_lG:1;g3b0Bm`/L4_<760kc1a@Bm`<D4^[k21;Bh
_0B^/KD4YjV^19nRY`>GVj04Si>J18N=T`AmPhX4MWf5175lQP=[N8@4I7B015e_O@AFJWT4D6If14UQ
LPA3GFlEoooo000Doooo141KK@A4GFl4B61a14]RL`A?IGD3DVQg15I[NPAJKG`4GW1m16EfP`A]OHT3
MHB@182>V@B=VZD4VZJ`1:Jb_0Ba_LP4^/SB0l7?f@C3dM`4aM;M1<KDg`C8eN04bMKQ1<_Fh0?<en04
cMSQ1<oIhPC@f^<8d=_S0m3JhPC@f^44c]SO1<cFg@C:dmX4am3F1<C=dP?2b/l4`<O=1;o5bPBm`lP4
_L;71;c1aP>l`LD4_L351;Zn`PBd^;`4[[6e1:NY[PBOXZL3Ui^P18nCVPB7SI<4OH>:17ImQ@AaO8H3
JgR416AdP0AMKgd4EVYi151VMPA9HG84@ee_5Oooo`005?ooo`A0Ffd4A5e_14QPL@A;HW<4CfEe0e9X
M`AFJgX4FVel15i`O@AUMX<4KGf90gF4T0B0SYT4SIZU19ZV/0BV/[`4/Kg81;[8dP?1cmT4`m7L1<GB
g@C6e=l4b=GP1<WFh@C;e^03c=OP1<gHh@C?fN84d=[S2=3Kh`?@f^84d=[Q1<kHg`C<e]d4b]?J1<O@
ePC4cM83`/[?1<37c@BoaLX4_L?81;g2a`Bl`LH3_<751;g0a@Bj_/84];Rl1:ja]@BWZJh4Wj:W0iNK
X0B?TiX4QhfC17f3RPAfOHD4LGb60f]hQ0ATM804GFmm15IZN@A@IWH4BF5b14=MKaGoool001Coool4
@5]]14AMK`A8H744Bf9c14mUM@=BJ7L4EV]j15Y]O0ANL7d4IGJ316emR@=eQ904P8jI18fJY@BJY[04
Y[:l1;6mb0Bjb=83`LoI1<?Ag0C5d]d4a]CO1<SEh0C9e^44bmKP0lcGh0C=f>44cmWR1=3Jh`S@fn<3
d=[R1=3Jh@C>f=l4c=KM1<[CfPC7d=H4a<gB0l;:c`C0ald4_lG:1;g3b0Bm`/L4_<760kc1a@Bm`<D4
^[k21;Bh_0B^/KD4YjV^19nRY`>GVj04Si>J18N=T`AmPhX4MWf5175lQP=[N8@4I7B015e_O@AFJWT4
D6If14UQLPA3GFlEoooo000Doooo141JK0A3G6h4AUi_14UOL0A<HG43Cf=b159UM0AEJ7H4FF]h161a
O@AXMh<3L7n:17^8TPB6TY/4TijV1::[]0B_^<04^LC<0l7=e@C5d]/4b=GO1<[Gh@C<fN@4c]_V1=3M
i`?Bg^P4e>3Y1=GQjPSGh^/4en;Z0mKQj0CEgnH4e=gT1=;Jh@C@emd4cMCI1<_AeP?8c]<4a/_?1<C8
c0C2a/X4`<C71<32a@>o`<<4^kg11;Jh^`B`/K@4YjR[19jOX`BEUi`3SHnD18F8S@AmPHL4MWb216mf
OPAZM7d3I75l15m^NPAIJgP4DfMf14iSL`A8H704@Ua^5Oooo`005?ooo`A0FV`4@ea^14INK`A9Gg04
C65a0dmSLPABIG@4EFQf15U[N0APLGd4J7N30g1oRPAkR984QY:K19>NYPBRZk@4[kS01;W4c0?1cMD4
aM;K1<SEg`C:en44c=WT1<kKiPC@gNL3d]kX1=CPj@CEhNX8en;[1=ORjP?FhNP4eMoV1=CMi0CBf^44
d=OM1<gDf@C;dMH3b<kC1<K;c`C4b<`4`/K:1<34a`C0`/D3_l331;^m`@Bf^;/4/;6d1:NXZ`BNWj<4
UINL0hf?U0B5R8d4OH6717IlPPA_MWh4JWAm0fAaO0AOKWX4FF]h15=WMPA>Hg<4B61`149LKQGoool0
01Coool4@5Y/14=LKPA6GVl4BEm`14aQL@=?Hg84DVEd15EXMPAIJgP4H75m16QgP`=`OhX4NhRB18JB
V`BCWZH4XZ^d1:nh`0Bia<`3`LgE1<GBf`C8eMl4b]OQ1<cIi0C>fnH4d=gW0m;Nj0CDh>T4eN7Z2=OR
j`CGh^X3e^7X1=GOiPCDgN@4d][Q1=3Gg@C=e=T4bm7F0lS>d`C6bll4a<S<1<;6bPC0a<L4`<;50ko0
``Bk_L44][Rk1;2a]0BWZ:/4WYnS19FGW0>=Si@4QHR=17f1Q`AfO884KgIn16YdO@=TLG`4Gfij15U[
N0ACIgH4CV=c14QPL0A2G6hEoooo000Doooo141JK0A3G6h4AUi_14UOL0A<HG43Cf=b159UM0AEJ7H4
FF]h161aO@AXMh<3L7n:17^8TPB6TY/4TijV1::[]0B_^<04^LC<0l7=e@C5d]/4b=GO1<[Gh@C<fN@4
c]_V1=3Mi`?Bg^P4e>3Y1=GQjPSGh^/4en;Z0mKQj0CEgnH4e=gT1=;Jh@C@emd4cMCI1<_AeP?8c]<4
a/_?1<C8c0C2a/X4`<C71<32a@>o`<<4^kg11;Jh^`B`/K@4YjR[19jOX`BEUi`3SHnD18F8S@AmPHL4
MWb216mfOPAZM7d3I75l15m^NPAIJgP4DfMf14iSL`A8H704@Ua^5Oooo`005?ooo`@oFF`4@UY/14AK
K0A6G6`4B5e]0d]NK@A=Gfd4Cf1]159RK`AJJGD4HW1k0fYgP@AcOhP4OhZC18fGW`BLYJ`4Zk>j1;W1
a`?3cM@4b=CL1<_Gh0C>fnD4dMkX1=CQk0CFi>l3f>Ka1=[Wl@CLjO84g^Wb1=kYl@COjNl3g^S^1=gV
k0CKhnP4f=oU1=KLh0CCf=d4d=GI0lcAe@C:c]44b<_>1<K9b`C4a/P4`l?50l30`PBl_;d4]KBe1:^Z
[0BQX:<4UYNI18f>T@>4QXT4Ngf1175dN0A[L7D4Ifie16=/M@=OJgD4FVUd15EVL`A@I784C65`14MN
K`A2FfdEoooo000Doooo13mIK0A2FV`4A5]/14ILK0A8GFd3Bei]14eOK@A?H6d4DV9_15YYM@ARL7/3
JWN117=oR0AoRY<4SINO19bU[0B[/kX4^L770l?=e0C8e=`4bmOP1<kKi@CAg^P4e>7/1=KTk`?Hi_44
f^Oa1=cYlPCNjO84g^Wa1=oYk`?Nj>h4gNK/1=_Sj0CHgnD4e]cP1=?Hg@C@eMT3c=7E1<[>d@C8blh4
a/W;1<C6b0C3`lD3`<321;bl_@Be];D4ZjZ/1:6PX`BFUiT4SHjA0hB6R@AkOH44LGAh16]`M@AWKWD4
Hfae0em[M@AJJG@4EFIc151TLPA<HG04Aei_149KKAGoool001Coool4?eU/149JK0A4Ff`4AUa/14QM
K@=;GVd4CEm]14mPK@ABHVl4FVUe169`N`=ZMh44Lgn817n:T`B=Uil4W:F/1:^c^PBi`LL3`lgD1<SD
g0C;en04c]_U1=7Nj0CDhN`4e^C_0mSVl@CJio44g>Wb1=kYlPCNjO44gnW_0mkXkPCMi^`4fn?X1=SO
i@CFg>04dmSM1=3Ef@?<dMD4b/kA1<S;cPC6bL/4a<K81<?3a@?0`<84_;bm1;Fd]@B[ZZ`4XJ2S19JG
V@B=SY43Q8J917]mP@AaM7P4Jg1e16M^M@ASK7D3Gf]e15YYM0AEIW<4D6Ab14aQL0A7GVl4@U]]5Ooo
o`005?ooo`@oFF/4@5UZ149IJPA4FFT4AEYX0dMJI`A8FFH4BUUU14]JI@ABH6X4FfMa0fA`N0A_NH84
NhF<18RAV0BGWZ@4Yjjc1;Nn``?3bm44b]CK1<oIh@CBg^L4e^?/1=WVl0CLj_@3gncf1>7]mPCSk_H4
i>oe1>G`mPCVl?D3iNkc1>C[k`CRj>/4gnCX1=cQi0CHgN04eMWL0m7Ee`C>d=<4blg>1<W9b`C7a/P4
a<?40l2n_`Bi]kL4[jb]1:BQXPBHUYL4SHb>18>3Q@=hNG`4KFmb169SIPANH6@4GVA[15aUK@=IIFh4
EFA_159RK`A>H6l4BEi^14ELK@A1FV`Eoooo000Doooo13mIJ`A0FFX4@UUZ14AIJ@A5FVP3AeYW14QI
IPA:FFD4BeYU159PJPAKIg43I71h16miPPAkQH`4R96H19NNY0BW[[<4]kk30l?;d@C:e=/4cmWQ1=;N
i`CFhn`4fNK`1=cZm0?Ok?H4hNgf1>?^mPCTkoD4iO3f1>K`m@?Uk_<4i>__1>;Xj`COi>P4g>7T1=SM
h0CEfM`3dMGG1<k@d`C;cLh4bLW;1<O6b0C4`l@3`;jo1;Vg]`B_[:d4Y:6R19RFU`B=S8h4Ph>50gQi
O0A]Kg84HV=V15iPI0ANI6/4G6E]0eUUKPAEI6l4DV9_14iPK`A9GVh4AEa]145JK1Goool001Coool4
?eU[141IJPA2FFX4A5UY14EJJ0=7FVL4B5UV14YII@A;FVD4DV1Z15]WL@=TL7P4KgV217^5S0B8TIP4
UijT1:N^/`Bg_/<3`l_A1<[Df`C?fN44d]kW1=KSk0CIi_04g>[d0mo/mPCQkOH4hnkf1>C_m@CUl?H4
i_3e0nG^l`CTjnl4h^S[1=oTj0CLhN@4f=gP1=GIg0?AeML4c]3C1<_=cPC9bL/4alK81<C3a0?0_[l4
^KNg1:n/[@BTXJ84V9JG18f<SPB3PhD3N7Ul16e_LPARHfH4GV1T15iTJ`ALIFd3FFE^15ETK`ABHVl4
CV1_14UNKPA5G6d4@EY/5Oooo`005?ooo`@oFF/4@5UZ149IJPA4FFT4AEYX0dMJI`A8FFH4BUUU14]J
I@ABH6X4FfMa0fA`N0A_NH84NhF<18RAV0BGWZ@4Yjjc1;Nn``?3bm44b]CK1<oIh@CBg^L4e^?/1=WV
l0CLj_@3gncf1>7]mPCSk_H4i>oe1>G`mPCVl?D3iNkc1>C[k`CRj>/4gnCX1=cQi0CHgN04eMWL0m7E
e`C>d=<4blg>1<W9b`C7a/P4a<?40l2n_`Bi]kL4[jb]1:BQXPBHUYL4SHb>18>3Q@=hNG`4KFmb169S
IPANH6@4GVA[15aUK@=IIFh4EFA_159RK`A>H6l4BEi^14ELK@A1FV`Eoooo000Doooo13iHJP@oF6T4
@5MW145GIPA2EV@3@eER14=DH0A4Deh4A55K14YFGPADGVH3GFM_16MaN0AcO884PXV>196GW0BQYj/4
/[Nj0l75bPC<dmT4d]cR1=OQj0CKi^h4gn[b1>;^mP?VlOP4jO?j1>[dnPC/mOX4kOKj1>ken@?]loH4
jo3d1>W]l0CUjN`4h^GW1=kPhPCJg=d3e]OH1=?Bd`C?c/l4blW:1<O5a0C2_kl3_;Rg1;>^[PBXY:<4
W9RG18n=S0B4PX84NGQi0fi^L0AUIFP4Gf1T15YMHPAHGV@4EUmW0eAOJ@AAGfX4CUi[14]MJ`A7G6`4
A5]/141JJaGoool001Coool4?UQZ13mHJ@A0EfL4@EMV149FI0=3EF84@eAP14ACGPA4DE/4BUIN15AN
IP=MIfl4Ig5h17=lPPB2RHh4TINL1:6WZ`Bb]kX3`LG:1<cCf@CBg>84en7X1=_VkPCOj_84h^kf0nKa
n0CYloX4j_Cj1>cenPC]m_X4k_Gi0ngcmPC[l?@4jNg`1>GYk0CRiNL4g^3R1=[Lg@?FemP4dm;C1<o>
c`C;bLX4alG41<:o_`>l^;L4/jj^1:RTX`BLV9L4Shf<18B2PPAiN7T3KVi`16EUJ0AOH6@4FUeR15QN
I0AFGfL3E5mY155OJPA>GV/4Bee[14MLK0A4Ff`4@5Y[5Oooo`005?ooo`@nF6X4?eQY141GI`A1EfH4
@UIT0d=EHPA3E604A5=N14AAF`A:EUh4E5iV0eeWK`AWLGP4Lgb218:9SPBAUi`4XJN[1;:g^P?1aLX4
c=?I1=;LhPCGhNP4fnK^1=oZlPCRk_H3i_7h1>WcnPCZm?X4k?Gj1>gfnPC^mOT3kO?f1>_`m0CYkO04
iNW/1>;Ui`CNh>84f]cM0mKGf0CCd]<4clk?1<_9bPC7aL@4`[no0kbh]`Bc[Zh4Z:BS19bHU`B?SH`4
Q8:217UhN@=^KW04IFEX15mPI0AJGF84F5iT15IOI`=DGfT4DEmZ14iNJ`A;GF/4Aea/14AKK0A0FV/E
oooo000Doooo13iHJP@oF6T4@5MW145GIPA2EV@3@eER14=DH0A4Deh4A55K14YFGPADGVH3GFM_16Ma
N0AcO884PXV>196GW0BQYj/4/[Nj0l75bPC<dmT4d]cR1=OQj0CKi^h4gn[b1>;^mP?VlOP4jO?j1>[d
nPC/mOX4kOKj1>ken@?]loH4jo3d1>W]l0CUjN`4h^GW1=kPhPCJg=d3e]OH1=?Bd`C?c/l4blW:1<O5
a0C2_kl3_;Rg1;>^[PBXY:<4W9RG18n=S0B4PX84NGQi0fi^L0AUIFP4Gf1T15YMHPAHGV@4EUmW0eAO
J@AAGfX4CUi[14]MJ`A7G6`4A5]/141JJaGoool001Coool4?UMY13iFI`@oEFD4?eAS13mBH0<oDEd4
?diJ13i<EP@nBU<4@deE14]DF`=FGV@4HFQ]16acN0AjP8D4R8jB19NLX0BX[:l3^[k11<[>d@CDfmh4
f^CY1=oZk`CTko@4jO?h0ncfnPC_n?`4l_[n1?CjoPCen_d4m_[l0oChn@CbmOH4ko7b1>_]kPCWj>P4
hn?S1=oNgP?JfMT4e]CC1=;>c@C=bLL4a/?11;jj^0>e/:h4ZZBR19fHUPBAS8/4QX:117YgMPA^Jf`3
HV1R15QHFPAEEUT4DeIJ159GG@A@FF43CeYS14eKIPA;FfL4B5]X14EJJ@A3FVX4@5U[5Oooo`005?oo
o`@nEfT4?UIW13mEI@@oE6<4?e9P0cmAG@@oCUX4?TaF13i:D`A3CED4BeAK0eINI0AQJ6d4K7=h17Z0
Q@B8SY84UibP1:R/[`>j_/44b/kA1=CKgPCJi>T4gn[_1>C_m0CYloP3k?Kj1>oho0Cbn_h4m?[n1?Gj
o@Cfn_`3m?Si1?;emPC_lO84jng^1>OXj0CShn<4gmkN0m[If@CFe=<4d/k=1<g9a`C6`l44_[Zh0kF`
[PBZY:84WIRF196<R`B6PX44NWMf16i[K0=RH684F5QJ15EFF@ACEUX4DUMM151IH@=?FV<4CE]V14]K
I`A8FfP4AEYY14=JJPA0FF/Eoooo000Doooo13iGJ@@nEVL4?eEU13mDH`@oDV03?e5M13m>FP@nC5H4
?TYC14==E@A;E5/3EUiT165XK@A/LgP4NX2518R>TPBGW:04Z:b_0kZn`@C:c]44e=_N1=[Tj@COj^l4
i>od1>Wcn0?/m_X4koSl1?;joPCdn_h4mO[m1?Kjo0?dn?T4l_Gf1>oalPC[kNh4inSX1>?Sh`COg]h3
f]WI1=KDd`CBc/d4cLW71<K3`@Bn^[P3]K2^1:ZTXPBMV9H4THb;18J2P@AjMgH4KV]/0f9PHPAHF5X4
EEII15=FFPABEed4D5UQ0dmJH`A=FfH4Be]W14QKJ0A5FVT4@eYZ141IJaGoool001Coool4?UMY13iF
I`@oEFD4?eAS13mBH0<oDEd4?diJ13i<EP@nBU<4@deE14]DF`=FGV@4HFQ]16acN0AjP8D4R8jB19NL
X0BX[:l3^[k11<[>d@CDfmh4f^CY1=oZk`CTko@4jO?h0ncfnPC_n?`4l_[n1?CjoPCen_d4m_[l0oCh
n@CbmOH4ko7b1>_]kPCWj>P4hn?S1=oNgP?JfMT4e]CC1=;>c@C=bLL4a/?11;jj^0>e/:h4ZZBR19fH
UPBAS8/4QX:117YgMPA^Jf`3HV1R15QHFPAEEUT4DeIJ159GG@A@FF43CeYS14eKIPA;FfL4B5]X14EJ
J@A3FVX4@5U[5Oooo`005?ooo`@mEfT4?EEV13eCH`@mDF04?4mM0ca=F@@kBE@4>DE?13I0A`@h@DL4
@TY@0deDF@AGGF84HVQ]16meN@AnPhH4SI6C19fPX@>^/;44`L?31=3De@CKhN<4h^[]1>S`l`C^m_T3
lo[l1?Kmo`Cho_l4n_oo1?goo`Cno_h3o?cl1?Shn0Celo84lNo^1>cZj@CWi><4h]kN0mgIe`CGd]04
dLc91<[4`@C2_;T4]k6^0j^TX@BNV9D4TH^918AoO@AhLg84K6QW161LG@=FDe@4C4Q814Q6B0A;CE44
Be5G14]CF`=:EEl4BEMR14MHI0A6F6H4A5QX145HJ@@oF6XEoooo000Doooo13eGJ@@mEFH4?E=S13eA
H0@lCed3?4eI13]9E0@iADl4=T1713Q1A`A2BU03CEAI15MMHPARJ6d4KgEi17j3QPB=TI<4WJ2Q0jj`
/@C1`l<4d=CE1=_Qh`CRj^d4j?3c1>kfn@?cn_`4m_go1?Sno`Cjool4oOoo1?knoP?lo?`4n?Sh1?Gc
lPCaknh4k>[Y1>OTh`CRg]h3gMWG1=OBd0CAc<T4b/C11<:l^@Bg/Jh3ZjBQ19jHU@BARhT4Q7mm17Qc
LPA/J6L4H5aM0eICE0A<B4P4B4I814]=D@A;DEL4Be=K0dYEG`A9Ef84AeQT14IHIPA4F6P4@EQY13mH
JQGoool001Coool4?EMY13eEIP@mDf<4?E5P13a?G@<lCET4>dUD13U5C`@f@4L4>457149:D0==E5T4
EeeR169XK@A_MGT4OX>618fAT`BMX:43[[2a1<73``C@e=D4fn7S1>;Zk@CXl?<4k_Ki0o?jo0CfoOl4
n?ko1?[oo`Cmool4o_kn0oclo0Chn?P4mO?b1?7_kPC/j^T4inCS1>;NgP?MfML4em;@1=7<b@C:a<44
`[bi1;Na[P>[Y:44WYRE196;R@B4Ogd4N7=b16aXI`APG5d3EU=D14a8B0A8ATP4BdeA14]AE`A;De/3
BUEO14UGHPA7F6@4AUQV14AHJ0A1F6T4?eQZ5Oooo`005?ooo`@mEfT4?EEV13eCH`@mDF04?4mM0ca=
F@@kBE@4>DE?13I0A`@h@DL4@TY@0deDF@AGGF84HVQ]16meN@AnPhH4SI6C19fPX@>^/;44`L?31=3D
e@CKhN<4h^[]1>S`l`C^m_T3lo[l1?Kmo`Cho_l4n_oo1?goo`Cno_h3o?cl1?Shn0Celo84lNo^1>cZ
j@CWi><4h]kN0mgIe`CGd]04dLc91<[4`@C2_;T4]k6^0j^TX@BNV9D4TH^918AoO@AhLg84K6QW161L
G@=FDe@4C4Q814Q6B0A;CE44Be5G14]CF`=:EEl4BEMR14MHI0A6F6H4A5QX145HJ@@oF6XEoooo000D
oooo13eFJ0@lE6D4?59R13]?GP@jC5X3>DUE13M5D0@d@4T4<CY1134h?P@j@4D3A4Y?14mDF0AJGV84
IfY]17AgNPB1Q8L4Si:C0inQX@B`/[84`L?31=3BdPCNhN44j>c/1?7dm@?gno/4n_kn1?gooPCoooh4
ookl1?olnP?on_P4oOSe1?Wdl@Cdk^/4l>WV1>_Th@CVg]X3g]OC1=O?bPC?al84aKfh1;Za[@B]Y:03
WiNC196:QPB3OGX4MW1^16UTHPAMF5L4DDe=0dU5A@A5@T84@d9414A7B`A6Be44ATmF0dIAF`A6Deh4
AEEQ14=FI0A2EfH4@5MX13mHJQGoool001Coool4?EIX13aDI@@lDV84>dmN13Y<FP<iBED4=dE@13A0
B@@a>T44<CPn13Y0A@=4BTl4CeAH15YNHPAWJVd4M7Mj1864Q`B?TY<3Wj6Q1;2b/PC1`l<4d=;B1=kQ
h@CXk>`4lOCe0oOkn`Cjo_h4oOon1?oooPCoo_`4oocj0oojn0Cmn?D4nOCa1?C^j`C`jNH4jnCQ1>KN
fP?Nem<4elo:1<o7`PC5_KP4^[6]1:fTX0>OUi<4THZ618=mNPAfL6h4JFAR15eHE`AACDd3BDE514E2
@PA3@T@4A4M;14I;D@A6CeH3AU5K14ICGPA5EF44@eIT149GIPA0EfP4?eQZ5Oooo`005?ooo`@mEVP4
?5AU13aBHP@kCeh4>TaJ0cU9E@@gAE04=419134j@@@a>3h4>T150dA:C`A?E5P4FUiR16MZK@AdMgX4
PHB718nBT`>OXJ44/;:b1<73``C@d]84g^7Q1>S/k0Cam?D3mo_k1?[noPCmooh4ooon1?ono0Coo?X3
oo[h1?ghm@Cim?44m>k[1?3YiPC[i>44i]kJ0mkGd`CGclX4clO21<Fm^0Bj/Jd4[JBP0inGT`BARXH4
Pgej17I`KPAYI684GEQG155=C@=9ADD4AD9214=2A0A4Ad/4AT]A14I?EP=6DE/4AU=N14EEH@A3EV@4
@UMV141GJ0@oF6XEoooo000Doooo13eFJ0@lE6D4?59R13]?GP@jC5X3>DUE13M5D0@d@4T4<CY1134h
?P@j@4D3A4Y?14mDF0AJGV84IfY]17AgNPB1Q8L4Si:C0inQX@B`/[84`L?31=3BdPCNhN44j>c/1?7d
m@?gno/4n_kn1?gooPCoooh4ookl1?olnP?on_P4oOSe1?Wdl@Cdk^/4l>WV1>_Th@CVg]X3g]OC1=O?
bPC?al84aKfh1;Za[@B]Y:03WiNC196:QPB3OGX4MW1^16UTHPAMF5L4DDe=0dU5A@A5@T84@d9414A7
B`A6Be44ATmF0dIAF`A6Deh4AEEQ14=FI0A2EfH4@5MX13mHJQGoool001Coool4?5IX13]CI0@jD604
>DeL13Q:E`<fAU84=49<134mAP@^=ch4:c8f12ld>0<i?T84A4Q;14iBE@AJGF04J6Y/17EgN0B3Q8D3
TI>C1:2RXPB`/K44`<701<o?cPCKg=/4i>OU0ng^k0Ccm?44moOc1?WflPCjmO04n_C^0o[ck@CjlN/4
n>kX1?CZh`C`i=l4jMkH1>;Gd@?Kd<X4d/O11<Nl]`Bk/:/4[Z>N19nET@>@R8@4PGYg17=]JPAUH5d4
F5=A14]7APA1?C`3>SDe13Tf=P@l?3h4?d961457C@A2Be83@TiG149@F`A2DUl4@EAR141EI@@oEVL4
?UMY5Oooo`005?ooo`@lEVP4>e=T13Y@H0@iCE`4>4YG0cI6DP@d@T`4<Ce612hg?P@[<SH4;c@h0cTn
@PA4B4/4CU9E15YMH0AXJV`4MGMh18>4Q@>ATi<4X::R1;2a/@C0`L04clo>1=_Lf`CTinD3kNk/1??d
l@Cgmo<4nOKb1?[el0Cjm>h3n_?]1?[aj`Chk^P4m>[S1?3Tg`CYg]P4h]OA0m_@bPCBal44akbg1;^`
Z`B^Xih4WiFA0i28Q0B1NWL4LfeZ16EPG@AHDe44BdM6144m?0<j=CD4>CHf13`l?P@o@TH4@DM=149;
DP=2CUL4@U1K149BG`A1E684@5EU13mFI`@nEfTEoooo000Doooo13aFJ0@kDf@4>U1P13U=G0@hBUL3
=TIB13A2C0@a?DH4;SLn12/b=P@_=3P3>Ci214A8B`A>DUD4FUeP16QZK0AeMgP4PhB50i6CT`BPXZ84
/;6a1<31`0C?clh4fmcK1>CWi@?]k^`4loCa1?Ogl`Cim_84n_G`1?[dkP?jlnd4n_7[1?S^j0Cdj^<4
l>CO1>WNf0CRem43fm3:1=;7`@C7_;L4^k2[1:jSWPBOUI43T8R4185jM`AcKFX4IF1M15QCD@A;AdH4
@Cdl0cXe=@@i=SH4?3`n13m2APA1Add4@T]B0d9>E`A2D5/4@U9O145DHPA0EFD4?eIW13iGJAGoool0
01Coool4?5EW13]BH`@iCel4>4aJ13I8E@<dA504<Cm:12hj@`@[<c/49R`a12H[;`<_<cL4>Ce014=7
BPA=D584FE]M16QZJ`AfN7T3QHN719FFUPBSYJ@4/K>b1;fo_PC9b/P4dm;@0mcJePCSh=`4jNGP1>_V
h0C/i^04knKO0o3UgPC`i=`4kn;J1>cOe`CWfM44hM?;1=[<a0?Aa;`4akZc1;^^Z0B]XI/4WiB?1926
P@>0N7<4LFYV16=LF@AECd`4AT4o13Xf=0@b;B/3;BLV130/;0@f=ST4>Se213a3B@@nAdl3?d]E141>
F@A0D5d4@59P13mDH`@oEVH4?UMY5Oooo`005?ooo`@lEFL4>e9S13U?G`@hC5X4=TQE0cA4D0@a?dX4
;SY312/c>`@V;3449R/_0blc=`@i?D04@dM:14e@DPAIFed4J6Y[17IhN@>5QhL4UIJF1:>UY0Ba/k84
_Knn1<W:b0CCd]03g=[F1>?Pg0CYiN04jnKP1>cVh0C_i]l3l>GN1?3Tg0C_h]X4k=oG1>OId@CQdl/4
f/c40m74_0C7^[<4^jjX1:fQV`BOU8l4T8J10h1hL`AaJVH4HeaI15E?C0A6@Cl4>SHd138]:`<]9bH4
<2`/13Hf>@@j?D84?4=913i7C`<oBeD4@4iI141@G@A0DV04?eAS13mFIP@nEfTEoooo000Doooo13aE
I`@kDV<4>DmO13Q<FP@fB5D3=4A@134oBP@^>T<4:c<k12H/<@@V:bl3;c<g13Tm@0A3AdX4CE1B15UK
G@AXJV/4MWQi0hF7Q`BEUYH4XjFT1;6c/PBm_kh4bL[81=?Bd0?Lf]H4hn3L1>WUh0C[i^04k>KP1>oV
g`?`iMh4l>CL1>oRfPC/gmL4imWA1>7Cb`CJc<@3dLBl1<Nj/`Bk[ZP4[J6K19nDS`B@QX43P7Qc175Z
IPASG5T4EDm<14I1?`@j=S@4<Rd[0bdW9P@`;2`4=SHi13Xm@P@l@dT4?TM?0cm;E@A0CUT4@51M141B
H0@oE6<4?eIV13iGJAGoool001Coool4?5EW13]BH`@iCel4>4aJ13I8E@<dA504<Cm:12hj@`@[<c/4
9R`a12H[;`<_<cL4>Ce014=7BPA=D584FE]M16QZJ`AfN7T3QHN719FFUPBSYJ@4/K>b1;fo_PC9b/P4
dm;@0mcJePCSh=`4jNGP1>_Vh0C/i^04knKO0o3UgPC`i=`4kn;J1>cOe`CWfM44hM?;1=[<a0?Aa;`4
akZc1;^^Z0B]XI/4WiB?1926P@>0N7<4LFYV16=LF@AECd`4AT4o13Xf=0@b;B/3;BLV130/;0@f=ST4
>Se213a3B@@nAdl3?d]E141>F@A0D5d4@59P13mDH`@oEVH4?UMY5Oooo`005?ooo`@lEFL4>U9S13Q>
GP@gBeT4=DMD0c92CP@_?DP4;3M112Pa>0@S:Bl47b<W0b@W:@@^<C@4>3/m14=5A`A?D584GEiO16]/
K0=hNGT4QXN719>CTPBPWih4[J^Y1;Ne/PBo_KX3a/C01<g:a@CDclX4f=;=1=[CcPCKdl`3g=;;1=c@
b@CJcLD4el[11=?6_@C>`;L4a[R`0kf_Z0BbYIl4Yi^E19Z?R@B;PGd4OGA_0fiVH`APFEH4DD]914<m
?0@f<Bl4:bHT12<L6P<T7Qd4;2X[138c=P@f>Sl4>D1713]5C@<mBE<4?DaH13i?G0@nDEl4?U=S13iE
IP@mEfPEoooo000Doooo13aEI`@jDV<4>4iN13M;F@@eAe@3<T9>12lmB0@/=d44:34h12<Y;`@O8bL3
92LY12ha=0@h>cd4@dE714m@DPAMGUl4Jfa/0gQiN@B6QhL4Ti>B1:2OWPB]ZjT4]kFb1;nm^P?6a<04
cL[51=C?bPCHd/d4f]?>1=_Cc0?Ld//4g=391=[=a@CGb/44dlJm1<k0]`C6^;03_JnX1;:UW`BWViD4
VXn918^1O@AmM6l3KVIS161IEPAABdT4@cdl13Ha;`@[9R@48a`J0b@N7@@/:R/4<S<f13Hj?`@i@4L4
>dE=0ce9D`@mC5P4?TmL13iAG`@nDf<4?UEV13eGJ1Goool001Coool4?5EW13YBH`@hCUh4=d]I13E7
E0<b@Th4;ce812`g@@@X<CP48bT_11lS9`<T9bT4;S4d13Pk?@A3ADL4Ce1B15eNG`A[K6`3N7Ui18J7
Q`BCTi84X9nN1:f[Z@Bg]K84_kfj0lK4`0C=b/D4e<o:1=SBc@CJdlh4fm?<0mcBb`CLd<T4f/g51=O:
`@CCa[d4c/2g1<Jh/0>m[jP4/ZFO1:NKU@BJShT4Rh5m17edK`=^IV<4H5UF155;B@A3?C`4=S4_12/V
90@S71X391hM12`Z:`@b<cH4=SXo13U0A`@kADd3?DUC13e<F0@nCe`4?U5O13iCH`@nEFH4?EMX5Ooo
o`005?ooo`@lEFL4>U9S13Q>GP@gBeT4=DMD0c92CP@_?DP4;3M112Pa>0@S:Bl47b<W0b@W:@@^<C@4
>3/m14=5A`A?D584GEiO16]/K0=hNGT4QXN719>CTPBPWih4[J^Y1;Ne/PBo_KX3a/C01<g:a@CDclX4
f=;=1=[CcPCKdl`3g=;;1=c@b@CJcLD4el[11=?6_@C>`;L4a[R`0kf_Z0BbYIl4Yi^E19Z?R@B;PGd4
OGA_0fiVH`APFEH4DD]914<m?0@f<Bl4:bHT12<L6P<T7Qd4;2X[138c=P@f>Sl4>D1713]5C@<mBE<4
?DaH13i?G0@nDEl4?U=S13iEIP@mEfPEoooo000Doooo13]EI`@jDF84>4iN13I:F@@dAU<3<D5=12hl
A`@Z=Sl49Rlg124X;P@L82@371lR12@V:0@];c44>3Tk14E5A`A@D544FeaL0fQXJ0AfMWH4Q8B3192@
S`BKVYP4Y::P1:bZY`>d/Jd4^KJb1;jj]@C2_KL4aKjh1<Jm]`?5_;D4aKZc1<>g/0C1]:`4_:nW1;JY
X@B_XYX3YYVC19b@RPBBQh44QG]f17M^JPAYHEd3FeAA14e7A@@n>CP4<B`[12LQ80@M5A<471@B0b<P
80@Z:B/4;c4e13<h?P@f?TH4>D=<0cY7DP@lBeL4?4iK13e@G`@mDf84?EEU13eFJ1Goool001Coool4
>eEW13YAHP@hCUh4=TYI13A6D`<a@Dd4;Sa712Xf?`@V;cL48BP^11`P90<L7b8492HX12d_<@@h>C/4
ADE7151@D@AKG5`3J6QX17IfMPB4Q8<4T92?19^JV0BTXZ04[:ZW0kBa[@Bi][84_[Ze1<:m]`C5_[P4
a[fg0lFl]@C5^[<4`kN`1<6d[0Bl[jL4]ZVQ1:nRVP>VVI<4W92:19:7P@B5NgH4MfiZ16UQG@=KE544
CDM513hi>0@a;2/49b4P11dE4`@L51838b0P12XY:`@_<CD4<cPn13HnAP@i@d`3>TMB13a;E`@lCU/4
?E1O13eCHP@mEFD4?EIX5Oooo`005?ooo`@kEFL4>U5R13Q>GP@fBUT4=4IC0c51C@@^?4L4:SHo12H_
=`@Q:2h4720T0a`O8P@T9RP4;Bla13Pi>`A5ADL4D51A15]LG0=XJ6P4MWIf18B4P`B@T8l4ViZH1:BR
X0B/ZZL3];6]1;Vf/PBn^[D4`[fg1<Fn^0C6_KL3aKbe1<Fj/`C3]k04`KB/1;b_Y`BfZJ44[j:J0jJI
T`BLT8X4TXN118EkMPAgKVX4JF5M0e]DD@A=AdD4?STh134/:`@W8B047ADC11`D4P<S8204:RT[12la
=@@c>3h4=Si613U3C0<jAe84?4]G13a>F`@mD5l4?E=R13eEI@@mEVPEoooo000Doooo13]EI`@jDF84
>4iN13I:F@@dAU<3<D5=12hlA`@Z=Sl49Rlg124X;P@L82@371lR12@V:0@];c44>3Tk14E5A`A@D544
FeaL0fQXJ0AfMWH4Q8B3192@S`BKVYP4Y::P1:bZY`>d/Jd4^KJb1;jj]@C2_KL4aKjh1<Jm]`?5_;D4
aKZc1<>g/0C1]:`4_:nW1;JYX@B_XYX3YYVC19b@RPBBQh44QG]f17M^JPAYHEd3FeAA14e7A@@n>CP4
<B`[12LQ80@M5A<471@B0b<P80@Z:B/4;c4e13<h?P@f?TH4>D=<0cY7DP@lBeL4?4iK13e@G`@mDf84
?EEU13eFJ1Goool001Coool4>eEW13UAHP@gCUh4=DYI13=5D`<`@Dd4;C]612Te?`@U;cL482L]11XM
8P<F5QX46AXL128S90@/;2h4=SLh1492@`A>CTl3FEYJ16EVI@AbLG04OGak18N6Q0B?SX`4UYFC0ifL
VPBSXIh4Z:BP1:bWX`B]Z:<4[JNQ0jfVX0B/Y9d4ZZ6J1:JMUPBQUi04VY6:19>9P`><PW`4Q7]e17Ya
K@A`If<4HeaH15I?C@=7@T04>SDd12l[:@@U8Al46Q<A11L@3P@M6AT38b8S12TZ;@@]<CH4<CPn13@n
AP@g@T`3>DMA13Y:EP@kCE/4?51N13aBHP@mE6D4?EIX5Oooo`005?ooo`@kEFL4>E5R13M>GP@eBUT4
<dEC0c11C@@]>dH4:CDo12D_=`@P9bd46QdR0aHF6P@I6Q`48R<T12`/;P@f=cP4@T9314i>C`=IFUX4
IFIU179aL0AmO7/4QhJ418n>S0BFUI<3WIbJ1:>QWPBXY:04[:NS1:fXX`B]Yj43[JJP1:bTW@BZXIX4
YYfF1:6GT0BJTHX4ThV30hb2O0B4NgD4NW5]171WH`ASG5P4ETm=0dM2@0@j=C@4;b/Y12DQ7`@J4a44
5a0>11dI6@<S8R<4:BX]12da=P@a>3h4=3i613M2C0<iAe44>TYF13]=F`@lD5h4?59R13eDI@@mEVPE
oooo000Doooo13]EI`@iDF84=diN13E:F@@cAE<3<45=12dkAP@Y=Cl49Blg120W;@@J7B835QHJ11TJ
70@R8b@4;2`^13Hg>0A2@T<4CTi?0eUJFPAUIVD4LW5`17elN`B7QX@4Shj<19JET`>MW9X4Xj6N1:RT
X0B/Yj<4[JRS1:fWX@>]YZ04[:BM1:ZQVPBVWIH4XIN@19ZARPBCRH<3S89l18AkM@AjLFd4L6MS16=L
F0AFCdd3Ad9013Xe=0@_:bT49B4O11XC4@@G40h47ATI0b<R8`@Y:Rd4;C4f134h?P@d?TH4=d9<0cU7
D@@jBUH4>deK13a@GP@lDV84?EAU13eFJ1Goool001Coool4>eEW13UAHP@gCUh4=DYI13=5D`<`@Dd4
;C]612Te?`@U;cL482L]11XM8P<F5QX46AXL128S90@/;2h4=SLh1492@`A>CTl3FEYJ16EVI@AbLG04
OGak18N6Q0B?SX`4UYFC0ifLVPBSXIh4Z:BP1:bWX`B]Z:<4[JNQ0jfVX0B/Y9d4ZZ6J1:JMUPBQUi04
VY6:19>9P`><PW`4Q7]e17YaK@A`If<4HeaH15I?C@=7@T04>SDd12l[:@@U8Al46Q<A11L@3P@M6AT3
8b8S12TZ;@@]<CH4<CPn13@nAP@g@T`3>DMA13Y:EP@kCE/4?51N13aBHP@mE6D4?EIX5Oooo`005?oo
o`@kEFL4>E5R13M>GP@eBUT4<dEC0c11C@@]>dL4:CI012@_=`@O9bh46AhS0a0A50@=30h45ADF11lO
80@Z:BX4=3@d13hn?P=7B4L4DU9A15eMG0AWIfD4LW5_17YiN0B1Ogl3QhF418b:R0B@SH/4THj;19>@
S0BDT8`3U8n:19:=R0B?RXD4RhF018EoNPB0NG@4NG9]0g9/J0A[I644HE]I15MBC`A;AdD4?c/i0c@`
;P@Y9B@47AXI11D@40@D3`h461@D11hL7@<S92H4:2/`12`b>0@`>404<ci613I2C0<hAU84>DYF13Y=
F`@kD5h4?59R13aDI@@mEVPEoooo000Doooo13]EI`@iDF84=diN13E:F@@cAE<3<45=12dkA`@Y=T04
92lg11lW;P@I7R<3414D10d<3P@E5AH47alP12XY:P@d=3@4?Shn0dM8A`ABDU44GEeL16MWI@AbLFl4
NWUh185oO`>7QH@4S8Z8192=R`BASX/4Ti2<19B@S0>DShX4TXf818n:Q@B;QH04QGmj181iM0AiLVd3
LVaX16]TH@AQFeT4Ee9?14]7A@@o>cT3=30^12TU90@M6QT45A0@11@?3P@H51@47Q`M0b<T9P@X:c04
;38h130h@0@c?TH4=T9<0cQ6DP@iBUH4>TeK13]@GP@lDV84?5AU13eFJ1Goool001Coool4>eEW13UA
HP@gCUh4=DYI13=5D`<`@Dd4;C]712Tf@0@T;cL47bL^11TN8`<@4A@43@`>11DE5P@O7b04:RTZ13@d
=0@n?Sh3AdQ7159BD@AMGE`4IfMU179aK`AjNGP4PGmo0hN5Q0B<RXP4T8f;196>R`BCT8`4U92<0iB?
RPBBSHP4ShZ518^5P0B5OgX4P7Ud17UbK@=bK6P4JfAQ165KF@AGDTl4BdM513lk>@<d<2h4:BDT11dJ
6@@E410450l>11PD50@N71d38b@V12P[<0@/<SP4<3Q013<nAP@f@T`3>4IB13U:EP@jCE/4>e1N13aB
HP@lE6D4?EIX5Oooo`005?ooo`@kEFL4>E5S13M>GP@eBUT4<dID0c11CP@]?4P4:CM112D`>@@P:C04
6R0V0a<F6P@;2P`420L7114@40@L71`49RHW12l_<0<g=cP4?clo14Q8A`AADE04FUYI169RH@AXJ6L3
KFe/175`L0AeM7<4NGMf17YiM`AkNWL3NgUf17YgM0AgM744M6m/16aXI0ATH5`4Ge]H0eUGE0AACdd4
B4E513lm?0@g=3@4;2XZ0b8O7`@J5aH44`l=10l81@@B30X46ALG11lO8@<T9RX4:2dc12`d>`@`>D84
<ci813E3CP<gAe<4>4YG13Y=F`@kD5l4>e9R13aDI@@lEVPEoooo000Doooo13]EI`@iDF<4=diN13E:
F@@cAU@3<45>12dlB0@Y=d449C0i120Y<0@J82H34aHJ10/:30@81`L44A0@11`L70@V9RL4;bl`0cLg
>0@o?cl4B4Q7155AD0AJFUT4HV9Q16QXI`=]KF`4LG1`17EdL`AiMgH4NWUg17]jM`=kNGH4NWMd17Md
L@AdKf`4K6QT16APG0AOFeP3FEMD155?C@A8ADD4?cdl13Ld=0@/:RX38QlO11XG5P@C3`d43`P5118<
2P@I5aL47alQ0b@V:P@X;C<4;3@k130i@P@c?TP4=D=>0cM7D`@hBUL4>TeK13]@G`@kDV84?5AU13aF
J1Goool001Coool4>eEW13UAH`@gCUh4=DYI13=6E0<`@Dh4;Ca812Tg@@@U<3T482T`11XP9P<C5QX4
2`X<10P71`@A410471`L12HV9`@_;c03=cLh13lo?`A8B4L4DE5@15YJF@ARHV44J6QW0fe]K0AaL704
MGAc17UgMPAjNGL4NgYg0g]iMPAjMg@4MgAa17A_K0A/J6@4I61L15mKF0=IEe@4DDm=14Q5A@@o?C`4
=c@d12`Z:P<R7al46QLF11<?3@@?20D44P`:11TG5`@O7b4392HZ12P]<`@/=3/4<3U213<nB0@e@dh3
=dMC13Q:E`@jCE/4>e1O13]BHP@lE6D4?5IX5Oooo`005?ooo`@kEFL4>E5S13M>GP@eBUT4<dID0c11
CP@]?4P4:CM112D`>@@P:C046R0V0a<F6P@;2P`420L7114@40@L71`49RHW12l_<0<g=cP4?clo14Q8
A`AADE04FUYI169RH@AXJ6L3KFe/175`L0AeM7<4NGMf17YiM`AkNWL3NgUf17YgM0AgM744M6m/16aX
I0ATH5`4Ge]H0eUGE0AACdd4B4E513lm?0@g=3@4;2XZ0b8O7`@J5aH44`l=10l81@@B30X46ALG11lO
8@<T9RX4:2dc12`d>`@`>D84<ci813E3CP<gAe<4>4YG13Y=F`@kD5l4>e9R13aDI@@lEVPEoooo000D
oooo13]EI`@iDV<4=diO13E;FP@cAeD3<4=@12dnBP@Z>4@49S8l124[=0@L92/35Q/P10lA5@@71PL4
1@@410d=3P@H61T48R8S0bTY:P@^;bl4=CHf13`m?PA3A4D4Bd];155AD@=EEeH4FU]J15eNGPAPHF04
HV9Q16=SHP=SHf44HV9P165PG`AMG5/4F5QG159CD`A:BT/3@d=313/k?0@d=3D4;Rh^12HU9P@N7Ah3
5Q@D10h;2P@:10443@L411@B4P@K6ad482<V0bDZ;`@Y<3L4;CHn130kA0@b@4X4=DA?0cM7E0@hBUP4
>DeL13Y@G`@kDV<4?5AV13aFJ1Goool001Coool4>eEW13UBH`@gCUl4=D]J13=7E@<`@e04;Ci:12Xh
A0@V<S`48B/d11`T:`<F6b043a4E10L61`@510@43@d>11PH6@@R8R<3:BTZ12h_;`@e=SH4?3dn14=4
A@A;Bd/4DE5A0eEGEPAJFeX4GEiN161QH0ARHV44Hf=R0f=SH@ARHV04HF1O15eLF`AHF5L4DU=C14Y:
B`=3@d<4>c/l13@d=@@^;Rh49RDV11hM7P<F51@43P/:10X40@@=1`@4518B11/K7@@P8bH39BX_12T`
=`@]=Sh4<3]41390BP@eA4l3=dMD13Q:F0@iCE`4>U1O13]BH`@lE6H4?5IX5Oooo`005?ooo`@kEFL4
>E9S13M>G`@eBeX4<dME0c13D0@]?TX4:SQ412Hb?0@Q:c@472@[0aHK80@?4AD41`H710D410@=3@h4
61PI128R8`<Y:BX4;Rl_13Df=P@l?Ch4@dA514];B`AADE43EEMF15YKFPAMGUh4H65P169RH@ASHf83
Hf=Q169RH0AQH5l4GEaK15QHE`ABDe<4BTY;0d=3@`@k>c`4=3@e12h^;P@V9BH47QdN0aHD50@>2`X4
2P@110d710@D4Q846a/M120S9P<U:Rl4:C0g12df?P@`>d@4<T1:13E4C`<gAe@4>4YH13U=G0@jD5l4
>e9S13aDIP@lEVPEoooo000Doooo13]EI`@iDV<4=diO13E;FP@cAeD3<4=@12dnBP@Z>4@49S8l124[
=0@L92/35Q/P10lA5@@71PL41@@410d=3P@H61T48R8S0bTY:P@^;bl4=CHf13`m?PA3A4D4Bd];155A
D@=EEeH4FU]J15eNGPAPHF04HV9Q16=SHP=SHf44HV9P165PG`AMG5/4F5QG159CD`A:BT/3@d=313/k
?0@d=3D4;Rh^12HU9P@N7Ah35Q@D10h;2P@:10443@L411@B4P@K6ad482<V0bDZ;`@Y<3L4;CHn130k
A0@b@4X4=DA?0cM7E0@hBUP4>DeL13Y@G`@kDV<4?5AV13aFJ1Goool001Coool4>eEW13UBI0@hCf04
=TaL13=8E`<aA584;T1=12/kA`@W=D048bli11hX<0<I8BL44aPM10d@4`@61@H410<410/;30@D51D3
71dM128R8P@V9RH4:b/[130a<P@c=SH4=cXj0c`o?`A1A4D4ADQ814Q;B`A;CDd7C4m?14]>CPA:CDh4
BTe?14Q;CPA4ATX4@4=50c/m?`@c=CP4;2d_128S9@@J6Q/44a8C0``:2`@70P442PD3114>3`@G61X4
7B0T128W;@<V;S@4:S@l12hi@P@`?DP4<d9=13E5DP<gBEH4>4]J13U>G@@jD604>e9S13aDIP@lEVTE
oooo000Doooo13]EI`@iDV@4>4mP13I<G0@cB5L3<DAB12i0C@@[>dL49cE012<_>@@N:3036B4W11<H
7@@=41<41PD610@310@;2``451@E0a`M7@@R8R849RHV12/[:`@`<C84<cHf13Lj>P<l?cl4@DA514E8
B0A8Bd/4Bde=1da?C`A;CTh4BTe>14Y=C`A8Bdh4A4I:1413A@<k?Cl4<cDh12`];`@R8bD46QXK11<B
4`<<2P/41`8110X50`@A3Pl45aPJ11dP90@R9bd39Rhd12Xd?0@^>D84<3e813=2C@@eAE83=dUF13Q;
FP@iCUd4>U1P13]BH`@lE6H4?5IY5Oooo`005?ooo`@kEFL4>E9T13Q?H0@fC5`4<dQG0c54DP@^@4d4
:c]712Le@0@S;cT47RP`0aTQ9`@C61d43A0C10H51P@40`@42`/<11@D5@<L7Ad48R8R12HV9P@[:b/4
<34b13<f=P@g>SX3?3lo1454A@A5B4P4B4];14]=C@M<Cdl4Bdi>14Y=CPA:CDl4B4]>14A6BPA0@dD3
>cdo13<e>0@/;Bl48R<U11XJ6`@C4Q<330X;10L20@@:1@<44@h?11LH6P@M82@48RL]0bH^=0@Z=3`4
;SU2130mB0@c@Td4=DEB0cM9EP@hBeX4>DiM13Y@H0@kDV<4?5AV13aFJAGoool001Coool4>eEW13UB
I0@hCf04=TaL13=8E`<aA584;T1=12/kA`@W=D048bli11hX<0<I8BL44aPM10d@4`@61@H410<410/;
30@D51D371dM128R8P@V9RH4:b/[130a<P@c=SH4=cXj0c`o?`A1A4D4ADQ814Q;B`A;CDd7C4m?14]>
CPA:CDh4BTe?14Q;CPA4ATX4@4=50c/m?`@c=CP4;2d_128S9@@J6Q/44a8C0``:2`@70P442PD3114>
3`@G61X47B0T128W;@<V;S@4:S@l12hi@P@`?DP4<d9=13E5DP<gBEH4>4]J13U>G@@jD604>e9S13aD
IP@lEVTEoooo000Doooo13]FJ0@jDfD4>51Q13I=G@@dBUT3<TIE1312D0@]?T/4:SU512Hd?P@R;SL3
7BL_11PP9`@B61d430lC10D41@@30P842PX;0a8B4`@G61P46Q/K11dN7P@P8R849BPX12P/;0<Y;Rh4
;30a12ld=@@c=cT4=3Tk13Dj?0<g?3h4=c`o13Hl?P@f?3l4=C/o138h?0@]<cL39R``120U:@@I7B04
4Q@G10d>40@920T31@4110L30P@?3@h45QHI11/O8`@P9R`49Bdd0bTb>`@/>444;ca71350C0@dA504
=DMD0cM:F0@hCE/4>DmO13YAH@@kDf@4?5EV13aFJAGoool001Coool4>eIX13YCI@@hD644=TeM13A:
F@<bAUD4<49@12dnB`@Z>DD49S@n128^=`<M9bl4620W118H7@@<3a<41@@510<20P@:2P/34Q8C11LH
60@J6a/47AhN120R8P@U:2P4:2`/0bT^;P@/<344;c@e13<g>@@d>C/4=CXl0cLl?P@g?3l4=S`n13Hl
?`@e>cl4<SPl12dc=`<V;30482DY11TM80@B51L43@h@10T82@<50@441`<210l=3P@F5QT46alS120V
;0@U;C@3:C8k12`h@@@_?4L4<D1<13A4D0@eAe@3=dYH13Q=F`@iCel4>U5Q13]CI0@lEFH4?5IY5Ooo
o`005?ooo`@kEVP4>U=U13Q@H@@fCEd4=4YI0c96E@@`@U04;Ci;12XiA@@V=3h48Rhg0adW;`@H82L4
4QPM10`?4`@510D40`8210X:2`<B4Q<45aPH11XK6`@M7Qh4828R12DX:0@X;2`3:Bh^12``<@@_=3D4
<cLi13@i>`@e>S`3=c`n13Ll?`@f?3h4=S`o13Dk?`@b>3`4;C<g0bH/<0@P9BT46AdP118D5`@=3Q04
2@P90`D10@@70`843`d>11HF6@@K7b<482H/12D]=0<Y<S/4;3Q112llA`@a@4`4=4A@13E7E0<gBUP4
>4eK13U?G`@jDF44>e=T13aEIP@lEVTEoooo000Doooo13]FJ0@jDfD4>51Q13I=G@@dBUT3<TIE1312
D0@]?T/4:SU512Hd?P@R;SL37BL_11PP9`@B61d430lC10D41@@30P842PX;0a8B4`@G61P46Q/K11dN
7P@P8R849BPX12P/;0<Y;Rh4;30a12ld=@@c=cT4=3Tk13Dj?0<g?3h4=c`o13Hl?P@f?3l4=C/o138h
?0@]<cL39R``120U:@@I7B044Q@G10d>40@920T31@4110L30P@?3@h45QHI11/O8`@P9R`49Bdd0bTb
>`@/>444;ca71350C0@dA504=DMD0cM:F0@hCE/4>DmO13YAH@@kDf@4?5EV13aFJAGoool001Coool4
?5IX13YDI@@iDF84=dmO13E<G0<cBEP4<DED12m2C`@/?DX4:CU512Hd?`<R;SP47BPa11PQ:0@C6Al4
3A4E10@61`@0000310D510h?40@D5QL45APH11DG5`@D5aP45QXK0aXN7`@N8b@47B<U11dS9P@P:2`4
9Bda0bP`=0@X<3D4:C4f12Ta>0@Y<CL49ble128Z<0<L92X45adR114F6P@;41<420X=10L51P<91`L4
410B11DH70@K82D482L^12@]=@@X<c`3:cQ212hlA`@a@4`4<dA@13E7E0@fBEP3>4aK13U>GP@jD604
>e9S13]DI@@lEFL4?5MY5Oooo`005?ooo`@lEVP4>UAU13UAHP@gCel4=DaL0c=9F0@aAE@4;d9?12`m
BP@Y>DD49S@o0b8^>0@M:344624X11<I7`@=4AD410H7100000<41@D43Pl@11@F5`@E61P45ALG11@G
60@F6Q/36QhO11hS90@M8bD47B<V120X;0@U;C43:30d12P`=@@Y<CH4:C4h12Ta=`@W;cD48RX`0a`T
:P@G7B844AHJ10/@4`@82Pd41`D60`T71`@@41845APL11/P9@@P9bh492de12Pc?0<[>484;Sa71350
C0@cA504=DMD13I9F0<hC5/4>DiN13Y@H0@kDV<4>eAU13aEI`@lEfTEoooo000Doooo13aFJ0@jE6D4
>E5R13M?G`@eC5`3<dUH1355E0@_@Tl4;3e:12TiA@@V=3l38Rhh11dX<@@H8BP44aTO10dA5@@41PL4
00000`@51@@>3a0451HG11DH60@E5aL451LH11HJ6`<J7Ql47R<T11dS9@@M8bH482P/12D]<@<X<3@4
:30e12Ta=P@Y<CP4:C4g12L_=@@R:S0372@Z11LM8P@A5QX42a0C10P:3@@71@H32@L7110@4P@E61`4
6b0U120W;P@T;CD4:3<l0b/h@P@^?4L4<D1<13=4D0@eAe@4=TUH0cQ<F`@iCUh4>U1P13]BH`@kE6D4
?5EW13aGJAGoool001Coool4?5IX13YDI@@iDF84=dmO13E<G0<cBEP4<DED12m2C`@/?DX4:CU512Hd
?`<R;SP47BPa11PQ:0@C6Al43A4E10@61`@0000310D510h?40@D5QL45APH11DG5`@D5aP45QXK0aXN
7`@N8b@47B<U11dS9P@P:2`49Bda0bP`=0@X<3D4:C4f12Ta>0@Y<CL49ble128Z<0<L92X45adR114F
6P@;41<420X=10L51P<91`L4410B11DH70@K82D482L^12@]=@@X<c`3:cQ212hlA`@a@4`4<dA@13E7
E0@fBEP3>4aK13U>GP@jD604>e9S13]DI@@lEFL4?5MY5Oooo`005?ooo`@lEVT4>eEW13UBI0@hD644
=diN0cE;F`@cBEP4<DID12m2D0@]?d`4:SY70bHf@@@S<C/47b/e11XU;@@E7RD441HL10X>4P<41PT4
10H810X=3`@=4Q@441@E110E5P@B5aT34QPK118J7@@E7R<4628X11/U:`@L9bh37bTb128]=P@S;SL4
8R`d124[<`@O:C046b@[0aHN90@A5a`43A8F10/?4@@720T42P/=0a8E6@@H7B847B@[124Z<P@U<3T4
:3Do12/iA0<^?TT4<D5>13=4D@@dAeD4=TYH13M<F`<hCUh4>E1P13YBHP@kDf@4>eAV13aFJ0@lEfXE
oooo000Doooo13aFJ@@kEFL4>E9T13Q@H@@gCUh3=D]K13=9F0@aAU@4;d9@12doC0@Z>TL39SI112<a
>`@O:cD46RD]11DN9@@@5Q`42PhB0`@62@@41PP42Pd?10dB50@@51D441DF118G6@<B61/44QXM11DN
8`@H8RP46bD[11`W;P<O:C848Rdf12<^=`@R;3@48B/c11lY<0@K92/35QhT114G70@=4QH42`lA10L8
2@@:2`d34QDI11PM8P@M92/48BXb12D`>@@X=Cl4:cU40bhnB@@a@Dh4<dAA13A7E@@fBUP4=daK0cQ>
GP@iD604>U9R13]CI0@kE6H4?5IX13aGJQGoool001Coool4?5IY13]EI`@iDV@4>51Q13M>GP<eBe/4
<dUH1356E0@_@U04;Cm<12XjA`<V=T448c4k11l[=@@J9Bd45AhU110F70@:3Q8310H910@620@:3@l4
3A8D110D5@@@5AH44QLI0a8H6`@B6Qd45AhS11PR:0@K9B/472L^0alY<P@R;CH48bhg128/=0@Q:c<4
7bT`11/T:`<F7R@44ALL10dB5P@;3a441`P910X;3@<B5AT461dR11dT:`@Q:S849C0i12Pe?`@[>D@3
;Si91351CP@cA544=4ME13I:F0@gC5/3>4iN13U@H0@jDV84>e=T13]DIP@lEVP4?5MZ5Oooo`005?oo
o`@lEfX4>eIX13YDIP@iDV@4>51Q0cM>G`@eC5d4=4YJ1397E`@`AE<4;T5?0b`nB`@Y>TL49SI212<a
?0@O;3H46bH_11HP:0<A6R442Q4G10H;40@52a042a8G10lG70@?5a/33aPL114L8@@D82H462<Z11PT
:`@H9Bd36BH_11XV<0@K9c4472Pa11`W<0@K92d46R0X0aHM8`@B5a`430lB10/=4@@@5AX45ahT0a`U
;0@P:c@4930j12Le@0@Z>DD4;Ce91311CP<bA544<dME13E9F0@fBeX4=deM13U?G`<iD644>U9S13]C
I0@kE6H4?5EW13aFJ@@mEfXEoooo000Doooo13aGJP@kEVP4>UAV13UBI0@hD643=diO13E<G@@dBUX4
<TMG1315D`@^@Dl3;3i;12TjA`@V=T848c4l11l/=P@K9Rl45R0X0a4J8@@:4AL41P/@10D;40@;4QL4
3aLL10lG6`<?61`44A`Q11@P9P@H8bX462@[11PU;@<I9Rl46RH`11/W<@@L:34472L`11/T;@@J82P3
5QdS118G70@<3a842`dA110E6P@G7R@372D/120[=0@T<3X49cE012XiA@@]?DT4<45>0c94D@@cAeD4
=DUH13I;FP@gCEd4>DmO0cU@H@@jDV<4>e=T13]DIP@lEFL4?5IY13eGJQGoool001Coool4?5MZ13]F
J0@jE6H4>E9T13Q@H@<gCUl4=DaM13A:FP@bAeL4<4EC12i1C`</?T/4:CY712Hf@P@S<C`47b`f11/V
;`@F82P34AXQ10XA5`@62a041@/@10/B5`@?5a`43aLK0`lH70@A7244520V11PS:P@H92/462D]0aTV
;`@J9S046bLa11`X<@@L9c046b@]11XP:0<F7B<44QLL10`?4P@;3A4441DJ11LN90<L9B`482/d12@`
>P@W=D04:SU512dmB@@`@Dh3<TAA13=7E@@eBEP4=T]J13M=G@@iCel3>E1Q13YBH`@kDf@4>eAV13aE
I`@lEVT4?EMZ5Oooo`005?ooo`@lEfX4>eIX13YDIP@iDV@4>51Q0cM>G`@eC5d4=4YJ1397E`@`AE<4
;T5?0b`nB`@Y>TL49SI212<a?0@O;3H46bH_11HP:0<A6R442Q4G10H;40@52a042a8G10lG70@?5a/3
3aPL114L8@@D82H462<Z11PT:`@H9Bd36BH_11XV<0@K9c4472Pa11`W<0@K92d46R0X0aHM8`@B5a`4
30lB10/=4@@@5AX45ahT0a`U;0@P:c@4930j12Le@0@Z>DD4;Ce91311CP<bA544<dME13E9F0@fBeX4
=deM13U?G`<iD644>U9S13]CI0@kE6H4?5EW13aFJ@@mEfXEoooo000Doooo13aGJ@@lEVP4>eEW13YD
IP@jDfD3>E9S13Q@H@@gCel4=TeM13A;F`@cBEP3<DIF12m4D`@]@Dl4:ci;12TjA`@V=d<48c<n0al^
>@@L:C@46BH`11LS;@@C7RT44QdV11@O:@<E8BX45B4Y11HR:P@I9Rh47BXc11l/=P<O;CP47bhi21l]
>0@P;ST47b`f11XT;@<D72@45AdU11TS:`@L9c047b`e12<a>`<V=D44:CY612`mBP@^@4h4<4=A1396
E0@dB5L3=DYJ13I<G0@gCUh4>4mP13UAH@@jDV<3>U=T13]DI@@kEFL4?5EX13aFJ@@lEfT4?EMZ5Ooo
o`005?ooo`@lEfT4?5IX13]EI`@jE6H4>U=U0cUBH`@hD644=dmO13I=G@@dBe/4<dUH0c56EP@_A5<4
;D5?12/nB`@Y>TL49SM312<c?P<O;ST472Td11TV<0@G8bd44ahY118M9P@D7bT35B4Z11DQ:@@F8RX4
6BH^11dZ<`@O;3H37bdh11l^>@PO;CP482hi11l/=P@J92d351`T11DM9@@I8b/472L`11l/=@@S<C/3
9SE112TjAP@/?DX4;T1>1313D@@bAU@4=4QG0cE:FP@fC5`4=diN13Q?H0@iDF44>U9S0cYCI0@kE6D4
>eEW13aEJ0@lEVT4?5MY13eGJQGoool001Coool4?5MY13aFJ0@kEFL4>UAV13YCI@<iDV<4>51Q13M?
G`@fCEd4=4]K13=9F0<aAUH4;dAC12e1C`@[?T/4:CY712Hg@`@S<ch37bhi11`Y=0@I9S045b<]11<N
:@@B7BH451lY0aDQ:P@E8BT45R8Z11TV;P@M:S<47b`f0al]>0@O;ST87bdh120^>@@O;3H46R@]0a@L
90@E7BD46B<[11`W<0@O;3D48c4k0bHe@@@Y>TH4;3e:12i0CP@`@e44<TID13A8E`<eBUX4=TaL13M>
GP@hCf04>E5Q13YBH`<jDf@4>eAU13]EI`@lEFP4?5IY13aGJ@@mEfXEoooo000Doooo13aGJ@@lEVP4
>eEW13YDIP@jDfD3>E9S13Q@H@@gCel4=TeM13A;F`@cBEP3<DIF12m4D`@]@Dl4:ci;12TjA`@V=d<4
8c<n0al^>@@L:C@46BH`11LS;@@C7RT44QdV11@O:@<E8BX45B4Y11HR:P@I9Rh47BXc11l/=P<O;CP4
7bhi21l]>0@P;ST47b`f11XT;@<D72@45AdU11TS:`@L9c047b`e12<a>`<V=D44:CY612`mBP@^@4h4
<4=A1396E0@dB5L3=DYJ13I<G0@gCUh4>4mP13UAH@@jDV<3>U=T13]DI@@kEFL4?5EX13aFJ@@lEfT4
?EMZ5Oooo`005?ooo`@mEfX4?5MZ13aGJ@@lEVT4>eEX0c]EI`@jE6H4>U=U13UBI0@iDF<4>51R0cM?
H0@fCUl4=DeM13A;F`@cBET4<DMG1315E@<^@e84;45@12/oCP@Z?D`4:3a:2bPkBP@X>TT49cU712@f
A@@S=D<48cA22b<d@@@R<d048S8n128b?@@U=T83:3Y712XkB@@[?D/4;D1>12i2D0@`A5<3<TMF13=9
F0@dBeX4=TaL13M>GP@hCf04>51Q0cUAHP@jDV<4>U=U13]DI@@kE6H4>eEW0caEJ0@lEVP4?5IY13aG
J@@lEfX4?EMZ13eHJaGoool001Coool4?EMZ13aGJP@lEfT4?5IY13]EJ0<kEFL4>UAV13YCI@@iDV@4
>E5S13Q@HP<gCf04=TiO13E=G@@dBe/4<dUI1357E`@`AED3;T=B12a1D0@[?dh4:Se<12PlBP/X>dX4
:3Y912LiA`@T=TD48cE312<d@P/S=4448S=0128b?P@R<Sd49CI20bPjA`@Z>dT4:ce;12e0CP@^@U04
<4AC0c97EP@cBEP4=4]J13I<G0@gCUh4>4mP13Q@H@<iDF84>U9S13YCI@@kE6D4>eAV13]EI`<lEFP4
?5IX13aFJ@@lEfT4?5MZ13eGJP@mF6/Eoooo000Doooo13eGJP@lEfX4?5MY13aFJ@@kEFP3>eEW13YD
IP@jDfD4>E9T13UAH`@hD683=dmP13I>G`@eCEd4=4]K13=9F@@aAeL4<4EE0bi3DP@/@E04:cm>12Xm
C0@X?4X;:3]:12PjB@@W>DL493I512<e@`@S=48;8cA1128c@0@R<Sh48S8m12Df@P<X>TL4:S]912/m
B`@]@4h4;T9@1314D`<bAeH4<dUH13A;FP@fC5`4=diN13Q?H0@hD643>E5R13YBH`@jDfD4>eAU13]D
IP@kEFL3?5EX13aFJ0@lEVT4?5MY13aGJP@mEfX4?EQ[5Oooo`005?ooo`@mEfX4?5MZ13aGJ@@lEVT4
>eEX0c]EI`@jE6H4>U=U13UBI0@iDF<4>51R0cM?H0@fCUl4=DeM13A;F`@cBET4<DMG1315E@<^@e84
;45@12/oCP@Z?D`4:3a:2bPkBP@X>TT49cU712@fA@@S=D<48cA22b<d@@@R<d048S8n128b?@@U=T83
:3Y712XkB@@[?D/4;D1>12i2D0@`A5<3<TMF13=9F0@dBeX4=TaL13M>GP@hCf04>51Q0cUAHP@jDV<4
>U=U13]DI@@kE6H4>eEW0caEJ0@lEVP4?5IY13aGJ@@lEfX4?EMZ13eHJaGoool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003o
oooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool009Woool30000Q?oo
o`00W?ooo`030000oooooooo087oool007coool200001?ooo`800004oooo0P0000Coool400000_oo
o`<00003oooo0`0000?oool20000O_ooo`00Noooo`040000oooooooo00000_ooo`040000oooooooo
00000_ooo`040000oooooooo00000_ooo`040000oooooooo00000_ooo`030000oooooooo00?oool0
10000?ooooooo`0008?oool007goool00`000?ooooooo`03oooo00D0003oooooooooool000000_oo
o`040000oooooooo00000_ooo`030000oooooooo00@00002oooo00@0003oooooool00023oooo001n
oooo00<0003oooooool00oooo`040000oooooooooooo0P0000Coool300000oooo`800004oooo1000
08;oool007_oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`00
00Goool00`000?ooooooo`2=oooo001loooo0P0000Coool200001?ooo`800005oooo0P0008ooool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 6.8125}} -> {-5.43703, \
-3.39431, 0.260941, 0.260941}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4.5 Summary",
  FontFamily->"Times New Roman"]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "As shown above, this chapter have clarified that the discrete orthogonal \
wavelet transform is a quite useful tool for image data compression as well \
as expansion.\n\tThis chapter has introduced the applications of the wavelet \
transform to the image data. The first section of this chapter has described \
about the discrete orthogonal wavelet transform, which employ the Daubechies, \
Coifman and Baylkin's base functions. The second section has described the \
monochrome image data compression and expansion by the wavelet transform. \
This section has been an introduction of the wavelet image processing. Also, \
this section has demonstrated that ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  "lly remarkable image compression rate is possible by the wavelet \
transform. The third section has concerned with the color image compression \
and recovery. It has been revealed that the compression rate and \
recoverability depend on the order of base function. The fourth section has \
proposed one of the orthogonal color image decomposition. In this section, \
the color image data have been represented in terms of the spherical \
coordinate quantities. The magnitude of color image characteristic vector has \
corresponded to a radius. The attitude and longitude have been represented in \
terms of their directional co-sinusoidal components. In continuation to this \
section, the fifth section has described about the wavelet compression and \
recovery to the color image data represented in terms of the spherical \
coordinate quantities. The sixth section has revealed that the color image \
data compression rate by the wavelet transform depends on the way of image \
data representations. Namely, higher recoverability could be achieved by the \
spherical coordinate representation. The seventh and final sections have \
concerned with the expansion of a small number of color animation data to a \
large number of ones by the wavelet transform. This has demonstrated that the \
three-dimensional wavelet transform makes it possible to increase the number \
of animation data.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    TextAlignment->Left,
    TextJustification->1,
    FontSize->10],
  StyleBox["\t",
    TextAlignment->Left,
    TextJustification->1],
  StyleBox[
  "Thus, we have confirmed that the wavelet transform along with the vector \
fields provides not only the simple image data compression and expansion \
tool, but also suggests a higher compression rate possibility, i.e., the \
image data represented in terms of the spherical coordinate components could \
be compressed with higher recoverability by the wavelet transform. ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["REFERENCES", "Section",
  FontFamily->"Century",
  FontSize->12]], "Subsection"],

Cell[TextData[{
  StyleBox["[1] Stephen Wolfram, ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10],
  StyleBox["The Mathematica Book",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10,
    FontSlant->"Italic"],
  StyleBox[
  ", 3rd ed. (Wolfram Media/Cambridge University Press, 1996).\n[2] \
J.D.Jackson, \"Classical Electrodynamics 3",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10],
  StyleBox["rd",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" Edition,\" John Wiley & Sons, New York (1998).",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10]
}], "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 555}},
ScreenStyleEnvironment->"Presentation",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{792, 528},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingStartingPageNumber->53,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          OptionValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True},
ShowCellLabel->False,
StyleDefinitions -> "Classroom.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S5.34.1"->{
    Cell[46425, 1337, 140, 4, 72, "Input",
      CellTags->"S5.34.1"],
    Cell[46590, 1345, 319, 7, 126, "Input",
      CellTags->"S5.34.1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S5.34.1", 7371148, 113747}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 265, 8, 43, "Title"],

Cell[CellGroupData[{
Cell[2007, 61, 138, 3, 75, "Section"],
Cell[2148, 66, 3979, 70, 825, "Text"],
Cell[6130, 138, 325, 5, 103, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6492, 148, 336, 12, 77, "Section"],

Cell[CellGroupData[{
Cell[6853, 164, 304, 11, 55, "Subsection"],
Cell[7160, 177, 637, 16, 91, "Text"],

Cell[CellGroupData[{
Cell[7822, 197, 227, 8, 49, "Subsubsection"],
Cell[8052, 207, 224, 7, 144, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[8325, 220, 295, 11, 27, "Subsection"],
Cell[8623, 233, 1440, 28, 178, "Text"],

Cell[CellGroupData[{
Cell[10088, 265, 111, 2, 47, "Subsubsection"],
Cell[10202, 269, 702, 20, 42, "Text"],
Cell[10907, 291, 443, 8, 170, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11387, 304, 115, 2, 25, "Subsubsection"],
Cell[11505, 308, 702, 20, 42, "Text"],
Cell[12210, 330, 430, 7, 170, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[12677, 342, 111, 2, 25, "Subsubsection"],
Cell[12791, 346, 585, 16, 66, "Text"],
Cell[13379, 364, 527, 14, 270, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[13943, 383, 111, 2, 25, "Subsubsection"],
Cell[14057, 387, 820, 21, 91, "Text"],
Cell[14880, 410, 516, 14, 270, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[15433, 429, 116, 2, 25, "Subsubsection"],
Cell[15552, 433, 738, 22, 66, "Text"],
Cell[16293, 457, 114, 3, 72, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[16444, 465, 116, 2, 25, "Subsubsection"],
Cell[16563, 469, 405, 11, 41, "Text"],
Cell[16971, 482, 222, 6, 126, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[17230, 493, 114, 2, 25, "Subsubsection"],
Cell[17347, 497, 713, 20, 91, "Text"],
Cell[18063, 519, 520, 15, 288, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[18620, 539, 117, 2, 25, "Subsubsection"],
Cell[18740, 543, 1376, 33, 203, "Text"],
Cell[20119, 578, 445, 14, 270, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[20601, 597, 133, 3, 27, "Subsubsection"],
Cell[20737, 602, 177, 3, 41, "Text"],
Cell[20917, 607, 233, 5, 102, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[21187, 617, 113, 2, 25, "Subsubsection"],
Cell[21303, 621, 609, 15, 66, "Text"],
Cell[21915, 638, 365, 8, 162, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[22317, 651, 114, 2, 25, "Subsubsection"],
Cell[22434, 655, 837, 24, 91, "Text"],
Cell[23274, 681, 425, 12, 234, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[23736, 698, 114, 2, 25, "Subsubsection"],
Cell[23853, 702, 958, 26, 91, "Text"],
Cell[24814, 730, 224, 5, 108, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[25075, 740, 117, 2, 25, "Subsubsection"],
Cell[25195, 744, 664, 17, 91, "Text"],
Cell[25862, 763, 480, 12, 234, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[26379, 780, 115, 2, 25, "Subsubsection"],
Cell[26497, 784, 1058, 27, 91, "Text"],
Cell[27558, 813, 551, 13, 270, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[28146, 831, 112, 2, 24, "Subsubsection"],
Cell[28261, 835, 317, 8, 66, "Text"],
Cell[28581, 845, 155, 4, 90, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[28785, 855, 326, 11, 27, "Subsection"],
Cell[29114, 868, 2287, 72, 115, "Text"],

Cell[CellGroupData[{
Cell[31426, 944, 197, 5, 54, "Subsubsection",
  Evaluatable->False],
Cell[31626, 951, 40, 0, 25, "Text"],
Cell[31669, 953, 4001, 88, 1752, "Input"],
Cell[35673, 1043, 40, 0, 29, "Text"],
Cell[35716, 1045, 3276, 70, 1274, "Input"],
Cell[38995, 1117, 39, 0, 29, "Text"],
Cell[39037, 1119, 1300, 27, 392, "Input"],
Cell[40340, 1148, 24, 0, 23, "Text"],
Cell[40367, 1150, 373, 11, 212, "Input"],
Cell[40743, 1163, 25, 0, 25, "Text"],
Cell[40771, 1165, 168, 4, 72, "Input"],
Cell[40942, 1171, 33, 0, 25, "Text"],
Cell[40978, 1173, 320, 9, 172, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[41335, 1187, 199, 5, 32, "Subsubsection",
  Evaluatable->False],
Cell[41537, 1194, 977, 25, 103, "Text"],
Cell[42517, 1221, 221, 6, 126, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[42775, 1232, 153, 3, 32, "Subsubsection"],
Cell[42931, 1237, 2856, 79, 473, "Text"],
Cell[45790, 1318, 319, 5, 125, "Input"],
Cell[46112, 1325, 310, 10, 66, "Text"],
Cell[46425, 1337, 140, 4, 72, "Input",
  CellTags->"S5.34.1"],

Cell[CellGroupData[{
Cell[46590, 1345, 319, 7, 126, "Input",
  CellTags->"S5.34.1"],
Cell[46912, 1354, 82125, 3167, 70, 44636, 2701, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[129052, 4524, 1032, 32, 78, "Text"],

Cell[CellGroupData[{
Cell[130109, 4560, 422, 10, 198, "Input"],
Cell[130534, 4572, 43508, 1399, 70, 16839, 1066, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[174057, 5974, 954, 22, 178, "Text"],

Cell[CellGroupData[{
Cell[175036, 6000, 137, 4, 90, "Input"],
Cell[175176, 6006, 57, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[175270, 6012, 114, 3, 72, "Input"],
Cell[175387, 6017, 153, 3, 70, "Print"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[175613, 6028, 114, 1, 47, "Section"],

Cell[CellGroupData[{
Cell[175752, 6033, 110, 2, 55, "Subsection"],
Cell[175865, 6037, 546, 14, 91, "Text"],
Cell[176414, 6053, 90, 3, 72, "Input"],
Cell[176507, 6058, 691, 21, 66, "Text"],

Cell[CellGroupData[{
Cell[177223, 6083, 449, 9, 180, "Input"],
Cell[177675, 6094, 201628, 2980, 158, 138470, 2197, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[379352, 9080, 149, 3, 27, "Subsection"],
Cell[379504, 9085, 1453, 38, 209, "Text"],
Cell[380960, 9125, 133, 4, 90, "Input"],

Cell[CellGroupData[{
Cell[381118, 9133, 164, 4, 90, "Input"],
Cell[381285, 9139, 61503, 951, 296, 35531, 626, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[442803, 10093, 1019, 23, 203, "Text"],
Cell[443825, 10118, 214, 5, 108, "Input"],

Cell[CellGroupData[{
Cell[444064, 10127, 191, 4, 90, "Input"],
Cell[444258, 10133, 29972, 467, 208, 4345, 147, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[474245, 10603, 528, 13, 91, "Text"],
Cell[474776, 10618, 212, 5, 126, "Input"],

Cell[CellGroupData[{
Cell[475013, 10627, 186, 4, 90, "Input"],
Cell[475202, 10633, 125941, 1746, 208, 35552, 627, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[601158, 12382, 635, 20, 103, "Text"],

Cell[CellGroupData[{
Cell[601818, 12406, 66, 0, 54, "Input"],
Cell[601887, 12408, 52, 1, 53, "Output"]
}, Open  ]],
Cell[601954, 12412, 233, 8, 41, "Text"],

Cell[CellGroupData[{
Cell[602212, 12424, 119, 3, 72, "Input"],
Cell[602334, 12429, 153, 3, 28, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[602536, 12438, 146, 3, 27, "Subsection"],
Cell[602685, 12443, 1981, 57, 202, "Text"],
Cell[604669, 12502, 103, 3, 72, "Input"],
Cell[604775, 12507, 652, 19, 91, "Text"],
Cell[605430, 12528, 92, 3, 72, "Input"],
Cell[605525, 12533, 408, 12, 252, "Input"],
Cell[605936, 12547, 380, 11, 66, "Text"],
Cell[606319, 12560, 108, 3, 90, "Input"],
Cell[606430, 12565, 750, 20, 128, "Text"],

Cell[CellGroupData[{
Cell[607205, 12589, 296, 6, 126, "Input"],
Cell[607504, 12597, 27664, 683, 308, 7711, 433, "GraphicsData", "PostScript", \
"Graphics"],
Cell[635171, 13282, 153, 3, 28, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[635373, 13291, 223, 7, 27, "Subsection"],
Cell[635599, 13300, 255, 8, 66, "Text"],

Cell[CellGroupData[{
Cell[635879, 13312, 218, 8, 49, "Subsubsection"],
Cell[636100, 13322, 491, 13, 91, "Text"],
Cell[636594, 13337, 430, 13, 252, "Input"],
Cell[637027, 13352, 662, 15, 116, "Text"],
Cell[637692, 13369, 44, 0, 54, "Input"],

Cell[CellGroupData[{
Cell[637761, 13373, 324, 8, 162, "Input"],
Cell[638088, 13383, 196808, 3039, 158, 108016, 1939, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[834945, 16428, 218, 8, 49, "Subsubsection"],
Cell[835166, 16438, 713, 21, 91, "Text"],
Cell[835882, 16461, 339, 11, 216, "Input"],
Cell[836224, 16474, 489, 13, 91, "Text"],
Cell[836716, 16489, 42, 0, 54, "Input"],

Cell[CellGroupData[{
Cell[836783, 16493, 502, 11, 216, "Input"],
Cell[837288, 16506, 323939, 4824, 308, 208303, 3393, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1161242, 21333, 480, 12, 91, "Text"],

Cell[CellGroupData[{
Cell[1161747, 21349, 103, 3, 72, "Input"],
Cell[1161853, 21354, 153, 3, 28, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1162067, 21364, 126, 2, 27, "Subsection"],
Cell[1162196, 21368, 2127, 59, 215, "Text"],
Cell[1164326, 21429, 445, 13, 252, "Input"],
Cell[1164774, 21444, 659, 18, 128, "Text"],

Cell[CellGroupData[{
Cell[1165458, 21466, 303, 6, 126, "Input"],
Cell[1165764, 21474, 29025, 703, 308, 7865, 438, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1194792, 22179, 153, 3, 28, "Print"]
}, Open  ]],
Cell[1194960, 22185, 960, 22, 215, "Text"],

Cell[CellGroupData[{
Cell[1195945, 22211, 220, 5, 108, "Input"],
Cell[1196168, 22218, 25312, 647, 308, 8405, 435, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1221483, 22867, 153, 3, 28, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1221685, 22876, 123, 2, 27, "Subsection"],
Cell[1221811, 22880, 1333, 32, 265, "Text"],
Cell[1223147, 22914, 71, 0, 54, "Input"],
Cell[1223221, 22916, 352, 9, 198, "Input"],

Cell[CellGroupData[{
Cell[1223598, 22929, 199, 5, 108, "Input"],
Cell[1223800, 22936, 811690, 11576, 408, 610812, 9093, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2035493, 34514, 153, 3, 28, "Print"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2035707, 34524, 100, 1, 47, "Section"],

Cell[CellGroupData[{
Cell[2035832, 34529, 127, 2, 55, "Subsection"],
Cell[2035962, 34533, 936, 28, 153, "Text"],
Cell[2036901, 34563, 81, 3, 72, "Input"],
Cell[2036985, 34568, 464, 12, 91, "Text"],
Cell[2037452, 34582, 75, 3, 72, "Input"],
Cell[2037530, 34587, 204, 5, 108, "Input"],

Cell[CellGroupData[{
Cell[2037759, 34596, 199, 5, 108, "Input"],
Cell[2037961, 34603, 324696, 5249, 208, 215532, 3897, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2362660, 39854, 153, 3, 28, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2362862, 39863, 132, 2, 27, "Subsection"],
Cell[2362997, 39867, 1074, 28, 128, "Text"],
Cell[2364074, 39897, 297, 7, 144, "Input"],
Cell[2364374, 39906, 511, 13, 91, "Text"],
Cell[2364888, 39921, 392, 9, 180, "Input"],
Cell[2365283, 39932, 476, 12, 91, "Text"],
Cell[2365762, 39946, 212, 5, 108, "Input"],

Cell[CellGroupData[{
Cell[2365999, 39955, 177, 4, 108, "Input"],
Cell[2366179, 39961, 655904, 10498, 408, 428933, 7691, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[3022098, 50462, 693, 22, 66, "Text"],

Cell[CellGroupData[{
Cell[3022816, 50488, 71, 0, 54, "Input"],

Cell[CellGroupData[{
Cell[3022912, 50492, 86366, 1244, 296, 27248, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3109281, 51738, 85849, 1238, 296, 27249, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3195133, 52978, 86497, 1246, 20, 27249, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3281633, 54226, 86529, 1246, 20, 27249, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3368165, 55474, 86189, 1242, 20, 27249, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3454357, 56718, 85535, 1234, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3539895, 57954, 86608, 1247, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3626506, 59203, 86471, 1246, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3712980, 60451, 86592, 1247, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3799575, 61700, 86458, 1245, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3886036, 62947, 86742, 1249, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3972781, 64198, 86669, 1248, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4059453, 65448, 86645, 1248, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4146101, 66698, 85843, 1238, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4231947, 67938, 86657, 1248, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4318607, 69188, 86511, 1246, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[4405145, 70438, 315, 10, 66, "Text"],

Cell[CellGroupData[{
Cell[4405485, 70452, 111, 3, 72, "Input"],
Cell[4405599, 70457, 153, 3, 28, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4405801, 70466, 111, 2, 27, "Subsection"],
Cell[4405915, 70470, 358, 11, 66, "Text"],
Cell[4406276, 70483, 54, 0, 54, "Input"],

Cell[CellGroupData[{
Cell[4406355, 70487, 359, 8, 180, "Input"],
Cell[4406717, 70497, 370999, 5819, 208, 215511, 3895, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4777731, 76319, 323, 10, 66, "Text"],
Cell[4778057, 76331, 582, 12, 234, "Input"],
Cell[4778642, 76345, 306, 10, 66, "Text"],
Cell[4778951, 76357, 214, 5, 108, "Input"],

Cell[CellGroupData[{
Cell[4779190, 76366, 178, 4, 108, "Input"],
Cell[4779371, 76372, 748881, 11642, 408, 428874, 7687, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[5528267, 88017, 694, 20, 103, "Text"],

Cell[CellGroupData[{
Cell[5528986, 88041, 72, 0, 54, "Input"],

Cell[CellGroupData[{
Cell[5529083, 88045, 114044, 1586, 296, 27248, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5643130, 89633, 114227, 1588, 296, 27249, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5757360, 91223, 115224, 1601, 20, 27249, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5872587, 92826, 115535, 1604, 20, 27249, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5988125, 94432, 115450, 1603, 20, 27249, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6103578, 96037, 114877, 1596, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6218458, 97635, 114614, 1593, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6333075, 99230, 113849, 1584, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6446927, 100816, 114250, 1589, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6561180, 102407, 114355, 1590, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6675538, 103999, 115367, 1602, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6790908, 105603, 115631, 1606, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6906542, 107211, 115578, 1605, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7022123, 108818, 114853, 1596, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7136979, 110416, 114622, 1593, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7251604, 112011, 113885, 1584, 20, 27251, 510, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7365562, 113603, 83, 1, 75, "Section"],
Cell[7365648, 113606, 3174, 63, 590, "Text"],

Cell[CellGroupData[{
Cell[7368847, 113673, 104, 2, 38, "Subsection"],
Cell[7368954, 113677, 918, 32, 54, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

