(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2475973,      47949]*)
(*NotebookOutlinePosition[   2494782,      48650]*)
(*  CellTagsIndexPosition[   2494738,      48646]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Chapter 5. Eigen Pattern Image Processing",
  TextAlignment->Left,
  TextJustification->0,
  FormatType->InputForm,
  FontFamily->"Times New Roman",
  FontSize->24]], "Title",
  TextAlignment->Left,
  TextJustification->0,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.1 Introduction",
  FormatType->InputForm,
  FontFamily->"Times New Roman"]], "Section",
  FormatType->InputForm],

Cell[TextData[{
  StyleBox["\t",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "In any physical vector fields, we can find the eigen value and vectors. \
The eigen value represents the distinct physical system parameter. For \
example, the time constants of the electrical resistance, inductance and \
capacitance circuits are the inverse of eigen value. In the mechanical mass \
and spring systems, we have the eigen value, which corresponds to a natural \
resonant frequency of the system.\n\tThe target of this chapter is to find \
the parameter representing the distinct image. Since we have regarded the \
image data as the scalar or one component of the vector potentials, then we \
have found and established the new methodologies for the image processing. In \
physical system, we have found the eigen value and vectors representing the \
intrinsic characteristics of the system. This means that the eigen value or \
vectors should be found in the computer graphics.\n\tIn classical vector \
fields, the eigen value or its equivalent has been deduced as a result of the \
continuous field governing equations. Fundamental difference between the \
classical field theory and computer graphics is that the physical field \
theory has been established in a continuous space but the computer graphics \
can be established only in a discretized space. In the other words, the \
computer graphics has been established in an artificial space. Thereby, it is \
difficult to find and define the eigen value of a digital image, exactly. \
Modern discrete mathematics has revealed that the approximate eigen values \
could be computed from the discretized system of equations. In such meaning, \
it is possible to find the image eigen values from an image governing system \
of equations. Discretization of the Poisson type partial differential \
equations can derive the image governing system of equations. When we \
evaluate the eigen values from such an image governing system of equations, \
the smaller and larger eigen values may provide the eigen vectors \
representing the smoother and spikier lines as well as surfaces, \
respectively. The investigations about this are significant, but we do not \
discuss about these eigen values.\n\tPrincipal purpose of this chapter is to \
derive an eigen pattern not the eigen value. In chapter 4, we have derived \
one of the eigen patterns by the discrete orthogonal wavelet transform. A \
wavelet spectrum is one of the eigen patterns derived by a simple linear \
transform using a square wavelet transform matrix. In the present chapter, we \
generalize this linear transform to a nonlinear transform using a rectangular \
transform matrix. A meaning of the term \[OpenCurlyDoubleQuote]nonlinear\
\[CloseCurlyDoubleQuote] is that an inverse transform using the rectangular \
transform matrix never recover an exact original data but gives the best \
approximate data. \n\tIn the first section of this chapter, we describe a key \
idea deriving an eigen pattern. In the second section, we describe to the \
practical ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " codes deriving the eigen pattern. Also, we examine the nature of eigen \
pattern employing several one-dimensional image examples, which are the time \
domain sinusoidal waves. The third section derives an eigen pattern of the \
monochrome images, where we are demonstrated the angle and resolution \
independencies of the image eigen pattern. In addition to this section, the \
fourth section derives the eigen pattern of color image.\n\tAs a result, it \
is revealed that the image eigen pattern makes it possible to generate any \
angled and resolution images.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["5.2 Preparation of ",
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"]
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["5.2.1 ",
    FontFamily->"Times New Roman",
    FontSize->12],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontSlant->"Italic"],
  StyleBox[" utilities and packages",
    FontFamily->"Times New Roman",
    FontSize->12]
}], "Subsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Before to move on the practical image processing, we have to install the \
memory conserve utilities and the warning messages suppressing. In addition ",
    
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" utilities",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["\:ff0c",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"\.82l\.82r \.96\.be\.92\[Copyright]"],
  StyleBox[" the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["\[OpenCurlyDoubleQuote]",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"\.82l\.82r \.96\.be\.92\[Copyright]"],
  StyleBox["LinearAlgebra",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["\[OpenCurlyQuote]",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"\.82l\.82r \.96\.be\.92\[Copyright]"],
  StyleBox[
  "MatrixManipulation\[CloseCurlyDoubleQuote] package has to be installed..",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
<<Utilities`MemoryConserve`
$MemoryIncrement=100000;
Off[General::spell1,MemoryConserve::start,MemoryConserve::end];
<< LinearAlgebra`MatrixManipulation`;\
\>", "Input",
  CellLabel->"In[1]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["5.2.2 ",
    FontFamily->"Times New Roman",
    FontSize->12],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontSlant->"Italic"],
  StyleBox[" functions",
    FontFamily->"Times New Roman",
    FontSize->12]
}], "Subsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Here, we define several functions that are described and used in the \
previous chapters. The functions \[OpenCurlyDoubleQuote]rgbBMP\
\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]convertRGB\
\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]vectorMag3D\
\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]corRelation\
\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]memoryUsed\
\[OpenCurlyDoubleQuote] have been defined in the previous chapters, so that \
the comments of such functions are not described.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function rgbBMP",
  FontFamily->"Times New Roman",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["   ",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["The function ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "\[OpenCurlyDoubleQuote]convertRGB\[CloseCurlyDoubleQuote] converts the \
numerical data representing color image into a RGB form in order to visualize \
the image on the Mathematica notebook. The parameter \
\[OpenCurlyDoubleQuote]colorData\[CloseCurlyDoubleQuote] refers to a list \
including the numerical values.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    \(\(rgbBMP[colorFile_] := \n\t
      Module[{i = 0, j = 0, k = 0, dim = {0}, input = {{{0. }}}}, \n\t\t
        link = Install["\<RGBsplit.exe\>"]; Pause[0.01]; \n\t\t
        input = RGBsplit[colorFile]; \n\t\tUninstall[link]; \n\t\t
        Off[General::spell1]; \n\t\tdim = Dimensions[input]; \n\t\t
        Table[input[\([i, j, k]\)], {k, 3}, \n
          \t\t\t{i, dim[\([1]\)]}, {j, dim[\([2]\)]}]]; \)\)], "Input",
  CellLabel->"In[5]:="]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function convertRGB",
  FontFamily->"Times New Roman",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["   ",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["The function ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "\[OpenCurlyDoubleQuote]convertRGB\[CloseCurlyDoubleQuote] converts the \
numerical data representing color image into a RGB form in order to visualize \
the image on the Mathematica notebook. The parameter \
\[OpenCurlyDoubleQuote]colorData\[CloseCurlyDoubleQuote] refers to a list \
including the numerical values.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    \(\(convertRGB[colorData_] := \n\t
      Module[{i = 0, j = 0, dim = {0}, out}, \n\t\t
        dim = Dimensions[colorData]; \n\t\ \ 
        Graphics[\n\t\t\t
          RasterArray[\n\t\t\t\t
            Table[RGBColor[colorData[\([1, i, j]\)], \n\t\t\t\t\t
                colorData[\([2, i, j]\)], colorData[\([3, i, j]\)]], \n
              \t\t\t{i, \ dim[\([2]\)]}, \ {j, \ dim[\([3]\)]}]]]]; \)\)], 
  "Input",
  CellLabel->"In[6]:="]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function vectorMag3D",
  FontFamily->"Times New Roman",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["   A",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  " Mathematica function \[OpenCurlyDoubleQuote]vectorMag3D\
\[CloseCurlyDoubleQuote] computes a magnitude of the three-dimensional \
vectors on a plane surface. A parameter \[OpenCurlyDoubleQuote]vectorData3D\
\[CloseCurlyDoubleQuote] refers to the three-dimensional vector data on a \
two-dimensional plane. This function has been introduced in chapter 3.",
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
vectorMag3D=Compile[{{vectorData3D,_Real,3}},
\tModule[{mag={{0.}},max=0.,min=0.,i=0,j=0,dim={0}},
\t\tdim=Dimensions[vectorData3D];
\t\tmag=Sqrt[Table[vectorData3D[[1,i,j]]^2+
\t\t\tvectorData3D[[2,i,j]]^2+
\t\t\tvectorData3D[[3,i,j]]^2,
\t\t\t{i,dim[[2]]},{j,dim[[3]]}]];
\t\tmin=Min[mag];max=Max[mag-min];
\t\tIf[max=!=0.,Return[(mag-min)/max],
\t\t\tPrint[\"Zero vectors !\"];
\t\tReturn[mag]]]];\
\>", "Input",
  CellLabel->"In[7]:=",
  FormatType->InputForm]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function corRelation",
  FontFamily->"Times New Roman",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["   A Mathematica function ",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "\[OpenCurlyDoubleQuote]corRelation\[CloseCurlyDoubleQuote] computes a \
correlation coefficient between the lists \"a\" and \"b\". The lists \
\[OpenCurlyDoubleQuote]a\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]b\
\[CloseCurlyDoubleQuote] have to contain the real numerical values and the \
same length array. This function has been introduced in chapter 3.",
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
corRelation=Compile[{{a,_Real,1},{b,_Real,1}},
\tModule[{aa={0.},bb={0.},av=0.,bv=0.},
\tav=Apply[Plus,a]/Length[a]; bv=Apply[Plus,b]/Length[b];
\taa=a-av; bb=b-bv; aa.bb/(Sqrt[aa.aa]*Sqrt[bb.bb])]];\
\>", "Input",
  CellLabel->"In[8]:="]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function memoryUsed",
  FontFamily->"Times New Roman"]], "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "   This function gives the used memories after removing privious \"In\" \
and \"Out\" objects. ",
  StyleBox["This function has been introduced in chapter 3.",
    FontFamily->"Times New Roman"]
}], "Text",
  FontFamily->"Times New Roman"],

Cell[TextData[StyleBox[
"memoryUsed:=Module[{},\n\tUnprotect[In,Out];Clear[In,Out];Protect[In,Out];\n\
\tPrint[Round[N[MemoryInUse[]/1000]],\"K Bytes used\"]];",
  FontFamily->"Courier"]], "Input",
  CellLabel->"In[9]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function window",
  FontFamily->"Times New Roman"]], "Subsubsection",
  FormatType->InputForm],

Cell[TextData[{
  StyleBox["\t",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox[
  "To reduce a background effect of the sample image, we employ a simple \
round shape of window constructed by a following function. In the function \
\[OpenCurlyDoubleQuote]window\[CloseCurlyDoubleQuote], the parameters \
\[OpenCurlyDoubleQuote]xl\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]yl\
\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]radius\
\[CloseCurlyDoubleQuote] are the number of pixels in the direction of x, y \
axes and a radius of circular window, so that the a number of pixels for the \
parameter \[OpenCurlyDoubleQuote]radius\[CloseCurlyDoubleQuote] should be \
always smaller than that of the halfs of \[OpenCurlyDoubleQuote]xl\
\[CloseCurlyDoubleQuote] and  \[OpenCurlyDoubleQuote]yl\
\[CloseCurlyDoubleQuote].",
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    \(\(window[xl_, yl_, radius_] := \n\t
      Module[{i = 0, j = 0, k = 0, p = 0, q = 0, win = {{0. }}}, \n\t\t\t\t
        win = ZeroMatrix[yl, xl]; \n\t\t\t\tp = Round[0.5\ yl]; 
        q = Round[0.5\ xl]; \n\t\t\t\t
        Do[j = Round[Sqrt[radius^2 - i^2]]; \n\t\t\t\t\t
          Do[win[\([p + i, k]\)] = 1. , {k, q - j, q + j}], \n
          \t\t\t{i, \(-radius\), radius}]; \n\t\twin]; \)\)], "Input",
  CellLabel->"In[10]:="]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function convert2D",
  FontFamily->"Times New Roman"]], "Subsubsection",
  FormatType->InputForm],

Cell[TextData[{
  "\t",
  StyleBox[
  "This function rearranges the data housing in a one-dimensional array \
\[OpenCurlyDoubleQuote]dara1D\[CloseCurlyDoubleQuote] into the data housing \
in a two-dimensional array. The parameters \[OpenCurlyDoubleQuote]nx\
\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]ny\[CloseCurlyDoubleQuote] refer to the number of \
columns and rows, respectively.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
convert2D=Compile[{{data1D,_Real,1},{nx,_Integer},
\t{ny,_Integer}},Module[{i=0,j=0},
\tTable[data1D[[i+(j*nx)]],{j,0,ny-1},{i,nx}]]];\
\>", "Input",
  CellLabel->"In[11]:=",
  PageBreakWithin->Automatic,
  GroupPageBreakWithin->Automatic,
  AspectRatioFixed->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["5.2.3 ",
    FontSize->12],
  StyleBox["Mathematica",
    FontSize->12,
    FontSlant->"Italic"],
  StyleBox[" functions for eigen pattern generation",
    FontSize->12]
}], "Subsection",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Principle",
  FormatType->InputForm]], "Subsubsection",
  FormatType->InputForm,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\t",
  StyleBox["Let us consider a vector given by",
    TextAlignment->Left,
    TextJustification->1]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["x={0,1,2,3,3,3,2,1,0};", "Input",
  CellLabel->"In[12]:="],

Cell[TextData[{
  "\t",
  StyleBox[
  "This vector \[OpenCurlyDoubleQuote]x\[CloseCurlyDoubleQuote] is composed \
of the two 0, two 1, two 2 and three 3 elements. Our purpose is to extract \
the number of the elements taking the same absolute value not taking into \
account the zero elements. In order to achieve this, we set a resolution to \
m=3 because we have to count the three kinds of numerical values. After that, \
we normalize the vector \[OpenCurlyDoubleQuote]x\[CloseCurlyDoubleQuote] by",
    TextAlignment->Left,
    TextJustification->1]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(m = 3; \nxn = m*x/Max[Abs[x]]; \)], "Input",
  CellLabel->"In[13]:="],

Cell[TextData[{
  "\t",
  StyleBox[
  "In order to extract the three kinds of numerical values from the vector 9",
    
    FontFamily->"Times New Roman"],
  StyleBox["th",
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[
  " order vector \[OpenCurlyDoubleQuote]x\[CloseCurlyDoubleQuote], we \
construct a 3 by 9 rectangular transform matrix \[OpenCurlyDoubleQuote]c\
\[CloseCurlyDoubleQuote] by",
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
n=9;
c=Table[
\t\tIf[Sign[xn[[j]]] xn[[j]]==i,p=1./x[[j]],p=0];p,
\t\t{i,m},{j,n}];\
\>", "Input",
  CellLabel->"In[14]:="],

Cell[TextData[{
  "\t",
  StyleBox[
  "This matrix \[OpenCurlyDoubleQuote]c\[CloseCurlyDoubleQuote] can be \
rewritten in matrix form by",
    FormatType->InputForm]
}], "Text",
  FormatType->InputForm,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["c//MatrixForm", "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0", 
              StyleBox["1.`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1], "0", "0", "0", "0", "0", 
              StyleBox["1.`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1], "0"},
            {"0", "0", "0.5`", "0", "0", "0", "0.5`", "0", "0"},
            {"0", "0", "0", "0.333333333333333303`", "0.333333333333333303`", 
              "0.333333333333333303`", "0", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[16]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "\t",
  "Using this matrix transform \[OpenCurlyDoubleQuote]c\
\[CloseCurlyDoubleQuote], we can extract the number of non-zero elements from \
the vector \[OpenCurlyDoubleQuote]x\[CloseCurlyDoubleQuote] by "
}], "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["b=c.x", "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \({2.`, 2.`, 3.`}\)], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "The first, second and third elements in a vector \[OpenCurlyDoubleQuote]b\
\[CloseCurlyDoubleQuote] are corresponding to the number of the elements \
taking the numeric values 1, 2 and 3, respectively.\n\tThus, we have \
succeeded in extracting the number of non-zero elements from the vector \
\[OpenCurlyDoubleQuote]x\[CloseCurlyDoubleQuote]. Here, we define the vector \
\[OpenCurlyDoubleQuote]b\[CloseCurlyDoubleQuote] as an ",
    FormatType->InputForm],
  StyleBox["eigen pattern",
    FormatType->InputForm,
    FontWeight->"Bold"],
  StyleBox[
  " vector. In order to recover the original vector \[OpenCurlyDoubleQuote]x\
\[CloseCurlyDoubleQuote] from the eigen pattern vector \
\[OpenCurlyDoubleQuote]b\[CloseCurlyDoubleQuote], we construct an inverse \
matrix by means of a least norm solution sense for an ill posed linear \
system.",
    FormatType->InputForm]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["c.Transpose[c]//MatrixForm", "Input",
  CellLabel->"In[18]:=",
  FormatType->InputForm],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"2.`", "0.`", "0.`"},
            {"0.`", "0.5`", "0.`"},
            {"0.`", "0.`", "0.333333333333333303`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[18]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "Since all of the elements excepting the diagonal elements are zero, then \
the row vectors of the transform matrix \[OpenCurlyDoubleQuote]c\
\[CloseCurlyDoubleQuote] are the independent orthogonal vectors. Thereby, \
similar to the least norm method, an inverse transform matrix \
\[OpenCurlyDoubleQuote]d\[CloseCurlyDoubleQuote] is formally obtained by",
    FormatType->InputForm]
}], "Text",
  FormatType->InputForm,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["\<\
d=Transpose[c].Inverse[c.Transpose[c]];
%//MatrixForm\
\>", "Input",
  CellLabel->"In[19]:=",
  FormatType->InputForm],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0.`", "0.`", "0.`"},
            {"0.5`", "0.`", "0.`"},
            {"0.`", "1.`", "0.`"},
            {"0.`", "0.`", "1.`"},
            {"0.`", "0.`", "1.`"},
            {"0.`", "0.`", "1.`"},
            {"0.`", "1.`", "0.`"},
            {"0.5`", "0.`", "0.`"},
            {"0.`", "0.`", "0.`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[20]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "\t",
  "Using this inverse transform matrix \[OpenCurlyDoubleQuote]d\
\[CloseCurlyDoubleQuote], we can recover the original vector \
\[OpenCurlyDoubleQuote]x\[CloseCurlyDoubleQuote] by "
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(d . b\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \({0.`, 1.`, 2.`, 3.`, 3.`, 3.`, 2.`, 1.`, 0.`}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[TextData[{
  "\t",
  "Thus, the original vector \[OpenCurlyDoubleQuote]x\[CloseCurlyDoubleQuote] \
is successfully obtained by means of the inverse transform matrix \
\[OpenCurlyDoubleQuote]d\[CloseCurlyDoubleQuote]. In this case, the target \
vector \[OpenCurlyDoubleQuote]x\[CloseCurlyDoubleQuote] has a 3 level \
resolution and we have set the 3 level resolution. This leads to a successful \
recovery result. However, it is difficult to set up the resolution in \
accordance with exact one. In such case, we confront to the zero row vector \
of the transform matrix, even though these vectors are the independent \
orthogonal ones. In such a case, it is difficult to derive an exact inverse \
transform matrix \[OpenCurlyDoubleQuote]d\[CloseCurlyDoubleQuote]."
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FontFamily->"Times New Roman"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Function",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox[" eigenMatrix",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Subsubsection",
  FormatType->InputForm],

Cell[TextData[{
  "\t",
  StyleBox[
  "This function \[OpenCurlyDoubleQuote]eigenMatrix\[CloseCurlyDoubleQuote] \
is derived from an input vector \[OpenCurlyDoubleQuote]base\
\[CloseCurlyDoubleQuote]. The resulting transform matrix becomes a \
rectangular matrix with the \[OpenCurlyDoubleQuote]resolution\
\[CloseCurlyDoubleQuote]",
    FormatType->InputForm],
  StyleBox["th",
    FormatType->InputForm,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[
  "  rows and length of the vector \[OpenCurlyDoubleQuote]base\
\[CloseCurlyDoubleQuote]",
    FormatType->InputForm],
  StyleBox["th",
    FormatType->InputForm,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" columns.",
    FormatType->InputForm]
}], "Text",
  FormatType->InputForm,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(eigenMatrix = 
      Compile[{{base, _Real, 1}, {resolution, _Integer}}, \n\t
        Module[{p = 0. , dataPrime = {0}, \n\t\t\t\tn = Length[base], i = 0, 
            j = 0}, \n\t\t\t\t
          dataPrime = Round[resolution*base/Max[Abs[base]]]; \n\t\t\t\t\t
          Table[\n\t\t\t\t\t\t\t
            If[Sign[base[\([j]\)]]*dataPrime[\([j]\)] == i, \n\t\t\t\t\t\t\t\t
              p = 1. /base[\([j]\)], p = 0. ]; p, \n
            \t\t\t\t\t{i, resolution}, {j, n}]\n\t\t]]; \)\)], "Input",
  CellLabel->"In[22]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Function",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox[" eigenPattern",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Subsubsection",
  FormatType->InputForm],

Cell[TextData[{
  "\t",
  StyleBox[
  "This function \[OpenCurlyDoubleQuote]eigenPattern\[CloseCurlyDoubleQuote] \
derives an eigen pattern directly from an input vector \
\[OpenCurlyDoubleQuote]base\[CloseCurlyDoubleQuote]. This functional type \
routine looses a structured process for the eigen pattern extraction, but it \
is extremely useful routine to handle a large size base function.",
    FormatType->InputForm]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(eigenPattern = \n\t
      Compile[{{base, _Real, 1}, {resolution, _Integer}}, \n\t\t
        Module[{dummy = Abs[base], out = {0}, i = 0}, \n\t\t\t
          out = Round[resolution*dummy/Max[dummy]]; \n\t\t\t
          Table[Count[out, i], {i, resolution}]\n\t\t]]; \)\)], "Input",
  CellLabel->"In[23]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Function",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox[" inverseEigenMatrix",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Subsubsection",
  FormatType->InputForm],

Cell[TextData[{
  "\t",
  StyleBox[
  "The inverse transform matrix \[OpenCurlyDoubleQuote]inverseEigenMatrix\
\[CloseCurlyDoubleQuote] is based on the fact that each of the row vectors in \
the transform matrix \[OpenCurlyDoubleQuote]eigenMat\[CloseCurlyDoubleQuote] \
is an orthogonal vector. The output matrix of the ",
    FormatType->InputForm],
  StyleBox["Mathematica",
    FormatType->InputForm,
    FontSlant->"Italic"],
  StyleBox[
  " function \
\[OpenCurlyDoubleQuote]inverseEigenMatrix\[CloseCurlyDoubleQuote] has a \
transposed form of the transform matrix \[OpenCurlyDoubleQuote]eigenMat\
\[CloseCurlyDoubleQuote]. ",
    FormatType->InputForm]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(inverseEigenMatrix = 
      Compile[{{eigenMat, _Real, 2}}, \n\t\t
        Module[{v = {0. }, d = {{0. }}, dim = {0}}, \n\t\t\t
          dim = Dimensions[eigenMat]; \n\t\t\t
          v = Table[
              eigenMat[\([i]\)] . eigenMat[\([i]\)], {i, dim[\([1]\)]}]; \n
          \t\t\td = ZeroMatrix[dim[\([1]\)]]; \n\t\t\t
          Do[If[v[\([i]\)] =!= 0. , d[\([i, i]\)] = 1. /v[\([i]\)]], {i, 
              dim[\([1]\)]}]; \n\t\t\tTranspose[eigenMat] . d\n\t]]; \)\)], 
  "Input",
  CellLabel->"In[24]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function inverseEigenPattern",
  FormatType->InputForm,
  FontFamily->"Times New Roman"]], "Subsubsection",
  FormatType->InputForm],

Cell[TextData[{
  "\t",
  StyleBox[
  "This \[OpenCurlyDoubleQuote]inverseEigenPattern\[CloseCurlyDoubleQuote] \
routine recovers an original image directly from an eigen pattern along with \
a base function \[OpenCurlyDoubleQuote]base\[CloseCurlyDoubleQuote]. Because \
of the different numerical processes, this function gives a recovered vector \
with a small difference compared with those of the function \
\[OpenCurlyDoubleQuote]inverse EigenMatrix\[CloseCurlyDoubleQuote].",
    FormatType->InputForm]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"inverseEigenPattern", "=", "\n", "\t", 
        RowBox[{"Compile", "[", 
          RowBox[{
          \({{eigen, _Real, 1}, {base, _Real, 1}, {resolution, _Integer}}\), 
            ",", "\n", "\t\t", 
            RowBox[{"Module", "[", 
              RowBox[{\({out = {{0. }}, d = {0. }}\), ",", "\n", "\t\t\t", 
                RowBox[{
                \(d = 1. *Round[resolution*base]/resolution\), ";", "\n", 
                  "\t\t\t", \(out = Transpose[Table[d, {resolution}]]\), ";", 
                  "\n", "\t\t\t", 
                  RowBox[{\(out . eigen\), "/", 
                    StyleBox[\(Apply[Plus, eigen]\),
                      FontFamily->"Courier"]}]}]}], "\n", "\t", "]"}]}], 
          "]"}]}], ";"}]], "Input",
  CellLabel->"In[25]:="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.3 The nature of eigen patterns", "Section",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.3.1 One-dimensional image",
  FontSize->12]], "Subsection",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Sample images",
  FormatType->InputForm,
  FontFamily->"Times New Roman"]], "Subsubsection",
  FormatType->InputForm],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Let us consider the four one-dimensional images in time domain having the \
different frequencies, time phase and waveforms.",
    TextAlignment->Left,
    TextJustification->1]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["\<\
resolution=100;
sample1D={Table[Sin[2Pi i/resolution],{i,0,resolution,0.1}],
\tTable[Sin[6Pi i/resolution],{i,0,resolution,0.1}],
\tTable[Abs[Sin[2Pi i/resolution]],{i,0,resolution,0.1}],
\tTable[Cos[2Pi i/resolution],{i,0,resolution,0.1}]};\
\>", "Input",
  CellLabel->"In[26]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["Figure 1 shows the one-dimensional sample images.",
    TextAlignment->Left,
    TextJustification->1]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["\<\
label={\"Fig.1(a)\",\"Fig.1(b)\",\"Fig.1(c)\",\"Fig.1(d)\"};
sample1DG=Table[ListPlot[sample1D[[i+j]],
\tPlotRange->All,PlotJoined->True,AxesLabel->{\"time\",\"Amp.\"},
\tPlotStyle->RGBColor[i,0,j/4],
\tPlotLabel->StringForm[\"`1`\",label[[i+j]]],
\tDisplayFunction->Identity],{j,1,4,2},{i,0,1}];\
\>", "Input",
  CellLabel->"In[28]:=",
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["Show[GraphicsArray[sample1DG],ImageSize->{400,250}];", "Input",
  CellLabel->"In[30]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 250 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0228571 0.000952381 0.0147151 0.588604 [
[.21333 .00222 -9 -9 ]
[.21333 .00222 9 0 ]
[.40381 .00222 -9 -9 ]
[.40381 .00222 9 0 ]
[.59429 .00222 -9 -9 ]
[.59429 .00222 9 0 ]
[.78476 .00222 -9 -9 ]
[.78476 .00222 9 0 ]
[.97524 .00222 -12 -9 ]
[.97524 .00222 12 0 ]
[1.025 .01472 0 -6.28125 ]
[1.025 .01472 28 6.28125 ]
[.01036 .13244 -18 -4.5 ]
[.01036 .13244 0 4.5 ]
[.01036 .25016 -18 -4.5 ]
[.01036 .25016 0 4.5 ]
[.01036 .36788 -18 -4.5 ]
[.01036 .36788 0 4.5 ]
[.01036 .4856 -18 -4.5 ]
[.01036 .4856 0 4.5 ]
[.01036 .60332 -6 -4.5 ]
[.01036 .60332 0 4.5 ]
[.02286 .64303 -14 0 ]
[.02286 .64303 14 12.5625 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21333 .01472 m
.21333 .02097 L
s
[(200)] .21333 .00222 0 1 Mshowa
.40381 .01472 m
.40381 .02097 L
s
[(400)] .40381 .00222 0 1 Mshowa
.59429 .01472 m
.59429 .02097 L
s
[(600)] .59429 .00222 0 1 Mshowa
.78476 .01472 m
.78476 .02097 L
s
[(800)] .78476 .00222 0 1 Mshowa
.97524 .01472 m
.97524 .02097 L
s
[(1000)] .97524 .00222 0 1 Mshowa
.125 Mabswid
.07048 .01472 m
.07048 .01847 L
s
.1181 .01472 m
.1181 .01847 L
s
.16571 .01472 m
.16571 .01847 L
s
.26095 .01472 m
.26095 .01847 L
s
.30857 .01472 m
.30857 .01847 L
s
.35619 .01472 m
.35619 .01847 L
s
.45143 .01472 m
.45143 .01847 L
s
.49905 .01472 m
.49905 .01847 L
s
.54667 .01472 m
.54667 .01847 L
s
.6419 .01472 m
.6419 .01847 L
s
.68952 .01472 m
.68952 .01847 L
s
.73714 .01472 m
.73714 .01847 L
s
.83238 .01472 m
.83238 .01847 L
s
.88 .01472 m
.88 .01847 L
s
.92762 .01472 m
.92762 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(time) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.02286 .13244 m
.02911 .13244 L
s
[(0.2)] .01036 .13244 1 0 Mshowa
.02286 .25016 m
.02911 .25016 L
s
[(0.4)] .01036 .25016 1 0 Mshowa
.02286 .36788 m
.02911 .36788 L
s
[(0.6)] .01036 .36788 1 0 Mshowa
.02286 .4856 m
.02911 .4856 L
s
[(0.8)] .01036 .4856 1 0 Mshowa
.02286 .60332 m
.02911 .60332 L
s
[(1)] .01036 .60332 1 0 Mshowa
.125 Mabswid
.02286 .04415 m
.02661 .04415 L
s
.02286 .07358 m
.02661 .07358 L
s
.02286 .10301 m
.02661 .10301 L
s
.02286 .16187 m
.02661 .16187 L
s
.02286 .1913 m
.02661 .1913 L
s
.02286 .22073 m
.02661 .22073 L
s
.02286 .27959 m
.02661 .27959 L
s
.02286 .30902 m
.02661 .30902 L
s
.02286 .33845 m
.02661 .33845 L
s
.02286 .39731 m
.02661 .39731 L
s
.02286 .42674 m
.02661 .42674 L
s
.02286 .45617 m
.02661 .45617 L
s
.02286 .51503 m
.02661 .51503 L
s
.02286 .54446 m
.02661 .54446 L
s
.02286 .57389 m
.02661 .57389 L
s
.25 Mabswid
.02286 0 m
.02286 .61803 L
s
gsave
.02286 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Amp) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
87.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 12.812500 moveto
(H) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 12.812500 moveto
(L) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 .75 r
.5 Mabswid
.02381 .01472 m
.02476 .01841 L
.02571 .02211 L
.02667 .02581 L
.02762 .02951 L
.02857 .0332 L
.02952 .0369 L
.03048 .04059 L
.03143 .04429 L
.03238 .04798 L
.03333 .05167 L
.03429 .05536 L
.03524 .05905 L
.03619 .06274 L
.03714 .06642 L
.0381 .07011 L
.03905 .07379 L
.04 .07747 L
.04095 .08114 L
.0419 .08482 L
.04286 .08849 L
.04381 .09215 L
.04476 .09582 L
.04571 .09948 L
.04667 .10314 L
.04762 .10679 L
.04857 .11044 L
.04952 .11409 L
.05048 .11773 L
.05143 .12137 L
.05238 .12501 L
.05333 .12864 L
.05429 .13227 L
.05524 .13589 L
.05619 .1395 L
.05714 .14312 L
.0581 .14672 L
.05905 .15032 L
.06 .15392 L
.06095 .15751 L
.0619 .16109 L
.06286 .16467 L
.06381 .16825 L
.06476 .17181 L
.06571 .17538 L
.06667 .17893 L
.06762 .18248 L
.06857 .18602 L
.06952 .18955 L
.07048 .19308 L
Mistroke
.07143 .1966 L
.07238 .20012 L
.07333 .20362 L
.07429 .20712 L
.07524 .21061 L
.07619 .2141 L
.07714 .21757 L
.0781 .22104 L
.07905 .2245 L
.08 .22795 L
.08095 .23139 L
.0819 .23483 L
.08286 .23825 L
.08381 .24167 L
.08476 .24508 L
.08571 .24848 L
.08667 .25187 L
.08762 .25525 L
.08857 .25862 L
.08952 .26198 L
.09048 .26533 L
.09143 .26867 L
.09238 .272 L
.09333 .27532 L
.09429 .27864 L
.09524 .28194 L
.09619 .28523 L
.09714 .2885 L
.0981 .29177 L
.09905 .29503 L
.1 .29828 L
.10095 .30151 L
.1019 .30474 L
.10286 .30795 L
.10381 .31115 L
.10476 .31434 L
.10571 .31752 L
.10667 .32068 L
.10762 .32383 L
.10857 .32698 L
.10952 .3301 L
.11048 .33322 L
.11143 .33632 L
.11238 .33942 L
.11333 .34249 L
.11429 .34556 L
.11524 .34861 L
.11619 .35165 L
.11714 .35468 L
.1181 .35769 L
Mistroke
.11905 .36069 L
.12 .36367 L
.12095 .36664 L
.1219 .3696 L
.12286 .37255 L
.12381 .37547 L
.12476 .37839 L
.12571 .38129 L
.12667 .38418 L
.12762 .38705 L
.12857 .38991 L
.12952 .39275 L
.13048 .39557 L
.13143 .39839 L
.13238 .40118 L
.13333 .40397 L
.13429 .40673 L
.13524 .40948 L
.13619 .41222 L
.13714 .41494 L
.1381 .41764 L
.13905 .42033 L
.14 .423 L
.14095 .42566 L
.1419 .4283 L
.14286 .43092 L
.14381 .43353 L
.14476 .43612 L
.14571 .43869 L
.14667 .44125 L
.14762 .44379 L
.14857 .44631 L
.14952 .44882 L
.15048 .45131 L
.15143 .45378 L
.15238 .45623 L
.15333 .45867 L
.15429 .46109 L
.15524 .46349 L
.15619 .46588 L
.15714 .46824 L
.1581 .47059 L
.15905 .47292 L
.16 .47523 L
.16095 .47753 L
.1619 .4798 L
.16286 .48206 L
.16381 .4843 L
.16476 .48652 L
.16571 .48872 L
Mistroke
.16667 .49091 L
.16762 .49307 L
.16857 .49522 L
.16952 .49734 L
.17048 .49945 L
.17143 .50154 L
.17238 .50361 L
.17333 .50566 L
.17429 .50769 L
.17524 .5097 L
.17619 .51169 L
.17714 .51366 L
.1781 .51561 L
.17905 .51755 L
.18 .51946 L
.18095 .52135 L
.1819 .52322 L
.18286 .52508 L
.18381 .52691 L
.18476 .52872 L
.18571 .53051 L
.18667 .53228 L
.18762 .53404 L
.18857 .53577 L
.18952 .53748 L
.19048 .53916 L
.19143 .54083 L
.19238 .54248 L
.19333 .54411 L
.19429 .54571 L
.19524 .5473 L
.19619 .54886 L
.19714 .55041 L
.1981 .55193 L
.19905 .55343 L
.2 .55491 L
.20095 .55637 L
.2019 .5578 L
.20286 .55922 L
.20381 .56061 L
.20476 .56199 L
.20571 .56334 L
.20667 .56466 L
.20762 .56597 L
.20857 .56726 L
.20952 .56852 L
.21048 .56976 L
.21143 .57098 L
.21238 .57218 L
.21333 .57336 L
Mistroke
.21429 .57451 L
.21524 .57564 L
.21619 .57675 L
.21714 .57784 L
.2181 .5789 L
.21905 .57995 L
.22 .58097 L
.22095 .58197 L
.2219 .58294 L
.22286 .5839 L
.22381 .58483 L
.22476 .58574 L
.22571 .58662 L
.22667 .58748 L
.22762 .58833 L
.22857 .58914 L
.22952 .58994 L
.23048 .59071 L
.23143 .59146 L
.23238 .59219 L
.23333 .59289 L
.23429 .59357 L
.23524 .59423 L
.23619 .59487 L
.23714 .59548 L
.2381 .59607 L
.23905 .59664 L
.24 .59718 L
.24095 .5977 L
.2419 .5982 L
.24286 .59868 L
.24381 .59913 L
.24476 .59956 L
.24571 .59996 L
.24667 .60035 L
.24762 .60071 L
.24857 .60104 L
.24952 .60136 L
.25048 .60165 L
.25143 .60191 L
.25238 .60216 L
.25333 .60238 L
.25429 .60258 L
.25524 .60275 L
.25619 .6029 L
.25714 .60303 L
.2581 .60313 L
.25905 .60321 L
.26 .60327 L
.26095 .60331 L
Mistroke
.2619 .60332 L
.26286 .60331 L
.26381 .60327 L
.26476 .60321 L
.26571 .60313 L
.26667 .60303 L
.26762 .6029 L
.26857 .60275 L
.26952 .60258 L
.27048 .60238 L
.27143 .60216 L
.27238 .60191 L
.27333 .60165 L
.27429 .60136 L
.27524 .60104 L
.27619 .60071 L
.27714 .60035 L
.2781 .59996 L
.27905 .59956 L
.28 .59913 L
.28095 .59868 L
.2819 .5982 L
.28286 .5977 L
.28381 .59718 L
.28476 .59664 L
.28571 .59607 L
.28667 .59548 L
.28762 .59487 L
.28857 .59423 L
.28952 .59357 L
.29048 .59289 L
.29143 .59219 L
.29238 .59146 L
.29333 .59071 L
.29429 .58994 L
.29524 .58914 L
.29619 .58833 L
.29714 .58748 L
.2981 .58662 L
.29905 .58574 L
.3 .58483 L
.30095 .5839 L
.3019 .58294 L
.30286 .58197 L
.30381 .58097 L
.30476 .57995 L
.30571 .5789 L
.30667 .57784 L
.30762 .57675 L
.30857 .57564 L
Mistroke
.30952 .57451 L
.31048 .57336 L
.31143 .57218 L
.31238 .57098 L
.31333 .56976 L
.31429 .56852 L
.31524 .56726 L
.31619 .56597 L
.31714 .56466 L
.3181 .56334 L
.31905 .56199 L
.32 .56061 L
.32095 .55922 L
.3219 .5578 L
.32286 .55637 L
.32381 .55491 L
.32476 .55343 L
.32571 .55193 L
.32667 .55041 L
.32762 .54886 L
.32857 .5473 L
.32952 .54571 L
.33048 .54411 L
.33143 .54248 L
.33238 .54083 L
.33333 .53916 L
.33429 .53748 L
.33524 .53577 L
.33619 .53404 L
.33714 .53228 L
.3381 .53051 L
.33905 .52872 L
.34 .52691 L
.34095 .52508 L
.3419 .52322 L
.34286 .52135 L
.34381 .51946 L
.34476 .51755 L
.34571 .51561 L
.34667 .51366 L
.34762 .51169 L
.34857 .5097 L
.34952 .50769 L
.35048 .50566 L
.35143 .50361 L
.35238 .50154 L
.35333 .49945 L
.35429 .49734 L
.35524 .49522 L
.35619 .49307 L
Mistroke
.35714 .49091 L
.3581 .48872 L
.35905 .48652 L
.36 .4843 L
.36095 .48206 L
.3619 .4798 L
.36286 .47753 L
.36381 .47523 L
.36476 .47292 L
.36571 .47059 L
.36667 .46824 L
.36762 .46588 L
.36857 .46349 L
.36952 .46109 L
.37048 .45867 L
.37143 .45623 L
.37238 .45378 L
.37333 .45131 L
.37429 .44882 L
.37524 .44631 L
.37619 .44379 L
.37714 .44125 L
.3781 .43869 L
.37905 .43612 L
.38 .43353 L
.38095 .43092 L
.3819 .4283 L
.38286 .42566 L
.38381 .423 L
.38476 .42033 L
.38571 .41764 L
.38667 .41494 L
.38762 .41222 L
.38857 .40948 L
.38952 .40673 L
.39048 .40397 L
.39143 .40118 L
.39238 .39839 L
.39333 .39557 L
.39429 .39275 L
.39524 .38991 L
.39619 .38705 L
.39714 .38418 L
.3981 .38129 L
.39905 .37839 L
.4 .37547 L
.40095 .37255 L
.4019 .3696 L
.40286 .36664 L
.40381 .36367 L
Mistroke
.40476 .36069 L
.40571 .35769 L
.40667 .35468 L
.40762 .35165 L
.40857 .34861 L
.40952 .34556 L
.41048 .34249 L
.41143 .33942 L
.41238 .33632 L
.41333 .33322 L
.41429 .3301 L
.41524 .32698 L
.41619 .32383 L
.41714 .32068 L
.4181 .31752 L
.41905 .31434 L
.42 .31115 L
.42095 .30795 L
.4219 .30474 L
.42286 .30151 L
.42381 .29828 L
.42476 .29503 L
.42571 .29177 L
.42667 .2885 L
.42762 .28523 L
.42857 .28194 L
.42952 .27864 L
.43048 .27532 L
.43143 .272 L
.43238 .26867 L
.43333 .26533 L
.43429 .26198 L
.43524 .25862 L
.43619 .25525 L
.43714 .25187 L
.4381 .24848 L
.43905 .24508 L
.44 .24167 L
.44095 .23825 L
.4419 .23483 L
.44286 .23139 L
.44381 .22795 L
.44476 .2245 L
.44571 .22104 L
.44667 .21757 L
.44762 .2141 L
.44857 .21061 L
.44952 .20712 L
.45048 .20362 L
.45143 .20012 L
Mistroke
.45238 .1966 L
.45333 .19308 L
.45429 .18955 L
.45524 .18602 L
.45619 .18248 L
.45714 .17893 L
.4581 .17538 L
.45905 .17181 L
.46 .16825 L
.46095 .16467 L
.4619 .16109 L
.46286 .15751 L
.46381 .15392 L
.46476 .15032 L
.46571 .14672 L
.46667 .14312 L
.46762 .1395 L
.46857 .13589 L
.46952 .13227 L
.47048 .12864 L
.47143 .12501 L
.47238 .12137 L
.47333 .11773 L
.47429 .11409 L
.47524 .11044 L
.47619 .10679 L
.47714 .10314 L
.4781 .09948 L
.47905 .09582 L
.48 .09215 L
.48095 .08849 L
.4819 .08482 L
.48286 .08114 L
.48381 .07747 L
.48476 .07379 L
.48571 .07011 L
.48667 .06642 L
.48762 .06274 L
.48857 .05905 L
.48952 .05536 L
.49048 .05167 L
.49143 .04798 L
.49238 .04429 L
.49333 .04059 L
.49429 .0369 L
.49524 .0332 L
.49619 .02951 L
.49714 .02581 L
.4981 .02211 L
.49905 .01841 L
Mistroke
.5 .01472 L
.50095 .01841 L
.5019 .02211 L
.50286 .02581 L
.50381 .02951 L
.50476 .0332 L
.50571 .0369 L
.50667 .04059 L
.50762 .04429 L
.50857 .04798 L
.50952 .05167 L
.51048 .05536 L
.51143 .05905 L
.51238 .06274 L
.51333 .06642 L
.51429 .07011 L
.51524 .07379 L
.51619 .07747 L
.51714 .08114 L
.5181 .08482 L
.51905 .08849 L
.52 .09215 L
.52095 .09582 L
.5219 .09948 L
.52286 .10314 L
.52381 .10679 L
.52476 .11044 L
.52571 .11409 L
.52667 .11773 L
.52762 .12137 L
.52857 .12501 L
.52952 .12864 L
.53048 .13227 L
.53143 .13589 L
.53238 .1395 L
.53333 .14312 L
.53429 .14672 L
.53524 .15032 L
.53619 .15392 L
.53714 .15751 L
.5381 .16109 L
.53905 .16467 L
.54 .16825 L
.54095 .17181 L
.5419 .17538 L
.54286 .17893 L
.54381 .18248 L
.54476 .18602 L
.54571 .18955 L
.54667 .19308 L
Mistroke
.54762 .1966 L
.54857 .20012 L
.54952 .20362 L
.55048 .20712 L
.55143 .21061 L
.55238 .2141 L
.55333 .21757 L
.55429 .22104 L
.55524 .2245 L
.55619 .22795 L
.55714 .23139 L
.5581 .23483 L
.55905 .23825 L
.56 .24167 L
.56095 .24508 L
.5619 .24848 L
.56286 .25187 L
.56381 .25525 L
.56476 .25862 L
.56571 .26198 L
.56667 .26533 L
.56762 .26867 L
.56857 .272 L
.56952 .27532 L
.57048 .27864 L
.57143 .28194 L
.57238 .28523 L
.57333 .2885 L
.57429 .29177 L
.57524 .29503 L
.57619 .29828 L
.57714 .30151 L
.5781 .30474 L
.57905 .30795 L
.58 .31115 L
.58095 .31434 L
.5819 .31752 L
.58286 .32068 L
.58381 .32383 L
.58476 .32698 L
.58571 .3301 L
.58667 .33322 L
.58762 .33632 L
.58857 .33942 L
.58952 .34249 L
.59048 .34556 L
.59143 .34861 L
.59238 .35165 L
.59333 .35468 L
.59429 .35769 L
Mistroke
.59524 .36069 L
.59619 .36367 L
.59714 .36664 L
.5981 .3696 L
.59905 .37255 L
.6 .37547 L
.60095 .37839 L
.6019 .38129 L
.60286 .38418 L
.60381 .38705 L
.60476 .38991 L
.60571 .39275 L
.60667 .39557 L
.60762 .39839 L
.60857 .40118 L
.60952 .40397 L
.61048 .40673 L
.61143 .40948 L
.61238 .41222 L
.61333 .41494 L
.61429 .41764 L
.61524 .42033 L
.61619 .423 L
.61714 .42566 L
.6181 .4283 L
.61905 .43092 L
.62 .43353 L
.62095 .43612 L
.6219 .43869 L
.62286 .44125 L
.62381 .44379 L
.62476 .44631 L
.62571 .44882 L
.62667 .45131 L
.62762 .45378 L
.62857 .45623 L
.62952 .45867 L
.63048 .46109 L
.63143 .46349 L
.63238 .46588 L
.63333 .46824 L
.63429 .47059 L
.63524 .47292 L
.63619 .47523 L
.63714 .47753 L
.6381 .4798 L
.63905 .48206 L
.64 .4843 L
.64095 .48652 L
.6419 .48872 L
Mistroke
.64286 .49091 L
.64381 .49307 L
.64476 .49522 L
.64571 .49734 L
.64667 .49945 L
.64762 .50154 L
.64857 .50361 L
.64952 .50566 L
.65048 .50769 L
.65143 .5097 L
.65238 .51169 L
.65333 .51366 L
.65429 .51561 L
.65524 .51755 L
.65619 .51946 L
.65714 .52135 L
.6581 .52322 L
.65905 .52508 L
.66 .52691 L
.66095 .52872 L
.6619 .53051 L
.66286 .53228 L
.66381 .53404 L
.66476 .53577 L
.66571 .53748 L
.66667 .53916 L
.66762 .54083 L
.66857 .54248 L
.66952 .54411 L
.67048 .54571 L
.67143 .5473 L
.67238 .54886 L
.67333 .55041 L
.67429 .55193 L
.67524 .55343 L
.67619 .55491 L
.67714 .55637 L
.6781 .5578 L
.67905 .55922 L
.68 .56061 L
.68095 .56199 L
.6819 .56334 L
.68286 .56466 L
.68381 .56597 L
.68476 .56726 L
.68571 .56852 L
.68667 .56976 L
.68762 .57098 L
.68857 .57218 L
.68952 .57336 L
Mistroke
.69048 .57451 L
.69143 .57564 L
.69238 .57675 L
.69333 .57784 L
.69429 .5789 L
.69524 .57995 L
.69619 .58097 L
.69714 .58197 L
.6981 .58294 L
.69905 .5839 L
.7 .58483 L
.70095 .58574 L
.7019 .58662 L
.70286 .58748 L
.70381 .58833 L
.70476 .58914 L
.70571 .58994 L
.70667 .59071 L
.70762 .59146 L
.70857 .59219 L
.70952 .59289 L
.71048 .59357 L
.71143 .59423 L
.71238 .59487 L
.71333 .59548 L
.71429 .59607 L
.71524 .59664 L
.71619 .59718 L
.71714 .5977 L
.7181 .5982 L
.71905 .59868 L
.72 .59913 L
.72095 .59956 L
.7219 .59996 L
.72286 .60035 L
.72381 .60071 L
.72476 .60104 L
.72571 .60136 L
.72667 .60165 L
.72762 .60191 L
.72857 .60216 L
.72952 .60238 L
.73048 .60258 L
.73143 .60275 L
.73238 .6029 L
.73333 .60303 L
.73429 .60313 L
.73524 .60321 L
.73619 .60327 L
.73714 .60331 L
Mistroke
.7381 .60332 L
.73905 .60331 L
.74 .60327 L
.74095 .60321 L
.7419 .60313 L
.74286 .60303 L
.74381 .6029 L
.74476 .60275 L
.74571 .60258 L
.74667 .60238 L
.74762 .60216 L
.74857 .60191 L
.74952 .60165 L
.75048 .60136 L
.75143 .60104 L
.75238 .60071 L
.75333 .60035 L
.75429 .59996 L
.75524 .59956 L
.75619 .59913 L
.75714 .59868 L
.7581 .5982 L
.75905 .5977 L
.76 .59718 L
.76095 .59664 L
.7619 .59607 L
.76286 .59548 L
.76381 .59487 L
.76476 .59423 L
.76571 .59357 L
.76667 .59289 L
.76762 .59219 L
.76857 .59146 L
.76952 .59071 L
.77048 .58994 L
.77143 .58914 L
.77238 .58833 L
.77333 .58748 L
.77429 .58662 L
.77524 .58574 L
.77619 .58483 L
.77714 .5839 L
.7781 .58294 L
.77905 .58197 L
.78 .58097 L
.78095 .57995 L
.7819 .5789 L
.78286 .57784 L
.78381 .57675 L
.78476 .57564 L
Mistroke
.78571 .57451 L
.78667 .57336 L
.78762 .57218 L
.78857 .57098 L
.78952 .56976 L
.79048 .56852 L
.79143 .56726 L
.79238 .56597 L
.79333 .56466 L
.79429 .56334 L
.79524 .56199 L
.79619 .56061 L
.79714 .55922 L
.7981 .5578 L
.79905 .55637 L
.8 .55491 L
.80095 .55343 L
.8019 .55193 L
.80286 .55041 L
.80381 .54886 L
.80476 .5473 L
.80571 .54571 L
.80667 .54411 L
.80762 .54248 L
.80857 .54083 L
.80952 .53916 L
.81048 .53748 L
.81143 .53577 L
.81238 .53404 L
.81333 .53228 L
.81429 .53051 L
.81524 .52872 L
.81619 .52691 L
.81714 .52508 L
.8181 .52322 L
.81905 .52135 L
.82 .51946 L
.82095 .51755 L
.8219 .51561 L
.82286 .51366 L
.82381 .51169 L
.82476 .5097 L
.82571 .50769 L
.82667 .50566 L
.82762 .50361 L
.82857 .50154 L
.82952 .49945 L
.83048 .49734 L
.83143 .49522 L
.83238 .49307 L
Mistroke
.83333 .49091 L
.83429 .48872 L
.83524 .48652 L
.83619 .4843 L
.83714 .48206 L
.8381 .4798 L
.83905 .47753 L
.84 .47523 L
.84095 .47292 L
.8419 .47059 L
.84286 .46824 L
.84381 .46588 L
.84476 .46349 L
.84571 .46109 L
.84667 .45867 L
.84762 .45623 L
.84857 .45378 L
.84952 .45131 L
.85048 .44882 L
.85143 .44631 L
.85238 .44379 L
.85333 .44125 L
.85429 .43869 L
.85524 .43612 L
.85619 .43353 L
.85714 .43092 L
.8581 .4283 L
.85905 .42566 L
.86 .423 L
.86095 .42033 L
.8619 .41764 L
.86286 .41494 L
.86381 .41222 L
.86476 .40948 L
.86571 .40673 L
.86667 .40397 L
.86762 .40118 L
.86857 .39839 L
.86952 .39557 L
.87048 .39275 L
.87143 .38991 L
.87238 .38705 L
.87333 .38418 L
.87429 .38129 L
.87524 .37839 L
.87619 .37547 L
.87714 .37255 L
.8781 .3696 L
.87905 .36664 L
.88 .36367 L
Mistroke
.88095 .36069 L
.8819 .35769 L
.88286 .35468 L
.88381 .35165 L
.88476 .34861 L
.88571 .34556 L
.88667 .34249 L
.88762 .33942 L
.88857 .33632 L
.88952 .33322 L
.89048 .3301 L
.89143 .32698 L
.89238 .32383 L
.89333 .32068 L
.89429 .31752 L
.89524 .31434 L
.89619 .31115 L
.89714 .30795 L
.8981 .30474 L
.89905 .30151 L
.9 .29828 L
.90095 .29503 L
.9019 .29177 L
.90286 .2885 L
.90381 .28523 L
.90476 .28194 L
.90571 .27864 L
.90667 .27532 L
.90762 .272 L
.90857 .26867 L
.90952 .26533 L
.91048 .26198 L
.91143 .25862 L
.91238 .25525 L
.91333 .25187 L
.91429 .24848 L
.91524 .24508 L
.91619 .24167 L
.91714 .23825 L
.9181 .23483 L
.91905 .23139 L
.92 .22795 L
.92095 .2245 L
.9219 .22104 L
.92286 .21757 L
.92381 .2141 L
.92476 .21061 L
.92571 .20712 L
.92667 .20362 L
.92762 .20012 L
Mistroke
.92857 .1966 L
.92952 .19308 L
.93048 .18955 L
.93143 .18602 L
.93238 .18248 L
.93333 .17893 L
.93429 .17538 L
.93524 .17181 L
.93619 .16825 L
.93714 .16467 L
.9381 .16109 L
.93905 .15751 L
.94 .15392 L
.94095 .15032 L
.9419 .14672 L
.94286 .14312 L
.94381 .1395 L
.94476 .13589 L
.94571 .13227 L
.94667 .12864 L
.94762 .12501 L
.94857 .12137 L
.94952 .11773 L
.95048 .11409 L
.95143 .11044 L
.95238 .10679 L
.95333 .10314 L
.95429 .09948 L
.95524 .09582 L
.95619 .09215 L
.95714 .08849 L
.9581 .08482 L
.95905 .08114 L
.96 .07747 L
.96095 .07379 L
.9619 .07011 L
.96286 .06642 L
.96381 .06274 L
.96476 .05905 L
.96571 .05536 L
.96667 .05167 L
.96762 .04798 L
.96857 .04429 L
.96952 .04059 L
.97048 .0369 L
.97143 .0332 L
.97238 .02951 L
.97333 .02581 L
.97429 .02211 L
.97524 .01841 L
Mistroke
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0228571 0.000952381 0.309017 0.294302 [
[.21333 .29652 -9 -9 ]
[.21333 .29652 9 0 ]
[.40381 .29652 -9 -9 ]
[.40381 .29652 9 0 ]
[.59429 .29652 -9 -9 ]
[.59429 .29652 9 0 ]
[.78476 .29652 -9 -9 ]
[.78476 .29652 9 0 ]
[.97524 .29652 -12 -9 ]
[.97524 .29652 12 0 ]
[1.025 .30902 0 -6.28125 ]
[1.025 .30902 28 6.28125 ]
[.01036 .01472 -12 -4.5 ]
[.01036 .01472 0 4.5 ]
[.01036 .16187 -24 -4.5 ]
[.01036 .16187 0 4.5 ]
[.01036 .45617 -18 -4.5 ]
[.01036 .45617 0 4.5 ]
[.01036 .60332 -6 -4.5 ]
[.01036 .60332 0 4.5 ]
[.02286 .64303 -14 0 ]
[.02286 .64303 14 12.5625 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21333 .30902 m
.21333 .31527 L
s
[(200)] .21333 .29652 0 1 Mshowa
.40381 .30902 m
.40381 .31527 L
s
[(400)] .40381 .29652 0 1 Mshowa
.59429 .30902 m
.59429 .31527 L
s
[(600)] .59429 .29652 0 1 Mshowa
.78476 .30902 m
.78476 .31527 L
s
[(800)] .78476 .29652 0 1 Mshowa
.97524 .30902 m
.97524 .31527 L
s
[(1000)] .97524 .29652 0 1 Mshowa
.125 Mabswid
.07048 .30902 m
.07048 .31277 L
s
.1181 .30902 m
.1181 .31277 L
s
.16571 .30902 m
.16571 .31277 L
s
.26095 .30902 m
.26095 .31277 L
s
.30857 .30902 m
.30857 .31277 L
s
.35619 .30902 m
.35619 .31277 L
s
.45143 .30902 m
.45143 .31277 L
s
.49905 .30902 m
.49905 .31277 L
s
.54667 .30902 m
.54667 .31277 L
s
.6419 .30902 m
.6419 .31277 L
s
.68952 .30902 m
.68952 .31277 L
s
.73714 .30902 m
.73714 .31277 L
s
.83238 .30902 m
.83238 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92762 .30902 m
.92762 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(time) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.02286 .01472 m
.02911 .01472 L
s
[(-1)] .01036 .01472 1 0 Mshowa
.02286 .16187 m
.02911 .16187 L
s
[(-0.5)] .01036 .16187 1 0 Mshowa
.02286 .45617 m
.02911 .45617 L
s
[(0.5)] .01036 .45617 1 0 Mshowa
.02286 .60332 m
.02911 .60332 L
s
[(1)] .01036 .60332 1 0 Mshowa
.125 Mabswid
.02286 .04415 m
.02661 .04415 L
s
.02286 .07358 m
.02661 .07358 L
s
.02286 .10301 m
.02661 .10301 L
s
.02286 .13244 m
.02661 .13244 L
s
.02286 .1913 m
.02661 .1913 L
s
.02286 .22073 m
.02661 .22073 L
s
.02286 .25016 m
.02661 .25016 L
s
.02286 .27959 m
.02661 .27959 L
s
.02286 .33845 m
.02661 .33845 L
s
.02286 .36788 m
.02661 .36788 L
s
.02286 .39731 m
.02661 .39731 L
s
.02286 .42674 m
.02661 .42674 L
s
.02286 .4856 m
.02661 .4856 L
s
.02286 .51503 m
.02661 .51503 L
s
.02286 .54446 m
.02661 .54446 L
s
.02286 .57389 m
.02661 .57389 L
s
.25 Mabswid
.02286 0 m
.02286 .61803 L
s
gsave
.02286 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Amp) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
87.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 12.812500 moveto
(H) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 12.812500 moveto
(L) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
1 0 .75 r
.5 Mabswid
.02381 .60332 m
.02476 .60331 L
.02571 .6033 L
.02667 .60327 L
.02762 .60323 L
.02857 .60317 L
.02952 .60311 L
.03048 .60303 L
.03143 .60295 L
.03238 .60285 L
.03333 .60274 L
.03429 .60262 L
.03524 .60248 L
.03619 .60234 L
.03714 .60218 L
.0381 .60201 L
.03905 .60183 L
.04 .60164 L
.04095 .60144 L
.0419 .60122 L
.04286 .601 L
.04381 .60076 L
.04476 .60051 L
.04571 .60025 L
.04667 .59998 L
.04762 .5997 L
.04857 .5994 L
.04952 .59909 L
.05048 .59878 L
.05143 .59845 L
.05238 .59811 L
.05333 .59775 L
.05429 .59739 L
.05524 .59702 L
.05619 .59663 L
.05714 .59623 L
.0581 .59582 L
.05905 .5954 L
.06 .59497 L
.06095 .59453 L
.0619 .59407 L
.06286 .59361 L
.06381 .59313 L
.06476 .59264 L
.06571 .59214 L
.06667 .59163 L
.06762 .59111 L
.06857 .59058 L
.06952 .59004 L
.07048 .58948 L
Mistroke
.07143 .58891 L
.07238 .58834 L
.07333 .58775 L
.07429 .58715 L
.07524 .58654 L
.07619 .58592 L
.07714 .58529 L
.0781 .58465 L
.07905 .58399 L
.08 .58333 L
.08095 .58265 L
.0819 .58197 L
.08286 .58127 L
.08381 .58056 L
.08476 .57984 L
.08571 .57911 L
.08667 .57837 L
.08762 .57762 L
.08857 .57686 L
.08952 .57609 L
.09048 .57531 L
.09143 .57452 L
.09238 .57371 L
.09333 .5729 L
.09429 .57208 L
.09524 .57124 L
.09619 .5704 L
.09714 .56954 L
.0981 .56868 L
.09905 .5678 L
.1 .56692 L
.10095 .56602 L
.1019 .56511 L
.10286 .5642 L
.10381 .56327 L
.10476 .56234 L
.10571 .56139 L
.10667 .56043 L
.10762 .55947 L
.10857 .55849 L
.10952 .5575 L
.11048 .55651 L
.11143 .5555 L
.11238 .55449 L
.11333 .55346 L
.11429 .55243 L
.11524 .55138 L
.11619 .55033 L
.11714 .54927 L
.1181 .54819 L
Mistroke
.11905 .54711 L
.12 .54602 L
.12095 .54492 L
.1219 .54381 L
.12286 .54269 L
.12381 .54156 L
.12476 .54042 L
.12571 .53928 L
.12667 .53812 L
.12762 .53695 L
.12857 .53578 L
.12952 .5346 L
.13048 .53341 L
.13143 .5322 L
.13238 .53099 L
.13333 .52978 L
.13429 .52855 L
.13524 .52731 L
.13619 .52607 L
.13714 .52482 L
.1381 .52355 L
.13905 .52228 L
.14 .52101 L
.14095 .51972 L
.1419 .51842 L
.14286 .51712 L
.14381 .51581 L
.14476 .51449 L
.14571 .51316 L
.14667 .51182 L
.14762 .51048 L
.14857 .50913 L
.14952 .50777 L
.15048 .5064 L
.15143 .50503 L
.15238 .50364 L
.15333 .50225 L
.15429 .50085 L
.15524 .49945 L
.15619 .49803 L
.15714 .49661 L
.1581 .49518 L
.15905 .49375 L
.16 .4923 L
.16095 .49085 L
.1619 .4894 L
.16286 .48793 L
.16381 .48646 L
.16476 .48498 L
.16571 .4835 L
Mistroke
.16667 .482 L
.16762 .4805 L
.16857 .479 L
.16952 .47748 L
.17048 .47597 L
.17143 .47444 L
.17238 .47291 L
.17333 .47137 L
.17429 .46982 L
.17524 .46827 L
.17619 .46671 L
.17714 .46515 L
.1781 .46358 L
.17905 .462 L
.18 .46042 L
.18095 .45883 L
.1819 .45723 L
.18286 .45563 L
.18381 .45403 L
.18476 .45242 L
.18571 .4508 L
.18667 .44917 L
.18762 .44755 L
.18857 .44591 L
.18952 .44427 L
.19048 .44263 L
.19143 .44098 L
.19238 .43932 L
.19333 .43766 L
.19429 .436 L
.19524 .43432 L
.19619 .43265 L
.19714 .43097 L
.1981 .42928 L
.19905 .42759 L
.2 .4259 L
.20095 .4242 L
.2019 .4225 L
.20286 .42079 L
.20381 .41907 L
.20476 .41736 L
.20571 .41564 L
.20667 .41391 L
.20762 .41218 L
.20857 .41045 L
.20952 .40871 L
.21048 .40697 L
.21143 .40522 L
.21238 .40347 L
.21333 .40172 L
Mistroke
.21429 .39996 L
.21524 .3982 L
.21619 .39644 L
.21714 .39467 L
.2181 .3929 L
.21905 .39112 L
.22 .38935 L
.22095 .38757 L
.2219 .38578 L
.22286 .384 L
.22381 .38221 L
.22476 .38041 L
.22571 .37862 L
.22667 .37682 L
.22762 .37502 L
.22857 .37322 L
.22952 .37141 L
.23048 .3696 L
.23143 .36779 L
.23238 .36598 L
.23333 .36416 L
.23429 .36235 L
.23524 .36053 L
.23619 .3587 L
.23714 .35688 L
.2381 .35506 L
.23905 .35323 L
.24 .3514 L
.24095 .34957 L
.2419 .34774 L
.24286 .3459 L
.24381 .34407 L
.24476 .34223 L
.24571 .34039 L
.24667 .33855 L
.24762 .33671 L
.24857 .33487 L
.24952 .33303 L
.25048 .33119 L
.25143 .32934 L
.25238 .3275 L
.25333 .32565 L
.25429 .3238 L
.25524 .32196 L
.25619 .32011 L
.25714 .31826 L
.2581 .31641 L
.25905 .31456 L
.26 .31272 L
.26095 .31087 L
Mistroke
.2619 .30902 L
.26286 .30717 L
.26381 .30532 L
.26476 .30347 L
.26571 .30162 L
.26667 .29977 L
.26762 .29792 L
.26857 .29608 L
.26952 .29423 L
.27048 .29238 L
.27143 .29054 L
.27238 .28869 L
.27333 .28685 L
.27429 .285 L
.27524 .28316 L
.27619 .28132 L
.27714 .27948 L
.2781 .27764 L
.27905 .2758 L
.28 .27397 L
.28095 .27213 L
.2819 .2703 L
.28286 .26847 L
.28381 .26663 L
.28476 .26481 L
.28571 .26298 L
.28667 .26115 L
.28762 .25933 L
.28857 .25751 L
.28952 .25569 L
.29048 .25387 L
.29143 .25206 L
.29238 .25024 L
.29333 .24843 L
.29429 .24662 L
.29524 .24482 L
.29619 .24301 L
.29714 .24121 L
.2981 .23941 L
.29905 .23762 L
.3 .23583 L
.30095 .23404 L
.3019 .23225 L
.30286 .23047 L
.30381 .22869 L
.30476 .22691 L
.30571 .22514 L
.30667 .22336 L
.30762 .2216 L
.30857 .21983 L
Mistroke
.30952 .21807 L
.31048 .21632 L
.31143 .21456 L
.31238 .21281 L
.31333 .21107 L
.31429 .20933 L
.31524 .20759 L
.31619 .20585 L
.31714 .20412 L
.3181 .2024 L
.31905 .20068 L
.32 .19896 L
.32095 .19725 L
.3219 .19554 L
.32286 .19383 L
.32381 .19214 L
.32476 .19044 L
.32571 .18875 L
.32667 .18707 L
.32762 .18538 L
.32857 .18371 L
.32952 .18204 L
.33048 .18037 L
.33143 .17871 L
.33238 .17706 L
.33333 .17541 L
.33429 .17376 L
.33524 .17212 L
.33619 .17049 L
.33714 .16886 L
.3381 .16724 L
.33905 .16562 L
.34 .16401 L
.34095 .1624 L
.3419 .1608 L
.34286 .15921 L
.34381 .15762 L
.34476 .15603 L
.34571 .15446 L
.34667 .15289 L
.34762 .15132 L
.34857 .14976 L
.34952 .14821 L
.35048 .14667 L
.35143 .14513 L
.35238 .14359 L
.35333 .14207 L
.35429 .14055 L
.35524 .13904 L
.35619 .13753 L
Mistroke
.35714 .13603 L
.3581 .13454 L
.35905 .13305 L
.36 .13157 L
.36095 .1301 L
.3619 .12864 L
.36286 .12718 L
.36381 .12573 L
.36476 .12429 L
.36571 .12285 L
.36667 .12142 L
.36762 .12 L
.36857 .11859 L
.36952 .11718 L
.37048 .11578 L
.37143 .11439 L
.37238 .11301 L
.37333 .11163 L
.37429 .11027 L
.37524 .10891 L
.37619 .10755 L
.37714 .10621 L
.3781 .10487 L
.37905 .10355 L
.38 .10223 L
.38095 .10091 L
.3819 .09961 L
.38286 .09832 L
.38381 .09703 L
.38476 .09575 L
.38571 .09448 L
.38667 .09322 L
.38762 .09197 L
.38857 .09072 L
.38952 .08949 L
.39048 .08826 L
.39143 .08704 L
.39238 .08583 L
.39333 .08463 L
.39429 .08344 L
.39524 .08225 L
.39619 .08108 L
.39714 .07991 L
.3981 .07876 L
.39905 .07761 L
.4 .07647 L
.40095 .07534 L
.4019 .07422 L
.40286 .07311 L
.40381 .07201 L
Mistroke
.40476 .07092 L
.40571 .06984 L
.40667 .06877 L
.40762 .0677 L
.40857 .06665 L
.40952 .06561 L
.41048 .06457 L
.41143 .06355 L
.41238 .06253 L
.41333 .06153 L
.41429 .06053 L
.41524 .05954 L
.41619 .05857 L
.41714 .0576 L
.4181 .05665 L
.41905 .0557 L
.42 .05476 L
.42095 .05384 L
.4219 .05292 L
.42286 .05201 L
.42381 .05112 L
.42476 .05023 L
.42571 .04936 L
.42667 .04849 L
.42762 .04764 L
.42857 .04679 L
.42952 .04596 L
.43048 .04513 L
.43143 .04432 L
.43238 .04352 L
.43333 .04272 L
.43429 .04194 L
.43524 .04117 L
.43619 .04041 L
.43714 .03966 L
.4381 .03892 L
.43905 .03819 L
.44 .03747 L
.44095 .03677 L
.4419 .03607 L
.44286 .03538 L
.44381 .03471 L
.44476 .03404 L
.44571 .03339 L
.44667 .03275 L
.44762 .03211 L
.44857 .03149 L
.44952 .03088 L
.45048 .03028 L
.45143 .0297 L
Mistroke
.45238 .02912 L
.45333 .02855 L
.45429 .028 L
.45524 .02745 L
.45619 .02692 L
.45714 .0264 L
.4581 .02589 L
.45905 .02539 L
.46 .0249 L
.46095 .02443 L
.4619 .02396 L
.46286 .02351 L
.46381 .02306 L
.46476 .02263 L
.46571 .02221 L
.46667 .0218 L
.46762 .02141 L
.46857 .02102 L
.46952 .02064 L
.47048 .02028 L
.47143 .01993 L
.47238 .01959 L
.47333 .01926 L
.47429 .01894 L
.47524 .01863 L
.47619 .01834 L
.47714 .01805 L
.4781 .01778 L
.47905 .01752 L
.48 .01727 L
.48095 .01704 L
.4819 .01681 L
.48286 .0166 L
.48381 .01639 L
.48476 .0162 L
.48571 .01602 L
.48667 .01585 L
.48762 .0157 L
.48857 .01555 L
.48952 .01542 L
.49048 .0153 L
.49143 .01519 L
.49238 .01509 L
.49333 .015 L
.49429 .01492 L
.49524 .01486 L
.49619 .01481 L
.49714 .01477 L
.4981 .01474 L
.49905 .01472 L
Mistroke
.5 .01472 L
.50095 .01472 L
.5019 .01474 L
.50286 .01477 L
.50381 .01481 L
.50476 .01486 L
.50571 .01492 L
.50667 .015 L
.50762 .01509 L
.50857 .01519 L
.50952 .0153 L
.51048 .01542 L
.51143 .01555 L
.51238 .0157 L
.51333 .01585 L
.51429 .01602 L
.51524 .0162 L
.51619 .01639 L
.51714 .0166 L
.5181 .01681 L
.51905 .01704 L
.52 .01727 L
.52095 .01752 L
.5219 .01778 L
.52286 .01805 L
.52381 .01834 L
.52476 .01863 L
.52571 .01894 L
.52667 .01926 L
.52762 .01959 L
.52857 .01993 L
.52952 .02028 L
.53048 .02064 L
.53143 .02102 L
.53238 .02141 L
.53333 .0218 L
.53429 .02221 L
.53524 .02263 L
.53619 .02306 L
.53714 .02351 L
.5381 .02396 L
.53905 .02443 L
.54 .0249 L
.54095 .02539 L
.5419 .02589 L
.54286 .0264 L
.54381 .02692 L
.54476 .02745 L
.54571 .028 L
.54667 .02855 L
Mistroke
.54762 .02912 L
.54857 .0297 L
.54952 .03028 L
.55048 .03088 L
.55143 .03149 L
.55238 .03211 L
.55333 .03275 L
.55429 .03339 L
.55524 .03404 L
.55619 .03471 L
.55714 .03538 L
.5581 .03607 L
.55905 .03677 L
.56 .03747 L
.56095 .03819 L
.5619 .03892 L
.56286 .03966 L
.56381 .04041 L
.56476 .04117 L
.56571 .04194 L
.56667 .04272 L
.56762 .04352 L
.56857 .04432 L
.56952 .04513 L
.57048 .04596 L
.57143 .04679 L
.57238 .04764 L
.57333 .04849 L
.57429 .04936 L
.57524 .05023 L
.57619 .05112 L
.57714 .05201 L
.5781 .05292 L
.57905 .05384 L
.58 .05476 L
.58095 .0557 L
.5819 .05665 L
.58286 .0576 L
.58381 .05857 L
.58476 .05954 L
.58571 .06053 L
.58667 .06153 L
.58762 .06253 L
.58857 .06355 L
.58952 .06457 L
.59048 .06561 L
.59143 .06665 L
.59238 .0677 L
.59333 .06877 L
.59429 .06984 L
Mistroke
.59524 .07092 L
.59619 .07201 L
.59714 .07311 L
.5981 .07422 L
.59905 .07534 L
.6 .07647 L
.60095 .07761 L
.6019 .07876 L
.60286 .07991 L
.60381 .08108 L
.60476 .08225 L
.60571 .08344 L
.60667 .08463 L
.60762 .08583 L
.60857 .08704 L
.60952 .08826 L
.61048 .08949 L
.61143 .09072 L
.61238 .09197 L
.61333 .09322 L
.61429 .09448 L
.61524 .09575 L
.61619 .09703 L
.61714 .09832 L
.6181 .09961 L
.61905 .10091 L
.62 .10223 L
.62095 .10355 L
.6219 .10487 L
.62286 .10621 L
.62381 .10755 L
.62476 .10891 L
.62571 .11027 L
.62667 .11163 L
.62762 .11301 L
.62857 .11439 L
.62952 .11578 L
.63048 .11718 L
.63143 .11859 L
.63238 .12 L
.63333 .12142 L
.63429 .12285 L
.63524 .12429 L
.63619 .12573 L
.63714 .12718 L
.6381 .12864 L
.63905 .1301 L
.64 .13157 L
.64095 .13305 L
.6419 .13454 L
Mistroke
.64286 .13603 L
.64381 .13753 L
.64476 .13904 L
.64571 .14055 L
.64667 .14207 L
.64762 .14359 L
.64857 .14513 L
.64952 .14667 L
.65048 .14821 L
.65143 .14976 L
.65238 .15132 L
.65333 .15289 L
.65429 .15446 L
.65524 .15603 L
.65619 .15762 L
.65714 .15921 L
.6581 .1608 L
.65905 .1624 L
.66 .16401 L
.66095 .16562 L
.6619 .16724 L
.66286 .16886 L
.66381 .17049 L
.66476 .17212 L
.66571 .17376 L
.66667 .17541 L
.66762 .17706 L
.66857 .17871 L
.66952 .18037 L
.67048 .18204 L
.67143 .18371 L
.67238 .18538 L
.67333 .18707 L
.67429 .18875 L
.67524 .19044 L
.67619 .19214 L
.67714 .19383 L
.6781 .19554 L
.67905 .19725 L
.68 .19896 L
.68095 .20068 L
.6819 .2024 L
.68286 .20412 L
.68381 .20585 L
.68476 .20759 L
.68571 .20933 L
.68667 .21107 L
.68762 .21281 L
.68857 .21456 L
.68952 .21632 L
Mistroke
.69048 .21807 L
.69143 .21983 L
.69238 .2216 L
.69333 .22336 L
.69429 .22514 L
.69524 .22691 L
.69619 .22869 L
.69714 .23047 L
.6981 .23225 L
.69905 .23404 L
.7 .23583 L
.70095 .23762 L
.7019 .23941 L
.70286 .24121 L
.70381 .24301 L
.70476 .24482 L
.70571 .24662 L
.70667 .24843 L
.70762 .25024 L
.70857 .25206 L
.70952 .25387 L
.71048 .25569 L
.71143 .25751 L
.71238 .25933 L
.71333 .26115 L
.71429 .26298 L
.71524 .26481 L
.71619 .26663 L
.71714 .26847 L
.7181 .2703 L
.71905 .27213 L
.72 .27397 L
.72095 .2758 L
.7219 .27764 L
.72286 .27948 L
.72381 .28132 L
.72476 .28316 L
.72571 .285 L
.72667 .28685 L
.72762 .28869 L
.72857 .29054 L
.72952 .29238 L
.73048 .29423 L
.73143 .29608 L
.73238 .29792 L
.73333 .29977 L
.73429 .30162 L
.73524 .30347 L
.73619 .30532 L
.73714 .30717 L
Mistroke
.7381 .30902 L
.73905 .31087 L
.74 .31272 L
.74095 .31456 L
.7419 .31641 L
.74286 .31826 L
.74381 .32011 L
.74476 .32196 L
.74571 .3238 L
.74667 .32565 L
.74762 .3275 L
.74857 .32934 L
.74952 .33119 L
.75048 .33303 L
.75143 .33487 L
.75238 .33671 L
.75333 .33855 L
.75429 .34039 L
.75524 .34223 L
.75619 .34407 L
.75714 .3459 L
.7581 .34774 L
.75905 .34957 L
.76 .3514 L
.76095 .35323 L
.7619 .35506 L
.76286 .35688 L
.76381 .3587 L
.76476 .36053 L
.76571 .36235 L
.76667 .36416 L
.76762 .36598 L
.76857 .36779 L
.76952 .3696 L
.77048 .37141 L
.77143 .37322 L
.77238 .37502 L
.77333 .37682 L
.77429 .37862 L
.77524 .38041 L
.77619 .38221 L
.77714 .384 L
.7781 .38578 L
.77905 .38757 L
.78 .38935 L
.78095 .39112 L
.7819 .3929 L
.78286 .39467 L
.78381 .39644 L
.78476 .3982 L
Mistroke
.78571 .39996 L
.78667 .40172 L
.78762 .40347 L
.78857 .40522 L
.78952 .40697 L
.79048 .40871 L
.79143 .41045 L
.79238 .41218 L
.79333 .41391 L
.79429 .41564 L
.79524 .41736 L
.79619 .41907 L
.79714 .42079 L
.7981 .4225 L
.79905 .4242 L
.8 .4259 L
.80095 .42759 L
.8019 .42928 L
.80286 .43097 L
.80381 .43265 L
.80476 .43432 L
.80571 .436 L
.80667 .43766 L
.80762 .43932 L
.80857 .44098 L
.80952 .44263 L
.81048 .44427 L
.81143 .44591 L
.81238 .44755 L
.81333 .44917 L
.81429 .4508 L
.81524 .45242 L
.81619 .45403 L
.81714 .45563 L
.8181 .45723 L
.81905 .45883 L
.82 .46042 L
.82095 .462 L
.8219 .46358 L
.82286 .46515 L
.82381 .46671 L
.82476 .46827 L
.82571 .46982 L
.82667 .47137 L
.82762 .47291 L
.82857 .47444 L
.82952 .47597 L
.83048 .47748 L
.83143 .479 L
.83238 .4805 L
Mistroke
.83333 .482 L
.83429 .4835 L
.83524 .48498 L
.83619 .48646 L
.83714 .48793 L
.8381 .4894 L
.83905 .49085 L
.84 .4923 L
.84095 .49375 L
.8419 .49518 L
.84286 .49661 L
.84381 .49803 L
.84476 .49945 L
.84571 .50085 L
.84667 .50225 L
.84762 .50364 L
.84857 .50503 L
.84952 .5064 L
.85048 .50777 L
.85143 .50913 L
.85238 .51048 L
.85333 .51182 L
.85429 .51316 L
.85524 .51449 L
.85619 .51581 L
.85714 .51712 L
.8581 .51842 L
.85905 .51972 L
.86 .52101 L
.86095 .52228 L
.8619 .52355 L
.86286 .52482 L
.86381 .52607 L
.86476 .52731 L
.86571 .52855 L
.86667 .52978 L
.86762 .53099 L
.86857 .5322 L
.86952 .53341 L
.87048 .5346 L
.87143 .53578 L
.87238 .53695 L
.87333 .53812 L
.87429 .53928 L
.87524 .54042 L
.87619 .54156 L
.87714 .54269 L
.8781 .54381 L
.87905 .54492 L
.88 .54602 L
Mistroke
.88095 .54711 L
.8819 .54819 L
.88286 .54927 L
.88381 .55033 L
.88476 .55138 L
.88571 .55243 L
.88667 .55346 L
.88762 .55449 L
.88857 .5555 L
.88952 .55651 L
.89048 .5575 L
.89143 .55849 L
.89238 .55947 L
.89333 .56043 L
.89429 .56139 L
.89524 .56234 L
.89619 .56327 L
.89714 .5642 L
.8981 .56511 L
.89905 .56602 L
.9 .56692 L
.90095 .5678 L
.9019 .56868 L
.90286 .56954 L
.90381 .5704 L
.90476 .57124 L
.90571 .57208 L
.90667 .5729 L
.90762 .57371 L
.90857 .57452 L
.90952 .57531 L
.91048 .57609 L
.91143 .57686 L
.91238 .57762 L
.91333 .57837 L
.91429 .57911 L
.91524 .57984 L
.91619 .58056 L
.91714 .58127 L
.9181 .58197 L
.91905 .58265 L
.92 .58333 L
.92095 .58399 L
.9219 .58465 L
.92286 .58529 L
.92381 .58592 L
.92476 .58654 L
.92571 .58715 L
.92667 .58775 L
.92762 .58834 L
Mistroke
.92857 .58891 L
.92952 .58948 L
.93048 .59004 L
.93143 .59058 L
.93238 .59111 L
.93333 .59163 L
.93429 .59214 L
.93524 .59264 L
.93619 .59313 L
.93714 .59361 L
.9381 .59407 L
.93905 .59453 L
.94 .59497 L
.94095 .5954 L
.9419 .59582 L
.94286 .59623 L
.94381 .59663 L
.94476 .59702 L
.94571 .59739 L
.94667 .59775 L
.94762 .59811 L
.94857 .59845 L
.94952 .59878 L
.95048 .59909 L
.95143 .5994 L
.95238 .5997 L
.95333 .59998 L
.95429 .60025 L
.95524 .60051 L
.95619 .60076 L
.95714 .601 L
.9581 .60122 L
.95905 .60144 L
.96 .60164 L
.96095 .60183 L
.9619 .60201 L
.96286 .60218 L
.96381 .60234 L
.96476 .60248 L
.96571 .60262 L
.96667 .60274 L
.96762 .60285 L
.96857 .60295 L
.96952 .60303 L
.97048 .60311 L
.97143 .60317 L
.97238 .60323 L
.97333 .60327 L
.97429 .6033 L
.97524 .60331 L
Mistroke
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0228571 0.000952381 0.309017 0.294302 [
[.21333 .29652 -9 -9 ]
[.21333 .29652 9 0 ]
[.40381 .29652 -9 -9 ]
[.40381 .29652 9 0 ]
[.59429 .29652 -9 -9 ]
[.59429 .29652 9 0 ]
[.78476 .29652 -9 -9 ]
[.78476 .29652 9 0 ]
[.97524 .29652 -12 -9 ]
[.97524 .29652 12 0 ]
[1.025 .30902 0 -6.28125 ]
[1.025 .30902 28 6.28125 ]
[.01036 .01472 -12 -4.5 ]
[.01036 .01472 0 4.5 ]
[.01036 .16187 -24 -4.5 ]
[.01036 .16187 0 4.5 ]
[.01036 .45617 -18 -4.5 ]
[.01036 .45617 0 4.5 ]
[.01036 .60332 -6 -4.5 ]
[.01036 .60332 0 4.5 ]
[.02286 .64303 -14 0 ]
[.02286 .64303 14 12.5625 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21333 .30902 m
.21333 .31527 L
s
[(200)] .21333 .29652 0 1 Mshowa
.40381 .30902 m
.40381 .31527 L
s
[(400)] .40381 .29652 0 1 Mshowa
.59429 .30902 m
.59429 .31527 L
s
[(600)] .59429 .29652 0 1 Mshowa
.78476 .30902 m
.78476 .31527 L
s
[(800)] .78476 .29652 0 1 Mshowa
.97524 .30902 m
.97524 .31527 L
s
[(1000)] .97524 .29652 0 1 Mshowa
.125 Mabswid
.07048 .30902 m
.07048 .31277 L
s
.1181 .30902 m
.1181 .31277 L
s
.16571 .30902 m
.16571 .31277 L
s
.26095 .30902 m
.26095 .31277 L
s
.30857 .30902 m
.30857 .31277 L
s
.35619 .30902 m
.35619 .31277 L
s
.45143 .30902 m
.45143 .31277 L
s
.49905 .30902 m
.49905 .31277 L
s
.54667 .30902 m
.54667 .31277 L
s
.6419 .30902 m
.6419 .31277 L
s
.68952 .30902 m
.68952 .31277 L
s
.73714 .30902 m
.73714 .31277 L
s
.83238 .30902 m
.83238 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92762 .30902 m
.92762 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(time) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.02286 .01472 m
.02911 .01472 L
s
[(-1)] .01036 .01472 1 0 Mshowa
.02286 .16187 m
.02911 .16187 L
s
[(-0.5)] .01036 .16187 1 0 Mshowa
.02286 .45617 m
.02911 .45617 L
s
[(0.5)] .01036 .45617 1 0 Mshowa
.02286 .60332 m
.02911 .60332 L
s
[(1)] .01036 .60332 1 0 Mshowa
.125 Mabswid
.02286 .04415 m
.02661 .04415 L
s
.02286 .07358 m
.02661 .07358 L
s
.02286 .10301 m
.02661 .10301 L
s
.02286 .13244 m
.02661 .13244 L
s
.02286 .1913 m
.02661 .1913 L
s
.02286 .22073 m
.02661 .22073 L
s
.02286 .25016 m
.02661 .25016 L
s
.02286 .27959 m
.02661 .27959 L
s
.02286 .33845 m
.02661 .33845 L
s
.02286 .36788 m
.02661 .36788 L
s
.02286 .39731 m
.02661 .39731 L
s
.02286 .42674 m
.02661 .42674 L
s
.02286 .4856 m
.02661 .4856 L
s
.02286 .51503 m
.02661 .51503 L
s
.02286 .54446 m
.02661 .54446 L
s
.02286 .57389 m
.02661 .57389 L
s
.25 Mabswid
.02286 0 m
.02286 .61803 L
s
gsave
.02286 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Amp) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
87.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 12.812500 moveto
(H) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 12.812500 moveto
(L) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 .25 r
.5 Mabswid
.02381 .30902 m
.02476 .31087 L
.02571 .31272 L
.02667 .31456 L
.02762 .31641 L
.02857 .31826 L
.02952 .32011 L
.03048 .32196 L
.03143 .3238 L
.03238 .32565 L
.03333 .3275 L
.03429 .32934 L
.03524 .33119 L
.03619 .33303 L
.03714 .33487 L
.0381 .33671 L
.03905 .33855 L
.04 .34039 L
.04095 .34223 L
.0419 .34407 L
.04286 .3459 L
.04381 .34774 L
.04476 .34957 L
.04571 .3514 L
.04667 .35323 L
.04762 .35506 L
.04857 .35688 L
.04952 .3587 L
.05048 .36053 L
.05143 .36235 L
.05238 .36416 L
.05333 .36598 L
.05429 .36779 L
.05524 .3696 L
.05619 .37141 L
.05714 .37322 L
.0581 .37502 L
.05905 .37682 L
.06 .37862 L
.06095 .38041 L
.0619 .38221 L
.06286 .384 L
.06381 .38578 L
.06476 .38757 L
.06571 .38935 L
.06667 .39112 L
.06762 .3929 L
.06857 .39467 L
.06952 .39644 L
.07048 .3982 L
Mistroke
.07143 .39996 L
.07238 .40172 L
.07333 .40347 L
.07429 .40522 L
.07524 .40697 L
.07619 .40871 L
.07714 .41045 L
.0781 .41218 L
.07905 .41391 L
.08 .41564 L
.08095 .41736 L
.0819 .41907 L
.08286 .42079 L
.08381 .4225 L
.08476 .4242 L
.08571 .4259 L
.08667 .42759 L
.08762 .42928 L
.08857 .43097 L
.08952 .43265 L
.09048 .43432 L
.09143 .436 L
.09238 .43766 L
.09333 .43932 L
.09429 .44098 L
.09524 .44263 L
.09619 .44427 L
.09714 .44591 L
.0981 .44755 L
.09905 .44917 L
.1 .4508 L
.10095 .45242 L
.1019 .45403 L
.10286 .45563 L
.10381 .45723 L
.10476 .45883 L
.10571 .46042 L
.10667 .462 L
.10762 .46358 L
.10857 .46515 L
.10952 .46671 L
.11048 .46827 L
.11143 .46982 L
.11238 .47137 L
.11333 .47291 L
.11429 .47444 L
.11524 .47597 L
.11619 .47748 L
.11714 .479 L
.1181 .4805 L
Mistroke
.11905 .482 L
.12 .4835 L
.12095 .48498 L
.1219 .48646 L
.12286 .48793 L
.12381 .4894 L
.12476 .49085 L
.12571 .4923 L
.12667 .49375 L
.12762 .49518 L
.12857 .49661 L
.12952 .49803 L
.13048 .49945 L
.13143 .50085 L
.13238 .50225 L
.13333 .50364 L
.13429 .50503 L
.13524 .5064 L
.13619 .50777 L
.13714 .50913 L
.1381 .51048 L
.13905 .51182 L
.14 .51316 L
.14095 .51449 L
.1419 .51581 L
.14286 .51712 L
.14381 .51842 L
.14476 .51972 L
.14571 .52101 L
.14667 .52228 L
.14762 .52355 L
.14857 .52482 L
.14952 .52607 L
.15048 .52731 L
.15143 .52855 L
.15238 .52978 L
.15333 .53099 L
.15429 .5322 L
.15524 .53341 L
.15619 .5346 L
.15714 .53578 L
.1581 .53695 L
.15905 .53812 L
.16 .53928 L
.16095 .54042 L
.1619 .54156 L
.16286 .54269 L
.16381 .54381 L
.16476 .54492 L
.16571 .54602 L
Mistroke
.16667 .54711 L
.16762 .54819 L
.16857 .54927 L
.16952 .55033 L
.17048 .55138 L
.17143 .55243 L
.17238 .55346 L
.17333 .55449 L
.17429 .5555 L
.17524 .55651 L
.17619 .5575 L
.17714 .55849 L
.1781 .55947 L
.17905 .56043 L
.18 .56139 L
.18095 .56234 L
.1819 .56327 L
.18286 .5642 L
.18381 .56511 L
.18476 .56602 L
.18571 .56692 L
.18667 .5678 L
.18762 .56868 L
.18857 .56954 L
.18952 .5704 L
.19048 .57124 L
.19143 .57208 L
.19238 .5729 L
.19333 .57371 L
.19429 .57452 L
.19524 .57531 L
.19619 .57609 L
.19714 .57686 L
.1981 .57762 L
.19905 .57837 L
.2 .57911 L
.20095 .57984 L
.2019 .58056 L
.20286 .58127 L
.20381 .58197 L
.20476 .58265 L
.20571 .58333 L
.20667 .58399 L
.20762 .58465 L
.20857 .58529 L
.20952 .58592 L
.21048 .58654 L
.21143 .58715 L
.21238 .58775 L
.21333 .58834 L
Mistroke
.21429 .58891 L
.21524 .58948 L
.21619 .59004 L
.21714 .59058 L
.2181 .59111 L
.21905 .59163 L
.22 .59214 L
.22095 .59264 L
.2219 .59313 L
.22286 .59361 L
.22381 .59407 L
.22476 .59453 L
.22571 .59497 L
.22667 .5954 L
.22762 .59582 L
.22857 .59623 L
.22952 .59663 L
.23048 .59702 L
.23143 .59739 L
.23238 .59775 L
.23333 .59811 L
.23429 .59845 L
.23524 .59878 L
.23619 .59909 L
.23714 .5994 L
.2381 .5997 L
.23905 .59998 L
.24 .60025 L
.24095 .60051 L
.2419 .60076 L
.24286 .601 L
.24381 .60122 L
.24476 .60144 L
.24571 .60164 L
.24667 .60183 L
.24762 .60201 L
.24857 .60218 L
.24952 .60234 L
.25048 .60248 L
.25143 .60262 L
.25238 .60274 L
.25333 .60285 L
.25429 .60295 L
.25524 .60303 L
.25619 .60311 L
.25714 .60317 L
.2581 .60323 L
.25905 .60327 L
.26 .6033 L
.26095 .60331 L
Mistroke
.2619 .60332 L
.26286 .60331 L
.26381 .6033 L
.26476 .60327 L
.26571 .60323 L
.26667 .60317 L
.26762 .60311 L
.26857 .60303 L
.26952 .60295 L
.27048 .60285 L
.27143 .60274 L
.27238 .60262 L
.27333 .60248 L
.27429 .60234 L
.27524 .60218 L
.27619 .60201 L
.27714 .60183 L
.2781 .60164 L
.27905 .60144 L
.28 .60122 L
.28095 .601 L
.2819 .60076 L
.28286 .60051 L
.28381 .60025 L
.28476 .59998 L
.28571 .5997 L
.28667 .5994 L
.28762 .59909 L
.28857 .59878 L
.28952 .59845 L
.29048 .59811 L
.29143 .59775 L
.29238 .59739 L
.29333 .59702 L
.29429 .59663 L
.29524 .59623 L
.29619 .59582 L
.29714 .5954 L
.2981 .59497 L
.29905 .59453 L
.3 .59407 L
.30095 .59361 L
.3019 .59313 L
.30286 .59264 L
.30381 .59214 L
.30476 .59163 L
.30571 .59111 L
.30667 .59058 L
.30762 .59004 L
.30857 .58948 L
Mistroke
.30952 .58891 L
.31048 .58834 L
.31143 .58775 L
.31238 .58715 L
.31333 .58654 L
.31429 .58592 L
.31524 .58529 L
.31619 .58465 L
.31714 .58399 L
.3181 .58333 L
.31905 .58265 L
.32 .58197 L
.32095 .58127 L
.3219 .58056 L
.32286 .57984 L
.32381 .57911 L
.32476 .57837 L
.32571 .57762 L
.32667 .57686 L
.32762 .57609 L
.32857 .57531 L
.32952 .57452 L
.33048 .57371 L
.33143 .5729 L
.33238 .57208 L
.33333 .57124 L
.33429 .5704 L
.33524 .56954 L
.33619 .56868 L
.33714 .5678 L
.3381 .56692 L
.33905 .56602 L
.34 .56511 L
.34095 .5642 L
.3419 .56327 L
.34286 .56234 L
.34381 .56139 L
.34476 .56043 L
.34571 .55947 L
.34667 .55849 L
.34762 .5575 L
.34857 .55651 L
.34952 .5555 L
.35048 .55449 L
.35143 .55346 L
.35238 .55243 L
.35333 .55138 L
.35429 .55033 L
.35524 .54927 L
.35619 .54819 L
Mistroke
.35714 .54711 L
.3581 .54602 L
.35905 .54492 L
.36 .54381 L
.36095 .54269 L
.3619 .54156 L
.36286 .54042 L
.36381 .53928 L
.36476 .53812 L
.36571 .53695 L
.36667 .53578 L
.36762 .5346 L
.36857 .53341 L
.36952 .5322 L
.37048 .53099 L
.37143 .52978 L
.37238 .52855 L
.37333 .52731 L
.37429 .52607 L
.37524 .52482 L
.37619 .52355 L
.37714 .52228 L
.3781 .52101 L
.37905 .51972 L
.38 .51842 L
.38095 .51712 L
.3819 .51581 L
.38286 .51449 L
.38381 .51316 L
.38476 .51182 L
.38571 .51048 L
.38667 .50913 L
.38762 .50777 L
.38857 .5064 L
.38952 .50503 L
.39048 .50364 L
.39143 .50225 L
.39238 .50085 L
.39333 .49945 L
.39429 .49803 L
.39524 .49661 L
.39619 .49518 L
.39714 .49375 L
.3981 .4923 L
.39905 .49085 L
.4 .4894 L
.40095 .48793 L
.4019 .48646 L
.40286 .48498 L
.40381 .4835 L
Mistroke
.40476 .482 L
.40571 .4805 L
.40667 .479 L
.40762 .47748 L
.40857 .47597 L
.40952 .47444 L
.41048 .47291 L
.41143 .47137 L
.41238 .46982 L
.41333 .46827 L
.41429 .46671 L
.41524 .46515 L
.41619 .46358 L
.41714 .462 L
.4181 .46042 L
.41905 .45883 L
.42 .45723 L
.42095 .45563 L
.4219 .45403 L
.42286 .45242 L
.42381 .4508 L
.42476 .44917 L
.42571 .44755 L
.42667 .44591 L
.42762 .44427 L
.42857 .44263 L
.42952 .44098 L
.43048 .43932 L
.43143 .43766 L
.43238 .436 L
.43333 .43432 L
.43429 .43265 L
.43524 .43097 L
.43619 .42928 L
.43714 .42759 L
.4381 .4259 L
.43905 .4242 L
.44 .4225 L
.44095 .42079 L
.4419 .41907 L
.44286 .41736 L
.44381 .41564 L
.44476 .41391 L
.44571 .41218 L
.44667 .41045 L
.44762 .40871 L
.44857 .40697 L
.44952 .40522 L
.45048 .40347 L
.45143 .40172 L
Mistroke
.45238 .39996 L
.45333 .3982 L
.45429 .39644 L
.45524 .39467 L
.45619 .3929 L
.45714 .39112 L
.4581 .38935 L
.45905 .38757 L
.46 .38578 L
.46095 .384 L
.4619 .38221 L
.46286 .38041 L
.46381 .37862 L
.46476 .37682 L
.46571 .37502 L
.46667 .37322 L
.46762 .37141 L
.46857 .3696 L
.46952 .36779 L
.47048 .36598 L
.47143 .36416 L
.47238 .36235 L
.47333 .36053 L
.47429 .3587 L
.47524 .35688 L
.47619 .35506 L
.47714 .35323 L
.4781 .3514 L
.47905 .34957 L
.48 .34774 L
.48095 .3459 L
.4819 .34407 L
.48286 .34223 L
.48381 .34039 L
.48476 .33855 L
.48571 .33671 L
.48667 .33487 L
.48762 .33303 L
.48857 .33119 L
.48952 .32934 L
.49048 .3275 L
.49143 .32565 L
.49238 .3238 L
.49333 .32196 L
.49429 .32011 L
.49524 .31826 L
.49619 .31641 L
.49714 .31456 L
.4981 .31272 L
.49905 .31087 L
Mistroke
.5 .30902 L
.50095 .30717 L
.5019 .30532 L
.50286 .30347 L
.50381 .30162 L
.50476 .29977 L
.50571 .29792 L
.50667 .29608 L
.50762 .29423 L
.50857 .29238 L
.50952 .29054 L
.51048 .28869 L
.51143 .28685 L
.51238 .285 L
.51333 .28316 L
.51429 .28132 L
.51524 .27948 L
.51619 .27764 L
.51714 .2758 L
.5181 .27397 L
.51905 .27213 L
.52 .2703 L
.52095 .26847 L
.5219 .26663 L
.52286 .26481 L
.52381 .26298 L
.52476 .26115 L
.52571 .25933 L
.52667 .25751 L
.52762 .25569 L
.52857 .25387 L
.52952 .25206 L
.53048 .25024 L
.53143 .24843 L
.53238 .24662 L
.53333 .24482 L
.53429 .24301 L
.53524 .24121 L
.53619 .23941 L
.53714 .23762 L
.5381 .23583 L
.53905 .23404 L
.54 .23225 L
.54095 .23047 L
.5419 .22869 L
.54286 .22691 L
.54381 .22514 L
.54476 .22336 L
.54571 .2216 L
.54667 .21983 L
Mistroke
.54762 .21807 L
.54857 .21632 L
.54952 .21456 L
.55048 .21281 L
.55143 .21107 L
.55238 .20933 L
.55333 .20759 L
.55429 .20585 L
.55524 .20412 L
.55619 .2024 L
.55714 .20068 L
.5581 .19896 L
.55905 .19725 L
.56 .19554 L
.56095 .19383 L
.5619 .19214 L
.56286 .19044 L
.56381 .18875 L
.56476 .18707 L
.56571 .18538 L
.56667 .18371 L
.56762 .18204 L
.56857 .18037 L
.56952 .17871 L
.57048 .17706 L
.57143 .17541 L
.57238 .17376 L
.57333 .17212 L
.57429 .17049 L
.57524 .16886 L
.57619 .16724 L
.57714 .16562 L
.5781 .16401 L
.57905 .1624 L
.58 .1608 L
.58095 .15921 L
.5819 .15762 L
.58286 .15603 L
.58381 .15446 L
.58476 .15289 L
.58571 .15132 L
.58667 .14976 L
.58762 .14821 L
.58857 .14667 L
.58952 .14513 L
.59048 .14359 L
.59143 .14207 L
.59238 .14055 L
.59333 .13904 L
.59429 .13753 L
Mistroke
.59524 .13603 L
.59619 .13454 L
.59714 .13305 L
.5981 .13157 L
.59905 .1301 L
.6 .12864 L
.60095 .12718 L
.6019 .12573 L
.60286 .12429 L
.60381 .12285 L
.60476 .12142 L
.60571 .12 L
.60667 .11859 L
.60762 .11718 L
.60857 .11578 L
.60952 .11439 L
.61048 .11301 L
.61143 .11163 L
.61238 .11027 L
.61333 .10891 L
.61429 .10755 L
.61524 .10621 L
.61619 .10487 L
.61714 .10355 L
.6181 .10223 L
.61905 .10091 L
.62 .09961 L
.62095 .09832 L
.6219 .09703 L
.62286 .09575 L
.62381 .09448 L
.62476 .09322 L
.62571 .09197 L
.62667 .09072 L
.62762 .08949 L
.62857 .08826 L
.62952 .08704 L
.63048 .08583 L
.63143 .08463 L
.63238 .08344 L
.63333 .08225 L
.63429 .08108 L
.63524 .07991 L
.63619 .07876 L
.63714 .07761 L
.6381 .07647 L
.63905 .07534 L
.64 .07422 L
.64095 .07311 L
.6419 .07201 L
Mistroke
.64286 .07092 L
.64381 .06984 L
.64476 .06877 L
.64571 .0677 L
.64667 .06665 L
.64762 .06561 L
.64857 .06457 L
.64952 .06355 L
.65048 .06253 L
.65143 .06153 L
.65238 .06053 L
.65333 .05954 L
.65429 .05857 L
.65524 .0576 L
.65619 .05665 L
.65714 .0557 L
.6581 .05476 L
.65905 .05384 L
.66 .05292 L
.66095 .05201 L
.6619 .05112 L
.66286 .05023 L
.66381 .04936 L
.66476 .04849 L
.66571 .04764 L
.66667 .04679 L
.66762 .04596 L
.66857 .04513 L
.66952 .04432 L
.67048 .04352 L
.67143 .04272 L
.67238 .04194 L
.67333 .04117 L
.67429 .04041 L
.67524 .03966 L
.67619 .03892 L
.67714 .03819 L
.6781 .03747 L
.67905 .03677 L
.68 .03607 L
.68095 .03538 L
.6819 .03471 L
.68286 .03404 L
.68381 .03339 L
.68476 .03275 L
.68571 .03211 L
.68667 .03149 L
.68762 .03088 L
.68857 .03028 L
.68952 .0297 L
Mistroke
.69048 .02912 L
.69143 .02855 L
.69238 .028 L
.69333 .02745 L
.69429 .02692 L
.69524 .0264 L
.69619 .02589 L
.69714 .02539 L
.6981 .0249 L
.69905 .02443 L
.7 .02396 L
.70095 .02351 L
.7019 .02306 L
.70286 .02263 L
.70381 .02221 L
.70476 .0218 L
.70571 .02141 L
.70667 .02102 L
.70762 .02064 L
.70857 .02028 L
.70952 .01993 L
.71048 .01959 L
.71143 .01926 L
.71238 .01894 L
.71333 .01863 L
.71429 .01834 L
.71524 .01805 L
.71619 .01778 L
.71714 .01752 L
.7181 .01727 L
.71905 .01704 L
.72 .01681 L
.72095 .0166 L
.7219 .01639 L
.72286 .0162 L
.72381 .01602 L
.72476 .01585 L
.72571 .0157 L
.72667 .01555 L
.72762 .01542 L
.72857 .0153 L
.72952 .01519 L
.73048 .01509 L
.73143 .015 L
.73238 .01492 L
.73333 .01486 L
.73429 .01481 L
.73524 .01477 L
.73619 .01474 L
.73714 .01472 L
Mistroke
.7381 .01472 L
.73905 .01472 L
.74 .01474 L
.74095 .01477 L
.7419 .01481 L
.74286 .01486 L
.74381 .01492 L
.74476 .015 L
.74571 .01509 L
.74667 .01519 L
.74762 .0153 L
.74857 .01542 L
.74952 .01555 L
.75048 .0157 L
.75143 .01585 L
.75238 .01602 L
.75333 .0162 L
.75429 .01639 L
.75524 .0166 L
.75619 .01681 L
.75714 .01704 L
.7581 .01727 L
.75905 .01752 L
.76 .01778 L
.76095 .01805 L
.7619 .01834 L
.76286 .01863 L
.76381 .01894 L
.76476 .01926 L
.76571 .01959 L
.76667 .01993 L
.76762 .02028 L
.76857 .02064 L
.76952 .02102 L
.77048 .02141 L
.77143 .0218 L
.77238 .02221 L
.77333 .02263 L
.77429 .02306 L
.77524 .02351 L
.77619 .02396 L
.77714 .02443 L
.7781 .0249 L
.77905 .02539 L
.78 .02589 L
.78095 .0264 L
.7819 .02692 L
.78286 .02745 L
.78381 .028 L
.78476 .02855 L
Mistroke
.78571 .02912 L
.78667 .0297 L
.78762 .03028 L
.78857 .03088 L
.78952 .03149 L
.79048 .03211 L
.79143 .03275 L
.79238 .03339 L
.79333 .03404 L
.79429 .03471 L
.79524 .03538 L
.79619 .03607 L
.79714 .03677 L
.7981 .03747 L
.79905 .03819 L
.8 .03892 L
.80095 .03966 L
.8019 .04041 L
.80286 .04117 L
.80381 .04194 L
.80476 .04272 L
.80571 .04352 L
.80667 .04432 L
.80762 .04513 L
.80857 .04596 L
.80952 .04679 L
.81048 .04764 L
.81143 .04849 L
.81238 .04936 L
.81333 .05023 L
.81429 .05112 L
.81524 .05201 L
.81619 .05292 L
.81714 .05384 L
.8181 .05476 L
.81905 .0557 L
.82 .05665 L
.82095 .0576 L
.8219 .05857 L
.82286 .05954 L
.82381 .06053 L
.82476 .06153 L
.82571 .06253 L
.82667 .06355 L
.82762 .06457 L
.82857 .06561 L
.82952 .06665 L
.83048 .0677 L
.83143 .06877 L
.83238 .06984 L
Mistroke
.83333 .07092 L
.83429 .07201 L
.83524 .07311 L
.83619 .07422 L
.83714 .07534 L
.8381 .07647 L
.83905 .07761 L
.84 .07876 L
.84095 .07991 L
.8419 .08108 L
.84286 .08225 L
.84381 .08344 L
.84476 .08463 L
.84571 .08583 L
.84667 .08704 L
.84762 .08826 L
.84857 .08949 L
.84952 .09072 L
.85048 .09197 L
.85143 .09322 L
.85238 .09448 L
.85333 .09575 L
.85429 .09703 L
.85524 .09832 L
.85619 .09961 L
.85714 .10091 L
.8581 .10223 L
.85905 .10355 L
.86 .10487 L
.86095 .10621 L
.8619 .10755 L
.86286 .10891 L
.86381 .11027 L
.86476 .11163 L
.86571 .11301 L
.86667 .11439 L
.86762 .11578 L
.86857 .11718 L
.86952 .11859 L
.87048 .12 L
.87143 .12142 L
.87238 .12285 L
.87333 .12429 L
.87429 .12573 L
.87524 .12718 L
.87619 .12864 L
.87714 .1301 L
.8781 .13157 L
.87905 .13305 L
.88 .13454 L
Mistroke
.88095 .13603 L
.8819 .13753 L
.88286 .13904 L
.88381 .14055 L
.88476 .14207 L
.88571 .14359 L
.88667 .14513 L
.88762 .14667 L
.88857 .14821 L
.88952 .14976 L
.89048 .15132 L
.89143 .15289 L
.89238 .15446 L
.89333 .15603 L
.89429 .15762 L
.89524 .15921 L
.89619 .1608 L
.89714 .1624 L
.8981 .16401 L
.89905 .16562 L
.9 .16724 L
.90095 .16886 L
.9019 .17049 L
.90286 .17212 L
.90381 .17376 L
.90476 .17541 L
.90571 .17706 L
.90667 .17871 L
.90762 .18037 L
.90857 .18204 L
.90952 .18371 L
.91048 .18538 L
.91143 .18707 L
.91238 .18875 L
.91333 .19044 L
.91429 .19214 L
.91524 .19383 L
.91619 .19554 L
.91714 .19725 L
.9181 .19896 L
.91905 .20068 L
.92 .2024 L
.92095 .20412 L
.9219 .20585 L
.92286 .20759 L
.92381 .20933 L
.92476 .21107 L
.92571 .21281 L
.92667 .21456 L
.92762 .21632 L
Mistroke
.92857 .21807 L
.92952 .21983 L
.93048 .2216 L
.93143 .22336 L
.93238 .22514 L
.93333 .22691 L
.93429 .22869 L
.93524 .23047 L
.93619 .23225 L
.93714 .23404 L
.9381 .23583 L
.93905 .23762 L
.94 .23941 L
.94095 .24121 L
.9419 .24301 L
.94286 .24482 L
.94381 .24662 L
.94476 .24843 L
.94571 .25024 L
.94667 .25206 L
.94762 .25387 L
.94857 .25569 L
.94952 .25751 L
.95048 .25933 L
.95143 .26115 L
.95238 .26298 L
.95333 .26481 L
.95429 .26663 L
.95524 .26847 L
.95619 .2703 L
.95714 .27213 L
.9581 .27397 L
.95905 .2758 L
.96 .27764 L
.96095 .27948 L
.9619 .28132 L
.96286 .28316 L
.96381 .285 L
.96476 .28685 L
.96571 .28869 L
.96667 .29054 L
.96762 .29238 L
.96857 .29423 L
.96952 .29608 L
.97048 .29792 L
.97143 .29977 L
.97238 .30162 L
.97333 .30347 L
.97429 .30532 L
.97524 .30717 L
Mistroke
.97619 .30902 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0228571 0.000952381 0.309017 0.294302 [
[.21333 .29652 -9 -9 ]
[.21333 .29652 9 0 ]
[.40381 .29652 -9 -9 ]
[.40381 .29652 9 0 ]
[.59429 .29652 -9 -9 ]
[.59429 .29652 9 0 ]
[.78476 .29652 -9 -9 ]
[.78476 .29652 9 0 ]
[.97524 .29652 -12 -9 ]
[.97524 .29652 12 0 ]
[1.025 .30902 0 -6.28125 ]
[1.025 .30902 28 6.28125 ]
[.01036 .01472 -12 -4.5 ]
[.01036 .01472 0 4.5 ]
[.01036 .16187 -24 -4.5 ]
[.01036 .16187 0 4.5 ]
[.01036 .45617 -18 -4.5 ]
[.01036 .45617 0 4.5 ]
[.01036 .60332 -6 -4.5 ]
[.01036 .60332 0 4.5 ]
[.02286 .64303 -14 0 ]
[.02286 .64303 14 12.5625 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21333 .30902 m
.21333 .31527 L
s
[(200)] .21333 .29652 0 1 Mshowa
.40381 .30902 m
.40381 .31527 L
s
[(400)] .40381 .29652 0 1 Mshowa
.59429 .30902 m
.59429 .31527 L
s
[(600)] .59429 .29652 0 1 Mshowa
.78476 .30902 m
.78476 .31527 L
s
[(800)] .78476 .29652 0 1 Mshowa
.97524 .30902 m
.97524 .31527 L
s
[(1000)] .97524 .29652 0 1 Mshowa
.125 Mabswid
.07048 .30902 m
.07048 .31277 L
s
.1181 .30902 m
.1181 .31277 L
s
.16571 .30902 m
.16571 .31277 L
s
.26095 .30902 m
.26095 .31277 L
s
.30857 .30902 m
.30857 .31277 L
s
.35619 .30902 m
.35619 .31277 L
s
.45143 .30902 m
.45143 .31277 L
s
.49905 .30902 m
.49905 .31277 L
s
.54667 .30902 m
.54667 .31277 L
s
.6419 .30902 m
.6419 .31277 L
s
.68952 .30902 m
.68952 .31277 L
s
.73714 .30902 m
.73714 .31277 L
s
.83238 .30902 m
.83238 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92762 .30902 m
.92762 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(time) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.02286 .01472 m
.02911 .01472 L
s
[(-1)] .01036 .01472 1 0 Mshowa
.02286 .16187 m
.02911 .16187 L
s
[(-0.5)] .01036 .16187 1 0 Mshowa
.02286 .45617 m
.02911 .45617 L
s
[(0.5)] .01036 .45617 1 0 Mshowa
.02286 .60332 m
.02911 .60332 L
s
[(1)] .01036 .60332 1 0 Mshowa
.125 Mabswid
.02286 .04415 m
.02661 .04415 L
s
.02286 .07358 m
.02661 .07358 L
s
.02286 .10301 m
.02661 .10301 L
s
.02286 .13244 m
.02661 .13244 L
s
.02286 .1913 m
.02661 .1913 L
s
.02286 .22073 m
.02661 .22073 L
s
.02286 .25016 m
.02661 .25016 L
s
.02286 .27959 m
.02661 .27959 L
s
.02286 .33845 m
.02661 .33845 L
s
.02286 .36788 m
.02661 .36788 L
s
.02286 .39731 m
.02661 .39731 L
s
.02286 .42674 m
.02661 .42674 L
s
.02286 .4856 m
.02661 .4856 L
s
.02286 .51503 m
.02661 .51503 L
s
.02286 .54446 m
.02661 .54446 L
s
.02286 .57389 m
.02661 .57389 L
s
.25 Mabswid
.02286 0 m
.02286 .61803 L
s
gsave
.02286 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Amp) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
87.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 12.812500 moveto
(H) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 12.812500 moveto
(L) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
1 0 .25 r
.5 Mabswid
.02381 .30902 m
.02476 .31456 L
.02571 .32011 L
.02667 .32565 L
.02762 .33119 L
.02857 .33671 L
.02952 .34223 L
.03048 .34774 L
.03143 .35323 L
.03238 .3587 L
.03333 .36416 L
.03429 .3696 L
.03524 .37502 L
.03619 .38041 L
.03714 .38578 L
.0381 .39112 L
.03905 .39644 L
.04 .40172 L
.04095 .40697 L
.0419 .41218 L
.04286 .41736 L
.04381 .4225 L
.04476 .42759 L
.04571 .43265 L
.04667 .43766 L
.04762 .44263 L
.04857 .44755 L
.04952 .45242 L
.05048 .45723 L
.05143 .462 L
.05238 .46671 L
.05333 .47137 L
.05429 .47597 L
.05524 .4805 L
.05619 .48498 L
.05714 .4894 L
.0581 .49375 L
.05905 .49803 L
.06 .50225 L
.06095 .5064 L
.0619 .51048 L
.06286 .51449 L
.06381 .51842 L
.06476 .52228 L
.06571 .52607 L
.06667 .52978 L
.06762 .53341 L
.06857 .53695 L
.06952 .54042 L
.07048 .54381 L
Mistroke
.07143 .54711 L
.07238 .55033 L
.07333 .55346 L
.07429 .55651 L
.07524 .55947 L
.07619 .56234 L
.07714 .56511 L
.0781 .5678 L
.07905 .5704 L
.08 .5729 L
.08095 .57531 L
.0819 .57762 L
.08286 .57984 L
.08381 .58197 L
.08476 .58399 L
.08571 .58592 L
.08667 .58775 L
.08762 .58948 L
.08857 .59111 L
.08952 .59264 L
.09048 .59407 L
.09143 .5954 L
.09238 .59663 L
.09333 .59775 L
.09429 .59878 L
.09524 .5997 L
.09619 .60051 L
.09714 .60122 L
.0981 .60183 L
.09905 .60234 L
.1 .60274 L
.10095 .60303 L
.1019 .60323 L
.10286 .60331 L
.10381 .6033 L
.10476 .60317 L
.10571 .60295 L
.10667 .60262 L
.10762 .60218 L
.10857 .60164 L
.10952 .601 L
.11048 .60025 L
.11143 .5994 L
.11238 .59845 L
.11333 .59739 L
.11429 .59623 L
.11524 .59497 L
.11619 .59361 L
.11714 .59214 L
.1181 .59058 L
Mistroke
.11905 .58891 L
.12 .58715 L
.12095 .58529 L
.1219 .58333 L
.12286 .58127 L
.12381 .57911 L
.12476 .57686 L
.12571 .57452 L
.12667 .57208 L
.12762 .56954 L
.12857 .56692 L
.12952 .5642 L
.13048 .56139 L
.13143 .55849 L
.13238 .5555 L
.13333 .55243 L
.13429 .54927 L
.13524 .54602 L
.13619 .54269 L
.13714 .53928 L
.1381 .53578 L
.13905 .5322 L
.14 .52855 L
.14095 .52482 L
.1419 .52101 L
.14286 .51712 L
.14381 .51316 L
.14476 .50913 L
.14571 .50503 L
.14667 .50085 L
.14762 .49661 L
.14857 .4923 L
.14952 .48793 L
.15048 .4835 L
.15143 .479 L
.15238 .47444 L
.15333 .46982 L
.15429 .46515 L
.15524 .46042 L
.15619 .45563 L
.15714 .4508 L
.1581 .44591 L
.15905 .44098 L
.16 .436 L
.16095 .43097 L
.1619 .4259 L
.16286 .42079 L
.16381 .41564 L
.16476 .41045 L
.16571 .40522 L
Mistroke
.16667 .39996 L
.16762 .39467 L
.16857 .38935 L
.16952 .384 L
.17048 .37862 L
.17143 .37322 L
.17238 .36779 L
.17333 .36235 L
.17429 .35688 L
.17524 .3514 L
.17619 .3459 L
.17714 .34039 L
.1781 .33487 L
.17905 .32934 L
.18 .3238 L
.18095 .31826 L
.1819 .31272 L
.18286 .30717 L
.18381 .30162 L
.18476 .29608 L
.18571 .29054 L
.18667 .285 L
.18762 .27948 L
.18857 .27397 L
.18952 .26847 L
.19048 .26298 L
.19143 .25751 L
.19238 .25206 L
.19333 .24662 L
.19429 .24121 L
.19524 .23583 L
.19619 .23047 L
.19714 .22514 L
.1981 .21983 L
.19905 .21456 L
.2 .20933 L
.20095 .20412 L
.2019 .19896 L
.20286 .19383 L
.20381 .18875 L
.20476 .18371 L
.20571 .17871 L
.20667 .17376 L
.20762 .16886 L
.20857 .16401 L
.20952 .15921 L
.21048 .15446 L
.21143 .14976 L
.21238 .14513 L
.21333 .14055 L
Mistroke
.21429 .13603 L
.21524 .13157 L
.21619 .12718 L
.21714 .12285 L
.2181 .11859 L
.21905 .11439 L
.22 .11027 L
.22095 .10621 L
.2219 .10223 L
.22286 .09832 L
.22381 .09448 L
.22476 .09072 L
.22571 .08704 L
.22667 .08344 L
.22762 .07991 L
.22857 .07647 L
.22952 .07311 L
.23048 .06984 L
.23143 .06665 L
.23238 .06355 L
.23333 .06053 L
.23429 .0576 L
.23524 .05476 L
.23619 .05201 L
.23714 .04936 L
.2381 .04679 L
.23905 .04432 L
.24 .04194 L
.24095 .03966 L
.2419 .03747 L
.24286 .03538 L
.24381 .03339 L
.24476 .03149 L
.24571 .0297 L
.24667 .028 L
.24762 .0264 L
.24857 .0249 L
.24952 .02351 L
.25048 .02221 L
.25143 .02102 L
.25238 .01993 L
.25333 .01894 L
.25429 .01805 L
.25524 .01727 L
.25619 .0166 L
.25714 .01602 L
.2581 .01555 L
.25905 .01519 L
.26 .01492 L
.26095 .01477 L
Mistroke
.2619 .01472 L
.26286 .01477 L
.26381 .01492 L
.26476 .01519 L
.26571 .01555 L
.26667 .01602 L
.26762 .0166 L
.26857 .01727 L
.26952 .01805 L
.27048 .01894 L
.27143 .01993 L
.27238 .02102 L
.27333 .02221 L
.27429 .02351 L
.27524 .0249 L
.27619 .0264 L
.27714 .028 L
.2781 .0297 L
.27905 .03149 L
.28 .03339 L
.28095 .03538 L
.2819 .03747 L
.28286 .03966 L
.28381 .04194 L
.28476 .04432 L
.28571 .04679 L
.28667 .04936 L
.28762 .05201 L
.28857 .05476 L
.28952 .0576 L
.29048 .06053 L
.29143 .06355 L
.29238 .06665 L
.29333 .06984 L
.29429 .07311 L
.29524 .07647 L
.29619 .07991 L
.29714 .08344 L
.2981 .08704 L
.29905 .09072 L
.3 .09448 L
.30095 .09832 L
.3019 .10223 L
.30286 .10621 L
.30381 .11027 L
.30476 .11439 L
.30571 .11859 L
.30667 .12285 L
.30762 .12718 L
.30857 .13157 L
Mistroke
.30952 .13603 L
.31048 .14055 L
.31143 .14513 L
.31238 .14976 L
.31333 .15446 L
.31429 .15921 L
.31524 .16401 L
.31619 .16886 L
.31714 .17376 L
.3181 .17871 L
.31905 .18371 L
.32 .18875 L
.32095 .19383 L
.3219 .19896 L
.32286 .20412 L
.32381 .20933 L
.32476 .21456 L
.32571 .21983 L
.32667 .22514 L
.32762 .23047 L
.32857 .23583 L
.32952 .24121 L
.33048 .24662 L
.33143 .25206 L
.33238 .25751 L
.33333 .26298 L
.33429 .26847 L
.33524 .27397 L
.33619 .27948 L
.33714 .285 L
.3381 .29054 L
.33905 .29608 L
.34 .30162 L
.34095 .30717 L
.3419 .31272 L
.34286 .31826 L
.34381 .3238 L
.34476 .32934 L
.34571 .33487 L
.34667 .34039 L
.34762 .3459 L
.34857 .3514 L
.34952 .35688 L
.35048 .36235 L
.35143 .36779 L
.35238 .37322 L
.35333 .37862 L
.35429 .384 L
.35524 .38935 L
.35619 .39467 L
Mistroke
.35714 .39996 L
.3581 .40522 L
.35905 .41045 L
.36 .41564 L
.36095 .42079 L
.3619 .4259 L
.36286 .43097 L
.36381 .436 L
.36476 .44098 L
.36571 .44591 L
.36667 .4508 L
.36762 .45563 L
.36857 .46042 L
.36952 .46515 L
.37048 .46982 L
.37143 .47444 L
.37238 .479 L
.37333 .4835 L
.37429 .48793 L
.37524 .4923 L
.37619 .49661 L
.37714 .50085 L
.3781 .50503 L
.37905 .50913 L
.38 .51316 L
.38095 .51712 L
.3819 .52101 L
.38286 .52482 L
.38381 .52855 L
.38476 .5322 L
.38571 .53578 L
.38667 .53928 L
.38762 .54269 L
.38857 .54602 L
.38952 .54927 L
.39048 .55243 L
.39143 .5555 L
.39238 .55849 L
.39333 .56139 L
.39429 .5642 L
.39524 .56692 L
.39619 .56954 L
.39714 .57208 L
.3981 .57452 L
.39905 .57686 L
.4 .57911 L
.40095 .58127 L
.4019 .58333 L
.40286 .58529 L
.40381 .58715 L
Mistroke
.40476 .58891 L
.40571 .59058 L
.40667 .59214 L
.40762 .59361 L
.40857 .59497 L
.40952 .59623 L
.41048 .59739 L
.41143 .59845 L
.41238 .5994 L
.41333 .60025 L
.41429 .601 L
.41524 .60164 L
.41619 .60218 L
.41714 .60262 L
.4181 .60295 L
.41905 .60317 L
.42 .6033 L
.42095 .60331 L
.4219 .60323 L
.42286 .60303 L
.42381 .60274 L
.42476 .60234 L
.42571 .60183 L
.42667 .60122 L
.42762 .60051 L
.42857 .5997 L
.42952 .59878 L
.43048 .59775 L
.43143 .59663 L
.43238 .5954 L
.43333 .59407 L
.43429 .59264 L
.43524 .59111 L
.43619 .58948 L
.43714 .58775 L
.4381 .58592 L
.43905 .58399 L
.44 .58197 L
.44095 .57984 L
.4419 .57762 L
.44286 .57531 L
.44381 .5729 L
.44476 .5704 L
.44571 .5678 L
.44667 .56511 L
.44762 .56234 L
.44857 .55947 L
.44952 .55651 L
.45048 .55346 L
.45143 .55033 L
Mistroke
.45238 .54711 L
.45333 .54381 L
.45429 .54042 L
.45524 .53695 L
.45619 .53341 L
.45714 .52978 L
.4581 .52607 L
.45905 .52228 L
.46 .51842 L
.46095 .51449 L
.4619 .51048 L
.46286 .5064 L
.46381 .50225 L
.46476 .49803 L
.46571 .49375 L
.46667 .4894 L
.46762 .48498 L
.46857 .4805 L
.46952 .47597 L
.47048 .47137 L
.47143 .46671 L
.47238 .462 L
.47333 .45723 L
.47429 .45242 L
.47524 .44755 L
.47619 .44263 L
.47714 .43766 L
.4781 .43265 L
.47905 .42759 L
.48 .4225 L
.48095 .41736 L
.4819 .41218 L
.48286 .40697 L
.48381 .40172 L
.48476 .39644 L
.48571 .39112 L
.48667 .38578 L
.48762 .38041 L
.48857 .37502 L
.48952 .3696 L
.49048 .36416 L
.49143 .3587 L
.49238 .35323 L
.49333 .34774 L
.49429 .34223 L
.49524 .33671 L
.49619 .33119 L
.49714 .32565 L
.4981 .32011 L
.49905 .31456 L
Mistroke
.5 .30902 L
.50095 .30347 L
.5019 .29792 L
.50286 .29238 L
.50381 .28685 L
.50476 .28132 L
.50571 .2758 L
.50667 .2703 L
.50762 .26481 L
.50857 .25933 L
.50952 .25387 L
.51048 .24843 L
.51143 .24301 L
.51238 .23762 L
.51333 .23225 L
.51429 .22691 L
.51524 .2216 L
.51619 .21632 L
.51714 .21107 L
.5181 .20585 L
.51905 .20068 L
.52 .19554 L
.52095 .19044 L
.5219 .18538 L
.52286 .18037 L
.52381 .17541 L
.52476 .17049 L
.52571 .16562 L
.52667 .1608 L
.52762 .15603 L
.52857 .15132 L
.52952 .14667 L
.53048 .14207 L
.53143 .13753 L
.53238 .13305 L
.53333 .12864 L
.53429 .12429 L
.53524 .12 L
.53619 .11578 L
.53714 .11163 L
.5381 .10755 L
.53905 .10355 L
.54 .09961 L
.54095 .09575 L
.5419 .09197 L
.54286 .08826 L
.54381 .08463 L
.54476 .08108 L
.54571 .07761 L
.54667 .07422 L
Mistroke
.54762 .07092 L
.54857 .0677 L
.54952 .06457 L
.55048 .06153 L
.55143 .05857 L
.55238 .0557 L
.55333 .05292 L
.55429 .05023 L
.55524 .04764 L
.55619 .04513 L
.55714 .04272 L
.5581 .04041 L
.55905 .03819 L
.56 .03607 L
.56095 .03404 L
.5619 .03211 L
.56286 .03028 L
.56381 .02855 L
.56476 .02692 L
.56571 .02539 L
.56667 .02396 L
.56762 .02263 L
.56857 .02141 L
.56952 .02028 L
.57048 .01926 L
.57143 .01834 L
.57238 .01752 L
.57333 .01681 L
.57429 .0162 L
.57524 .0157 L
.57619 .0153 L
.57714 .015 L
.5781 .01481 L
.57905 .01472 L
.58 .01474 L
.58095 .01486 L
.5819 .01509 L
.58286 .01542 L
.58381 .01585 L
.58476 .01639 L
.58571 .01704 L
.58667 .01778 L
.58762 .01863 L
.58857 .01959 L
.58952 .02064 L
.59048 .0218 L
.59143 .02306 L
.59238 .02443 L
.59333 .02589 L
.59429 .02745 L
Mistroke
.59524 .02912 L
.59619 .03088 L
.59714 .03275 L
.5981 .03471 L
.59905 .03677 L
.6 .03892 L
.60095 .04117 L
.6019 .04352 L
.60286 .04596 L
.60381 .04849 L
.60476 .05112 L
.60571 .05384 L
.60667 .05665 L
.60762 .05954 L
.60857 .06253 L
.60952 .06561 L
.61048 .06877 L
.61143 .07201 L
.61238 .07534 L
.61333 .07876 L
.61429 .08225 L
.61524 .08583 L
.61619 .08949 L
.61714 .09322 L
.6181 .09703 L
.61905 .10091 L
.62 .10487 L
.62095 .10891 L
.6219 .11301 L
.62286 .11718 L
.62381 .12142 L
.62476 .12573 L
.62571 .1301 L
.62667 .13454 L
.62762 .13904 L
.62857 .14359 L
.62952 .14821 L
.63048 .15289 L
.63143 .15762 L
.63238 .1624 L
.63333 .16724 L
.63429 .17212 L
.63524 .17706 L
.63619 .18204 L
.63714 .18707 L
.6381 .19214 L
.63905 .19725 L
.64 .2024 L
.64095 .20759 L
.6419 .21281 L
Mistroke
.64286 .21807 L
.64381 .22336 L
.64476 .22869 L
.64571 .23404 L
.64667 .23941 L
.64762 .24482 L
.64857 .25024 L
.64952 .25569 L
.65048 .26115 L
.65143 .26663 L
.65238 .27213 L
.65333 .27764 L
.65429 .28316 L
.65524 .28869 L
.65619 .29423 L
.65714 .29977 L
.6581 .30532 L
.65905 .31087 L
.66 .31641 L
.66095 .32196 L
.6619 .3275 L
.66286 .33303 L
.66381 .33855 L
.66476 .34407 L
.66571 .34957 L
.66667 .35506 L
.66762 .36053 L
.66857 .36598 L
.66952 .37141 L
.67048 .37682 L
.67143 .38221 L
.67238 .38757 L
.67333 .3929 L
.67429 .3982 L
.67524 .40347 L
.67619 .40871 L
.67714 .41391 L
.6781 .41907 L
.67905 .4242 L
.68 .42928 L
.68095 .43432 L
.6819 .43932 L
.68286 .44427 L
.68381 .44917 L
.68476 .45403 L
.68571 .45883 L
.68667 .46358 L
.68762 .46827 L
.68857 .47291 L
.68952 .47748 L
Mistroke
.69048 .482 L
.69143 .48646 L
.69238 .49085 L
.69333 .49518 L
.69429 .49945 L
.69524 .50364 L
.69619 .50777 L
.69714 .51182 L
.6981 .51581 L
.69905 .51972 L
.7 .52355 L
.70095 .52731 L
.7019 .53099 L
.70286 .5346 L
.70381 .53812 L
.70476 .54156 L
.70571 .54492 L
.70667 .54819 L
.70762 .55138 L
.70857 .55449 L
.70952 .5575 L
.71048 .56043 L
.71143 .56327 L
.71238 .56602 L
.71333 .56868 L
.71429 .57124 L
.71524 .57371 L
.71619 .57609 L
.71714 .57837 L
.7181 .58056 L
.71905 .58265 L
.72 .58465 L
.72095 .58654 L
.7219 .58834 L
.72286 .59004 L
.72381 .59163 L
.72476 .59313 L
.72571 .59453 L
.72667 .59582 L
.72762 .59702 L
.72857 .59811 L
.72952 .59909 L
.73048 .59998 L
.73143 .60076 L
.73238 .60144 L
.73333 .60201 L
.73429 .60248 L
.73524 .60285 L
.73619 .60311 L
.73714 .60327 L
Mistroke
.7381 .60332 L
.73905 .60327 L
.74 .60311 L
.74095 .60285 L
.7419 .60248 L
.74286 .60201 L
.74381 .60144 L
.74476 .60076 L
.74571 .59998 L
.74667 .59909 L
.74762 .59811 L
.74857 .59702 L
.74952 .59582 L
.75048 .59453 L
.75143 .59313 L
.75238 .59163 L
.75333 .59004 L
.75429 .58834 L
.75524 .58654 L
.75619 .58465 L
.75714 .58265 L
.7581 .58056 L
.75905 .57837 L
.76 .57609 L
.76095 .57371 L
.7619 .57124 L
.76286 .56868 L
.76381 .56602 L
.76476 .56327 L
.76571 .56043 L
.76667 .5575 L
.76762 .55449 L
.76857 .55138 L
.76952 .54819 L
.77048 .54492 L
.77143 .54156 L
.77238 .53812 L
.77333 .5346 L
.77429 .53099 L
.77524 .52731 L
.77619 .52355 L
.77714 .51972 L
.7781 .51581 L
.77905 .51182 L
.78 .50777 L
.78095 .50364 L
.7819 .49945 L
.78286 .49518 L
.78381 .49085 L
.78476 .48646 L
Mistroke
.78571 .482 L
.78667 .47748 L
.78762 .47291 L
.78857 .46827 L
.78952 .46358 L
.79048 .45883 L
.79143 .45403 L
.79238 .44917 L
.79333 .44427 L
.79429 .43932 L
.79524 .43432 L
.79619 .42928 L
.79714 .4242 L
.7981 .41907 L
.79905 .41391 L
.8 .40871 L
.80095 .40347 L
.8019 .3982 L
.80286 .3929 L
.80381 .38757 L
.80476 .38221 L
.80571 .37682 L
.80667 .37141 L
.80762 .36598 L
.80857 .36053 L
.80952 .35506 L
.81048 .34957 L
.81143 .34407 L
.81238 .33855 L
.81333 .33303 L
.81429 .3275 L
.81524 .32196 L
.81619 .31641 L
.81714 .31087 L
.8181 .30532 L
.81905 .29977 L
.82 .29423 L
.82095 .28869 L
.8219 .28316 L
.82286 .27764 L
.82381 .27213 L
.82476 .26663 L
.82571 .26115 L
.82667 .25569 L
.82762 .25024 L
.82857 .24482 L
.82952 .23941 L
.83048 .23404 L
.83143 .22869 L
.83238 .22336 L
Mistroke
.83333 .21807 L
.83429 .21281 L
.83524 .20759 L
.83619 .2024 L
.83714 .19725 L
.8381 .19214 L
.83905 .18707 L
.84 .18204 L
.84095 .17706 L
.8419 .17212 L
.84286 .16724 L
.84381 .1624 L
.84476 .15762 L
.84571 .15289 L
.84667 .14821 L
.84762 .14359 L
.84857 .13904 L
.84952 .13454 L
.85048 .1301 L
.85143 .12573 L
.85238 .12142 L
.85333 .11718 L
.85429 .11301 L
.85524 .10891 L
.85619 .10487 L
.85714 .10091 L
.8581 .09703 L
.85905 .09322 L
.86 .08949 L
.86095 .08583 L
.8619 .08225 L
.86286 .07876 L
.86381 .07534 L
.86476 .07201 L
.86571 .06877 L
.86667 .06561 L
.86762 .06253 L
.86857 .05954 L
.86952 .05665 L
.87048 .05384 L
.87143 .05112 L
.87238 .04849 L
.87333 .04596 L
.87429 .04352 L
.87524 .04117 L
.87619 .03892 L
.87714 .03677 L
.8781 .03471 L
.87905 .03275 L
.88 .03088 L
Mistroke
.88095 .02912 L
.8819 .02745 L
.88286 .02589 L
.88381 .02443 L
.88476 .02306 L
.88571 .0218 L
.88667 .02064 L
.88762 .01959 L
.88857 .01863 L
.88952 .01778 L
.89048 .01704 L
.89143 .01639 L
.89238 .01585 L
.89333 .01542 L
.89429 .01509 L
.89524 .01486 L
.89619 .01474 L
.89714 .01472 L
.8981 .01481 L
.89905 .015 L
.9 .0153 L
.90095 .0157 L
.9019 .0162 L
.90286 .01681 L
.90381 .01752 L
.90476 .01834 L
.90571 .01926 L
.90667 .02028 L
.90762 .02141 L
.90857 .02263 L
.90952 .02396 L
.91048 .02539 L
.91143 .02692 L
.91238 .02855 L
.91333 .03028 L
.91429 .03211 L
.91524 .03404 L
.91619 .03607 L
.91714 .03819 L
.9181 .04041 L
.91905 .04272 L
.92 .04513 L
.92095 .04764 L
.9219 .05023 L
.92286 .05292 L
.92381 .0557 L
.92476 .05857 L
.92571 .06153 L
.92667 .06457 L
.92762 .0677 L
Mistroke
.92857 .07092 L
.92952 .07422 L
.93048 .07761 L
.93143 .08108 L
.93238 .08463 L
.93333 .08826 L
.93429 .09197 L
.93524 .09575 L
.93619 .09961 L
.93714 .10355 L
.9381 .10755 L
.93905 .11163 L
.94 .11578 L
.94095 .12 L
.9419 .12429 L
.94286 .12864 L
.94381 .13305 L
.94476 .13753 L
.94571 .14207 L
.94667 .14667 L
.94762 .15132 L
.94857 .15603 L
.94952 .1608 L
.95048 .16562 L
.95143 .17049 L
.95238 .17541 L
.95333 .18037 L
.95429 .18538 L
.95524 .19044 L
.95619 .19554 L
.95714 .20068 L
.9581 .20585 L
.95905 .21107 L
.96 .21632 L
.96095 .2216 L
.9619 .22691 L
.96286 .23225 L
.96381 .23762 L
.96476 .24301 L
.96571 .24843 L
.96667 .25387 L
.96762 .25933 L
.96857 .26481 L
.96952 .2703 L
.97048 .2758 L
.97143 .28132 L
.97238 .28685 L
.97333 .29238 L
.97429 .29792 L
.97524 .30347 L
Mistroke
.97619 .30902 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[30]:=",
  ImageSize->{400, 250},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000nR000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00;`3oool3@00000<0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`0=0?oo
o`=000000P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00/0oooo0T0000040?oo
o`03@000003oool0oooo0080oooo00=000000?ooo`3oool0303oool00d000000oooo0?ooo`020?oo
o`03@000003oool0oooo0080oooo00=000000?ooo`3oool0203oool5@0000080oooo00=000000?oo
o`3oool00P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0>/0oooo000_0?ooo`03
@000003oool0oooo0080oooo00=000000?oood0000000P3oool00d000000oooo@000000?0?ooo`06
@000003oool0oooo@000003ooom000000P3oool00d000000oooo@000000<0?ooo`03@000003ooom0
00000080oooo00=000000?oood0000000P3oool00d000000oooo@000000<0?ooo`03@000003ooom0
00000080oooo00=000000?oood0000000P3oool00d000000oooo@000000;0?ooo`07@000003oool0
oooo0?oood000000oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oood000000
k03oool00300oooo00M000000?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood00
00003@3oool4@00000040?oood000000oooo@0000080oooo00=000000?oood000000303oool00d00
0000oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oood000000303oool00d00
0000oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oood0000002`3oool01d00
0000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003o
oom000000>`0oooo000`0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000
003ooom0000000d0oooo00=000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000
003ooom0000000`0oooo0T0000030?ooo`03@000003ooom000000080oooo00=000000?oood000000
3@3oool01d000000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@000000;0?oo
o`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000003ooom000000080oooo00=0
00000?oood000000k03oool002l0oooo00=000000?oood0000000P3oool00d000000oooo@0000002
0?ooo`03@000003ooom0000000h0oooo0T0000020?ooo`03@000003ooom000000080oooo00=00000
0?oood000000303oool00d000000oooo0?ooo`020?ooo`03@000003ooom000000080oooo00=00000
0?oood000000303oool00d000000oooo@00000020?ooo`03@000003ooom000000080oooo00=00000
0?oood0000002`3oool01d000000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo
@00000020?ooo`03@000003ooom000000>`0oooo000`0?ooo`03@000003oool0oooo0080oooo00=0
00000?ooo`3oool00P3oool00d000000oooo0?ooo`0>0?ooo`05@000003oool0oooo0?oood000000
103oool00d000000oooo0?ooo`0<0?ooo`9000000`3oool00d000000oooo0?ooo`020?ooo`03@000
003oool0oooo00`0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03@000
003oool0oooo00T0oooo0T0000040?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool0
0P3oool00d000000oooo0?ooo`3[0?ooo`00o`3ooonA0?ooo`00h`3oool5@0000080oooo00<00000
0?ooo`3oool0X`3oool001d0oooo00<000000?ooo`3oool0QP3oool2@0000080oooo0d0000001P3o
oom000000?oood000000oooo@0000080oooo0T00000^0?ooo`03@000003oool0oooo0080oooo00<0
00000?ooo`3oool0X`3oool001d0oooo00<000000?ooo`3oool0Q@3oool014000000oooo0?oood00
00020?ooo`0:@000003oool0oooo@000003ooom000000?oood000000oooo@00002X0oooo0d000003
0?ooo`03@000003oool0oooo0080oooo00<000000?ooo`3oool0=@3oool90?l0_fD0oooo000J0?oo
o`<0000000<0002o000000000000?00000000`000;l000000000000l000000050000_`0000000000
0000040000001@3oool00d000000oooo0?ooo`030?ooo`09@000003oool0oooo@000003ooom00000
0?oood000000oooo00=00000;P3oool00d000000oooo0?ooo`020?ooo`030000003oool0oooo03<0
oooo0`3o0;l80?ooo`80o`2oH`3oool001d0oooo00<0002o0?ooo`3oool05P3oool00d000000oooo
0?ooo`0F0?ooo`03@000003oool0oooo00X0oooo00<0002o0?ooo`3oool02P3oool00d000000oooo
0?ooo`0F0?ooo`03@000003oool0oooo01H0oooo00<0002o0?ooo`3oool01P3oool4@0000080oooo
0T0000020?ooo`90000000@0oooo@000003oool0oooo0d00000^0?ooo`03@000003oool0oooo0080
oooo00<000000?ooo`3oool0<P3oool20?l0_``0oooo0P3o0;mQ0?ooo`007@3oool00`000;l0oooo
0?ooo`0k0?ooo`<0002o?@3oool00`000;l0oooo0?ooo`070?ooo`03@000003oool0oooo03`0oooo
0T0000040?ooo`030000003oool0oooo0300oooo0P3o0;l?0?ooo`80o`2oH03oool001d0oooo00<0
00000000_`3oool0>`3oool00`000;l0oooo0000_`0m0?ooo`030000_`3oool0oooo00d0oooo00=0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0_0?ooo`80o`2o4@3oool20?l0_el0oooo000M
0?ooo`03000000000;l0oooo03/0oooo00<0002o0?ooo`000;l0?03oool00`000;l0oooo0?ooo`1=
0?ooo`030000003oool0oooo02h0oooo0P3o0;lC0?ooo`80o`2oGP3oool001d0oooo00<000000000
_`3oool0>`3oool010000;l0oooo0000_`000;lk0?ooo`030000_`3oool0oooo04d0oooo00<00000
0?ooo`3oool0;@3oool20?l0_aD0oooo0P3o0;mM0?ooo`007@3oool00`000000002o0?ooo`0j0?oo
o`80002o0P3oool00`000;l0oooo0?ooo`0i0?ooo`030000_`3oool0oooo04d0oooo00<000000?oo
o`3oool0;@3oool00`3o0;l0oooo0?ooo`0E0?ooo`80o`2oG03oool001d0oooo00<000000?ooo`00
0;l0>P3oool01@000;l0oooo0?ooo`3oool0002o03/0oooo00<0002o0?ooo`3oool0C@3oool00`00
0000oooo0?ooo`0/0?ooo`030?l0_`3oool0oooo01L0oooo0P3o0;mK0?ooo`007@3oool00`000000
oooo0000_`0j0?ooo`050000_`3oool0oooo0?ooo`000;l0>P3oool00`000;l0oooo0?ooo`1>0?oo
o`030000003oool0oooo02/0oooo0P3o0;lJ0?ooo`80o`2oFP3oool001d0oooo00<000000?ooo`00
0;l0>P3oool010000;l0oooo0?ooo`3oool20000_cT0oooo00<0002o0?ooo`3oool0CP3oool00`00
0000oooo0?ooo`0Z0?ooo`80o`2o703oool00`3o0;l0oooo0?ooo`1H0?ooo`007@3oool00`000000
oooo0000_`0i0?ooo`80002o103oool00`000;l0oooo0?ooo`0g0?ooo`030000_`3oool0oooo04h0
oooo00<000000?ooo`3oool0:@3oool20?l0_ad0oooo0P3o0;mI0?ooo`007@3oool010000000oooo
0?ooo`000;lh0?ooo`030000_`3oool0oooo00<0oooo00<0002o0?ooo`3oool0=`3oool00`000;l0
oooo0?ooo`1>0?ooo`030000003oool0oooo02T0oooo00<0o`2o0?ooo`3oool07@3oool20?l0_eP0
oooo000M0?ooo`040000003oool0oooo0000_cP0oooo00<0002o0?ooo`3oool00`3oool00`000;l0
oooo0?ooo`0f0?ooo`030000_`3oool0oooo04l0oooo00<000000?ooo`3oool0:03oool20?l0_b00
oooo00<0o`2o0?ooo`3oool0EP3oool000h0oooo00=000000?ooo`3oool00P3oool014000000oooo
0?ooo`3oool3@00000<0oooo00@000000?ooo`3oool0002o>03oool00`000;l0oooo0?ooo`030?oo
o`80002o=`3oool00`000;l0oooo0?ooo`1?0?ooo`030000003oool0oooo02L0oooo0P3o0;lQ0?oo
o`80o`2oE`3oool000d0oooo00=000000?oood0000001`3oool00d000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080002o=P3oool00`000;l0oooo0?ooo`050?ooo`030000_`3oool0oooo03D0
oooo00<0002o0?ooo`3oool0C`3oool00`000000oooo0?ooo`0W0?ooo`030?l0_`3oool0oooo0240
oooo0P3o0;mF0?ooo`003@3oool00d000000oooo@00000080?ooo`03@000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo0000_`0f0?ooo`030000_`3oool0oooo00D0oooo00<0002o0?ooo`3o
ool0=03oool20000_d80oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03
@000003oool0oooo0080oooo00<000000?ooo`3oool09P3oool20?l0_b@0oooo00<0o`2o0?ooo`3o
ool0E03oool000d0oooo00=000000?oood000000203oool00d000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000;l0=P3oool00`000;l0oooo0?ooo`050?ooo`030000_`3oool0oooo03@0
oooo00<0002o0?ooo`3oool0@03oool00d000000oooo@00000070?ooo`03@000003ooom0000000<0
oooo00<000000?ooo`3oool09P3oool00`3o0;l0oooo0?ooo`0S0?ooo`80o`2oE@3oool000d0oooo
00=000000?oood0000001`3oool00d000000oooo@00000030?ooo`050000003oool0oooo0?ooo`00
0;l0=P3oool00`000;l0oooo0?ooo`060?ooo`030000_`3oool0oooo03<0oooo00<0002o0?ooo`3o
ool0>`3oool3@0000080oooo00=000000?oood0000002@3oool01D000000oooo0?ooo`3oool00000
02L0oooo00<0o`2o0?ooo`3oool09@3oool00`3o0;l0oooo0?ooo`1C0?ooo`003P3oool00d000000
oooo0?ooo`070?ooo`03@000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P000;ld0?oo
o`030000_`3oool0oooo00L0oooo00<0002o0?ooo`3oool0<`3oool00`000;l0oooo0?ooo`100?oo
o`03@000003ooom0000000L0oooo0T0000040?ooo`030000003oool0oooo02@0oooo0P3o0;lX0?oo
o`030?l0_`3oool0oooo0580oooo000M0?ooo`030000003oool0oooo0080oooo00<0002o0?ooo`3o
ool0<P3oool00`000;l0oooo0?ooo`070?ooo`030000_`3oool0oooo0380oooo0P000;m20?ooo`03
@000003ooom0000000L0oooo00=000000?ooo`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`03
0?l0_`3oool0oooo02L0oooo0P3o0;mC0?ooo`007@3oool00`000000oooo0?ooo`020?ooo`030000
_`3oool0oooo0380oooo00<0002o0?ooo`3oool01`3oool00`000;l0oooo0?ooo`0b0?ooo`030000
_`3oool0oooo0480oooo00=000000?ooo`3oool01P3oool3@00000<0oooo00<000000?ooo`3oool0
8`3oool20?l0_bX0oooo00<0o`2o0?ooo`3oool0D@3oool001d0oooo00<000000?ooo`3oool00P3o
ool00`000;l0oooo0?ooo`0b0?ooo`030000_`3oool0oooo00P0oooo00<0002o0?ooo`3oool0<@3o
ool00`000;l0oooo0?ooo`1A0?ooo`030000003oool0oooo02<0oooo00<0o`2o0?ooo`3oool0:@3o
ool20?l0_e80oooo000M0?ooo`030000003oool0oooo0080oooo0P000;lb0?ooo`030000_`3oool0
oooo00T0oooo00<0002o0?ooo`3oool0<@3oool00`000;l0oooo0?ooo`1A0?ooo`030000003oool0
oooo0280oooo0P3o0;l/0?ooo`030?l0_`3oool0oooo0500oooo000M0?ooo`030000003oool0oooo
00<0oooo00<0002o0?ooo`3oool0<03oool00`000;l0oooo0?ooo`090?ooo`030000_`3oool0oooo
0300oooo00<0002o0?ooo`3oool0DP3oool00`000000oooo0?ooo`0R0?ooo`030?l0_`3oool0oooo
02/0oooo0P3o0;mA0?ooo`007@3oool00`000000oooo0?ooo`030?ooo`030000_`3oool0oooo0300
oooo00<0002o0?ooo`3oool02@3oool20000_c40oooo00<0002o0?ooo`3oool0DP3oool00`000000
oooo0?ooo`0Q0?ooo`80o`2o;P3oool00`3o0;l0oooo0?ooo`1?0?ooo`007@3oool00`000000oooo
0?ooo`030?ooo`80002o<03oool20000_``0oooo00<0002o0?ooo`3oool0;`3oool00`000;l0oooo
0?ooo`1B0?ooo`030000003oool0oooo0240oooo00<0o`2o0?ooo`3oool0;P3oool00`3o0;l0oooo
0?ooo`1>0?ooo`007@3oool00`000000oooo0?ooo`040?ooo`030000_`3oool0oooo02h0oooo00<0
002o0?ooo`3oool02`3oool00`000;l0oooo0?ooo`0^0?ooo`80002oE03oool00`000000oooo0?oo
o`0>0?ooo`=000000`3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00@0oooo00<0
o`2o0?ooo`3oool01@3oool3@0000080oooo00=000000?ooo`3oool00P3oool00d000000oooo0?oo
o`0:0?ooo`900000103oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00D0oooo0P3o
0;l40?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool00d000000oooo0?oo
o`070?ooo`E000000P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00=0
00000?ooo`3oool08`3oool001d0oooo00<000000?ooo`3oool0103oool00`000;l0oooo0?ooo`0^
0?ooo`030000_`3oool0oooo00/0oooo00<0002o0?ooo`3oool0;P3oool00`000;l0oooo0?ooo`1C
0?ooo`030000003oool0oooo00h0oooo00=000000?ooo`3oool00P3oool00d000000oooo@0000002
0?ooo`03@000003ooom0000000@0oooo0P3o0;l80?ooo`06@000003oool0oooo@000003ooom00000
0P3oool00d000000oooo@000000;0?ooo`03@000003ooom000000080oooo00=000000?oood000000
0P3oool00d000000oooo@00000070?ooo`070?l0_`3oool0oooo0?oood000000oooo@00000020?oo
o`03@000003ooom000000080oooo00=000000?oood0000002P3oool01d000000oooo0?ooo`3ooom0
00000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom0000002@0oooo000M
0?ooo`030000003oool0oooo00@0oooo00<0002o0?ooo`3oool0;P3oool00`000;l0oooo0?ooo`0;
0?ooo`80002o;`3oool00`000;l0oooo0?ooo`1C0?ooo`030000003oool0oooo00l0oooo00M00000
0?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood000000103oool00`3o0;l0oooo
0?ooo`050?ooo`A0000000@0oooo@000003ooom000000P3oool00d000000oooo@000000;0?ooo`03
@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo@00000070?ooo`07
0?l0_`3oool0oooo0?oood000000oooo@00000020?ooo`03@000003ooom000000080oooo00=00000
0?oood0000002P3oool01d000000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo
@00000020?ooo`03@000003ooom0000002@0oooo000>0?ooo`03@000003oool0oooo0080oooo00=0
00000?ooo`3oool00P3oool3@0000080oooo00<000000?ooo`3oool0103oool20000_bh0oooo0P00
0;l>0?ooo`030000_`3oool0oooo02d0oooo00<0002o0?ooo`3oool0D`3oool00`000000oooo0?oo
o`0?0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000003ooom0000000<0
oooo0P3o0;l70?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000
oooo@000000;0?ooo`9000000`3oool00d000000oooo@00000020?ooo`03@000003ooom0000000P0
oooo00D0o`2o0?ooo`3oool0oooo@00000030?ooo`03@000003ooom000000080oooo00=000000?oo
od0000002P3oool01d000000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@000
00020?ooo`03@000003ooom0000002@0oooo000=0?ooo`03@000003ooom0000000T0oooo00E00000
0?ooo`3oool0oooo000000070?ooo`030000_`3oool0oooo02`0oooo00<0002o0?ooo`3oool03@3o
ool00`000;l0oooo0?ooo`0/0?ooo`80002oE@3oool00`000000oooo0?ooo`0>0?ooo`03@000003o
oom000000080oooo00=000000?oood0000000P3oool00d000000oooo@00000030?ooo`030?l0_`3o
ool0oooo00L0oooo0T0000020?ooo`03@000003ooom000000080oooo00=000000?oood0000002`3o
ool00d000000oooo0?ooo`020?ooo`03@000003ooom000000080oooo00=000000?oood000000203o
ool20?l0_`040?oood000000oooo@0000080oooo00=000000?oood0000000P3oool00d000000oooo
@000000:0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000003ooom00000
0080oooo00=000000?oood000000903oool000d0oooo00=000000?oood0000001`3oool4@0000080
oooo00<000000?ooo`3oool01@3oool00`000;l0oooo0?ooo`0/0?ooo`030000_`3oool0oooo00d0
oooo00<0002o0?ooo`3oool0;03oool00`000;l0oooo0?ooo`1D0?ooo`030000003oool0oooo00l0
oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo0?oo
o`80o`2o2P3oool01D000000oooo0?ooo`3ooom0000000@0oooo00=000000?ooo`3oool02`3oool2
@00000<0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`080?ooo`040?l0_`3oool0
oooo@00000@0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`080?ooo`900000103o
ool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool08`3o
ool000d0oooo00=000000?oood0000001`3oool00d000000oooo@00000030?ooo`030000003oool0
oooo00D0oooo00<0002o0?ooo`3oool0;03oool00`000;l0oooo0?ooo`0>0?ooo`030000_`3oool0
oooo02/0oooo00<0002o0?ooo`3oool0E03oool00`000000oooo0?ooo`0M0?ooo`030?l0_`3oool0
oooo03D0oooo0P3o0;m<0?ooo`003@3oool00d000000oooo@00000080?ooo`9000000`3oool00`00
0000oooo0?ooo`060?ooo`030000_`3oool0oooo02X0oooo00<0002o0?ooo`3oool03`3oool00`00
0;l0oooo0?ooo`0[0?ooo`030000_`3oool0oooo05@0oooo00<000000?ooo`3oool0703oool20?l0
_cP0oooo00<0o`2o0?ooo`3oool0BP3oool000h0oooo00=000000?ooo`3oool0203oool01D000000
oooo0?ooo`3oool0000000P0oooo00<0002o0?ooo`3oool0:P3oool00`000;l0oooo0?ooo`0?0?oo
o`030000_`3oool0oooo02X0oooo00<0002o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0L0?oo
o`030?l0_`3oool0oooo03L0oooo0P3o0;lX0?ooo`9000000P3oool3@00000060?oood000000oooo
@000003ooom000000P3oool2@0000180oooo000M0?ooo`030000003oool0oooo00H0oooo00<0002o
0?ooo`3oool0:P3oool00`000;l0oooo0?ooo`0?0?ooo`80002o:`3oool00`000;l0oooo0?ooo`1E
0?ooo`030000003oool0oooo01/0oooo0P3o0;lj0?ooo`030?l0_`3oool0oooo02D0oooo00A00000
0?ooo`3ooom000000P3oool02T000000oooo0?oood000000oooo@000003ooom000000?oood00000D
0?ooo`007@3oool00`000000oooo0?ooo`060?ooo`80002o:P3oool00`000;l0oooo0?ooo`0A0?oo
o`030000_`3oool0oooo02T0oooo00<0002o0?ooo`3oool0DP3ooolQ000000030?l0_`0000000000
03T000000P3o0;lP00000003@000003oool0oooo00<0oooo00=000000?ooo`3oool00`3oool02D00
0000oooo0?oood000000oooo@000003ooom000000?ooo`03@0000180oooo000M0?ooo`030000003o
ool0oooo00L0oooo00<0002o0?ooo`3oool0:03oool00`000;l0oooo0?ooo`0A0?ooo`030000_`3o
ool0oooo02P0oooo0P000;mG0?ooo`030000003oool0oooo01D0oooo00=000000?ooo`3oool00P3o
ool20?l0_a40oooo00=000000?ooo`3oool05@3oool00d000000oooo0?ooo`0@0?ooo`030?l0_`3o
ool0oooo0080oooo00=000000?ooo`3oool05P3oool00d000000oooo0?ooo`050?ooo`A000000P3o
ool2@0000080oooo0T000000103ooom000000?ooo`3oool3@0000180oooo000M0?ooo`030000003o
ool0oooo00L0oooo00<0002o0?ooo`3oool0:03oool00`000;l0oooo0?ooo`0A0?ooo`80002o:@3o
ool00`000;l0oooo0?ooo`1F0?ooo`030000003oool0oooo01X0oooo00<0o`2o0?ooo`3oool0>`3o
ool20?l0_bD0oooo00=000000?ooo`3oool08@3oool001d0oooo00<000000?ooo`3oool01`3oool0
0`000;l0oooo0?ooo`0W0?ooo`80002o503oool00`000;l0oooo0?ooo`0W0?ooo`030000_`3oool0
oooo05H0oooo00<000000?ooo`3oool06@3oool20?l0_ch0oooo00<0o`2o0?ooo`3oool0:@3oool0
0d000000oooo0?ooo`0K0?ooo`007@3oool00`000000oooo0?ooo`080?ooo`030000_`3oool0oooo
02H0oooo00<0002o0?ooo`3oool04`3oool00`000;l0oooo0?ooo`0V0?ooo`80002oF03oool00`00
0000oooo0?ooo`0I0?ooo`030?l0_`3oool0oooo03d0oooo0P3o0;m80?ooo`007@3oool00`000000
oooo0?ooo`080?ooo`030000_`3oool0oooo02H0oooo00<0002o0?ooo`3oool04`3oool00`000;l0
oooo0?ooo`0V0?ooo`030000_`3oool0oooo05L0oooo00<000000?ooo`3oool0603oool20?l0_d00
oooo00<0o`2o0?ooo`3oool0AP3oool001d0oooo00<000000?ooo`3oool0203oool00`000;l0oooo
0?ooo`0V0?ooo`030000_`3oool0oooo01@0oooo00<0002o0?ooo`3oool09@3oool00`000;l0oooo
0?ooo`1G0?ooo`030000003oool0oooo01P0oooo00<0o`2o0?ooo`3oool0?`3oool20?l0_dL0oooo
000M0?ooo`030000003oool0oooo00P0oooo0P000;lV0?ooo`030000_`3oool0oooo01D0oooo00<0
002o0?ooo`3oool09@3oool00`000;l0oooo0?ooo`1G0?ooo`030000003oool0oooo01L0oooo0P3o
0;m20?ooo`030?l0_`3oool0oooo04D0oooo000M0?ooo`030000003oool0oooo00T0oooo00<0002o
0?ooo`3oool0903oool00`000;l0oooo0?ooo`0E0?ooo`030000_`3oool0oooo02@0oooo00<0002o
0?ooo`3oool0F03oool00`000000oooo0?ooo`0G0?ooo`030?l0_`3oool0oooo0440oooo0P3o0;m6
0?ooo`003P3oool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo0?ooo`900000103oool0
0`000000oooo0?ooo`090?ooo`030000_`3oool0oooo02@0oooo00<0002o0?ooo`3oool05@3oool2
0000_bD0oooo00<0002o0?ooo`3oool0F03oool00`000000oooo0?ooo`0F0?ooo`030?l0_`3oool0
oooo04<0oooo00<0o`2o0?ooo`3oool0A03oool000d0oooo00=000000?oood0000001`3oool00d00
0000oooo@00000030?ooo`030000003oool0oooo00T0oooo0P000;lT0?ooo`030000_`3oool0oooo
01L0oooo00<0002o0?ooo`3oool08`3oool00`000;l0oooo0?ooo`1H0?ooo`030000003oool0oooo
01H0oooo00<0o`2o0?ooo`3oool0@`3oool20?l0_dD0oooo000=0?ooo`03@000003ooom0000000L0
oooo00=000000?oood0000000`3oool00`000000oooo0?ooo`0:0?ooo`030000_`3oool0oooo0280
oooo00<0002o0?ooo`3oool05`3oool00`000;l0oooo0?ooo`0R0?ooo`80002oFP3oool00`000000
oooo0?ooo`0E0?ooo`030?l0_`3oool0oooo04D0oooo00<0o`2o0?ooo`3oool0@`3oool000d0oooo
00=000000?oood0000001`3oool2@00000@0oooo00<000000?ooo`3oool02P3oool00`000;l0oooo
0?ooo`0R0?ooo`030000_`3oool0oooo01L0oooo0P000;lS0?ooo`030000_`3oool0oooo05T0oooo
00<000000?ooo`3oool0503oool20?l0_dP0oooo00<0o`2o0?ooo`3oool0@P3oool000d0oooo00=0
00000?oood0000001`3oool00d000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo0P00
0;lR0?ooo`80002o6P3oool00`000;l0oooo0?ooo`0Q0?ooo`030000_`3oool0oooo05T0oooo00<0
00000?ooo`3oool0503oool00`3o0;l0oooo0?ooo`170?ooo`030?l0_`3oool0oooo0480oooo000>
0?ooo`03@000003oool0oooo00L0oooo0T0000030?ooo`030000003oool0oooo00/0oooo00<0002o
0?ooo`3oool0803oool00`000;l0oooo0?ooo`0I0?ooo`030000_`3oool0oooo0200oooo0P000;mK
0?ooo`030000003oool0oooo01<0oooo0P3o0;m:0?ooo`030?l0_`3oool0oooo0440oooo000M0?oo
o`030000003oool0oooo00/0oooo00<0002o0?ooo`3oool0803oool00`000;l0oooo0?ooo`0I0?oo
o`80002o8@3oool00`000;l0oooo0?ooo`1J0?ooo`030000003oool0oooo01<0oooo00<0o`2o0?oo
o`3oool0B@3oool20?l0_d80oooo000M0?ooo`030000003oool0oooo00/0oooo0P000;lP0?ooo`80
002o703oool00`000;l0oooo0?ooo`0O0?ooo`030000_`3oool0oooo05X0oooo00<000000?ooo`3o
ool04P3oool20?l0_d`0oooo00<0o`2o0?ooo`3oool0@03oool001d0oooo00<000000?ooo`3oool0
303oool00`000;l0oooo0?ooo`0N0?ooo`030000_`3oool0oooo01/0oooo00<0002o0?ooo`3oool0
7P3oool20000_dd0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03@000
003oool0oooo0080oooo00<000000?ooo`3oool04P3oool00`3o0;l0oooo0?ooo`1;0?ooo`80o`2o
@@3oool001d0oooo00<000000?ooo`3oool0303oool00`000;l0oooo0?ooo`0N0?ooo`030000_`3o
ool0oooo01/0oooo0P000;lO0?ooo`030000_`3oool0oooo04/0oooo00=000000?oood0000001`3o
ool00d000000oooo@00000030?ooo`030000003oool0oooo0140oooo0P3o0;m>0?ooo`030?l0_`3o
ool0oooo03l0oooo000M0?ooo`030000003oool0oooo00`0oooo0P000;lN0?ooo`030000_`3oool0
oooo01d0oooo00<0002o0?ooo`3oool0703oool20000_dd0oooo00=000000?oood0000002@3oool0
1D000000oooo0?ooo`3oool000000180oooo0P3o0;m@0?ooo`030?l0_`3oool0oooo03h0oooo000M
0?ooo`030000003oool0oooo00d0oooo00<0002o0?ooo`3oool0703oool00`000;l0oooo0?ooo`0M
0?ooo`030000_`3oool0oooo01`0oooo00<0002o0?ooo`3oool0C03oool00d000000oooo@0000007
0?ooo`900000103oool00`000000oooo0?ooo`0@0?ooo`030?l0_`3oool0oooo04l0oooo0P3o0;lo
0?ooo`007@3oool00`000000oooo0?ooo`0=0?ooo`030000_`3oool0oooo01`0oooo00<0002o0?oo
o`3oool07@3oool20000_ad0oooo00<0002o0?ooo`3oool0C03oool00d000000oooo@00000070?oo
o`03@000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool20?l0_e80oooo00<0o`2o0?oo
o`3oool0?@3oool001d0oooo00<000000?ooo`3oool03P3oool00`000;l0oooo0?ooo`0J0?ooo`03
0000_`3oool0oooo01l0oooo00<0002o0?ooo`3oool06P3oool20000_dl0oooo00=000000?ooo`3o
ool01P3oool3@00000<0oooo00<000000?ooo`3oool03`3oool00`3o0;l0oooo0?ooo`1A0?ooo`80
o`2o?P3oool001d0oooo00<000000?ooo`3oool03P3oool00`000;l0oooo0?ooo`0J0?ooo`030000
_`3oool0oooo01l0oooo0P000;lK0?ooo`030000_`3oool0oooo05d0oooo00<000000?ooo`3oool0
3P3oool20?l0_e@0oooo0P3o0;lm0?ooo`003P3oool00d000000oooo0?ooo`020?ooo`03@000003o
ool0oooo0080oooo00=000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`80002o6P3o
ool20000_b80oooo00<0002o0?ooo`3oool06@3oool00`000;l0oooo0?ooo`1M0?ooo`030000003o
ool0oooo00d0oooo0P3o0;mF0?ooo`030?l0_`3oool0oooo03/0oooo000=0?ooo`03@000003ooom0
000000L0oooo00=000000?oood0000000`3oool00`000000oooo0?ooo`0?0?ooo`030000_`3oool0
oooo01P0oooo00<0002o0?ooo`3oool08@3oool00`000;l0oooo0?ooo`0H0?ooo`030000_`3oool0
oooo05h0oooo00<000000?ooo`3oool03@3oool00`3o0;l0oooo0?ooo`1E0?ooo`80o`2o?03oool0
00d0oooo00=000000?oood0000001`3oool00d000000oooo@00000030?ooo`030000003oool0oooo
00l0oooo00<0002o0?ooo`3oool0603oool00`000;l0oooo0?ooo`0Q0?ooo`80002o6@3oool00`00
0;l0oooo0?ooo`1N0?ooo`030000003oool0oooo00`0oooo00<0o`2o0?ooo`3oool0E`3oool20?l0
_c/0oooo000=0?ooo`03@000003ooom0000000P0oooo00=000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0@0?ooo`030000_`3oool0oooo01H0oooo00<0002o0?ooo`3oool08`3oool00`000;l0
oooo0?ooo`0F0?ooo`80002oH03oool00`000000oooo0?ooo`0;0?ooo`80o`2oFP3oool00`3o0;l0
oooo0?ooo`0i0?ooo`003@3oool00d000000oooo@00000070?ooo`03@000003ooom0000000<0oooo
00<000000?ooo`3oool0403oool00`000;l0oooo0?ooo`0F0?ooo`030000_`3oool0oooo02<0oooo
0P000;lG0?ooo`030000_`3oool0oooo05l0oooo00<000000?ooo`3oool02P3oool20?l0_e/0oooo
0P3o0;lj0?ooo`003P3oool00d000000oooo0?ooo`070?ooo`03@000003oool0oooo0080oooo00<0
00000?ooo`3oool0403oool20000_aH0oooo00<0002o0?ooo`3oool09@3oool00`000;l0oooo0?oo
o`0D0?ooo`80002oH@3oool00`000000oooo0?ooo`0:0?ooo`030?l0_`3oool0oooo05/0oooo0P3o
0;li0?ooo`007@3oool00`000000oooo0?ooo`0A0?ooo`030000_`3oool0oooo01@0oooo00<0002o
0?ooo`3oool09@3oool20000_aD0oooo00<0002o0?ooo`3oool0H03oool00`000000oooo0?ooo`09
0?ooo`030?l0_`3oool0oooo05d0oooo0P3o0;lh0?ooo`007@3oool00`000000oooo0?ooo`0A0?oo
o`80002o503oool00`000;l0oooo0?ooo`0W0?ooo`030000_`3oool0oooo0180oooo0P000;mR0?oo
o`030000003oool0oooo00P0oooo0P3o0;mP0?ooo`80o`2o=`3oool001d0oooo00<000000?ooo`3o
ool04P3oool00`000;l0oooo0?ooo`0B0?ooo`030000_`3oool0oooo02L0oooo0P000;lC0?ooo`03
0000_`3oool0oooo0640oooo00<000000?ooo`3oool01`3oool20?l0_f80oooo0P3o0;lf0?ooo`00
7@3oool00`000000oooo0?ooo`0B0?ooo`80002o4P3oool00`000;l0oooo0?ooo`0Y0?ooo`030000
_`3oool0oooo0100oooo0P000;mS0?ooo`030000003oool0oooo00H0oooo0P3o0;mT0?ooo`80o`2o
=@3oool001d0oooo00<000000?ooo`3oool04`3oool00`000;l0oooo0?ooo`0?0?ooo`80002o:`3o
ool20000_a40oooo00<0002o0?ooo`3oool0HP3oool00`000000oooo0?ooo`040?ooo`<0o`2oIP3o
ool20?l0_c@0oooo000M0?ooo`030000003oool0oooo01@0oooo00<0002o0?ooo`3oool03P3oool0
0`000;l0oooo0?ooo`0[0?ooo`030000_`3oool0oooo00h0oooo0P000;mM0?ooo`E000000P3oool0
0`000000oooo0?ooo`030?ooo`80o`2oJ@3oool30?l0_c80oooo000M0?ooo`030000003oool0oooo
01@0oooo0P000;l>0?ooo`80002o;P3oool00`000;l0oooo0?ooo`0=0?ooo`030000_`3oool0oooo
05h0oooo00=000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool30?l0_f`0oooo0`3o0;l`
0?ooo`007@3oool00`000000oooo0?ooo`0E0?ooo`030000_`3oool0oooo00/0oooo0P000;l_0?oo
o`80002o3@3oool00`000;l0oooo0?ooo`1O0?ooo`03@000003oool0oooo0080oooo1@3o0;m`0?oo
o`D0o`2o;03oool001d0oooo00<000000?ooo`3oool05P3oool00`000;l0oooo0?ooo`0:0?ooo`03
0000_`3oool0oooo02l0oooo0P000;l;0?ooo`80002oH@3oool00d000000oooo0?ooo`020?ooo`03
0000003oool0oooo0:<0oooo000M0?ooo`030000003oool0oooo01H0oooo0P000;l:0?ooo`80002o
<P3oool20000_`T0oooo0P000;mR0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool0
X`3oool001H0oooo1D0000020?ooo`030000003oool0oooo01L0oooo0P000;l80?ooo`80002o=03o
ool20000_`L0oooo0P000;mR0?ooo`900000ZP3oool001P0oooo00=000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0H0?ooo`<0002o103oool30000_cH0oooo0P000;l40?ooo`<0002oo`3oool@
0?ooo`00603oool00d000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo1P000;li0?oo
o`H0002oo`3ooolB0?ooo`00603oool00d000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0
ooooL@3oool001P0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`3j0?ooo`900000
503oool00d000000oooo0?ooo`060?ooo`03@000003oool0oooo05@0oooo000G0?ooo`900000c`3o
ool3@0000340oooo00=000000?ooo`3oool0403oool00d000000oooo0?ooo`080?ooo`03@000003o
ool0oooo05<0oooo003Y0?ooo`03@000003oool0oooo0280oooo0d0000030?ooo`=000000`3oool3
@00000D0oooo00=000000?ooo`3oool01D0000040?ooo`03@000003oool0oooo00<0oooo0d000004
0?ooo`03@000003oool0oooo0580oooo003N0?ooo`90000000T0oooo@0000400001000000?oood00
0000oooo@000003oool00d0000060?ooo`03@000003oool0oooo01X0oooo00=000000?ooo`3oool0
0`3oool01D000000oooo0?ooo`3ooom000000080oooo00=000000?ooo`3oool0203oool00d000000
oooo0?ooo`040?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3ooom00000103oool00d00
0000oooo0?ooo`1B0?ooo`00D03oool2@00001@0oooo00=000000?ooo`3oool01P3oool00d000000
oooo0?ooo`1/0?ooo`04@000003oool0oooo0?ooo`90000000H0oooo@000003ooom000000?oood00
00020?ooo`03@000003oool0oooo0200oooo00=000000?ooo`3oool00`3oool01D000000oooo0?oo
o`3ooom000000080oooo00=000000?ooo`3oool0203oool00d000000oooo0?ooo`040?ooo`03@000
003oool0oooo0080oooo00A000000?ooo`3ooom00000103oool00d000000oooo0?ooo`1B0?ooo`00
DP3oool00d000000oooo0?ooo`0@0?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool0
K03oool3@00000080?oood000000oooo@000003ooom000000?oood0000020?ooo`03@000003oool0
oooo0200oooo0T0000030?ooo`900000103oool3@00000X0oooo00=000000?ooo`3oool0103oool0
0d000000oooo0?ooo`030?ooo`=00000103oool00d000000oooo0?ooo`1B0?ooo`006`3oool3@000
02H0oooo0d0000030?ooo`=000000`3oool3@00000D0oooo00=000000?ooo`3oool01D0000040?oo
o`03@000003oool0oooo0080oooo0d0000050?ooo`03@000003oool0oooo06/0oooo00A000000?oo
od000000oooo0T0000000`3ooom000000?ooo`04@00002<0oooo00A000000?ooo`3ooom00000503o
ool00d000000oooo0?ooo`050?ooo`03@000003oool0oooo00@0oooo00E000000?ooo`3oool0oooo
@000001E0?ooo`00703oool00d000000oooo0?ooo`0V0?ooo`03@000003oool0oooo00<0oooo00E0
00000?ooo`3oool0oooo@00000020?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool0
103oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00D0oooo00=000000?ooo`3oool0
K03oool00d000000oooo0?ooo`0[0?ooo`E000000P3oool00d000000oooo0?ooo`0>0?ooo`900000
203oool00d000000oooo0?ooo`020?ooo`9000000P3oool00d000000oooo0?ooo`1D0?ooo`004@3o
ool2@00000090?oood0000100000@000003ooom000000?oood000000oooo00=000001P3oool00d00
0000oooo0?ooo`0M0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@0000002
0?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool0103oool00d000000oooo0?ooo`02
0?ooo`03@000003oool0oooo00D0oooo00=000000?ooo`3oool0J`3oool2@0000:l0oooo000A0?oo
o`04@000003oool0oooo0?ooo`90000000H0oooo@000003ooom000000?oood0000020?ooo`03@000
003oool0oooo02<0oooo0T0000030?ooo`900000103oool3@00000X0oooo00=000000?ooo`3oool0
103oool00d000000oooo0?ooo`020?ooo`=000001@3oool00d000000oooo0?ooo`3o0?oooad0oooo
000B0?ooo`=0000000P0oooo@000003ooom000000?oood000000oooo@0000080oooo00=000000?oo
o`3oool08`3oool014000000oooo0?oood00000D0?ooo`03@000003oool0oooo00D0oooo00=00000
0?ooo`3oool0203oool00d000000oooo0?ooo`3o0?oooah0oooo000B0?ooo`04@000003ooom00000
0?ooo`90000000<0oooo@000003oool01400000U0?ooo`E000000P3oool00d000000oooo0?ooo`0>
0?ooo`900000203oool00d000000oooo0?ooo`060?ooo`03@000003oool0oooo0?l0oooo7`3oool0
01<0oooo00=000000?ooo`3oool0o`3ooomk0?ooo`004P3oool2@0000?l0ooooO@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool001`0oooo1D0000020?ooo`030000003oool0oooo0;d0oooo1D0000020?ooo`030000003o
ool0oooo0:<0oooo000N0?ooo`03@000003oool0oooo0080oooo00<000000?ooo`3oool0_`3oool0
0d000000oooo0?ooo`020?ooo`030000003oool0oooo0:<0oooo000H0?ooo`=000000`3oool00d00
0000oooo0?ooo`020?ooo`030000003oool0oooo05<0oooo2P0003mL0?ooo`=000000`3oool00d00
0000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo0`3o03lU0?ooo`@0o`0o903oool40?l0
?cD0oooo000N0?ooo`03@000003oool0oooo0080oooo00<000000?ooo`3oool0D@3oool30000?`P0
oooo0`0003mP0?ooo`03@000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool20?l0?`03
0?ooo`3o03l0o`0o02<0oooo0P3o03l20?ooo`030?l0?`3oool0oooo0280oooo00<0o`0o0?ooo`3o
ool00P3o03ld0?ooo`007P3oool00d000000oooo0?ooo`020?ooo`030000003oool0oooo0500oooo
0P0003l<0?ooo`80000oG`3oool00d000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo
0P3o03l30?ooo`80o`0o8P3oool0103o03l0oooo0?ooo`3oool20?l0?b80oooo0P3o03l30?ooo`03
0?l0?`3oool0oooo0380oooo000M0?ooo`900000103oool00`000000oooo0?ooo`1?0?ooo`80000o
3P3oool20000?ed0oooo0T0000040?ooo`030000003oool0oooo01P0oooo00<0o`0o0?ooo`3oool0
0`3oool00`3o03l0oooo0?ooo`0O0?ooo`80o`0o103oool00`3o03l0oooo0?ooo`0P0?ooo`030?l0
?`3oool0oooo0080oooo0P3o03lc0?ooo`008`3oool00`000000oooo0?ooo`1>0?ooo`80000o403o
ool20000?f80oooo00<000000?ooo`3oool0603oool00`3o03l0oooo0?ooo`030?ooo`030?l0?`3o
ool0oooo01l0oooo00<0o`0o0?ooo`3oool00`3oool20?l0?b00oooo0P3o03l50?ooo`030?l0?`3o
ool0oooo0340oooo000S0?ooo`030000003oool0oooo04d0oooo00<0000o0?ooo`3oool04P3oool0
0`0003l0oooo0?ooo`1O0?ooo`030000003oool0oooo01L0oooo0P3o03l50?ooo`80o`0o803oool0
0`3o03l0oooo0?ooo`040?ooo`030?l0?`3oool0oooo01h0oooo00<0o`0o0?ooo`3oool0103oool0
0`3o03l0oooo0?ooo`0a0?ooo`008`3oool00`000000oooo0?ooo`1<0?ooo`030000?`3oool0oooo
01<0oooo0P0003mP0?ooo`030000003oool0oooo01L0oooo00<0o`0o0?ooo`3oool01@3oool00`3o
03l0oooo0?ooo`0M0?ooo`80o`0o1P3oool00`3o03l0oooo0?ooo`0N0?ooo`030?l0?`3oool0oooo
00@0oooo0P3o03lb0?ooo`008`3oool00`000000oooo0?ooo`1;0?ooo`030000?`3oool0oooo01D0
oooo0P0003mO0?ooo`030000003oool0oooo01L0oooo00<0o`0o0?ooo`3oool01@3oool00`3o03l0
oooo0?ooo`0M0?ooo`030?l0?`3oool0oooo00D0oooo0P3o03lN0?ooo`80o`0o1`3oool00`3o03l0
oooo0?ooo`0`0?ooo`008`3oool00`000000oooo0?ooo`1:0?ooo`80000o603oool20000?eh0oooo
00<000000?ooo`3oool05P3oool20?l0?`L0oooo00<0o`0o0?ooo`3oool07@3oool00`3o03l0oooo
0?ooo`060?ooo`030?l0?`3oool0oooo01`0oooo00<0o`0o0?ooo`3oool01P3oool00`3o03l0oooo
0?ooo`0`0?ooo`008`3oool00`000000oooo0?ooo`190?ooo`80000o6P3oool20000?ed0oooo00<0
00000?ooo`3oool05P3oool00`3o03l0oooo0?ooo`070?ooo`030?l0?`3oool0oooo01`0oooo00<0
o`0o0?ooo`3oool01P3oool00`3o03l0oooo0?ooo`0L0?ooo`030?l0?`3oool0oooo00H0oooo00<0
o`0o0?ooo`3oool0<03oool002<0oooo00<000000?ooo`3oool0B03oool20000?a`0oooo00<0000o
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0F0?ooo`030?l0?`3oool0oooo00L0oooo00<0o`0o
0?ooo`3oool06`3oool00`3o03l0oooo0?ooo`070?ooo`030?l0?`3oool0oooo01`0oooo00<0o`0o
0?ooo`3oool01`3oool00`3o03l0oooo0?ooo`0_0?ooo`008`3oool00`000000oooo0?ooo`180?oo
o`030000?`3oool0oooo01`0oooo00<0000o0?ooo`3oool0FP3oool00`000000oooo0?ooo`0F0?oo
o`030?l0?`3oool0oooo00L0oooo00<0o`0o0?ooo`3oool06`3oool00`3o03l0oooo0?ooo`070?oo
o`030?l0?`3oool0oooo01/0oooo0P3o03l90?ooo`030?l0?`3oool0oooo02l0oooo000S0?ooo`03
0000003oool0oooo04L0oooo0P0003lN0?ooo`80000oF`3oool00`000000oooo0?ooo`0F0?ooo`03
0?l0?`3oool0oooo00L0oooo00<0o`0o0?ooo`3oool06`3oool00`3o03l0oooo0?ooo`080?ooo`03
0?l0?`3oool0oooo01X0oooo00<0o`0o0?ooo`3oool0203oool00`3o03l0oooo0?ooo`0_0?ooo`00
8`3oool00`000000oooo0?ooo`160?ooo`80000o803oool20000?eX0oooo00<000000?ooo`3oool0
5@3oool00`3o03l0oooo0?ooo`090?ooo`030?l0?`3oool0oooo01X0oooo00<0o`0o0?ooo`3oool0
203oool00`3o03l0oooo0?ooo`0J0?ooo`030?l0?`3oool0oooo00P0oooo00<0o`0o0?ooo`3oool0
;`3oool002<0oooo00<000000?ooo`3oool0AP3oool00`0003l0oooo0?ooo`0P0?ooo`030000?`3o
ool0oooo05P0oooo00<000000?ooo`3oool05@3oool00`3o03l0oooo0?ooo`090?ooo`030?l0?`3o
ool0oooo01T0oooo0P3o03l:0?ooo`030?l0?`3oool0oooo01X0oooo00<0o`0o0?ooo`3oool0203o
ool20?l0?c00oooo000S0?ooo`030000003oool0oooo04D0oooo0P0003lR0?ooo`80000oF@3oool0
0`000000oooo0?ooo`0E0?ooo`030?l0?`3oool0oooo00T0oooo00<0o`0o0?ooo`3oool06@3oool0
0`3o03l0oooo0?ooo`090?ooo`030?l0?`3oool0oooo01X0oooo00<0o`0o0?ooo`3oool02@3oool0
0`3o03l0oooo0?ooo`0^0?ooo`00503oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo
0080oooo00=000000?ooo`3oool00P3oool00`000000oooo0?ooo`140?ooo`80000o903oool00`00
03l0oooo0?ooo`180?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool00d00
0000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00<0o`0o0?ooo`3oool02@3oool00`3o
03l0oooo0?ooo`0I0?ooo`030?l0?`3oool0oooo00X0oooo00<0o`0o0?ooo`3oool0603oool00`3o
03l0oooo0?ooo`0:0?ooo`030?l0?`3oool0oooo02h0oooo000C0?ooo`03@000003ooom0000000L0
oooo00=000000?oood0000000`3oool00`000000oooo0?ooo`140?ooo`030000?`3oool0oooo02@0
oooo00<0000o0?ooo`3oool0AP3oool00d000000oooo@00000070?ooo`03@000003ooom0000000<0
oooo00<000000?ooo`3oool0503oool20?l0?`/0oooo0P3o03lJ0?ooo`030?l0?`3oool0oooo00X0
oooo00<0o`0o0?ooo`3oool0603oool00`3o03l0oooo0?ooo`0:0?ooo`030?l0?`3oool0oooo02h0
oooo000>0?ooo`=000000P3oool00d000000oooo@00000090?ooo`05@000003oool0oooo0?ooo`00
0000A@3oool20000?bH0oooo0P0003m20?ooo`=000000P3oool00d000000oooo@00000090?ooo`05
@000003oool0oooo0?ooo`0000005P3oool00`3o03l0oooo0?ooo`0;0?ooo`030?l0?`3oool0oooo
01P0oooo00<0o`0o0?ooo`3oool02P3oool00`3o03l0oooo0?ooo`0H0?ooo`030?l0?`3oool0oooo
00X0oooo00<0o`0o0?ooo`3oool0;P3oool001<0oooo00=000000?oood0000001`3oool2@00000@0
oooo00<000000?ooo`3oool0@`3oool00`0003l0oooo0?ooo`0V0?ooo`030000?`3oool0oooo04D0
oooo00=000000?oood0000001`3oool2@00000@0oooo00<000000?ooo`3oool0503oool00`3o03l0
oooo0?ooo`0;0?ooo`030?l0?`3oool0oooo01L0oooo00<0o`0o0?ooo`3oool02`3oool00`3o03l0
oooo0?ooo`0H0?ooo`030?l0?`3oool0oooo00X0oooo0P3o03l_0?ooo`004`3oool00d000000oooo
@00000070?ooo`03@000003oool0oooo00<0oooo00<000000?ooo`3oool0@P3oool20000?bP0oooo
0P0003m60?ooo`03@000003ooom0000000L0oooo00=000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0D0?ooo`030?l0?`3oool0oooo00/0oooo00<0o`0o0?ooo`3oool05`3oool00`3o03l0oooo
0?ooo`0;0?ooo`030?l0?`3oool0oooo01P0oooo00<0o`0o0?ooo`3oool02`3oool00`3o03l0oooo
0?ooo`0]0?ooo`00503oool00d000000oooo0?ooo`060?ooo`=000000`3oool00`000000oooo0?oo
o`110?ooo`80000o:P3oool20000?dH0oooo00=000000?ooo`3oool01P3oool3@00000<0oooo00<0
00000?ooo`3oool0503oool00`3o03l0oooo0?ooo`0;0?ooo`030?l0?`3oool0oooo01L0oooo00<0
o`0o0?ooo`3oool0303oool00`3o03l0oooo0?ooo`0F0?ooo`030?l0?`3oool0oooo00`0oooo00<0
o`0o0?ooo`3oool0;@3oool002<0oooo00<000000?ooo`3oool0@@3oool00`0003l0oooo0?ooo`0Z
0?ooo`030000?`3oool0oooo05<0oooo00<000000?ooo`3oool04`3oool20?l0?`d0oooo00<0o`0o
0?ooo`3oool05`3oool00`3o03l0oooo0?ooo`0<0?ooo`030?l0?`3oool0oooo01H0oooo00<0o`0o
0?ooo`3oool0303oool00`3o03l0oooo0?ooo`0]0?ooo`008`3oool00`000000oooo0?ooo`100?oo
o`80000o;03oool20000?e@0oooo00<000000?ooo`3oool04`3oool00`3o03l0oooo0?ooo`0=0?oo
o`030?l0?`3oool0oooo01H0oooo00<0o`0o0?ooo`3oool0303oool00`3o03l0oooo0?ooo`0F0?oo
o`030?l0?`3oool0oooo00`0oooo00<0o`0o0?ooo`3oool0;@3oool002<0oooo00<000000?ooo`3o
ool0@03oool00`0003l0oooo0?ooo`0/0?ooo`030000?`3oool0oooo0580oooo00<000000?ooo`3o
ool04`3oool00`3o03l0oooo0?ooo`0=0?ooo`030?l0?`3oool0oooo01H0oooo00<0o`0o0?ooo`3o
ool0303oool00`3o03l0oooo0?ooo`0F0?ooo`030?l0?`3oool0oooo00`0oooo00<0o`0o0?ooo`3o
ool0;@3oool002<0oooo00<000000?ooo`3oool0?`3oool20000?bh0oooo0P0003mC0?ooo`030000
003oool0oooo01<0oooo00<0o`0o0?ooo`3oool03@3oool00`3o03l0oooo0?ooo`0E0?ooo`030?l0
?`3oool0oooo00d0oooo00<0o`0o0?ooo`3oool05P3oool00`3o03l0oooo0?ooo`0=0?ooo`030?l0
?`3oool0oooo02`0oooo000S0?ooo`030000003oool0oooo03l0oooo00<0000o0?ooo`3oool0;P3o
ool00`0003l0oooo0?ooo`1A0?ooo`030000003oool0oooo01<0oooo00<0o`0o0?ooo`3oool03@3o
ool00`3o03l0oooo0?ooo`0E0?ooo`030?l0?`3oool0oooo00d0oooo00<0o`0o0?ooo`3oool05@3o
ool00`3o03l0oooo0?ooo`0>0?ooo`030?l0?`3oool0oooo02`0oooo000S0?ooo`030000003oool0
oooo00h0oooo0d0000030?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool0303oool3
@0000080oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`090?ooo`80000o00=00000
0?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00/0oooo00=00000
0?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00L0oooo14000002
0000?`030?oood000000oooo00<0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`14
0?ooo`030000003oool0oooo00h0oooo0d0000020?ooo`030?l0?d000000oooo00<0oooo00=00000
0?ooo`3oool01`3oool00`3o03l0oooo0?ooo`020?ooo`=000000P3oool00d000000oooo0?ooo`02
0?ooo`03@000003oool0oooo00H0oooo00@0o`0o0?ooo`3oool0oooo0T0000040?ooo`03@000003o
ool0oooo0080oooo00=000000?ooo`3o03l02`3oool00d000000oooo0?ooo`020?ooo`03@000003o
ool0oooo0080oooo00=000000?l0?`3oool01`3oool5@0000080oooo00=000000?l0?`3oool00P3o
ool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo02<0oooo000S0?ooo`030000003oool0
oooo00h0oooo00=000000?ooo`3oool00P3oool00d000000oooo@00000020?ooo`03@000003ooom0
000000h0oooo00I000000?ooo`3ooom000000?oood0000020?ooo`03@000003ooom0000000X0oooo
00@0000o@000003ooom000000P3oool00d000000oooo@00000020?ooo`03@000003ooom0000000/0
oooo00=000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom0000000X0
oooo00M000000?ooo`3oool0000o@000003ooom000000080oooo00=000000?oood0000000P3oool0
0d000000oooo@00000150?ooo`030000003oool0oooo00h0oooo00Q000000?ooo`3oool0oooo0?l0
?d000000oooo@0000080oooo00=000000?oood000000203oool20?l0?`@0oooo00I000000?ooo`3o
oom000000?oood0000020?ooo`03@000003ooom0000000L0oooo00L0o`0o0?ooo`3oool0oooo@000
003ooom000000080oooo00=000000?oood0000000P3oool014000000oooo@000003o03l:0?ooo`03
@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo0?l0?`0:0?ooo`07
@000003oool0oooo0?oood000000oooo0?l0?`020?ooo`03@000003ooom000000080oooo00=00000
0?oood000000903oool002<0oooo00<000000?ooo`3oool03`3oool01d000000oooo0?ooo`3ooom0
00000?oood0000000P3oool00d000000oooo@000000<0?ooo`A0000000@0oooo@000003ooom00000
0P3oool00d000000oooo@00000090?ooo`80000o00=000000?oood0000000P3oool00d000000oooo
@00000020?ooo`03@000003ooom0000000/0oooo00=000000?oood0000000P3oool00d000000oooo
@00000020?ooo`03@000003ooom0000000X0oooo00=000000?ooo`3oool00P0003l01`3ooom00000
0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@00000150?ooo`030000003oool0oooo
00l0oooo00M000000?ooo`3oool0o`0o@000003ooom000000080oooo00=000000?oood0000002@3o
ool00`3o03l0oooo0?ooo`04@00000040?oood000000oooo@0000080oooo00=000000?oood000000
1`3oool01`3o03l0oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@00000020?oo
o`04@000003ooom000000?l0?`X0oooo00=000000?oood0000000P3oool00d000000oooo@0000002
0?ooo`03@000003oool0o`0o00X0oooo00M000000?ooo`3oool0oooo@000003oool0o`0o0080oooo
00=000000?oood0000000P3oool00d000000oooo@000000T0?ooo`008`3oool00`000000oooo0?oo
o`0?0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000003ooom0000000`0
oooo00=000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom0000000T0
oooo00@0000o0?oood00001000000`3oool00d000000oooo@00000020?ooo`03@000003ooom00000
00`0oooo00M000000?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood0000002P3o
ool01d000000oooo0?ooo`3oool0000o0?oood0000000P3oool00d000000oooo@00000020?ooo`03
@000003ooom0000004D0oooo00<000000?ooo`3oool03`3oool01d000000oooo0?ooo`3o03m00000
0?oood0000000P3oool00d000000oooo@00000090?ooo`060?l0?`3oool0oooo@000003ooom00000
0P3oool00d000000oooo@00000020?ooo`03@000003ooom0000000H0oooo00<0o`0o0?ooo`3oool0
0P3oool2@00000<0oooo00=000000?oood0000000P3oool014000000oooo@000003o03l;0?ooo`07
@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000003oool0o`0o00X0oooo00a00000
0?ooo`3oool0oooo@000003ooom000000?l0?`3ooom000000?oood0000020?ooo`03@000003ooom0
000002@0oooo000S0?ooo`030000003oool0oooo00h0oooo00=000000?oood0000000P3oool00d00
0000oooo@00000020?ooo`03@000003ooom0000000d0oooo0T0000020?ooo`03@000003ooom00000
0080oooo00=000000?oood000000203oool0100003l0oooo0?oood0000040?ooo`03@000003ooom0
00000080oooo00=000000?oood0000002`3oool00d000000oooo@00000020?ooo`03@000003ooom0
00000080oooo00=000000?oood0000002P3oool014000000oooo0?ooo`3oool20000?`06@000003o
ool0oooo@000003ooom000000P3oool00d000000oooo@00000150?ooo`030000003oool0oooo00h0
oooo00Q000000?oood000000oooo0?l0?d000000oooo@0000080oooo00=000000?oood0000002@3o
ool0103o03l0oooo0?ooo`3oool2@0000080oooo00=000000?oood0000000P3oool00d000000oooo
@00000060?ooo`030?l0?`3oool0oooo0080oooo00=000000?ooo`3oool00P3oool00d000000oooo
@00000020?ooo`04@000003ooom000000?l0?`X0oooo00=000000?oood0000000P3oool00d000000
oooo@00000020?ooo`03@000003oool0o`0o00X0oooo00a000000?ooo`3oool0oooo@000003ooom0
00000?l0?`3ooom000000?oood0000020?ooo`03@000003ooom0000002@0oooo000S0?ooo`030000
003oool0oooo00l0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03@000
003oool0oooo00d0oooo00E000000?ooo`3oool0oooo@00000040?ooo`03@000003oool0oooo00L0
oooo00@0000o0?ooo`3oool0oooo0T0000030?ooo`03@000003oool0oooo0080oooo00=000000?oo
o`3oool02`3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00=000000?oo
o`3oool0203oool2@00000@0oooo00<0000o0?ooo`3oool00P3oool00d000000oooo0?ooo`020?oo
o`03@000003oool0oooo04@0oooo00<000000?ooo`3oool03`3oool01T000000oooo0?ooo`3o03l0
oooo@00000@0oooo00=000000?ooo`3oool0203oool00`3o03l0oooo0?ooo`020?ooo`05@000003o
ool0oooo0?oood000000103oool00d000000oooo0?ooo`050?ooo`030?l0?`3oool0oooo00<0oooo
0T0000030?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3o03l0o`0o2P3oool00d000000
oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00<0o`0o0?ooo`3oool0203oool2@00000@0
oooo00=000000?ooo`3o03l00P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo02<0
oooo000S0?ooo`030000003oool0oooo03/0oooo0P0003lf0?ooo`80000oC`3oool00`000000oooo
0?ooo`0B0?ooo`030?l0?`3oool0oooo00l0oooo00<0o`0o0?ooo`3oool04`3oool00`3o03l0oooo
0?ooo`0@0?ooo`030?l0?`3oool0oooo0180oooo00<0o`0o0?ooo`3oool0403oool00`3o03l0oooo
0?ooo`0[0?ooo`008`3oool00`000000oooo0?ooo`0k0?ooo`030000?`3oool0oooo03H0oooo00<0
000o0?ooo`3oool0C@3oool00`000000oooo0?ooo`0A0?ooo`030?l0?`3oool0oooo0140oooo00<0
o`0o0?ooo`3oool04P3oool00`3o03l0oooo0?ooo`0@0?ooo`030?l0?`3oool0oooo0180oooo00<0
o`0o0?ooo`3oool0403oool00`3o03l0oooo0?ooo`0[0?ooo`008`3oool00`000000oooo0?ooo`0j
0?ooo`030000?`3oool0oooo03P0oooo00<0000o0?ooo`3oool0203oool2@0000080oooo0d000000
1P3ooom000000?oood000000oooo@0000080oooo0T00000c0?ooo`030000003oool0oooo0140oooo
00<0o`0o0?ooo`3oool04@3oool00`3o03l0oooo0?ooo`0B0?ooo`030?l0?`3oool0oooo0100oooo
00<0o`0o0?ooo`3oool04P3oool00`3o03l0oooo0?ooo`0@0?ooo`030?l0?`3oool0oooo00P0oooo
0T0000020?ooo`=0000000H0oooo@000003ooom000000?oood0000020?ooo`9000004P3oool002<0
oooo00<000000?ooo`3oool0>P3oool00`0003l0oooo0?ooo`0h0?ooo`030000?`3oool0oooo00L0
oooo00A000000?ooo`3ooom000000P3oool02T000000oooo0?oood000000oooo@000003ooom00000
0?oood00000e0?ooo`030000003oool0oooo0140oooo00<0o`0o0?ooo`3oool04@3oool00`3o03l0
oooo0?ooo`0A0?ooo`030?l0?`3oool0oooo0140oooo00<0o`0o0?ooo`3oool04P3oool00`3o03l0
oooo0?ooo`0@0?ooo`80o`0o203oool014000000oooo0?oood0000020?ooo`0:@000003oool0oooo
@000003ooom000000?oood000000oooo@00001@0oooo000P0?ooo`<0000000<0000o000000000000
>@0000000`0003l000000000000i00000080000o0P0000000d000000oooo0?ooo`030?ooo`03@000
003oool0oooo00<0oooo00U000000?ooo`3ooom000000?oood000000oooo@000003oool00d00000`
0?ooo`<0000000<0o`0o0000000000004@0000000`3o03l000000000000A000000030?l0?`000000
00000140000000<0o`0o0000000000004@0000000`3o03l000000000000B000000030?l0?`000000
00000140000000@0o`0o00000000001000001@3oool00d000000oooo0?ooo`030?ooo`09@000003o
ool0oooo@000003ooom000000?oood000000oooo00=000004P3oool002<0oooo00<0000o0?ooo`3o
ool05@3oool00d000000oooo0?ooo`0E0?ooo`03@000003oool0oooo00P0oooo0P0003l;0?ooo`03
@000003oool0oooo01D0oooo00=000000?ooo`3oool05P3oool00d000000oooo0?ooo`050?ooo`A0
00000P3oool2@0000080oooo0T000000103ooom000000?ooo`3oool3@00003<0oooo00<0o`0o0?oo
o`3oool04@3oool01@3o03l0oooo0?ooo`3ooom0000000l0oooo00<0o`0o0?ooo`3oool01@3oool0
0d000000oooo0?ooo`090?ooo`030?l0?`3oool0oooo00T0oooo00=000000?ooo`3oool01P3oool0
0`3o03l0oooo0?ooo`0<0?ooo`05@000003oool0oooo0?ooo`3o03l0503oool00d000000oooo0?oo
o`050?ooo`A000000P3oool2@0000080oooo0T000000103ooom000000?ooo`3oool3@0000180oooo
000S0?ooo`030000000003l0oooo03P0oooo00<0000o0?ooo`3oool0A03oool00d000000oooo0?oo
o`120?ooo`030?l0?`3oool0oooo0140oooo00<0o`0o0?ooo`3oool04@3oool00`3o03l0oooo0?oo
o`0A0?ooo`030?l0?`3oool0oooo0180oooo00<0o`0o0?ooo`3oool0403oool00`3o03l0oooo0?oo
o`0K0?ooo`03@000003oool0oooo0240oooo000S0?ooo`030000000003l0000o03L0oooo0P0003m<
0?ooo`03@000003oool0oooo03`0oooo00<0o`0o0?ooo`3oool0403oool00`3o03l0oooo0?ooo`0B
0?ooo`80o`0o4P3oool00`3o03l0oooo0?ooo`0B0?ooo`030?l0?`3oool0oooo0100oooo00<0o`0o
0?ooo`3oool08@3oool00d000000oooo0?ooo`0K0?ooo`008`3oool00`000000oooo0000?`0g0?oo
o`030000?`3oool0oooo08X0oooo00<0o`0o0?ooo`3oool0403oool00`3o03l0oooo0?ooo`0C0?oo
o`030?l0?`3oool0oooo00l0oooo00<0o`0o0?ooo`3oool04`3oool00`3o03l0oooo0?ooo`0@0?oo
o`030?l0?`3oool0oooo03l0oooo000S0?ooo`030000003oool0000o03H0oooo0P0003n<0?ooo`03
0000003o03l0oooo0100oooo00<0o`0o0?ooo`3oool04`3oool00`3o03l0oooo0?ooo`0?0?ooo`03
0?l0?`3oool0oooo01<0oooo00<0o`0o0?ooo`3oool0403oool00`3o03l0oooo0?ooo`0o0?ooo`00
8`3oool010000000oooo0?ooo`0003le0?ooo`030000?`3oool0oooo08/0oooo00<000000?l0?`3o
ool0403oool00`3o03l0oooo0?ooo`0C0?ooo`030?l0?`3oool0oooo00l0oooo00<0o`0o0?ooo`3o
ool04`3oool00`3o03l0oooo0?ooo`0@0?ooo`030?l0?`3oool0oooo03l0oooo000S0?ooo`030000
003oool0oooo0080000o<`3oool20000?hd0oooo00<000000?l0?`3oool0403oool00`3o03l0oooo
0?ooo`0C0?ooo`030?l0?`3oool0oooo00l0oooo00<0o`0o0?ooo`3oool0503oool00`3o03l0oooo
0?ooo`0>0?ooo`030?l0?`3oool0oooo0400oooo000S0?ooo`050000003oool0oooo0?ooo`0003l0
<`3oool00`0003l0oooo0?ooo`2<0?ooo`030000003o03l0oooo00l0oooo00<0o`0o0?ooo`3oool0
503oool00`3o03l0oooo0?ooo`0?0?ooo`030?l0?`3oool0oooo01@0oooo00<0o`0o0?ooo`3oool0
3P3oool00`3o03l0oooo0?ooo`100?ooo`008`3oool010000000oooo0?ooo`3oool20000?c40oooo
0P0003n>0?ooo`030000003o03l0oooo00l0oooo00<0o`0o0?ooo`3oool05@3oool00`3o03l0oooo
0?ooo`0>0?ooo`030?l0?`3oool0oooo01@0oooo00<0o`0o0?ooo`3oool03P3oool00`3o03l0oooo
0?ooo`100?ooo`008`3oool00`000000oooo0?ooo`020?ooo`030000?`3oool0oooo02l0oooo00<0
000o0?ooo`3oool0S@3oool00`000000o`0o0?l0?`0?0?ooo`030?l0?`3oool0oooo01D0oooo00<0
o`0o0?ooo`3oool03@3oool20?l0?aH0oooo00<0o`0o0?ooo`3oool03P3oool00`3o03l0oooo0?oo
o`100?ooo`008`3oool00`000000oooo0?ooo`020?ooo`80000o;`3oool20000?hl0oooo00<00000
0?ooo`3o03l03`3oool00`3o03l0oooo0?ooo`0E0?ooo`030?l0?`3oool0oooo00d0oooo00<0o`0o
0?ooo`3oool05@3oool00`3o03l0oooo0?ooo`0>0?ooo`030?l0?`3oool0oooo0400oooo000S0?oo
o`030000003oool0oooo00<0oooo00<0000o0?ooo`3oool0;@3oool00`0003l0oooo0?ooo`2>0?oo
o`030000003oool0o`0o00l0oooo00<0o`0o0?ooo`3oool05@3oool00`3o03l0oooo0?ooo`0=0?oo
o`030?l0?`3oool0oooo01D0oooo00<0o`0o0?ooo`3oool03@3oool00`3o03l0oooo0?ooo`110?oo
o`008`3oool00`000000oooo0?ooo`030?ooo`80000o;@3oool20000?i00oooo00<000000?ooo`3o
03l03`3oool00`3o03l0oooo0?ooo`0E0?ooo`030?l0?`3oool0oooo00d0oooo00<0o`0o0?ooo`3o
ool05P3oool00`3o03l0oooo0?ooo`0<0?ooo`030?l0?`3oool0oooo0440oooo000S0?ooo`030000
003oool0oooo00@0oooo00<0000o0?ooo`3oool0:`3oool00`0003l0oooo0?ooo`2?0?ooo`030000
003oool0o`0o00h0oooo0P3o03lG0?ooo`80o`0o3P3oool00`3o03l0oooo0?ooo`0F0?ooo`030?l0
?`3oool0oooo00`0oooo00<0o`0o0?ooo`3oool0@@3oool002<0oooo00<000000?ooo`3oool0103o
ool20000?b/0oooo00<0000o0?ooo`3oool0T03oool00`000000oooo0?l0?`0>0?ooo`030?l0?`3o
ool0oooo01L0oooo00<0o`0o0?ooo`3oool0303oool00`3o03l0oooo0?ooo`0F0?ooo`030?l0?`3o
ool0oooo00`0oooo00<0o`0o0?ooo`3oool0@@3oool002<0oooo00<000000?ooo`3oool01@3oool0
0`0003l0oooo0?ooo`0Y0?ooo`030000?`3oool0oooo0900oooo00@000000?ooo`3o03l0o`0o3@3o
ool00`3o03l0oooo0?ooo`0G0?ooo`030?l0?`3oool0oooo00/0oooo00<0o`0o0?ooo`3oool05`3o
ool00`3o03l0oooo0?ooo`0<0?ooo`030?l0?`3oool0oooo0440oooo000D0?ooo`03@000003oool0
oooo0080oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<0000o0?ooo`3oool09`3oool00`0003l0oooo0?ooo`220?ooo`03@000003oool0
oooo0080oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`040000003oool0
oooo0?l0?`d0oooo00<0o`0o0?ooo`3oool05`3oool00`3o03l0oooo0?ooo`0;0?ooo`030?l0?`3o
ool0oooo01L0oooo00<0o`0o0?ooo`3oool02`3oool20?l0?d<0oooo000C0?ooo`03@000003ooom0
000000L0oooo00=000000?oood0000000`3oool00`000000oooo0?ooo`060?ooo`80000o9`3oool2
0000?h<0oooo00=000000?oood0000001`3oool00d000000oooo@00000030?ooo`040000003oool0
oooo0?l0?`d0oooo00<0o`0o0?ooo`3oool05`3oool00`3o03l0oooo0?ooo`0;0?ooo`030?l0?`3o
ool0oooo01P0oooo00<0o`0o0?ooo`3oool02P3oool00`3o03l0oooo0?ooo`120?ooo`004`3oool0
0d000000oooo@00000090?ooo`05@000003oool0oooo0?ooo`0000002@3oool00`0003l0oooo0?oo
o`0U0?ooo`030000?`3oool0oooo0880oooo00=000000?oood0000002@3oool01D000000oooo0?oo
o`3oool000000080oooo00<0o`0o0?ooo`3oool02P3oool20?l0?aT0oooo0P3o03l<0?ooo`030?l0
?`3oool0oooo01P0oooo00<0o`0o0?ooo`3oool02P3oool00`3o03l0oooo0?ooo`120?ooo`004`3o
ool00d000000oooo@00000070?ooo`900000103oool00`000000oooo0?ooo`070?ooo`80000o9@3o
ool20000?h@0oooo00=000000?oood0000001`3oool2@00000@0oooo00@000000?ooo`3oool0o`0o
303oool00`3o03l0oooo0?ooo`0I0?ooo`030?l0?`3oool0oooo00X0oooo00<0o`0o0?ooo`3oool0
603oool00`3o03l0oooo0?ooo`0:0?ooo`030?l0?`3oool0oooo0480oooo000C0?ooo`03@000003o
oom0000000L0oooo00=000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000?`3o
ool0oooo0280oooo0P0003n50?ooo`03@000003ooom0000000L0oooo00=000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?l0?`/0oooo00<0o`0o0?ooo`3oool06@3oool00`3o03l0oooo0?oo
o`090?ooo`030?l0?`3oool0oooo01T0oooo00<0o`0o0?ooo`3oool02P3oool00`3o03l0oooo0?oo
o`120?ooo`00503oool00d000000oooo0?ooo`060?ooo`=000000`3oool00`000000oooo0?ooo`09
0?ooo`030000?`3oool0oooo0240oooo00<0000o0?ooo`3oool0Q@3oool00d000000oooo0?ooo`06
0?ooo`=000000`3oool01@000000oooo0?ooo`3oool0o`0o00/0oooo00<0o`0o0?ooo`3oool06@3o
ool00`3o03l0oooo0?ooo`090?ooo`030?l0?`3oool0oooo01T0oooo00<0o`0o0?ooo`3oool02P3o
ool00`3o03l0oooo0?ooo`120?ooo`008`3oool00`000000oooo0?ooo`090?ooo`80000o8@3oool2
0000?iH0oooo00D000000?ooo`3oool0oooo0?l0?`0;0?ooo`030?l0?`3oool0oooo01T0oooo00<0
o`0o0?ooo`3oool02@3oool00`3o03l0oooo0?ooo`0J0?ooo`030?l0?`3oool0oooo00P0oooo00<0
o`0o0?ooo`3oool0@`3oool002<0oooo00<000000?ooo`3oool02P3oool00`0003l0oooo0?ooo`0O
0?ooo`030000?`3oool0oooo09D0oooo00D000000?ooo`3oool0oooo0?l0?`0:0?ooo`030?l0?`3o
ool0oooo01X0oooo0P3o03l:0?ooo`030?l0?`3oool0oooo01X0oooo00<0o`0o0?ooo`3oool0203o
ool00`3o03l0oooo0?ooo`130?ooo`008`3oool00`000000oooo0?ooo`0;0?ooo`030000?`3oool0
oooo01d0oooo00<0000o0?ooo`3oool0UP3oool01@000000oooo0?ooo`3oool0o`0o00X0oooo00<0
o`0o0?ooo`3oool06`3oool00`3o03l0oooo0?ooo`080?ooo`030?l0?`3oool0oooo01X0oooo00<0
o`0o0?ooo`3oool0203oool00`3o03l0oooo0?ooo`130?ooo`008`3oool00`000000oooo0?ooo`0;
0?ooo`80000o7@3oool20000?iP0oooo00<000000?ooo`3oool00P3oool00`3o03l0oooo0?ooo`07
0?ooo`030?l0?`3oool0oooo01/0oooo00<0o`0o0?ooo`3oool01`3oool00`3o03l0oooo0?ooo`0K
0?ooo`030?l0?`3oool0oooo00P0oooo00<0o`0o0?ooo`3oool0@`3oool002<0oooo00<000000?oo
o`3oool0303oool20000?a/0oooo0P0003nI0?ooo`030000003oool0oooo0080oooo00<0o`0o0?oo
o`3oool01`3oool00`3o03l0oooo0?ooo`0K0?ooo`030?l0?`3oool0oooo00L0oooo00<0o`0o0?oo
o`3oool0703oool00`3o03l0oooo0?ooo`060?ooo`030?l0?`3oool0oooo04@0oooo000S0?ooo`03
0000003oool0oooo00d0oooo00<0000o0?ooo`3oool06@3oool00`0003l0oooo0?ooo`2H0?ooo`03
0000003oool0oooo0080oooo00<0o`0o0?ooo`3oool01P3oool00`3o03l0oooo0?ooo`0L0?ooo`80
o`0o203oool00`3o03l0oooo0?ooo`0L0?ooo`030?l0?`3oool0oooo00H0oooo00<0o`0o0?ooo`3o
ool0A03oool002<0oooo00<000000?ooo`3oool03P3oool00`0003l0oooo0?ooo`0G0?ooo`030000
?`3oool0oooo09T0oooo00<000000?ooo`3oool00P3oool20?l0?`L0oooo00<0o`0o0?ooo`3oool0
7@3oool00`3o03l0oooo0?ooo`050?ooo`80o`0o7P3oool00`3o03l0oooo0?ooo`060?ooo`030?l0
?`3oool0oooo04@0oooo000S0?ooo`030000003oool0oooo00h0oooo0P0003lG0?ooo`80000oV`3o
ool00`000000oooo0?ooo`030?ooo`030?l0?`3oool0oooo00D0oooo00<0o`0o0?ooo`3oool07@3o
ool00`3o03l0oooo0?ooo`050?ooo`030?l0?`3oool0oooo01d0oooo00<0o`0o0?ooo`3oool01@3o
ool20?l0?dH0oooo000S0?ooo`030000003oool0oooo00l0oooo0P0003lE0?ooo`80000oW03oool0
0`000000oooo0?ooo`030?ooo`030?l0?`3oool0oooo00D0oooo00<0o`0o0?ooo`3oool07@3oool0
0`3o03l0oooo0?ooo`050?ooo`030?l0?`3oool0oooo01h0oooo00<0o`0o0?ooo`3oool0103oool0
0`3o03l0oooo0?ooo`150?ooo`008`3oool00`000000oooo0?ooo`0@0?ooo`80000o4`3oool20000
?id0oooo00<000000?ooo`3oool00`3oool00`3o03l0oooo0?ooo`040?ooo`030?l0?`3oool0oooo
01l0oooo00<0o`0o0?ooo`3oool0103oool00`3o03l0oooo0?ooo`0N0?ooo`030?l0?`3oool0oooo
00@0oooo00<0o`0o0?ooo`3oool0A@3oool002<0oooo00<000000?ooo`3oool04@3oool20000?a40
oooo0P0003nN0?ooo`030000003oool0oooo00<0oooo0P3o03l50?ooo`030?l0?`3oool0oooo01l0
oooo00<0o`0o0?ooo`3oool00`3oool00`3o03l0oooo0?ooo`0O0?ooo`030?l0?`3oool0oooo00@0
oooo00<0o`0o0?ooo`3oool0A@3oool002<0oooo00<000000?ooo`3oool04P3oool20000?`l0oooo
0P0003nO0?ooo`030000003oool0oooo00@0oooo00<0o`0o0?ooo`3oool00P3oool20?l0?b40oooo
0P3o03l40?ooo`030?l0?`3oool0oooo0200oooo00<0o`0o0?ooo`3oool00P3oool00`3o03l0oooo
0?ooo`160?ooo`00703oool5@0000080oooo00<000000?ooo`3oool04`3oool30000?`/0oooo0P00
03nJ0?ooo`E000000P3oool00`000000oooo0?ooo`040?ooo`80o`0o0`3oool00`3o03l0oooo0?oo
o`0Q0?ooo`040?l0?`3oool0oooo0?ooo`80o`0o8P3oool00`3o03l0oooo0?ooo`020?ooo`030?l0
?`3oool0oooo04H0oooo000N0?ooo`03@000003oool0oooo0080oooo00<000000?ooo`3oool05@3o
ool30000?`L0oooo0`0003nM0?ooo`03@000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`3o03l0oooo0?ooo`020?l0?b<0oooo0P3o03l20?ooo`030?l0?`3oool0oooo0280oooo00@0
o`0o0?ooo`3oool0o`0oB@3oool001h0oooo00=000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0G0?ooo`T0000oW`3oool00d000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo103o
03lU0?ooo`@0o`0o903oool40?l0?dT0oooo000N0?ooo`03@000003oool0oooo0080oooo00<00000
0?ooo`3oool0_`3oool00d000000oooo0?ooo`020?ooo`030000003oool0oooo0:<0oooo000N0?oo
o`03@000003oool0oooo0080oooo00=000000?ooo`3oool0_`3oool00d000000oooo0?ooo`020?oo
o`03@000003oool0oooo0:<0oooo000M0?ooo`900000a@3oool2@0000:X0oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo001C0?ooo`900000503oool00d000000oooo0?ooo`060?oo
o`03@000003oool0oooo0:D0oooo0T00000D0?ooo`03@000003oool0oooo00H0oooo00=000000?oo
o`3oool0E03oool00240oooo0d00000a0?ooo`03@000003oool0oooo0100oooo00=000000?ooo`3o
ool0203oool00d000000oooo0?ooo`1b0?ooo`=00000<@3oool00d000000oooo0?ooo`0@0?ooo`03
@000003oool0oooo00P0oooo00=000000?ooo`3oool0D`3oool00280oooo00=000000?ooo`3oool0
8P3oool3@00000<0oooo0d0000030?ooo`=000001@3oool00d000000oooo0?ooo`05@00000@0oooo
00=000000?ooo`3oool00P3oool4@00000@0oooo00=000000?ooo`3oool0LP3oool00d000000oooo
0?ooo`0R0?ooo`=000000`3oool3@00000<0oooo0d0000050?ooo`03@000003oool0oooo00E00000
103oool014000000oooo0?ooo`3oool4@00000D0oooo00=000000?ooo`3oool0DP3oool001L0oooo
0T0000002@3ooom00000@00004000000oooo@000003ooom000000?ooo`03@00000H0oooo00=00000
0?ooo`3oool06P3oool00d000000oooo0?ooo`030?ooo`05@000003oool0oooo0?oood0000000P3o
ool00d000000oooo0?ooo`080?ooo`03@000003oool0oooo00@0oooo00=000000?ooo`3oool00P3o
ool3@00000D0oooo00=000000?ooo`3oool0I`3oool2@00000090?oood0000100000@000003ooom0
00000?oood000000oooo00=000001P3oool00d000000oooo0?ooo`0J0?ooo`03@000003oool0oooo
00<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003oool0oooo00P0oooo00=00000
0?ooo`3oool0103oool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo@00000@0oooo00=0
00000?ooo`3oool0DP3oool001L0oooo00A000000?ooo`3oool0oooo0T0000001P3ooom000000?oo
od000000oooo@0000080oooo00=000000?ooo`3oool0803oool00d000000oooo0?ooo`030?ooo`05
@000003oool0oooo0?oood0000000P3oool00d000000oooo0?ooo`080?ooo`03@000003oool0oooo
00@0oooo00=000000?ooo`3oool0103oool00d000000oooo0?ooo`030?ooo`03@000003oool0oooo
06L0oooo00A000000?ooo`3oool0oooo0T0000001P3ooom000000?oood000000oooo@0000080oooo
00=000000?ooo`3oool0803oool00d000000oooo0?ooo`030?ooo`05@000003oool0oooo0?oood00
00000P3oool00d000000oooo0?ooo`080?ooo`03@000003oool0oooo00@0oooo00=000000?ooo`3o
ool00P3oool014000000oooo0?oood0000040?ooo`03@000003oool0oooo0580oooo000H0?ooo`=0
000000P0oooo@000003ooom000000?oood000000oooo@0000080oooo00=000000?ooo`3oool0803o
ool2@00000<0oooo0T0000040?ooo`=000002P3oool00d000000oooo0?ooo`040?ooo`03@000003o
ool0oooo00<0oooo0T0000050?ooo`03@000003oool0oooo06P0oooo0d000000203ooom000000?oo
od000000oooo@000003ooom000000P3oool00d000000oooo0?ooo`0P0?ooo`9000000`3oool2@000
00@0oooo0d00000:0?ooo`03@000003oool0oooo00@0oooo00=000000?ooo`3oool00P3oool3@000
00D0oooo00=000000?ooo`3oool0DP3oool001P0oooo00A000000?oood000000oooo0T0000000`3o
oom000000?ooo`04@00002<0oooo00A000000?ooo`3ooom00000503oool00d000000oooo0?ooo`05
0?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool0J@3oool014000000oooo@000003o
ool2@00000030?oood000000oooo00A000008`3oool014000000oooo0?oood00000D0?ooo`03@000
003oool0oooo00D0oooo00E000000?ooo`3oool0oooo@00000060?ooo`03@000003oool0oooo05<0
oooo000I0?ooo`03@000003oool0oooo02/0oooo1D0000020?ooo`03@000003oool0oooo00h0oooo
0T0000080?ooo`03@000003oool0oooo00H0oooo00=000000?ooo`3oool0J`3oool00d000000oooo
0?ooo`0[0?ooo`E000000P3oool00d000000oooo0?ooo`0>0?ooo`900000203oool014000000oooo
@000040000050?ooo`03@000003oool0oooo05@0oooo000H0?ooo`900000a@3oool2@0000:l0oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {249, 0}} -> {-0.0500105, -0.03724, 
  0.00526322, 0.00526322}, {{9.5, 190.438}, {241.875, 
  130.063}} -> {-230.25, -0.259349, 7.89538, 0.012775}, {{208.5, 389.438}, {
  241.875, 130.063}} -> {-1934.22, -1.51012, 8.26278, 0.0267389}, {{9.5, 
  190.438}, {118.875, 7.0625}} -> {-289.931, -4.79901, 8.26278, 0.0267389}, {{
  208.5, 389.438}, {118.875, 7.0625}} -> {-1934.22, -4.79901, 8.26278, 
  0.0267389}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Eigen patterns",
  FormatType->InputForm,
  FontFamily->"Times New Roman"]], "Subsubsection",
  FormatType->InputForm],

Cell[TextData[{
  "\t",
  StyleBox["Let us compute the eigen pattern transform matrices by",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  FormatType->InputForm],

Cell["eigenMat=Table[eigenMatrix[sample1D[[i]],resolution],{i,4}];", "Input",
  CellLabel->"In[31]:=",
  FormatType->InputForm],

Cell[TextData[StyleBox[
"then we evaluate the eigen patterns, which are shown in Fig.2.",
  FormatType->InputForm,
  FontFamily->"Times New Roman"]], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["eigenPatternM=Table[eigenMat[[i]].sample1D[[i]],{i,4}];", "Input",
  CellLabel->"In[32]:=",
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
label={\"Fig.2(a)\",\"Fig.2(b)\",\"Fig.2(c)\",\"Fig.2(d)\"};
eigenM1DG=Table[ListPlot[eigenPatternM[[i+j]],
\tPlotRange->All,PlotJoined->True,
\tAxesLabel->{\"Reso.\",\"Amp.\"},
\tPlotLabel->StringForm[\"`1`\",label[[i+j]]],
\tDisplayFunction->Identity],{j,1,4,2},{i,0,1}];
Show[GraphicsArray[eigenM1DG],ImageSize->{400,250}];\
\>", "Input",
  CellLabel->"In[33]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 250 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0141895 0.00962001 -0.0258783 0.0101483 [
[.20659 .04281 -6 -9 ]
[.20659 .04281 6 0 ]
[.39899 .04281 -6 -9 ]
[.39899 .04281 6 0 ]
[.59139 .04281 -6 -9 ]
[.59139 .04281 6 0 ]
[.78379 .04281 -6 -9 ]
[.78379 .04281 6 0 ]
[.97619 .04281 -9 -9 ]
[.97619 .04281 9 0 ]
[1.025 .05531 0 -6.28125 ]
[1.025 .05531 34 6.28125 ]
[.00169 .07561 -12 -4.5 ]
[.00169 .07561 0 4.5 ]
[.00169 .17709 -12 -4.5 ]
[.00169 .17709 0 4.5 ]
[.00169 .27857 -12 -4.5 ]
[.00169 .27857 0 4.5 ]
[.00169 .38006 -12 -4.5 ]
[.00169 .38006 0 4.5 ]
[.00169 .48154 -12 -4.5 ]
[.00169 .48154 0 4.5 ]
[.00169 .58302 -12 -4.5 ]
[.00169 .58302 0 4.5 ]
[.01419 .64303 -14 0 ]
[.01419 .64303 14 12.5625 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20659 .05531 m
.20659 .06156 L
s
[(20)] .20659 .04281 0 1 Mshowa
.39899 .05531 m
.39899 .06156 L
s
[(40)] .39899 .04281 0 1 Mshowa
.59139 .05531 m
.59139 .06156 L
s
[(60)] .59139 .04281 0 1 Mshowa
.78379 .05531 m
.78379 .06156 L
s
[(80)] .78379 .04281 0 1 Mshowa
.97619 .05531 m
.97619 .06156 L
s
[(100)] .97619 .04281 0 1 Mshowa
.125 Mabswid
.06229 .05531 m
.06229 .05906 L
s
.11039 .05531 m
.11039 .05906 L
s
.15849 .05531 m
.15849 .05906 L
s
.25469 .05531 m
.25469 .05906 L
s
.30279 .05531 m
.30279 .05906 L
s
.35089 .05531 m
.35089 .05906 L
s
.44709 .05531 m
.44709 .05906 L
s
.49519 .05531 m
.49519 .05906 L
s
.54329 .05531 m
.54329 .05906 L
s
.63949 .05531 m
.63949 .05906 L
s
.68759 .05531 m
.68759 .05906 L
s
.73569 .05531 m
.73569 .05906 L
s
.83189 .05531 m
.83189 .05906 L
s
.87999 .05531 m
.87999 .05906 L
s
.92809 .05531 m
.92809 .05906 L
s
.25 Mabswid
0 .05531 m
1 .05531 L
s
gsave
1.025 .05531 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Reso) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
93.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.01419 .07561 m
.02044 .07561 L
s
[(10)] .00169 .07561 1 0 Mshowa
.01419 .17709 m
.02044 .17709 L
s
[(20)] .00169 .17709 1 0 Mshowa
.01419 .27857 m
.02044 .27857 L
s
[(30)] .00169 .27857 1 0 Mshowa
.01419 .38006 m
.02044 .38006 L
s
[(40)] .00169 .38006 1 0 Mshowa
.01419 .48154 m
.02044 .48154 L
s
[(50)] .00169 .48154 1 0 Mshowa
.01419 .58302 m
.02044 .58302 L
s
[(60)] .00169 .58302 1 0 Mshowa
.125 Mabswid
.01419 .0959 m
.01794 .0959 L
s
.01419 .1162 m
.01794 .1162 L
s
.01419 .1365 m
.01794 .1365 L
s
.01419 .15679 m
.01794 .15679 L
s
.01419 .19739 m
.01794 .19739 L
s
.01419 .21768 m
.01794 .21768 L
s
.01419 .23798 m
.01794 .23798 L
s
.01419 .25828 m
.01794 .25828 L
s
.01419 .29887 m
.01794 .29887 L
s
.01419 .31917 m
.01794 .31917 L
s
.01419 .33946 m
.01794 .33946 L
s
.01419 .35976 m
.01794 .35976 L
s
.01419 .40035 m
.01794 .40035 L
s
.01419 .42065 m
.01794 .42065 L
s
.01419 .44095 m
.01794 .44095 L
s
.01419 .46124 m
.01794 .46124 L
s
.01419 .50184 m
.01794 .50184 L
s
.01419 .52213 m
.01794 .52213 L
s
.01419 .54243 m
.01794 .54243 L
s
.01419 .56273 m
.01794 .56273 L
s
.01419 .03501 m
.01794 .03501 L
s
.01419 .01472 m
.01794 .01472 L
s
.01419 .60332 m
.01794 .60332 L
s
.25 Mabswid
.01419 0 m
.01419 .61803 L
s
gsave
.01419 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Amp) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
87.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 12.812500 moveto
(H) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 12.812500 moveto
(L) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.5 Mabswid
.02381 .05531 m
.03343 .01472 L
.04305 .05531 L
.05267 .05531 L
.06229 .01472 L
.07191 .05531 L
.08153 .01472 L
.09115 .05531 L
.10077 .05531 L
.11039 .01472 L
.12001 .05531 L
.12963 .01472 L
.13925 .05531 L
.14887 .05531 L
.15849 .01472 L
.16811 .05531 L
.17773 .01472 L
.18735 .05531 L
.19697 .05531 L
.20659 .01472 L
.21621 .05531 L
.22583 .05531 L
.23545 .01472 L
.24507 .05531 L
.25469 .05531 L
.26431 .01472 L
.27393 .05531 L
.28355 .01472 L
.29317 .05531 L
.30279 .05531 L
.31241 .05531 L
.32203 .01472 L
.33165 .05531 L
.34127 .05531 L
.35089 .01472 L
.36051 .05531 L
.37013 .05531 L
.37975 .01472 L
.38937 .05531 L
.39899 .05531 L
.40861 .05531 L
.41823 .01472 L
.42785 .05531 L
.43747 .05531 L
.44709 .05531 L
.45671 .01472 L
.46633 .05531 L
.47595 .05531 L
.48557 .05531 L
.49519 .05531 L
Mistroke
.50481 .05531 L
.51443 .01472 L
.52405 .05531 L
.53367 .05531 L
.54329 .05531 L
.55291 .05531 L
.56253 .05531 L
.57215 .05531 L
.58177 .05531 L
.59139 .05531 L
.60101 .05531 L
.61063 .05531 L
.62025 .05531 L
.62987 .05531 L
.63949 .05531 L
.64911 .05531 L
.65873 .05531 L
.66835 .0959 L
.67797 .05531 L
.68759 .05531 L
.69721 .05531 L
.70683 .0959 L
.71645 .05531 L
.72607 .05531 L
.73569 .0959 L
.74531 .05531 L
.75493 .0959 L
.76455 .05531 L
.77417 .0959 L
.78379 .05531 L
.79341 .0959 L
.80303 .0959 L
.81265 .0959 L
.82227 .0959 L
.83189 .0959 L
.84151 .0959 L
.85113 .0959 L
.86075 .0959 L
.87037 .1365 L
.87999 .1365 L
.88961 .0959 L
.89923 .1365 L
.90885 .17709 L
.91847 .1365 L
.92809 .21768 L
.93771 .17709 L
.94733 .25828 L
.95695 .29887 L
.96657 .46124 L
.97619 .60332 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0141895 0.00962001 -0.0251902 0.00997634 [
[.20659 .04212 -6 -9 ]
[.20659 .04212 6 0 ]
[.39899 .04212 -6 -9 ]
[.39899 .04212 6 0 ]
[.59139 .04212 -6 -9 ]
[.59139 .04212 6 0 ]
[.78379 .04212 -6 -9 ]
[.78379 .04212 6 0 ]
[.97619 .04212 -9 -9 ]
[.97619 .04212 9 0 ]
[1.025 .05462 0 -6.28125 ]
[1.025 .05462 34 6.28125 ]
[.00169 .07457 -12 -4.5 ]
[.00169 .07457 0 4.5 ]
[.00169 .17434 -12 -4.5 ]
[.00169 .17434 0 4.5 ]
[.00169 .2741 -12 -4.5 ]
[.00169 .2741 0 4.5 ]
[.00169 .37386 -12 -4.5 ]
[.00169 .37386 0 4.5 ]
[.00169 .47363 -12 -4.5 ]
[.00169 .47363 0 4.5 ]
[.00169 .57339 -12 -4.5 ]
[.00169 .57339 0 4.5 ]
[.01419 .64303 -14 0 ]
[.01419 .64303 14 12.5625 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20659 .05462 m
.20659 .06087 L
s
[(20)] .20659 .04212 0 1 Mshowa
.39899 .05462 m
.39899 .06087 L
s
[(40)] .39899 .04212 0 1 Mshowa
.59139 .05462 m
.59139 .06087 L
s
[(60)] .59139 .04212 0 1 Mshowa
.78379 .05462 m
.78379 .06087 L
s
[(80)] .78379 .04212 0 1 Mshowa
.97619 .05462 m
.97619 .06087 L
s
[(100)] .97619 .04212 0 1 Mshowa
.125 Mabswid
.06229 .05462 m
.06229 .05837 L
s
.11039 .05462 m
.11039 .05837 L
s
.15849 .05462 m
.15849 .05837 L
s
.25469 .05462 m
.25469 .05837 L
s
.30279 .05462 m
.30279 .05837 L
s
.35089 .05462 m
.35089 .05837 L
s
.44709 .05462 m
.44709 .05837 L
s
.49519 .05462 m
.49519 .05837 L
s
.54329 .05462 m
.54329 .05837 L
s
.63949 .05462 m
.63949 .05837 L
s
.68759 .05462 m
.68759 .05837 L
s
.73569 .05462 m
.73569 .05837 L
s
.83189 .05462 m
.83189 .05837 L
s
.87999 .05462 m
.87999 .05837 L
s
.92809 .05462 m
.92809 .05837 L
s
.25 Mabswid
0 .05462 m
1 .05462 L
s
gsave
1.025 .05462 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Reso) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
93.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.01419 .07457 m
.02044 .07457 L
s
[(10)] .00169 .07457 1 0 Mshowa
.01419 .17434 m
.02044 .17434 L
s
[(20)] .00169 .17434 1 0 Mshowa
.01419 .2741 m
.02044 .2741 L
s
[(30)] .00169 .2741 1 0 Mshowa
.01419 .37386 m
.02044 .37386 L
s
[(40)] .00169 .37386 1 0 Mshowa
.01419 .47363 m
.02044 .47363 L
s
[(50)] .00169 .47363 1 0 Mshowa
.01419 .57339 m
.02044 .57339 L
s
[(60)] .00169 .57339 1 0 Mshowa
.125 Mabswid
.01419 .09453 m
.01794 .09453 L
s
.01419 .11448 m
.01794 .11448 L
s
.01419 .13443 m
.01794 .13443 L
s
.01419 .15438 m
.01794 .15438 L
s
.01419 .19429 m
.01794 .19429 L
s
.01419 .21424 m
.01794 .21424 L
s
.01419 .23419 m
.01794 .23419 L
s
.01419 .25415 m
.01794 .25415 L
s
.01419 .29405 m
.01794 .29405 L
s
.01419 .31401 m
.01794 .31401 L
s
.01419 .33396 m
.01794 .33396 L
s
.01419 .35391 m
.01794 .35391 L
s
.01419 .39382 m
.01794 .39382 L
s
.01419 .41377 m
.01794 .41377 L
s
.01419 .43372 m
.01794 .43372 L
s
.01419 .45367 m
.01794 .45367 L
s
.01419 .49358 m
.01794 .49358 L
s
.01419 .51353 m
.01794 .51353 L
s
.01419 .53348 m
.01794 .53348 L
s
.01419 .55344 m
.01794 .55344 L
s
.01419 .03467 m
.01794 .03467 L
s
.01419 .01472 m
.01794 .01472 L
s
.01419 .59334 m
.01794 .59334 L
s
.01419 .6133 m
.01794 .6133 L
s
.25 Mabswid
.01419 0 m
.01419 .61803 L
s
gsave
.01419 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Amp) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
87.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 12.812500 moveto
(H) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 12.812500 moveto
(L) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.5 Mabswid
.02381 .05462 m
.03343 .01472 L
.04305 .05462 L
.05267 .05462 L
.06229 .01472 L
.07191 .05462 L
.08153 .01472 L
.09115 .05462 L
.10077 .05462 L
.11039 .01472 L
.12001 .05462 L
.12963 .01472 L
.13925 .05462 L
.14887 .05462 L
.15849 .01472 L
.16811 .05462 L
.17773 .01472 L
.18735 .05462 L
.19697 .05462 L
.20659 .01472 L
.21621 .05462 L
.22583 .05462 L
.23545 .01472 L
.24507 .05462 L
.25469 .05462 L
.26431 .01472 L
.27393 .05462 L
.28355 .01472 L
.29317 .05462 L
.30279 .05462 L
.31241 .05462 L
.32203 .01472 L
.33165 .05462 L
.34127 .05462 L
.35089 .01472 L
.36051 .05462 L
.37013 .05462 L
.37975 .01472 L
.38937 .05462 L
.39899 .05462 L
.40861 .05462 L
.41823 .01472 L
.42785 .05462 L
.43747 .05462 L
.44709 .05462 L
.45671 .01472 L
.46633 .05462 L
.47595 .05462 L
.48557 .05462 L
.49519 .05462 L
Mistroke
.50481 .05462 L
.51443 .01472 L
.52405 .05462 L
.53367 .05462 L
.54329 .05462 L
.55291 .05462 L
.56253 .05462 L
.57215 .05462 L
.58177 .05462 L
.59139 .05462 L
.60101 .05462 L
.61063 .05462 L
.62025 .05462 L
.62987 .05462 L
.63949 .05462 L
.64911 .05462 L
.65873 .05462 L
.66835 .09453 L
.67797 .05462 L
.68759 .05462 L
.69721 .05462 L
.70683 .09453 L
.71645 .05462 L
.72607 .05462 L
.73569 .09453 L
.74531 .05462 L
.75493 .09453 L
.76455 .05462 L
.77417 .09453 L
.78379 .05462 L
.79341 .09453 L
.80303 .09453 L
.81265 .09453 L
.82227 .09453 L
.83189 .09453 L
.84151 .09453 L
.85113 .09453 L
.86075 .09453 L
.87037 .13443 L
.87999 .13443 L
.88961 .09453 L
.89923 .13443 L
.90885 .17434 L
.91847 .13443 L
.92809 .21424 L
.93771 .17434 L
.94733 .25415 L
.95695 .29405 L
.96657 .45367 L
.97619 .60332 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0141895 0.00962001 -0.0258783 0.0101483 [
[.20659 .04281 -6 -9 ]
[.20659 .04281 6 0 ]
[.39899 .04281 -6 -9 ]
[.39899 .04281 6 0 ]
[.59139 .04281 -6 -9 ]
[.59139 .04281 6 0 ]
[.78379 .04281 -6 -9 ]
[.78379 .04281 6 0 ]
[.97619 .04281 -9 -9 ]
[.97619 .04281 9 0 ]
[1.025 .05531 0 -6.28125 ]
[1.025 .05531 34 6.28125 ]
[.00169 .07561 -12 -4.5 ]
[.00169 .07561 0 4.5 ]
[.00169 .17709 -12 -4.5 ]
[.00169 .17709 0 4.5 ]
[.00169 .27857 -12 -4.5 ]
[.00169 .27857 0 4.5 ]
[.00169 .38006 -12 -4.5 ]
[.00169 .38006 0 4.5 ]
[.00169 .48154 -12 -4.5 ]
[.00169 .48154 0 4.5 ]
[.00169 .58302 -12 -4.5 ]
[.00169 .58302 0 4.5 ]
[.01419 .64303 -14 0 ]
[.01419 .64303 14 12.5625 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20659 .05531 m
.20659 .06156 L
s
[(20)] .20659 .04281 0 1 Mshowa
.39899 .05531 m
.39899 .06156 L
s
[(40)] .39899 .04281 0 1 Mshowa
.59139 .05531 m
.59139 .06156 L
s
[(60)] .59139 .04281 0 1 Mshowa
.78379 .05531 m
.78379 .06156 L
s
[(80)] .78379 .04281 0 1 Mshowa
.97619 .05531 m
.97619 .06156 L
s
[(100)] .97619 .04281 0 1 Mshowa
.125 Mabswid
.06229 .05531 m
.06229 .05906 L
s
.11039 .05531 m
.11039 .05906 L
s
.15849 .05531 m
.15849 .05906 L
s
.25469 .05531 m
.25469 .05906 L
s
.30279 .05531 m
.30279 .05906 L
s
.35089 .05531 m
.35089 .05906 L
s
.44709 .05531 m
.44709 .05906 L
s
.49519 .05531 m
.49519 .05906 L
s
.54329 .05531 m
.54329 .05906 L
s
.63949 .05531 m
.63949 .05906 L
s
.68759 .05531 m
.68759 .05906 L
s
.73569 .05531 m
.73569 .05906 L
s
.83189 .05531 m
.83189 .05906 L
s
.87999 .05531 m
.87999 .05906 L
s
.92809 .05531 m
.92809 .05906 L
s
.25 Mabswid
0 .05531 m
1 .05531 L
s
gsave
1.025 .05531 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Reso) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
93.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.01419 .07561 m
.02044 .07561 L
s
[(10)] .00169 .07561 1 0 Mshowa
.01419 .17709 m
.02044 .17709 L
s
[(20)] .00169 .17709 1 0 Mshowa
.01419 .27857 m
.02044 .27857 L
s
[(30)] .00169 .27857 1 0 Mshowa
.01419 .38006 m
.02044 .38006 L
s
[(40)] .00169 .38006 1 0 Mshowa
.01419 .48154 m
.02044 .48154 L
s
[(50)] .00169 .48154 1 0 Mshowa
.01419 .58302 m
.02044 .58302 L
s
[(60)] .00169 .58302 1 0 Mshowa
.125 Mabswid
.01419 .0959 m
.01794 .0959 L
s
.01419 .1162 m
.01794 .1162 L
s
.01419 .1365 m
.01794 .1365 L
s
.01419 .15679 m
.01794 .15679 L
s
.01419 .19739 m
.01794 .19739 L
s
.01419 .21768 m
.01794 .21768 L
s
.01419 .23798 m
.01794 .23798 L
s
.01419 .25828 m
.01794 .25828 L
s
.01419 .29887 m
.01794 .29887 L
s
.01419 .31917 m
.01794 .31917 L
s
.01419 .33946 m
.01794 .33946 L
s
.01419 .35976 m
.01794 .35976 L
s
.01419 .40035 m
.01794 .40035 L
s
.01419 .42065 m
.01794 .42065 L
s
.01419 .44095 m
.01794 .44095 L
s
.01419 .46124 m
.01794 .46124 L
s
.01419 .50184 m
.01794 .50184 L
s
.01419 .52213 m
.01794 .52213 L
s
.01419 .54243 m
.01794 .54243 L
s
.01419 .56273 m
.01794 .56273 L
s
.01419 .03501 m
.01794 .03501 L
s
.01419 .01472 m
.01794 .01472 L
s
.01419 .60332 m
.01794 .60332 L
s
.25 Mabswid
.01419 0 m
.01419 .61803 L
s
gsave
.01419 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Amp) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
87.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 12.812500 moveto
(H) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 12.812500 moveto
(L) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.5 Mabswid
.02381 .05531 m
.03343 .01472 L
.04305 .05531 L
.05267 .05531 L
.06229 .01472 L
.07191 .05531 L
.08153 .01472 L
.09115 .05531 L
.10077 .05531 L
.11039 .01472 L
.12001 .05531 L
.12963 .01472 L
.13925 .05531 L
.14887 .05531 L
.15849 .01472 L
.16811 .05531 L
.17773 .01472 L
.18735 .05531 L
.19697 .05531 L
.20659 .01472 L
.21621 .05531 L
.22583 .05531 L
.23545 .01472 L
.24507 .05531 L
.25469 .05531 L
.26431 .01472 L
.27393 .05531 L
.28355 .01472 L
.29317 .05531 L
.30279 .05531 L
.31241 .05531 L
.32203 .01472 L
.33165 .05531 L
.34127 .05531 L
.35089 .01472 L
.36051 .05531 L
.37013 .05531 L
.37975 .01472 L
.38937 .05531 L
.39899 .05531 L
.40861 .05531 L
.41823 .01472 L
.42785 .05531 L
.43747 .05531 L
.44709 .05531 L
.45671 .01472 L
.46633 .05531 L
.47595 .05531 L
.48557 .05531 L
.49519 .05531 L
Mistroke
.50481 .05531 L
.51443 .01472 L
.52405 .05531 L
.53367 .05531 L
.54329 .05531 L
.55291 .05531 L
.56253 .05531 L
.57215 .05531 L
.58177 .05531 L
.59139 .05531 L
.60101 .05531 L
.61063 .05531 L
.62025 .05531 L
.62987 .05531 L
.63949 .05531 L
.64911 .05531 L
.65873 .05531 L
.66835 .0959 L
.67797 .05531 L
.68759 .05531 L
.69721 .05531 L
.70683 .0959 L
.71645 .05531 L
.72607 .05531 L
.73569 .0959 L
.74531 .05531 L
.75493 .0959 L
.76455 .05531 L
.77417 .0959 L
.78379 .05531 L
.79341 .0959 L
.80303 .0959 L
.81265 .0959 L
.82227 .0959 L
.83189 .0959 L
.84151 .0959 L
.85113 .0959 L
.86075 .0959 L
.87037 .1365 L
.87999 .1365 L
.88961 .0959 L
.89923 .1365 L
.90885 .17709 L
.91847 .1365 L
.92809 .21768 L
.93771 .17709 L
.94733 .25828 L
.95695 .29887 L
.96657 .46124 L
.97619 .60332 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0141895 0.00962001 -0.0258783 0.0101483 [
[.20659 .04281 -6 -9 ]
[.20659 .04281 6 0 ]
[.39899 .04281 -6 -9 ]
[.39899 .04281 6 0 ]
[.59139 .04281 -6 -9 ]
[.59139 .04281 6 0 ]
[.78379 .04281 -6 -9 ]
[.78379 .04281 6 0 ]
[.97619 .04281 -9 -9 ]
[.97619 .04281 9 0 ]
[1.025 .05531 0 -6.28125 ]
[1.025 .05531 34 6.28125 ]
[.00169 .07561 -12 -4.5 ]
[.00169 .07561 0 4.5 ]
[.00169 .17709 -12 -4.5 ]
[.00169 .17709 0 4.5 ]
[.00169 .27857 -12 -4.5 ]
[.00169 .27857 0 4.5 ]
[.00169 .38006 -12 -4.5 ]
[.00169 .38006 0 4.5 ]
[.00169 .48154 -12 -4.5 ]
[.00169 .48154 0 4.5 ]
[.00169 .58302 -12 -4.5 ]
[.00169 .58302 0 4.5 ]
[.01419 .64303 -14 0 ]
[.01419 .64303 14 12.5625 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.20659 .05531 m
.20659 .06156 L
s
[(20)] .20659 .04281 0 1 Mshowa
.39899 .05531 m
.39899 .06156 L
s
[(40)] .39899 .04281 0 1 Mshowa
.59139 .05531 m
.59139 .06156 L
s
[(60)] .59139 .04281 0 1 Mshowa
.78379 .05531 m
.78379 .06156 L
s
[(80)] .78379 .04281 0 1 Mshowa
.97619 .05531 m
.97619 .06156 L
s
[(100)] .97619 .04281 0 1 Mshowa
.125 Mabswid
.06229 .05531 m
.06229 .05906 L
s
.11039 .05531 m
.11039 .05906 L
s
.15849 .05531 m
.15849 .05906 L
s
.25469 .05531 m
.25469 .05906 L
s
.30279 .05531 m
.30279 .05906 L
s
.35089 .05531 m
.35089 .05906 L
s
.44709 .05531 m
.44709 .05906 L
s
.49519 .05531 m
.49519 .05906 L
s
.54329 .05531 m
.54329 .05906 L
s
.63949 .05531 m
.63949 .05906 L
s
.68759 .05531 m
.68759 .05906 L
s
.73569 .05531 m
.73569 .05906 L
s
.83189 .05531 m
.83189 .05906 L
s
.87999 .05531 m
.87999 .05906 L
s
.92809 .05531 m
.92809 .05906 L
s
.25 Mabswid
0 .05531 m
1 .05531 L
s
gsave
1.025 .05531 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Reso) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
93.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.01419 .07561 m
.02044 .07561 L
s
[(10)] .00169 .07561 1 0 Mshowa
.01419 .17709 m
.02044 .17709 L
s
[(20)] .00169 .17709 1 0 Mshowa
.01419 .27857 m
.02044 .27857 L
s
[(30)] .00169 .27857 1 0 Mshowa
.01419 .38006 m
.02044 .38006 L
s
[(40)] .00169 .38006 1 0 Mshowa
.01419 .48154 m
.02044 .48154 L
s
[(50)] .00169 .48154 1 0 Mshowa
.01419 .58302 m
.02044 .58302 L
s
[(60)] .00169 .58302 1 0 Mshowa
.125 Mabswid
.01419 .0959 m
.01794 .0959 L
s
.01419 .1162 m
.01794 .1162 L
s
.01419 .1365 m
.01794 .1365 L
s
.01419 .15679 m
.01794 .15679 L
s
.01419 .19739 m
.01794 .19739 L
s
.01419 .21768 m
.01794 .21768 L
s
.01419 .23798 m
.01794 .23798 L
s
.01419 .25828 m
.01794 .25828 L
s
.01419 .29887 m
.01794 .29887 L
s
.01419 .31917 m
.01794 .31917 L
s
.01419 .33946 m
.01794 .33946 L
s
.01419 .35976 m
.01794 .35976 L
s
.01419 .40035 m
.01794 .40035 L
s
.01419 .42065 m
.01794 .42065 L
s
.01419 .44095 m
.01794 .44095 L
s
.01419 .46124 m
.01794 .46124 L
s
.01419 .50184 m
.01794 .50184 L
s
.01419 .52213 m
.01794 .52213 L
s
.01419 .54243 m
.01794 .54243 L
s
.01419 .56273 m
.01794 .56273 L
s
.01419 .03501 m
.01794 .03501 L
s
.01419 .01472 m
.01794 .01472 L
s
.01419 .60332 m
.01794 .60332 L
s
.25 Mabswid
.01419 0 m
.01419 .61803 L
s
gsave
.01419 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Amp) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
87.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 12.812500 moveto
(H) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 12.812500 moveto
(L) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.5 Mabswid
.02381 .05531 m
.03343 .01472 L
.04305 .05531 L
.05267 .05531 L
.06229 .01472 L
.07191 .05531 L
.08153 .01472 L
.09115 .05531 L
.10077 .05531 L
.11039 .01472 L
.12001 .05531 L
.12963 .01472 L
.13925 .05531 L
.14887 .05531 L
.15849 .01472 L
.16811 .05531 L
.17773 .01472 L
.18735 .05531 L
.19697 .05531 L
.20659 .01472 L
.21621 .05531 L
.22583 .05531 L
.23545 .01472 L
.24507 .05531 L
.25469 .05531 L
.26431 .01472 L
.27393 .05531 L
.28355 .01472 L
.29317 .05531 L
.30279 .05531 L
.31241 .05531 L
.32203 .01472 L
.33165 .05531 L
.34127 .05531 L
.35089 .01472 L
.36051 .05531 L
.37013 .05531 L
.37975 .01472 L
.38937 .05531 L
.39899 .05531 L
.40861 .05531 L
.41823 .01472 L
.42785 .05531 L
.43747 .05531 L
.44709 .05531 L
.45671 .01472 L
.46633 .05531 L
.47595 .05531 L
.48557 .05531 L
.49519 .05531 L
Mistroke
.50481 .05531 L
.51443 .01472 L
.52405 .05531 L
.53367 .05531 L
.54329 .05531 L
.55291 .05531 L
.56253 .05531 L
.57215 .05531 L
.58177 .05531 L
.59139 .05531 L
.60101 .05531 L
.61063 .05531 L
.62025 .05531 L
.62987 .05531 L
.63949 .05531 L
.64911 .05531 L
.65873 .05531 L
.66835 .0959 L
.67797 .05531 L
.68759 .05531 L
.69721 .05531 L
.70683 .0959 L
.71645 .05531 L
.72607 .05531 L
.73569 .0959 L
.74531 .05531 L
.75493 .0959 L
.76455 .05531 L
.77417 .0959 L
.78379 .05531 L
.79341 .0959 L
.80303 .0959 L
.81265 .0959 L
.82227 .0959 L
.83189 .0959 L
.84151 .0959 L
.85113 .0959 L
.86075 .0959 L
.87037 .1365 L
.87999 .1365 L
.88961 .0959 L
.89923 .1365 L
.90885 .17709 L
.91847 .1365 L
.92809 .21768 L
.93771 .17709 L
.94733 .25828 L
.95695 .29887 L
.96657 .46124 L
.97619 .60332 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[33]:=",
  ImageSize->{400, 250},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000nR000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00;03oool3@00000<0oooo00=0
00000?ooo`3oool04P3oool3@0000080oooo00=000000?ooo`3oool0403oool2@00000@0oooo00=0
00000?ooo`3oool04@3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00d0oooo1D00
00020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool0EP3oool3@00000<0oooo00=0
00000?ooo`3oool04P3oool3@0000080oooo00=000000?ooo`3oool0403oool2@00000@0oooo00=0
00000?ooo`3oool04@3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00d0oooo1D00
00020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool0;03oool002`0oooo00=00000
0?ooo`3oool00P3oool00d000000oooo@000000D0?ooo`06@000003oool0oooo@000003ooom00000
4@3oool00d000000oooo@00000020?ooo`03@000003ooom000000140oooo00=000000?oood000000
0P3oool00d000000oooo@000000@0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?oo
o`03@000003ooom0000005L0oooo00=000000?ooo`3oool00P3oool00d000000oooo@000000D0?oo
o`06@000003oool0oooo@000003ooom000004@3oool00d000000oooo@00000020?ooo`03@000003o
oom000000140oooo00=000000?oood0000000P3oool00d000000oooo@000000@0?ooo`07@000003o
ool0oooo0?oood000000oooo@00000020?ooo`03@000003ooom0000002d0oooo000]0?ooo`07@000
003oool0oooo0?oood000000oooo@000000B0?ooo`A0000000@0oooo@000003ooom000004@3oool0
0d000000oooo@00000020?ooo`03@000003ooom000000140oooo00=000000?oood0000000P3oool0
0d000000oooo@000000@0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000
003ooom0000005P0oooo00M000000?ooo`3oool0oooo@000003ooom000000180oooo14000000103o
oom000000?oood00000A0?ooo`03@000003ooom000000080oooo00=000000?oood0000004@3oool0
0d000000oooo@00000020?ooo`03@000003ooom000000100oooo00M000000?ooo`3oool0oooo@000
003ooom000000080oooo00=000000?oood000000;@3oool001L0oooo00<000000?ooo`3oool04`3o
ool01d000000oooo0?ooo`3ooom000000?oood0000004P3oool00d000000oooo@00000020?ooo`03
@000003ooom000000140oooo0T0000030?ooo`03@000003ooom000000180oooo00M000000?ooo`3o
ool0oooo@000003ooom000000100oooo00M000000?ooo`3oool0oooo@000003ooom000000080oooo
00=000000?oood000000@P3oool00`000000oooo0?ooo`0C0?ooo`07@000003oool0oooo0?oood00
0000oooo@000000B0?ooo`03@000003ooom000000080oooo00=000000?oood0000004@3oool2@000
00<0oooo00=000000?oood0000004P3oool01d000000oooo0?ooo`3ooom000000?oood000000403o
ool01d000000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@000000]0?ooo`00
5`3oool00`000000oooo0?ooo`0B0?ooo`03@000003ooom000000080oooo00=000000?oood000000
4`3oool2@0000080oooo00=000000?oood0000004@3oool00d000000oooo0?ooo`020?ooo`03@000
003ooom000000140oooo00=000000?oood0000000P3oool00d000000oooo@000000@0?ooo`07@000
003oool0oooo0?oood000000oooo@00000020?ooo`03@000003ooom000000480oooo00<000000?oo
o`3oool04P3oool00d000000oooo@00000020?ooo`03@000003ooom0000001<0oooo0T0000020?oo
o`03@000003ooom000000140oooo00=000000?ooo`3oool00P3oool00d000000oooo@000000A0?oo
o`03@000003ooom000000080oooo00=000000?oood000000403oool01d000000oooo0?ooo`3ooom0
00000?oood0000000P3oool00d000000oooo@000000]0?ooo`005`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool010000000oooo
0?ooo`0000020?ooo`050000003ooom000000?ooo`0000000`3oool00`000000oooo000000040?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`00001000000?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`9000000`3oool0
0d000000oooo0?ooo`0A0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool03P3oool2
@00000@0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`110?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`040000
003oool0oooo00000080oooo00D000000?oood000000oooo000000030?ooo`030000003oool00000
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`03000004000000oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo0T000003
0?ooo`03@000003oool0oooo0140oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`0>
0?ooo`900000103oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo02`0oooo000G0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000
00030?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0880oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0000000<0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0K@3oool001L0oooo00@000000?ooo`00000000000P3oool2000000040?ooo`000000oooo
0?ooo`80000000<0oooo0000003oool00P3oool010000000oooo0000000000020?ooo`8000000P3o
ool01P000000oooo0?ooo`3oool000000?ooo`8000000`3oool200000080oooo0P0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0880oooo00@000000?ooo`00000000000P3oool2000000040?ooo`000000oooo
0?ooo`80000000<0oooo0000003oool00P3oool010000000oooo0000000000020?ooo`8000000P3o
ool01P000000oooo0?ooo`3oool000000?ooo`8000000`3oool200000080oooo0P0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo06d0oooo000G0?ooo`040000003oool000000?ooo`80000000h0oooo00000000
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`80000000l0oooo0000
00000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`0000000P3oool00`000000oooo000000050?ooo`030000003oool0000004<0oooo0d000000103o
oom000000?ooo`3oool2@0000080oooo0T0000040?ooo`9000001`3oool00d000000oooo0?ooo`0S
0?ooo`040000003oool000000?ooo`80000000h0oooo000000000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`80000000l0oooo000000000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000000P3oool00`000000oooo
000000050?ooo`030000003oool0000004<0oooo0d000000103ooom000000?ooo`3oool2@0000080
oooo0T0000040?ooo`9000001`3oool00d000000oooo0?ooo`0>0?ooo`005`3oool200000080oooo
0P0000020?ooo`040000003oool0000000000080oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo0P0000020?ooo`80000000H0oooo0000003oool000000?ooo`0000020?ooo`030000
003oool000000080oooo0P0000020?ooo`80000000L0oooo0000003oool0oooo0000003oool00000
0080oooo00<000000?ooo`0000001@3oool00`000000oooo000000140?ooo`06@000003oool0oooo
@000003ooom000001P3oool014000000oooo0?oood0000020?ooo`03@000003oool0oooo02X0oooo
0P0000020?ooo`8000000P3oool010000000oooo0000000000020?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`8000000P3oool2000000060?ooo`000000oooo0000003oool00000
0P3oool00`000000oooo000000020?ooo`8000000P3oool2000000070?ooo`000000oooo0?ooo`00
0000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`000000A03oool01T00
0000oooo0?oood000000oooo@00000H0oooo00A000000?ooo`3ooom000000P3oool00d000000oooo
0?ooo`0E0?ooo`005@3ooon400000003@000003oool0oooo00<0oooo0d0000020?ooo`=000000`3o
ool01D000000oooo0?ooo`3ooom000000080oooo00=000000?ooo`3oool0:03ooon400000003@000
003oool0oooo00<0oooo0d0000020?ooo`=000000`3oool01D000000oooo0?ooo`3ooom000000080
oooo00=000000?ooo`3oool05@3oool000/0oooo1D0000020?ooo`03@000003oool0oooo0080oooo
00<000000?ooo`3oool05P3oool00d000000oooo0?ooo`0G0?ooo`03@000003oool0oooo01H0oooo
00=000000?ooo`3oool01P3oool00`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool0000001T0oooo00=000000?ooo`3oool01P3oool01D00
0000oooo0?oood000000oooo00=000000`3oool2@00000<0oooo0T00000Q0?ooo`E000000P3oool0
0d000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo00=000000?ooo`3oool05`3oool0
0d000000oooo0?ooo`0F0?ooo`03@000003oool0oooo00H0oooo00<000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000I0?ooo`03@000
003oool0oooo00H0oooo00E000000?ooo`3ooom000000?ooo`03@00000<0oooo0T0000030?ooo`90
0000603oool000d0oooo00M000000?ooo`3oool0oooo@000003ooom0000000<0oooo00<000000?oo
o`3oool0DP3oool00`000000oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000
003oool2000000030?ooo`000000oooo0240oooo00A000000?ooo`3ooom00000<@3oool01d000000
oooo0?ooo`3ooom000000?oood0000000`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
00000080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`80000000<0oooo0000003o
ool08@3oool014000000oooo0?oood00000V0?ooo`003@3oool01d000000oooo0?ooo`3ooom00000
0?oood0000000`3oool00`00001000000?ooo`1C0?ooo`030000003oool0oooo0080oooo00H00000
0?ooo`3oool0oooo0000003oool2000000040?ooo`000000oooo00000200oooo1400000b0?ooo`07
@000003oool0oooo0?oood000000oooo@00000030?ooo`03000004000000oooo05<0oooo00<00000
0?ooo`3oool00P3oool01P000000oooo0?ooo`3oool000000?ooo`80000000@0oooo0000003oool0
0000803oool4@00002L0oooo000=0?ooo`07@000003oool0oooo0?oood000000oooo@00000030?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool00`000000oooo0000001F0?ooo`07@000003oool0oooo0?oood000000
oooo@00000030?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool00P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0000001;0?ooo`003@3oool01d00
0000oooo0?ooo`3ooom000000?oood0000000`3oool00`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`00
00002@0000030?ooo`030000003oool0oooo04L0oooo00M000000?ooo`3oool0oooo@000003ooom0
000000<0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`020?ooo`070000003oool0
oooo0?ooo`000000oooo000000020?ooo`030000003oool0000000T000000`3oool00`000000oooo
0?ooo`0l0?ooo`00303oool2@00000@0oooo00=000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1/0?ooo`050000003oool0oooo0?ooo`000000B03oool2@00000@0oooo00=000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1/0?ooo`050000003oool0oooo0?ooo`000000?P3oool001L0oooo
00<000000?ooo`3oool0K@3oool010000000oooo0?ooo`00001C0?ooo`030000003oool0oooo06d0
oooo00@000000?ooo`3oool00000?P3oool001L0oooo00<000000?ooo`3oool0K@3oool00`000000
oooo0?ooo`0200000580oooo00<000000?ooo`3oool0K@3oool01@000000oooo0000003oool00000
03d0oooo000G0?ooo`030000003oool0oooo06d0oooo00D000000?ooo`000000oooo0000001B0?oo
o`030000003oool0oooo06h0oooo0P0000000`3oool000000?ooo`0l0?ooo`005`3oool00`000000
oooo0?ooo`1^0?ooo`80000000<0oooo0000003oool0D@3oool00`000000oooo0?ooo`1^0?ooo`80
000000D0oooo0000003oool0oooo0000000j0?ooo`005`3oool00`000000oooo0?ooo`1^0?ooo`80
000000D0oooo0000003oool0oooo0000001?0?ooo`030000003oool0oooo0740oooo00@000000?oo
o`3oool00000>P3oool001L0oooo00<000000?ooo`3oool0L@3oool010000000oooo0?ooo`00001?
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`000000>P3oool001L0oooo00<000000?oo
o`3oool0LP3oool00`000000oooo0000001?0?ooo`030000003oool0oooo0780oooo00<000000?oo
o`000000>P3oool000`0oooo0d0000030?ooo`03@000003oool0oooo0080oooo00<000000?ooo`3o
ool0LP3oool3000004@0oooo0d0000030?ooo`03@000003oool0oooo0080oooo00<000000?ooo`3o
ool0LP3oool3000003X0oooo000<0?ooo`03@000003oool0oooo0080oooo00=000000?oood000000
0`3oool00`000000oooo0?ooo`1c0?ooo`800000A03oool00d000000oooo0?ooo`020?ooo`03@000
003ooom0000000<0oooo00<000000?ooo`3oool0L`3oool2000003X0oooo000=0?ooo`07@000003o
ool0oooo0?oood000000oooo@00000030?ooo`03000004000000oooo07<0oooo00@000000?ooo`00
00000000@`3oool01d000000oooo0?ooo`3ooom000000?oood0000000`3oool00`00001000000?oo
o`1c0?ooo`040000003oool00000000003P0oooo000=0?ooo`07@000003oool0oooo0?oood000000
oooo@00000030?ooo`030000003oool0oooo07D0oooo0P0000130?ooo`07@000003oool0oooo0?oo
od000000oooo@00000030?ooo`030000003oool0oooo07D0oooo0P00000h0?ooo`00303oool00d00
0000oooo@00000020?ooo`03@000003ooom0000000<0oooo00<000000?ooo`3oool0M@3oool20000
0480oooo00=000000?oood0000000P3oool00d000000oooo@00000030?ooo`030000003oool0oooo
07D0oooo0P00000h0?ooo`003@3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080
oooo00<000000?ooo`3oool0M@3oool00`000000oooo000000120?ooo`03@000003oool0oooo0080
oooo00=000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0000003L0
oooo000G0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`000000C03oool00`000000oooo
0?ooo`1e0?ooo`030000003oool0000003L0oooo000G0?ooo`030000003oool0oooo07D0oooo00<0
00000?ooo`000000C03oool00`000000oooo0?ooo`1e0?ooo`030000003oool0000003L0oooo000G
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo03D0oooo000G0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03D0oooo000G0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo03@0oooo000G0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03@0oooo000G0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo03@0oooo000<0?ooo`900000103oool00d000000oooo0?ooo`020?ooo`030000003oool0
oooo07P0oooo00<000000?ooo`3oool0?P3oool2@00000@0oooo00=000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03@0oooo000>0?ooo`06@000003oool0oooo
@000003ooom000000`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0400oooo00I0
00000?ooo`3ooom000000?oood0000030?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool0=03oool000d0oooo00M000000?ooo`3oool0oooo@000003ooom0000000<0oooo00<00000@000
003oool0N03oool00`000000oooo0?ooo`0o0?ooo`07@000003oool0oooo0?oood000000oooo@000
00030?ooo`03000004000000oooo07T0oooo00<000000?ooo`3oool0<`3oool000h0oooo00I00000
0?ooo`3ooom000000?oood0000030?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
?`3oool01T000000oooo0?oood000000oooo@00000<0oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`0c0?ooo`00303oool00d000000oooo@00000020?ooo`03@000003ooom0000000<0
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`03@000003ooom000000080
oooo00=000000?oood0000000`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo03<0
oooo000=0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo03h0oooo00=000000?ooo`3oool00P3oool00d000000oooo
0?ooo`020?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0<`3oool001L0oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool0<`3oool001L0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`18
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0<`3oool001L0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool0<`3oool001L0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0<`3oool001L0oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
<`3oool001L0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool0<`3oool001L0oooo00<000000?ooo`3oool0N@3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0<`3oool0
01L0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0n0?ooo`=000000P3oool00d00
0000oooo0?ooo`020?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0<`3oool000d0
oooo0d0000020?ooo`03@000003oool0oooo0080oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`0o0?ooo`06@000003oool0oooo@000003ooom000000`3oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo03<0oooo000>0?ooo`06@000003oool0oooo@000003ooom000000`3o
ool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo03d0oooo14000000103ooom000000?oo
od0000030?ooo`03000004000000oooo07X0oooo00<000000?ooo`3oool0<P3oool000`0oooo1400
0000103ooom000000?oood0000030?ooo`03000004000000oooo07X0oooo00<000000?ooo`3oool0
?03oool00d000000oooo@00000020?ooo`03@000003ooom0000000<0oooo00<000000?ooo`3oool0
NP3oool00`000000oooo0?ooo`0b0?ooo`00303oool00d000000oooo@00000020?ooo`03@000003o
oom0000000<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0m0?ooo`9000000P3o
ool00d000000oooo@00000030?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0<P3o
ool000d0oooo0T0000020?ooo`03@000003ooom0000000<0oooo00<000000?ooo`3oool0NP3oool0
0`000000oooo0?ooo`0n0?ooo`05@000003oool0oooo0?oood000000103oool00`000000oooo0?oo
o`1j0?ooo`030000003oool0oooo0380oooo000>0?ooo`05@000003oool0oooo0?oood000000103o
ool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0NP3o
ool00`000000oooo0?ooo`0b0?ooo`005`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0b0?ooo`005`3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0NP3oool00`00
0000oooo0?ooo`0b0?ooo`005`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0b0?ooo`005`3oool00`000000oooo
0?ooo`1j0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0NP3oool00`000000oooo
0?ooo`0b0?ooo`005`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo04L0oooo00<0
00000?ooo`3oool0NP3oool00`000000oooo0?ooo`0b0?ooo`005`3oool00`000000oooo0?ooo`1j
0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0b
0?ooo`005`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo03d0oooo00=000000?oo
o`3oool00P3oool00d000000oooo0?ooo`020?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0<P3oool000d0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool0?03oool00d000000oooo@00000020?ooo`03
@000003ooom0000000<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0b0?ooo`00
303oool00d000000oooo@00000020?ooo`03@000003ooom0000000<0oooo00<000000?ooo`3oool0
NP3oool00`000000oooo0?ooo`0n0?ooo`06@000003oool0oooo@000003ooom000000`3oool00`00
001000000?ooo`1j0?ooo`030000003oool0oooo0380oooo000>0?ooo`06@000003oool0oooo@000
003ooom000000`3oool00`00001000000?ooo`1j0?ooo`030000003oool0oooo03`0oooo0T000003
0?ooo`03@000003ooom0000000<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0b
0?ooo`00303oool2@00000<0oooo00=000000?oood0000000`3oool00`000000oooo0?ooo`1j0?oo
o`030000003oool0oooo03`0oooo00=000000?ooo`3oool00P3oool00d000000oooo@00000030?oo
o`030000003oool0oooo07/0oooo00<000000?ooo`3oool0<@3oool000`0oooo00=000000?ooo`3o
ool00P3oool00d000000oooo@00000030?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3o
ool0>`3oool3@00000<0oooo00=000000?ooo`3oool00P3oool00`000000oooo0?ooo`1k0?ooo`03
0000003oool0oooo0340oooo000<0?ooo`=000000`3oool00d000000oooo0?ooo`020?ooo`030000
003oool0oooo07/0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1k0?ooo`030000
003oool0oooo0340oooo000G0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0340oooo000G0?ooo`030000003oool0
oooo07/0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0
oooo0340oooo000G0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`1k0?ooo`030000003oool0oooo0340oooo000G0?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0340
oooo000G0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`1k0?ooo`030000003oool0oooo0340oooo000G0?ooo`030000003oool0oooo07/0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0340oooo000G
0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0>`3oool2@00000@0oooo00=00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0340oooo000<0?oo
o`900000103oool00d000000oooo0?ooo`020?ooo`030000003oool0oooo07/0oooo00<000000?oo
o`3oool0>`3oool00d000000oooo@00000020?ooo`03@000003ooom0000000<0oooo00<000000?oo
o`3oool0O03oool00`000000oooo0?ooo`0`0?ooo`00303oool00d000000oooo@00000020?ooo`03
@000003ooom0000000<0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0j0?ooo`03
@000003ooom000000080oooo00=000000?oood0000000`3oool00`00001000000?ooo`1l0?ooo`03
0000003oool0oooo0300oooo000<0?ooo`03@000003ooom000000080oooo00=000000?oood000000
0`3oool00`00001000000?ooo`1l0?ooo`030000003oool0oooo03X0oooo0T0000030?ooo`03@000
003ooom0000000<0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0`0?ooo`00303o
ool2@00000<0oooo00=000000?oood0000000`3oool00`000000oooo0?ooo`1l0?ooo`030000003o
ool0oooo03X0oooo00=000000?ooo`3oool00P3oool00d000000oooo@00000030?ooo`030000003o
ool0oooo07`0oooo00<000000?ooo`3oool0<03oool000`0oooo00=000000?ooo`3oool00P3oool0
0d000000oooo@00000030?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0>`3oool2
@00000<0oooo00=000000?ooo`3oool00P3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo0300oooo000=0?ooo`9000000`3oool00d000000oooo0?ooo`020?ooo`030000003oool0oooo
07`0oooo00=000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1l0?ooo`03@000003oool0oooo
0300oooo000G0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool0[`3oool001L0oooo
00=000000?ooo`3oool0a03oool00d000000oooo0?ooo`2_0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00B`3oool2@00001@0oooo00=000000?ooo`3oool01P3oool00d000000
oooo0?ooo`2U0?ooo`900000503oool00d000000oooo0?ooo`060?ooo`03@000003oool0oooo05`0
oooo001=0?ooo`03@000003oool0oooo0100oooo00=000000?ooo`3oool0203oool00d000000oooo
0?ooo`2V0?ooo`03@000003oool0oooo0100oooo00=000000?ooo`3oool0203oool00d000000oooo
0?ooo`1K0?ooo`005@3oool3@00002L0oooo0d0000030?ooo`=000000`3oool3@00000D0oooo00A0
00000?ooo`3oool0oooo0d0000050?ooo`03@000003oool0oooo0080oooo0d0000050?ooo`03@000
003oool0oooo06d0oooo0d00000W0?ooo`=000000`3oool3@00000<0oooo0d0000050?ooo`04@000
003oool0oooo0?ooo`=000001@3oool00d000000oooo0?ooo`030?ooo`=00000103oool00d000000
oooo0?ooo`1J0?ooo`005P3oool00d000000oooo0?ooo`0W0?ooo`03@000003oool0oooo00<0oooo
00E000000?ooo`3oool0oooo@00000020?ooo`03@000003oool0oooo00L0oooo00=000000?ooo`3o
ool01@3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00D0oooo00=000000?ooo`3o
ool0KP3oool00d000000oooo0?ooo`0W0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3o
ool0oooo@00000020?ooo`03@000003oool0oooo00L0oooo00=000000?ooo`3oool01@3oool00d00
0000oooo0?ooo`020?ooo`04@000003oool0oooo@00000@0oooo00=000000?ooo`3oool0FP3oool0
00/0oooo0T0000002@3ooom00000@00004000000oooo@000003ooom000000?ooo`03@00000H0oooo
00=000000?ooo`3oool07P3oool00d000000oooo0?ooo`030?ooo`05@000003oool0oooo0?oood00
00000P3oool00d000000oooo0?ooo`080?ooo`03@000003oool0oooo00@0oooo00=000000?ooo`3o
ool00P3oool00d000000oooo0?ooo`050?ooo`03@000003oool0oooo06<0oooo0T0000002@3ooom0
0000@00004000000oooo@000003ooom000000?ooo`03@00000H0oooo00=000000?ooo`3oool07P3o
ool00d000000oooo0?ooo`030?ooo`05@000003oool0oooo0?oood0000000P3oool00d000000oooo
0?ooo`080?ooo`03@000003oool0oooo00@0oooo00=000000?ooo`3oool00P3oool014000000oooo
0?oood0000040?ooo`03@000003oool0oooo05X0oooo000;0?ooo`04@000003oool0oooo0?ooo`90
000000H0oooo@000003ooom000000?oood0000020?ooo`03@000003oool0oooo02@0oooo0T000003
0?ooo`900000103oool3@00000X0oooo00=000000?ooo`3oool0103oool00d000000oooo0?ooo`02
0?ooo`=000001@3oool00d000000oooo0?ooo`1S0?ooo`04@000003oool0oooo0?ooo`90000000H0
oooo@000003ooom000000?oood0000020?ooo`03@000003oool0oooo02@0oooo0T0000030?ooo`90
0000103oool3@00000X0oooo00=000000?ooo`3oool0103oool00d000000oooo0?ooo`030?ooo`=0
0000103oool00d000000oooo0?ooo`1J0?ooo`00303oool3@00000080?oood000000oooo@000003o
oom000000?oood0000020?ooo`03@000003oool0oooo02@0oooo00A000000?ooo`3ooom000004`3o
ool00d000000oooo@00000060?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool0I@3o
ool3@00000080?oood000000oooo@000003ooom000000?oood0000020?ooo`03@000003oool0oooo
02@0oooo00A000000?ooo`3ooom000004`3oool00d000000oooo@00000060?ooo`03@000003oool0
oooo00@0oooo00E000000?ooo`3oool0oooo@000001M0?ooo`00303oool014000000oooo@000003o
ool2@00000030?oood000000oooo00A000009P3oool5@0000080oooo00=000000?ooo`3oool03`3o
ool00d000000oooo0?ooo`060?ooo`03@000003oool0oooo00H0oooo00=000000?ooo`3oool0IP3o
ool014000000oooo@000003oool2@00000030?oood000000oooo00A000009P3oool5@0000080oooo
00=000000?ooo`3oool03`3oool00d000000oooo0?ooo`060?ooo`03@000003oool0oooo0080oooo
0T0000020?ooo`03@000003oool0oooo05`0oooo000=0?ooo`03@000003oool0oooo0<@0oooo00=0
00000?ooo`3oool0^@3oool000`0oooo0T0000350?ooo`900000^`3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool002`0oooo0d0000030?oo
o`03@000003oool0oooo0180oooo0d0000020?ooo`03@000003oool0oooo0100oooo0T0000040?oo
o`03@000003oool0oooo0140oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`0=0?oo
o`E000000P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo05H0oooo0d0000030?oo
o`03@000003oool0oooo0180oooo0d0000020?ooo`03@000003oool0oooo0100oooo0T0000040?oo
o`03@000003oool0oooo0140oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`0=0?oo
o`E000000P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo02`0oooo000/0?ooo`03
@000003oool0oooo0080oooo00=000000?oood000000503oool01T000000oooo0?oood000000oooo
@0000140oooo00=000000?oood0000000P3oool00d000000oooo@000000A0?ooo`03@000003ooom0
00000080oooo00=000000?oood000000403oool01d000000oooo0?ooo`3ooom000000?oood000000
0P3oool00d000000oooo@000001G0?ooo`03@000003oool0oooo0080oooo00=000000?oood000000
503oool01T000000oooo0?oood000000oooo@0000140oooo00=000000?oood0000000P3oool00d00
0000oooo@000000A0?ooo`03@000003ooom000000080oooo00=000000?oood000000403oool01d00
0000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@000000]0?ooo`00;@3oool0
1d000000oooo0?ooo`3ooom000000?oood0000004P3oool4@00000040?oood000000oooo@0000140
oooo00=000000?oood0000000P3oool00d000000oooo@000000A0?ooo`03@000003ooom000000080
oooo00=000000?oood000000403oool01d000000oooo0?ooo`3ooom000000?oood0000000P3oool0
0d000000oooo@000001H0?ooo`07@000003oool0oooo0?oood000000oooo@000000B0?ooo`A00000
00@0oooo@000003ooom000004@3oool00d000000oooo@00000020?ooo`03@000003ooom000000140
oooo00=000000?oood0000000P3oool00d000000oooo@000000@0?ooo`07@000003oool0oooo0?oo
od000000oooo@00000020?ooo`03@000003ooom0000002d0oooo000G0?ooo`030000003oool0oooo
01<0oooo00M000000?ooo`3oool0oooo@000003ooom000000180oooo00=000000?oood0000000P3o
ool00d000000oooo@000000A0?ooo`9000000`3oool00d000000oooo@000000B0?ooo`07@000003o
ool0oooo0?oood000000oooo@000000@0?ooo`07@000003oool0oooo0?oood000000oooo@0000002
0?ooo`03@000003ooom000000480oooo00<000000?ooo`3oool04`3oool01d000000oooo0?ooo`3o
oom000000?oood0000004P3oool00d000000oooo@00000020?ooo`03@000003ooom000000140oooo
0T0000030?ooo`03@000003ooom000000180oooo00M000000?ooo`3oool0oooo@000003ooom00000
0100oooo00M000000?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood000000;@3o
ool001L0oooo00<000000?ooo`3oool04P3oool00d000000oooo@00000020?ooo`03@000003ooom0
000001<0oooo0T0000020?ooo`03@000003ooom000000140oooo00=000000?ooo`3oool00P3oool0
0d000000oooo@000000A0?ooo`03@000003ooom000000080oooo00=000000?oood000000403oool0
1d000000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@00000120?ooo`030000
003oool0oooo0180oooo00=000000?oood0000000P3oool00d000000oooo@000000C0?ooo`900000
0P3oool00d000000oooo@000000A0?ooo`03@000003oool0oooo0080oooo00=000000?oood000000
4@3oool00d000000oooo@00000020?ooo`03@000003ooom000000100oooo00M000000?ooo`3oool0
oooo@000003ooom000000080oooo00=000000?oood000000;@3oool001L0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00@00000
0?ooo`3oool000000P3oool01@000000oooo@000003oool0000000<0oooo00<000000?ooo`000000
103oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000@000003oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool2@00000<0
oooo00=000000?ooo`3oool04@3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00h0
oooo0T0000040?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool0@@3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool0
10000000oooo0?ooo`0000020?ooo`050000003ooom000000?ooo`0000000`3oool00`000000oooo
000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00001000000?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`90
00000`3oool00d000000oooo0?ooo`0A0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3o
ool03P3oool2@00000@0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`0/0?ooo`00
5`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`0000000`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`220?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo000000030?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo06d0oooo000G0?ooo`040000003oool0000000000080oooo0P000000103oool00000
0?ooo`3oool2000000030?ooo`000000oooo0080oooo00@000000?ooo`00000000000P3oool20000
0080oooo00H000000?ooo`3oool0oooo0000003oool2000000<0oooo0P0000020?ooo`8000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`220?ooo`040000003oool0000000000080oooo0P000000103oool00000
0?ooo`3oool2000000030?ooo`000000oooo0080oooo00@000000?ooo`00000000000P3oool20000
0080oooo00H000000?ooo`3oool0oooo0000003oool2000000<0oooo0P0000020?ooo`8000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`1]0?ooo`005`3oool010000000oooo0000003oool20000000>0?ooo`00
000000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool20000000?0?oo
o`00000000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo000000130?ooo`=00000
00@0oooo@000003oool0oooo0T0000020?ooo`900000103oool2@00000L0oooo00=000000?ooo`3o
ool08`3oool010000000oooo0000003oool20000000>0?ooo`00000000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool20000000?0?ooo`00000000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool000000080oooo00<00000
0?ooo`0000001@3oool00`000000oooo000000130?ooo`=0000000@0oooo@000003oool0oooo0T00
00020?ooo`900000103oool2@00000L0oooo00=000000?ooo`3oool03P3oool001L0oooo0P000002
0?ooo`8000000P3oool010000000oooo0000000000020?ooo`070000003oool000000?ooo`000000
oooo000000020?ooo`8000000P3oool2000000060?ooo`000000oooo0000003oool000000P3oool0
0`000000oooo000000020?ooo`8000000P3oool2000000070?ooo`000000oooo0?ooo`000000oooo
000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`000000A03oool01T000000oooo
0?oood000000oooo@00000H0oooo00A000000?ooo`3ooom000000P3oool00d000000oooo0?ooo`0Z
0?ooo`8000000P3oool200000080oooo00@000000?ooo`00000000000P3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool200000080oooo0P0000001P3oool000000?ooo`000000oooo
00000080oooo00<000000?ooo`0000000P3oool200000080oooo0P0000001`3oool000000?ooo`3o
ool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0000004@0oooo
00I000000?ooo`3ooom000000?oood0000060?ooo`04@000003oool0oooo@0000080oooo00=00000
0?ooo`3oool05@3oool001D0ooooQ00000000d000000oooo0?ooo`030?ooo`=000000P3oool3@000
00<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003oool0oooo02P0ooooQ0000000
0d000000oooo0?ooo`030?ooo`=000000P3oool3@00000<0oooo00E000000?ooo`3oool0oooo@000
00020?ooo`03@000003oool0oooo01D0oooo000;0?ooo`E000000P3oool00d000000oooo0?ooo`02
0?ooo`030000003oool0oooo01H0oooo00=000000?ooo`3oool05`3oool00d000000oooo0?ooo`0F
0?ooo`03@000003oool0oooo00H0oooo00<000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo0000000I0?ooo`03@000003oool0oooo00H0oooo
00E000000?ooo`3ooom000000?ooo`03@00000<0oooo0T0000030?ooo`9000008@3oool5@0000080
oooo00=000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`03@000003oool0oooo01L0
oooo00=000000?ooo`3oool05P3oool00d000000oooo0?ooo`060?ooo`030000003oool000000080
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000006@3oool0
0d000000oooo0?ooo`060?ooo`05@000003oool0oooo@000003oool00d0000030?ooo`9000000`3o
ool2@00001P0oooo000=0?ooo`07@000003oool0oooo0?oood000000oooo@00000030?ooo`030000
003oool0oooo0580oooo00<000000?ooo`0000000P3oool020000000oooo0000003oool000000?oo
o`000000oooo0P0000000`3oool000000?ooo`0Q0?ooo`04@000003oool0oooo@0000340oooo00M0
00000?ooo`3oool0oooo@000003ooom0000000<0oooo00<000000?ooo`3oool0DP3oool00`000000
oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool2000000030?ooo`00
0000oooo0240oooo00A000000?ooo`3ooom000009P3oool000d0oooo00M000000?ooo`3oool0oooo
@000003ooom0000000<0oooo00<00000@000003oool0D`3oool00`000000oooo0?ooo`020?ooo`06
0000003oool0oooo0?ooo`000000oooo0P000000103oool000000?ooo`00000P0?ooo`A00000<P3o
ool01d000000oooo0?ooo`3ooom000000?oood0000000`3oool00`00001000000?ooo`1C0?ooo`03
0000003oool0oooo0080oooo00H000000?ooo`3oool0oooo0000003oool2000000040?ooo`000000
oooo00000200oooo1400000W0?ooo`003@3oool01d000000oooo0?ooo`3ooom000000?oood000000
0`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0
oooo0000003oool000000080oooo00<000000?ooo`000000EP3oool01d000000oooo0?ooo`3ooom0
00000?oood0000000`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0080oooo00L0
00000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`000000B`3oool000d0oooo
00M000000?ooo`3oool0oooo@000003ooom0000000<0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003o
ool0000000T000000`3oool00`000000oooo0?ooo`170?ooo`07@000003oool0oooo0?oood000000
oooo@00000030?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool00P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo00000009000000<0oooo00<00000
0?ooo`3oool0?03oool000`0oooo0T0000040?ooo`03@000003oool0oooo0080oooo00<000000?oo
o`3oool0K03oool01@000000oooo0?ooo`3oool0000004P0oooo0T0000040?ooo`03@000003oool0
oooo0080oooo00<000000?ooo`3oool0K03oool01@000000oooo0?ooo`3oool0000003h0oooo000G
0?ooo`030000003oool0oooo06d0oooo00@000000?ooo`3oool00000D`3oool00`000000oooo0?oo
o`1]0?ooo`040000003oool0oooo000003h0oooo000G0?ooo`030000003oool0oooo06d0oooo00<0
00000?ooo`3oool00P00001B0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool00P00
000m0?ooo`005`3oool00`000000oooo0?ooo`1]0?ooo`050000003oool000000?ooo`000000DP3o
ool00`000000oooo0?ooo`1]0?ooo`050000003oool000000?ooo`000000?@3oool001L0oooo00<0
00000?ooo`3oool0KP3oool2000000030?ooo`000000oooo0540oooo00<000000?ooo`3oool0KP3o
ool2000000030?ooo`000000oooo03`0oooo000G0?ooo`030000003oool0oooo06h0oooo0P000000
1@3oool000000?ooo`3oool0000004l0oooo00<000000?ooo`3oool0KP3oool2000000050?ooo`00
0000oooo0?ooo`000000>P3oool001L0oooo00<000000?ooo`3oool0L@3oool010000000oooo0?oo
o`00001?0?ooo`030000003oool0oooo0740oooo00@000000?ooo`3oool00000>P3oool001L0oooo
00<000000?ooo`3oool0LP3oool00`000000oooo0000001?0?ooo`030000003oool0oooo0780oooo
00<000000?ooo`000000>P3oool000`0oooo0d0000030?ooo`03@000003oool0oooo0080oooo00<0
00000?ooo`3oool0LP3oool3000004@0oooo0d0000030?ooo`03@000003oool0oooo0080oooo00<0
00000?ooo`3oool0LP3oool3000003X0oooo000<0?ooo`03@000003oool0oooo0080oooo00=00000
0?oood0000000`3oool00`000000oooo0?ooo`1c0?ooo`800000A03oool00d000000oooo0?ooo`02
0?ooo`03@000003ooom0000000<0oooo00<000000?ooo`3oool0L`3oool2000003X0oooo000=0?oo
o`07@000003oool0oooo0?oood000000oooo@00000030?ooo`03000004000000oooo07<0oooo00@0
00000?ooo`0000000000@`3oool01d000000oooo0?ooo`3ooom000000?oood0000000`3oool00`00
001000000?ooo`1c0?ooo`040000003oool00000000003P0oooo000=0?ooo`07@000003oool0oooo
0?oood000000oooo@00000030?ooo`030000003oool0oooo07D0oooo0P0000130?ooo`07@000003o
ool0oooo0?oood000000oooo@00000030?ooo`030000003oool0oooo07D0oooo0P00000h0?ooo`00
303oool00d000000oooo@00000020?ooo`03@000003ooom0000000<0oooo00<000000?ooo`3oool0
M@3oool200000480oooo00=000000?oood0000000P3oool00d000000oooo@00000030?ooo`030000
003oool0oooo07D0oooo0P00000h0?ooo`003@3oool00d000000oooo0?ooo`020?ooo`03@000003o
ool0oooo0080oooo00<000000?ooo`3oool0M@3oool00`000000oooo000000120?ooo`03@000003o
ool0oooo0080oooo00=000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e0?ooo`030000003o
ool0000003L0oooo000G0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`000000C03oool0
0`000000oooo0?ooo`1e0?ooo`030000003oool0000003L0oooo000G0?ooo`030000003oool0oooo
07D0oooo00<000000?ooo`000000C03oool00`000000oooo0?ooo`1e0?ooo`030000003oool00000
03L0oooo000G0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0BP3oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo03D0oooo000G0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03D0oooo
000G0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo03D0oooo000G0?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03@0oooo000G0?oo
o`030000003oool0oooo07P0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo03@0oooo000<0?ooo`900000103oool00d000000oooo0?ooo`020?ooo`03
0000003oool0oooo07P0oooo00<000000?ooo`3oool0?P3oool2@00000@0oooo00=000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03@0oooo000>0?ooo`06@000
003oool0oooo@000003ooom000000`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
0400oooo00I000000?ooo`3ooom000000?oood0000030?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool0=03oool000d0oooo00M000000?ooo`3oool0oooo@000003ooom0000000<0oooo
00<00000@000003oool0N03oool00`000000oooo0?ooo`0o0?ooo`07@000003oool0oooo0?oood00
0000oooo@00000030?ooo`03000004000000oooo07P0oooo00<000000?ooo`3oool0=03oool000h0
oooo00I000000?ooo`3ooom000000?oood0000030?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool0?`3oool01T000000oooo0?oood000000oooo@00000<0oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`0c0?ooo`00303oool00d000000oooo@00000020?ooo`03@000003o
oom0000000<0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`03@000003o
oom000000080oooo00=000000?oood0000000`3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo03<0oooo000=0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo03h0oooo00=000000?ooo`3oool00P3oool0
0d000000oooo0?ooo`020?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0<`3oool0
01L0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool0<`3oool001L0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0<`3oool001L0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool0<`3oool001L0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0<`3oool001L0oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool0<`3oool001L0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool0<`3oool001L0oooo00<000000?ooo`3o
ool0N@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool0<`3oool001L0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool0<`3oool000d0oooo0d0000020?ooo`03@000003o
ool0oooo0080oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0n0?ooo`=000000P3o
ool00d000000oooo0?ooo`020?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0<`3o
ool000h0oooo00I000000?ooo`3ooom000000?oood0000030?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool0?`3oool01T000000oooo0?oood000000oooo@00000<0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0c0?ooo`00303oool4@00000040?oood000000oooo@000
00<0oooo00<00000@000003oool0NP3oool00`000000oooo0?ooo`0l0?ooo`A0000000@0oooo@000
003ooom000000`3oool00`00001000000?ooo`1j0?ooo`030000003oool0oooo0380oooo000<0?oo
o`03@000003ooom000000080oooo00=000000?oood0000000`3oool00`000000oooo0?ooo`1j0?oo
o`030000003oool0oooo03`0oooo00=000000?oood0000000P3oool00d000000oooo@00000030?oo
o`030000003oool0oooo07X0oooo00<000000?ooo`3oool0<P3oool000d0oooo0T0000020?ooo`03
@000003ooom0000000<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0m0?ooo`90
00000P3oool00d000000oooo@00000030?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3o
ool0<P3oool000h0oooo00E000000?ooo`3oool0oooo@00000040?ooo`030000003oool0oooo07X0
oooo00<000000?ooo`3oool0?P3oool01D000000oooo0?ooo`3ooom0000000@0oooo00<000000?oo
o`3oool0NP3oool00`000000oooo0?ooo`0b0?ooo`005`3oool00`000000oooo0?ooo`1j0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0b0?ooo`00
5`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
NP3oool00`000000oooo0?ooo`0b0?ooo`005`3oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0b0?ooo`005`3oool0
0`000000oooo0?ooo`1j0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0NP3oool0
0`000000oooo0?ooo`0b0?ooo`005`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0b0?ooo`005`3oool00`000000
oooo0?ooo`1j0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`0b0?ooo`005`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0b0?ooo`003@3oool00d000000oooo0?oo
o`020?ooo`03@000003oool0oooo0080oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?oo
o`0m0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1j0?ooo`030000003oool0oooo0380oooo000<0?ooo`03@000003ooom000000080oooo00=00000
0?oood0000000`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo03`0oooo00=00000
0?oood0000000P3oool00d000000oooo@00000030?ooo`030000003oool0oooo07X0oooo00<00000
0?ooo`3oool0<P3oool000h0oooo00I000000?ooo`3ooom000000?oood0000030?ooo`0300000400
0000oooo07X0oooo00<000000?ooo`3oool0?P3oool01T000000oooo0?oood000000oooo@00000<0
oooo00<00000@000003oool0NP3oool00`000000oooo0?ooo`0b0?ooo`00303oool2@00000<0oooo
00=000000?oood0000000`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo03`0oooo
0T0000030?ooo`03@000003ooom0000000<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo
0?ooo`0b0?ooo`00303oool00d000000oooo0?ooo`020?ooo`03@000003ooom0000000<0oooo00<0
00000?ooo`3oool0N`3oool00`000000oooo0?ooo`0k0?ooo`03@000003oool0oooo0080oooo00=0
00000?oood0000000`3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0340oooo000<
0?ooo`=000000`3oool00d000000oooo0?ooo`020?ooo`030000003oool0oooo07/0oooo00<00000
0?ooo`3oool0>`3oool3@00000<0oooo00=000000?ooo`3oool00P3oool00`000000oooo0?ooo`1k
0?ooo`030000003oool0oooo0340oooo000G0?ooo`030000003oool0oooo07/0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0340oooo000G0?ooo`03
0000003oool0oooo07/0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1k0?ooo`03
0000003oool0oooo0340oooo000G0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0340oooo000G0?ooo`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1k0?ooo`030000003o
ool0oooo0340oooo000G0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0340oooo000G0?ooo`030000003oool0oooo
07/0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo
0340oooo000G0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`1k0?ooo`030000003oool0oooo0340oooo000<0?ooo`900000103oool00d000000oooo
0?ooo`020?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0>`3oool2@00000@0oooo
00=000000?ooo`3oool00P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0340oooo
000<0?ooo`03@000003ooom000000080oooo00=000000?oood0000000`3oool00`000000oooo0?oo
o`1l0?ooo`030000003oool0oooo03X0oooo00=000000?oood0000000P3oool00d000000oooo@000
00030?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0<03oool000`0oooo00=00000
0?oood0000000P3oool00d000000oooo@00000030?ooo`03000004000000oooo07`0oooo00<00000
0?ooo`3oool0>P3oool00d000000oooo@00000020?ooo`03@000003ooom0000000<0oooo00<00000
@000003oool0O03oool00`000000oooo0?ooo`0`0?ooo`00303oool2@00000<0oooo00=000000?oo
od0000000`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03X0oooo0T0000030?oo
o`03@000003ooom0000000<0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0`0?oo
o`00303oool00d000000oooo0?ooo`020?ooo`03@000003ooom0000000<0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`0j0?ooo`03@000003oool0oooo0080oooo00=000000?oood00
00000`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0300oooo000=0?ooo`900000
0`3oool00d000000oooo0?ooo`020?ooo`030000003oool0oooo07`0oooo00=000000?ooo`3oool0
>`3oool2@00000<0oooo00=000000?ooo`3oool00P3oool00`000000oooo0?ooo`1l0?ooo`03@000
003oool0oooo0300oooo000G0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool0[`3o
ool001L0oooo00=000000?ooo`3oool0a03oool00d000000oooo0?ooo`2_0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00B`3oool2@00001@0oooo00=000000?ooo`3oool01P3o
ool00d000000oooo0?ooo`2U0?ooo`900000503oool00d000000oooo0?ooo`060?ooo`03@000003o
ool0oooo05`0oooo001=0?ooo`03@000003oool0oooo0100oooo00=000000?ooo`3oool0203oool0
0d000000oooo0?ooo`2V0?ooo`03@000003oool0oooo0100oooo00=000000?ooo`3oool0203oool0
0d000000oooo0?ooo`1K0?ooo`005@3oool3@00002L0oooo0d0000030?ooo`=000000`3oool3@000
00D0oooo00A000000?ooo`3oool0oooo0d0000050?ooo`03@000003oool0oooo0080oooo14000004
0?ooo`03@000003oool0oooo06d0oooo0d00000W0?ooo`=000000`3oool3@00000<0oooo0d000005
0?ooo`04@000003oool0oooo0?ooo`=000001@3oool014000000oooo0?ooo`3oool4@00000D0oooo
00=000000?ooo`3oool0FP3oool001H0oooo00=000000?ooo`3oool09`3oool00d000000oooo0?oo
o`030?ooo`05@000003oool0oooo0?oood0000000P3oool00d000000oooo0?ooo`070?ooo`03@000
003oool0oooo00D0oooo00=000000?ooo`3oool00P3oool3@00000D0oooo00=000000?ooo`3oool0
KP3oool00d000000oooo0?ooo`0W0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0
oooo@00000020?ooo`03@000003oool0oooo00L0oooo00=000000?ooo`3oool01@3oool00d000000
oooo0?ooo`020?ooo`04@000003oool0oooo@00000@0oooo00=000000?ooo`3oool0FP3oool000/0
oooo0T0000002@3ooom00000@00004000000oooo@000003ooom000000?ooo`03@00000H0oooo00=0
00000?ooo`3oool07P3oool00d000000oooo0?ooo`030?ooo`05@000003oool0oooo0?oood000000
0P3oool00d000000oooo0?ooo`080?ooo`03@000003oool0oooo00@0oooo00=000000?ooo`3oool0
103oool00d000000oooo0?ooo`030?ooo`03@000003oool0oooo06<0oooo0T0000002@3ooom00000
@00004000000oooo@000003ooom000000?ooo`03@00000H0oooo00=000000?ooo`3oool07P3oool0
0d000000oooo0?ooo`030?ooo`05@000003oool0oooo0?oood0000000P3oool00d000000oooo0?oo
o`080?ooo`03@000003oool0oooo00@0oooo00=000000?ooo`3oool00P3oool014000000oooo0?oo
od0000040?ooo`03@000003oool0oooo05X0oooo000;0?ooo`04@000003oool0oooo0?ooo`900000
00H0oooo@000003ooom000000?oood0000020?ooo`03@000003oool0oooo02@0oooo0T0000030?oo
o`900000103oool3@00000X0oooo00=000000?ooo`3oool0103oool00d000000oooo0?ooo`030?oo
o`9000001@3oool00d000000oooo0?ooo`1S0?ooo`04@000003oool0oooo0?ooo`90000000H0oooo
@000003ooom000000?oood0000020?ooo`03@000003oool0oooo02@0oooo0T0000030?ooo`900000
103oool3@00000X0oooo00=000000?ooo`3oool0103oool00d000000oooo0?ooo`020?ooo`=00000
1@3oool00d000000oooo0?ooo`1J0?ooo`00303oool3@00000080?oood000000oooo@000003ooom0
00000?oood0000020?ooo`03@000003oool0oooo02@0oooo00A000000?ooo`3ooom000004`3oool0
0d000000oooo@00000060?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool0I@3oool3
@00000080?oood000000oooo@000003ooom000000?oood0000020?ooo`03@000003oool0oooo02@0
oooo00A000000?ooo`3ooom000004`3oool00d000000oooo@00000060?ooo`05@000003oool0oooo
0?oood0000001P3oool00d000000oooo0?ooo`1K0?ooo`00303oool014000000oooo@000003oool2
@00000030?oood000000oooo00A000009P3oool5@0000080oooo00=000000?ooo`3oool03`3oool0
0d000000oooo0?ooo`060?ooo`03@000003oool0oooo00H0oooo00=000000?ooo`3oool0IP3oool0
14000000oooo@000003oool2@00000030?oood000000oooo00A000009P3oool5@0000080oooo00=0
00000?ooo`3oool03`3oool00d000000oooo0?ooo`060?ooo`04@000003ooom00000@00000D0oooo
00=000000?ooo`3oool0G03oool000d0oooo00=000000?ooo`3oool0a03oool00d000000oooo0?oo
o`2i0?ooo`00303oool2@0000<D0oooo0T00002k0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {249, 0}} -> {-0.0500105, -0.03724, 
  0.00526322, 0.00526322}, {{9.5, 190.438}, {241.875, 
  130.063}} -> {-18.575, -9.55134, 0.790407, 0.749261}, {{208.5, 389.438}, {
  241.875, 130.063}} -> {-175.866, -9.81952, 0.790407, 0.762176}, {{9.5, 
  190.438}, {118.875, 7.0625}} -> {-18.575, -101.71, 0.790407, 0.749261}, {{
  208.5, 389.438}, {118.875, 7.0625}} -> {-175.866, -101.71, 0.790407, 
  0.749261}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Comparison the original one-dimensional images in Fig.1 and their eigen \
patterns reveals that all of the eigen patterns are the same even though \
their frequencies, time phase and waveforms are different. To check this, we \
compute a correlation coefficient between them.",
    TextAlignment->Left,
    TextJustification->1]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["\<\
Table[
\tcorRelation[eigenPatternM[[1]],eigenPatternM[[i]]],
{i,2,4,1}]\
\>", "Input",
  CellLabel->"In[36]:=",
  FormatType->InputForm],

Cell[BoxData[
    \({0.999999999999999822`, 0.999999999999999822`, 0.999956397393305707`}
      \)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "Thus, our method has extracted the unique eigen pattern that has a common \
nature of the sinusoidal waveform.",
    TextAlignment->Left,
    TextJustification->1,
    FormatType->InputForm]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm,
  FontFamily->"Times New Roman"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Inverse transform",
  FormatType->InputForm,
  FontFamily->"Times New Roman"]], "Subsubsection",
  FormatType->InputForm],

Cell[TextData[{
  "\t",
  StyleBox[
  "The recovering to the original time domain one-dimensional images from the \
eigen pattern depends on an inverse transform matrix. Because of the same \
eigen pattern, the time domain image is determined by which transform matrix \
to be used for constructing the inverse transform matrix. In this textbook, \
we recover the sinusoidal waveform from the eigen pattern of the \
co-sinusoidal waveform shown in Fig.1 (d).",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["\n\t",
    TextAlignment->Left,
    TextJustification->1],
  StyleBox[
  "At first, we construct the inverse transform matrix based on the transform \
matrix of the sinusoidal waveform in Fig. 1(a).",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["inverseMat=inverseEigenMatrix[eigenMat[[1]]];", "Input",
  CellLabel->"In[37]:=",
  FormatType->InputForm],

Cell[TextData[{
  "\t",
  StyleBox[
  "Second, we recover the sinusoidal waveform from the eigen pattern of \
co-sinusoidal waveform in Fig 2(d). Figure 3 shows a recovered sinusoidal \
waveform.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
sinR=inverseMat.eigenPatternM[[4]];
sinRG=ListPlot[sinR,PlotRange->All,PlotJoined->True,
\tPlotStyle->RGBColor[1,0,0],AxesLabel->{\"time\",\"Amp.\"},
\tPlotLabel->\"Fig.3. Recovered\"];\
\>", "Input",
  CellLabel->"In[38]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0228571 0.000952381 0.309017 0.289259 [
[.21333 .29652 -9 -9 ]
[.21333 .29652 9 0 ]
[.40381 .29652 -9 -9 ]
[.40381 .29652 9 0 ]
[.59429 .29652 -9 -9 ]
[.59429 .29652 9 0 ]
[.78476 .29652 -9 -9 ]
[.78476 .29652 9 0 ]
[.97524 .29652 -12 -9 ]
[.97524 .29652 12 0 ]
[1.025 .30902 0 -6.28125 ]
[1.025 .30902 28 6.28125 ]
[.01036 .01976 -12 -4.5 ]
[.01036 .01976 0 4.5 ]
[.01036 .16439 -24 -4.5 ]
[.01036 .16439 0 4.5 ]
[.01036 .45365 -18 -4.5 ]
[.01036 .45365 0 4.5 ]
[.01036 .59828 -6 -4.5 ]
[.01036 .59828 0 4.5 ]
[.02286 .64303 -14 0 ]
[.02286 .64303 14 12.5625 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21333 .30902 m
.21333 .31527 L
s
[(200)] .21333 .29652 0 1 Mshowa
.40381 .30902 m
.40381 .31527 L
s
[(400)] .40381 .29652 0 1 Mshowa
.59429 .30902 m
.59429 .31527 L
s
[(600)] .59429 .29652 0 1 Mshowa
.78476 .30902 m
.78476 .31527 L
s
[(800)] .78476 .29652 0 1 Mshowa
.97524 .30902 m
.97524 .31527 L
s
[(1000)] .97524 .29652 0 1 Mshowa
.125 Mabswid
.07048 .30902 m
.07048 .31277 L
s
.1181 .30902 m
.1181 .31277 L
s
.16571 .30902 m
.16571 .31277 L
s
.26095 .30902 m
.26095 .31277 L
s
.30857 .30902 m
.30857 .31277 L
s
.35619 .30902 m
.35619 .31277 L
s
.45143 .30902 m
.45143 .31277 L
s
.49905 .30902 m
.49905 .31277 L
s
.54667 .30902 m
.54667 .31277 L
s
.6419 .30902 m
.6419 .31277 L
s
.68952 .30902 m
.68952 .31277 L
s
.73714 .30902 m
.73714 .31277 L
s
.83238 .30902 m
.83238 .31277 L
s
.88 .30902 m
.88 .31277 L
s
.92762 .30902 m
.92762 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(time) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.02286 .01976 m
.02911 .01976 L
s
[(-1)] .01036 .01976 1 0 Mshowa
.02286 .16439 m
.02911 .16439 L
s
[(-0.5)] .01036 .16439 1 0 Mshowa
.02286 .45365 m
.02911 .45365 L
s
[(0.5)] .01036 .45365 1 0 Mshowa
.02286 .59828 m
.02911 .59828 L
s
[(1)] .01036 .59828 1 0 Mshowa
.125 Mabswid
.02286 .04868 m
.02661 .04868 L
s
.02286 .07761 m
.02661 .07761 L
s
.02286 .10654 m
.02661 .10654 L
s
.02286 .13546 m
.02661 .13546 L
s
.02286 .19331 m
.02661 .19331 L
s
.02286 .22224 m
.02661 .22224 L
s
.02286 .25117 m
.02661 .25117 L
s
.02286 .28009 m
.02661 .28009 L
s
.02286 .33794 m
.02661 .33794 L
s
.02286 .36687 m
.02661 .36687 L
s
.02286 .39579 m
.02661 .39579 L
s
.02286 .42472 m
.02661 .42472 L
s
.02286 .48257 m
.02661 .48257 L
s
.02286 .5115 m
.02661 .5115 L
s
.02286 .54042 m
.02661 .54042 L
s
.02286 .56935 m
.02661 .56935 L
s
.25 Mabswid
.02286 0 m
.02286 .61803 L
s
gsave
.02286 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Amp) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
87.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.3) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Recovered) show
159.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02476 .31192 L
.02571 .31047 L
.02667 .31447 L
.02762 .31788 L
.02857 .31611 L
.02952 .32159 L
.03048 .31979 L
.03143 .32355 L
.03238 .32708 L
.03333 .32528 L
.03429 .32899 L
.03524 .33254 L
.03619 .33074 L
.03714 .33617 L
.0381 .33437 L
.03905 .33805 L
.04 .34161 L
.04095 .33981 L
.0419 .34347 L
.04286 .34703 L
.04381 .34523 L
.04476 .35063 L
.04571 .34884 L
.04667 .35247 L
.04762 .35603 L
.04857 .35423 L
.04952 .35785 L
.05048 .3614 L
.05143 .35961 L
.05238 .36497 L
.05333 .36319 L
.05429 .36678 L
.05524 .37032 L
.05619 .36854 L
.05714 .37386 L
.0581 .37209 L
.05905 .37566 L
.06 .37917 L
.06095 .3774 L
.0619 .38269 L
.06286 .38093 L
.06381 .38447 L
.06476 .38795 L
.06571 .3862 L
.06667 .38972 L
.06762 .39318 L
.06857 .39144 L
.06952 .39666 L
.07048 .39492 L
Mistroke
.07143 .40011 L
.07238 .39839 L
.07333 .40185 L
.07429 .40527 L
.07524 .40356 L
.07619 .40869 L
.07714 .40699 L
.0781 .41041 L
.07905 .41379 L
.08 .4121 L
.08095 .41717 L
.0819 .41549 L
.08286 .41887 L
.08381 .42221 L
.08476 .42054 L
.08571 .42555 L
.08667 .42388 L
.08762 .42887 L
.08857 .42721 L
.08952 .43053 L
.09048 .43381 L
.09143 .43217 L
.09238 .43708 L
.09333 .43545 L
.09429 .44033 L
.09524 .43871 L
.09619 .44195 L
.09714 .44516 L
.0981 .44356 L
.09905 .44836 L
.1 .44676 L
.10095 .45153 L
.1019 .44995 L
.10286 .45469 L
.10381 .45311 L
.10476 .45782 L
.10571 .45625 L
.10667 .45938 L
.10762 .46246 L
.10857 .46092 L
.10952 .46553 L
.11048 .464 L
.11143 .46858 L
.11238 .46706 L
.11333 .4716 L
.11429 .47009 L
.11524 .47459 L
.11619 .4731 L
.11714 .47756 L
.1181 .47608 L
Mistroke
.11905 .4805 L
.12 .47903 L
.12095 .48341 L
.1219 .48196 L
.12286 .4863 L
.12381 .48486 L
.12476 .48916 L
.12571 .48773 L
.12667 .49199 L
.12762 .49058 L
.12857 .49479 L
.12952 .49339 L
.13048 .49756 L
.13143 .49618 L
.13238 .5003 L
.13333 .49894 L
.13429 .50301 L
.13524 .50166 L
.13619 .50702 L
.13714 .50568 L
.1381 .50436 L
.13905 .50966 L
.14 .50835 L
.14095 .51226 L
.1419 .51096 L
.14286 .51483 L
.14381 .51355 L
.14476 .51862 L
.14571 .51735 L
.14667 .5161 L
.14762 .52111 L
.14857 .51987 L
.14952 .52357 L
.15048 .52235 L
.15143 .52719 L
.15238 .52597 L
.15333 .52478 L
.15429 .52956 L
.15524 .52838 L
.15619 .53305 L
.15714 .53188 L
.1581 .53073 L
.15905 .53533 L
.16 .53419 L
.16095 .53868 L
.1619 .53756 L
.16286 .53646 L
.16381 .54088 L
.16476 .53978 L
.16571 .54409 L
Mistroke
.16667 .54302 L
.16762 .54196 L
.16857 .54723 L
.16952 .54618 L
.17048 .54515 L
.17143 .55028 L
.17238 .54926 L
.17333 .54826 L
.17429 .55325 L
.17524 .55225 L
.17619 .55128 L
.17714 .55612 L
.1781 .55516 L
.17905 .55422 L
.18 .55891 L
.18095 .55798 L
.1819 .55706 L
.18286 .56162 L
.18381 .56071 L
.18476 .55983 L
.18571 .56423 L
.18667 .56335 L
.18762 .5625 L
.18857 .56758 L
.18952 .56673 L
.19048 .5659 L
.19143 .56508 L
.19238 .57075 L
.19333 .56995 L
.19429 .56916 L
.19524 .56839 L
.19619 .57302 L
.19714 .57226 L
.1981 .57152 L
.19905 .57592 L
.2 .57519 L
.20095 .57447 L
.2019 .57377 L
.20286 .5793 L
.20381 .57861 L
.20476 .57793 L
.20571 .57727 L
.20667 .57662 L
.20762 .58179 L
.20857 .58116 L
.20952 .58054 L
.21048 .57993 L
.21143 .58525 L
.21238 .58466 L
.21333 .58408 L
Mistroke
.21429 .58351 L
.21524 .58296 L
.21619 .58242 L
.21714 .5878 L
.2181 .58728 L
.21905 .58676 L
.22 .58626 L
.22095 .58577 L
.2219 .59096 L
.22286 .59049 L
.22381 .59003 L
.22476 .58958 L
.22571 .58915 L
.22667 .58873 L
.22762 .58832 L
.22857 .59389 L
.22952 .59349 L
.23048 .59311 L
.23143 .59274 L
.23238 .59239 L
.23333 .59204 L
.23429 .59171 L
.23524 .59139 L
.23619 .59702 L
.23714 .59672 L
.2381 .59643 L
.23905 .59615 L
.24 .59588 L
.24095 .59562 L
.2419 .59538 L
.24286 .59514 L
.24381 .59492 L
.24476 .59471 L
.24571 .59452 L
.24667 .59433 L
.24762 .60332 L
.24857 .60315 L
.24952 .60299 L
.25048 .60285 L
.25143 .60271 L
.25238 .60259 L
.25333 .60248 L
.25429 .60238 L
.25524 .6023 L
.25619 .60222 L
.25714 .60216 L
.2581 .60211 L
.25905 .60206 L
.26 .60204 L
.26095 .60202 L
Mistroke
.2619 .60201 L
.26286 .60202 L
.26381 .60204 L
.26476 .60206 L
.26571 .60211 L
.26667 .60216 L
.26762 .60222 L
.26857 .6023 L
.26952 .60238 L
.27048 .60248 L
.27143 .60259 L
.27238 .60271 L
.27333 .60285 L
.27429 .60299 L
.27524 .60315 L
.27619 .60332 L
.27714 .59433 L
.2781 .59452 L
.27905 .59471 L
.28 .59492 L
.28095 .59514 L
.2819 .59538 L
.28286 .59562 L
.28381 .59588 L
.28476 .59615 L
.28571 .59643 L
.28667 .59672 L
.28762 .59702 L
.28857 .59139 L
.28952 .59171 L
.29048 .59204 L
.29143 .59239 L
.29238 .59274 L
.29333 .59311 L
.29429 .59349 L
.29524 .59389 L
.29619 .58832 L
.29714 .58873 L
.2981 .58915 L
.29905 .58958 L
.3 .59003 L
.30095 .59049 L
.3019 .59096 L
.30286 .58577 L
.30381 .58626 L
.30476 .58676 L
.30571 .58728 L
.30667 .5878 L
.30762 .58242 L
.30857 .58296 L
Mistroke
.30952 .58351 L
.31048 .58408 L
.31143 .58466 L
.31238 .58525 L
.31333 .57993 L
.31429 .58054 L
.31524 .58116 L
.31619 .58179 L
.31714 .57662 L
.3181 .57727 L
.31905 .57793 L
.32 .57861 L
.32095 .5793 L
.3219 .57377 L
.32286 .57447 L
.32381 .57519 L
.32476 .57592 L
.32571 .57152 L
.32667 .57226 L
.32762 .57302 L
.32857 .56839 L
.32952 .56916 L
.33048 .56995 L
.33143 .57075 L
.33238 .56508 L
.33333 .5659 L
.33429 .56673 L
.33524 .56758 L
.33619 .5625 L
.33714 .56335 L
.3381 .56423 L
.33905 .55983 L
.34 .56071 L
.34095 .56162 L
.3419 .55706 L
.34286 .55798 L
.34381 .55891 L
.34476 .55422 L
.34571 .55516 L
.34667 .55612 L
.34762 .55128 L
.34857 .55225 L
.34952 .55325 L
.35048 .54826 L
.35143 .54926 L
.35238 .55028 L
.35333 .54515 L
.35429 .54618 L
.35524 .54723 L
.35619 .54196 L
Mistroke
.35714 .54302 L
.3581 .54409 L
.35905 .53978 L
.36 .54088 L
.36095 .53646 L
.3619 .53756 L
.36286 .53868 L
.36381 .53419 L
.36476 .53533 L
.36571 .53073 L
.36667 .53188 L
.36762 .53305 L
.36857 .52838 L
.36952 .52956 L
.37048 .52478 L
.37143 .52597 L
.37238 .52719 L
.37333 .52235 L
.37429 .52357 L
.37524 .51987 L
.37619 .52111 L
.37714 .5161 L
.3781 .51735 L
.37905 .51862 L
.38 .51355 L
.38095 .51483 L
.3819 .51096 L
.38286 .51226 L
.38381 .50835 L
.38476 .50966 L
.38571 .50436 L
.38667 .50568 L
.38762 .50702 L
.38857 .50166 L
.38952 .50301 L
.39048 .49894 L
.39143 .5003 L
.39238 .49618 L
.39333 .49756 L
.39429 .49339 L
.39524 .49479 L
.39619 .49058 L
.39714 .49199 L
.3981 .48773 L
.39905 .48916 L
.4 .48486 L
.40095 .4863 L
.4019 .48196 L
.40286 .48341 L
.40381 .47903 L
Mistroke
.40476 .4805 L
.40571 .47608 L
.40667 .47756 L
.40762 .4731 L
.40857 .47459 L
.40952 .47009 L
.41048 .4716 L
.41143 .46706 L
.41238 .46858 L
.41333 .464 L
.41429 .46553 L
.41524 .46092 L
.41619 .46246 L
.41714 .45938 L
.4181 .45625 L
.41905 .45782 L
.42 .45311 L
.42095 .45469 L
.4219 .44995 L
.42286 .45153 L
.42381 .44676 L
.42476 .44836 L
.42571 .44356 L
.42667 .44516 L
.42762 .44195 L
.42857 .43871 L
.42952 .44033 L
.43048 .43545 L
.43143 .43708 L
.43238 .43217 L
.43333 .43381 L
.43429 .43053 L
.43524 .42721 L
.43619 .42887 L
.43714 .42388 L
.4381 .42555 L
.43905 .42054 L
.44 .42221 L
.44095 .41887 L
.4419 .41549 L
.44286 .41717 L
.44381 .4121 L
.44476 .41379 L
.44571 .41041 L
.44667 .40699 L
.44762 .40869 L
.44857 .40356 L
.44952 .40527 L
.45048 .40185 L
.45143 .39839 L
Mistroke
.45238 .40011 L
.45333 .39492 L
.45429 .39666 L
.45524 .39144 L
.45619 .39318 L
.45714 .38972 L
.4581 .3862 L
.45905 .38795 L
.46 .38447 L
.46095 .38093 L
.4619 .38269 L
.46286 .3774 L
.46381 .37917 L
.46476 .37566 L
.46571 .37209 L
.46667 .37386 L
.46762 .36854 L
.46857 .37032 L
.46952 .36678 L
.47048 .36319 L
.47143 .36497 L
.47238 .35961 L
.47333 .3614 L
.47429 .35785 L
.47524 .35423 L
.47619 .35603 L
.47714 .35247 L
.4781 .34884 L
.47905 .35063 L
.48 .34523 L
.48095 .34703 L
.4819 .34347 L
.48286 .33981 L
.48381 .34161 L
.48476 .33805 L
.48571 .33437 L
.48667 .33617 L
.48762 .33074 L
.48857 .33254 L
.48952 .32899 L
.49048 .32528 L
.49143 .32708 L
.49238 .32355 L
.49333 .31979 L
.49429 .32159 L
.49524 .31611 L
.49619 .31788 L
.49714 .31447 L
.4981 .31047 L
.49905 .31192 L
Mistroke
.5 .30902 L
.50095 .30611 L
.5019 .30756 L
.50286 .30356 L
.50381 .30015 L
.50476 .30193 L
.50571 .29645 L
.50667 .29824 L
.50762 .29448 L
.50857 .29095 L
.50952 .29276 L
.51048 .28904 L
.51143 .28549 L
.51238 .2873 L
.51333 .28186 L
.51429 .28367 L
.51524 .27999 L
.51619 .27643 L
.51714 .27823 L
.5181 .27457 L
.51905 .27101 L
.52 .27281 L
.52095 .2674 L
.5219 .2692 L
.52286 .26556 L
.52381 .26201 L
.52476 .2638 L
.52571 .26018 L
.52667 .25663 L
.52762 .25842 L
.52857 .25306 L
.52952 .25484 L
.53048 .25125 L
.53143 .24772 L
.53238 .2495 L
.53333 .24417 L
.53429 .24594 L
.53524 .24237 L
.53619 .23887 L
.53714 .24063 L
.5381 .23534 L
.53905 .2371 L
.54 .23357 L
.54095 .23008 L
.5419 .23183 L
.54286 .22832 L
.54381 .22485 L
.54476 .22659 L
.54571 .22138 L
.54667 .22311 L
Mistroke
.54762 .21792 L
.54857 .21965 L
.54952 .21618 L
.55048 .21276 L
.55143 .21448 L
.55238 .20934 L
.55333 .21105 L
.55429 .20762 L
.55524 .20424 L
.55619 .20594 L
.55714 .20086 L
.5581 .20255 L
.55905 .19916 L
.56 .19582 L
.56095 .1975 L
.5619 .19248 L
.56286 .19415 L
.56381 .18917 L
.56476 .19082 L
.56571 .1875 L
.56667 .18423 L
.56762 .18587 L
.56857 .18096 L
.56952 .18259 L
.57048 .17771 L
.57143 .17933 L
.57238 .17608 L
.57333 .17287 L
.57429 .17448 L
.57524 .16967 L
.57619 .17127 L
.57714 .1665 L
.5781 .16808 L
.57905 .16335 L
.58 .16492 L
.58095 .16022 L
.5819 .16178 L
.58286 .15866 L
.58381 .15557 L
.58476 .15711 L
.58571 .1525 L
.58667 .15403 L
.58762 .14946 L
.58857 .15097 L
.58952 .14644 L
.59048 .14794 L
.59143 .14344 L
.59238 .14494 L
.59333 .14047 L
.59429 .14196 L
Mistroke
.59524 .13753 L
.59619 .139 L
.59714 .13462 L
.5981 .13607 L
.59905 .13173 L
.6 .13317 L
.60095 .12888 L
.6019 .1303 L
.60286 .12605 L
.60381 .12746 L
.60476 .12324 L
.60571 .12464 L
.60667 .12047 L
.60762 .12186 L
.60857 .11773 L
.60952 .1191 L
.61048 .11502 L
.61143 .11637 L
.61238 .11101 L
.61333 .11236 L
.61429 .11368 L
.61524 .10838 L
.61619 .10969 L
.61714 .10577 L
.6181 .10707 L
.61905 .1032 L
.62 .10448 L
.62095 .09941 L
.6219 .10068 L
.62286 .10193 L
.62381 .09692 L
.62476 .09816 L
.62571 .09446 L
.62667 .09569 L
.62762 .09085 L
.62857 .09206 L
.62952 .09325 L
.63048 .08848 L
.63143 .08966 L
.63238 .08499 L
.63333 .08616 L
.63429 .0873 L
.63524 .08271 L
.63619 .08384 L
.63714 .07935 L
.6381 .08047 L
.63905 .08158 L
.64 .07716 L
.64095 .07825 L
.6419 .07394 L
Mistroke
.64286 .07502 L
.64381 .07608 L
.64476 .0708 L
.64571 .07185 L
.64667 .07288 L
.64762 .06775 L
.64857 .06877 L
.64952 .06978 L
.65048 .06479 L
.65143 .06578 L
.65238 .06676 L
.65333 .06191 L
.65429 .06287 L
.65524 .06382 L
.65619 .05912 L
.65714 .06005 L
.6581 .06097 L
.65905 .05642 L
.66 .05732 L
.66095 .05821 L
.6619 .05381 L
.66286 .05468 L
.66381 .05554 L
.66476 .05046 L
.66571 .0513 L
.66667 .05213 L
.66762 .05295 L
.66857 .04728 L
.66952 .04809 L
.67048 .04887 L
.67143 .04965 L
.67238 .04501 L
.67333 .04577 L
.67429 .04652 L
.67524 .04212 L
.67619 .04285 L
.67714 .04357 L
.6781 .04427 L
.67905 .03874 L
.68 .03943 L
.68095 .0401 L
.6819 .04076 L
.68286 .04141 L
.68381 .03624 L
.68476 .03687 L
.68571 .0375 L
.68667 .0381 L
.68762 .03278 L
.68857 .03337 L
.68952 .03395 L
Mistroke
.69048 .03452 L
.69143 .03507 L
.69238 .03562 L
.69333 .03023 L
.69429 .03076 L
.69524 .03127 L
.69619 .03177 L
.69714 .03226 L
.6981 .02707 L
.69905 .02754 L
.7 .028 L
.70095 .02845 L
.7019 .02889 L
.70286 .02931 L
.70381 .02972 L
.70476 .02415 L
.70571 .02454 L
.70667 .02492 L
.70762 .02529 L
.70857 .02565 L
.70952 .02599 L
.71048 .02633 L
.71143 .02665 L
.71238 .02101 L
.71333 .02131 L
.71429 .02161 L
.71524 .02189 L
.71619 .02216 L
.71714 .02241 L
.7181 .02266 L
.71905 .02289 L
.72 .02311 L
.72095 .02332 L
.7219 .02352 L
.72286 .0237 L
.72381 .01472 L
.72476 .01488 L
.72571 .01504 L
.72667 .01519 L
.72762 .01532 L
.72857 .01544 L
.72952 .01555 L
.73048 .01565 L
.73143 .01574 L
.73238 .01581 L
.73333 .01588 L
.73429 .01593 L
.73524 .01597 L
.73619 .016 L
.73714 .01602 L
Mistroke
.7381 .01602 L
.73905 .01602 L
.74 .016 L
.74095 .01597 L
.7419 .01593 L
.74286 .01588 L
.74381 .01581 L
.74476 .01574 L
.74571 .01565 L
.74667 .01555 L
.74762 .01544 L
.74857 .01532 L
.74952 .01519 L
.75048 .01504 L
.75143 .01488 L
.75238 .01472 L
.75333 .0237 L
.75429 .02352 L
.75524 .02332 L
.75619 .02311 L
.75714 .02289 L
.7581 .02266 L
.75905 .02241 L
.76 .02216 L
.76095 .02189 L
.7619 .02161 L
.76286 .02131 L
.76381 .02101 L
.76476 .02665 L
.76571 .02633 L
.76667 .02599 L
.76762 .02565 L
.76857 .02529 L
.76952 .02492 L
.77048 .02454 L
.77143 .02415 L
.77238 .02972 L
.77333 .02931 L
.77429 .02889 L
.77524 .02845 L
.77619 .028 L
.77714 .02754 L
.7781 .02707 L
.77905 .03226 L
.78 .03177 L
.78095 .03127 L
.7819 .03076 L
.78286 .03023 L
.78381 .03562 L
.78476 .03507 L
Mistroke
.78571 .03452 L
.78667 .03395 L
.78762 .03337 L
.78857 .03278 L
.78952 .0381 L
.79048 .0375 L
.79143 .03687 L
.79238 .03624 L
.79333 .04141 L
.79429 .04076 L
.79524 .0401 L
.79619 .03943 L
.79714 .03874 L
.7981 .04427 L
.79905 .04357 L
.8 .04285 L
.80095 .04212 L
.8019 .04652 L
.80286 .04577 L
.80381 .04501 L
.80476 .04965 L
.80571 .04887 L
.80667 .04809 L
.80762 .04728 L
.80857 .05295 L
.80952 .05213 L
.81048 .0513 L
.81143 .05046 L
.81238 .05554 L
.81333 .05468 L
.81429 .05381 L
.81524 .05821 L
.81619 .05732 L
.81714 .05642 L
.8181 .06097 L
.81905 .06005 L
.82 .05912 L
.82095 .06382 L
.8219 .06287 L
.82286 .06191 L
.82381 .06676 L
.82476 .06578 L
.82571 .06479 L
.82667 .06978 L
.82762 .06877 L
.82857 .06775 L
.82952 .07288 L
.83048 .07185 L
.83143 .0708 L
.83238 .07608 L
Mistroke
.83333 .07502 L
.83429 .07394 L
.83524 .07825 L
.83619 .07716 L
.83714 .08158 L
.8381 .08047 L
.83905 .07935 L
.84 .08384 L
.84095 .08271 L
.8419 .0873 L
.84286 .08616 L
.84381 .08499 L
.84476 .08966 L
.84571 .08848 L
.84667 .09325 L
.84762 .09206 L
.84857 .09085 L
.84952 .09569 L
.85048 .09446 L
.85143 .09816 L
.85238 .09692 L
.85333 .10193 L
.85429 .10068 L
.85524 .09941 L
.85619 .10448 L
.85714 .1032 L
.8581 .10707 L
.85905 .10577 L
.86 .10969 L
.86095 .10838 L
.8619 .11368 L
.86286 .11236 L
.86381 .11101 L
.86476 .11637 L
.86571 .11502 L
.86667 .1191 L
.86762 .11773 L
.86857 .12186 L
.86952 .12047 L
.87048 .12464 L
.87143 .12324 L
.87238 .12746 L
.87333 .12605 L
.87429 .1303 L
.87524 .12888 L
.87619 .13317 L
.87714 .13173 L
.8781 .13607 L
.87905 .13462 L
.88 .139 L
Mistroke
.88095 .13753 L
.8819 .14196 L
.88286 .14047 L
.88381 .14494 L
.88476 .14344 L
.88571 .14794 L
.88667 .14644 L
.88762 .15097 L
.88857 .14946 L
.88952 .15403 L
.89048 .1525 L
.89143 .15711 L
.89238 .15557 L
.89333 .15866 L
.89429 .16178 L
.89524 .16022 L
.89619 .16492 L
.89714 .16335 L
.8981 .16808 L
.89905 .1665 L
.9 .17127 L
.90095 .16967 L
.9019 .17448 L
.90286 .17287 L
.90381 .17608 L
.90476 .17933 L
.90571 .17771 L
.90667 .18259 L
.90762 .18096 L
.90857 .18587 L
.90952 .18423 L
.91048 .1875 L
.91143 .19082 L
.91238 .18917 L
.91333 .19415 L
.91429 .19248 L
.91524 .1975 L
.91619 .19582 L
.91714 .19916 L
.9181 .20255 L
.91905 .20086 L
.92 .20594 L
.92095 .20424 L
.9219 .20762 L
.92286 .21105 L
.92381 .20934 L
.92476 .21448 L
.92571 .21276 L
.92667 .21618 L
.92762 .21965 L
Mistroke
.92857 .21792 L
.92952 .22311 L
.93048 .22138 L
.93143 .22659 L
.93238 .22485 L
.93333 .22832 L
.93429 .23183 L
.93524 .23008 L
.93619 .23357 L
.93714 .2371 L
.9381 .23534 L
.93905 .24063 L
.94 .23887 L
.94095 .24237 L
.9419 .24594 L
.94286 .24417 L
.94381 .2495 L
.94476 .24772 L
.94571 .25125 L
.94667 .25484 L
.94762 .25306 L
.94857 .25842 L
.94952 .25663 L
.95048 .26018 L
.95143 .2638 L
.95238 .26201 L
.95333 .26556 L
.95429 .2692 L
.95524 .2674 L
.95619 .27281 L
.95714 .27101 L
.9581 .27457 L
.95905 .27823 L
.96 .27643 L
.96095 .27999 L
.9619 .28367 L
.96286 .28186 L
.96381 .2873 L
.96476 .28549 L
.96571 .28904 L
.96667 .29276 L
.96762 .29095 L
.96857 .29448 L
.96952 .29824 L
.97048 .29645 L
.97143 .30193 L
.97238 .30015 L
.97333 .30356 L
.97429 .30756 L
.97524 .30611 L
Mistroke
.97619 .30902 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[38]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000J0?ooo`030000
003oool0oooo0?l0oooo103oool001X0oooo00<000000?ooo`3oool0o`3oool40?ooo`004`3oool5
@0000080oooo00<000000?ooo`3oool0o`3oool40?ooo`005@3oool00d000000oooo0?ooo`020?oo
o`030000003oool0oooo0:00oooo1`3o001L0?ooo`003`3oool3@00000<0oooo00=000000?ooo`3o
ool00P3oool200000003@000003oool0oooo09/0oooo0P3o00000`3oool0o`000?ooo`050?ooo`<0
o`00F@3oool001D0oooo00=000000?ooo`3oool00P3oool00`000000oooo0?ooo`2K0?ooo`H0o`00
1P3oool50?l005L0oooo000E0?ooo`03@000003oool0oooo0080oooo00<000000?ooo`3oool0V@3o
ool30?l000l0oooo0`3o001E0?ooo`00503oool2@00000@0oooo00<000000?ooo`3oool0U`3oool4
0?l00180oooo0`3o001C0?ooo`006P3oool00`000000oooo0?ooo`2E0?ooo`@0o`005@3oool40?l0
0540oooo000J0?ooo`030000003oool0oooo09@0oooo0`3o000I0?ooo`<0o`00D03oool001X0oooo
00<000000?ooo`3oool0T`3oool30?l001/0oooo0`3o001?0?ooo`006P3oool00`00001000000?oo
o`2B0?ooo`<0o`007@3oool30?l004h0oooo000J0?ooo`030000003oool0oooo0940oooo0`3o000O
0?ooo`<0o`00C@3oool001X0oooo00<000000?ooo`3oool0T03oool20?l002<0oooo0P3o001<0?oo
o`006P3oool00`000000oooo0?ooo`2?0?ooo`80o`009@3oool20?l004/0oooo000J0?ooo`030000
003oool0oooo08h0oooo0P3o000W0?ooo`80o`00BP3oool001X0oooo00<000000?ooo`3oool0S@3o
ool20?l002T0oooo0P3o00190?ooo`006P3oool00`00001000000?ooo`2<0?ooo`80o`00:`3oool2
0?l004P0oooo000J0?ooo`030000003oool0oooo08/0oooo0P3o000]0?ooo`80o`00A`3oool001X0
oooo00<000000?ooo`3oool0R`3oool00`3o0000oooo0?ooo`0]0?ooo`80o`00AP3oool001X0oooo
00<000000?ooo`3oool0R@3oool30?l002l0oooo0`3o00150?ooo`006P3oool00`000000oooo0?oo
o`290?ooo`80o`00<@3oool20?l004D0oooo000J0?ooo`030000003oool0oooo08P0oooo0P3o000c
0?ooo`80o`00A03oool001X0oooo00<000000?ooo`3oool0Q`3oool20?l003D0oooo0P3o00130?oo
o`006P3oool00`00001000000?ooo`270?ooo`030?l0003oool0oooo03D0oooo0P3o00120?ooo`00
6P3oool00`000000oooo0?ooo`260?ooo`80o`00=`3oool20?l00480oooo000J0?ooo`030000003o
ool0oooo08D0oooo0P3o000i0?ooo`80o`00@@3oool001X0oooo00<000000?ooo`3oool0Q@3oool0
0`3o0000oooo0?ooo`0i0?ooo`030?l0003oool0oooo03l0oooo000J0?ooo`030000003oool0oooo
08@0oooo0P3o000k0?ooo`80o`00@03oool001X0oooo00<000000?ooo`3oool0P`3oool20?l003d0
oooo0P3o000o0?ooo`006P3oool00`000000oooo0?ooo`220?ooo`80o`00?`3oool20?l003h0oooo
000J0?ooo`03000004000000oooo0880oooo0P3o000o0?ooo`80o`00?P3oool001X0oooo00<00000
0?ooo`3oool0PP3oool00`3o0000oooo0?ooo`0o0?ooo`80o`00?@3oool001X0oooo00<000000?oo
o`3oool0P@3oool00`3o0000oooo0?ooo`110?ooo`030?l0003oool0oooo03/0oooo000J0?ooo`03
0000003oool0oooo0800oooo0P3o00130?ooo`80o`00?03oool000/0oooo00=000000?ooo`3oool0
0P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00<000000?ooo`3oool0
O`3oool20?l004D0oooo0P3o000k0?ooo`002P3oool00d000000oooo@00000070?ooo`03@000003o
oom0000000<0oooo00<000000?ooo`3oool0O`3oool20?l004H0oooo00<0o`000?ooo`3oool0>@3o
ool000D0oooo0d0000020?ooo`03@000003ooom0000000T0oooo00A000000?ooo`3oool0oooo0P00
00000d000000oooo0?ooo`1l0?ooo`80o`00A`3oool20?l003X0oooo000:0?ooo`03@000003ooom0
000000L0oooo0T0000040?ooo`030000003oool0oooo07h0oooo00<0o`000?ooo`3oool0A`3oool0
0`3o0000oooo0?ooo`0h0?ooo`002P3oool00d000000oooo@00000070?ooo`03@000003oool0oooo
00<0oooo00<000000?ooo`3oool0O@3oool20?l004X0oooo00<0o`000?ooo`3oool0=`3oool000/0
oooo00=000000?ooo`3oool01P3oool3@00000<0oooo00<000000?ooo`3oool0O03oool20?l004/0
oooo0P3o000h0?ooo`006P3oool00`000000oooo0?ooo`1l0?ooo`030?l0003oool0oooo04/0oooo
00<0o`000?ooo`3oool0=P3oool001X0oooo00<000000?ooo`3oool0N`3oool20?l004d0oooo0P3o
000g0?ooo`006P3oool00`000000oooo0?ooo`1k0?ooo`030?l0003oool0oooo04d0oooo00<0o`00
0?ooo`3oool0=@3oool001X0oooo00<00000@000003oool0NP3oool00`3o0000oooo0?ooo`1?0?oo
o`030?l0003oool0oooo03@0oooo000J0?ooo`030000003oool0oooo07X0oooo00<0o`000?ooo`3o
ool0C`3oool20?l003D0oooo000J0?ooo`030000003oool0oooo07T0oooo00<0o`000?ooo`3oool0
D@3oool00`3o0000oooo0?ooo`0c0?ooo`006P3oool00`000000oooo0?ooo`1h0?ooo`80o`00D`3o
ool20?l003@0oooo000J0?ooo`030000003oool0oooo07P0oooo00<0o`000?ooo`3oool0D`3oool0
0`3o0000oooo0?ooo`0b0?ooo`006P3oool00`000000oooo0?ooo`1g0?ooo`80o`00E@3oool20?l0
03<0oooo000J0?ooo`030000003oool0oooo07L0oooo00<0o`000?ooo`3oool0E@3oool00`3o0000
oooo0?ooo`0a0?ooo`006P3oool00`00001000000?ooo`1f0?ooo`80o`00E`3oool20?l00380oooo
000J0?ooo`030000003oool0oooo07H0oooo00<0o`000?ooo`3oool0E`3oool00`3o0000oooo0?oo
o`0`0?ooo`006P3oool00`000000oooo0?ooo`1e0?ooo`80o`00F@3oool20?l00340oooo000J0?oo
o`030000003oool0oooo07D0oooo00<0o`000?ooo`3oool0F@3oool00`3o0000oooo0?ooo`0_0?oo
o`006P3oool00`000000oooo0?ooo`1d0?ooo`80o`00G03oool00`3o0000oooo0?ooo`0^0?ooo`00
6P3oool00`000000oooo0?ooo`1d0?ooo`030?l0003oool0oooo05/0oooo00<0o`000?ooo`3oool0
;P3oool001X0oooo00<00000@000003oool0L`3oool00`3o0000oooo0?ooo`1M0?ooo`030?l0003o
ool0oooo02d0oooo000J0?ooo`030000003oool0oooo07<0oooo00<0o`000?ooo`3oool0G@3oool2
0?l002h0oooo000J0?ooo`030000003oool0oooo0780oooo00<0o`000?ooo`3oool0G`3oool00`3o
0000oooo0?ooo`0/0?ooo`006P3oool00`000000oooo0?ooo`0S0?ooo`=000000`3oool00d000000
oooo0?ooo`020?ooo`03@000003oool0oooo01l0oooo0d0000020?ooo`03@000003oool0oooo0080
oooo00=000000?ooo`3oool0503oool20?l000P0oooo0T0000040?ooo`03@000003oool0oooo0080
oooo00=000000?ooo`3oool07`3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080
oooo00=000000?ooo`3oool06`3oool4@0000080o`0000<0oooo@000003oool00`3oool00d000000
oooo0?ooo`020?ooo`03@000003oool0oooo01l0oooo000J0?ooo`030000003oool0oooo02<0oooo
00=000000?ooo`3oool00P3oool00d000000oooo@00000020?ooo`03@000003ooom000000240oooo
00I000000?ooo`3ooom000000?oood0000020?ooo`03@000003ooom0000001D0oooo00<0o`000?oo
o`3oool01`3oool00d000000oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oo
od0000007`3oool00d000000oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oo
od0000007P3oool01d000000oooo0?ooo`3o001000000?oood0000000P3oool00d000000oooo@000
00020?ooo`03@000003ooom000000200oooo000J0?ooo`030000003oool0oooo02@0oooo00M00000
0?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood0000007`3oool4@00000040?oo
od000000oooo@0000080oooo00=000000?oood000000503oool20?l000T0oooo00=000000?oood00
00000P3oool00d000000oooo@00000020?ooo`03@000003ooom0000001l0oooo00=000000?oood00
00000P3oool00d000000oooo@00000020?ooo`03@000003ooom0000001h0oooo00=000000?ooo`3o
ool00P3o00001`3ooom000000?ooo`3ooom000000?oood0000000P3oool00d000000oooo@000000P
0?ooo`006P3oool00`000000oooo0?ooo`0T0?ooo`07@000003oool0oooo0?oood000000oooo@000
00020?ooo`03@000003ooom0000001l0oooo00=000000?oood0000000P3oool00d000000oooo@000
00020?ooo`03@000003ooom0000001@0oooo00<0o`000?ooo`3oool0203oool2@00000<0oooo00=0
00000?oood0000000P3oool00d000000oooo@000000P0?ooo`07@000003oool0oooo0?oood000000
oooo@00000020?ooo`03@000003ooom0000001h0oooo00M000000?ooo`3oool0oooo0?l0003ooom0
00000080oooo00=000000?oood0000000P3oool00d000000oooo@000000P0?ooo`006P3oool00`00
001000000?ooo`0S0?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool00d00
0000oooo@000000P0?ooo`9000000P3oool00d000000oooo@00000020?ooo`03@000003ooom00000
01<0oooo0P3o000:0?ooo`03@000003oool0oooo0080oooo00=000000?oood0000000P3oool00d00
0000oooo@000000O0?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool00d00
0000oooo@000000N0?ooo`04@000003oool0oooo0?ooo`80o`0000I000000?ooo`3ooom000000?oo
od0000020?ooo`03@000003ooom000000200oooo000J0?ooo`030000003oool0oooo02@0oooo00=0
00000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0200oooo00E0
00000?ooo`3oool0oooo@00000040?ooo`03@000003oool0oooo0180oooo00<0o`000?ooo`3oool0
2P3oool2@00000<0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`0O0?ooo`03@000
003oool0oooo0080oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`0L0?ooo`900000
103oool20?l000<0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`0O0?ooo`006P3o
ool00`000000oooo0?ooo`1^0?ooo`80o`00I`3oool20?l002X0oooo000J0?ooo`030000003oool0
oooo06h0oooo00<0o`000?ooo`3oool0I`3oool00`3o0000oooo0?ooo`0X0?ooo`006P3oool00`00
0000oooo0?ooo`1]0?ooo`030?l0003oool0oooo06T0oooo00<0o`000?ooo`3oool09`3oool001X0
oooo00<000000?ooo`3oool0K@3oool00`3o0000oooo0?ooo`1Y0?ooo`030?l0003oool0oooo00h0
oooo0T0000020?ooo`=0000000H0oooo@000003ooom000000?oood0000020?ooo`900000203oool0
01X0oooo00<000000?ooo`3oool0K03oool20?l006`0oooo00<0o`000?ooo`3oool0303oool01400
0000oooo0?oood0000020?ooo`0:@000003oool0oooo@000003ooom000000?oood000000oooo@000
00X0oooo000E0?ooo`H0000000<0o`00000000000000JP0000020?l006d0000000<0o`0000000000
00000`0000000d000000oooo0?ooo`060?ooo`03@000003oool0oooo00<0oooo00U000000?ooo`3o
oom000000?oood000000oooo@000003oool00d0000080?ooo`006P3oool00`000000o`000?l00008
0?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool0203oool00d000000oooo0?ooo`09
0?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool0203oool00d000000oooo0?ooo`08
0?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool0203oool00d000000oooo0?ooo`07
0?ooo`80o`002P3oool00d000000oooo0?ooo`080?ooo`03@000003oool0oooo00P0oooo00=00000
0?ooo`3oool0203oool00d000000oooo0?ooo`080?ooo`03@000003oool0oooo00P0oooo00=00000
0?ooo`3oool0203oool00d000000oooo0?ooo`080?ooo`03@000003oool0oooo00P0oooo00=00000
0?ooo`3oool0203oool00d000000oooo0?ooo`0;0?ooo`A000000P3oool2@0000080oooo0T000000
103ooom000000?ooo`3oool3@00000P0oooo000J0?ooo`030000003oool0o`0006X0oooo0P3o001m
0?ooo`03@000003oool0oooo01L0oooo000J0?ooo`030000003oool0o`0006X0oooo0P3o00230?oo
o`03@000003oool0oooo0140oooo000J0?ooo`040000003oool0oooo0?l006P0oooo0P3o002H0?oo
o`006P3oool010000000oooo0?ooo`3o001X0?ooo`030?l0003oool0oooo09L0oooo000J0?ooo`05
0000003oool0oooo0?ooo`3o0000I`3oool00`3o0000oooo0?ooo`2G0?ooo`006P3oool010000010
00000?ooo`3oool20?l006D0oooo00<0o`000?ooo`3oool0V03oool001X0oooo00<000000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`1R0?ooo`80o`00VP3oool001X0oooo00<000000?ooo`3oool0
0P3oool20?l006<0oooo00<0o`000?ooo`3oool0V@3oool001X0oooo00<000000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`1P0?ooo`80o`00V`3oool001X0oooo00<000000?ooo`3oool00`3oool2
0?l00640oooo00<0o`000?ooo`3oool0VP3oool001X0oooo00<000000?ooo`3oool0103oool00`3o
0000oooo0?ooo`1N0?ooo`80o`00W03oool001X0oooo00<00000@000003oool0103oool20?l005l0
oooo00<0o`000?ooo`3oool0V`3oool001X0oooo00<000000?ooo`3oool01@3oool20?l005d0oooo
0P3o002M0?ooo`006P3oool00`000000oooo0?ooo`050?ooo`80o`00G@3oool00`3o0000oooo0?oo
o`2L0?ooo`006P3oool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo05X0oooo0P3o002N
0?ooo`006P3oool00`000000oooo0?ooo`060?ooo`80o`00F`3oool00`3o0000oooo0?ooo`2M0?oo
o`006P3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo05P0oooo00<0o`000?ooo`3o
ool0WP3oool001X0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`1G0?ooo`030?l0
003oool0oooo09h0oooo000J0?ooo`03000004000000oooo00P0oooo00<0o`000?ooo`3oool0EP3o
ool00`3o0000oooo0?ooo`2O0?ooo`006P3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0
oooo05@0oooo0P3o002Q0?ooo`006P3oool00`000000oooo0?ooo`090?ooo`80o`00E@3oool00`3o
0000oooo0?ooo`2P0?ooo`006P3oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0580
oooo0P3o002R0?ooo`006P3oool00`000000oooo0?ooo`0:0?ooo`80o`00D`3oool00`3o0000oooo
0?ooo`2Q0?ooo`006P3oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0500oooo0P3o
002S0?ooo`006P3oool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo04h0oooo0P3o002T
0?ooo`006P3oool00`00001000000?ooo`0<0?ooo`80o`00C`3oool20?l00:@0oooo000J0?ooo`03
0000003oool0oooo00`0oooo0P3o001>0?ooo`80o`00Y@3oool001X0oooo00<000000?ooo`3oool0
3@3oool20?l004d0oooo00<0o`000?ooo`3oool0Y03oool001X0oooo00<000000?ooo`3oool03@3o
ool20?l004`0oooo0P3o002V0?ooo`002`3oool00d000000oooo0?ooo`020?ooo`03@000003oool0
oooo0080oooo00=000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`80o`00B`3oool0
0`3o0000oooo0?ooo`2U0?ooo`002P3oool00d000000oooo@00000070?ooo`03@000003ooom00000
00<0oooo00<000000?ooo`3oool03`3oool20?l004T0oooo00<0o`000?ooo`3oool0YP3oool000X0
oooo00=000000?oood0000002@3oool014000000oooo0?ooo`3oool200000003@000003oool0oooo
00d0oooo0P3o00180?ooo`80o`00Z03oool000X0oooo00=000000?oood0000001`3oool2@00000@0
oooo00<000000?ooo`3oool0403oool20?l004L0oooo0P3o002X0?ooo`002P3oool00d000000oooo
@00000070?ooo`03@000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`3o0000oooo
0?ooo`140?ooo`80o`00Z@3oool000/0oooo00=000000?ooo`3oool01P3oool3@00000<0oooo00<0
00000?ooo`3oool04@3oool20?l004@0oooo0P3o002Z0?ooo`006P3oool00`000000oooo0?ooo`0B
0?ooo`80o`00@`3oool20?l00:X0oooo000J0?ooo`030000003oool0oooo0180oooo0P3o00130?oo
o`030?l0003oool0oooo0:T0oooo000J0?ooo`030000003oool0oooo01<0oooo0P3o00110?ooo`03
0?l0003oool0oooo0:X0oooo000J0?ooo`03000004000000oooo01@0oooo00<0o`000?ooo`3oool0
?P3oool20?l00:`0oooo000J0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool0?03o
ool20?l00:d0oooo000J0?ooo`030000003oool0oooo01D0oooo0P3o000m0?ooo`80o`00[@3oool0
01X0oooo00<000000?ooo`3oool05P3oool20?l003/0oooo0P3o002^0?ooo`006P3oool00`000000
oooo0?ooo`0F0?ooo`80o`00>P3oool20?l00:l0oooo000J0?ooo`030000003oool0oooo01L0oooo
0P3o000h0?ooo`80o`00/03oool001X0oooo00<000000?ooo`3oool0603oool20?l003L0oooo0P3o
002`0?ooo`006P3oool00`00001000000?ooo`0I0?ooo`030?l0003oool0oooo03@0oooo0P3o002a
0?ooo`006P3oool00`000000oooo0?ooo`0I0?ooo`80o`00=03oool20?l00;80oooo000J0?ooo`03
0000003oool0oooo01X0oooo0P3o000c0?ooo`030?l0003oool0oooo0;40oooo000J0?ooo`030000
003oool0oooo01/0oooo0P3o000a0?ooo`80o`00/`3oool001X0oooo00<000000?ooo`3oool0703o
ool20?l002l0oooo0P3o002d0?ooo`006P3oool00`000000oooo0?ooo`0L0?ooo`80o`00;P3oool2
0?l00;D0oooo000J0?ooo`03000004000000oooo01d0oooo0P3o000/0?ooo`80o`00]P3oool001X0
oooo00<000000?ooo`3oool07P3oool20?l002/0oooo00<0o`000?ooo`3oool0]@3oool001X0oooo
00<000000?ooo`3oool07`3oool20?l002P0oooo0P3o002h0?ooo`006P3oool00`000000oooo0?oo
o`0P0?ooo`80o`009`3oool20?l00;P0oooo000J0?ooo`030000003oool0oooo0240oooo0P3o000T
0?ooo`80o`00^P3oool001X0oooo00<000000?ooo`3oool08P3oool20?l002<0oooo0P3o002j0?oo
o`006P3oool00`000000oooo0?ooo`0S0?ooo`80o`00803oool20?l00;`0oooo000J0?ooo`030000
04000000oooo02@0oooo0P3o000N0?ooo`<0o`00_03oool001X0oooo00<000000?ooo`3oool09P3o
ool20?l001/0oooo0P3o002n0?ooo`006P3oool00`000000oooo0?ooo`0V0?ooo`<0o`006@3oool2
0?l00;l0oooo000J0?ooo`030000003oool0oooo02P0oooo0`3o000D0?ooo`<0o`00`@3oool001X0
oooo00<000000?ooo`3oool0:@3oool30?l00180oooo0`3o00320?ooo`004`3oool5@0000080oooo
00<000000?ooo`3oool0:`3oool50?l000/0oooo103o00340?ooo`005@3oool00d000000oooo0?oo
o`020?ooo`030000003oool0oooo02d0oooo1@3o00060?ooo`D0o`00aP3oool001D0oooo00=00000
0?ooo`3oool00P3oool200000003@000003oool0oooo02d0oooo00<0o`000?ooo`3o00001P3oool0
103o0000oooo0?ooo`3o00370?ooo`005@3oool00d000000oooo0?ooo`020?ooo`030000003oool0
oooo0340oooo203o003:0?ooo`005@3oool00d000000oooo0?ooo`020?ooo`030000003oool0oooo
0?l0oooo103oool001@0oooo0T0000040?ooo`030000003oool0oooo0?l0oooo103oool001X0oooo
00=000000?ooo`3oool0o`3oool40?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00I@3oool2@0000;T0oooo001W0?ooo`03@000003oool0
oooo0;H0oooo001I0?ooo`=000000`3oool3@00000<0oooo0d0000050?ooo`04@000003oool0oooo
0?ooo`9000001P3oool00d000000oooo0?ooo`070?ooo`=0000000@0oooo@000003oool0oooo0T00
00020?ooo`=000000`3oool2@00000<0oooo0T0000030?ooo`9000000P3oool3@00000<0oooo0T00
00030?ooo`=00000L03oool001P0oooo0d00000o0?ooo`03@000003oool0oooo00<0oooo00E00000
0?ooo`3oool0oooo@00000020?ooo`03@000003oool0oooo00T0oooo00=000000?ooo`3oool03P3o
ool01T000000oooo0?oood000000oooo@00000@0oooo00=000000?ooo`3oool00P3oool014000000
oooo0?oood0000020?ooo`9000000P3oool00d000000oooo0?ooo`030?ooo`05@000003oool0oooo
0?oood000000103oool014000000oooo0?oood00001`0?ooo`006@3oool00d000000oooo0?ooo`0n
0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003o
ool0oooo00P0oooo00=000000?ooo`3oool03`3oool3@0000080oooo0d0000020?ooo`03@000003o
ool0oooo0080oooo00I000000?ooo`3ooom000000?oood0000020?ooo`03@000003ooom000000090
00000`3oool014000000oooo0?ooo`3oool3@0000080oooo00A000000?ooo`3ooom00000L03oool0
00h0oooo0T0000002@3ooom00000@00004000000oooo@000003ooom000000?ooo`03@00000H0oooo
00=000000?ooo`3oool0=@3oool2@00000<0oooo0T0000040?ooo`=000002`3oool00d000000oooo
0?ooo`0>0?ooo`05@000003oool0oooo@000003oool00d0000020?ooo`=000000`3oool2@0000003
0?oood00001000000080oooo00=000000?oood0000000T0000020?ooo`A0000000@0oooo@0000400
001000000`3oool3@0000700oooo000>0?ooo`04@000003oool0oooo0?ooo`90000000H0oooo@000
003ooom000000?oood0000020?ooo`03@000003oool0oooo03/0oooo00A000000?ooo`3ooom00000
4`3oool00d000000oooo@000000@0?ooo`04@000003oool0oooo@00002L0oooo00=000000?ooo`3o
ool0KP3oool000l0oooo0d000000203ooom000000?oood000000oooo@000003ooom000000P3oool0
0d000000oooo0?ooo`0j0?ooo`E000000P3oool00d000000oooo0?ooo`0?0?ooo`03@000003oool0
oooo00h0oooo1400000W0?ooo`900000L03oool000l0oooo00A000000?oood000000oooo0T000000
0`3ooom000000?ooo`04@0000?l0oooo1@3oool00100oooo00=000000?ooo`3oool0o`3oool>0?oo
o`003`3oool2@0000?l0oooo403oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-121.932, -1.18358, 4.53354, 
  0.0149266}}]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "To check up recoverability, we compute a maximum absolute difference \
between the original and recovered one-dimensional image data.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["Max[Abs[sample1D[[1]]-sinR]]", "Input",
  CellLabel->"In[40]:=",
  FormatType->InputForm],

Cell[BoxData[
    \(0.0218712469948547649`\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "As you can see, about 2 percent error has been occurred by the finite \
resolution=100 limit. Finally, we remove the needless memories and check the \
used memories. Thereby, it is possible to know that the ",
    TextAlignment->Left,
    TextJustification->1,
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" front-end uses about 1.7 mega bytes memories.",
    TextAlignment->Left,
    TextJustification->1,
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
Remove[\"sample1D\",\"sample1DG\",\"label\",\"eigenMat\",\"eigenPatternM\",
\t\"eigenM1DG\",\"inverseMat\",\"sinR\",\"sinRG\"];
memoryUsed\
\>", "Input",
  CellLabel->"In[41]:=",
  FormatType->InputForm],

Cell[BoxData[
    InterpretationBox[\(1706\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ 1706, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.3.2 Eigen pattern of a monochrome image",
  FontSize->12]], "Subsection",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Sample images",
  FormatType->InputForm,
  FontFamily->"Times New Roman"]], "Subsubsection",
  FormatType->InputForm],

Cell[TextData[{
  "\t",
  StyleBox[
  "This section extracts the eigen patterns of the monochrome images. At \
first, we have to read in a sample image data by",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["sample=rgbBMP[\"BF001.bmp\"];", "Input",
  CellLabel->"In[43]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\t",
  StyleBox[
  "After computing an array size and three-dimensional vector magnitude of \
the sample image, Fig. 4 shows the original monochrome sample image.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
dim=Dimensions[sample];
monoSample=vectorMag3D[sample];
ListDensityPlot[monoSample,PlotRange->All,Mesh->False,Frame->False,
\tPlotLabel->\"Fig.4. Original monochrome sample\"];\
\>", "Input",
  CellLabel->"In[44]:=",
  FontFamily->"Times New Roman"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -101 0 ]
[.5 1.0125 101 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.4) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Original) show
159.000000 12.812500 moveto
(monochrome) show
225.000000 12.812500 moveto
(sample) show
261.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F1EFF7F7F1EFECECF7ECEFCFCFCFD2D8D2D2D2D2D2EFE990
C7D2C7C7C1C8C8BFC8CAC8CAC1C1C8C8CDCDCACAC8C8C8CA
C0CACACAD3D3D3D3D3D3D3CDD3CACAD0D3CACACACACAC8C8
C8C8CACAC7CACAC8CACAC8E0EFE099C1C1C8C8C1C1C1C7C7
C7C7C7C7CFCDCDCDD8D3D8D8D8D2D8CFC9C7BDBDC1C1BFBD
DDE0B1CFE9F4F7F1
F1F4F4ECEFF7F7F1F1F7EFECD2D2D2D2D2D2D2CFCFCFE9AB
CACFC9C7C7C1C1C1C2C8CAC8CAC8C2CACFCACAC8C8C0C2C8
C8C1C8CAC8CACDD0CACAD3CACAD3CACACACACAD0CACAC8C8
CACACACACAC7C1CACAC8CAC8E0EFAB9DC8C8C8C1C1C1C1C1
C8CACACACDCACFCACFCFD2D2D2D8D2D2C7C9C7C7C1C1C7E6
E9BFBDC1E9F4F1EF
ECECECEFF1F1F1EFF1F1F7F7F4D2CFCFCFD0CFCFCDCFE3E9
86C7CDC9C1BCC1C8C8C8CAC8CAC8C1C0CDCDCAC8C2C2BFBF
BCBCBCC2C8CACACDCACACACAC8CACACFD3D3CDD0D3CACACA
CACACACACAC8CACACACACACAC8D2EFE08EC1C1C1C8C7C1C1
C8C1C1CACFCDCFCDCFCFD2D8D8D8D2CFCDC7CAC7C7CFD7D5
E6D5BFC1DDECF7EF
EFF1F4F7F1F7F7ECF7F7EFF1EFECECD8CDCFCACACACACAE9
D8B6C7C9C9C1C1C1C1C1C8CACAC8C1C1C8CACACAC2C8BFBC
BFBFBCBAC1C8C8CACAC8CAC8C8C8CDD8D3D3D3D8D3D3CDD3
D3CACACDCDCDCACDCDCACACACACAD2EFE09DCACACACACACD
CACACDCACDCACFCDCFD2D8D8D8D2D8CDCDC9CFC9E9D7D5E6
BFDDC7BFE9E9E9EF
F1F4F1F4F7F4F4F1F7F7F7F7EFF7F1EFD8CFD3CACDCAD3E9
E9B6CACDCFC1C1C1C8C1C1C8C8CAC8C8CAC8C2C2C2C8C8C8
C8C8C2BCBFC1C8C0C0C0C8CACACACACAD3CACAD8D8CDD3D0
D3D0CACFCFCDCDCFCFCFCACFCACACAD2EFB1B9CACDCDCDCA
CACACDCFCDCFD3CFCFD3D8D8D8D8D2D2D2C9D8ECE9E6E6EC
CFE3BFBFE9F7EFEC
F1F4ECF4F1EFF4F7ECF4F4ECF7F7F4F7F4DDCFD3CFCFCFD2
E9E6CACFCFC9C7C1C1C8C7CACAC1C1C8C1BCC2C2BFC8C8C8
CAC8CACAC0BCBCC2BCC8C1C8CACACACACAD0D3D3CAD2CFCF
CFD3CFD3CFD2CFCDCFCDCDCDCACDCACAD2EFC1B9CACFCFCD
CDCDCDD3D3D3D3CFD3D2D2D8D8D8D2C9C6BFD7E6EFC7D7C7
D2E9C1D7F4F4F4EC
F1F7F7F7ECF7ECF4F4F7ECF7F7F1F7F7F7F7EFD8D8D8D8D8
D8EFDACDD2D2CFC9C7C1C1BFBFC1BAB3BABABABFBAC8CACD
CDCDCDD3C8C8BCC2BFC2BCBFC1C0C8C8CACACDCACACACACA
CDCACACFCFCDCDCDCACACACACAC7CACAC7D8EFE0C7CACACA
C8CDD0D3D3CFD3CFD8D2D8D8D8C9C7B6ACC1E9DDECC9CFCF
CFCFBDE9F4EFF7F1
F1EFF4F4F4F7F4F7F1F1ECF1F1F7F4F7F7F7F4F1E3E0E0E0
DDDDEFD895D2CDCAC1C1C1C1BFB3B3BABABABABABAC1C8CA
CDCDCDD3CACAC0BCBABABCC1BCBABABCC1C1C1C8C1C1C2C1
C8C1C8C7C1C7C8C8C1C1C1C1C1C1C1C8C1C1DAE9C9C7C8CA
CACACACFD3CFCFD8D8D2D2D2C7C1A3ABACC7D7C7B1C1C8BD
D7C9BFE6F4ECEFF1
F1F7F1F7F7F7F1EFF4F4F7F4F1ECF7F4F7F7F1F7F1F7F4F4
F7F7F4F4EFBDC7CAC7C1C1C1BCBFB8BFBFC2C8C8C2BAC2C8
CDCDCDCDD3CDC8BDC2C8C0C2C2C1C1BABAB1B3B1ACB3B1B1
B1ACB1B1B3B3B3B3B3B3B3BFBCBFBFBFBCBABFB3D2D2AE9D
B3C1C1CACACACFD2D2D8D2C997A1B1B4B1B1C9C7C1BDBFDD
CFBFDAE6F1F4ECEC
F7F4F7EFF7F7F7F4F4ECEFF1F1EFF7F1ECF7F1F7F4F7F4F1
F7F4F4EFF7F1BFA3D5C1B6C1C1BFB8B8B3BABFC2C2BABFC8
C8D3CDD3CDCACAC2C2C2C2C8C2C8C8C8C2C8C2C2BFBCBFBC
BCBCBFBCBCC2BFC2C1C1C8C8BCC8C8C8C1C8C1C1C2CDCFD2
C15EBCB6C1C7C7C9AE8C868692B1BDC1B1BDBFC1CFC7B1D8
D5B1DDDDEFF4F7F1
ECF1F7F1F4ECF1F4F4F7ECF4F7F7F4F4F4F7F4F7F4F7F1F4
F4F1F7F1F4F4BFA1B3ACB6BFBFBFBFC1B8BABFC2C2BABDC8
CAC8CACDCDCDCDC8C2C2C8C8C8C8C8C8C8C2C0C8C8C8C8C1
BFC2C2C8C8C2C2C2C1C8C8C8C8C8C2C8C2C8C8CAC8C1CAC8
CFCBDAAE9595A98D8692868CA1A1BDB3ABE6BDBDC6AAD2DD
BFDDC9ECE9ECECF7
F7F1EFF7F1F7F7ECEFEFF7F4F7F1F7F1F4F4F7F1F7F7F7F7
F1F1ECECF4ECC9C797ABAB99BFC1BCBFB6BDBFBAC2BDBDC8
C8C8CACACDC8CDC8C8C2C2C8C8C8C8C8C8C8C8C0C2C2C8C8
C8BFC2C1C0C2C8C8C0C8C8C8C8C2C2C8C1C8BFC8C8C8C8C1
C1C1CFD2D2BD6E718C868C97979997ACB8DDA1AFC7AAC9D5
BDECE6ECECF1F1F7
F1F7F7F1F1F7EFF7F7F7F1F7F7F4EFF7F7F7F7EFF4F7F7F4
F1F1F4F1F1F1D2C9AE97AB8571B6BFBCBCBFBCBFBDBABFC8
C8C8C8C8CDC8C8C8C8C8C8C8C8C8CAC8C8C8C8C2C2C2C8C2
C2C8BFC0C2C2C2BFC1C8CAC8C8C0C8C8C2C2C2C8C8C1C1C1
BFB3A9A386778685818597929799AFAFB1C7AAAFBDAFD5C7
CFE6ECF4E6F7F7F4
F7F4F1F4EFF7F1F7ECF7F1F7EFF7F1F7F7F7F1F4F7F7F1F7
EFECF1F7EFF1DDE6D5929785755ABCB6BFB3B6BCBFBDBFC8
C8C8C8C8CAC8C8C8C8C8C2C2C2C2C8C2C8C8C8C2C2C2C2C2
BFBFBFC2C2C2C2BFC2C2C8BFC2C2C8C8C2BFC2C2C2BABFB3
B1A3977B77869292958C859797A8B1AFBFB1A1AFAFC7C7C7
D5F4ECEFEFF4F4EC
F1F4F7F4ECF7F7F7EFF7F4F1F7F1F7F7EFF1F4F1F7ECF7F4
EFF7F4F4ECEFD7EFC7928685725A44ACB1B3BFBCBFBABDC1
C8C8C8C8C2C8C8C8C8C8C8C8C2C8C2C2C2C8C8C8C8BDBDC2
C2C2C2C0C2BFBDBDBFC0C8C2C8C2BFC8C8C2C2BFBABAB1AF
A1A186718C928692A3928C92A897ABA1ACAABDBDBDDDB1C9
ECECF4E9F1ECF7F4
EFF1F1EFF1F7ECEFECF7F7F7EFF7EFEFF7F1F7F4F1F7F1EF
F7EFF7F4EFECDDE6C9BD858C755A4444B3B3BAB3BFBDBAC8
C8C8C8C8C8C2C2C8C8C2C2C2C2BDBFC2C8C8C8C2C2C2BFBD
BDBAC2C2C2BDBFB5BFBDC2C2C2C2C2C2BDAFAFAAA1A1A1A1
8C665A86A197739299ABA8A8929297A1B1AABDBDE6BFC7D8
E9E6E9EFEFF1F7F4
ECF7F4F1F7F1F1F4F7F4F4F7F4F7F4F7F7F4F7F4EFEFF7F4
F1ECF4EFF4ECEFDDDDAB8C866E5A514439B1BCACBDBABDC2
C8C2C2C2C2C8C2C2C8C2C2C8C2C2BDBDC2C2BFC8C2BDBABD
BABABABABDBABAB5B5B5BDC2B5C2AFBDBAB5AAAAA1998C7B
5A6B6E8C979791A1A1A8A1A1A89297AAAAAFBDC1BFC7D5E6
E9DDE9F4F4F1F7F7
EFECF7F7F7ECF7F7F7EFF1F7EFF4ECF4F1F1F7F7F7F4F4F7
F1F1EFF4EFE9E6CFDD928C856B5A5A51391FA9B6B3BABAC1
BFC2C2C2C2C8C2C8C2C2C2C2BFC2C2BDBDBDBDC2C2BFBDBD
BABDB5AFB5BDB5B5BDB5BDBAB5AFBAB1B1AFAAA3947B716E
66738D99929197A1978C8C9792A8AAAAA8BDC1C1C7E6E6DD
E9F4EFF7F7F7F7F7
ECF7F4F7F7F7EFF4F7F7F4F1ECF4F7F7F7F7F4F1F4F4F4F7
F4F4F4F1EFF4E9D5DD978C866E5A5A5132321FB3B3BFBCBF
BFC2C2C2C2C2C8C8C2C2C2C2C2C2C2BDBDC2BDBFBDC0BABA
BABAB5B5B5B5AFAAAFB5AFBFAAB1AFAFA3ACA1866B714C73
7B869792919591A8A1A1A1A8A8AAAFABBDBFC1C1D2D8DDE6
ECEFF7F4F7F4F1F7
F7F7ECF7F4F7F7F7F4F4ECF4F7F1ECF4F4F7F7EFF4F7F1F1
F4F7F4F1EFECE6DDD2978C776E665A44322739B3B3BABFBF
C1BFC8C2C8C2C2C2C2C2BDC2C2BDC2BDBFBDBABAB5BABABA
BAB5B5AFACAAAAAAAFBFAFA3A1A3A5A594948586556B6671
6686928C8C91A1A1ABB1A1A8BDABAFBDBDC1BFD2D8D8EFEF
F7F7F4F4F7F1F7F7
F7F4EFEFF4F1F7EFF7EFF1F7F7F4F7EFF7F4F4F4F7F1F1F7
F7F4F7EFF4ECE9D5AB978C7B6B755A543939484BB6BDBFC8
BFBFC8C2C2C2C2C2C2BFC2BFBAC0C2BDBDBDBDB5BDAFBABD
BAB5B5ACAC99A1B1BFB19499A199A1998685726E86738686
8D9799919291A19299A1A1AAA1A1BDBDBDBFCFD8E6E6F4F7
F1ECF7F7F4F4F7F4
F7F7F1F7F1F4F4F7F7EFF7F7F7F7F1F4F7F1F4ECF1F7F1F4
F7EFF4EFECE6E9CBAB8C8C777B715454444C5132B3BFC1C8
BFBFC2BDBDC2BDBDC2C2BDBDBDBDBDC2BABABABDAFBDAFB5
B1AFACA799A1A1BDBF9499A1A194817A6685756E71858677
8C9797928C7BAB97AB99BDA1AABDBDBDBDC7C9E6E9E9F4F7
ECF7F7F7F1F7F7F7
F7F1F7EFF7F7F7F7F7F4F7F7F7F7F4EFF7F7F4F4ECF7F4F7
F1F1F7F7EFE6E6B3AB8C7B73666651545A5A441FBFBAC1BF
C2BFC2BDBDC2BDBDBDBDBDBDBDBDBDBABDBABAAFAFAFB5AF
B1B1A7A19494AFB3948E8E918E81795E7385757575777377
8C97998D8D97A399A19999A8A8AABFBFC1D8EFE6E9ECF7F7
F4F7F7F1F4F1F7F7
F7F7F7F1F7F7F4F7F4F7F4F7F7F7F7F4F4F4F4F4F7F7F4F7
F1F7F7F7F1E6D7ABA18D817773544C5A5E543D39C1BCC8C1
BAC2BFBFC2BDC0BDBDB5BDBDB5B5B5B5BDAFB5B1AFB5AAAC
AAA3A1909497A1998C8E8C8C81666C6C7192868575718D86
8C8D9295ABA1A195999999A1BDC1C8C1D8DDE6ECE6ECEFEC
F7F7F4F7F7F7F7F7
F7F4F7F7F7F4F4F7F7F4F7F7F7F7F4F7F4F4F7F7F4F7F4F4
F4F4F4EFF1E6D5AE998C7B73715E5A715A393932C1BCBFB3
BFC2C2B5B5BDBAB5B5B5AFB5B5AFAFB5ACB5ACACACACAAAA
A1A199928EA391817A867B81647B71717386928C7B868186
8D7B9195ABABAB9799AB97A1BDBFC7D8E6EFE6ECE6EFEFF7
F7F7F4F1F4F1F4F7
F7F7F7F4F7F7F4F7F7F7F4F7F7F7F7F7F7F7F7F7F4F7F4F4
F7EFF1F7F7E6C1A1A18D7B737354665A4C323D32BFBFBFBF
BFBAC2BDB5BDB5AFB5AFACAFACAFACACACB1AFAAA7A3AAA3
A3A1998C9994817A7B73735E6C6C5A66779292929986867B
7B8D958CA9ABA395ABB1A1AFBDBDD8E0E6DDE6ECF4F4F4F7
F4F7F7F7F4F4F7F4
F7F7F7F7F4F4F7F4F1F7F7F7F7F4F7F7F7F7F7F4F7F7F4EC
F4ECF7F4EFEFACA1918C666C5E5E665E483D4839C1B6BFBA
BFBAB5BDB5B5B5AFACACACA5A7AAA7A7ACAAAAA1A5A1A1A1
A194948C998C7B73717164736C5E5E667585928C928C8D7B
7B778CA1A3A1AEAEAB99A1AFBFC9DDDDE6EFECE6F4F7F4F7
F7F7F7F7F4F7F7F4
F7F4F4F7F4F4F7F7F7F4F1F7F7F4F7F7F4F4EFF1F7F4F4F7
F7F4F7ECEFD5AEA18C81737B5A66665E3232393DBFB3BCB3
BABAB5B5B5ACAFAAA7AAA7A7A5999999A1A1A7A1A1999999
94948E8D7B7371667173736666666E75778592A8A1AF9171
717B918CA1ABABAB979797BDC7C9DDE6DDECE6F7F4F7F7F7
F7F4F7F7F7F1F7F4
F4F7F7F4F4EFF1F1F4F7F7F7F1F7F4F7F4F7EFF7F7F7F7F7
F4F1F4EFEFC1AB958D7B666C5E71544C2A2A3939BFB3BABC
BAB5B5ACAAAAAAAAA5A3A1A5A1A199999999A1A19999998E
8E8C818C77665E73667373484854728585858C97A199AB8D
7B8C8C998CAEAE99979997BDC7E6DDE6E6E9F1F7ECEFF7F7
F4F7F7F7F4F7F7F7
F7F7F7F7F4F7F7F7F7F7F7F7F7EFF4F7EFF7F4F7F4F7F4EF
F4F7ECF4DDB8AB8D81736C5E5E665444393D3D44B3B3B1B1
B5B1ACB1ACACA3A5A5999999909494909999909999998E8C
8E8C7B9273546C6C665E4C48326E857285778697A8A3AF8D
8D978D9995AB99998C92AFC7D8DDDDDDECEFEFF7F4F4F7F7
F7F1F7F4F7F4F7F7
F7F7F4F7F4F4F1F4F4F7F4F7F7F7F7F7F1EFF4F1F7F7F4F7
F7F1F4ECC9AE9F81816C71665E5E3D3D393D3D3DB3B1B3C1
B7B7B5B7B5B5B1ACACA3948C94898C8C8C8C94948C8C8C81
817A7B8C664B66735448444B5A6B85857B857197A1AB9995
8C91918DABAB97A197ABABC6EFD8DDECE9F7F7F7F7F4F7F7
F7F7F7F7F7F4F7F4
F4F7F7ECECF7F4F7F7F4F4F7F7F1F7F4F7EFF4EFF7F7F4F4
F1F1F1E6C6AB95817B73667B5E5E27453D3D3954B3C7CACA
CAC8C8C0C0C0B9B7B7B1ACA389898689898181818C898186
7B7373865455665E4C393D6E4C6686857B717B92A3AFB1AB
95958177ABAB9599ABABBFECE6E6E6ECEFF4F7F4F7F7F7F7
F4F7F7F7F7F7F4F1
F7F4F4F7F7F7F4F7F7F7F7F7F7F4F7F7F4F7F7ECF7F4F7EF
F1F4F4CFB8A19181795E665E664C3248453D3986CACDD8D0
D0CACAD0CACAC0C0BCB7B1ACA799867B818686897A818681
7B73647B5E667B4C443949755166778675717B8C92AFB1AB
A1957B8DA1A1A1A1BDA1BFECDDD5E9E9F7F4F7F1F4F1F4F4
F7F7F4F7F7F7F7F7
F4F7EFF7F4EFF7F1F7F7F7F7F4EFF7F4F4F7F4F4F7F4F1F1
EFF4F4CFAC958D797373665E66323D4B3D3D8DCDD3D8D3D8
D0D8D0D3D0CAC8CAC0C0B7B5ACAAA1997B7B7B7B867B817B
716C554C7B5E8C4439273271775A7792718D7B8CA1AFBDC1
AE778D8D9991A1AEABAAE9DDD2E6EFF4F7F7EFF7F7F7F7F4
F4F7F7F7F7F4F7F7
F7F4F7F7F7F7F7F1F4EFF7F7F7EFF4F7F4F4F4F4F7F7F7F7
F1E9D5C79F95816C5E66665E50324B4B3DC9D3CDD3D8D8D8
D8D8D0D0D0D3CAC8C8C8BFB3B1B5ACA3997A73737B737A73
71664C488C4C94663D49274C86517786758C8C8C97A1BFC1
AB91818D9595ABAEABBDDDD7DDECECF7EFF7F4F7F7F4F4F7
F4F4F7F7F7F7F7F7
F7F7F7F7F1F7F7F7F7F7F7F7F1F4EFF7F7F4F7F7F7F7F7F4
ECE9CBBD958D817364665E5E3D39483D81CFD3CAD3D3D8D8
D8D8D8D8D0D0CACACAC1BCBFBAB5B3ACA390997171736C71
645E51458679817B39274866868C86868C73918D95A1ABBF
BD8D7B8D8695B8BDB4AEC7E6EFEFF4F7F4F7F4F7F4F4F7F7
F7F7F4F7F7F7F4F7
F1F7F4F7F7F7EFF7F4F4F7F4F4F4EFF7F4F4EFF7F7ECF7F1
ECDDCBAC958D7B6C555E545E2A3D455ECACDD3D3D3D3D8D0
D8D0D0D8D0D0CAC8CACAC8BCBCBAB3B1ACA3999066717161
66504B326CA354996473396E558D6E85868D869581AB97C1
CF8D7B8D919FA1ABAEBDDDE6E9EFECF4F7F4F7F7F4F4F7F4
F4F7F4F4F7F4F7F7
F4F7F4F7F7F7F4F4F7F7F7F7F4F4F7F4F7F7F7F7F7F7F4E9
E9CFCB9F91797B645E5E543D39505ACDCACDD3D3D3D0CDCA
CACACACAC8C0C0C1C8BFC2BCBCB1B5B3B1ACA19994665E66
55543D3D558D816C9F51815E71778671868D668D8DA1A1AC
B1BD8D778D9F95ABBDD7ECDDECEFECF7F4F4F7F4F7F7F4F7
F4F7F7F7F4F7F7F7
F7F7F4F7F7F7F4F7F4F4F4F4F7F7F4F7F4EFF1F4F4F7F7E9
D7CFB4958179645E5E5E323D3939CDCDD3CDCACAD0CAC2BC
B7B7B1B1B1ACB1B1B1B1BABABABCBAB1B1ACA7A3A1947A5E
5451453D4964998D7AA186814C718C8586718181A395A1AB
C1C98D95A39591ACBFEFDDF4ECEFECF7F7F4F7F1F4F7F4F4
F7F7F7F7F7F7F7F4
F7F4F7F7F7F4F7F7F7F7F4F7F7F7F7F7F4F4F4F7F7F4F4E9
D5CBAE957B7B71555E54393D50C9CFCFD3CDCACAC8C1B7B5
ACA7A6A6A6A6A6ACA7ACB1ACBABABCB3B1ACA9A399998E5E
4E4B3D2A3D6299795EA9869781667392867B8D81A195ABA1
ABC7ABA19F9FA1AEC1E6E6EFECF4F7F4F7F7F1F7F7F7F4F7
F7F4F7F7F7F7F7F7
F7F4F7F7F4F7F7F7F7F7F4F7F7F7F7F7F7F4EFEFF7F4ECD7
CFCE9F8179667155503D3D444BCDCDCACACACAC8C0958999
999D9D9D9D9D89898989A3B1B1BABABAB3B1ACA3A399908C
4B3D3927395579A38690AB97A195867B8C8D717B8DA18DAF
AEBDC19FAB95A1BDCBD7E9ECE9ECEFF7F1F4F7F4F7F7F7F4
F7F7F4F7F7F4F7F7
F7F4F7F4F7F4F7F7F7F7F4F7F7F4EFF7F7F4F7F7EFF7E9DD
D5AE957A6C665E4B55453D4BD2CDCACAC8CDCAA69D9D9DCD
C0A6A6B5C09D9D99908D89A3B1B3BABCB3B1B1A9A3999D8E
81492A2A27552AA9B166AE81AAAB8D8C976E8C818D9599A3
AEC1C9958695A1ACE6E6ECECE6F7F7F1F4F4F7F4F7F4F4F7
F7F4F7F7F4F4F7F4
F4F7F4F7F4F7F4F7F4F4F7F4F4F4F4F4F4EFF7F7F1F7DACB
AC95867A555E555E323D3D81CFCFCFCAC8C8C8999D9D9995
95959D89897D7F7FA68D8D7DABB7BABABABAB1A9A3A39999
8C793D3D17395E8695818DAB8CAFCD8D7B8C8C73819795A1
A1C1C19F959F95ACE6E9EFE9E9F7F7F7F7F7F7F7F4F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F4F4F7F4F4F4F7F4F4F4F7F7F4F4F7F4F4F4D7C3
A1957964555E503948395ED2D2CFCACAC8A69D795E677579
75757D6F5E565B674D655B4E619DBABABAB1B1B1A3A3A1A3
8E815E1F173D495A8DA95EA981A3BFCD9999758C818D9181
ABBDC1BDA1AB9FB8DDECE6ECF4ECF7F7F4F7F4F7F7F7F7F7
F7F7F7F4F7F4F7F7
F4F4F4F7F7F4F4F7F4F7F4F7F4F7F4F4F4F4F4EFF4E9D7BD
958164555E544B4B4B4ED2D2CDCFD3CAC8C0C8A68D897F89
7F89997F7F7F7F7F7FA1A9ABB1B1BABAB5B5B1B5ACA3A3A1
998E71361717365A71A3956CA181BFBFCF798C8C818D8D81
ABABC1C795ABA1D5E9E9E6E6F4F4F4F4F7F7F7F7F4F7F7F4
F7F7F4F7F7F4F7F7
F7F4F4F7F4F7F7F7F4F7F4F7F7F7F7F7EFF7F4ECEFE6CEAE
866C6C5E5450454B4C54CFCACFCDCACDC8CDD3D3D8D8CDCA
D8CAC8D3D8CDCAC1BCC1BCBABABCBABCBAB7B1B1ACACA3A1
99998154280B5A495A718D668C738CBFBFA1998D7B7B8D99
A199C1C79F9F91DDE6E6E9E6F7F7F7F4F7F7F7F7F7F7F4F7
F4F7F7F7F4F7F7F7
F4F7F7F7F7F7F4F7F7F7F4F7F4F4F7F7F4EFF4F4E9C6BF9F
7964545451394B4B48B8CFCFCFD0D3CAD3CAD3D3D8D3D8D3
D8C8CACACABCBCBCBCBFBCBFC8BCBABFBCB7B7B1ACACA39D
99998161271F495481719F665E918DB3BFC8AB8C8C917B81
8199C1C7A1AE95E6E9DDE6EFF7F7F7F4F7F7F4F4F4F7F7F7
F7F7F7F7F7F7F7F4
F4F7F4F4F4F4F7EFF7F7F7F7F4F7F4F7F4F4EFF4F4CE9F81
666C50513D4B4B4B4BCFCFCDCFD3D0D0D3CFD3D3D3D3D3D3
CFCAC8C8C8BCBFC2BCC1BCC8BCC8BCBCB7B7BAB1ACA7ACA1
99998E6C4536174F5564667966817A99BDBD99A18C8D7B8D
7BA1ABC1AC95A3D7E6E6D5F7F4F7F7F4F7F4F7F7F7F7F4F7
F7F7F4F4F7F7F7F7
F7F4F7F4F4F7F7F7F4F7F7F7F7F7F7F7F7F4F4EFCEC3957B
6C505E3D4B394B503DCFCDCDCFD3D3D3D0D3D3D3D3CFD3D3
C8C8BCC8BCB5BABFBCC0C2C8C0C0CAC8BCBCB7B5ACACA3A1
9D908E7B49272A49626B71866C5E649591A8C8AB86916C95
8DA3A1C1AC8DC9D5E9E9E9F4F7F7F7F7F7F7F4F7F7F7F4F7
F4F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F4F7F7F7F7F4F4F4F7F7E9C6A6956C
66644E4B4B494B3D86C9CDCDD3D3D3D3D8D3CFD3D3D3CACA
BCB1ACB7B3ACB1B7BABCC2C1C8CACAC0C0BCB7B1ACACA3A3
A199897A5E363D3C5A5571647B546655AEBDA1AA91957A81
8D9FA1BFB895DDC1F4E9F7F7F7F7F7F7F4F7F7F7F7F7F7F4
F4F7F7F4F7F7F7F7
F4F7F7F7F7F7F4F7F4F4F7F7F4F7F7F7EFF7F4F4BF957964
55554B3D3D4B4B39C9CDCDD0D3D3D3D3D3D3CDD3D3D3CAC0
B9BAA7ACACA3A9B1B1BABCC2C0C8C8C8C0C8BDB7B1ACA3A3
A1908E8161360B2349546C557B66664BA98CA1CD95919181
8D8C95BFBDBDCBD7D7D2F7F7F7F7F7F7F4F7F7F7F7F7F7F7
F7F7F7F4F7F7F7F7
F7F7F7F7F7F7F7F4F7F7F7F4F7F7F7F7F7F7F7E9AE866454
553D4B454B4E3932CDC7CACAD3D0D8D8D3D3D3D0D8A799CA
CAC0B5757590A781A1B1BCC8C8CACACAC8C0BCB7B5ACACA3
A1998E7A714517233249555A6C6C546C5E8DAFA1AF8C8D66
8181A1BDBDE9ACE9B8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F4F7
F4F4F7F4F4F7F7F7F7F4F4F7F4F7F7F7F7F7F4E095796466
4B4B3D484B3D3255CDCACFD3D8D3D0D8D0D3CDD3D8CFCDD0
D0CABAB1B3B5BAAC94A3BCCACACACACAC0C8C8BDB5B1ACA3
99998E89715E0B17233C4F5E5571545E2AAB9497BF818D6C
798D95ACC6C6ACB8F7F7F4F7F7F7F7F7F4F7F7F7F7F4F7F7
F7F7F7F4F4F7F7F7
F7F7F7F7F7F7F4F7F7F4F4F7F7F7F7EFF7F7F7D78D64613D
4951454B5132327CC7D0D0D0D8D8D8D8D8D3D3D0D8CDD8D8
D8D0C8BAB9B9B3B1ACACC0CACAD0CACACAC0C0C0BAB5B1A7
9D9D8E8173640B1F17495564456C545E32958DABBF818D79
818695AEC6C6BDCBF7F7F4F7F7F7F7F7F7F7F4F7F7F7F7F7
F7F7F7F7F4F7F7F7
F7F7F7F4F7F4F7F7F4F7F4F7F7EFF7F4F4F7F4D2795E5E54
4B4B5055482A36C9CDD3D3D8D8D8D8D8D8D8D0CAD8D8D8E3
D8D0CAC1B7B5B3B1ACB7C0CACACDCAD0CAC8C8C0C0B7B5AC
A7999081735E2A001F452A66546C48545E7991AAAAA1818D
798181ACC7B8D2F4F7F7F7F7F7F7F7F4F4F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F4F4F7F4F4F7F7F4F7F7F7EF9564643D45
454B514B1F321FCAD0D2D0D8D8D8D8D8D8D8D8D3D3D0D8D8
D8D3CAB7ABACB1ABB3BCCACDCDCFD3CACAC8CAC8C0B7B5B1
ACA1908179714906173656555E644B5449718C99B1C17B81
718195BFC79FCBF7F4F7F4F4F4F7F7F7F4F7F7F7F7F7F7F7
F7F7F4F7F7F7F7F7
F4F4F7F7F7F4F7F7F7F7F7F7F4F7F4F7F7F7F18864503D55
51514B172A2736CAD3D8D8D8D8D8D8D8D8D8D8D8D0D2D0D8
D0CDC0BCABB1B3B3BCCACACACDD0D3CDD0CAC8CAC0C0B7B5
A9AC998E796C550B282A454954546654547A8D97B1CD817B
6C7A86ACC6CBF4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7
F7F7F4F4F7F7F7F7
F7F7F7F7F4F7F7F7F7F7F7F4F7F4F7F4F4F4F4885E4B4B55
494B512A1F2AACCFCFD8D8D8D8D8E0E0E0D8D8D8D8D3CDD8
D8CAC0B3B3B1BABCC1CACFCDD0D0D8D2D0CDCACAC0BCBCB3
ACA3A18E7A6C641F06322A555E4B5E6654719FA1AFCD7991
5E8679BDCFCBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F4F7
F4F4F4F7F7F7F7F7F7F7F4F4F4F7F7F4F4F7CB715E455454
514B2A1F17C0D2D0D8E0D8D8E0D8D8D8D8D8D8D8D8D8D3D8
D8D0CABCB3BABABCC1CDCDD8D8D0D8D0D8D2D2CDCAC7C0BA
B1A9A3A1816C6645323D49496454665E5571A9A1ABC18D7B
547A81B1D5ECF7F7F7F7F7F7F7F7F7F4F7F7F4F4F7F7F4F7
F4F7F7F7F7F7F7F7
F4F7F4F7F7F7F7F7F7F4F7F7F4F7F7F7F7F7715E54325649
49512A3D36CACDD8D8D8D8E0E0D8D8D8E0D8D8D8D8D8D2D8
D8D8D0BCB3BCBFC1C1C7CFD8D2D8D8D8D0D2D2D2CDCAC1BC
B3B1A3A1897A61493D3D3D555466645E6F88A3A1A1AB9171
507A95AEDDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F4
F7F7F7F4F7F7F7F7
F4F7F7F7F7F7F7F7F7F7F7F7F4F7F7F7F4F77966493D5E55
4B453D2A83D0D2D8D8D8E0E0D8D8D8D8D8D8E0E0D8D8D8D8
D8D0D0BCB3B3BFC1CACAD2D2D2D8D8D0D0D8D3CFCDCACAC1
B3B1A9A18E7A615532323D49516466645EA1A1A1A1A9AB73
737986AFECF7F7F7F7F7F7F7F7F7F7F7F7F7F4F7F4F7F7F7
F7F7F7F7F7F7F7F7
F7F7F4F7F4F7F7F7F4F7F7F7F7F7F7F7F7F4717155494555
51324555CDD3D2D8D8D8D8D8D8D8D8D8D2D8D8D8D8D8D8CD
D8D8D8C1B7B3BCC1C1C7CDD2D2D2D8D2D8D2CDCDCACDC7C1
C1B3A9A399816C5545393D3D555E625550AEA195A39FB15E
797981ABEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F4F7
F7F7F7F7F7F7F7F7
F4F7F7F7F4F7F4F7F4F7F7F7F7F7F7F4F7AE5E62545E5455
3D3645C7D8CDD8D8D8D8D8E0D8D8D8D2CDCDD2D2D8D8D0D3
D8D8D8CAB7B1B3B6BFB6C9CFCDD8D2D2D2CDC9CDCACACAC1
C1B6B1A99D8E6C5E492A3D3D496C5E5E5E9F95A1A16CBD4C
6C8D95ACF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F4F7F7F4F7F7F7F7F7F7F7F7F4F77E8D6C496C4955
32494BC7D0C7D8D8E0D8D8D8D8D2D2C0C7CACACDD2D8CFD3
D8D8D8CAB5B1ABB3B3C1C9CDD2C7C7C1C7C7C7C7CACDC7C7
B8BFB1A9A18E795E512A273D495E665E5E9F9999A151AF61
5E88A9C7F7F7F7F4F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F4F7F7F7F4F7F7F7F4F4F4F4F7F754925E6B5A5E49
2A66B5CAB7CDD8D8D8D8D8D2CFCDCDCAB6B3C1C7CDD2C7CD
D8D8D8C0B3A7AEABACB8C7C9C1C1B8B9B1B1ABB6B6C1C1C1
BFBFB3A999907A6C554517323D5E5E6C5595A3818D50BD6C
5595ABD5F7F7F7F7F7F7F7F7F4F7F7F7F7F7F7F7F7F7F7F7
F4F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F4F7F4F7F7F7F7FF6C7C555E556127
5451D099ACCFD8D8D8D8D2C9B6958DABAA95B6B6D2D2CDCD
D8D8D8CAB3A39FA3BFB6C9B9B6A99D888D9F9F9FAABFC1B6
B6B6B1A99F90816155493D32325554625E888D81815EBD5E
559FA1D7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F4F7F7F7F7F4F7F4F7F7F7F7F7F7F7F7A07A714955496132
5EBDC0A6ABCFD2D8D8CDB9868DB6AE6267839F9D9DCDCDC7
D8D8D8C8BCA3A995A95E7D90ABCB79547E7C7A7C88ABB3B3
B6B6ABAB99907A6C5E49552A2A55555E6C86957B815ABF66
71ABABE9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F4F7F7F7F7889D716232556139
2AD0B5B5B3D2D8D2C7B98890C0D76D6250737E9F95B9B3C8
D8D8CFCABCAC9588909F65CBE96E6F628559A0716788A9A9
B3B1ABA3A188796C5449320B1F555E456C88866C7A71B150
95AEAEF7F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7F7F4F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F4F7F7F7F7F7F7FFF481544B32555555
61D0ACA6B3C9CFCAB6956F3697B777B30C6E426F8895BCCD
D8D8D3CABFBA958D718D956CC250BD0C6750A0284F7C8D95
A9ABA995958E796155511F171F2A554979717A7A8171AB50
8DA3C6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F792C8866F5349555561
8DC0A6A3B1CDCFBCAA904961613C23365567617C95B7C2D3
D3D8D3CAC2BCAC9590796F8B8B362A3636493C54537C8688
99A3A3958881615E5E493D1F363D3D496C796C668179AB64
8DA1E6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F4F7F7F7F7F7F7F7
F7F7F7F7F4F7F7F7F4F7F7F7F7F7F779A09A5E4962554955
8EB5A3A3B1CDC9C7C1B3957A62535353556F90A9BCCACAD3
D8D8D3CACAC8BAACA395885F7C837A61463C49718D8D9099
A3A395998D7A615E5555452A3632324571817166818DAB6C
8DA9ECF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7E6896B494549493D6C
8E999F95ABC9CFCFD8D2CACDC1BCB9BCC1BCA3ACB7C8D8D3
D8D8D8D3CDCABAA1A795A9ABA995959599A3A9A9B1B5B3AB
A9A399908D816162553D3D2A3649453D6C8D6C668C95B371
95DDFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F4F7
F7F7F4F7F7F4F7F7F7F7F7F4F7F7FFFF455E323D3D64325E
7A9D998DA9CFC1D3D8D8D8D8D8D8B5907C717ABCC8D8D8D8
E0D8D8D8D3D8C2B79071717A8DC1C7CAC7C1C1BCBCBCB3A9
9586998D81796C5E5455322A2A3627495E796C649195BF7A
9FE9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7E9FF3D4B323D49554966
75818D909FCAC6BFCDD8D8D8D0887C6F7AA9C8D3D3D8E0D8
E0D8D8D8D8D3D3C8B78D6155617AACB9C7CACAC0C1B3AC95
7A998D88796C6C5E3D3D2A322A274F5A6B7A715E8D8DAE95
9FF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F4F7FFAEFF5445494932554B5E
61617C889FC9D2959FA9A39D7A79A3D3D8D8E0E0E0E0E0E0
D8D8D8D8D8D8D3D3D3CDBCA98D6F5E7171898D90867C7A88
95959D8D796C6C556C1F45453D2A235F6C796C648DA18873
CBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F4F7F7A67149495F5549494955
5E62717AA9C9CFCFCAA99D9DB6D8E0E0E0E0E0E0E0E0E0E3
D8D8E0E0E0D8D8D8D8D3D0CACACAC7C79F7C797C7C959F95
99A1998D797179553D493D3217171F626F5E7A71959F6C8D
E9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F4F7F7F7F4F7F7F7F7F7C86C56497A675655495E
5E627979A3CACDCFCFD8D8D8D8D8E0E0E0E0E0E0E0E3E0E0
D8E0E0E0D8D8D8D8D8D8CFCFD3CACACAC1C7C7BCB3B1ABA3
A9958D81797A796C493D271717171F8D625EA16C81AB6C9F
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F4F7F7F7F7F4F7F7F7F7F7F7B4504F5A866B555A565A
5A5E7A71A3C7CFCFD2D8D8D8E0E0D8D8E0E0E0D8E0E0E0E0
D8D8E0D8D8E0D8D8D8D8D8D0D3CDCAC7C1CABCBCB3A9A9A3
A395958D7A79795E6C452A2A1F3227957A5E95796CAE6CBD
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7CE556762716267625A55
54546C7190BFCDCFCFD2D8D8D8E0E0D8E0E0E0E0E0E0E0E0
E0E0E0E0E0D8D8D8D3D3D3D3D3CAC8C7CAC1BFBAB3B1ABA9
A3A199817981716C49323D3217171F957C6CA17B62956CF4
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F4F7F7F7F7F7F7F7F7F4625555555F62555A55
5A557A8195BCC1CDD2D3D8D8D8D8E0E0E0E0E0D8D8E0E0E0
E0E0D8D8D8D8D8D0D3D3D3CDCACACAC0C1BFC1BCB1B3ACA9
9599908D81796C554936451F17173271A186A3817164ACF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF53675562676B625A5A
5562718D95B1C1CFD2D8D8D8D8E0E0D8D8E0E0D8E0E0D8E0
E0E0D8D8D8D8D8D8D8D3D3CDCACACAC0BCBCBCBCB7B1ABA9
A3998D86867C6C5E3D49271F1F17236F9571958D8164D2F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF7A4F5E6B6B5A625556
6B62718895ABC1CAD3D3D3D8D8D8E0E0D8D8E0E0D8D8E0D8
D8D8D8D8D8D8D8D3D8D3D3CAD3CAC8C8C1BFC1BAB3B1ABA9
95999086866C6C5E493D27170B0B53627A799F95AE95F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF557C7A5E625F5E5A66
45627C8D8DA9BFCACFD3D8D8D8E0E0D8E0E0E0D8E0D8D8E0
D8D8D8D8D8D8D8D8D8D8CAD0CDCACAC0C8BCBCB3B3B1ABA9
95A18D88716B5A495532170B230B5F6B6C6495959FDDF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F4F7F4F7F7F7F7F7F7F7F7F7F7E07C56565555545A55
62627A8D9FABBFCACFD8D8D8D8E0E0D8E0D8E0D8D8D8E0D8
D8D8D8D8D8D8D8D8D8D0D3D3CACACAC0C8BCBCB3B1B1B1A9
9FA3887C71716C563D32171723176B6B7166959FABF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF62565549544F4956
626C868DA3AEBFCAD3D0D8D8D8D8D8D8D8E0E0E0E0D8D8E0
D8D8D8D8D8D8D8D8D0D3D3D3CAD3CAC8C8C2BCB3B1ABB1A9
A99588887C625E3D321F1F0B1A17786B66649FB4CEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BA5F55555455554F
556C7C8D9FB6C1CAD3D3D8D8D8E0D8E0E0E0E0E0D8E0D8D8
E0D8D8D8D8D8D8D8D3D8D3D0CDCACAC8C8BCBCB6B1B1A9AB
99998D7C7A715E36321F23141F1F7C885E7995BFF7F7F4F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F46749494F4F5556
4F6B8695A9B3C8CACDCFD3D8D8D8D8D8E0D8E0D8D8D8D8D8
D8D8D8D8D8D8D8D8D3D3CDD3D0CACACAC1C1BFBAB1B1ABA3
A38D8D7C7162553632231F2A2A176C866C8CA9D1F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F77C674F5A564F56
5A6B7195AEC1C1CAD3D3D8D8D8D8D8E0E0D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D3D3D3CDCDCAC8C8CAC1BFBAB7B1B1ACAC
998D88796C5E4936362A1F2A170B6B716C8DB1ECF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFBA7C6B6B6B56
566B818DA3BCC8CACAD3CFD3D8D8D8D8D8D8D8E0D8D8D8D8
D8D8D3D8D3D3D3D3D8D0D3C8C8C8C8C0C1BFBAB3BAA9A9A9
8D8D7C7A6255454932321F17063688717B99ACF7F4F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F4F7F7F7F7F7F7F7F7F7F4F7F7F7F7F7FFFFE96F6B5A62
5F6279959FB3C8CACAD3D3D8D8D3D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D3D3D3D8D3CACACACAC8CAC2BCBCBCBAB1A3AB95
958D7961555A453636232A0C067A7C648191CFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFA0555F4F
62627A8DA3B6C1C0CACAD3CDCDD3D3D8D8D8D3D8D8D8D3D8
CFD3D2D3D3D3CDCACACACAC8CAC8C8C0BCBCBCB3B3ABA3A9
8D7C6C645E5A5A32322A170B88786C648DB8E9F7F4F4F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFCB3D5A7A
567A7A8D9FB3BFC7CAC8CAD3D3D8D3D2D8D3D8D8D8D8D8D3
D3D8D3CAD3CAD3CACAC8CACAC8C8BFC2BABAB6B1AC95A399
887C716C5A494F6B1F171A56557A6C7995C1F4F7F4FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFB4715555
5F7C7A8DA3B3B6C1CAC8CAD0CAD8CDD3D3D3D3D3D3D3D8D0
D0CACACAC0CAC8C8C8C8C8CAC8C8BABABCB3B3B1A9959588
7971645A5A555536493649457C71868DAEBDF7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFA69F4554
565E7186959FB8BCC1C8C0D0D0CFCFCDCAD0D3D3D8CDCFCA
CAC8C0BCBCBDC8C8C2C0C2BDBCBCB1B7B3ABABA395958D88
797A6C4F4F49493C4532816B716CA395BFF7F7F7F4F7F7FF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E0CB3245
6C5571818DABB3B6BCC0C0C8CAC7CACFCACACACDCAC8CACA
C2BCB5B7B7BABDB5B5B5B5ACB1B7A9B1A9A99FA195888686
7A715E5A564F67564967886F7C8DA9BFBDF4F7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F4F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A67A56
5A6B62717C95ABBFB6B8BCBCCACACACAC7C1C1C1C1BCB6B1
B3B3A9A9A3A3A3A1A7A3A1A19599999999908D958D88816C
626F6B546B6B49626C6C716C8D86B3BFEFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AE6F
5A626B7A887E8D95B3B8C1C8C7C1C1C1BFB3B3A9B3BFABAC
A9AB959F90998DA38D99818D81818D868688887C8D958186
7A7C62626F7C5A3D558186818DACB8BDF7F7F7F7F7F7F7F4
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E9
896F56717A628D9FBDC9C9C9C1C1B8B6A9ACABABA9ABA9A9
95958D8D888D88798886716C88718671797C7A7C626B6F79
6F716F71555A676C717A7A95B8B89FF7F7F7F7F4F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F4F7F4F7F7F7F7F7F7F7F7F7F7F7F7F7F7
897E7C7586A6AA9DB6AAB6BDBDB6B3ABA9AB959FA99F959F
9590868871957C95867C8D7A6C957A887C7A81865F6B7A78
676F7C646C646C647186ABB4ACAED2F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FF6F83756B818D8D9DB6B8B3ACABAE9F9F9F8D958D958D95
88957A717E64817A8D717C7A7C95627171887A6B6B5A5649
4F6255555656647B95ABC79DAE86F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7FF927E7CA09FA6B8B8B8B89F9F9F9F959F959588889586
7A7C64818162497C5A867A7C7C5E6C7A4549665E5A5E6664
6C646455666CAC95AEBD629D81D1FFF7F7F7F7F7F7F7F4F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7A9835F756C81A9B4B6B8A695958D95958D81868D7C86
8662957A6295625A7C62626B5A5E54455555665556645E55
515E7186869F95BFB8817A9D81F7F7F7F7F7F4F7F7F4F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7FFF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FF547A9D7E8192ACB4ABA67C88819595887588867C8D
7C865A716F627A5A62645A5F5A4F55555549455556555454
627A7A7A7A9FB4787881A695E9F4F4F7F7F4F7F7F4F7F7FF
F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F77A49929A9D92B8B8AC7A8D7C7C867A6F81816F7C
6F7C5A7A6C6B4F497A4F565A565449493D36454545546C5A
62819F95C1B49D866B9F6BE9FFFFF4F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F4F7FF7E45728392B4BDAC7A6B927C8D92866B817A62
7C7C62717A6F673249567A55553D55453D32363232495E81
958895B4925F7786816CA9F7F7F7F7F7F7F4F7FFF7F7F7F7
F7F7F7F7F7F7F7F4F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7D162565F869DACB8816B7A8D6F6F7C6762756F
676B7C6F627A71676249495F55555E546C54545E6C797C8D
9FC6929D7A496F819292F7F7F7F7F7F7FFF7F4F7F7F7F7F7
FFF7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7C0776C615F838BB8626778866F6B5A565662
626B6F62627A81716F567A55546F6B62646C7A869F8D95B8
9D9A8686567586817EFFF7FFFFF7F4FFF4FFF7F4F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FFF7F7F7F7AE6F727581899FA6676781816B81555A5A
6C6B71557E718D7C88926B5E5E717186868D8DA9A9A67C7A
7A5E45557C817895FFF7F7F7FFFFF7F7FFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F4F7F7F4F7F7BA617286929DA6AC6F8162836F7C6B55
534962567571958DC6C9B89FB6ABABABC7C7B3B48667786B
5A566286927C7EFFF7F7FFF7F7F7F7F7F7F7F4F7F7FFFFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFF7F7F182725A86B4B4AC838D83897E95A6
7A5367536F92A69D89BDC0BDC6D5D2BD9F929283726F6B4F
556F78957C92F7F7F7F4F7F7F4F4F7F7F7F4F7F7F7F7F7F7
F4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFF7F7F7FF7A618089ACCBACACC0AECBC0A9
D2D8EFE6D8D2CFBDCBC6C6C6CFB486A686787A7A6267547C
8681817CFFF7F7FFF4F7F7F7F7F4F7F7F7F7F4F7F7FFF7F7
F4F7F7F4F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7F7F7FFF7F7F7F7F7E0616E92A5C0CBD7CECBCBCB
D7C6C9CFC9D8DDD7CBD2B4A0BD9D9AA06C7A62677A839D9F
8D81A9F7F7F4F7F4F7F7F7F7F7F7F7F4F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7FFF7F4F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7FFF7FFFFF7FFF7F7FFE983808BB4B4C0C3CBD7D7
D7D7E6DDDAD7DDD2CBC0C29A8BA0787A6F8661899D9F9A89
9FE0F7F7F7F4F7F7F7FFF7FFF7F7F4F7F7F7F7F7F7F7F7F7
FFF7F7F7F7F7F7F7FFF7F7F7F7FFF7F7F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F4F7FFF7F7977A83BACBD7D7D5
D2CBDACECBC0AC9D92A6AC9A89637E9A89ACACB4AC8BACF4
F7F7F7F7F7F7FFF7F7F7F7F4F7F7FFF7FFF7F7F7F4F7FFF7
F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7FFFFFFF4F7F7F7F7
F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F4FFF7F7FFF7F7F7F7F7A097B7BAC0
DADAD7DADAD7C0C0A9A597B4CBA0C0CBC0A092BDE9FFFFFF
F7F7F7FFF7F7F7F7F7FFF7F7F7F7F7F7F4F7F7F7F7F7F7F7
FFF7FFFFFFFFFFF7F7F7F7F7FFF7F7F7FFFFF7FFF7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7AEA5C0
A9BDCECEDDDAE6EFE6D7CBD7CECBA99DB4CBE9F7F7FFFFF4
F7F7F7F7F7F7F7F4F7F7F4F7F7F7F4F7F7F7F7F7F7F7F4F7
F7F7F7F7F7F7F4F7FFF4F7F7F7F7F7F4F7F7F7F7F4F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7FFF4F4F7F7F7F4F4
F4E9E9E0EFE6CBC0C0CBCECBCBD1E9F4F7F7F7F7F7FFFFF7
FFFFFFF7F7F7F7F7F4F4F7F7F7F7F7F7F4F7FFF4F7F7F7FF
F7F7F7F7F7F7F7F7F7FFF7FFF7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7F7
F7F7F7F7F7F7F7F7FFF4F7F7F7F7F4F7F7F7F7F7F7F7F7F7
FFF7F7F7F7F7F4F4F4F4FFF7F7F7F7F7F7FFFFF7F7F7FFF7
F7F7F7F4F7FFF7F7FFF7F7F7FFF7FFF7FFF7F4F7F7F4F7F7
F7F7F7F7F7F7F7F7F7F4F7F7FFF7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7F4FFF7F7F7F4F7F4
F7F7FFF4F7F7F7F7F7F7FFF7F7F4F7F7F7F7F7F7FFF7FFF7
F7F7F4FFF7FFFFF7F7F7F7F7F7F7F7F7FFF4F4F7F4F7F7F7
F7F7F7F7F7FFF7F7F7F7F7F7FFF7F7F7F4F7FFFFF7F7F7F7
F7F7F7F7FFF7F4F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFF7F7F7F4F7F7FF
F7F7F7FFF7F7FFF7F7F7F4F7F7F7F7F7F7F4F7FFF7F7FFFF
F7F7F7F4F7F7F4F7FFF7F7F7F7FFF7F7F7F7F7F7F7F7F7FF
F4F7F7F7F7FFF7F7FFF7F7F4F7F7F7F7F7F7F4FFF7F7F7F7
F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F4F7F7F4
F7F7F7F7F7F7F7F7F7F7F7F4FFF7F7F7F4F7F7F7F7F4FFF4
F7F7F7FFF7F7F7FFF7F4F7F7F4F7F7F7F7F7F7F7F7F7F7FF
F7F7F4F7FFF7F7F7F4FFFFF7F7F4FFF7F7F7F7FFF7F7F7FF
F7F7F7FFF7F7FFF7F7FFFFF7F7FFF7F7F7F4F7F7F7F7F7F7
F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7
F7FFF4F7FFF7F7F7F7FFF7FFF7F7F7F7F7F7F4F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F4F7F7F7F7F7F7F4FFF4FFF7F7FF
F7F7F4F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7F7F7F7F7F7F7
F7F4FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F4F7F7F7F7F7F7F7F7F7F7F4F4F7
F7F7F7F4FFFFF7F7FFF4F7F7F7F7F7FFF7F4F4F7F7FFF4F7
FFF7FFF7F7FFF7FFF7F7F7F7F7FFF7F7F7F7F7F4F7FFF7F7
F7FFF7F7F7FFF7FFF7F7FFF4F7F7F7F7F7FFF7F7FFF7F7F7
F7F7F7F7F7F7F4F4
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7FFF7F7F4F7F4F7F7F7F7F7F7FF
F7F7F7F7F7F7F7F4FFF7F7F7F7F7F7F7F7F7F7F7F4F7FFF7
FFF7F7F7F4FFF4FFF7F7F7F4F7F7F7F7F7F7F7F7FFF4F4F7
F7F7F4F7F7F7F7FFF7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7
F7F7F7F7F4F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F4
F7F7F7F7F7F7F7F7F4FFF7F7F4F7F7F4F4F7F7F7FFFFF7F7
F7F4F7F7F7F7F4F7F7FFF7F4FFF7F7F7F7F7FFF7FFF7F4FF
F7F4F7F4F7F7FFF7F7F4F7F7FFF4FFF7F4F7F4FFF7FFF7F7
F7F4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F4FFFFF7F4FFF7F7
F7F7F7F7F7F7FFFFF7F7F7F7FFF7F7F7F7F7F7FFF7F7F7F7
F7FFFFFFFFF7F7F7F7F4F7FFF7F7F7FFFFFFFFF7F7F7F7F7
F7FFFFF7F7F7F7F4F7F7F7F7F7F7FFF7F7F7F7FFF7F7F7F7
FFF7FFF7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7F4
F7F4F7F7F7F7F7FFF7F7F7F7F7F7F4F7F4F7F4F7F7F7F7F7
F7F7F4F7F7F7F7F7F7FFF7F7F7F7FFF4F7FFFFF7F7F7F7F7
F7F7F7F7F7F7FFF7F7F7F7F7F4F7F7F7F7F7F7FFF7FFF7F7
F4F7FFF7F7F7FFF7F7F7F7F7F7F7F7F4F7F4F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F4F7F7F7F7F7F7FFF7FFF7F7
F7F7F7F7F7F7F7F7FFFFF7F7F7F4F7F7FFFFF7F7F7F7F7F7
F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F4F7F4F7F7FFF7F7FF
F4F7F7F7F7F7F7F7
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`003@3oool20?7al@80kno_103gmoL20?7al@80kno_103/k>`20?Ogm`80
k>c/0P3_knl60<o?c`80d];B0`3Hf=P:0=;BdP80kno_0P3YjNT2092@T080alO70P3Bd]840<O7a`80
`L711038b<P20;no_`80b<S80P3:b/X20<S8b080b/[:1031`L440<S8b0@0cLg=103:b/X60<S8b0<0
b/[:0P30`<060<[:bPh0dm?C0P3=cLd20=?Cd`@0b/[:0P3@d=020=?Cd`X0b/[:2038b<P40<[:bP80
alO7103:b/X30<S8b0@0b/[:0P38b<P20>3Ph080kno_0P3Ph>0209VIV@@0`L711038b<P60<71`@`0
alO70P3?cll60<g=c@80f=SH0P3Cdm<60=SHf080d];B0P3Hf=P30<o?c`80bLW90P37alL40;fm_@@0
`L710P2o_kl20;fm_@80gMgM0P3Ph>020;6a/@80clo?0P3YjNT20?Cdm080moOg0P3alO4?0?ooo`00
3@3oool20?7al@80kno_103gmoL20?7al@80kno_103/k>`20?Ogm`80k>c/0P3_knl60<o?c`80d];B
0`3Hf=P:0=;BdP80kno_0P3YjNT2092@T080alO70P3Bd]840<O7a`80`L711038b<P20;no_`80b<S8
0P3:b/X20<S8b080b/[:1031`L440<S8b0@0cLg=103:b/X60<S8b0<0b/[:0P30`<060<[:bPh0dm?C
0P3=cLd20=?Cd`@0b/[:0P3@d=020=?Cd`X0b/[:2038b<P40<[:bP80alO7103:b/X30<S8b0@0b/[:
0P38b<P20>3Ph080kno_0P3Ph>0209VIV@@0`L711038b<P60<71`@`0alO70P3?cll60<g=c@80f=SH
0P3Cdm<60=SHf080d];B0P3Hf=P30<o?c`80bLW90P37alL40;fm_@@0`L710P2o_kl20;fm_@80gMgM
0P3Ph>020;6a/@80clo?0P3YjNT20?Cdm080moOg0P3alO4?0?ooo`003@3oool20?7al@@0m?Cd0P3/
k>`20>o_k`@0moOg103alO420?Ogm`80kno_0P3/k>`?0=;BdPH0clo?0P3YjNT20:^[Z`80b/[:0P3?
cll20<W9b@@0alO71P31`L420<;2`P80b<S80P3:b/X20<S8b080b/[:0P38b<P20<;2`P80b/[:0P3?
cll40<[:bP@0b<S80P30`<020<;2`PD0b<S80P31`L420<S8b080b/[:0P38b<P20<[:bP80cLg=0P3@
d=040<[:bP80dm?C103:b/X20=?Cd`X0b/[:0P3@d=040<[:bP@0b<S82P3:b/X20<O7a`80`L711@3:
b/X20<S8b080b/[:0P38b<P20>3Ph080kno_0P2[Zj/209fMW@H0b<S82P31`L420<S8b0H0b/[:0P3=
cLd20<[:bP80clo?0P3:b/X40<o?c`H0d];B0P3Hf=P50=;BdP80alO70P39bLT40<O7a`@0`L710P37
alL20>KViP80jNWY0P2o_kl20;fm_@80`L710P3YjNT20?Cdm080lO7a0P3_knl?0?ooo`003@3oool2
0?7al@@0m?Cd0P3/k>`20>o_k`@0moOg103alO420?Ogm`80kno_0P3/k>`?0=;BdPH0clo?0P3YjNT2
0:^[Z`80b/[:0P3?cll20<W9b@@0alO71P31`L420<;2`P80b<S80P3:b/X20<S8b080b/[:0P38b<P2
0<;2`P80b/[:0P3?cll40<[:bP@0b<S80P30`<020<;2`PD0b<S80P31`L420<S8b080b/[:0P38b<P2
0<[:bP80cLg=0P3@d=040<[:bP80dm?C103:b/X20=?Cd`X0b/[:0P3@d=040<[:bP@0b<S82P3:b/X2
0<O7a`80`L711@3:b/X20<S8b080b/[:0P38b<P20>3Ph080kno_0P2[Zj/209fMW@H0b<S82P31`L42
0<S8b0H0b/[:0P3=cLd20<[:bP80clo?0P3:b/X40<o?c`H0d];B0P3Hf=P50=;BdP80alO70P39bLT4
0<O7a`@0`L710P37alL20>KViP80jNWY0P2o_kl20;fm_@80`L710P3YjNT20?Cdm080lO7a0P3_knl?
0?ooo`003@3oool60>c/k080kno_1P3alO420>o_k`@0lO7a103gmoL20?Cdm080d];B1`3?cll20=3@
d0@0clo?0P3=cLd20<o?c`80hn?S0P3YjNT208J6QP80alO70P3=cLd20<W9b@80`L710P2l_;`20<71
`@H0b<S80P3:b/X20<S8b080b/[:0P38b<P20<71`@80`<30103=cLd20<[:bP80b<S81032`/850;no
_`H0_;bl0P32`/820<S8b0@0b/[:0P3=cLd80<[:bP80b<S8103:b/X20<o?c`@0dm?C0P3=cLd20=3@
d080dm?C403:b/X20<S8b0d0b/[:0P38b<P20=;BdP80kno_0P3Ph>0208j>SPH0`L710P38b<P20<O7
a`@0`L710P38b<P40<71`@80b/[:0P3?cll20<g=c@80clo?0P3=cLd40<o?c`80d];B1P3Hf=P20=;B
dP<0clo?0P3=cLd20<O7a`80b/[:1037alL20<o?c`80emOG0P3EeMD20>KViP80eMGE0P2o_kl20<71
`@80gMgM0P3/k>`20?Ogm`80kno_3`3oool000d0oooo1P3/k>`20>o_k`H0lO7a0P3_knl40?7al@@0
moOg0P3dm?@20=;BdPL0clo?0P3@d=040<o?c`80cLg=0P3?cll20>?Sh`80jNWY0P26QXH20<O7a`80
cLg=0P39bLT20<71`@80_;bl0P31`L460<S8b080b/[:0P38b<P20<[:bP80b<S80P31`L420<30`0@0
cLg=0P3:b/X20<S8b0@0`/;21@2o_kl60;bl_080`/;20P38b<P40<[:bP80cLg=203:b/X20<S8b0@0
b/[:0P3?cll40=?Cd`80cLg=0P3@d=020=?Cda00b/[:0P38b<P=0<[:bP80b<S80P3Bd]820>o_k`80
h>3P0P2>SXh60<71`@80b<S80P37alL40<71`@80b<S81031`L420<[:bP80clo?0P3=cLd20<o?c`80
cLg=103?cll20=;BdPH0f=SH0P3Bd]830<o?c`80cLg=0P37alL20<[:bP@0alO70P3?cll20=OGe`80
eMGE0P3Vi^H20=GEe@80_kno0P31`L420=gMg@80k>c/0P3gmoL20>o_k`l0oooo000=0?ooo`80kno_
0P3alO420?Cdm080moOg0P3alO440?Ogm`80k>c/103gmoL20>o_k`80lO7a0P3_knl40>c/k0<0f=SH
0P3=cLd20<o?c`X0b/[:0P3YjNT20=SHf080][Jf0P37alL40<W9b@X0`L710P38b<P40<[:bP80b<S8
1031`L420<S8b0H0b/[:0P32`/820<S8b080_kno0`2l_;`40;no_`80_;bl0P2j^[X20<71`@@0b<S8
103:b/X20<S8b080b/[:1P38b<P20<g=c@80f=SH1P3Cdm<20=SHf0@0dm?C0P3=cLd40=?Cd`@0b/[:
1P3=cLd20<[:bPD0cLg=2P3:b/X20=;BdP80kno_0P3Ph>0209fMW@X0b/[:0P3=cLd40<[:bP80cLg=
0P3:b/X20<g=c@80b/[:0P3?cll20<g=c@80clo?0P3Bd]860=SHf080d];B0P3Hf=P50<g=c@80bLW9
0P3?cll20<W9b@80jNWY0P3GemL20=GEe@80i^KV0P2o_kl20=gMg@80alO70P2o_kl60>WYj@80kno_
3`3oool000d0oooo0P3_knl20?7al@80m?Cd0P3gmoL20?7al@@0moOg0P3/k>`40?Ogm`80kno_0P3a
lO420>o_k`@0k>c/0`3Hf=P20<g=c@80clo?2P3:b/X20>WYj@80f=SH0P2f][H20<O7a`@0bLW92P31
`L420<S8b0@0b/[:0P38b<P40<71`@80b<S81P3:b/X20<;2`P80b<S80P2o_kl30;bl_0@0_kno0P2l
_;`20;Zj^P80`L711038b<P40<[:bP80b<S80P3:b/X60<S8b080cLg=0P3Hf=P60=?Cd`80f=SH103C
dm<20<g=c@@0dm?C103:b/X60<g=c@80b/[:1@3=cLd:0<[:bP80d];B0P3_knl20>3Ph080WIfM2P3:
b/X20<g=c@@0b/[:0P3=cLd20<[:bP80cLg=0P3:b/X20<o?c`80cLg=0P3?cll20=;BdPH0f=SH0P3B
d]820=SHf0D0cLg=0P39bLT20<o?c`80bLW90P3YjNT20=OGe`80eMGE0P3Vi^H20;no_`80gMgM0P37
alL20;no_`H0jNWY0P3_knl?0?ooo`003@3oool20?7al@80m?Cd0P3alO420?Cdm080moOg103dm?@2
0?7al@P0moOg0P3_knl20?Ogm`80lO7a0`3_knl20=SHf080clo?0P3Cdm<20<[:bP80cLg=0P3:b/X2
0=?Cd`@0jNWY0P2f][H20<[:bP80cLg=0P3?cll60<71`@80b<S81031`L440<S8b080b/[:1038b<P2
0<[:bP80b<S81P32`/8;0<S8b080`/;20P2l_;`20;no_`80`L710P38b<P60<30`080b<S82P3:b/X2
0=?Cd`@0b/[:103Hf=P20<g=c@80dm?C0P3@d=020=?Cd`80d=3@0P3:b/X40<o?c`@0cLg=1`3?cll2
0<[:bP80clo?1P3:b/X20=;BdP80kno_0P2a/K420;Vi^@80b/[:1P3=cLd60<[:bP80cLg=0P3?cll2
0<g=c@80clo?0P3Cdm<40<o?c`80dm?C203Hf=P70=;BdP80bLW90P3Hf=P20>c/k080jNWY103Vi^H2
0>c/k080clo?0P3Shn<40;no_`80jNWY0P3gmoL20>o_k`80k>c/3`3oool000d0oooo0P3alO420?Cd
m080lO7a0P3dm?@20?Ogm`@0m?Cd0P3alO480?Ogm`80kno_0P3gmoL20?7al@<0kno_0P3Hf=P20<o?
c`80dm?C0P3:b/X20<g=c@80b/[:0P3Cdm<40>WYj@80][Jf0P3:b/X20<g=c@80clo?1P31`L420<S8
b0@0`L711038b<P20<[:bP@0b<S80P3:b/X20<S8b0H0`/;22`38b<P20<;2`P80_;bl0P2o_kl20<71
`@80b<S81P30`<020<S8b0X0b/[:0P3Cdm<40<[:bP@0f=SH0P3=cLd20=?Cd`80d=3@0P3Cdm<20=3@
d080b/[:103?cll40<g=c@L0clo?0P3:b/X20<o?c`H0b/[:0P3Bd]820>o_k`80/K6a0P2i^KT20<[:
bPH0cLg=1P3:b/X20<g=c@80clo?0P3=cLd20<o?c`80dm?C103?cll20=?Cd`P0f=SH1`3Bd]820<W9
b@80f=SH0P3/k>`20>WYj@@0i^KV0P3/k>`20<o?c`80hn?S102o_kl20>WYj@80moOg0P3_knl20>c/
k0l0oooo000=0?ooo`80lO7a0P3dm?@20>c/k080m?Cd0P3alO420>o_k`80m?Cd0P3gmoL20>c/k0@0
m?Cd0P3/k>`40?Ogm`80m?Cd0`3gmoL20?Cdm080gMgM0P3?cll20=?Cd`H0clo?0P3Bd]820>WYj@80
i^KV0P3:b/X40<o?c`80bLW90P37alL40<71`@80b<S80P37alL40<[:bP@0`L710P38b<P20<71`@80
_;bl1032`/820;no_`L0b<S80P3:b/X20<S8b0@0b/[:0P30`<040;bl_080`/;20P2l_;`20<S8b080
`L710P38b<P:0<[:bP80d=3@103Cdm<20<[:bP80d];B1P3?cll20=?Cd`80clo?0P3Cdm<20<o?c`80
d];B0P3?cll30<g=c@80clo?1P3=cLd20<[:bP80cLg=103:b/X20=;BdP80kno_0P31`L420;Vi^@80
b/[:103?cll80<g=c@P0dm?C0P3?cll20=?Cd`@0d];B1P3Hf=P20=;BdP<0bLW90P36a/H20;no_`80
emOG0P3Vi^H20>o_k`80alO70P3GemL20<O7a`80d];B0P3YjNT20<71`@80emOG1P3dm?@20>c/k0l0
oooo000=0?ooo`80lO7a0P3dm?@20>c/k080m?Cd0P3alO420>o_k`80m?Cd0P3gmoL20>c/k0@0m?Cd
0P3/k>`40?Ogm`80m?Cd0`3gmoL20?Cdm080gMgM0P3?cll20=?Cd`H0clo?0P3Bd]820>WYj@80i^KV
0P3:b/X40<o?c`80bLW90P37alL40<71`@80b<S80P37alL40<[:bP@0`L710P38b<P20<71`@80_;bl
1032`/820;no_`L0b<S80P3:b/X20<S8b0@0b/[:0P30`<040;bl_080`/;20P2l_;`20<S8b080`L71
0P38b<P:0<[:bP80d=3@103Cdm<20<[:bP80d];B1P3?cll20=?Cd`80clo?0P3Cdm<20<o?c`80d];B
0P3?cll30<g=c@80clo?1P3=cLd20<[:bP80cLg=103:b/X20=;BdP80kno_0P31`L420;Vi^@80b/[:
103?cll80<g=c@P0dm?C0P3?cll20=?Cd`@0d];B1P3Hf=P20=;BdP<0bLW90P36a/H20;no_`80emOG
0P3Vi^H20>o_k`80alO70P3GemL20<O7a`80d];B0P3YjNT20<71`@80emOG1P3dm?@20>c/k0l0oooo
000=0?ooo`80lO7a1P3gmoL20>c/k080moOg0P3/k>`40?Cdm080moOg0P3/k>`40?Ogm`80lO7a2@3g
moL20>o_k``0f=SH0P3_knl20=[JfP80cLg=103Bd]820<o?c`80bLW90P37alL40<71`@@0_kno0P31
`L420;Zj^P80/k>c1P2j^[X20;no_`80^[Zj0P38b<P20<[:bPT0cLg=0P3Cdm<40<S8b080_;bl0P32
`/820;no_`80`/;20P2l_;`20;no_`80`L710P30`<040<S8b0@0b/[:0P3=cLd:0<[:bP80cLg=103:
b/X40<o?c`L0cLg=2P3:b/X20<O7a`@0b/[:0P37alL20=SHf080kno_0P3Ph>020<O7a`H0b/[:0P38
b<P20<g=c@80d=3@103Cdm<20<o?c`80dm?C0P3?cll20=SHf080d];B1P3Hf=P20<W9b@80alO70`2f
][H20:b/[080`L710P3YjNT20=gMg@80k>c/0P39bLT80<o?c`80_Kfm0P3YjNT20?Cdm080kno_0P3g
moL20?7al@l0oooo000=0?ooo`80lO7a1P3gmoL20>c/k080moOg0P3/k>`40?Cdm080moOg0P3/k>`4
0?Ogm`80lO7a2@3gmoL20>o_k``0f=SH0P3_knl20=[JfP80cLg=103Bd]820<o?c`80bLW90P37alL4
0<71`@@0_kno0P31`L420;Zj^P80/k>c1P2j^[X20;no_`80^[Zj0P38b<P20<[:bPT0cLg=0P3Cdm<4
0<S8b080_;bl0P32`/820;no_`80`/;20P2l_;`20;no_`80`L710P30`<040<S8b0@0b/[:0P3=cLd:
0<[:bP80cLg=103:b/X40<o?c`L0cLg=2P3:b/X20<O7a`@0b/[:0P37alL20=SHf080kno_0P3Ph>02
0<O7a`H0b/[:0P38b<P20<g=c@80d=3@103Cdm<20<o?c`80dm?C0P3?cll20=SHf080d];B1P3Hf=P2
0<W9b@80alO70`2f][H20:b/[080`L710P3YjNT20=gMg@80k>c/0P39bLT80<o?c`80_Kfm0P3YjNT2
0?Cdm080kno_0P3gmoL20?7al@l0oooo000=0?ooo`80lO7a0P3_knl60?Cdm080moOg0P3dm?@20?Og
m`@0lO7a0P3/k>`40?7al@80moOg0P3dm?@70?Ogm`80m?Cd0P3alO420>?Sh`H0h>3P103MgMd20>o_
k`80f=SH0P2EUID20=;BdP80cLg=0P3:b/X80<71`@80_kno102c/k<<0;Zj^P80`L710P38b<P30<[:
bPH0cLg=0P3Cdm<40<[:bP80`<300P2l_;`40;Zj^P80_;bl0P31`L420;bl_0@0^[Zj0P2l_;`60<71
`@80b<S81031`L420<;2`P80`L710P38b<P20<71`@80b<S80P37alL20<71`@80alO71@38b<P>0<71
`@80b<S81031`L420=[JfP80jNWY0P39bLT20<O7a`80b<S8203:b/X20<o?c`80dm?C103?cll40=SH
f0H0d];B0P37alL20<71`@80Xj>S0`2[Zj/20:b/[080alO70P3GemL20<O7a`80/K6a0P31`L420<S8
b080_Kfm0P3GemL20<W9b@80_kno0P3Vi^H20?Cdm080k>c/0P3_knl20?7al@l0oooo000=0?ooo`80
lO7a0P3_knl60?Cdm080moOg0P3dm?@20?Ogm`@0lO7a0P3/k>`40?7al@80moOg0P3dm?@70?Ogm`80
m?Cd0P3alO420>?Sh`H0h>3P103MgMd20>o_k`80f=SH0P2EUID20=;BdP80cLg=0P3:b/X80<71`@80
_kno102c/k<<0;Zj^P80`L710P38b<P30<[:bPH0cLg=0P3Cdm<40<[:bP80`<300P2l_;`40;Zj^P80
_;bl0P31`L420;bl_0@0^[Zj0P2l_;`60<71`@80b<S81031`L420<;2`P80`L710P38b<P20<71`@80
b<S80P37alL20<71`@80alO71@38b<P>0<71`@80b<S81031`L420=[JfP80jNWY0P39bLT20<O7a`80
b<S8203:b/X20<o?c`80dm?C103?cll40=SHf0H0d];B0P37alL20<71`@80Xj>S0`2[Zj/20:b/[080
alO70P3GemL20<O7a`80/K6a0P31`L420<S8b080_Kfm0P3GemL20<W9b@80_kno0P3Vi^H20?Cdm080
k>c/0P3_knl20?7al@l0oooo000=0?ooo`80lO7a0P3gmoL20?7al@H0moOg0P3alO420>o_k`@0m?Cd
0P3gmoL20?Cdm080lO7a0P3/k>`20?Ogm`<0m?Cd103gmoL20?7al@80moOg0P3alO420?Ogm`@0m?Cd
103gmoL40?Cdm080kno_0P2m_Kd20<O7a`80b/[:0P37alL60<71`@80_;bl0P2o_kl20;Rh^0@0_kno
0P32`/840<S8b080`/;20P2j^[X20<;2`P<0b<S8203=cLd20=?Cd`80cLg=0P38b<P20;fm_@80`/;2
0P38b<P20<30`0@0`/;21031`L440;Zj^P80/K6a0P2c/k<20;6a/@80[:b/0P2c/k<60;6a/@80[:b/
102a/K4?0;>c/`80_kno0P2l_;`60;no_`80_;bl0P2j^[X20;no_`80/k>c103Bd]820:j^[P80WIfM
0P2c/k<40<71`@H0b/[:0P3?cll40=;BdP80f=SH0P3Bd]820<W9b@80UiNG0P2QXJ420;6a/@<0];Bd
102a/K420<W9b@80alO70P31`L420;fm_@80_kno0P3MgMd20<o?c`80_kno0P3Jf]X20>KViP80lO7a
0P3dm?@40>c/k0l0oooo000=0?ooo`80lO7a0P3gmoL20?7al@H0moOg0P3alO420>o_k`@0m?Cd0P3g
moL20?Cdm080lO7a0P3/k>`20?Ogm`<0m?Cd103gmoL20?7al@80moOg0P3alO420?Ogm`@0m?Cd103g
moL40?Cdm080kno_0P2m_Kd20<O7a`80b/[:0P37alL60<71`@80_;bl0P2o_kl20;Rh^0@0_kno0P32
`/840<S8b080`/;20P2j^[X20<;2`P<0b<S8203=cLd20=?Cd`80cLg=0P38b<P20;fm_@80`/;20P38
b<P20<30`0@0`/;21031`L440;Zj^P80/K6a0P2c/k<20;6a/@80[:b/0P2c/k<60;6a/@80[:b/102a
/K4?0;>c/`80_kno0P2l_;`60;no_`80_;bl0P2j^[X20;no_`80/k>c103Bd]820:j^[P80WIfM0P2c
/k<40<71`@H0b/[:0P3?cll40=;BdP80f=SH0P3Bd]820<W9b@80UiNG0P2QXJ420;6a/@<0];Bd102a
/K420<W9b@80alO70P31`L420;fm_@80_kno0P3MgMd20<o?c`80_kno0P3Jf]X20>KViP80lO7a0P3d
m?@40>c/k0l0oooo000=0?ooo`80moOg0P3dm?@20?Ogm`80kno_1P3gmoL40?Cdm080k>c/0P3_knl4
0?7al@80kno_0P3gmoL30?7al@80k>c/0P3gmoL20?7al@80moOg0P3dm?@20?Ogm`80m?Cd0P3alO42
0?Ogm`@0m?Cd0P3_knl20?Ogm`80lO7a0P2o_kl20:>SX`80eMGE0P31`L420;Jf]P@0`L710P2o_kl4
0;Rh^080/k>c0P2j^[X20;no_`@0`/;20P2j^[X20;no_`D0b<S80P3Cdm<20<g=c@80dm?C0P3=cLd4
0<[:bPP0`/;20P38b<P20<;2`PH0b<S80P32`/820<S8b0@0`/;20P2o_kl20;bl_080_kno1P2l_;`2
0;no_`@0_;bl0P32`/820;no_`<0`/;21031`L440<S8b080_;bl1P38b<P20<71`@80b<S81031`L42
0<;2`P80cLg=0P3?cll20=;BdP80`L710P1NGUh20;bl_080][Jf0P31`L440<O7a`80bLW90P2^[Zh2
08b<S0@0QXJ60P2BTY820;6a/@80_Kfm0`31`L420;6a/@80_Kfm0P2o_kl20<71`@80clo?0P37alL2
0;6a/@80f=SH0P3EeMD20;6a/@@0gMgM0P3_knl20?Cdm080moOg0P3alO4?0?ooo`003@3oool20?Og
m`80m?Cd0P3gmoL20>o_k`H0moOg103dm?@20>c/k080kno_103alO420>o_k`80moOg0`3alO420>c/
k080moOg0P3alO420?Ogm`80m?Cd0P3gmoL20?Cdm080lO7a0P3gmoL40?Cdm080kno_0P3gmoL20?7a
l@80_kno0P2SXj<20=GEe@80`L710P2f][H40<71`@80_kno102h^;P20;>c/`80^[Zj0P2o_kl40<;2
`P80^[Zj0P2o_kl50<S8b080dm?C0P3=cLd20=?Cd`80cLg=103:b/X80<;2`P80b<S80P32`/860<S8
b080`/;20P38b<P40<;2`P80_kno0P2l_;`20;no_`H0_;bl0P2o_kl40;bl_080`/;20P2o_kl30<;2
`P@0`L711038b<P20;bl_0H0b<S80P31`L420<S8b0@0`L710P32`/820<g=c@80clo?0P3Bd]820<71
`@80GUiN0P2l_;`20;Jf]P80`L711037alL20<W9b@80[Zj^0P2<S8`408J6QP80TY:B0P2a/K420;fm
_@<0`L710P2a/K420;fm_@80_kno0P31`L420<o?c`80alO70P2a/K420=SHf080eMGE0P2a/K440=gM
g@80kno_0P3dm?@20?Ogm`80lO7a3`3oool000d0oooo0P3/k>`20?7al@80moOg0P3alO420?Cdm080
k>c/0P3alO440?Cdm080moOg0P3/k>`20?Cdm0@0moOg1`3dm?@20?Ogm`80m?Cd0P3gmoL20?Cdm080
moOg0P3alO440?Cdm080lO7a0P3gmoL20?7al@@0m?Cd0P2o_kl20:6QX@80/k>c0P2/[:`20;Jf]PP0
_kno0P31`L420;Rh^080^[Zj0P2o_kl40<;2`P80^[Zj0P2m_Kd30<S8b080b/[:0P38b<P20<[:bPP0
cLg=0P38b<P40<;2`Ph0b<S80P32`/820<30`0P0b<S80P31`L420;no_`@0`/;21038b<P70<;2`P80
`L712P38b<P20<;2`P80b<S80P32`/840<S8b080b/[:0P38b<P20<71`@80b/[:0P38b<P20<o?c`80
bl_;0P3Jf]X20:j^[P@0UIFE0P2YZJT208f=S@80QXJ60P2BTY8208J6QP80S8b<102QXJ420;fm_@<0
/k>c0P2[Zj/20>KViP@0_Kfm0P36a/H20:ZZZP80d];B0P3MgMd20;no_`80gMgM0P39bLT20>c/k080
jNWY103/k>`20?Ogm`l0oooo000=0?ooo`80k>c/0P3alO420?Ogm`80lO7a0P3dm?@20>c/k080lO7a
103dm?@20?Ogm`80k>c/0P3dm?@40?Ogm`L0m?Cd0P3gmoL20?Cdm080moOg0P3dm?@20?Ogm`80lO7a
103dm?@20?7al@80moOg0P3alO440?Cdm080_kno0P2QXJ420;>c/`80[:b/0P2f][H80;no_`80`L71
0P2h^;P20;Zj^P80_kno1032`/820;Zj^P80_Kfm0`38b<P20<[:bP80b<S80P3:b/X80<g=c@80b<S8
1032`/8>0<S8b080`/;20P30`<080<S8b080`L710P2o_kl40<;2`P@0b<S81`32`/820<71`@X0b<S8
0P32`/820<S8b080`/;21038b<P20<[:bP80b<S80P31`L420<[:bP80b<S80P3?cll20<_;b`80f][J
0P2^[Zh409FEU@80ZJVY0P2=SHd208J6QP80TY:B0P26QXH208b<S0@0XJ6Q0P2m_Kd30;>c/`80Zj^[
0P3Vi^H40;fm_@80a/K60P2ZZZX20=;BdP80gMgM0P2o_kl20=gMg@80bLW90P3/k>`20>WYj@@0k>c/
0P3gmoL?0?ooo`003@3oool20?Ogm`80lO7a0P3_knl20?Ogm`80lO7a103gmoL20>c/k0@0kno_0P3g
moL20?Cdm080moOg0P3alO420?Ogm`<0lO7a103dm?@20?Ogm`80lO7a203gmoL40?7al@@0k>c/0P3d
m?@20>c/k080bLW90P37alL209NGU`@0Zj^[0P2IVIT20;no_`80`L710P2l_;`20;no_`80][Jf0P2m
_Kd20;no_`80^[Zj0P32`/840;fm_@L0b<S8103:b/X20<g=c@80b<S80P3=cLd40<S8b0@0`/;24038
b<P20<30`0@0`/;21P38b<P20;no_`80`/;20P31`L420<30`080`/;21@38b<P20<30`0P0b<S81032
`/820<S8b080`L710P38b<P20;no_`P0b<S81P31`L420<o?c`@0d];B0P2m_Kd206i^KP80LG5a0P2<
S8`208J6QP80S8b<102GUiL209VIV@80UiNG0`2/[:`20;Rh^080gMgM0P2QXJ420:n_[`80alO70P2Z
ZZX20<W9b@80eMGE0P2m_Kd20>c/k080i^KV103/k>`40?7al@80moOg3`3oool000d0oooo0P3gmoL2
0?7al@80kno_0P3gmoL20?7al@@0moOg0P3/k>`40>o_k`80moOg0P3dm?@20?Ogm`80lO7a0P3gmoL3
0?7al@@0m?Cd0P3gmoL20?7al@P0moOg103alO440>c/k080m?Cd0P3/k>`20<W9b@80alO70P2GUiL4
0:^[Z`80VIVI0P2o_kl20<71`@80_;bl0P2o_kl20;Jf]P80_Kfm0P2o_kl20;Zj^P80`/;2102m_Kd7
0<S8b0@0b/[:0P3=cLd20<S8b080cLg=1038b<P40<;2`Q00b<S80P30`<040<;2`PH0b<S80P2o_kl2
0<;2`P80`L710P30`<020<;2`PD0b<S80P30`<080<S8b0@0`/;20P38b<P20<71`@80b<S80P2o_kl8
0<S8b0H0`L710P3?cll40=;BdP80_Kfm0P1^KVh2075aL@80S8b<0P26QXH208b<S0@0UiNG0P2IVIT2
09NGU`<0[:b/0P2h^;P20=gMg@80XJ6Q0P2_[jl20<O7a`80ZZZZ0P39bLT20=GEe@80_Kfm0P3/k>`2
0>KViP@0k>c/103alO420?Ogm`l0oooo000=0?ooo`80lO7a103gmoL40?7al@80moOg0P3_knl60?Og
m`80lO7a103gmoL20?Cdm080kno_2@3gmoL20>o_k`80m?Cd103gmoL20?Cdm0@0lO7a0P3dm?@60?7a
l@80d];B0P39bLT20:j^[P80UiNG0P2[Zj/208F5Q@80LG5a0P2f][H20;no_`@0_;bl0P2o_kl20;bl
_080_kno0P2m_Kd20;Zj^P80_kno2`38b<P20<g=cA80b<S80P3:b/X80<S8b0H0`/;20P38b<P40<;2
`P80b<S80P2o_kl20<30`0H0`/;20`2o_kl20<71`@80b<S80P3:b/X40<S8b080`<301038b<P60<;2
`P@0b<S81P31`L420;no_`80/k>c0P2YZJT20:>SX`80QXJ60P1gMgL208J6QP80QHF50P21PH4208F5
Q@80UiNG0P2BTY8209NGU`80VIVI1@2_[jl20;6a/@80alO70P2ZZZX20:n_[`80_Kfm0P2_[jl20=GE
e@80alO70P3?cll20>KViP80k>c/0P3dm?@20>KViP@0moOg0P3dm?@?0?ooo`003@3oool20?7al@@0
moOg103alO420?Ogm`80kno_1P3gmoL20?7al@@0moOg0P3dm?@20>o_k`T0moOg0P3_knl20?Cdm0@0
moOg0P3dm?@40?7al@80m?Cd1P3alO420=;BdP80bLW90P2^[Zh209NGU`80Zj^[0P25QHD2075aL@80
][Jf0P2o_kl40;bl_080_kno0P2l_;`20;no_`80_Kfm0P2j^[X20;no_`/0b<S80P3=cLdB0<S8b080
b/[:2038b<P60<;2`P80b<S81032`/820<S8b080_kno0P30`<060<;2`P<0_kno0P31`L420<S8b080
b/[:1038b<P20<30`0@0b<S81P32`/840<S8b0H0`L710P2o_kl20;>c/`80ZJVY0P2SXj<208J6QP80
MgMg0P26QXH208F5Q@80PH610P25QHD209NGU`80TY:B0P2GUiL209VIV@D0[jn_0P2a/K420<O7a`80
ZZZZ0P2_[jl20;fm_@80[jn_0P3EeMD20<O7a`80clo?0P3Vi^H20>c/k080m?Cd0P3Vi^H40?Ogm`80
m?Cd3`3oool000d0oooo0P3gmoL20?Cdm080lO7a0P3dm?@20>o_k`80moOg0P3alO420?Ogm`80k>c/
0P3gmoL20?7al@80moOg0P3_knl20?Ogm`80lO7a1`3gmoL20?7al@80m?Cd103gmoL20?7al@80moOg
0P3_knl20>c/k080lO7a0P3gmoL20>o_k`80lO7a0P3MgMd20>KViP80eMGE0P2BTY8209NGU`80QHF5
0P1eMGD205YJFP80_;bl0P2f][H20;no_`80/k>c0P2f][H20;bl_080_kno0P2m_Kd20;no_`/0b<S8
0P3:b/X:0<S8b0P0`/;20P38b<P20<;2`PH0b<S82P32`/860;no_`P0`/;20`2o_kl40<;2`P80b<S8
0P2o_kl40<;2`P@0b<S80P32`/820;no_`H0`/;20P2j^[X20;no_`80/k>c0P2a/K420:>SX`80UiNG
0P1kNg/207MgM`80QXJ6102BTY8209FEU@80S8b<0P25QHD409NGU`80Z:RX0P2a/K430:n_[`80_kno
0P2a/K420:6QX@@0[jn_1P37alL20=GEe@80m?Cd0P3/k>`40>o_k`@0m?Cd0P3/k>`?0?ooo`003@3o
ool20?Ogm`80m?Cd0P3alO420?Cdm080kno_0P3gmoL20?7al@80moOg0P3/k>`20?Ogm`80lO7a0P3g
moL20>o_k`80moOg0P3alO470?Ogm`80lO7a0P3dm?@40?Ogm`80lO7a0P3gmoL20>o_k`80k>c/0P3a
lO420?Ogm`80kno_0P3alO420=gMg@80i^KV0P3EeMD209:BTP80UiNG0P25QHD207EeM@80FUYJ0P2l
_;`20;Jf]P80_kno0P2c/k<20;Jf]P80_;bl0P2o_kl20;fm_@80_kno2`38b<P20<[:bPX0b<S82032
`/820<S8b080`/;21P38b<P:0<;2`PH0_kno2032`/830;no_`@0`/;20P38b<P20;no_`@0`/;21038
b<P20<;2`P80_kno1P32`/820;Zj^P80_kno0P2c/k<20;6a/@80Xj>S0P2GUiL207]kN`80MgMg0P26
QXH409:BTP80UIFE0P2<S8`208F5Q@@0UiNG0P2XZ:P20;6a/@<0[jn_0P2o_kl20;6a/@80XJ6Q102_
[jl60<O7a`80eMGE0P3dm?@20>c/k0@0kno_103dm?@20>c/k0l0oooo000=0?ooo`80lO7a0P3dm?@2
0?Ogm`80m?Cd0P3/k>`60?Ogm`80kno_0P3gmoL20?Cdm080lO7a0P3gmoL20?7al@D0moOg0P3_knl2
0?7al@80m?Cd0P3alO420?Ogm`80k>c/0P3gmoL20?Cdm080kno_0P3gmoL40?Cdm080k>c/0P3_knl2
0=OGe`80kno_0P37alL209:BTP80QXJ60P25QHD2079bLP80FUYJ0P14A4@20:b/[080/K6a0P2c/k<2
0;no_`80_;bl0P2o_kl20;Zj^P80_Kfm0`31`L480<S8b080`/;23P38b<P20<;2`P80b<S81P32`/88
0<S8b0@0_Kfm2032`/820<30`080`/;20P2o_kl50;fm_@80_kno0P30`<020<S8b080`/;20P38b<P2
0<;2`P80_kno1038b<P40<;2`P80_kno102j^[X20;6a/@80[jn_102QXJ4208J6QP80LG5a0P2<S8`2
09:BTP80QXJ60P2BTY820:>SX`80TY:B0P2<S8`209:BTP80Z:RX0P2GUiL20:^[Z`<0XJ6Q0P2/[:`2
0:ZZZPH0_Kfm0P3MgMd20;6a/@80bLW9103/k>`20?Cdm080jNWY0P3alO420>c/k080moOg0P3dm?@?
0?ooo`003@3oool20?7al@80m?Cd0P3gmoL20?Cdm080k>c/1P3gmoL20>o_k`80moOg0P3dm?@20?7a
l@80moOg0P3alO450?Ogm`80kno_0P3alO420?Cdm080lO7a0P3gmoL20>c/k080moOg0P3dm?@20>o_
k`80moOg103dm?@20>c/k080kno_0P3GemL20>o_k`80alO70P2BTY8208J6QP80QHF50P1bLW8205YJ
FP80A4A40P2/[:`20;6a/@80/k>c0P2o_kl20;bl_080_kno0P2j^[X20;fm_@<0`L712038b<P20<;2
`Ph0b<S80P32`/820<S8b0H0`/;22038b<P40;fm_@P0`/;20P30`<020<;2`P80_kno1@2m_Kd20;no
_`80`<300P38b<P20<;2`P80b<S80P32`/820;no_`@0b<S81032`/820;no_`@0^[Zj0P2a/K420:n_
[`@0XJ6Q0P26QXH2075aL@80S8b<0P2BTY8208J6QP80TY:B0P2SXj<209:BTP80S8b<0P2BTY820:RX
Z080UiNG0P2[Zj/30:6QX@80[:b/0P2ZZZX60;fm_@80gMgM0P2a/K420<W9b@@0k>c/0P3dm?@20>WY
j@80lO7a0P3/k>`20?Ogm`80m?Cd3`3oool000d0oooo0P3_knl40?7al@80kno_0P3alO420?Ogm`80
k>c/0P3_knl20>c/k0H0moOg0P3_knl20?Ogm`D0kno_0P3gmoL20?7al@80moOg0P3dm?@20?7al@80
moOg0P3alO420>o_k`80moOg0P3_knl20?Ogm`80m?Cd0P3_knl20>c/k080gMgM0P3Vi^H20<W9b@80
_Kfm0P25QHD208b<S080MGEe0P1JFUX404A4A0@0/k>c0P2j^[X20;>c/`80_kno0P2m_Kd20;Zj^Pd0
b<S81032`/840<S8b0P0`/;20P2m_Kd20;no_`80`/;21P38b<P60<;2`P80_kno102m_Kd20;Zj^PH0
`/;20P2m_Kd20;no_`<0]KFe0P2o_kl20;fm_@`0`/;20P2m_Kd40:n_[`80ZZZZ202QXJ4208b<S080
IVIV0P1JFUX208J6QP80XJ6Q0P2GUiL207=cL`80TY:B0P2IVIT20:^[Z`@0Z:RX102BTY8209NGU`<0
XJ6Q0P2a/K420:ZZZP@0_Kfm0P3Vi^H20;no_`80alO70P3Hf=P20>WYj@80i^KV0P3YjNT40>o_k`80
lO7a0P3gmoL20?Cdm0l0oooo000=0?ooo`80kno_103alO420>o_k`80lO7a0P3gmoL20>c/k080kno_
0P3/k>`60?Ogm`80kno_0P3gmoL50>o_k`80moOg0P3alO420?Ogm`80m?Cd0P3alO420?Ogm`80lO7a
0P3_knl20?Ogm`80kno_0P3gmoL20?Cdm080kno_0P3/k>`20=gMg@80i^KV0P39bLT20;fm_@80QHF5
0P2<S8`207EeM@80FUYJ1014A4@40;>c/`80^[Zj0P2c/k<20;no_`80_Kfm0P2j^[X=0<S8b0@0`/;2
1038b<P80<;2`P80_Kfm0P2o_kl20<;2`PH0b<S81P32`/820;no_`@0_Kfm0P2j^[X60<;2`P80_Kfm
0P2o_kl30;Fe]@80_kno0P2m_Kd<0<;2`P80_Kfm102_[jl20:ZZZPP0XJ6Q0P2<S8`206IVIP80FUYJ
0P26QXH20:6QX@80UiNG0P1cLg<209:BTP80VIVI0P2[Zj/40:RXZ0@0TY:B0P2GUiL30:6QX@80/K6a
0P2ZZZX40;fm_@80i^KV0P2o_kl20<O7a`80f=SH0P3YjNT20>KViP80jNWY103_knl20?7al@80moOg
0P3dm?@?0?ooo`003@3oool20>o_k`@0lO7a0P3_knl20?7al@80moOg0P3/k>`20>o_k`80k>c/1P3g
moL20>o_k`80moOg1@3_knl20?Ogm`80lO7a0P3gmoL20?Cdm080lO7a0P3gmoL20?7al@80kno_0P3g
moL20>o_k`80moOg0P3dm?@20>o_k`80k>c/0P3MgMd20>KViP80bLW90P2m_Kd208F5Q@80S8b<0P1e
MGD205YJFP@0A4A4102c/k<20;Zj^P80/k>c0P2o_kl20;fm_@80^[Zj3@38b<P40<;2`P@0b<S82032
`/820;fm_@80_kno0P32`/860<S8b0H0`/;20P2o_kl40;fm_@80^[Zj1P32`/820;fm_@80_kno0`2e
]KD20;no_`80_Kfm3032`/820;fm_@@0[jn_0P2ZZZX80:6QX@80S8b<0P1VIVH205YJFP80QXJ60P2Q
XJ4209NGU`80Lg=c0P2BTY8209VIV@80Zj^[102XZ:P409:BTP80UiNG0`2QXJ420;6a/@80ZZZZ102m
_Kd20>KViP80_kno0P37alL20=SHf080jNWY0P3Vi^H20>WYj@@0kno_0P3alO420?Ogm`80m?Cd3`3o
ool000d0oooo0P3/k>`20?Ogm`80m?Cd0P3alO420?Ogm`@0lO7a0P3dm?@20?Ogm`@0m?Cd0P3gmoL2
0?Cdm080moOg0P3dm?@50?Ogm`80m?Cd0P3gmoL20?Cdm0@0kno_0P3gmoL20?Cdm080lO7a0P3/k>`2
0?Cdm080kno_0P3dm?@20>c/k080kno_103MgMd20:^[Z`80S8b<0P26QXH206i^KP80FUYJ0P1ADE42
04A4A080>CTi0P2a/K420;bl_080[:b/0P2m_Kd20;Zj^P80_Kfm0`32`/820<S8b0P0`/;20P38b<P4
0<;2`P80b<S81032`/820<S8b0@0`/;2102m_Kd40<;2`P80_kno0P38b<P20<;2`P80_Kfm0P2j^[X2
0;fm_@P0^[Zj0P2m_Kd40;Zj^PL0]KFe0P2m_Kd20<;2`P80]KFe0P32`/820:n_[`80_Kfm0P2j^[X2
0;Fe]@@0ZZZZ0P2QXJ4209VIV@80S8b<0P1kNg/205YJFP80Jf][0P1^KVh208b<S0@0UiNG0P2ATI44
0:6QX@80Z:RX102QXJ420:RXZ080TY:B0P2GUiL50:ZZZP80[jn_0P2m_Kd20<71`@80_kno0P37alL2
0=GEe@80i^KV0P3YjNT20=gMg@80jNWY103dm?@20?7al@@0moOg3`3oool000d0oooo0P3/k>`20?Og
m`80m?Cd0P3alO420?Ogm`@0lO7a0P3dm?@20?Ogm`@0m?Cd0P3gmoL20?Cdm080moOg0P3dm?@50?Og
m`80m?Cd0P3gmoL20?Cdm0@0kno_0P3gmoL20?Cdm080lO7a0P3/k>`20?Cdm080kno_0P3dm?@20>c/
k080kno_103MgMd20:^[Z`80S8b<0P26QXH206i^KP80FUYJ0P1ADE4204A4A080>CTi0P2a/K420;bl
_080[:b/0P2m_Kd20;Zj^P80_Kfm0`32`/820<S8b0P0`/;20P38b<P40<;2`P80b<S81032`/820<S8
b0@0`/;2102m_Kd40<;2`P80_kno0P38b<P20<;2`P80_Kfm0P2j^[X20;fm_@P0^[Zj0P2m_Kd40;Zj
^PL0]KFe0P2m_Kd20<;2`P80]KFe0P32`/820:n_[`80_Kfm0P2j^[X20;Fe]@@0ZZZZ0P2QXJ4209VI
V@80S8b<0P1kNg/205YJFP80Jf][0P1^KVh208b<S0@0UiNG0P2ATI440:6QX@80Z:RX102QXJ420:RX
Z080TY:B0P2GUiL50:ZZZP80[jn_0P2m_Kd20<71`@80_kno0P37alL20=GEe@80i^KV0P3YjNT20=gM
g@80jNWY103dm?@20?7al@@0moOg3`3oool000d0oooo0P3_knl20>c/k0H0moOg0P3/k>`60?Ogm`80
kno_0P3alO420?Ogm`80kno_0P3dm?@20>c/k0<0m?Cd103alO460?Ogm`@0m?Cd0P3gmoL40?7al@80
kno_0P3dm?@20>o_k`80jNWY0P3Vi^H20<o?c`80gMgM0P2BTY8208b<S080QHF50P1[Jf/405YJFP80
DE5A0P0i>CT201lO7`80ZJVY0P2f][H20;>c/`@0^[Zj0`31`L420;no_`P0`/;20P38b<P20<;2`P80
b<S82032`/820;no_`@0`/;2202m_Kd40<;2`P80_kno102m_Kd20;Zj^P80_Kfm0P2e]KD20:n_[`80
]KFe0P2m_Kd50;Fe]@80_Kfm0P2e]KD20;fm_@80^[Zj0P2e]KD20:n_[`80^[Zj102a/K420:n_[`80
ZZZZ0P2SXj<209BDU080Ng]k0P1aLG4206i^KP80IVIV0P1cLg<208f=S@80VIVI0P2BTY82096AT@80
UiNG0P2QXJ4209NGU`@0S8b<0P2GUiL209:BTP80Z:RX1@2ZZZX20:RXZ080_Kfm1031`L420<O7a`@0
i^KV0P3MgMd20>WYj@80m?Cd0P3_knl:0?Ogm`l0oooo000=0?ooo`80kno_0P3/k>`60?Ogm`80k>c/
1P3gmoL20>o_k`80lO7a0P3gmoL20>o_k`80m?Cd0P3/k>`30?Cdm0@0lO7a1P3gmoL40?Cdm080moOg
103alO420>o_k`80m?Cd0P3_knl20>WYj@80i^KV0P3?cll20=gMg@80TY:B0P2<S8`208F5Q@80Jf][
101JFUX2055AD@80>CTi0P0O7al20:VYZ@80][Jf0P2c/k<40;Zj^P<0`L710P2o_kl80<;2`P80b<S8
0P32`/820<S8b0P0`/;20P2o_kl40<;2`PP0_Kfm1032`/820;no_`@0_Kfm0P2j^[X20;fm_@80]KFe
0P2_[jl20;Fe]@80_Kfm1@2e]KD20;fm_@80]KFe0P2m_Kd20;Zj^P80]KFe0P2_[jl20;Zj^P@0/K6a
0P2_[jl20:ZZZP80Xj>S0P2DU9@207]kN`80LG5a0P1^KVh206IVIP80Lg=c0P2=SHd209VIV@80TY:B
0P2ATI4209NGU`80XJ6Q0P2GUiL408b<S080UiNG0P2BTY820:RXZ0D0ZZZZ0P2XZ:P20;fm_@@0`L71
0P37alL40>KViP80gMgM0P3YjNT20?Cdm080kno_2P3gmoL?0?ooo`003@3oool20>c/k080moOg0P3d
m?@60?Ogm`80kno_0P3dm?@40?Ogm`80m?Cd0P3alO420>c/k080m?Cd2@3gmoL20?Cdm080lO7a1P3d
m?@20?Ogm`H0m?Cd0P3alO420>o_k`80m?Cd0P3YjNT20=GEe@80gMgM0P2GUiL208b<S080QXJ60P1^
KVh405YJFP80DE5A100b<S8201lO7`@0/k>c0P2o_kl20;bl_0D0_kno2P32`/840<S8b0h0`/;2102m
_Kd20<;2`P80_Kfm0P2o_kl20;fm_@80`<30202j^[X80;Fe]@80[jn_0`2ZZZX20:n_[`80]KFe0P2_
[jl20;no_`80ZZZZ0P2a/K440:n_[`80Xj>S0P2/[:`20:6QX@80QXJ60P1[Jf/2075aL@80C4a<0P1c
Lg<207]kN`80QXJ60P2GUiL209:BTP80TI6A0P2EUID2096AT@80Z:RX1P2QXJ440:RXZ080ZZZZ0P2_
[jl30:^[Z`80_Kfm0P2o_kl40<71`@80d];B0P3Hf=P20=gMg@80i^KV0P3/k>`20>o_k`80moOg0P3d
m?@20?Ogm`80m?Cd0P3alO420?Ogm`l0oooo000=0?ooo`80k>c/0P3gmoL20?Cdm0H0moOg0P3_knl2
0?Cdm0@0moOg0P3dm?@20?7al@80k>c/0P3dm?@90?Ogm`80m?Cd0P3alO460?Cdm080moOg1P3dm?@2
0?7al@80kno_0P3dm?@20>WYj@80eMGE0P3MgMd209NGU`80S8b<0P26QXH206i^KP@0FUYJ0P1ADE44
038b<P807alO102c/k<20;no_`80_;bl1@2o_kl:0<;2`P@0b<S83P32`/840;fm_@80`/;20P2m_Kd2
0;no_`80_Kfm0P30`<080;Zj^PP0]KFe0P2_[jl30:ZZZP80[jn_0P2e]KD20:n_[`80_kno0P2ZZZX2
0;6a/@@0[jn_0P2SXj<20:b/[080XJ6Q0P26QXH206][J`80LG5a0P1<C4`207=cL`80Ng]k0P26QXH2
09NGU`80TY:B0P2ATI4209FEU@80TI6A0P2XZ:P60:6QX@@0Z:RX0P2ZZZX20:n_[`<0Zj^[0P2m_Kd2
0;no_`@0`L710P3Bd]820=SHf080gMgM0P3Vi^H20>c/k080kno_0P3gmoL20?Cdm080moOg0P3dm?@2
0?7al@80moOg3`3oool000d0oooo103gmoL20>c/k080moOg0P3dm?@60?Ogm`@0m?Cd0P3/k>`20?Cd
m080moOg0P3alO420>c/k0D0m?Cd103gmoL20>o_k`80m?Cd0P3gmoL40?7al@80m?Cd0P3gmoL20?Cd
m080lO7a0P3_knl20>c/k080i^KV0P3MgMd20=;BdP80UiNG0P2<S8`207MgM`80KVi^0P1VIVH205YJ
FP80A4A40P0b<S8202LW9`80>CTi102c/k<20;Zj^PD0_kno0P31`L420;no_`80b<S80P32`/820<S8
b0X0`/;20P2m_Kd40<;2`P80_Kfm0P32`/820;fm_@80_kno0P2m_Kd40;Zj^P80]KFe202j^[X40;Fe
]@80[jn_0P2/[:`70:ZZZP80[jn_0P2o_kl20:n_[`80Xj>S0P2QXJ420:>SX`@0YJFU102DU9@208F5
Q@80QXJ60P1EEED206][J`80IVIV0P1aLG4206IVIP80QXJ60P2BTY8408b<S080TI6A102QXJ420:^[
Z`80/K6a0P2QXJ420:RXZ080_Kfm0P2[Zj/20:n_[`D0_Kfm0P31`L420;no_`80d];B103Hf=P40>o_
k`@0moOg103dm?@20?Ogm`80lO7a103gmoL?0?ooo`003@3oool40?Ogm`80k>c/0P3gmoL20?Cdm0H0
moOg103dm?@20>c/k080m?Cd0P3gmoL20?7al@80k>c/1@3dm?@40?Ogm`80kno_0P3dm?@20?Ogm`@0
lO7a0P3dm?@20?Ogm`80m?Cd0P3alO420>o_k`80k>c/0P3Vi^H20=gMg@80d];B0P2GUiL208b<S080
MgMg0P1^KVh206IVIP80FUYJ0P14A4@2038b<P809bLW0P0i>CT40;>c/`80^[Zj1@2o_kl20<71`@80
_kno0P38b<P20<;2`P80b<S82P32`/820;fm_@@0`/;20P2m_Kd20<;2`P80_Kfm0P2o_kl20;fm_@@0
^[Zj0P2e]KD80;Zj^P@0]KFe0P2_[jl20:b/[0L0ZZZZ0P2_[jl20;no_`80[jn_0P2SXj<20:6QX@80
Xj>S102UYJD409BDU080QHF50P26QXH205EEE@80Jf][0P1VIVH2075aL@80IVIV0P26QXH209:BTP@0
S8b<0P2ATI440:6QX@80Zj^[0P2a/K420:6QX@80Z:RX0P2m_Kd20:^[Z`80[jn_1@2m_Kd20<71`@80
_kno0P3Bd]840=SHf0@0kno_103gmoL40?Cdm080moOg0P3alO440?Ogm`l0oooo000=0?ooo`80moOg
0P3dm?@40>o_k`80m?Cd0P3alO420?Ogm`80kno_0P3gmoL20>o_k`80lO7a103gmoL20?Cdm080moOg
0`3_knl20?Ogm`H0m?Cd0P3gmoL40?7al@@0moOg0P3dm?@20?Ogm`80kno_0P3dm?@20>c/k080jNWY
0P3EeMD20:^[Z`80UiNG0P2<S8`207]kN`80Jf][0P1eMGD205YJFP80E5AD100i>CT204Q8B080Bd];
0P2f][H20;fm_@80_kno0`38b<P40;no_`80b<S83032`/820;no_`80`/;20P2o_kl20;Zj^P80`<30
0P32`/880;fm_@80]KFe0P2m_Kd20:n_[`80^[Zj0P2m_Kd20;Zj^P@0]KFe102/[:`209VIV@80XJ6Q
0`2a/K420;no_`80/K6a0P2DU9@209VIV@80XJ6Q0P2IVIT20:6QX@80VIVI0P26QXH208F5Q@80LW9b
0P1^KVh208J6QP80Lg=c1026QXH208f=S@80UiNG0P2IVIT2096AT@80TY:B0P2ATI420:6QX@80TY:B
0P2IVIT40:6QX@80ZZZZ102QXJ470;fm_@80_kno0P3?cll20=SHf0@0i^KV0P3dm?@20?Ogm`80lO7a
0P3/k>`40?Ogm`@0m?Cd0P3gmoL20?Cdm0l0oooo000=0?ooo`80moOg0P3dm?@40>o_k`80m?Cd0P3a
lO420?Ogm`80kno_0P3gmoL20>o_k`80lO7a103gmoL20?Cdm080moOg0`3_knl20?Ogm`H0m?Cd0P3g
moL40?7al@@0moOg0P3dm?@20?Ogm`80kno_0P3dm?@20>c/k080jNWY0P3EeMD20:^[Z`80UiNG0P2<
S8`207]kN`80Jf][0P1eMGD205YJFP80E5AD100i>CT204Q8B080Bd];0P2f][H20;fm_@80_kno0`38
b<P40;no_`80b<S83032`/820;no_`80`/;20P2o_kl20;Zj^P80`<300P32`/880;fm_@80]KFe0P2m
_Kd20:n_[`80^[Zj0P2m_Kd20;Zj^P@0]KFe102/[:`209VIV@80XJ6Q0`2a/K420;no_`80/K6a0P2D
U9@209VIV@80XJ6Q0P2IVIT20:6QX@80VIVI0P26QXH208F5Q@80LW9b0P1^KVh208J6QP80Lg=c1026
QXH208f=S@80UiNG0P2IVIT2096AT@80TY:B0P2ATI420:6QX@80TY:B0P2IVIT40:6QX@80ZZZZ102Q
XJ470;fm_@80_kno0P3?cll20=SHf0@0i^KV0P3dm?@20?Ogm`80lO7a0P3/k>`40?Ogm`@0m?Cd0P3g
moL20?Cdm0l0oooo000=0?ooo`@0moOg0P3alO420?Ogm`80lO7a103dm?@40?Ogm`80kno_203gmoL2
0?7al@<0m?Cd0P3gmoL20?7al@80m?Cd0P3/k>`20?7al@80moOg0P3alO420?Cdm080moOg0P3_knl2
0?Cdm080kno_0P3/k>`20>KViP80jNWY0P3;bl/20:^[Z`@0S8b<0P1gMgL207]kN`80LG5a101DE5@2
04A4A080C4a<0P1ADE42038b<P80/k>c0P2o_kl20<71`@<0b<S8102o_kl20<;2`P@0_Kfm0P32`/84
0;fm_@@0`/;22P2m_Kd20<;2`PH0^[Zj0P2m_Kd20:n_[`80_Kfm0P2_[jl20;Fe]@80/K6a0P2_[jl2
0:b/[080YjNW0P2IVIT40:6QX@<0_Kfm0P2o_kl209BDU080VIVI102QXJ4209BDU080PH610P1jNWX2
06IVIP80QHF50P1eMGD206i^KP80LG5a0P25QHD208J6QP80MgMg0P2<S8`409NGU`80TY:B0P2<S8`2
07]kN`80Zj^[0P2GUiL20:^[Z`80VIVI0P2m_Kd20:6QX@80ZZZZ2@2m_Kd20<O7a`80bLW90P3Vi^H4
0>WYj@80m?Cd0P3gmoL20>c/k0H0moOg0P3alO460?Ogm`l0oooo000=0?ooo`@0moOg0P3alO420?Og
m`80lO7a103dm?@40?Ogm`80kno_203gmoL20?7al@<0m?Cd0P3gmoL20?7al@80m?Cd0P3/k>`20?7a
l@80moOg0P3alO420?Cdm080moOg0P3_knl20?Cdm080kno_0P3/k>`20>KViP80jNWY0P3;bl/20:^[
Z`@0S8b<0P1gMgL207]kN`80LG5a101DE5@204A4A080C4a<0P1ADE42038b<P80/k>c0P2o_kl20<71
`@<0b<S8102o_kl20<;2`P@0_Kfm0P32`/840;fm_@@0`/;22P2m_Kd20<;2`PH0^[Zj0P2m_Kd20:n_
[`80_Kfm0P2_[jl20;Fe]@80/K6a0P2_[jl20:b/[080YjNW0P2IVIT40:6QX@<0_Kfm0P2o_kl209BD
U080VIVI102QXJ4209BDU080PH610P1jNWX206IVIP80QHF50P1eMGD206i^KP80LG5a0P25QHD208J6
QP80MgMg0P2<S8`409NGU`80TY:B0P2<S8`207]kN`80Zj^[0P2GUiL20:^[Z`80VIVI0P2m_Kd20:6Q
X@80ZZZZ2@2m_Kd20<O7a`80bLW90P3Vi^H40>WYj@80m?Cd0P3gmoL20>c/k0H0moOg0P3alO460?Og
m`l0oooo000=0?ooo`80moOg0P3alO420?Ogm`80kno_2P3gmoL20?Cdm0P0moOg0P3dm?@30>o_k`@0
moOg103dm?@20>c/k080moOg0P3dm?@20?Ogm`@0lO7a103gmoL20>o_k`@0i^KV0P2c/k<20:^[Z`80
S8b<0P1kNg/207=cL`@0IVIV0P1ADE4205ADE0@0FUYJ0P14A4@201lO7`80_kno0P2j^[X20<71`@<0
_kno0P32`/820;no_`80`/;2102m_Kd20<;2`Q80_Kfm0P2j^[X20;fm_@@0^[Zj1P2_[jl20;Fe]@80
[jn_102a/K420:NWY`80XJ6Q102DU9@20:n_[`<0/k>c0P2DU9@408j>SP80TI6A0P2>SXh20861P@80
NGUi0P1NGUh207=cL`80QHF51P1eMGD207MgM`80Lg=c0P1gMgL208b<S080UiNG0P2IVIT408f=S@80
UiNG0P2SXj<209VIV@80XJ6Q102IVIT40:RXZ080ZZZZ1@2o_kl20<71`@80f=SH0P3_knl20>KViP80
jNWY0P3/k>`40?Ogm`80m?Cd103gmoL20?7al@80m?Cd0P3alO440?Ogm`l0oooo000=0?ooo`80moOg
0P3alO420?Ogm`80kno_2P3gmoL20?Cdm0P0moOg0P3dm?@30>o_k`@0moOg103dm?@20>c/k080moOg
0P3dm?@20?Ogm`@0lO7a103gmoL20>o_k`@0i^KV0P2c/k<20:^[Z`80S8b<0P1kNg/207=cL`@0IVIV
0P1ADE4205ADE0@0FUYJ0P14A4@201lO7`80_kno0P2j^[X20<71`@<0_kno0P32`/820;no_`80`/;2
102m_Kd20<;2`Q80_Kfm0P2j^[X20;fm_@@0^[Zj1P2_[jl20;Fe]@80[jn_102a/K420:NWY`80XJ6Q
102DU9@20:n_[`<0/k>c0P2DU9@408j>SP80TI6A0P2>SXh20861P@80NGUi0P1NGUh207=cL`80QHF5
1P1eMGD207MgM`80Lg=c0P1gMgL208b<S080UiNG0P2IVIT408f=S@80UiNG0P2SXj<209VIV@80XJ6Q
102IVIT40:RXZ080ZZZZ1@2o_kl20<71`@80f=SH0P3_knl20>KViP80jNWY0P3/k>`40?Ogm`80m?Cd
103gmoL20?7al@80m?Cd0P3alO440?Ogm`l0oooo000=0?ooo`H0moOg0P3alO440?Ogm`80m?Cd0P3g
moL20?Cdm080moOg0P3dm?@80?Ogm`/0m?Cd103gmoL20?Cdm080moOg0P3alO460?Ogm`80lO7a0P3V
i^H20=OGe`80Zj^[0P2QXJ4208f=S@80PH610P1gMgL207=cL`80E5AD0P1<C4`205YJFP80GUiN0P1D
E5@203dm?@80>CTi0P31`L420;bl_080b<S80`31`L420;Zj^P80`/;2102o_kl20<;2`P80_Kfm0P30
`<040;fm_@80]KFe102m_Kd80;Fe]@80_Kfm0P2_[jl20;Fe]@80/K6a0P2_[jl20;Fe]@80ZZZZ0P2/
[:`20:ZZZP80Xj>S0P2QXJ42092@T080U9BD0P2GUiL20:6QX@<0VIVI0P2<S8`208j>SP@0S8b<0P21
PH4206IVIP@0K6a/0P1aLG4209:BTP80QXJ60P25QHD207EeM@80LG5a0P2=SHd208J6QP80S8b<0P2=
SHd209:BTP80UIFE0P2[Zj/40:6QX@80UIFE1P2IVIT20:6QX@80_Kfm0P31`L420<S8b0<0`L710P3H
f=P20=gMg@80i^KV0P3/k>`20>KViP80k>c/0P3_knl20>c/k0@0moOg0P3dm?@:0?Ogm`l0oooo000=
0?ooo`H0moOg0P3alO440?Ogm`80m?Cd0P3gmoL20?Cdm080moOg0P3dm?@80?Ogm`/0m?Cd103gmoL2
0?Cdm080moOg0P3alO460?Ogm`80lO7a0P3Vi^H20=OGe`80Zj^[0P2QXJ4208f=S@80PH610P1gMgL2
07=cL`80E5AD0P1<C4`205YJFP80GUiN0P1DE5@203dm?@80>CTi0P31`L420;bl_080b<S80`31`L42
0;Zj^P80`/;2102o_kl20<;2`P80_Kfm0P30`<040;fm_@80]KFe102m_Kd80;Fe]@80_Kfm0P2_[jl2
0;Fe]@80/K6a0P2_[jl20;Fe]@80ZZZZ0P2/[:`20:ZZZP80Xj>S0P2QXJ42092@T080U9BD0P2GUiL2
0:6QX@<0VIVI0P2<S8`208j>SP@0S8b<0P21PH4206IVIP@0K6a/0P1aLG4209:BTP80QXJ60P25QHD2
07EeM@80LG5a0P2=SHd208J6QP80S8b<0P2=SHd209:BTP80UIFE0P2[Zj/40:6QX@80UIFE1P2IVIT2
0:6QX@80_Kfm0P31`L420<S8b0<0`L710P3Hf=P20=gMg@80i^KV0P3/k>`20>KViP80k>c/0P3_knl2
0>c/k0@0moOg0P3dm?@:0?Ogm`l0oooo000=0?ooo`80moOg0P3dm?@60?Ogm`@0m?Cd103gmoL20?Cd
m0P0moOg0P3dm?@30?Ogm`@0m?Cd103gmoL20?Cdm080moOg2P3dm?@20>o_k`80lO7a0P3Vi^H20=GE
e@80[Zj^0P2IVIT208b<S080Ng]k0P1cLg<2075aL@80GUiN0P1JFUX2075aL@80FUYJ100i>CT2038b
<P80`L710P2l_;`20;no_`<0/k>c0P2o_kl40<;2`P@0]KFe0P2m_Kd20;Zj^PH0]KFe0P2_[jl40;Fe
]@@0[jn_0P2e]KD20:b/[080]KFe202/[:`40:ZZZP@0XJ6Q0P2IVIT209:BTP80SXj>0P2SXj<2096A
T@<0PH610P1jNWX208J6QP80Ng]k0P21PH4206ATI080Ng]k101aLG4207=cL`80QXJ60P2BTY8208b<
S080Ng]k0P26QXH20861P@80QXJ60P2=SHd207]kN`80TI6A0P2EUID60:^[Z`80UiNG0P2IVIT20:^[
Z`80UiNG0P2QXJ420;fm_@80_kno0P37alL30=SHf080i^KV0P3_knl20>KViP80k>c/0P3Vi^H40>o_
k`H0moOg0P3dm?@20?7al@80m?Cd0P3alO420?Cdm080moOg3`3oool000d0oooo0P3gmoL20?Cdm0H0
moOg103dm?@40?Ogm`80m?Cd203gmoL20?Cdm0<0moOg103dm?@40?Ogm`80m?Cd0P3gmoL:0?Cdm080
kno_0P3alO420>KViP80eMGE0P2^[Zh209VIV@80S8b<0P1kNg/207=cL`80LG5a0P1NGUh205YJFP80
LG5a0P1JFUX403Ti>@80<S8b0P31`L420;bl_080_kno0`2c/k<20;no_`@0`/;2102e]KD20;fm_@80
^[Zj1P2e]KD20:n_[`@0]KFe102_[jl20;Fe]@80[:b/0P2e]KD80:b/[0@0ZZZZ102QXJ4209VIV@80
TY:B0P2>SXh20:>SX`80TI6A0`21PH4207YjNP80QXJ60P1kNg/20861P@80I6AT0P1kNg/4075aL@80
Lg=c0P26QXH209:BTP80S8b<0P1kNg/208J6QP80PH610P26QXH208f=S@80Ng]k0P2ATI4209FEU@H0
Zj^[0P2GUiL209VIV@80Zj^[0P2GUiL20:6QX@80_Kfm0P2o_kl20<O7a`<0f=SH0P3Vi^H20>o_k`80
i^KV0P3/k>`20>KViP@0kno_1P3gmoL20?Cdm080lO7a0P3dm?@20?7al@80m?Cd0P3gmoL?0?ooo`00
3@3oool60?Ogm`80m?Cd103gmoL20?Cdm0H0moOg0P3dm?@C0?Ogm`80m?Cd0P3gmoL40?Cdm080moOg
0P3_knl20?7al@@0moOg0P3Vi^H20<71`@@0XJ6Q0P2=SHd207]kN`@0Lg=c0P1DE5@206IVIP80FUYJ
0P1<C4`2038b<P80?Cdm0P0b<S8;0;no_`80^[Zj0P32`/820;fm_@80]KFe0P2m_Kd20;Fe]@80[jn_
0P2e]KD20:n_[`80[:b/0P2_[jl20:b/[080[jn_1P2/[:`20;6a/@80[jn_0P2ZZZX20:NWY`80Xj>S
0P2ZZZX40:>SX`80XJ6Q0P2IVIT208b<S080VIVI0P2DU9@20861P@<0NWYj0P1kNg/407=cL`80GUiN
101/K6`205YJFP80IVIV0P1gMgL609:BTP80VIVI1026QXH407]kN`80SHf=0P2EUID208b<S080ZJVY
0P2[Zj/20:>SX`80UIFE0P2[Zj/20;6a/@80XJ6Q0P2_[jl40;fm_@80f=SH0`3Ph>020>KViP80gMgM
0P3Vi^H20>c/k0H0m?Cd0P3gmoL20?Cdm0H0moOg103dm?@20?Ogm`80m?Cd3`3oool000d0oooo1P3g
moL20?Cdm0@0moOg0P3dm?@60?Ogm`80m?Cd4`3gmoL20?Cdm080moOg103dm?@20?Ogm`80kno_0P3a
lO440?Ogm`80i^KV0P31`L440:6QX@80SHf=0P1kNg/407=cL`80E5AD0P1VIVH205YJFP80C4a<0P0b
<S8203dm?@80<S8b2`2o_kl20;Zj^P80`/;20P2m_Kd20;Fe]@80_Kfm0P2e]KD20:n_[`80]KFe0P2_
[jl20:b/[080[jn_0P2/[:`20:n_[`H0[:b/0P2a/K420:n_[`80ZZZZ0P2WYjL20:>SX`80ZZZZ102S
Xj<20:6QX@80VIVI0P2<S8`209VIV@80U9BD0P21PH4307YjNP80Ng]k101cLg<205iNGP@0K6a/0P1J
FUX206IVIP80MgMg1P2BTY8209VIV@@0QXJ6101kNg/208f=S@80UIFE0P2<S8`20:VYZ@80Zj^[0P2S
Xj<209FEU@80Zj^[0P2a/K420:6QX@80[jn_102m_Kd20=SHf0<0h>3P0P3Vi^H20=gMg@80i^KV0P3/
k>`60?Cdm080moOg0P3dm?@60?Ogm`@0m?Cd0P3gmoL20?Cdm0l0oooo000=0?ooo`P0moOg103dm?@2
0?Ogm`80m?Cd0P3alO480?Ogm`80m?Cd2`3gmoL20?Cdm0@0moOg0P3dm?@20>c/k080m?Cd0P3/k>`2
0?Ogm`80m?Cd103_knl20:b/[080XJ6Q0P2ATI4208b<S080IVIV0P1/K6`405iNGP80IVIV0P1NGUh2
04Q8B080?Cdm0P18B4P203Ti>@80`L710P2f][H20;no_`<0^[Zj0P2o_kl20;Zj^P80]KFe0P2m_Kd6
0;Fe]@80[jn_1P2/[:`20:FUY@80YjNW0P2ZZZX40:NWY`80[:b/102ZZZX20:6QX@80YJFU202QXJ44
09BDU080S8b<0P2IVIT208b<S080Ng]k0`1cLg<4075aL@80I6AT0P1cLg<206a/K0@0GUiN0P1VIVH2
07EeM@80QHF50P2BTY8208b<S080TY:B0P2<S8`208f=S@@0Ng]k0P1gMgL208b<S080XJ6Q0P2SXj<2
0:6QX@@0[Zj^0P2[Zj/209VIV@80XJ6Q0P2_[jl20;no_`80bLW91@3MgMd20>KViP80kno_0P3/k>`2
0>KViP80m?Cd0P3gmoL20?Cdm0X0moOg0P3dm?@40?Ogm`80m?Cd3`3oool000d0oooo203gmoL40?Cd
m080moOg0P3dm?@20?7al@P0moOg0P3dm?@;0?Ogm`80m?Cd103gmoL20?Cdm080k>c/0P3dm?@20>c/
k080moOg0P3dm?@40>o_k`80[:b/0P2QXJ42096AT@80S8b<0P1VIVH206a/K0@0GUiN0P1VIVH205iN
GP80B4Q80P0m?Cd204Q8B080>CTi0P31`L420;Jf]P80_kno0`2j^[X20;no_`80^[Zj0P2e]KD20;fm
_@H0]KFe0P2_[jl60:b/[080YJFU0P2WYjL20:ZZZP@0YjNW0P2/[:`40:ZZZP80XJ6Q0P2UYJD80:6Q
X@@0U9BD0P2<S8`209VIV@80S8b<0P1kNg/307=cL`@0LG5a0P1TI6@207=cL`80K6a/101NGUh206IV
IP80MGEe0P25QHD209:BTP80S8b<0P2BTY8208b<S080SHf=101kNg/207MgM`80S8b<0P2QXJ420:>S
X`80XJ6Q102^[Zh20:^[Z`80VIVI0P2QXJ420:n_[`80_kno0P39bLT50=gMg@80i^KV0P3_knl20>c/
k080i^KV0P3dm?@20?Ogm`80m?Cd2P3gmoL20?Cdm0@0moOg0P3dm?@?0?ooo`003@3oool20?Ogm`@0
m?Cd0P3gmoL40?Cdm0H0moOg0P3dm?@20?7al@@0moOg0P3dm?@50?Ogm`@0m?Cd0P3_knl20?7al@80
moOg103dm?@40?Ogm`80m?Cd0P3gmoL20>c/k080kno_0P3EeMD20:j^[P80XJ6Q0P2<S8`20861P@80
Lg=c0P1kNg/205YJFP@0IVIV0P1NGUh4038b<P80>CTi0P0m?Cd20;no_`80/k>c0P2l_;`30;>c/`@0
^[Zj1P2e]KD20:b/[080[jn_0P2ZZZX20:NWY`80ZZZZ102WYjL20:FUY@H0VIVI102QXJ420:NWY`@0
XJ6Q1P2IVIT409BDU080SXj>0P2=SHd207]kN`80Lg=c0P1aLG4306IVIP80LG5a101cLg<606IVIP80
KVi^0P1eMGD207MgM`80QHF50P2BTY820:RXZ080XJ6Q0P2_[jl2096AT@@0LG5a0P1kNg/2096AT@80
S8b<0P2QXJ460:^[Z`H0UiNG0P2m_Kd20<O7a`80bLW90P3MgMd30>KViP80gMgM0P3/k>`20>KViP80
moOg0P3dm?@80?Ogm`80m?Cd1P3gmoL20?7al@80moOg0P3dm?@?0?ooo`003@3oool20?Ogm`@0m?Cd
0P3gmoL40?Cdm0H0moOg0P3dm?@20?7al@@0moOg0P3dm?@50?Ogm`@0m?Cd0P3_knl20?7al@80moOg
103dm?@40?Ogm`80m?Cd0P3gmoL20>c/k080kno_0P3EeMD20:j^[P80XJ6Q0P2<S8`20861P@80Lg=c
0P1kNg/205YJFP@0IVIV0P1NGUh4038b<P80>CTi0P0m?Cd20;no_`80/k>c0P2l_;`30;>c/`@0^[Zj
1P2e]KD20:b/[080[jn_0P2ZZZX20:NWY`80ZZZZ102WYjL20:FUY@H0VIVI102QXJ420:NWY`@0XJ6Q
1P2IVIT409BDU080SXj>0P2=SHd207]kN`80Lg=c0P1aLG4306IVIP80LG5a101cLg<606IVIP80KVi^
0P1eMGD207MgM`80QHF50P2BTY820:RXZ080XJ6Q0P2_[jl2096AT@@0LG5a0P1kNg/2096AT@80S8b<
0P2QXJ460:^[Z`H0UiNG0P2m_Kd20<O7a`80bLW90P3MgMd30>KViP80gMgM0P3/k>`20>KViP80moOg
0P3dm?@80?Ogm`80m?Cd1P3gmoL20?7al@80moOg0P3dm?@?0?ooo`003@3oool20?Cdm0@0moOg103d
m?@20>o_k`@0lO7a0P3dm?@60?Ogm`80lO7a0P3gmoL20?Cdm0<0moOg0P3dm?@20?Ogm`80kno_2P3g
moL20?Cdm080lO7a0P3dm?@40>o_k`80`L710P2[Zj/209FEU@80SHf=0P1kNg/206IVIP80K6a/0P1N
GUh2075aL@80E5AD0P1<C4`402XZ:P@0>CTi0P2o_kl20;>c/`80^[Zj0`2l_;`20;Zj^P@0]KFe0P2/
[:`80:ZZZP80YJFU0P2SXj<20:6QX@80YJFU102QXJ4809VIV@@0XJ6Q1P2IVIT408j>SP80S8b<0P21
PH4208b<S080MgMg0P1VIVH205iNGP<0Lg=c0P1VIVH407=cL`@0B4Q80P1DE5@2079bLPH0QHF50P2<
S8`209NGU`80XJ6Q0P2IVIT20:^[Z`80SHf=0P1kNg/408b<S080VIVI0P2<S8`40:j^[P80VIVI0P2G
UiL209VIV@80UiNG0P2m_Kd20<O7a`80i^KV0P3MgMd50>KViP80jNWY0P3alO420?Ogm`80k>c/0P3_
knl40?Ogm`80m?Cd1P3gmoL20?Cdm0H0moOg3`3oool000d0oooo0P3dm?@40?Ogm`@0m?Cd0P3_knl4
0?7al@80m?Cd1P3gmoL20?7al@80moOg0P3dm?@30?Ogm`80m?Cd0P3gmoL20>o_k`X0moOg0P3dm?@2
0?7al@80m?Cd103_knl20<71`@80Zj^[0P2EUID208f=S@80Ng]k0P1VIVH206a/K080GUiN0P1aLG42
05ADE080C4a<100Z:RX403Ti>@80_kno0P2c/k<20;Zj^P<0_;bl0P2j^[X40;Fe]@80[:b/202ZZZX2
0:FUY@80Xj>S0P2QXJ420:FUY@@0XJ6Q202IVIT40:6QX@H0VIVI102>SXh208b<S080PH610P2<S8`2
07MgM`80IVIV0P1NGUh307=cL`80IVIV101cLg<404Q8B080E5AD0P1bLW8608F5Q@80S8b<0P2GUiL2
0:6QX@80VIVI0P2[Zj/208f=S@80Ng]k102<S8`209VIV@80S8b<102^[Zh209VIV@80UiNG0P2IVIT2
09NGU`80_Kfm0P37alL20>KViP80gMgM1@3Vi^H20>WYj@80lO7a0P3gmoL20>c/k080kno_103gmoL2
0?Cdm0H0moOg0P3dm?@60?Ogm`l0oooo000=0?ooo`P0moOg0P3dm?@@0?Ogm`80kno_0P3dm?@30?Og
m`80kno_0P3gmoL20?Cdm080moOg0P3dm?@20?Ogm`80m?Cd0P3_knl20?Cdm080moOg0P3/k>`20?Cd
m080gMgM0P2h^;P20:^[Z`80SHf=0P21PH4207=cL`80K6a/101NGUh206IVIP80E5AD0P14A4@203Ti
>@@0?Cdm0P14A4@40;>c/`D0/K6a0P2e]KD20;6a/@80[:b/0P2a/K440:b/[080Xj>S102UYJD609VI
V@80T92@102DU9@2092@T0@0VIVI0P2@T90609VIV@80SXj>0P2<S8`208j>SP80S8b<0P1kNg/209:B
TP80Lg=c0P1DE5@506a/K080IVIV0P1NGUh204a<C080B4Q80P0b<S8206i^KP80QHF50P1bLW8208F5
Q@80MgMg0P26QXH209NGU`80Z:RX0P2SXj<20:n_[`@0SHf=0P2GUiL208f=S@80VIVI0P2EUID20:^[
Z`@0VIVI0P2<S8`209:BTP80[jn_0P37alL20=SHf0L0gMgM0P3/k>`40>o_k`80moOg103dm?@60?Og
m`80lO7a0P3gmoL20?Cdm080moOg0P3dm?@40?Ogm`l0oooo000=0?ooo`P0moOg0P3dm?@@0?Ogm`80
kno_0P3dm?@30?Ogm`80kno_0P3gmoL20?Cdm080moOg0P3dm?@20?Ogm`80m?Cd0P3_knl20?Cdm080
moOg0P3/k>`20?Cdm080gMgM0P2h^;P20:^[Z`80SHf=0P21PH4207=cL`80K6a/101NGUh206IVIP80
E5AD0P14A4@203Ti>@@0?Cdm0P14A4@40;>c/`D0/K6a0P2e]KD20;6a/@80[:b/0P2a/K440:b/[080
Xj>S102UYJD609VIV@80T92@102DU9@2092@T0@0VIVI0P2@T90609VIV@80SXj>0P2<S8`208j>SP80
S8b<0P1kNg/209:BTP80Lg=c0P1DE5@506a/K080IVIV0P1NGUh204a<C080B4Q80P0b<S8206i^KP80
QHF50P1bLW8208F5Q@80MgMg0P26QXH209NGU`80Z:RX0P2SXj<20:n_[`@0SHf=0P2GUiL208f=S@80
VIVI0P2EUID20:^[Z`@0VIVI0P2<S8`209:BTP80[jn_0P37alL20=SHf0L0gMgM0P3/k>`40>o_k`80
moOg103dm?@60?Ogm`80lO7a0P3gmoL20?Cdm080moOg0P3dm?@40?Ogm`l0oooo000=0?ooo`@0moOg
0P3dm?@20?Ogm`@0m?Cd0P3alO440?Cdm080moOg0P3dm?@;0?Ogm`80lO7a0P3_knl20?Cdm080lO7a
103gmoL20?Cdm0@0moOg0P3alO420?Cdm080k>c/0P39bLT20:j^[P80WinO1021PH4206a/K080LG5a
0P1VIVH405iNGP@0?Cdm0P0i>CT603dm?@80/k>c0P2a/K420;>c/`<0`L71102g]kL20;Fe]@80]kNg
102e]KD20;6a/@@0[:b/0P2SXj<209BDU080S8b<0P2DU9@208V9R@P0S8b<102DU9@608b<S0@0PH61
0P1jNWX207]kN`80S8b<0P1VIVH204];B`80IVIV0`1cLg<205ADE080B4Q80P14A4@204];B`80FUYJ
0P1[Jf/408F5Q@80Ng]k0P25QHD2075aL@80UiNG0P2QXJ420:^[Z`80VIVI0P2EUID208b<S0@0TI6A
0P2=SHd40:^[Z`80UiNG0P2QXJ4209NGU`@0Zj^[0P36a/H20>o_k`80f=SH0P3MgMd30>c/k080jNWY
203gmoL20?Cdm0h0moOg0P3dm?@20?Ogm`80m?Cd3`3oool000d0oooo103gmoL20?Cdm080moOg103d
m?@20?7al@@0m?Cd0P3gmoL20?Cdm0/0moOg0P3alO420>o_k`80m?Cd0P3alO440?Ogm`80m?Cd103g
moL20?7al@80m?Cd0P3/k>`20<W9b@80[Zj^0P2OWil40861P@80K6a/0P1aLG4206IVIP@0GUiN100m
?Cd203Ti>@H0?Cdm0P2c/k<20;6a/@80/k>c0`31`L440;Ng]`80]KFe0P2g]kL40;Fe]@80/K6a102/
[:`20:>SX`80U9BD0P2<S8`209BDU080RHV9202<S8`409BDU0H0S8b<1021PH4207YjNP80Ng]k0P2<
S8`206IVIP80Bd];0P1VIVH307=cL`80E5AD0P18B4P204A4A080Bd];0P1JFUX206][J`@0QHF50P1k
Ng/208F5Q@80LG5a0P2GUiL20:6QX@80Zj^[0P2IVIT209FEU@80S8b<102ATI4208f=S@@0Zj^[0P2G
UiL20:6QX@80UiNG102[Zj/20<K6aP80kno_0P3Hf=P20=gMg@<0k>c/0P3YjNT80?Ogm`80m?Cd3P3g
moL20?Cdm080moOg0P3dm?@?0?ooo`003@3oool20?Cdm0@0moOg103/k>`20?Ogm`80m?Cd103gmoL4
0?Cdm0@0moOg0P3alO420?Ogm`<0m?Cd0P3gmoL20>o_k`80m?Cd0P3_knl40?Ogm`@0m?Cd1P3alO42
0>KViP80a/K60P2[Zj/209FEU@80PH610P1kNg/207=cL`80IVIV0P1kNg/405iNGP809bLW0P15ADD4
03dm?@80>CTi0P1DE5@20;>c/`80alO71`3:b/X40<S8b0H0`<300P2i^KT40;Ng]`80/K6a0P2/[:`2
0:>SX`@0RHV90P26QXH408V9R@H0PH610P2<S8`208V9R@80PH610P26QXH207]kN`@0Lg=c0P26QXH2
05ADE080EEEE0P1VIVH305iNGP80C4a<0P0i>CT203dm?@80KVi^0P1<C4`206IVIP80QXJ60P25QHD2
07]kN`80LG5a0P1kNg/209:BTP80Xj>S0P2_[jl20;6a/@80Zj^[102EUID20861P@80MgMg102[Zj/2
09FEU@80VIVI102[Zj/20;no_`80k>c/1P3Vi^H30>c/k080kno_0P3dm?@20?Ogm`80m?Cd203gmoL2
0?Cdm0X0moOg0P3dm?@20?7al@l0oooo000=0?ooo`80m?Cd103gmoL40>c/k080moOg0P3dm?@40?Og
m`@0m?Cd103gmoL20?7al@80moOg0`3dm?@20?Ogm`80kno_0P3dm?@20>o_k`@0moOg103dm?@60?7a
l@80i^KV0P36a/H20:^[Z`80UIFE0P21PH4207]kN`80Lg=c0P1VIVH207]kN`@0GUiN0P0W9bL204E5
A@@0?Cdm0P0i>CT205ADE080/k>c0P37alL70<[:bP@0b<S81P30`<020;Vi^@@0]kNg0P2a/K420:b/
[080Xj>S1029RHT208J6QP@0RHV91P21PH4208b<S080RHV90P21PH4208J6QP80Ng]k101cLg<208J6
QP80E5AD0P1EEED206IVIP<0GUiN0P1<C4`203Ti>@80?Cdm0P1^KVh204a<C080IVIV0P26QXH208F5
Q@80Ng]k0P1aLG4207]kN`80TY:B0P2SXj<20:n_[`80/K6a0P2[Zj/409FEU@80PH610P1gMgL40:^[
Z`80UIFE0P2IVIT40:^[Z`80_kno0P3/k>`60>KViP<0k>c/0P3_knl20?Cdm080moOg0P3dm?@80?Og
m`80m?Cd2P3gmoL20?Cdm080lO7a3`3oool000d0oooo0P3gmoL40?Cdm0H0moOg0P3dm?@<0?Ogm`80
m?Cd1@3gmoL20?Cdm0@0moOg0P3/k>`20?Ogm`80m?Cd0P3gmoL20>o_k`80lO7a103dm?@20<o?c`80
^;Rh0P2QXJ42096AT@80PH610P1iNGT205iNGP80IVIV0P1NGUh206IVIP80C4a<0P0b<S8204Q8B080
ADE50P0m?Cd203Ti>@80QXJ60P3:b/X20<g=c@80f=SH1@3@d=040<[:bP80d=3@103:b/X40<30`080
_;bl0P2g]kL20;6a/@80[:b/0P2WYjL209VIV@80QXJ60P1kNg/20861P@@0QXJ60P29RHT207YjNP80
PH610P26QXH20861P@80Ng]k0P1cLg<206ATI080Ng]k0P1NGUh206IVIP80Ng]k0`1<C4`204A4A080
>CTi0P19BDT207EeM@80DE5A0P1VIVH207MgM`80QXJ60P1eMGD2075aL@80Ng]k0P2<S8`209:BTP80
[jn_0P2a/K420:^[Z`80XJ6Q0P2EUID207]kN`80SHf=202QXJ420;fm_@80XJ6Q0P2o_kl20>c/k080
gMgM0P3EeMD50>WYj@80moOg0P3dm?@20?Ogm`80lO7a0P3dm?@20?7al@@0m?Cd103gmoL20?Cdm0X0
moOg3`3oool000d0oooo0P3gmoL40?Cdm0H0moOg0P3dm?@<0?Ogm`80m?Cd1@3gmoL20?Cdm0@0moOg
0P3/k>`20?Ogm`80m?Cd0P3gmoL20>o_k`80lO7a103dm?@20<o?c`80^;Rh0P2QXJ42096AT@80PH61
0P1iNGT205iNGP80IVIV0P1NGUh206IVIP80C4a<0P0b<S8204Q8B080ADE50P0m?Cd203Ti>@80QXJ6
0P3:b/X20<g=c@80f=SH1@3@d=040<[:bP80d=3@103:b/X40<30`080_;bl0P2g]kL20;6a/@80[:b/
0P2WYjL209VIV@80QXJ60P1kNg/20861P@@0QXJ60P29RHT207YjNP80PH610P26QXH20861P@80Ng]k
0P1cLg<206ATI080Ng]k0P1NGUh206IVIP80Ng]k0`1<C4`204A4A080>CTi0P19BDT207EeM@80DE5A
0P1VIVH207MgM`80QXJ60P1eMGD2075aL@80Ng]k0P2<S8`209:BTP80[jn_0P2a/K420:^[Z`80XJ6Q
0P2EUID207]kN`80SHf=202QXJ420;fm_@80XJ6Q0P2o_kl20>c/k080gMgM0P3EeMD50>WYj@80moOg
0P3dm?@20?Ogm`80lO7a0P3dm?@20?7al@@0m?Cd103gmoL20?Cdm0X0moOg3`3oool000d0oooo0P3d
m?@20?Ogm`80kno_0P3gmoL20?Cdm080kno_0P3gmoL20?7al@P0moOg0P3dm?@20>o_k`80moOg1@3d
m?@20?Ogm`@0m?Cd0P3gmoL20?Cdm0@0lO7a0P3_knl40?Cdm080clo?0P2/[:`209FEU@80SHf=0P1i
NGT407=cL`80IVIV0P1NGUh206IVIP80<S8b0P0m?Cd204];B`@0?Cdm0P2=SHd20<g=c@80dm?C0P3H
f=P20=?Cd`<0f=SH0P3@d=020=SHf080d=3@0P3Cdm<20=3@d080b/[:0P38b<P20<[:bP@0`<300P2g
]kL20;Fe]@80[:b/0P2ZZZX20:6QX@80VIVI201kNg/208J6QP80Ng]k0P21PH4207]kN`80LG5a0P1/
K6`205EEE@80C4a<0P1kNg/205iNGP80S8b<0`14A4@203Ti>@809bLW0P0b<S82075aL@80MgMg0P1J
FUX207MgM`80TY:B0P1aLG4208f=S@80Ng]k0P2<S8`20:6QX@80[jn_0P2m_Kd20<71`@80[Zj^0P1g
MgL408f=S@80VIVI0P2ATI420:6QX@80[Zj^0P2[Zj/20:ZZZP80jNWY0P3MgMd20=;BdP80i^KV0P3_
knl30?Cdm0@0moOg0P3_knl80?Ogm`@0m?Cd203gmoL20?Cdm0@0moOg3`3oool000d0oooo0P3dm?@2
0?Ogm`80kno_0P3gmoL20?Cdm080kno_0P3gmoL20?7al@P0moOg0P3dm?@20>o_k`80moOg1@3dm?@2
0?Ogm`@0m?Cd0P3gmoL20?Cdm0@0lO7a0P3_knl40?Cdm080clo?0P2/[:`209FEU@80SHf=0P1iNGT4
07=cL`80IVIV0P1NGUh206IVIP80<S8b0P0m?Cd204];B`@0?Cdm0P2=SHd20<g=c@80dm?C0P3Hf=P2
0=?Cd`<0f=SH0P3@d=020=SHf080d=3@0P3Cdm<20=3@d080b/[:0P38b<P20<[:bP@0`<300P2g]kL2
0;Fe]@80[:b/0P2ZZZX20:6QX@80VIVI201kNg/208J6QP80Ng]k0P21PH4207]kN`80LG5a0P1/K6`2
05EEE@80C4a<0P1kNg/205iNGP80S8b<0`14A4@203Ti>@809bLW0P0b<S82075aL@80MgMg0P1JFUX2
07MgM`80TY:B0P1aLG4208f=S@80Ng]k0P2<S8`20:6QX@80[jn_0P2m_Kd20<71`@80[Zj^0P1gMgL4
08f=S@80VIVI0P2ATI420:6QX@80[Zj^0P2[Zj/20:ZZZP80jNWY0P3MgMd20=;BdP80i^KV0P3_knl3
0?Cdm0@0moOg0P3_knl80?Ogm`@0m?Cd203gmoL20?Cdm0@0moOg3`3oool000d0oooo0P3gmoL20?Cd
m0X0moOg0P3alO420?Cdm080kno_1P3gmoL20>o_k`80m?Cd0`3gmoL80?Cdm0P0moOg0P3alO420>WY
j@80eMGE0P37alL209nOW`80UIFE0P21PH4206a/K080GUiN101VIVH205iNGP80D51@0P0b<S8404];
B`80?Cdm0P39bLT20=?Cd`80cLg=0P3Cdm<;0=SHf0H0d=3@0P3Cdm<20<[:bPH0b<S80P2o_kl20;>c
/`80/K6a0P2e]KD20:b/[080Xj>S0P2IVIT207YjNP@0Lg=c0P1kNg/207=cL`80NWYj0P1cLg<2075a
L@80IVIV0P1<C4`204Q8B080S8b<0P1<C4`209BDU0<0IVIV0P0m?Cd204U9B@809bLW0P1<C4`208J6
QP80DE5A0P1gMgL208J6QP80MGEe1P2<S8`209NGU`80XJ6Q0P2o_kl20<71`@80Zj^[0P2ATI420861
P@80SHf=102EUID20:^[Z`80[Zj^0P2[Zj/20;fm_@80gMgM0P3GemL20=gMg@@0k>c/0`3gmoL20>o_
k`80moOg0P3dm?@40?Ogm`@0m?Cd0P3gmoL40?Cdm0`0moOg3`3oool000d0oooo0P3gmoL20?Cdm0X0
moOg0P3alO420?Cdm080kno_1P3gmoL20>o_k`80m?Cd0`3gmoL80?Cdm0P0moOg0P3alO420>WYj@80
eMGE0P37alL209nOW`80UIFE0P21PH4206a/K080GUiN101VIVH205iNGP80D51@0P0b<S8404];B`80
?Cdm0P39bLT20=?Cd`80cLg=0P3Cdm<;0=SHf0H0d=3@0P3Cdm<20<[:bPH0b<S80P2o_kl20;>c/`80
/K6a0P2e]KD20:b/[080Xj>S0P2IVIT207YjNP@0Lg=c0P1kNg/207=cL`80NWYj0P1cLg<2075aL@80
IVIV0P1<C4`204Q8B080S8b<0P1<C4`209BDU0<0IVIV0P0m?Cd204U9B@809bLW0P1<C4`208J6QP80
DE5A0P1gMgL208J6QP80MGEe1P2<S8`209NGU`80XJ6Q0P2o_kl20<71`@80Zj^[0P2ATI420861P@80
SHf=102EUID20:^[Z`80[Zj^0P2[Zj/20;fm_@80gMgM0P3GemL20=gMg@@0k>c/0`3gmoL20>o_k`80
moOg0P3dm?@40?Ogm`@0m?Cd0P3gmoL40?Cdm0`0moOg3`3oool000d0oooo203gmoL20?7al@h0moOg
0P3alO420?Cdm080kno_1@3gmoL20?Cdm0X0moOg0P3dm?@20>c/k080jNWY0P3;bl/20;fm_@80UIFE
0P2=SHd20861P@80Lg=c0P1TI6@206IVIP@0GUiN0P0m?Cd203Ti>@80B4Q80P0m?Cd20861P@80clo?
0P3Cdm<20<[:bP@0dm?C3@3Hf=P40=3@d0H0b/[:0P31`L420;bl_080_kno0P2j^[X20;Fe]@80/k>c
0P2/[:`20:>SX`80T92@0P2IVIT4075aL@80Lg=c0P1/K6`2075aL@80I6AT0P1NGUh2055AD@80ADE5
0P26QXH207UiN@80PH610`1kNg/203Ti>@809bLW0P18B4P206IVIP80QXJ60P2<S8`408J6QP80S8b<
0P1cLg<2096AT@80SHf=0P2EUID20:6QX@80Zj^[0P2o_kl20;fm_@80SHf=0P1kNg/208f=S@80QXJ6
0P2EUID20;Rh^080_Kfm0P2d];@20:j^[P80alO70P3Vi^H40>o_k`80m?Cd0`3gmoL20?Cdm080moOg
0P3dm?@20?Ogm`@0m?Cd203gmoL20?Cdm0H0moOg0P3dm?@20?Ogm`l0oooo000=0?ooo`P0moOg0P3a
lO4>0?Ogm`80lO7a0P3dm?@20>o_k`D0moOg0P3dm?@:0?Ogm`80m?Cd0P3/k>`20>WYj@80bl_;0P2m
_Kd209FEU@80SHf=0P21PH4207=cL`80I6AT0P1VIVH405iNGP80?Cdm0P0i>CT204Q8B080?Cdm0P21
PH420<o?c`80dm?C0P3:b/X40=?Cd`d0f=SH103@d=060<[:bP80`L710P2l_;`20;no_`80^[Zj0P2e
]KD20;>c/`80[:b/0P2SXj<2092@T080VIVI101aLG4207=cL`80K6a/0P1aLG4206ATI080GUiN0P1A
DE4204E5A@80QXJ60P1iNGT20861P@<0Ng]k0P0i>CT202LW9`80B4Q80P1VIVH208J6QP80S8b<1026
QXH208b<S080Lg=c0P2ATI4208f=S@80UIFE0P2QXJ420:^[Z`80_kno0P2m_Kd208f=S@80Ng]k0P2=
SHd208J6QP80UIFE0P2h^;P20;fm_@80];Bd0P2^[Zh20<O7a`80i^KV103_knl20?Cdm0<0moOg0P3d
m?@20?Ogm`80m?Cd0P3gmoL40?Cdm0P0moOg0P3dm?@60?Ogm`80m?Cd0P3gmoL?0?ooo`003@3oool2
0?7al@80moOg0P3dm?@60?Ogm`80kno_0P3gmoL40?Cdm080moOg1P3dm?@20>o_k`<0moOg103dm?@2
0>o_k`@0moOg0P3/k>`20?Ogm`80lO7a0P3/k>`20=gMg@80bl_;0P2/[:`209FEU@80SHf=0P1kNg/2
06a/K080EEEE0P1NGUh205ADE080GUiN0P0Z:RX203dm?@80ADE50P1NGUh20<[:bP80cLg=203Cdm<2
0=SHf0<0d=3@0P3Hf=P40=3@d080f=SH103@d=020<[:bP80b<S8103:b/X20<S8b0@0_;bl0P2j^[X2
0;>c/`80/K6a0P2/[:`20:>SX`80VIVI0P2@T90206IVIP@0LG5a0P1QHF4206IVIP80D51@0P1;Bd/2
038b<P80K6a/0P2SXj<205ADE0<0VIVI0P1TI6@207=cL`80>CTi0P1^KVh205EEE@80SHf=0P1^KVh2
08F5Q@80QXJ60P2=SHd208J6QP80UIFE0P21PH420:^[Z`80UiNG0P31`L420<o?c`80SHf=0P1kNg/2
08f=S@80TI6A0P2OWil20:6QX@80Zj^[0P2^[Zh20;fm_@80gMgM0P3Vi^H20>WYj@80kno_0P3/k>`3
0?Cdm080moOg0P3dm?@40?Ogm`@0m?Cd0P3gmoL40?Cdm080moOg103dm?@20?Ogm`80m?Cd103gmoL?
0?ooo`003@3oool20?7al@80moOg0P3dm?@60?Ogm`80kno_0P3gmoL40?Cdm080moOg1P3dm?@20>o_
k`<0moOg103dm?@20>o_k`@0moOg0P3/k>`20?Ogm`80lO7a0P3/k>`20=gMg@80bl_;0P2/[:`209FE
U@80SHf=0P1kNg/206a/K080EEEE0P1NGUh205ADE080GUiN0P0Z:RX203dm?@80ADE50P1NGUh20<[:
bP80cLg=203Cdm<20=SHf0<0d=3@0P3Hf=P40=3@d080f=SH103@d=020<[:bP80b<S8103:b/X20<S8
b0@0_;bl0P2j^[X20;>c/`80/K6a0P2/[:`20:>SX`80VIVI0P2@T90206IVIP@0LG5a0P1QHF4206IV
IP80D51@0P1;Bd/2038b<P80K6a/0P2SXj<205ADE0<0VIVI0P1TI6@207=cL`80>CTi0P1^KVh205EE
E@80SHf=0P1^KVh208F5Q@80QXJ60P2=SHd208J6QP80UIFE0P21PH420:^[Z`80UiNG0P31`L420<o?
c`80SHf=0P1kNg/208f=S@80TI6A0P2OWil20:6QX@80Zj^[0P2^[Zh20;fm_@80gMgM0P3Vi^H20>WY
j@80kno_0P3/k>`30?Cdm080moOg0P3dm?@40?Ogm`@0m?Cd0P3gmoL40?Cdm080moOg103dm?@20?Og
m`80m?Cd103gmoL?0?ooo`003@3oool20?Cdm080moOg0P3dm?@60?Ogm`@0m?Cd203gmoL40?Cdm080
moOg0`3dm?@<0?Ogm`80m?Cd103YjNT20<o?c`80bl_;0P2OWil2096AT@80NGUi0P1kNg/206ATI0@0
GUiN0P1DE5@203dm?@80>CTi0P1@D50205YJFP80cLg=0P3:b/X20<g=c@H0dm?C0P3@d=020<g=c@/0
b/[:0P38b<P40<30`080`L710P38b<P20;no_`80`/;2102l_;`20;6a/@80]KFe0P2c/k<20;6a/@80
[:b/0P2QXJ4209VIV@80U9BD0P1VIVH205iNGP80IVIV0P1EEED205ADE0@0?Cdm0P1EEED208f=S@80
PH610`1/K6`209nOW`80DE5A0P21PH4205iNGP80LG5a0P1gMgL208J6QP80LG5a0P26QXH208f=S@80
IVIV102=SHd40:6QX@80[:b/0P2a/K420;fm_@80SHf=0P1gMgL208f=S@80WinO0P2EUID20:^[Z`80
_Kfm0P3GemL20>c/k080gMgM0P3/k>`20>o_k`80k>c/0`3gmoL40?Cdm080moOg0P3dm?@40?Ogm`80
m?Cd0P3gmoL20?Cdm0H0moOg0P3dm?@60?Ogm`l0oooo000=0?ooo`80m?Cd0P3gmoL20?Cdm0H0moOg
103dm?@80?Ogm`@0m?Cd0P3gmoL30?Cdm0`0moOg0P3dm?@40>WYj@80clo?0P3;bl/209nOW`80TI6A
0P1iNGT207]kN`80I6AT101NGUh205ADE080?Cdm0P0i>CT2051@D080FUYJ0P3=cLd20<[:bP80cLg=
1P3Cdm<20=3@d080cLg=2`3:b/X20<S8b0@0`<300P31`L420<S8b080_kno0P32`/840;bl_080/K6a
0P2e]KD20;>c/`80/K6a0P2/[:`20:6QX@80VIVI0P2DU9@206IVIP80GUiN0P1VIVH205EEE@80E5AD
100m?Cd205EEE@80SHf=0P21PH4306a/K080WinO0P1ADE420861P@80GUiN0P1aLG4207MgM`80QXJ6
0P1aLG4208J6QP80SHf=0P1VIVH408f=S@@0XJ6Q0P2/[:`20;6a/@80_Kfm0P2=SHd207MgM`80SHf=
0P2OWil209FEU@80Zj^[0P2m_Kd20=OGe`80k>c/0P3MgMd20>c/k080kno_0P3/k>`30?Ogm`@0m?Cd
0P3gmoL20?Cdm0@0moOg0P3dm?@20?Ogm`80m?Cd1P3gmoL20?Cdm0H0moOg3`3oool000d0oooo103g
moL20?Cdm0H0moOg0P3dm?@20?Ogm`P0m?Cd103gmoL20?Cdm0<0moOg0P3dm?@20>o_k`80lO7a103d
m?@40?Ogm`80jNWY0P3GemL20<o?c`80];Bd0P2EUID20861P@80NGUi0P1TI6@605iNGP80<S8b0P0m
?Cd403Ti>@@0cLg=0P3Cdm<20<g=c@@0b/[:0P3@d=020<[:bP80`/;20`2l_;`40;Ng]`H0/K6a0P2/
[:`80;6a/@H0^[Zj0P2l_;`20;Zj^P@0/K6a0P2/[:`20:NWY`80Xj>S0P2QXJ4209BDU080NWYj0P1N
GUh205ADE080DE5A0P15ADD203dm?@80BDU90P1TI6@209VIV@<0SHf=0P1jNWX20:6QX@80QXJ60P21
PH4204a<C080LG5a0P2<S8`208F5Q@80QXJ60P1aLG440861P@80Xj>S0P2EUID20:6QX@80Zj^[0P31
`L420<W9b@80SHf=0P2EUID20:>SX`80UIFE0P2ATI420:b/[080_kno0P3_knl20=gMg@80m?Cd0P3/
k>`20>o_k`80k>c/1@3gmoL20?Cdm080moOg0P3alO420?Cdm080moOg103dm?@>0?Ogm`80m?Cd3`3o
ool000d0oooo103gmoL20?Cdm0H0moOg0P3dm?@20?Ogm`P0m?Cd103gmoL20?Cdm0<0moOg0P3dm?@2
0>o_k`80lO7a103dm?@40?Ogm`80jNWY0P3GemL20<o?c`80];Bd0P2EUID20861P@80NGUi0P1TI6@6
05iNGP80<S8b0P0m?Cd403Ti>@@0cLg=0P3Cdm<20<g=c@@0b/[:0P3@d=020<[:bP80`/;20`2l_;`4
0;Ng]`H0/K6a0P2/[:`80;6a/@H0^[Zj0P2l_;`20;Zj^P@0/K6a0P2/[:`20:NWY`80Xj>S0P2QXJ42
09BDU080NWYj0P1NGUh205ADE080DE5A0P15ADD203dm?@80BDU90P1TI6@209VIV@<0SHf=0P1jNWX2
0:6QX@80QXJ60P21PH4204a<C080LG5a0P2<S8`208F5Q@80QXJ60P1aLG440861P@80Xj>S0P2EUID2
0:6QX@80Zj^[0P31`L420<W9b@80SHf=0P2EUID20:>SX`80UIFE0P2ATI420:b/[080_kno0P3_knl2
0=gMg@80m?Cd0P3/k>`20>o_k`80k>c/1@3gmoL20?Cdm080moOg0P3alO420?Cdm080moOg103dm?@>
0?Ogm`80m?Cd3`3oool000d0oooo0P3gmoL20?Cdm0H0moOg0P3dm?@80?Ogm`80m?Cd2`3gmoL60?Cd
m0@0moOg103dm?@20>WYj@80eMGE0P3;bl/20:j^[P80UIFE101kNg/2075aL@80EEEE0P1NGUh205AD
E080>CTi0P0m?Cd2051@D080bLW9103?cll20=?Cd`80cLg=103:b/X20<S8b080`L710P2g]kL30;Fe
]@80[:b/0P2WYjL:0:JVYP80[:b/0P2WYjL20:b/[080/K6a0P2/[:`40;Zj^P80_;bl0P2c/k<20;6a
/@80[:b/0P2YZJT20:>SX`@0VIVI0P2>SXh205iNGP80CTi>0P1;Bd/203dm?@80:RXZ0P0m?Cd2069R
HP80VIVI0`1iNGT205iNGP80ZJVY0P26QXH209NGU`80PH610P1VIVH207=cL`80TY:B0P26QXH207]k
N`80SHf=0P21PH420:6QX@80UIFE0P2[Zj/20:6QX@80Zj^[0P37alL20:^[Z`80XJ6Q102OWil20:6Q
X@80[Zj^0P31`L440>KViP80kno_0P3/k>`20?Cdm080moOg0`3dm?@40?Ogm`80lO7a1P3gmoL20?Cd
m0@0moOg0P3dm?@<0?Ogm`l0oooo000=0?ooo`80moOg0P3dm?@60?Ogm`80m?Cd203gmoL20?Cdm0/0
moOg1P3dm?@40?Ogm`@0m?Cd0P3YjNT20=GEe@80bl_;0P2^[Zh209FEU@@0Ng]k0P1aLG4205EEE@80
GUiN0P1DE5@203Ti>@80?Cdm0P1@D5020<W9b@@0clo?0P3Cdm<20<g=c@@0b/[:0P38b<P20<71`@80
]kNg0`2e]KD20:b/[080YjNW2P2VYZH20:b/[080YjNW0P2/[:`20;6a/@80[:b/102j^[X20;bl_080
/k>c0P2a/K420:b/[080ZJVY0P2SXj<409VIV@80SXj>0P1NGUh204i>CP80Bd];0P0m?Cd202XZ:P80
?Cdm0P1RHV8209VIV@<0NGUi0P1NGUh20:VYZ@80QXJ60P2GUiL20861P@80IVIV0P1cLg<209:BTP80
QXJ60P1kNg/208f=S@80PH610P2QXJ4209FEU@80Zj^[0P2QXJ420:^[Z`80alO70P2[Zj/20:6QX@@0
WinO0P2QXJ420:j^[P80`L71103Vi^H20>o_k`80k>c/0P3dm?@20?Ogm`<0m?Cd103gmoL20?7al@H0
moOg0P3dm?@40?Ogm`80m?Cd303gmoL?0?ooo`003@3oool20?Ogm`80m?Cd103gmoL20?Cdm0X0moOg
0P3dm?@=0?Ogm`80m?Cd103_knl20?Ogm`80m?Cd0P3/k>`20=OGe`80clo?0P3>c/h209nOW`80PH61
0P1iNGT206IVIP80LG5a0P1EEED2051@D0@0?Cdm0P14A4@204];B`@0cLg=203:b/X20<S8b080`<30
0P2EUID208V9R@D0VIVI2P2MWId808V9R@80Xj>S102a/K460;Zj^P80/k>c0P2a/K420:b/[0@0Xj>S
0P2IVIT2092@T080S8b<0P1;Bd/203dm?@80>CTi0P0W9bL203Ti>@80EEEE0P1iNGT30:>SX`80QXJ6
0P2@T9020:^[Z`80UiNG0P2QXJ4209FEU@80QXJ60P1kNg/208b<S080SHf=0P1aLG4207]kN`80SHf=
0P2QXJ4208f=S@80[jn_0P2^[Zh20;fm_@80`L710P2OWil20:^[Z`80UIFE0P2QXJ420;fm_@80bl_;
0P3GemL20>WYj@80k>c/0P3YjNT20>c/k080kno_0`3gmoL20?7al@80m?Cd0P3gmoL20?Cdm0H0moOg
0P3dm?@40?Ogm`80m?Cd103gmoL20?Cdm0@0moOg3`3oool000d0oooo0P3gmoL20?Cdm0@0moOg0P3d
m?@:0?Ogm`80m?Cd3@3gmoL20?Cdm0@0kno_0P3gmoL20?Cdm080k>c/0P3GemL20<o?c`80c/k>0P2O
Wil20861P@80NGUi0P1VIVH2075aL@80EEEE0P1@D50403dm?@80A4A40P1;Bd/40<g=c@P0b/[:0P38
b<P20<30`080UIFE0P29RHT509VIV@X0WIfM2029RHT20:>SX`@0/K6a1P2j^[X20;>c/`80/K6a0P2/
[:`40:>SX`80VIVI0P2@T90208b<S080Bd];0P0m?Cd203Ti>@809bLW0P0i>CT205EEE@80NGUi0`2S
Xj<208J6QP80T92@0P2[Zj/209NGU`80XJ6Q0P2EUID208J6QP80Ng]k0P2<S8`208f=S@80LG5a0P1k
Ng/208f=S@80XJ6Q0P2=SHd20:n_[`80[Zj^0P2m_Kd20<71`@80WinO0P2[Zj/209FEU@80XJ6Q0P2m
_Kd20<_;b`80emOG0P3YjNT20>c/k080jNWY0P3/k>`20>o_k`<0moOg0P3alO420?Cdm080moOg0P3d
m?@60?Ogm`80m?Cd103gmoL20?Cdm0@0moOg0P3dm?@40?Ogm`l0oooo000=0?ooo`80moOg0P3dm?@2
0?Ogm`80m?Cd0P3gmoL20?Cdm0P0moOg0P3dm?@40?Ogm`80m?Cd0P3_knl50?Ogm`80m?Cd103gmoL2
0>o_k`80moOg0P3YjNT20=gMg@80eMGE0P2^[Zh209FEU@80NWYj0P1/K6`206IVIP80GUiN0P1;Bd/2
05EEE@80ADE50P0m?Cd204];B`80d];B0P3=cLd40<[:bP80b<S80P3=cLd20<[:bP80YZJV1P2MWId3
0<g=c@80`<30102VYZH20;Fe]@80`<30102MWId209VIV@80T92@0P2=SHd208V9R@80Xj>S0P2a/K42
0;>c/`80^[Zj0P2l_;`20;>c/`@0/K6a0P2YZJT20:>SX`80VIVI0P2MWId208j>SP80PH610P19BDT4
02XZ:P809bLW0P1EEED202XZ:P<0ZJVY0P2a/K4206IVIP80[Zj^0P21PH420:ZZZP80Zj^[0P2=SHd2
08b<S080UiNG0P1^KVh208b<S080PH610P2=SHd209FEU@80VIVI0P2SXj<20:j^[P80`L710P39bLT2
09FEU@80QXJ60P2EUID20:6QX@80[:b/103Vi^H40>c/k080i^KV103gmoL30?7al@@0m?Cd0P3gmoL2
0?Cdm080moOg103dm?@40?Ogm`80m?Cd103gmoL40?Cdm080moOg0P3dm?@?0?ooo`003@3oool20?Og
m`80m?Cd0P3gmoL20?Cdm080moOg0P3dm?@80?Ogm`80m?Cd103gmoL20?Cdm080kno_1@3gmoL20?Cd
m0@0moOg0P3_knl20?Ogm`80jNWY0P3MgMd20=GEe@80[Zj^0P2EUID207YjNP80K6a/0P1VIVH205iN
GP80Bd];0P1EEED204E5A@80?Cdm0P1;Bd/20=;BdP80cLg=103:b/X20<S8b080cLg=0P3:b/X20:JV
YPH0WIfM0`3=cLd20<30`0@0YZJV0P2e]KD20<30`0@0WIfM0P2IVIT2092@T080SHf=0P29RHT20:>S
X`80/K6a0P2c/k<20;Zj^P80_;bl0P2c/k<40;6a/@80ZJVY0P2SXj<209VIV@80WIfM0P2>SXh20861
P@80BDU9100Z:RX202LW9`80EEEE0P0Z:RX30:VYZ@80/K6a0P1VIVH20:j^[P80PH610P2ZZZX20:^[
Z`80SHf=0P2<S8`209NGU`80KVi^0P2<S8`20861P@80SHf=0P2EUID209VIV@80Xj>S0P2^[Zh20<71
`@80bLW90P2EUID208J6QP80UIFE0P2QXJ420:b/[0@0i^KV103/k>`20>KViP@0moOg0`3alO440?Cd
m080moOg0P3dm?@20?Ogm`@0m?Cd103gmoL20?Cdm0@0moOg103dm?@20?Ogm`80m?Cd3`3oool000d0
oooo0P3dm?@20?Ogm`80m?Cd0P3gmoL20?Cdm080moOg0P3dm?@20?Ogm`@0m?Cd0P3gmoL=0?Cdm080
kno_103gmoL20?7al@80moOg0P3Jf]X20<_;b`80[:b/0P2EUID208J6QP80NWYj0P1EEED205iNGP80
EEEE0P1NGUh2038b<P@0?Cdm0P21PH460<o?c`80b/[:1P38b<P209VIV@@0WIfM0P2IVIT709FEU@80
WIfM1029RHT207emO@@0Ogmo0P2VYZH408f=S@80OGem0P2[Zj/20;Ng]`P0^[Zj0P2a/K420:VYZ@@0
Xj>S102IVIT208b<S080NGUi100m?Cd201LG5`80>CTi0P1NGUh308J6QP80UIFE0P21PH4208f=S@80
Zj^[0P2<S8`20:n_[`80cLg=0P2=SHd207]kN`@0S8b<0P1cLg<20861P@80UiNG0P2EUID40:6QX@@0
`L710P2OWil209FEU@80WinO0P2EUID20:b/[080i^KV0P3YjNT20>o_k`@0jNWY3`3gmoL20?Cdm1H0
moOg3`3oool000d0oooo0P3dm?@20?Ogm`80m?Cd0P3gmoL20?Cdm080moOg0P3dm?@20?Ogm`@0m?Cd
0P3gmoL=0?Cdm080kno_103gmoL20?7al@80moOg0P3Jf]X20<_;b`80[:b/0P2EUID208J6QP80NWYj
0P1EEED205iNGP80EEEE0P1NGUh2038b<P@0?Cdm0P21PH460<o?c`80b/[:1P38b<P209VIV@@0WIfM
0P2IVIT709FEU@80WIfM1029RHT207emO@@0Ogmo0P2VYZH408f=S@80OGem0P2[Zj/20;Ng]`P0^[Zj
0P2a/K420:VYZ@@0Xj>S102IVIT208b<S080NGUi100m?Cd201LG5`80>CTi0P1NGUh308J6QP80UIFE
0P21PH4208f=S@80Zj^[0P2<S8`20:n_[`80cLg=0P2=SHd207]kN`@0S8b<0P1cLg<20861P@80UiNG
0P2EUID40:6QX@@0`L710P2OWil209FEU@80WinO0P2EUID20:b/[080i^KV0P3YjNT20>o_k`@0jNWY
3`3gmoL20?Cdm1H0moOg3`3oool000d0oooo203gmoL40?Cdm080moOg1P3dm?@20?Ogm`H0m?Cd1@3g
moL40?Cdm080moOg1P3dm?@20=OGe`80`l?30P2QXJ4209FEU@80NGUi0P1TI6@205EEE@80GUiN0P1@
D50203Ti>@80B4Q80P0i>CT205iNGP@0d];B0P3?cll40<[:bP80b<S80P2VYZH209fMW@80NGUi0P1N
GUh206MWI`80MGEe0`1iNGT407EeM@80OGem0P1_Kfl205iNGP80EUIF0P1KFe/206MWI`80CDe=0P1U
IFD205]KF`80CTi>0P1QHF4209fMW@H0^[Zj1P2a/K440:>SX`80XJ6Q0P2SXj<208j>SP80PH610P1N
GUh201lO7`805aLG0P0m?Cd204U9B@<0FUYJ0P2=SHd20:VYZ@80GUiN0P2YZJT20861P@80Xj>S0P2o
_kl20<g=c@@0VIVI0P1eMGD208b<S080PH610P2=SHd2096AT@80PH610P2[Zj/20;fm_@80`L710P2m
_Kd20:6QX@80Zj^[0P2OWil20;Rh^080gMgM0P3/k>`20>KViP80k>c/0P3dm?@20>c/k0D0moOg0P3d
m?@20?Ogm`80m?Cd403gmoL20?Cdm080moOg0P3dm?@40?Ogm`l0oooo000=0?ooo`P0moOg103dm?@2
0?Ogm`H0m?Cd0P3gmoL60?Cdm0D0moOg103dm?@20?Ogm`H0m?Cd0P3GemL20<?3``80XJ6Q0P2EUID2
07UiN@80I6AT0P1EEED205iNGP80D51@0P0i>CT204Q8B080>CTi0P1NGUh40=;BdP80clo?103:b/X2
0<S8b080YZJV0P2MWId207UiN@80GUiN0P1WIfL207EeM@<0NGUi101eMGD207emO@80Kfm_0P1NGUh2
05IFEP80Fe]K0P1WIfL204e=C@80IFEU0P1KFe/204i>CP80HF5Q0P2MWId60;Zj^PH0/K6a102SXj<2
0:6QX@80Xj>S0P2>SXh20861P@80GUiN0P0O7al201LG5`80?Cdm0P19BDT305YJFP80SHf=0P2YZJT2
05iNGP80ZJVY0P21PH420:>SX`80_kno0P3=cLd409VIV@80MGEe0P2<S8`20861P@80SHf=0P2ATI42
0861P@80Zj^[0P2m_Kd20<71`@80_Kfm0P2QXJ420:^[Z`80WinO0P2h^;P20=gMg@80k>c/0P3Vi^H2
0>c/k080m?Cd0P3/k>`50?Ogm`80m?Cd0P3gmoL20?Cdm100moOg0P3dm?@20?Ogm`80m?Cd103gmoL?
0?ooo`003@3oool60?Cdm0@0moOg103dm?@20?Ogm`80m?Cd0P3gmoL20?Cdm080moOg0P3dm?@20?Og
m`/0m?Cd0P3_knl20?Cdm080jNWY0P3GemL20;fm_@80UIFE0P21PH4206ATI080EEEE0P1NGUh205AD
E0H0Bd];0P1>CTh40=;BdP80cLg=0P3?cll20=?Cd`80b/[:0P38b<P20<30`080b<S80P2VYZH208f=
S@80RHV90P1oOgl308V9R@80Ogmo0P29RHT209VIV@`0Ogmo0P2QXJ420:VYZ@80Zj^[102a/K440;Zj
^P@0]KFe0P2a/K420;Fe]@80[:b/102SXj<20:6QX@80VIVI0P2>SXh2075aL@80=SHf100G5aL203Hf
=P<0FUYJ0P1aLG420:>SX`80UIFE0P1/K6`20:6QX@80PH61102o_kl20<o?c`80NGUi102<S8`20861
P@@0SHf=0P21PH440:^[Z`80`L710P37alL209FEU@80Zj^[0P2QXJ420=GEe@@0jNWY103Vi^H90?Cd
m0P0moOg0P3dm?@40?Ogm`80m?Cd103gmoL20?Cdm0@0moOg0P3dm?@40?Ogm`l0oooo000=0?ooo`H0
m?Cd103gmoL40?Cdm080moOg0P3dm?@20?Ogm`80m?Cd0P3gmoL20?Cdm080moOg2`3dm?@20>o_k`80
m?Cd0P3YjNT20=OGe`80_Kfm0P2EUID20861P@80I6AT0P1EEED205iNGP80E5AD1P1;Bd/204i>CP@0
d];B0P3=cLd20<o?c`80dm?C0P3:b/X20<S8b080`<300P38b<P20:JVYP80SHf=0P29RHT207moO`<0
RHV90P1oOgl208V9R@80VIVI301oOgl20:6QX@80ZJVY0P2[Zj/40;6a/@@0^[Zj102e]KD20;6a/@80
]KFe0P2/[:`40:>SX`80XJ6Q0P2IVIT208j>SP80LG5a0P0f=SH401LG5`80=SHf0`1JFUX2075aL@80
Xj>S0P2EUID206a/K080XJ6Q0P21PH440;no_`80clo?0P1iNGT408b<S080PH61102=SHd20861P@@0
Zj^[0P31`L420<O7a`80UIFE0P2[Zj/20:6QX@80eMGE103YjNT40>KViPT0m?Cd203gmoL20?Cdm0@0
moOg0P3dm?@40?Ogm`80m?Cd103gmoL20?Cdm0@0moOg3`3oool000d0oooo0P3gmoL40?Cdm080moOg
0P3dm?@60?Ogm`80m?Cd0P3gmoL20?Cdm0/0moOg0P3_knl20?Ogm`80m?Cd0P3/k>`20>o_k`80i^KV
0P3>c/h20:j^[P80QXJ6101/K6`205iNGP80E5AD0P1@D50204E5A@80Bd];0P1<C4`205ADE080clo?
0P3:b/X20<o?c`80cLg=0P3:b/X20<g=c@80b<S80P3=cLd40=?Cd`@0f=SH0P3=cLd30<[:bP80f=SH
0P3:b/X20<S8b080dm?C0P3Hf=P20<g=c@80b/[:0P31`L420;bl_080`L710P2l_;`40;Zj^P80_;bl
0P2j^[X20;bl_080^[Zj0P2g]kL40;6a/@@0[:b/0P2SXj<20:6QX@@0VIVI0P21PH4205ADE080:2PX
0P0;2`/205YJFP<0BDU90P1JFUX2075aL@80SHf=0P1VIVH208b<S080Lg=c0P2<S8`40;no_`80XJ6Q
0P2IVIT208f=S@@0Ng]k0P2=SHd209VIV@80XJ6Q0P2IVIT20<71`@80alO7102OWil2096AT@80gMgM
103Vi^H20>WYj@80i^KV1P3gmoL30?Cdm0`0moOg0P3dm?@20?Ogm`80m?Cd1P3gmoL20?Cdm0H0moOg
3`3oool000d0oooo0P3gmoL40?Cdm080moOg0P3dm?@60?Ogm`80m?Cd0P3gmoL20?Cdm0/0moOg0P3_
knl20?Ogm`80m?Cd0P3/k>`20>o_k`80i^KV0P3>c/h20:j^[P80QXJ6101/K6`205iNGP80E5AD0P1@
D50204E5A@80Bd];0P1<C4`205ADE080clo?0P3:b/X20<o?c`80cLg=0P3:b/X20<g=c@80b<S80P3=
cLd40=?Cd`@0f=SH0P3=cLd30<[:bP80f=SH0P3:b/X20<S8b080dm?C0P3Hf=P20<g=c@80b/[:0P31
`L420;bl_080`L710P2l_;`40;Zj^P80_;bl0P2j^[X20;bl_080^[Zj0P2g]kL40;6a/@@0[:b/0P2S
Xj<20:6QX@@0VIVI0P21PH4205ADE080:2PX0P0;2`/205YJFP<0BDU90P1JFUX2075aL@80SHf=0P1V
IVH208b<S080Lg=c0P2<S8`40;no_`80XJ6Q0P2IVIT208f=S@@0Ng]k0P2=SHd209VIV@80XJ6Q0P2I
VIT20<71`@80alO7102OWil2096AT@80gMgM103Vi^H20>WYj@80i^KV1P3gmoL30?Cdm0`0moOg0P3d
m?@20?Ogm`80m?Cd1P3gmoL20?Cdm0H0moOg3`3oool000d0oooo0P3dm?@:0?Ogm`80m?Cd1P3gmoL2
0?Cdm080moOg103dm?@50?Ogm`80m?Cd0P3_knl40?Cdm080jNWY0P36a/H20;no_`80WinO0P1iNGT2
06ATI0@0E5AD0P1ADE4203Ti>@@0Bd];0P18B4P20;Rh^0H0clo?0P3@d=020=?Cd`80b/[:0P3Cdm<2
0<[:bP@0dm?C0P3Hf=P20=?Cd`80f=SH0`3Cdm<20=SHf080b<S81P3:b/X80;bl_080_kno0P2l_;`2
0;no_`80b<S80P2l_;`20;Zj^P80_kno0P2l_;`40;Ng]`80/K6a102/[:`20:>SX`80WIfM102IVIT2
0861P@80HF5Q0P0W9bL201lO7`80BDU90`1DE5@20861P@80LG5a0P2OWil206IVIP80GUiN0P2ATI42
08f=S@80/k>c0P2o_kl20<S8b080Zj^[102<S8`2096AT@80Ng]k1021PH4209VIV@80`L710P37alL2
0:6QX@80[Zj^0P2EUID20>KViP80jNWY0P3MgMd20>KViP80kno_1P3gmoL30?Cdm0@0moOg1P3dm?@D
0?Ogm`80m?Cd3`3oool000d0oooo0P3dm?@:0?Ogm`80m?Cd1P3gmoL20?Cdm080moOg103dm?@50?Og
m`80m?Cd0P3_knl40?Cdm080jNWY0P36a/H20;no_`80WinO0P1iNGT206ATI0@0E5AD0P1ADE4203Ti
>@@0Bd];0P18B4P20;Rh^0H0clo?0P3@d=020=?Cd`80b/[:0P3Cdm<20<[:bP@0dm?C0P3Hf=P20=?C
d`80f=SH0`3Cdm<20=SHf080b<S81P3:b/X80;bl_080_kno0P2l_;`20;no_`80b<S80P2l_;`20;Zj
^P80_kno0P2l_;`40;Ng]`80/K6a102/[:`20:>SX`80WIfM102IVIT20861P@80HF5Q0P0W9bL201lO
7`80BDU90`1DE5@20861P@80LG5a0P2OWil206IVIP80GUiN0P2ATI4208f=S@80/k>c0P2o_kl20<S8
b080Zj^[102<S8`2096AT@80Ng]k1021PH4209VIV@80`L710P37alL20:6QX@80[Zj^0P2EUID20>KV
iP80jNWY0P3MgMd20>KViP80kno_1P3gmoL30?Cdm0@0moOg1P3dm?@D0?Ogm`80m?Cd3`3oool000d0
oooo0P3dm?@20?Ogm`P0m?Cd0P3gmoL20>o_k`P0moOg0P3dm?@20?Ogm`80m?Cd0`3gmoL40?Cdm080
kno_103dm?@20<k>cP80WinO0P21PH4206IVIP80K6a/0P1@D502055AD@80?Cdm201;Bd/40<o?c`80
cLg=0P3?cll20=?Cd`@0d=3@0P3Cdm<20<o?c`d0dm?C0P3?cll20<[:bPH0b<S80P2l_;`20;no_`80
`/;20P2l_;`20<71`@80_;bl0P38b<P20;bl_080b<S8102l_;`40;Ng]`80^[Zj0P2a/K420:b/[080
YjNW0P2/[:`20:6QX@@0VIVI0P2>SXh206a/K080ADE50P0f=SH201LG5`<0Cdm?0P1EEED206ATI080
IVIV0P1iNGT206IVIP80PH610P1jNWX209VIV@@0_Kfm0P2IVIT20:6QX@80S8b<0P2=SHd207]kN`80
SHf=0P1kNg/20:6QX@80Zj^[0P31`L420:b/[080UIFE0P2SXj<20=OGe`@0i^KV0P3EeMD20?Ogm`80
m?Cd103gmoL30?Cdm080moOg0P3dm?@80?Ogm`80m?Cd1P3gmoL40?Cdm0P0moOg3`3oool000d0oooo
0P3dm?@20?Ogm`P0m?Cd0P3gmoL20>o_k`P0moOg0P3dm?@20?Ogm`80m?Cd0`3gmoL40?Cdm080kno_
103dm?@20<k>cP80WinO0P21PH4206IVIP80K6a/0P1@D502055AD@80?Cdm201;Bd/40<o?c`80cLg=
0P3?cll20=?Cd`@0d=3@0P3Cdm<20<o?c`d0dm?C0P3?cll20<[:bPH0b<S80P2l_;`20;no_`80`/;2
0P2l_;`20<71`@80_;bl0P38b<P20;bl_080b<S8102l_;`40;Ng]`80^[Zj0P2a/K420:b/[080YjNW
0P2/[:`20:6QX@@0VIVI0P2>SXh206a/K080ADE50P0f=SH201LG5`<0Cdm?0P1EEED206ATI080IVIV
0P1iNGT206IVIP80PH610P1jNWX209VIV@@0_Kfm0P2IVIT20:6QX@80S8b<0P2=SHd207]kN`80SHf=
0P1kNg/20:6QX@80Zj^[0P31`L420:b/[080UIFE0P2SXj<20=OGe`@0i^KV0P3EeMD20?Ogm`80m?Cd
103gmoL30?Cdm080moOg0P3dm?@80?Ogm`80m?Cd1P3gmoL40?Cdm0P0moOg3`3oool000d0oooo0P3d
m?@20?Ogm`P0m?Cd0P3gmoL20>o_k`P0moOg0P3dm?@20?Ogm`80m?Cd0`3gmoL40?Cdm080kno_103d
m?@20<k>cP80WinO0P21PH4206IVIP80K6a/0P1@D502055AD@80?Cdm201;Bd/40<o?c`80cLg=0P3?
cll20=?Cd`@0d=3@0P3Cdm<20<o?c`d0dm?C0P3?cll20<[:bPH0b<S80P2l_;`20;no_`80`/;20P2l
_;`20<71`@80_;bl0P38b<P20;bl_080b<S8102l_;`40;Ng]`80^[Zj0P2a/K420:b/[080YjNW0P2/
[:`20:6QX@@0VIVI0P2>SXh206a/K080ADE50P0f=SH201LG5`<0Cdm?0P1EEED206ATI080IVIV0P1i
NGT206IVIP80PH610P1jNWX209VIV@@0_Kfm0P2IVIT20:6QX@80S8b<0P2=SHd207]kN`80SHf=0P1k
Ng/20:6QX@80Zj^[0P31`L420:b/[080UIFE0P2SXj<20=OGe`@0i^KV0P3EeMD20?Ogm`80m?Cd103g
moL30?Cdm080moOg0P3dm?@80?Ogm`80m?Cd1P3gmoL40?Cdm0P0moOg3`3oool000d0oooo0P3gmoL2
0?Cdm080moOg103dm?@60?Ogm`80m?Cd4@3gmoL40?Cdm080kno_0P3>c/h20<?3``80UIFE0P1kNg/2
06a/K080D51@0P1NGUh203dm?@80Bd];0P0i>CT204];B`80D51@0P0m?Cd20<o?c`@0cLg=0P3?cll6
0=?Cd`80d=3@203Cdm<20<o?c`D0dm?C1038b<P20;bl_080b<S80P2l_;`20;Fe]@80^[Zj0P2o_kl2
0;bl_080`<300P32`/820<S8b0@0`<300P3:b/X20<S8b0@0_;bl0P2g]kL20;Fe]@@0[:b/0P2SXj<2
0:6QX@80WIfM0P2@T90208j>SP80Ng]k0P19BDT202LW9`80:RXZ0`19BDT2069RHP80Jf][0P1aLG42
08J6QP80K6a/0P1NGUh206ATI080UIFE0P2ATI420:RXZ080b<S80P2[Zj/208J6QP80TI6A0P1/K6`2
09FEU@80SHf=0P2SXj<20:6QX@80`L710P2/[:`208f=S@80bLW90P3EeMD60>WYj@80m?Cd3@3gmoL2
0?Cdm0H0moOg0P3dm?@20?Ogm`80m?Cd3P3gmoL?0?ooo`003@3oool20?Ogm`80m?Cd0P3gmoL40?Cd
m0H0moOg0P3dm?@A0?Ogm`@0m?Cd0P3_knl20<k>cP80`l?30P2EUID207]kN`80K6a/0P1@D50205iN
GP80?Cdm0P1;Bd/203Ti>@80Bd];0P1@D50203dm?@80clo?103=cLd20<o?c`H0dm?C0P3@d=080=?C
d`80clo?1@3Cdm<40<S8b080_;bl0P38b<P20;bl_080]KFe0P2j^[X20;no_`80_;bl0P30`<020<;2
`P80b<S81030`<020<[:bP80b<S8102l_;`20;Ng]`80]KFe102/[:`20:>SX`80XJ6Q0P2MWId2092@
T080SXj>0P1kNg/204U9B@809bLW0P0Z:RX304U9B@80HV9R0P1[Jf/2075aL@80QXJ60P1/K6`205iN
GP80I6AT0P2EUID2096AT@80Z:RX0P38b<P20:^[Z`80QXJ60P2ATI4206a/K080UIFE0P2=SHd20:>S
X`80XJ6Q0P31`L420:b/[080SHf=0P39bLT20=GEe@H0jNWY0P3dm?@=0?Ogm`80m?Cd1P3gmoL20?Cd
m080moOg0P3dm?@>0?Ogm`l0oooo000=0?oooa80moOg0P3dm?@80?Ogm`L0m?Cd103gmoL20>WYj@80
a/K60P2VYZH209FEU@80K6a/0P1VIVH206ATI080CTi>101;Bd/204U9B@80Bd];0P0m?Cd208J6QP80
bLW9103=cLd80=?Cd`80f=SH0P3Cdm<20<o?c`H0dm?C1@3:b/X20;bl_080/K6a0P2/[:`20;Ng]`80
/k>c0P2/[:`20;6a/@80]kNg0P2j^[X20;bl_080`/;20P31`L420<S8b0@0b/[:1030`<020;bl_080
]kNg0P2a/K440:b/[0@0Xj>S0P2QXJ4209VIV@80RHV90P1jNWX205iNGP80=SHf0P0m?Cd303`l?080
FUYJ0P1EEED2075aL@80I6AT0P1kNg/205ADE080IVIV0P1EEED20:j^[P80_Kfm0P2QXJ420:ZZZP80
TI6A0P2EUID207YjNP80PH610P2=SHd209nOW`80XJ6Q0P2o_kl20;Rh^080UIFE0P3MgMd20<71`@80
m?Cd0P3YjNT=0?Ogm`80m?Cd303gmoL40?Cdm0@0moOg0P3dm?@80?Ogm`l0oooo000=0?oooa80moOg
0P3dm?@80?Ogm`L0m?Cd103gmoL20>WYj@80a/K60P2VYZH209FEU@80K6a/0P1VIVH206ATI080CTi>
101;Bd/204U9B@80Bd];0P0m?Cd208J6QP80bLW9103=cLd80=?Cd`80f=SH0P3Cdm<20<o?c`H0dm?C
1@3:b/X20;bl_080/K6a0P2/[:`20;Ng]`80/k>c0P2/[:`20;6a/@80]kNg0P2j^[X20;bl_080`/;2
0P31`L420<S8b0@0b/[:1030`<020;bl_080]kNg0P2a/K440:b/[0@0Xj>S0P2QXJ4209VIV@80RHV9
0P1jNWX205iNGP80=SHf0P0m?Cd303`l?080FUYJ0P1EEED2075aL@80I6AT0P1kNg/205ADE080IVIV
0P1EEED20:j^[P80_Kfm0P2QXJ420:ZZZP80TI6A0P2EUID207YjNP80PH610P2=SHd209nOW`80XJ6Q
0P2o_kl20;Rh^080UIFE0P3MgMd20<71`@80m?Cd0P3YjNT=0?Ogm`80m?Cd303gmoL40?Cdm0@0moOg
0P3dm?@80?Ogm`l0oooo000=0?ooo`80m?Cd2P3gmoL20?Cdm080moOg103dm?@40?Ogm`80m?Cd1`3g
moL20>o_k`80moOg103dm?@20;no_`80UIFE0P1iNGT206ATI0@0EEEE0P1;Bd/403dm?@@0Bd];0P0i
>CT20<W9b@@0cLg=0P3@d=0<0=?Cd`80cLg=1P3Cdm<20<[:bP<0`<300P2i^KT20;Zj^P80YjNW102/
[:`20:>SX`80ZJVY102a/K420;Zj^P80_;bl0P32`/820<30`0H0b<S80P30`<020<S8b080_Kfm0P2g
]kL20;6a/@80[:b/102SXj<20:6QX@80T92@0P2>SXh20861P@80HF5Q0P0f=SH200/;2`<08b<S0P19
BDT205ADE080K6a/0P1EEED207]kN`@0IVIV0P1;Bd/20:VYZ@80S8b<0P2QXJ420<g=c@80UIFE102A
TI420861P@80SHf=0P2<S8`209FEU@80_kno102m_Kd20<_;b`@0emOG0P3Bd]8=0?Ogm`80m?Cd503g
moL20?Cdm0P0moOg3`3oool000d0oooo0P3dm?@:0?Ogm`80m?Cd0P3gmoL40?Cdm0@0moOg0P3dm?@7
0?Ogm`80kno_0P3gmoL40?Cdm080_kno0P2EUID207UiN@80I6AT101EEED204];B`@0?Cdm101;Bd/2
03Ti>@80bLW9103=cLd20=3@d0`0dm?C0P3=cLd60=?Cd`80b/[:0`30`<020;Vi^@80^[Zj0P2WYjL4
0:b/[080Xj>S0P2YZJT40;6a/@80^[Zj0P2l_;`20<;2`P80`<301P38b<P20<30`080b<S80P2m_Kd2
0;Ng]`80/K6a0P2/[:`40:>SX`80XJ6Q0P2@T90208j>SP80PH610P1QHF4203Hf=P802`/;0`0S8b<2
04U9B@80E5AD0P1/K6`205EEE@80Ng]k101VIVH204];B`80ZJVY0P2<S8`20:6QX@80cLg=0P2EUID4
096AT@80PH610P2=SHd208b<S080UIFE0P2o_kl40;fm_@80bl_;103GemL20=;BdPd0moOg0P3dm?@D
0?Ogm`80m?Cd203gmoL?0?ooo`003@3oool>0?Ogm`80m?Cd1P3gmoL20?Cdm0l0moOg0P3YjNT20:j^
[P80QXJ60P1TI6@205ADE080EEEE0P0m?Cd204];B`80ADE50P1;Bd/204i>CP80>CTi0P0b<S820<g=
c@80alO7103:b/X20=?Cd`80d=3@103Hf=P60=?Cd`80d=3@0P3Hf=P20:NWY`80VIVI1@3:b/X20<30
`080]KFe101eMGD2092@T080YjNW0P21PH420:6QX@80/K6a0P2l_;`40<S8b0H0b/[:0P38b<P20<30
`080_;bl0P2g]kL20;Fe]@@0[:b/0P2SXj<20:6QX@80VIVI0P2>SXh207YjNP80LG5a0P15ADD201LG
5`<08b<S0P0b<S8204U9B@80EEEE0P1JFUX406a/K080E5AD0P1/K6`205iNGP80SHf=0P2_[jl20:6Q
X@80[jn_0P2<S8`208f=S@80IVIV1021PH420:6QX@@0_Kfm0P3YjNT20:b/[080jNWY0P2h^;P[0?Og
m`80m?Cd0P3gmoL?0?ooo`003@3oool>0?Ogm`80m?Cd1P3gmoL20?Cdm0l0moOg0P3YjNT20:j^[P80
QXJ60P1TI6@205ADE080EEEE0P0m?Cd204];B`80ADE50P1;Bd/204i>CP80>CTi0P0b<S820<g=c@80
alO7103:b/X20=?Cd`80d=3@103Hf=P60=?Cd`80d=3@0P3Hf=P20:NWY`80VIVI1@3:b/X20<30`080
]KFe101eMGD2092@T080YjNW0P21PH420:6QX@80/K6a0P2l_;`40<S8b0H0b/[:0P38b<P20<30`080
_;bl0P2g]kL20;Fe]@@0[:b/0P2SXj<20:6QX@80VIVI0P2>SXh207YjNP80LG5a0P15ADD201LG5`<0
8b<S0P0b<S8204U9B@80EEEE0P1JFUX406a/K080E5AD0P1/K6`205iNGP80SHf=0P2_[jl20:6QX@80
[jn_0P2<S8`208f=S@80IVIV1021PH420:6QX@@0_Kfm0P3YjNT20:b/[080jNWY0P2h^;P[0?Ogm`80
m?Cd0P3gmoL?0?ooo`003@3oool40?Cdm080moOg103dm?@80?Ogm`@0m?Cd0P3gmoL20?Cdm0/0moOg
0P3dm?@20>3Ph080UIFE0P1iNGT206ATI080IVIV101;Bd/203dm?@80B4Q80P1;Bd/203dm?@80<S8b
0P1EEED20<g=c@80b/[:0P3?cll20=?Cd`80f=SH0P3Cdm<20=3@d080f=SH0P3@d=020=?Cd`80cLg=
0P3Cdm<20=SHf080clo?0P3=cLd50=3@d080b/[:0P2j^[X20;6a/@80/k>c0P2e]KD20;Zj^P80[:b/
0P2DU9@20:>SX`80_;bl2P3:b/X20<30`0@0b<S80P2m_Kd20;Fe]@80/K6a0P2/[:`20:>SX`@0VIVI
0P2>SXh208V9R@80LG5a0P1NGUh200/;2`<05aLG0P0S8b<203`l?080Cdm?0P1NGUh205EEE@80LG5a
0P1DE5@205iNGP80:RXZ0P2[Zj/209BDU080UiNG0P2o_kl20861P@80SHf=0P1/K6`207UiN@80SHf=
0P2EUID20:b/[0@0a/K60P2/[:`20;Rh^0@0moOg0P3dm?@;0?Ogm`80m?Cd203gmoL20?Cdm0X0moOg
103dm?@60?Ogm`l0oooo000=0?ooo`@0m?Cd0P3gmoL40?Cdm0P0moOg103dm?@20?Ogm`80m?Cd2`3g
moL20?Cdm080h>3P0P2EUID207UiN@80I6AT0P1VIVH404];B`80?Cdm0P18B4P204];B`80?Cdm0P0b
<S8205EEE@80cLg=0P3:b/X20<o?c`80dm?C0P3Hf=P20=?Cd`80d=3@0P3Hf=P20=3@d080dm?C0P3=
cLd20=?Cd`80f=SH0P3?cll20<g=c@D0d=3@0P3:b/X20;Zj^P80/K6a0P2c/k<20;Fe]@80^[Zj0P2/
[:`209BDU080Xj>S0P2l_;`:0<[:bP80`<301038b<P20;fm_@80]KFe0P2a/K420:b/[080Xj>S102I
VIT208j>SP80RHV90P1aLG4205iNGP802`/;0`0G5aL202<S8`80?3`l0P1?Cdl205iNGP80EEEE0P1a
LG4205ADE080GUiN0P0Z:RX20:^[Z`80U9BD0P2GUiL20;no_`80PH610P2=SHd206a/K080NGUi0P2=
SHd209FEU@80[:b/1036a/H20:b/[080^;Rh103gmoL20?Cdm0/0moOg0P3dm?@80?Ogm`80m?Cd2P3g
moL40?Cdm0H0moOg3`3oool000d0oooo303gmoL20?Cdm0@0moOg103dm?@80?Ogm`<0kno_1P3gmoL2
0=OGe`80SHf=0P1TI6@2065QH@80?Cdm0P19BDT2055AD@80ADE50P1;Bd/2055AD@@0<S8b0P1lO7`2
0<O7a`H0d=3@2P3Hf=P40=?Cd`80d=3@0P3Hf=P20<g=c@L0f=SH0P3@d=020<S8b080^[Zj102i^KT2
0;>c/`80/K6a102/[:`20<30`0@0b/[:0P3@d=060<[:bPH0`<300P2j^[X20;Fe]@80/K6a0P2WYjL4
09fMW@80SXj>0P21PH4207=cL`80I6AT0P0;2`/301lO7`805aLG0P19BDT205EEE@80I6AT0P15ADD2
06a/K080E5AD0P1NGUh2038b<P80UIFE0P2=SHd20:^[Z`80_kno0P21PH4208f=S@80NGUi0P21PH42
08J6QP80UIFE0P2^[Zh40<K6aP80_Kfm0P3;bl/40?Ogm`80m?Cd3`3gmoL20?Cdm180moOg0P3dm?@6
0?Ogm`l0oooo000=0?ooo``0moOg0P3dm?@40?Ogm`@0m?Cd203gmoL30>o_k`H0moOg0P3GemL208f=
S@80I6AT0P1QHF4203dm?@80BDU90P1ADE4204E5A@80Bd];0P1ADE44038b<P80O7al0P37alL60=3@
d0X0f=SH103Cdm<20=3@d080f=SH0P3=cLd70=SHf080d=3@0P38b<P20;Zj^P@0^KVi0P2c/k<20;6a
/@@0[:b/0P30`<040<[:bP80d=3@1P3:b/X60<30`080^[Zj0P2e]KD20;6a/@80YjNW102MWId208j>
SP80PH610P1cLg<206ATI0802`/;0`0O7al201LG5`80BDU90P1EEED206ATI080ADE50P1/K6`205AD
E080GUiN0P0b<S8209FEU@80SHf=0P2[Zj/20;no_`80PH610P2=SHd207UiN@80PH610P26QXH209FE
U@80[Zj^1036a/H20;fm_@80bl_;103gmoL20?Cdm0l0moOg0P3dm?@B0?Ogm`80m?Cd1P3gmoL?0?oo
o`003@3oool60?Ogm`80m?Cd0P3gmoL20?Cdm0@0moOg0P3dm?@20?Ogm`80m?Cd103gmoL20>o_k`80
moOg1@3dm?@20?Ogm`80m?Cd0P3Bd]8207UiN@@0GUiN0P1DE5@404];B`80D51@0P1EEED204Q8B080
:RXZ0P0f=SH20<W9b@80cLg=103Cdm<>0=SHf080d=3@0P3:b/X60=SHf0<0hn?S0P3Hf=P20=3@d080
b/[:0P31`L420;Ng]`80]KFe0P2c/k<20;6a/@80[:b/0P2g]kL20<30`0@0b/[:0P3=cLd20<[:bP80
d=3@0P3:b/X40<S8b0@0`<300P2g]kL20;Fe]@80[:b/0P2WYjL209VIV@80T92@0P21PH4207=cL`80
GUiN0P0Z:RX3000000807alO0P15ADD202XZ:P80IVIV0P1DE5@206a/K080B4Q80P1DE5@205iNGP80
NGUi0P2ATI440:ZZZP80XJ6Q0P21PH4208f=S@80NGUi1021PH420:b/[080alO70P2h^;P20=;BdP80
m?Cd3P3gmoL50?Cdm1h0moOg3`3oool000d0oooo1P3gmoL20?Cdm080moOg0P3dm?@40?Ogm`80m?Cd
0P3gmoL20?Cdm0@0moOg0P3_knl20?Ogm`D0m?Cd0P3gmoL20?Cdm080d];B0P1iNGT405iNGP80E5AD
101;Bd/2051@D080EEEE0P18B4P202XZ:P80=SHf0P39bLT20<g=c@@0dm?C3P3Hf=P20=3@d080b/[:
1P3Hf=P30>?Sh`80f=SH0P3@d=020<[:bP80`L710P2g]kL20;Fe]@80/k>c0P2a/K420:b/[080]kNg
0P30`<040<[:bP80cLg=0P3:b/X20=3@d080b/[:1038b<P40<30`080]kNg0P2e]KD20:b/[080YjNW
0P2IVIT2092@T080PH610P1cLg<205iNGP80:RXZ0`00000201lO7`80ADE50P0Z:RX206IVIP80E5AD
0P1/K6`204Q8B080E5AD0P1NGUh207UiN@80TI6A102ZZZX20:6QX@80PH610P2=SHd207UiN@@0PH61
0P2/[:`20<O7a`80^;Rh0P3Bd]820?Cdm0h0moOg1@3dm?@N0?Ogm`l0oooo000=0?ooo`h0moOg103d
m?@20?Ogm`@0m?Cd103gmoL20?Cdm0L0moOg0P3_knl209FEU@@0I6AT0P0m?Cd404E5A@80Bd];0P1A
DE4204];B`807alO0P0b<S8201lO7`80b/[:0P3@d=020=;BdP80d=3@403Hf=P40=?Cd`80d=3@1`3H
f=P20=?Cd`80b/[:0P2g]kL20:^[Z`80[:b/0P2a/K420:^[Z`80/k>c0P2l_;`20<[:bP@0cLg=0P3?
cll20=?Cd`@0b/[:0P38b<P20<[:bP80b<S80P30`<020;Ng]`80]KFe0P2a/K420:b/[080XJ6Q0P2@
T9020861P@80NGUi0P1aLG4204U9B@<01PH60P0G5aL203Hf=P80EUIF0P1EEED205iNGP80I6AT0P1;
Bd/205ADE080BDU90P1aLG4208b<S080VIVI0P2a/K420<71`@80Ng]k0P21PH42075aL@80PH610P2E
UID20;no_`80alO70P2OWil20<_;b`80moOg0P3dm?@20?Ogm`H0m?Cd1`3gmoL20?Cdm180moOg0P3d
m?@:0?Ogm`l0oooo000=0?ooo`h0moOg103dm?@20?Ogm`@0m?Cd103gmoL20?Cdm0L0moOg0P3_knl2
09FEU@@0I6AT0P0m?Cd404E5A@80Bd];0P1ADE4204];B`807alO0P0b<S8201lO7`80b/[:0P3@d=02
0=;BdP80d=3@403Hf=P40=?Cd`80d=3@1`3Hf=P20=?Cd`80b/[:0P2g]kL20:^[Z`80[:b/0P2a/K42
0:^[Z`80/k>c0P2l_;`20<[:bP@0cLg=0P3?cll20=?Cd`@0b/[:0P38b<P20<[:bP80b<S80P30`<02
0;Ng]`80]KFe0P2a/K420:b/[080XJ6Q0P2@T9020861P@80NGUi0P1aLG4204U9B@<01PH60P0G5aL2
03Hf=P80EUIF0P1EEED205iNGP80I6AT0P1;Bd/205ADE080BDU90P1aLG4208b<S080VIVI0P2a/K42
0<71`@80Ng]k0P21PH42075aL@80PH610P2EUID20;no_`80alO70P2OWil20<_;b`80moOg0P3dm?@2
0?Ogm`H0m?Cd1`3gmoL20?Cdm180moOg0P3dm?@:0?Ogm`l0oooo000=0?ooo`@0m?Cd1P3gmoL20?Cd
m0`0moOg0P3dm?@20?Ogm`80m?Cd1`3gmoL20?7al@80R8R80P1TI6@2051@D080?Cdm0P1EEED4055A
D@80Bd];0P0G5aL202XZ:P809bLW0P0f=SH20<[:bP80dm?C5P3Hf=P20=3@d080d];B0P3@d=030=SH
f080d=3@0P3=cLd20<30`080_;bl0P2[Zj/20;6a/@@0/k>c0P2l_;`60<[:bP80cLg=0P3@d=020=?C
d`80cLg=0P3@d=020<[:bP80b<S80P3:b/X40<30`080]kNg0P2e]KD20:VYZ@80[:b/0P2IVIT208j>
SP80NGUi0P1/K6`205EEE@<02`/;0P0X:2P202XZ:P80ADE50P19BDT405ADE080IVIV101DE5@207Yj
NP80SHf=0P2GUiL20;6a/@80cLg=0P21PH4207]kN`80K6a/0P1jNWX208J6QP80[:b/0P36a/H20<_;
b`80m?Cd7@3gmoL20?Cdm0P0moOg103dm?@80?Ogm`l0oooo000=0?ooo`@0m?Cd1P3gmoL20?Cdm0`0
moOg0P3dm?@20?Ogm`80m?Cd1`3gmoL20?7al@80R8R80P1TI6@2051@D080?Cdm0P1EEED4055AD@80
Bd];0P0G5aL202XZ:P809bLW0P0f=SH20<[:bP80dm?C5P3Hf=P20=3@d080d];B0P3@d=030=SHf080
d=3@0P3=cLd20<30`080_;bl0P2[Zj/20;6a/@@0/k>c0P2l_;`60<[:bP80cLg=0P3@d=020=?Cd`80
cLg=0P3@d=020<[:bP80b<S80P3:b/X40<30`080]kNg0P2e]KD20:VYZ@80[:b/0P2IVIT208j>SP80
NGUi0P1/K6`205EEE@<02`/;0P0X:2P202XZ:P80ADE50P19BDT405ADE080IVIV101DE5@207YjNP80
SHf=0P2GUiL20;6a/@80cLg=0P21PH4207]kN`80K6a/0P1jNWX208J6QP80[:b/0P36a/H20<_;b`80
m?Cd7@3gmoL20?Cdm0P0moOg103dm?@80?Ogm`l0oooo000=0?ooo`P0moOg0P3dm?@<0?Ogm`80m?Cd
0P3gmoL20?Cdm080moOg2@3dm?@208R8R080GUiN101;Bd/205EEE@80BDU90P1;Bd/2055AD@80:RXZ
0P0O7al202XZ:P80[:b/103?cll:0=SHf0H0h>3P203Hf=P20=?Cd`80cLg=1@3Hf=P20<[:bP80`<30
102c/k<20;6a/@80^[Zj0P2l_;`20<71`@80b/[:0P3?cll20<g=c@@0d=3@0P3Hf=P20=;BdP80d=3@
0P3=cLd40<[:bP80`<30102l_;`20;>c/`80[:b/0P2SXj<20:6QX@80SXj>0P1jNWX206a/K080I6AT
0`0O7al200H61P80<S8b0P0Z:RX205EEE@80GUiN0P1;Bd/205iNGP80IVIV0P1DE5@2075aL@80WinO
0P2QXJ420:n_[`80cLg=0P1iNGT2096AT@80GUiN0P26QXH207UiN@80_Kfm0P3?cll20<_;bc40moOg
0P3dm?@20?Ogm`l0oooo000=0?ooo`P0moOg0P3dm?@<0?Ogm`80m?Cd0P3gmoL20?Cdm080moOg2@3d
m?@208R8R080GUiN101;Bd/205EEE@80BDU90P1;Bd/2055AD@80:RXZ0P0O7al202XZ:P80[:b/103?
cll:0=SHf0H0h>3P203Hf=P20=?Cd`80cLg=1@3Hf=P20<[:bP80`<30102c/k<20;6a/@80^[Zj0P2l
_;`20<71`@80b/[:0P3?cll20<g=c@@0d=3@0P3Hf=P20=;BdP80d=3@0P3=cLd40<[:bP80`<30102l
_;`20;>c/`80[:b/0P2SXj<20:6QX@80SXj>0P1jNWX206a/K080I6AT0`0O7al200H61P80<S8b0P0Z
:RX205EEE@80GUiN0P1;Bd/205iNGP80IVIV0P1DE5@2075aL@80WinO0P2QXJ420:n_[`80cLg=0P1i
NGT2096AT@80GUiN0P26QXH207UiN@80_Kfm0P3?cll20<_;bc40moOg0P3dm?@20?Ogm`l0oooo000=
0?ooo`H0m?Cd3P3gmoL60?Cdm0@0moOg1@3dm?@20?Ogm`80bl_;0P1aLG4205iNGP80ADE5101DE5@2
055AD@80Bd];0P0Z:RX201lO7`805aLG0P30`<020=;BdP80d=3@0P3Hf=P20>3Ph0@0f=SH0P3Ph>0B
0=SHf080dm?C1@3Hf=P20=3@d080b/[:0P2l_;`20;>c/`@0^[Zj0P2l_;`20<71`@@0cLg=103Hf=P2
0=3@d080f=SH0P3@d=020=SHf0@0d];B0P3=cLd20<[:bP80alO70P30`<020;Zj^P80/K6a0P2YZJT2
0:>SX`80XJ6Q0P21PH4206a/K080IVIV0`15ADD2038b<P80?Cdm1019BDT206ATI080E5AD0P1VIVH2
05iNGP80EEEE0P1aLG420:VYZ@80XJ6Q0P2[Zj/20<71`@80SHf=0P1kNg/205ADE080NWYj0P21PH42
0;6a/@80eMGE0P3/k>`B0?Ogm`<0m?Cd103gmoL40?Cdm0@0moOg0P3dm?@20?Ogm`80m?Cd3P3gmoL?
0?ooo`003@3oool60?Cdm0h0moOg1P3dm?@40?Ogm`D0m?Cd0P3gmoL20<_;b`80LG5a0P1NGUh204E5
A@@0E5AD0P1ADE4204];B`80:RXZ0P0O7al201LG5`80`<300P3Bd]820=3@d080f=SH0P3Ph>040=SH
f080h>3P4P3Hf=P20=?Cd`D0f=SH0P3@d=020<[:bP80_;bl0P2c/k<40;Zj^P80_;bl0P31`L440<g=
c@@0f=SH0P3@d=020=SHf080d=3@0P3Hf=P40=;BdP80cLg=0P3:b/X20<O7a`80`<300P2j^[X20;6a
/@80ZJVY0P2SXj<20:6QX@80PH610P1/K6`206IVIP<0ADE50P0b<S8203dm?@@0BDU90P1TI6@205AD
E080IVIV0P1NGUh205EEE@80LG5a0P2YZJT20:6QX@80Zj^[0P31`L4208f=S@80Ng]k0P1DE5@207Yj
NP80PH610P2a/K420=GEe@80k>c/4P3gmoL30?Cdm0@0moOg103dm?@40?Ogm`80m?Cd0P3gmoL20?Cd
m0h0moOg3`3oool000d0oooo0P3dm?@20?Ogm`80m?Cd303gmoL20?Cdm0@0moOg0P3dm?@;0?Ogm`80
LG5a0P1NGUh205ADE080<S8b0P1FEUH404U9B@80DE5A0P0Z:RX203dm?@80=SHf0P3:b/X20<g=c@P0
f=SH103Ph>060=SHf080h>3P2P3Hf=P20=;BdPL0f=SH0P3@d=020;bl_080/k>c0P2l_;`20;no_`@0
`L710P37alL20<o?c`80f=SH0P3Bd]860=SHf080d=3@1P3Bd]820<g=c@80b/[:0P31`L420;bl_080
/k>c0P2a/K420:>SX`80XJ6Q0P29RHT207YjNP80HF5Q0`19BDT603dm?@80EEEE0P1DE5@206IVIP80
I6AT0P1NGUh206m_K`80R8R80P2SXj<40:6QX@80Zj^[0P2ATI42075aL@80D51@0P1jNWX209FEU@80
[Zj^0P3MgMdU0?Ogm`80m?Cd1P3gmoL20?Cdm0P0moOg3`3oool000d0oooo0P3dm?@20?Ogm`80m?Cd
303gmoL20?Cdm0@0moOg0P3dm?@;0?Ogm`80LG5a0P1NGUh205ADE080<S8b0P1FEUH404U9B@80DE5A
0P0Z:RX203dm?@80=SHf0P3:b/X20<g=c@P0f=SH103Ph>060=SHf080h>3P2P3Hf=P20=;BdPL0f=SH
0P3@d=020;bl_080/k>c0P2l_;`20;no_`@0`L710P37alL20<o?c`80f=SH0P3Bd]860=SHf080d=3@
1P3Bd]820<g=c@80b/[:0P31`L420;bl_080/k>c0P2a/K420:>SX`80XJ6Q0P29RHT207YjNP80HF5Q
0`19BDT603dm?@80EEEE0P1DE5@206IVIP80I6AT0P1NGUh206m_K`80R8R80P2SXj<40:6QX@80Zj^[
0P2ATI42075aL@80D51@0P1jNWX209FEU@80[Zj^0P3MgMdU0?Ogm`80m?Cd1P3gmoL20?Cdm0P0moOg
3`3oool000d0oooo0P3dm?@F0?Ogm`80m?Cd1`3gmoL20?Cdm080moOg0P1iNGT206IVIP80BDU90P0m
?Cd205iNGP80EEEE0P1;Bd/204E5A@80?Cdm0P0Z:RX208>3P`80d=3@0P3Bd]860=SHf0@0h>3P303H
f=P40>3Ph0/0f=SH103@d=020;bl_0@0/k>c0P2o_kl20<71`@@0b/[:1P3Bd]840=SHf0@0d=3@0P3H
f=P20=?Cd`80clo?0P3=cLd40<[:bP80`L710P2c/k<20;6a/@80ZJVY0P2QXJ4208j>SP80NWYj0P1Q
HF4305EEE@@0<S8b0P0m?Cd204U9B@80DE5A0P1TI6@206IVIP80I6AT0P1NGUh80:6QX@80ZJVY0P2[
Zj/407=cL`80NGUi0P26QXH20:n_[`80k>c/6`3gmoL20?Cdm080moOg0P3dm?@F0?Ogm`l0oooo000=
0?ooo`80m?Cd5P3gmoL20?Cdm0L0moOg0P3dm?@20?Ogm`80NGUi0P1VIVH204U9B@80?Cdm0P1NGUh2
05EEE@80Bd];0P15ADD203dm?@80:RXZ0P23Ph<20=3@d080d];B1P3Hf=P40>3Ph0`0f=SH103Ph>0;
0=SHf0@0d=3@0P2l_;`40;>c/`80_kno0P31`L440<[:bPH0d];B103Hf=P40=3@d080f=SH0P3Cdm<2
0<o?c`80cLg=103:b/X20<71`@80/k>c0P2a/K420:VYZ@80XJ6Q0P2>SXh207YjNP80HF5Q0`1EEED4
038b<P80?Cdm0P19BDT2055AD@80I6AT0P1VIVH206ATI080GUiN202QXJ420:VYZ@80Zj^[101cLg<2
07UiN@80QXJ60P2_[jl20>c/k1/0moOg0P3dm?@20?Ogm`80m?Cd5P3gmoL?0?ooo`003@3oool40?Og
m`80m?Cd0P3gmoL20?Cdm0H0moOg0P3dm?@A0?Ogm`80m?Cd101aLG4205EEE@80BDU90P15ADD205EE
E@80DE5A0P0b<S8204E5A@80EEEE0P3=cLd20=?Cd`80d];B4P3Hf=P20=;BdP`0f=SH0`3=cLd60=SH
f080`L710P2g]kL20;>c/`80_;bl1031`L420<O7a`80cLg=1P3Bd]820=SHf080d];B0P3Hf=P20=;B
dP@0cLg=0P3:b/X20<g=c@80alO71031`L420;>c/`80ZJVY0P2SXj<209VIV@80PH610P1/K6`305EE
E@80ADE50P0i>CT403dm?@80EEEE0P1NGUh2069RHP80EEEE0P1@D5020:j^[P80XJ6Q0P2EUID20:>S
X`80WinO0P2a/K4205iNGP@0NGUi0P21PH420:^[Z`80kno_8`3gmoL20?Cdm180moOg3`3oool000d0
oooo103gmoL20?Cdm080moOg0P3dm?@60?Ogm`80m?Cd4@3gmoL20?Cdm0@0LG5a0P1EEED204U9B@80
ADE50P1EEED2055AD@80<S8b0P15ADD205EEE@80cLg=0P3Cdm<20=;BdQ80f=SH0P3Bd]8<0=SHf0<0
cLg=1P3Hf=P20<71`@80]kNg0P2c/k<20;bl_0@0`L710P37alL20<g=c@H0d];B0P3Hf=P20=;BdP80
f=SH0P3Bd]840<g=c@80b/[:0P3=cLd20<O7a`@0`L710P2c/k<20:VYZ@80Xj>S0P2IVIT20861P@80
K6a/0`1EEED204E5A@80>CTi100m?Cd205EEE@80GUiN0P1RHV8205EEE@80D51@0P2^[Zh20:6QX@80
UIFE0P2SXj<209nOW`80/K6a0P1NGUh407UiN@80PH610P2[Zj/20>o_kb<0moOg0P3dm?@B0?Ogm`l0
oooo000=0?ooo`80m?Cd1P3gmoL20?Cdm080moOg0P3dm?@20?Ogm`80m?Cd303gmoL30?Cdm080moOg
0P2^[Zh205iNGP80HV9R0P1DE5@205iNGP80E5AD0P1EEED203dm?@80=SHf0P15ADD20<O7a`80f=SH
0P3=cLd:0=SHf080h>3P1P3Hf=P20=;BdP@0cLg=103Bd]840=SHf080d=3@0`3Cdm<60=SHf080b/[:
0P2g]kL20;6a/@80/k>c0P2f][H20;no_`80][Jf0P39bLT20<o?c`80cLg=0P3Hf=P60=;BdP80cLg=
0P39bLT20<g=c@H0b/[:1031`L420;Jf]P80/K6a0P2YZJT209fMW@80SXj>0P1/K6`305iNGP80BDU9
0P0Z:RX403dm?@80BDU90P1/K6`605iNGP80WinO0P2EUID40:6QX@80K6a/0P2m_Kd204a<C080K6a/
0P2=SHd209FEU@80[:b/8@3gmoL20?Cdm1H0moOg3`3oool000d0oooo0P3dm?@60?Ogm`80m?Cd0P3g
moL20?Cdm080moOg0P3dm?@<0?Ogm`<0m?Cd0P3gmoL20:j^[P80GUiN0P1RHV8205ADE080GUiN0P1D
E5@205EEE@80?Cdm0P0f=SH204E5A@80alO70P3Hf=P20<g=c@X0f=SH0P3Ph>060=SHf080d];B103=
cLd40=;BdP@0f=SH0P3@d=030=?Cd`H0f=SH0P3:b/X20;Ng]`80/K6a0P2c/k<20;Jf]P80_kno0P2f
][H20<W9b@80clo?0P3=cLd20=SHf0H0d];B0P3=cLd20<W9b@80cLg=1P3:b/X40<71`@80][Jf0P2a
/K420:VYZ@80WIfM0P2>SXh206a/K0<0GUiN0P19BDT202XZ:P@0?Cdm0P19BDT206a/K0H0GUiN0P2O
Wil209FEU@@0XJ6Q0P1/K6`20;fm_@80C4a<0P1/K6`208f=S@80UIFE0P2/[:`Q0?Ogm`80m?Cd5P3g
moL?0?ooo`003@3oool60?Ogm`80m?Cd103gmoL20?Cdm100moOg0`3dm?@20?Ogm`80OWin0P2=SHd2
06a/K080BDU90P1/K6`204U9B@80EEEE0P0b<S8204U9B@80Bd];0P37alL20=3@d080alO7103Hf=P2
0>3Ph0P0f=SH103Bd]820<30`080alO7103:b/X20<g=c@80d];B0P3Hf=P20<o?c`<0dm?C1P3Hf=P2
0<[:bP80]KFe0P2a/K420:^[Z`@0/k>c0P31`L420<W9b@80cLg=0P3Bd]840<O7a`80`L712037alL2
0<[:bP80cLg=1037alL20;Rh^080_kno0P2a/K420:VYZ@80XJ6Q0P2>SXh207UiN@<0GUiN0P1ADE42
02XZ:P809bLW0P0m?Cd204U9B@80GUiN0P1VIVH405iNGP80WinO102IVIT20:6QX@80DE5A0P2_[jl2
065QH@80GUiN0P28R8P20:VYZ@80alO71P3gmoL20?Cdm1T0moOg0P3dm?@F0?Ogm`l0oooo000=0?oo
o`H0moOg0P3dm?@40?Ogm`80m?Cd403gmoL30?Cdm080moOg0P1nOWh208f=S@80K6a/0P19BDT206a/
K080BDU90P1EEED2038b<P80BDU90P1;Bd/20<O7a`80d=3@0P37alL40=SHf080h>3P203Hf=P40=;B
dP80`<300P37alL40<[:bP80cLg=0P3Bd]820=SHf080clo?0`3Cdm<60=SHf080b/[:0P2e]KD20;6a
/@80Zj^[102c/k<20<71`@80bLW90P3=cLd20=;BdP@0alO70P31`L480<O7a`80b/[:0P3=cLd40<O7
a`80^;Rh0P2o_kl20;6a/@80ZJVY0P2QXJ4208j>SP80NGUi0`1NGUh2055AD@80:RXZ0P0W9bL203dm
?@80BDU90P1NGUh206IVIP@0GUiN0P2OWil409VIV@80XJ6Q0P1ADE420:n_[`80HF5Q0P1NGUh208R8
R080ZJVY0P37alL60?Ogm`80m?Cd6@3gmoL20?Cdm1H0moOg3`3oool000d0oooo1P3gmoL20?Cdm0H0
moOg0P3dm?@60?Ogm`P0m?Cd1@3gmoL205ADE080TY:B0P1NGUh206][J`80FUYJ0P1NGUh204U9B@80
:RXZ0P1VIVH20;Fe]@80b/[:0P2g]kL20<g=c@X0f=SH0P3Bd]820<o?c`@0cLg=0P3:b/X20;Jf]P80
/k>c0P31`L420<O7a`80cLg=0P3Bd]820<O7a`<0cLg=1P3Hf=P20<30`080/k>c0P2WYjL20:j^[P80
Zj^[0P2/[:`20;Rh^080alO70P39bLT40<71`@80^;Rh0P2i^KT40;6a/@80Zj^[102f][H60<71`@@0
_kno0P2c/k<20:VYZ@80VIVI0P2@T90207YjNP<0K6a/0P1EEED204E5A@805aLG0P0b<S8203dm?@@0
GUiN0P1/K6`205EEE@80UIFE0P2SXj<20861P@80SHf=0P1@D5020;fm_@80K6a/0P1EEED209FEU@80
Zj^[0P3EeMD@0?Ogm`80m?Cd5`3gmoL20?Cdm0h0moOg3`3oool000d0oooo1P3gmoL20?Cdm0H0moOg
0P3dm?@60?Ogm`P0m?Cd1@3gmoL205ADE080TY:B0P1NGUh206][J`80FUYJ0P1NGUh204U9B@80:RXZ
0P1VIVH20;Fe]@80b/[:0P2g]kL20<g=c@X0f=SH0P3Bd]820<o?c`@0cLg=0P3:b/X20;Jf]P80/k>c
0P31`L420<O7a`80cLg=0P3Bd]820<O7a`<0cLg=1P3Hf=P20<30`080/k>c0P2WYjL20:j^[P80Zj^[
0P2/[:`20;Rh^080alO70P39bLT40<71`@80^;Rh0P2i^KT40;6a/@80Zj^[102f][H60<71`@@0_kno
0P2c/k<20:VYZ@80VIVI0P2@T90207YjNP<0K6a/0P1EEED204E5A@805aLG0P0b<S8203dm?@@0GUiN
0P1/K6`205EEE@80UIFE0P2SXj<20861P@80SHf=0P1@D5020;fm_@80K6a/0P1EEED209FEU@80Zj^[
0P3EeMD@0?Ogm`80m?Cd5`3gmoL20?Cdm0h0moOg3`3oool000d0oooo4P3gmoL20?Cdm080moOg0P3d
m?@90?Ogm`80oooo0P1/K6`207alO080EEEE0P1NGUh205EEE@80HF5Q0P0W9bL205ADE080DE5A0P3@
d=0209VIV@80[:b/0P3?cll80=SHf080d];B0P39bLT20;Jf]P80UIFE0P2=SHd20:^[Z`80ZZZZ0P2E
UID40;Jf]P@0d];B1@3=cLd60=SHf080b/[:0P2c/k<20:>SX`80WinO0P2SXj<20;no_`80][Jf0P39
bLT20;Vi^@80][Jf0P2YZJT209fMW@80R8R80P2=SHd609nOW`80ZZZZ0P2o_kl20<71`@H0][Jf0P2a
/K420:VYZ@80WinO0P2@T9020861P@<0HF5Q0P1EEED204U9B@80?Cdm100b<S8205EEE@80E5AD0P1R
HV8205iNGP80R8R80P2=SHd40861P@80GUiN0P2m_Kd205iNGP80EEEE0P2OWil20:6QX@80emOG0P3o
oolg0?Ogm`l0oooo000=0?oooa80moOg0P3dm?@20?Ogm`80m?Cd2@3gmoL20?ooo`80K6a/0P1lO7`2
05EEE@80GUiN0P1EEED2065QH@809bLW0P1DE5@2055AD@80d=3@0P2IVIT20:b/[080clo?203Hf=P2
0=;BdP80bLW90P2f][H209FEU@80SHf=0P2[Zj/20:ZZZP80UIFE102f][H40=;BdPD0cLg=1P3Hf=P2
0<[:bP80/k>c0P2SXj<209nOW`80Xj>S0P2o_kl20;Jf]P80bLW90P2i^KT20;Jf]P80ZJVY0P2MWId2
08R8R080SHf=1P2OWil20:ZZZP80_kno0P31`L460;Jf]P80/K6a0P2YZJT209nOW`80T92@0P21PH43
065QH@80EEEE0P19BDT203dm?@@0<S8b0P1EEED205ADE080HV9R0P1NGUh208R8R080SHf=1021PH42
05iNGP80_Kfm0P1NGUh205EEE@80WinO0P2QXJ420=OGe`80oooo=`3gmoL?0?ooo`003@3oool20?Cd
m0P0moOg0P3dm?@20?Ogm`80m?Cd4@3gmoL20:2PX080NWYj0P1aLG4204U9B@80EEEE0P19BDT2065Q
H@80<S8b0P1NGUh20;fm_@80`<300P2VYZH20:^[Z`80clo?0P3Bd]840=SHf080cLg=0P2i^KT208J6
QP80SHf=0P2f][H20:j^[P80HV9R0P1WIfL208>3P`80WinO102MWId40<g=c@<0alO71P3Hf=P20<S8
b080_;bl0P2SXj<20:VYZ@80UIFE0P2YZJT205iNGP80OGem0P2@T9020:^[Z`80bl_;0P1iNGT205AD
E080OWin0P1lO7`207YjNP80O7al0P28R8P20:^[Z`@0/k>c102f][H40:^[Z`80VIVI0P2@T90207Yj
NP<0K6a/0P1NGUh204U9B@80EEEE100Z:RX405EEE@80GUiN0P1/K6`208J6QP80UIFE0P1kNg/20861
P@80FUYJ0P2o_kl206IVIP80LG5a102[Zj/20>WYjAl0moOg0P3dm?@H0?Ogm`l0oooo000=0?ooo`80
m?Cd203gmoL20?Cdm080moOg0P3dm?@A0?Ogm`80X:2P0P1jNWX2075aL@80BDU90P1EEED204U9B@80
HF5Q0P0b<S8205iNGP80_Kfm0P30`<020:JVYP80Zj^[0P3?cll20=;BdP@0f=SH0P3=cLd20;Vi^@80
QXJ60P2=SHd20;Jf]P80[Zj^0P1RHV8206MWI`80Ph>30P2OWil409fMW@@0cLg=0`37alL60=SHf080
b<S80P2l_;`20:>SX`80ZJVY0P2EUID20:VYZ@80GUiN0P1mOGd2092@T080Zj^[0P3;bl/207UiN@80
E5AD0P1nOWh207alO080NWYj0P1lO7`208R8R080Zj^[102c/k<40;Jf]P@0Zj^[0P2IVIT2092@T080
NWYj0`1/K6`205iNGP80BDU90P1EEED402XZ:P@0EEEE0P1NGUh206a/K080QXJ60P2EUID207]kN`80
PH610P1JFUX20;no_`80IVIV0P1aLG440:^[Z`80jNWY7`3gmoL20?Cdm1P0moOg3`3oool000d0oooo
5P3gmoL20?Cdm0T0moOg0P28R8P209fMW@80LG5a0P1RHV82038b<P80EEEE0P1QHF4203Ti>@80:RXZ
0P3@d=040;Fe]@80/k>c0P3Bd]820=SHf080d];B0P37alL20;Vi^@80R8R80P2@T9020<30`080emOG
0P1]KFd2069RHP80D51@0P1cLg<207inOP80WinO0P2EUID20;Vi^@80/k>c0`38b<P40=SHf080clo?
0P3:b/X20;bl_080[:b/0P2EUID208R8R080T92@0P2OWil206EUI@80bl_;0P3YjNT206i^KP80Kfm_
0P1RHV8208F5Q@80FEUI0P2PX:02075aL@80IfMW0P28R8P40:VYZ@80/k>c0P2a/K420:^[Z`80Xj>S
0P2QXJ4208R8R080NGUi0`1/K6`205ADE080BDU90P0b<S8200/;2`807alO0P1EEED205iNGP80ADE5
0P1/K6`208R8R080QXJ60P1/K6`207YjNP80LG5a0P2a/K42051@D080UIFE102^[ZhK0?Ogm`80m?Cd
1P3gmoL20?Cdm1H0moOg3`3oool000d0oooo5P3gmoL20?Cdm0T0moOg0P28R8P209fMW@80LG5a0P1R
HV82038b<P80EEEE0P1QHF4203Ti>@80:RXZ0P3@d=040;Fe]@80/k>c0P3Bd]820=SHf080d];B0P37
alL20;Vi^@80R8R80P2@T9020<30`080emOG0P1]KFd2069RHP80D51@0P1cLg<207inOP80WinO0P2E
UID20;Vi^@80/k>c0`38b<P40=SHf080clo?0P3:b/X20;bl_080[:b/0P2EUID208R8R080T92@0P2O
Wil206EUI@80bl_;0P3YjNT206i^KP80Kfm_0P1RHV8208F5Q@80FEUI0P2PX:02075aL@80IfMW0P28
R8P40:VYZ@80/k>c0P2a/K420:^[Z`80Xj>S0P2QXJ4208R8R080NGUi0`1/K6`205ADE080BDU90P0b
<S8200/;2`807alO0P1EEED205iNGP80ADE50P1/K6`208R8R080QXJ60P1/K6`207YjNP80LG5a0P2a
/K42051@D080UIFE102^[ZhK0?Ogm`80m?Cd1P3gmoL20?Cdm1H0moOg3`3oool000d0oooo403gmoL2
0?Cdm0`0moOg0`3oool20?Cdm080PH610P1DE5@204];B`80<S8b1P1EEED2065QH@80d=3@0P2/[:`2
0:JVYP80/k>c0P39bLT20<o?c`80b/[:0P2f][H209FEU@80Kfm_0P0f=SH209NGU`80]kNg0P1gMgL2
0;>c/`8030`<0P1^KVh20492@P80Kfm_0P28R8P209FEU@80_;bl0`3=cLd40=SHf080dm?C0P3:b/X2
0;no_`80^[Zj0P2EUID208f=S@80LG5a0P2=SHd209FEU@80K6a/0P32`/82051@D080_Kfm0P0<30`2
06MWI`80D51@0P2PX:0202PX:080Cdm?0P1lO7`208f=S@80UIFE0P2YZJT20:^[Z`80ZJVY102EUID2
08j>SP80NGUi0`1QHF4205EEE@80DE5A0P0O7al201LG5`807alO0P0Z:RX205EEE@80BDU90P1iNGT2
075aL@@0NWYj0P21PH42075aL@80Zj^[0P1@D50208f=S@80Xj>S0P36a/Hk0?Ogm`l0oooo000=0?oo
oa00moOg0P3dm?@<0?Ogm`<0oooo0P3dm?@20861P@80E5AD0P1;Bd/2038b<PH0EEEE0P1QHF420=3@
d080[:b/0P2VYZH20;>c/`80bLW90P3?cll20<[:bP80][Jf0P2EUID206m_K`80=SHf0P2GUiL20;Ng
]`80MgMg0P2c/k<200`<3080KVi^0P12@T8206m_K`80R8R80P2EUID20;bl_0<0cLg=103Hf=P20=?C
d`80b/[:0P2o_kl20;Zj^P80UIFE0P2=SHd2075aL@80SHf=0P2EUID206a/K080`/;20P1@D5020;fm
_@8030`<0P1WIfL2051@D080X:2P0P0X:2P204m?C`80O7al0P2=SHd209FEU@80ZJVY0P2[Zj/20:VY
Z@@0UIFE0P2>SXh207UiN@<0HF5Q0P1EEED2055AD@807alO0P0G5aL201lO7`80:RXZ0P1EEED204U9
B@80NGUi0P1aLG4407YjNP80PH610P1aLG420:^[Z`80D51@0P2=SHd20:>SX`80a/K6>`3gmoL?0?oo
o`003@3ooolN0?Ogm`<0TY:B0P38b<P208J6QP80Kfm_0P1CDe<204U9B@@0EEEE0P1QHF4208f=S@80
`<300P2VYZH20:>SX`80/K6a0P3=cLd20<o?c`80_;bl0P2ZZZX2092@T080BDU9101QHF4203`l?080
8b<S0P0f=SH205EEE@80IfMW0P1QHF4207alO080UIFE0P2g]kL20<;2`PD0dm?C0P3Hf=P20=?Cd`80
b/[:0P32`/820;bl_080[:b/0P2EUID2092@T080NGUi0P1_Kfl408^;R`80=SHf0P0Z:RX403Hf=P80
BDU90P0l?3`205ADE080De=C0P1lO7`208J6QP80R8R80P2IVIT40:>SX`80UIFE0P28R8P20861P@80
HF5Q1@1NGUh204U9B@80?Cdm0P0O7al203Hf=P@0?Cdm0P19BDT206a/K080NGUi0P1/K6`206IVIP80
PH610P1iNGT20:^[Z`80I6AT0P2=SHd20:6QX@80i^KV:`3gmoL20?Cdm0h0moOg3`3oool000d0oooo
7P3gmoL309:BTP80b<S80P26QXH206m_K`80De=C0P19BDT405EEE@80HF5Q0P2=SHd20<30`080YZJV
0P2SXj<20;6a/@80cLg=0P3?cll20;bl_080ZZZZ0P2@T90204U9B@@0HF5Q0P0l?3`202<S8`80=SHf
0P1EEED206MWI`80HF5Q0P1lO7`209FEU@80]kNg0P32`/850=?Cd`80f=SH0P3Cdm<20<[:bP80`/;2
0P2l_;`20:b/[080UIFE0P2@T90207UiN@80Kfm_102;Rh/203Hf=P80:RXZ100f=SH204U9B@80?3`l
0P1DE5@205=CD`80O7al0P26QXH208R8R080VIVI102SXj<209FEU@80R8R80P21PH42065QH@D0GUiN
0P19BDT203dm?@807alO0P0f=SH403dm?@80BDU90P1/K6`207UiN@80K6a/0P1VIVH20861P@80NGUi
0P2[Zj/206ATI080SHf=0P2QXJ420>KViR/0moOg0P3dm?@>0?Ogm`l0oooo000=0?ooo`P0moOg0P3d
m?@60?Ogm`80m?Cd303gmoL307UiN@80X:2P0P2JVYX205iNGP80BDU90P1RHV8205EEE@80BDU90P1E
EED208j>SP80]KFe102SXj<20;6a/@80cLg=0P39bLT20<O7a`80`L710P2c/k<209FEU@80NWYj0P1R
HV8605=CD`80EEEE0P1_Kfl2092@T080ZJVY0P2l_;`40<[:bP<0dm?C103Hf=P20=?Cd`@0b/[:0P38
b<P20;Zj^P80[:b/0P2SXj<209FEU@80R8R80P1OGel207alO080Ph>30P1jNWX2065QH@80ATI60P0l
?3`204U9B@80LG5a102=SHd2092@T080VIVI102SXj<209FEU@80VIVI0P2=SHd207YjNP80HF5Q0`1N
GUh405EEE@80ADE50P0Z:RX203Hf=P@0<S8b0P15ADD2075aL@80PH610P1aLG4206IVIP80PH610P2=
SHd20:^[Z`80K6a/0P2=SHd20:VYZ@80k>c/>`3gmoL?0?ooo`003@3oool80?Ogm`80m?Cd1P3gmoL2
0?Cdm0`0moOg0`1iNGT20:2PX080VYZJ0P1NGUh204U9B@80HV9R0P1EEED204U9B@80EEEE0P2>SXh2
0;Fe]@@0Xj>S0P2a/K420<g=c@80bLW90P37alL20<71`@80/k>c0P2EUID207YjNP80HV9R1P1CDe<2
05EEE@80Kfm_0P2@T9020:VYZ@80_;bl103:b/X30=?Cd`@0f=SH0P3Cdm<40<[:bP80b<S80P2j^[X2
0:b/[080Xj>S0P2EUID208R8R080GemO0P1lO7`208>3P`80NWYj0P1QHF4204I6AP80?3`l0P19BDT2
075aL@@0SHf=0P2@T90209VIV@@0Xj>S0P2EUID209VIV@80SHf=0P1jNWX2065QH@<0GUiN101EEED2
04E5A@80:RXZ0P0f=SH4038b<P80ADE50P1aLG420861P@80LG5a0P1VIVH20861P@80SHf=0P2[Zj/2
06a/K080SHf=0P2YZJT20>c/k3/0moOg3`3oool000d0oooo603gmoL20?Cdm0@0moOg0`3Vi^H208V9
R@80Jf][0P19BDT204E5A@@0BDU90P0m?Cd206a/K080SXj>0P2IVIT209nOW`80UIFE0P2[Zj/20<W9
b@@0clo?0P3Hf=P20=;BdP80b/[:0P3=cLd20<71`@80_;bl0P2i^KT20;bl_080`L710P2l_;`20:>S
X`80[:b/0P2g]kL20<S8b080f=SH0`3Cdm<60=SHf080dm?C0P3=cLd20<[:bP80^[Zj0P2QXJ420:NW
Y`80UIFE0P2YZJT20:^[Z`80ZJVY1P2EUID209VIV@80Xj>S102YZJT20;6a/@80]KFe0P2c/k<20:^[
Z`80ZJVY0P2SXj<209VIV@80T92@0P2=SHd20861P@80HF5Q0`1RHV8205EEE@@0?Cdm0P0Z:RX203Hf
=P80BDU90P15ADD203dm?@80K6a/0P2=SHd206a/K080IVIV0P2<S8`209FEU@80/k>c0P1aLG4209FE
U@80gMgM0P3ooolg0?Ogm`80m?Cd0P3gmoL?0?ooo`003@3ooolH0?Ogm`80m?Cd103gmoL30>KViP80
RHV90P1[Jf/204U9B@80ADE51019BDT203dm?@80K6a/0P2>SXh209VIV@80WinO0P2EUID20:^[Z`80
bLW9103?cll20=SHf080d];B0P3:b/X20<g=c@80`L710P2l_;`20;Vi^@80_;bl0P31`L420;bl_080
Xj>S0P2/[:`20;Ng]`80b<S80P3Hf=P30=?Cd`H0f=SH0P3Cdm<20<g=c@80b/[:0P2j^[X20:6QX@80
YjNW0P2EUID20:VYZ@80Zj^[0P2YZJT609FEU@80VIVI0P2SXj<40:VYZ@80/K6a0P2e]KD20;>c/`80
Zj^[0P2YZJT20:>SX`80VIVI0P2@T90208f=S@80PH610P1QHF43069RHP80EEEE100m?Cd202XZ:P80
=SHf0P19BDT204E5A@80?Cdm0P1/K6`208f=S@80K6a/0P1VIVH208b<S080UIFE0P2c/k<2075aL@80
UIFE0P3MgMd20?ooocL0moOg0P3dm?@20?Ogm`l0oooo000=0?ooo`@0moOg0P3dm?@40?Ogm`80m?Cd
2P3gmoL20?Cdm0@0moOg1@3oool204E5A@80GUiN0P0b<S8403dm?@80I6AT0P0b<S8205iNGP80NWYj
0P2MWId209VIV@80SHf=0P2YZJT20<o?c`80`L710P3Cdm<<0=SHf080]KFe0P2@T90207alO080LG5a
0P1jNWX20;bl_080b<S81`3Hf=P20>3Ph0H0f=SH0P3Cdm<20=SHf080`/;20P2g]kL2092@T0@0LG5a
0P1jNWX208f=S@80`L710P37alL20<[:bP80alO71031`L460;bl_080/k>c0P2YZJT209FEU@80QXJ6
0P2IVIT208f=S@80PH610P1iNGT206a/K0<0GUiN0P1DE5@205EEE@80<S8b100Z:RX203Hf=P809bLW
0P19BDT205iNGP80NGUi0P1/K6`206ATI080TI6A0P2EUID20;no_`80NWYj0P2OWil20>WYjCd0moOg
3`3oool000d0oooo103gmoL20?Cdm0@0moOg0P3dm?@:0?Ogm`80m?Cd103gmoL50?ooo`80ADE50P1N
GUh2038b<P@0?Cdm0P1TI6@2038b<P80GUiN0P1jNWX209fMW@80VIVI0P2=SHd20:VYZ@80clo?0P31
`L420=?Cd``0f=SH0P2e]KD2092@T080O7al0P1aLG4207YjNP80_;bl0P38b<P70=SHf080h>3P1P3H
f=P20=?Cd`80f=SH0P32`/820;Ng]`80T92@101aLG4207YjNP80SHf=0P31`L420<O7a`80b/[:0P37
alL40<71`@H0_;bl0P2c/k<20:VYZ@80UIFE0P26QXH209VIV@80SHf=0P21PH4207UiN@80K6a/0`1N
GUh205ADE080EEEE0P0b<S8402XZ:P80=SHf0P0W9bL204U9B@80GUiN0P1iNGT206a/K080I6AT0P2A
TI4209FEU@80_kno0P1jNWX209nOW`80jNWY?@3gmoL?0?ooo`003@3ooolL0?Ogm`80jNWY0`3oool2
03dm?@80Bd];0P0b<S8203dm?@80BDU90P1EEED204U9B@80IVIV0P1eMGD20861P@80SHf=0P2@T902
09nOW`80b/[:0P36a/H20;no_`80cLg=1P3Hf=P20=3@d080R8R80P1lO7`206m_K`80NWYj0P2YZJT2
0<S8b0@0dm?C0P3Hf=P20>3Ph0<0f=SH0P3Ph>080=SHf0@0dm?C0P38b<P20;Ng]`80SHf=0P1QHF42
05EEE@80HF5Q0P1jNWX20:b/[080^KVi0P37alL40<[:bP80`<300P31`L420;>c/`80[:b/0P2EUID2
07YjNP80VIVI0P2=SHd208R8R080NGUi101/K6`305iNGP@0?Cdm0P0Z:RX2038b<P80:RXZ0P0W9bL2
04m?C`80FUYJ0P1[Jf/207YjNP80LG5a0P1NGUh408f=S@80[Zj^0P2EUID209nOWcl0moOg3`3oool0
00d0oooo703gmoL20>WYj@<0oooo0P0m?Cd204];B`80<S8b0P0m?Cd204U9B@80EEEE0P19BDT206IV
IP80MGEe0P21PH4208f=S@80T92@0P2OWil20<[:bP80a/K60P2o_kl20<g=c@H0f=SH0P3@d=0208R8
R080O7al0P1_Kfl207YjNP80ZJVY0P38b<P40=?Cd`80f=SH0P3Ph>030=SHf080h>3P203Hf=P40=?C
d`80b<S80P2g]kL208f=S@80HF5Q0P1EEED2065QH@80NWYj0P2/[:`20;Vi^@80alO7103:b/X20<30
`080`L710P2c/k<20:b/[080UIFE0P1jNWX209VIV@80SHf=0P28R8P207UiN@@0K6a/0`1NGUh403dm
?@80:RXZ0P0b<S8202XZ:P809bLW0P1?Cdl205YJFP80Jf][0P1jNWX2075aL@80GUiN102=SHd20:j^
[P80UIFE0P2OWilo0?Ogm`l0oooo000=0?oooaH0moOg0P3dm?@20?Ogm`80oooo0P2^[Zh30?ooo`80
E5AD0P15ADD404U9B@80<S8b0P1EEED204];B`80GUiN101QHF4207alO080R8R80P2OWil20<W9b@80
d];B0P2EUID209nOW`80ZJVY0P2SXj<209fMW@80NWYj0P1iNGT20:>SX`80dm?C103Hf=P=0>3Ph0`0
f=SH1P3Cdm<20<g=c@80_;bl0P2YZJT208f=S@80Kfm_0P1NGUh4075aL@80RHV90P2=SHd2092@T080
QXJ60P1lO7`207YjNP80R8R8102EUID209fMW@80SHf=0P1iNGT406a/K0<0EEEE0P1/K6`201lO7`@0
ADE50P0m?Cd202XZ:P808b<S0P1OGel206a/K080NGUi0P1/K6`206ATI080SHf=0P2QXJ4208R8R080
Lg=c0P3;bl/S0?Ogm`80m?Cd6P3gmoL?0?ooo`003@3ooolF0?Ogm`80m?Cd0P3gmoL20?ooo`80[Zj^
0`3oool205ADE080ADE51019BDT2038b<P80EEEE0P1;Bd/205iNGP@0HF5Q0P1lO7`208R8R080WinO
0P39bLT20=;BdP80UIFE0P2OWil20:VYZ@80Xj>S0P2MWId207YjNP80NGUi0P2SXj<20=?Cd`@0f=SH
3@3Ph>0<0=SHf0H0dm?C0P3=cLd20;bl_080ZJVY0P2=SHd206m_K`80GUiN101aLG4208V9R@80SHf=
0P2@T90208J6QP80O7al0P1jNWX208R8R0@0UIFE0P2MWId208f=S@80NGUi101/K6`305EEE@80K6a/
0P0O7al404E5A@80?Cdm0P0Z:RX202<S8`80GemO0P1/K6`207UiN@80K6a/0P1TI6@208f=S@80XJ6Q
0P28R8P207=cL`80bl_;8`3gmoL20?Cdm1X0moOg3`3oool000d0oooo5P3gmoL20?Cdm0@0moOg0P2V
YZH3075aL@@0BDU90P1OGel205EEE@H0BDU90P1EEED205iNGP80HV9R0P1aLG4207YjNP80ZJVY0P39
bLT40<o?c`80b/[:0P2YZJT409fMW@80][Jf0P3Hf=PB0>3Ph0<0hn?S103Hf=P60>3Ph0P0f=SH0P3C
dm<20=3@d0H0b/[:1037alL209nOW`80O7al0P1iNGT407alO080UIFE0P2OWil209FEU@80VIVI0P2Q
XJ4209VIV@80SHf=0P1iNGT2075aL@80NGUi0`1EEED203dm?@80BDU90P0m?Cd2038b<P@05aLG0P0O
7al2069RHP80Kfm_0P1NGUh207YjNP80LG5a0P2EUID209nOW`80K6a/0P2=SHd20>WYjBL0moOg0P3d
m?@F0?Ogm`l0oooo000=0?oooaH0moOg0P3dm?@40?Ogm`80YZJV0`1aLG4404U9B@80GemO0P1EEED6
04U9B@80EEEE0P1NGUh2069RHP80LG5a0P1jNWX20:VYZ@80bLW9103?cll20<[:bP80ZJVY102MWId2
0;Jf]P80f=SH4P3Ph>030>?Sh`@0f=SH1P3Ph>080=SHf080dm?C0P3@d=060<[:bP@0alO70P2OWil2
07alO080NGUi101lO7`209FEU@80WinO0P2EUID209VIV@80XJ6Q0P2IVIT208f=S@80NGUi0P1aLG42
07UiN@<0EEEE0P0m?Cd204U9B@80?Cdm0P0b<S8401LG5`807alO0P1RHV8206m_K`80GUiN0P1jNWX2
075aL@80UIFE0P2OWil206a/K080SHf=0P3YjNTW0?Ogm`80m?Cd5P3gmoL?0?ooo`003@3oool80?Og
m`80m?Cd1P3gmoL20?Cdm0X0moOg0P38b<P306a/K080EUIF0P19BDT207YjNP80IfMW0P1FEUH205EE
E@80BDU9101NGUh2069RHP@0NGUi0P2SXj<20<[:bP80cLg=103?cll:0=SHf0h0h>3P0P3Shn<50>3P
h080f=SH1P3Ph>0<0=SHf0@0clo?0P3Cdm<60<[:bP80`L711037alL20;bl_080/k>c0P2a/K420:^[
Z`80Xj>S0P2YZJT209FEU@80SHf=0P21PH4207UiN@80NWYj0P1iNGT306a/K080BDU90P0m?Cd202LW
9`H05aLG0P0O7al208f=S@80HV9R0P1NGUh20:6QX@80K6a/0P21PH420:^[Z`80K6a/0P2OWim10?Og
m`l0oooo000=0?ooo`P0moOg0P3dm?@60?Ogm`80m?Cd2P3gmoL20<S8b0<0K6a/0P1FEUH204U9B@80
NWYj0P1WIfL205IFEP80EEEE0P19BDT405iNGP80HV9R101iNGT20:>SX`80b/[:0P3=cLd40<o?c`X0
f=SH3P3Ph>020>?Sh`D0h>3P0P3Hf=P60>3Ph0`0f=SH103?cll20=?Cd`H0b/[:0P31`L440<O7a`80
_;bl0P2c/k<20;6a/@80Zj^[0P2SXj<20:VYZ@80UIFE0P2=SHd20861P@80NGUi0P1jNWX207UiN@<0
K6a/0P19BDT203dm?@809bLW1P0G5aL201lO7`80SHf=0P1RHV8205iNGP80XJ6Q0P1/K6`20861P@80
Zj^[0P1/K6`209nOWd40moOg3`3oool000d0oooo103gmoL20?Cdm0P0moOg0P3dm?@<0?Ogm`80];Bd
0`1@D50204m?C`80FUYJ0P26QXH206][J`80EEEE0P1JFUX205IFEP@0FUYJ0P1NGUh207YjNP80LG5a
0P2SXj<20<O7a`@0clo?0P3Bd]860=SHf0@0h>3P103Hf=P60>3Ph080f=SH2@3Ph>040=SHf080h>3P
103Hf=P20>3Ph0X0f=SH0P3@d=020=?Cd`80cLg=0P3:b/X20<O7a`80`L710P3:b/X40;bl_080/k>c
102YZJT40:>SX`@0UIFE0P2=SHd207YjNP@0NGUi0`1NGUh206a/K080ADE5100Z:RX201lO7`80<S8b
0P0W9bL209FEU@80NWYj0P1NGUh209FEU@80NGUi0P1/K6`20:j^[P80K6a/0P2m_Kd20?ooocl0moOg
3`3oool000d0oooo103gmoL20?Cdm0P0moOg0P3dm?@<0?Ogm`80];Bd0`1@D50204m?C`80FUYJ0P26
QXH206][J`80EEEE0P1JFUX205IFEP@0FUYJ0P1NGUh207YjNP80LG5a0P2SXj<20<O7a`@0clo?0P3B
d]860=SHf0@0h>3P103Hf=P60>3Ph080f=SH2@3Ph>040=SHf080h>3P103Hf=P20>3Ph0X0f=SH0P3@
d=020=?Cd`80cLg=0P3:b/X20<O7a`80`L710P3:b/X40;bl_080/k>c102YZJT40:>SX`@0UIFE0P2=
SHd207YjNP@0NGUi0`1NGUh206a/K080ADE5100Z:RX201lO7`80<S8b0P0W9bL209FEU@80NWYj0P1N
GUh209FEU@80NGUi0P1/K6`20:j^[P80K6a/0P2m_Kd20?ooocl0moOg3`3oool000d0oooo703gmoL2
0<k>cP<0EEEE0P1WIfL2069RHP80LG5a0P1RHV8206MWI`80HV9R0P1JFUX205EEE@@0E5AD0P1/K6`2
075aL@80T92@0P2o_kl20<g=c@@0clo?0P3Bd]860=SHf0@0h>3P0P3Hf=PK0>3Ph0H0f=SH2P3Cdm<2
0<[:bP80b<S80P37alL20<[:bP80`L710P2o_kl20;Zj^P80/k>c0P2a/K420:^[Z`80ZJVY0P2SXj<2
0:6QX@80VIVI0P21PH4207UiN@80PH610P1aLG4306a/K080BDU90P0b<S8203dm?@80<S8b100G5aL2
01lO7`80UIFE0P1lO7`206a/K080XJ6Q0P1kNg/2069RHP80UIFE0P1/K6`20?Cdm440moOg3`3oool0
00d0oooo703gmoL20<k>cP<0EEEE0P1WIfL2069RHP80LG5a0P1RHV8206MWI`80HV9R0P1JFUX205EE
E@@0E5AD0P1/K6`2075aL@80T92@0P2o_kl20<g=c@@0clo?0P3Bd]860=SHf0@0h>3P0P3Hf=PK0>3P
h0H0f=SH2P3Cdm<20<[:bP80b<S80P37alL20<[:bP80`L710P2o_kl20;Zj^P80/k>c0P2a/K420:^[
Z`80ZJVY0P2SXj<20:6QX@80VIVI0P21PH4207UiN@80PH610P1aLG4306a/K080BDU90P0b<S8203dm
?@80<S8b100G5aL201lO7`80UIFE0P1lO7`206a/K080XJ6Q0P1kNg/2069RHP80UIFE0P1/K6`20?Cd
m440moOg3`3oool000d0oooo2P3gmoL20?Cdm100moOg0P3dm?@3069RHPH0EEEE0P1OGel2069RHP80
EEEE0P1JFUX205EEE@80FUYJ0P1EEED207YjNP80PH610P2EUID20;bl_080`L710P3=cLd20=;BdP80
dm?C203Hf=P:0>3Ph0@0f=SH2`3Ph>0:0=SHf080d=3@1P3Cdm<20<g=c@H0b/[:0P30`<020<71`@80
_kno0P31`L420;bl_080/K6a0P2c/k<20:b/[080ZJVY0P2EUID209VIV@80T92@0P2=SHd20861P@80
NGUi0P1/K6`305EEE@80BDU90P0f=SH204E5A@807alO100G5aL2038b<P80LG5a0P2QXJ4208J6QP80
Xj>S0P21PH42075aL@80I6AT0P2/[:`Y0?Ogm`80m?Cd603gmoL?0?ooo`003@3oool:0?Ogm`80m?Cd
403gmoL20?Cdm0<0HV9R1P1EEED205mOG`80HV9R0P1EEED205YJFP80EEEE0P1JFUX205EEE@80NWYj
0P21PH4209FEU@80_;bl0P31`L420<g=c@80d];B0P3Cdm<80=SHf0X0h>3P103Hf=P;0>3Ph0X0f=SH
0P3@d=060=?Cd`80cLg=1P3:b/X20<30`080`L710P2o_kl20<71`@80_;bl0P2a/K420;>c/`80[:b/
0P2YZJT209FEU@80VIVI0P2@T90208f=S@80PH610P1iNGT206a/K0<0EEEE0P19BDT203Hf=P80ADE5
0P0O7al401LG5`80<S8b0P1aLG420:6QX@80QXJ60P2SXj<20861P@80LG5a0P1TI6@20:b/[2T0moOg
0P3dm?@H0?Ogm`l0oooo000=0?ooo`X0moOg0P3dm?@@0?Ogm`80m?Cd0`1RHV8605EEE@80GemO0P1R
HV8205EEE@80FUYJ0P1EEED205YJFP80EEEE0P1jNWX20861P@80UIFE0P2l_;`20<71`@80cLg=0P3B
d]820=?Cd`P0f=SH2P3Ph>040=SHf0/0h>3P2P3Hf=P20=3@d0H0dm?C0P3=cLd60<[:bP80`<300P31
`L420;no_`80`L710P2l_;`20;6a/@80/k>c0P2/[:`20:VYZ@80UIFE0P2IVIT2092@T080SHf=0P21
PH4207UiN@80K6a/0`1EEED204U9B@80=SHf0P15ADD201lO7`@05aLG0P0b<S82075aL@80XJ6Q0P26
QXH20:>SX`80PH610P1aLG4206ATI080[:b/:@3gmoL20?Cdm1P0moOg3`3oool000d0oooo703gmoL2
0?ooo`<0De=C0P1WIfL205EEE@80HV9R0P1WIfL206][J`80HV9R101JFUX205EEE@80HV9R0P1aLG42
08f=S@80UIFE0P2a/K420<71`@80clo?0P3Bd]880=SHf0@0h>3P103Hf=P40>3Ph080f=SH103Ph>02
0=SHf0L0h>3P3P3Hf=P40=?Cd`80cLg=1P3:b/X20<30`0P0_;bl0P2g]kL20;6a/@80Zj^[0P2YZJT2
0:>SX`80VIVI0P2=SHd408J6QP80O7al0P1/K6`305iNGP80?Cdm0P19BDT202LW9`@07alO0P0G5aL2
02<S8`80Kfm_0P2EUID2075aL@80UIFE0P2=SHd20861P@80I6AT0P3Bd]930?Ogm`l0oooo000=0?oo
oa`0moOg0P3oool305=CD`80IfMW0P1EEED2069RHP80IfMW0P1[Jf/2069RHP@0FUYJ0P1EEED2069R
HP80LG5a0P2=SHd209FEU@80/K6a0P31`L420<o?c`80d];B203Hf=P40>3Ph0@0f=SH103Ph>020=SH
f0@0h>3P0P3Hf=P70>3Ph0h0f=SH103Cdm<20<g=c@H0b/[:0P30`<080;bl_080]kNg0P2a/K420:^[
Z`80ZJVY0P2SXj<209VIV@80SHf=1026QXH207alO080K6a/0`1NGUh203dm?@80BDU90P0W9bL401lO
7`805aLG0P0S8b<206m_K`80UIFE0P1aLG4209FEU@80SHf=0P21PH4206ATI080d];B@`3gmoL?0?oo
o`003@3ooolL0?Ogm`80oooo0`1jNWX204m?C`80GUiN101[Jf/205YJFP80HV9R0P1EEED205IFEP80
Jf][0P1RHV82075aL@80R8R80P2EUID20:^[Z`80`L710P3:b/X60=?Cd`H0f=SH103Ph>040=SHf0@0
h>3P103Hf=P20>3Ph140f=SH0P3Cdm<20=SHf0@0dm?C0P3:b/X20=?Cd`80b/[:1038b<P20<71`@80
_kno0P31`L420;Zj^P80/k>c0P2a/K420:^[Z`80ZJVY0P2EUID209VIV@80T92@1026QXH406a/K0<0
GUiN0P19BDT203dm?@809bLW0P0G5aL400/;2`80De=C0P1RHV8207YjNP80NGUi0P2OWil209FEU@80
[Zj^0P2EUIE50?Ogm`l0oooo000=0?oooa`0moOg0P3oool307YjNP80Cdm?0P1NGUh406][J`80FUYJ
0P1RHV8205EEE@80EUIF0P1[Jf/2069RHP80LG5a0P28R8P209FEU@80Zj^[0P31`L420<[:bPH0dm?C
1P3Hf=P40>3Ph0@0f=SH103Ph>040=SHf080h>3P4@3Hf=P20=?Cd`80f=SH103Cdm<20<[:bP80dm?C
0P3:b/X40<S8b080`L710P2o_kl20<71`@80^[Zj0P2c/k<20;6a/@80Zj^[0P2YZJT209FEU@80VIVI
0P2@T90408J6QP@0K6a/0`1NGUh204U9B@80?Cdm0P0W9bL201LG5`@02`/;0P1CDe<2069RHP80NWYj
0P1iNGT209nOW`80UIFE0P2^[Zh209FEUDD0moOg3`3oool000d0oooo703gmoL20?ooo`<0EEEE0P1l
O7`207YjNP80GUiN0P1RHV8205mOG`80GUiN0P1JFUX206IVIP80ADE50P1RHV8207alO0@0SHf=0P2Y
ZJT20;no_`80b/[:0P3?cll20=?Cd`H0f=SH103Ph>020=SHf0H0h>3P0P3Hf=P20>3Ph0@0f=SH0`3P
h>0D0=SHf080b/[:0P3@d=020<g=c@@0b/[:0P30`<020<S8b0@0_;bl102c/k<20;6a/@80Zj^[0P2Y
ZJT209FEU@80XJ6Q0P2=SHd208R8R080LG5a0P1[Jf/205YJFP<0BDU90P1EEED2038b<P805aLG0P0;
2`/202<S8`802`/;0P1OGel206][J`80K6a/0P1TI6@409FEU@80WinO0P3MgMe50?Ogm`l0oooo000=
0?oooa`0moOg0P3oool305EEE@80O7al0P1jNWX205iNGP80HV9R0P1OGel205iNGP80FUYJ0P1VIVH2
04E5A@80HV9R0P1lO7`408f=S@80ZJVY0P2o_kl20<[:bP80clo?0P3Cdm<60=SHf0@0h>3P0P3Hf=P6
0>3Ph080f=SH0P3Ph>040=SHf0<0h>3P503Hf=P20<[:bP80d=3@0P3=cLd40<[:bP80`<300P38b<P4
0;bl_0@0/k>c0P2a/K420:^[Z`80ZJVY0P2EUID20:6QX@80SHf=0P28R8P2075aL@80Jf][0P1JFUX3
04U9B@80EEEE0P0b<S8201LG5`802`/;0P0S8b<200/;2`80GemO0P1[Jf/206a/K080I6AT102EUID2
09nOW`80gMgMA@3gmoL?0?ooo`003@3oool40?Ogm`80m?Cd0P3gmoL20?Cdm1@0moOg0`3Ph>0207al
O0@0EUIF101EEED205ADE080FUYJ0P1EEED4069RHP80NWYj0P2=SHd209nOW`80Zj^[0P2o_kl20<[:
bP80clo?203Hf=P40>3Ph080f=SH0P3Ph>020=SHf080h>3P1P3Hf=P20>3Ph1D0f=SH0P3@d=040=?C
d`H0b/[:0P30`<020<S8b0@0_;bl0P2c/k<60;6a/@80ZJVY0P2OWil20:>SX`80R8R80P1lO7`4075a
L@80K6a/0`1FEUH203dm?@80<S8b100G5aL202<S8`805aLG101[Jf/2075aL@80IVIV0P2EUID209nO
W`80Zj^[A`3gmoL?0?ooo`003@3oool40?Ogm`80m?Cd0P3gmoL20?Cdm1@0moOg0`3Ph>0207alO0@0
EUIF101EEED205ADE080FUYJ0P1EEED4069RHP80NWYj0P2=SHd209nOW`80Zj^[0P2o_kl20<[:bP80
clo?203Hf=P40>3Ph080f=SH0P3Ph>020=SHf080h>3P1P3Hf=P20>3Ph1D0f=SH0P3@d=040=?Cd`H0
b/[:0P30`<020<S8b0@0_;bl0P2c/k<60;6a/@80ZJVY0P2OWil20:>SX`80R8R80P1lO7`4075aL@80
K6a/0`1FEUH203dm?@80<S8b100G5aL202<S8`805aLG101[Jf/2075aL@80IVIV0P2EUID209nOW`80
Zj^[A`3gmoL?0?ooo`003@3ooolN0?Ogm`<0oooo0P1RHV8205IFEP80EEEE0P19BDT205ADE080Cdm?
0P19BDT205IFEP80HV9R0P1/K6`208J6QP80SHf=0P2SXj<20:j^[P80_kno0P3:b/X20=?Cd`80d=3@
3P3Hf=P80>3Ph0@0f=SH0`3Ph>0@0=SHf080d=3@1P3Cdm<20<[:bP80dm?C0P3:b/X40<S8b080`/;2
0P2l_;`20;>c/`80/K6a0P2[Zj/20;6a/@@0ZJVY0P2EUID408R8R080O7al0P1RHV8205iNGP<0?Cdm
0P0b<S8401lO7`802`/;0P0J6QX201LG5`80N7Qh0P1[Jf/206IVIP80I6AT0P2OWil20;Bd]080c/k>
A`3gmoL?0?ooo`003@3ooolN0?Ogm`<0oooo0P1RHV8205IFEP80EEEE0P19BDT205ADE080Cdm?0P19
BDT205IFEP80HV9R0P1/K6`208J6QP80SHf=0P2SXj<20:j^[P80_kno0P3:b/X20=?Cd`80d=3@3P3H
f=P80>3Ph0@0f=SH0`3Ph>0@0=SHf080d=3@1P3Cdm<20<[:bP80dm?C0P3:b/X40<S8b080`/;20P2l
_;`20;>c/`80/K6a0P2[Zj/20;6a/@@0ZJVY0P2EUID408R8R080O7al0P1RHV8205iNGP<0?Cdm0P0b
<S8401lO7`802`/;0P0J6QX201LG5`80N7Qh0P1[Jf/206IVIP80I6AT0P2OWil20;Bd]080c/k>A`3g
moL?0?ooo`003@3ooolQ0?Ogm`80^[Zj0P1OGel405EEE@80E5AD101EEED204m?C`80EEEE0P1/K6`2
07alO080SHf=0P2OWil20;Jf]P80`L710P3:b/X40=?Cd`H0f=SH0P3Ph>020=SHf0X0h>3P0P3Hf=P2
0>3Ph0D0f=SH0P3Ph>0>0=SHf080dm?C0P3Hf=P20=?Cd`80d=3@0P3=cLd40<[:bP@0b<S8102l_;`2
0;Jf]P@0/K6a0P2YZJT20:^[Z`@0VIVI0P2=SHd207alO080NWYj0P1aLG4205iNGP<0=SHf0P0b<S82
01lO7`808b<S0P0D51@401lO7`80O7al0P28R8P205iNGP80NGUi0P2EUID20;no_`@0moOg0P3dm?A3
0?Ogm`l0oooo000=0?ooob40moOg0P2j^[X205mOG`@0EEEE0P1DE5@405EEE@80Cdm?0P1EEED206a/
K080O7al0P2=SHd209nOW`80][Jf0P31`L420<[:bP@0dm?C1P3Hf=P20>3Ph080f=SH2P3Ph>020=SH
f080h>3P1@3Hf=P20>3Ph0h0f=SH0P3Cdm<20=SHf080dm?C0P3@d=020<g=c@@0b/[:1038b<P40;bl
_080][Jf102a/K420:VYZ@80Zj^[102IVIT208f=S@80O7al0P1jNWX2075aL@80GUiN0`0f=SH2038b
<P807alO0P0S8b<201@D50@07alO0P1lO7`208R8R080GUiN0P1iNGT209FEU@80_kno103gmoL20?Cd
m4<0moOg3`3oool000d0oooo0P3gmoL20?Cdm1d0moOg0P3dm?@206MWI`@0BDU9101?Cdl205EEE@80
EUIF0P1?Cdl206][J`80QXJ60P2EUID20:VYZ@80/k>c0P38b<P20<[:bP80cLg=0P3?cll20=?Cd`X0
f=SH0P3Ph>020=SHf080h>3P6`3Hf=P40=?Cd`80cLg=0P3Cdm<20=3@d0H0b/[:1031`L420;no_`80
^[Zj102a/K420:^[Z`@0Xj>S102=SHd207alO080LG5a0P1RHV8205EEE@<0=SHf0P0b<S8202<S8`80
7alO100Z:RX201LG5`80K6a/0P26QXH206a/K080S8b<0P2YZJT20=7AdDT0moOg3`3oool000d0oooo
0P3gmoL20?Cdm1d0moOg0P3dm?@206MWI`@0BDU9101?Cdl205EEE@80EUIF0P1?Cdl206][J`80QXJ6
0P2EUID20:VYZ@80/k>c0P38b<P20<[:bP80cLg=0P3?cll20=?Cd`X0f=SH0P3Ph>020=SHf080h>3P
6`3Hf=P40=?Cd`80cLg=0P3Cdm<20=3@d0H0b/[:1031`L420;no_`80^[Zj102a/K420:^[Z`@0Xj>S
102=SHd207alO080LG5a0P1RHV8205EEE@<0=SHf0P0b<S8202<S8`807alO100Z:RX201LG5`80K6a/
0P26QXH206a/K080S8b<0P2YZJT20=7AdDT0moOg3`3oool000d0oooo8`3gmoL207alO080IfMW0P1?
Cdl205YJFP80EUIF0P1?Cdl205IFEP80FUYJ0P1[Jf/2075aL@80UIFE0P2^[Zh40<71`@80b/[:103C
dm<:0=SHf0@0h>3P7@3Hf=P60=?Cd`@0cLg=0P3:b/X40<S8b080b/[:0P31`L420;no_`80^[Zj0P2g
]kL40;6a/@@0[:b/0P2IVIT208f=S@80R8R80P1iNGT206a/K080GUiN0P19BDT503Hf=P80:RXZ0P0O
7al202XZ:P805aLG0P0;2`/206][J`80LG5a0P1/K6`208f=S@80/K6a0P3/k>a90?Ogm`l0oooo000=
0?ooob<0moOg0P1lO7`206MWI`80Cdm?0P1JFUX205IFEP80Cdm?0P1FEUH205YJFP80Jf][0P1aLG42
09FEU@80[Zj^1031`L420<[:bP@0dm?C2P3Hf=P40>3Ph1d0f=SH1P3Cdm<40<g=c@80b/[:1038b<P2
0<[:bP80`L710P2o_kl20;Zj^P80]kNg102a/K440:b/[080VIVI0P2=SHd208R8R080NGUi0P1/K6`2
05iNGP80BDU91@0f=SH202XZ:P807alO0P0Z:RX201LG5`802`/;0P1[Jf/2075aL@80K6a/0P2=SHd2
0;6a/@80k>c/B@3gmoL?0?ooo`003@3ooolS0?Ogm`80oooo0P2j^[X207alO0H0Jf][101FEUH206][
J`80PH610P2=SHd20:>SX`80_;bl0P38b<P40<[:bP80dm?C0P3?cll20=?Cd`h0f=SH0P3Ph>0=0=SH
f080dm?C0P3Hf=P80=?Cd`80f=SH0P3@d=020=?Cd`P0b<S80P30`<020<71`@80_kno0P2j^[X20;>c
/`80^[Zj1P2YZJT408f=S@80O7al0P1jNWX2069RHP80EEEE0P15ADD304U9B@@0<S8b0P0O7al201LG
5`801PH60P0f=SH208R8R080LG5a0P1kNg/209VIV@80[:b/0P3gmoL20?Cdm4L0moOg3`3oool000d0
oooo8`3gmoL20?ooo`80^[Zj0P1lO7`606][J`@0EUIF0P1[Jf/20861P@80SHf=0P2SXj<20;bl_080
b<S8103:b/X20=?Cd`80clo?0P3Cdm<>0=SHf080h>3P3@3Hf=P20=?Cd`80f=SH203Cdm<20=SHf080
d=3@0P3Cdm<80<S8b080`<300P31`L420;no_`80^[Zj0P2c/k<20;Zj^PH0ZJVY102=SHd207alO080
NWYj0P1RHV8205EEE@80ADE50`19BDT4038b<P807alO0P0G5aL200H61P80=SHf0P28R8P2075aL@80
Ng]k0P2IVIT20:b/[080moOg0P3dm?A70?Ogm`l0oooo000=0?ooo`80moOg0P3dm?@B0?Ogm`80m?Cd
2`3gmoL40?ooo`80jNWY0P1_Kfl206][J`80FUYJ0P1RHV8205mOG`80HV9R0P1iNGT209FEU@80WinO
0P2c/k<20<S8b0@0b/[:103Cdm<40=SHf080dm?C7@3Hf=P60=?Cd`80f=SH0P3Cdm<80<[:bP80b<S8
0P3:b/X20<;2`PH0_;bl0P2j^[X20;6a/@80Xj>S0P2[Zj/409FEU@80SHf=0P1iNGT2065QH@80EEEE
0P1JFUX204E5A@D0=SHf0P0S8b<202XZ:P8030`<0P061PH207YjNP80O7al0P1TI6@20861P@80TI6A
0P3?clm;0?Ogm`l0oooo000=0?ooo`80moOg0P3dm?@B0?Ogm`80m?Cd2`3gmoL40?ooo`80jNWY0P1_
Kfl206][J`80FUYJ0P1RHV8205mOG`80HV9R0P1iNGT209FEU@80WinO0P2c/k<20<S8b0@0b/[:103C
dm<40=SHf080dm?C7@3Hf=P60=?Cd`80f=SH0P3Cdm<80<[:bP80b<S80P3:b/X20<;2`PH0_;bl0P2j
^[X20;6a/@80Xj>S0P2[Zj/409FEU@80SHf=0P1iNGT2065QH@80EEEE0P1JFUX204E5A@D0=SHf0P0S
8b<202XZ:P8030`<0P061PH207YjNP80O7al0P1TI6@20861P@80TI6A0P3?clm;0?Ogm`l0oooo000=
0?ooobL0moOg0P3oool20:2PX080EEEE0P1OGel204m?C`@0HV9R0P1jNWX208f=S@80Xj>S0P2f][H2
0<71`@80`<30103:b/X20=?Cd`@0cLg=103Cdm<60=SHf080dm?C1P3Hf=P20=?Cd`<0f=SH0P3?cll2
0=?Cd`80d];B1P3Cdm<20<g=c@P0b/[:0P38b<P20<[:bP@0b<S80P30`<060;bl_0@0/k>c0P2[Zj/2
0:>SX`80ZJVY0P2=SHd207alO080K6a/0P1TI6@205iNGP@0FUYJ1@0b<S8202XZ:P805aLG0P0;2`/2
08R8R080N7Qh0P1/K6`206ATI080SHf=0P2h^;P20>WYj@80moOg103dm?A50?Ogm`l0oooo000=0?oo
obL0moOg0P3oool20:2PX080EEEE0P1OGel204m?C`@0HV9R0P1jNWX208f=S@80Xj>S0P2f][H20<71
`@80`<30103:b/X20=?Cd`@0cLg=103Cdm<60=SHf080dm?C1P3Hf=P20=?Cd`<0f=SH0P3?cll20=?C
d`80d];B1P3Cdm<20<g=c@P0b/[:0P38b<P20<[:bP@0b<S80P30`<060;bl_0@0/k>c0P2[Zj/20:>S
X`80ZJVY0P2=SHd207alO080K6a/0P1TI6@205iNGP@0FUYJ1@0b<S8202XZ:P805aLG0P0;2`/208R8
R080N7Qh0P1/K6`206ATI080SHf=0P2h^;P20>WYj@80moOg103dm?A50?Ogm`l0oooo000=0?ooobL0
moOg0P3oool20<_;b`80?Cdm0P1JFUX207YjNP80EUIF101jNWX208f=S@80WinO0P2c/k<20;no_`80
alO70P3:b/X20<S8b080b/[:103Cdm<20=SHf080dm?C0P3Bd]820=SHf080dm?C2P3Hf=P50=?Cd`80
f=SH0P3Cdm<20<[:bP80dm?C0P3:b/X20=?Cd`@0b/[:0P38b<P40<[:bP@0b<S80P2o_kl20<;2`P@0
^[Zj0P2f][H20;6a/@80[:b/0P2EUID20:>SX`80VIVI0P28R8P207alO080LG5a0P1/K6`205YJFP80
BDU90P1?Cdl306][J`807alO0P0G5aL201XJ6P80EUIF0P1EEED207YjNP80K6a/0P1iNGT209FEU@80
`L710P3dm?@20?Ogm`80m?Cd0P3ooom50?Ogm`l0oooo000=0?ooobL0moOg0P3oool20<_;b`80?Cdm
0P1JFUX207YjNP80EUIF101jNWX208f=S@80WinO0P2c/k<20;no_`80alO70P3:b/X20<S8b080b/[:
103Cdm<20=SHf080dm?C0P3Bd]820=SHf080dm?C2P3Hf=P50=?Cd`80f=SH0P3Cdm<20<[:bP80dm?C
0P3:b/X20=?Cd`@0b/[:0P38b<P40<[:bP@0b<S80P2o_kl20<;2`P@0^[Zj0P2f][H20;6a/@80[:b/
0P2EUID20:>SX`80VIVI0P28R8P207alO080LG5a0P1/K6`205YJFP80BDU90P1?Cdl306][J`807alO
0P0G5aL201XJ6P80EUIF0P1EEED207YjNP80K6a/0P1iNGT209FEU@80`L710P3dm?@20?Ogm`80m?Cd
0P3ooom50?Ogm`l0oooo000=0?ooobL0moOg0P3oool20;Bd]080LG5a101EEED205mOG`80O7al0P1j
NWX208f=S@80Xj>S0P2c/k<20;Jf]P80`L710P3:b/X20<S8b080b/[:0P3@d=020<[:bP80f=SH0P3=
cLd>0=?Cd`80f=SH1@3@d=060<[:bP80`<300P3:b/X:0<S8b080b/[:1038b<P40;Zj^P80_;bl102c
/k<20;6a/@80ZJVY102EUID208R8R080NGUi0P1aLG4206ATI0@0FUYJ101EEED303Hf=P80BDU90P0f
=SH204U9B@80ADE50P1lO7`2075aL@80QXJ60P2=SHd20:j^[P80_Kfm0P3gmoL20?ooodT0moOg3`3o
ool000d0oooo9`3gmoL20?ooo`80];Bd0P1aLG4405EEE@80GemO0P1lO7`207YjNP80SHf=0P2SXj<2
0;>c/`80][Jf0P31`L420<[:bP80b<S80P3:b/X20=3@d080b/[:0P3Hf=P20<g=c@h0dm?C0P3Hf=P5
0=3@d0H0b/[:0P30`<020<[:bPX0b<S80P3:b/X40<S8b0@0^[Zj0P2l_;`40;>c/`80/K6a0P2YZJT4
09FEU@80R8R80P1iNGT2075aL@80I6AT101JFUX405EEE@<0=SHf0P19BDT203Hf=P80BDU90P15ADD2
07alO080LG5a0P26QXH208f=S@80[Zj^0P2m_Kd20?Ogm`80ooooB@3gmoL?0?ooo`003@3ooolW0?Og
m`80oooo0P2VYZH209nOW`80ADE50P1DE5@205IFEP80GUiN0P1aLG4208J6QP80UIFE0P2OWil20;Rh
^080_;bl0P31`L420<S8b080`<30103@d=040<o?c`80cLg=0P3:b/X20=3@d0@0dm?C0P3Hf=P20<g=
c@80clo?1@3:b/X20<S8b080`<30102l_;`20;fm_@@0b<S80P32`/820<30`080`/;20P2m_Kd40;bl
_080/K6a0P2g]kL20;>c/`@0Zj^[0P2SXj<409FEU@80SHf=0P28R8P207UiN@80NWYj0P1/K6`404m?
C`@0BDU90`0l?3`204E5A@80<S8b0P21PH4206][J`80LG5a0P1/K6`20:>SX`80UIFE0P2o_kl60?Og
m`80m?Cd103gmoL20?ooob<0moOg0P3ooolL0?Ogm`l0oooo000=0?ooobL0moOg0P3oool20:JVYP80
WinO0P15ADD205ADE080EUIF0P1NGUh2075aL@80QXJ60P2EUID209nOW`80^;Rh0P2l_;`20<71`@80
b<S80P30`<040=3@d0@0clo?0P3=cLd20<[:bP80d=3@103Cdm<20=SHf080cLg=0P3?cll50<[:bP80
b<S80P30`<040;bl_080_Kfm1038b<P20<;2`P80`<300P32`/820;fm_@@0_;bl0P2a/K420;Ng]`80
/k>c102[Zj/20:>SX`@0UIFE0P2=SHd208R8R080NGUi0P1jNWX206a/K0@0Cdm?1019BDT303`l?080
ADE50P0b<S820861P@80Jf][0P1aLG4206a/K080Xj>S0P2EUID20;no_`H0moOg0P3dm?@40?Ogm`80
oooo8`3gmoL20?oooa`0moOg3`3oool000d0oooo:@3gmoL20>3Ph080bl_;0P0b<S8204E5A@80K6a/
0P1EEED2075aL@80PH610P2=SHd20:^[Z`80/k>c0P2f][H20;bl_0@0`<300P38b<P20<[:bP80alO7
0P3:b/X20<o?c`H0b/[:0P3=cLd20<[:bP80b<S81@3:b/X20<;2`P80_;bl0P2e]KD40;Ng]`80^[Zj
0P2m_Kd80;Fe]@80[:b/0P2a/K420;Ng]`80ZJVY0P2a/K440:VYZ@80WinO0P2QXJ4209FEU@80R8R8
1026QXH207YjNP80LG5a0P1NGUh205YJFP80EUIF0P1?Cdl206MWI`<0EUIF0P19BDT206MWI`80R8R8
0P1_Kfl207alO080SHf=0P2YZJT20;no_`80_Kfm0P3dm?@60?Ogm`80oooo6P3gmoL20?Cdm2T0moOg
3`3oool000d0oooo:@3gmoL20>3Ph080bl_;0P0b<S8204E5A@80K6a/0P1EEED2075aL@80PH610P2=
SHd20:^[Z`80/k>c0P2f][H20;bl_0@0`<300P38b<P20<[:bP80alO70P3:b/X20<o?c`H0b/[:0P3=
cLd20<[:bP80b<S81@3:b/X20<;2`P80_;bl0P2e]KD40;Ng]`80^[Zj0P2m_Kd80;Fe]@80[:b/0P2a
/K420;Ng]`80ZJVY0P2a/K440:VYZ@80WinO0P2QXJ4209FEU@80R8R81026QXH207YjNP80LG5a0P1N
GUh205YJFP80EUIF0P1?Cdl206MWI`<0EUIF0P19BDT206MWI`80R8R80P1_Kfl207alO080SHf=0P2Y
ZJT20;no_`80_Kfm0P3dm?@60?Ogm`80oooo6P3gmoL20?Cdm2T0moOg3`3oool000d0oooo:`3gmoL2
0:JVYP80NWYj0P1FEUH205YJFP80Jf][0P1RHV82075aL@80O7al0P2EUID20:^[Z`80_kno0P2f][H2
0;Rh^0@0_;bl203:b/X20<O7a`P0`L710P2l_;`20;Jf]P<0/K6a102c/k<40:VYZ@H0Xj>S0P2QXJ42
0:NWY`80Xj>S102QXJ4209FEU@P0VIVI0P2@T90208f=S@80UIFE0P2=SHd208R8R080PH610P1/K6`2
069RHP80Kfm_0P1[Jf/205ADE0@0Jf][0P19BDT3069RHP@0K6a/0P1aLG4206a/K080SHf=0P26QXH2
0;>c/`80_kno0P3_knm?0?Ogm`l0oooo000=0?ooob/0moOg0P2VYZH207YjNP80EUIF0P1JFUX206][
J`80HV9R0P1aLG4207alO080UIFE0P2[Zj/20;no_`80][Jf0P2h^;P40;bl_0P0b/[:0P37alL80<71
`@80_;bl0P2f][H30;6a/@@0/k>c102YZJT60:>SX`80XJ6Q0P2WYjL20:>SX`@0XJ6Q0P2EUID809VI
V@80T92@0P2=SHd209FEU@80SHf=0P28R8P20861P@80K6a/0P1RHV8206m_K`80Jf][0P1DE5@406][
J`80BDU90`1RHV8406a/K080LG5a0P1/K6`208f=S@80QXJ60P2c/k<20;no_`80kno_C`3gmoL?0?oo
o`003@3oool]0?Ogm`80[Zj^0P1_Kfl205YJFP80HV9R0P1[Jf/207YjNP80R8R80P1nOWh208f=S@80
UIFE0P2c/k<20;Rh^080`L710P38b<P20<O7a`H0`L710P2o_kl40;>c/`80ZJVY0P2c/k<20;no_`80
Zj^[0`2/[:`20:VYZ@80Zj^[0P2EUID209nOW`80T92@0P2IVIT208f=S@80Xj>S0P2=SHd209VIV@80
PH610P2=SHd40861P@80SHf=1026QXH408R8R080O7al0P2=SHd209FEU@80PH610P26QXH207YjNP80
O7al101RHV8206m_K`80O7al0P1JFUX303dm?@80EEEE0P21PH4208J6QP80PH610P2=SHd20:b/[080
^;Rh0P2m_Kd>0?Ogm`80m?Cd8`3gmoL20?oooa`0moOg3`3oool000d0oooo;@3gmoL20:j^[P80Kfm_
0P1JFUX2069RHP80Jf][0P1jNWX208R8R080OWin0P2=SHd209FEU@80/k>c0P2h^;P20<71`@80b<S8
0P37alL60<71`@80_kno102c/k<20:VYZ@80/k>c0P2o_kl20:^[Z`<0[:b/0P2YZJT20:^[Z`80UIFE
0P2OWil2092@T080VIVI0P2=SHd20:>SX`80SHf=0P2IVIT20861P@80SHf=1021PH4208f=S@@0QXJ6
1028R8P207alO080SHf=0P2EUID20861P@80QXJ60P1jNWX207alO0@0HV9R0P1_Kfl207alO080FUYJ
0`0m?Cd205EEE@80PH610P26QXH20861P@80SHf=0P2/[:`20;Rh^080_Kfm3P3gmoL20?Cdm2<0moOg
0P3ooolL0?Ogm`l0oooo000=0?ooobl0moOg0P3YjNT208V9R@80Kfm_0P1FEUH2075aL@80NWYj0P1R
HV8208f=S@80WinO0P2m_Kd60<W9b@@0`L710P2h^;P20;Jf]P80ZJVY0P2/[:`40:^[Z`80ZJVY0P2[
Zj/50:VYZ@@0UIFE102=SHd208R8R080SHf=0P28R8P207UiN@80R8R80P26QXH2075aL@80K6a/0P28
R8P2075aL@80QXJ60P1aLG4207UiN@80O7al0P1jNWX207alO080HV9R0P1[Jf/206m_K`80NGUi0P1_
Kfl2075aL@80Kfm_0P1aLG4205EEE@80FUYJ0P1WIfL306a/K080LG5a101jNWX209FEU@@0^;Rh0P2O
Wil80?Ogm`80m?Cd8P3gmoL20?Cdm2D0moOg3`3oool000d0oooo;`3gmoL20>WYj@80RHV90P1_Kfl2
05IFEP80LG5a0P1jNWX2069RHP80SHf=0P2OWil20;fm_@H0bLW91031`L420;Rh^080][Jf0P2YZJT2
0:b/[0@0Zj^[0P2YZJT20:^[Z`D0ZJVY102EUID408f=S@80R8R80P2=SHd208R8R080NGUi0P28R8P2
08J6QP80LG5a0P1/K6`208R8R080LG5a0P26QXH2075aL@80NGUi0P1lO7`207YjNP80O7al0P1RHV82
06][J`80Kfm_0P1iNGT206m_K`80LG5a0P1_Kfl2075aL@80EEEE0P1JFUX206MWI`<0K6a/0P1aLG44
07YjNP80UIFE102h^;P209nOW`P0moOg0P3dm?@R0?Ogm`80m?Cd9@3gmoL?0?ooo`003@3oool>0?Og
m`80m?Cd0P3gmoL20?Cdm1d0moOg0P29RHT207inOP80O7al0P1eMGD208J6QP80YZJV0P2ZZZX209fM
W@80][Jf0P2ZZZX20;Jf]P@0_Kfm0P2f][H20;>c/`80Zj^[0P2YZJT20:^[Z`80UIFE0P2OWil20:VY
Z@80WinO0P2EUID309nOW`80UIFE0P2@T90208J6QP80R8R80P1aLG4209FEU@80O7al0P2EUID208J6
QP80O7al0P2=SHd207YjNP80K6a/0P2EUID207YjNP80R8R80P1lO7`207YjNP80PH610P26QXH205mO
G`80Jf][0P1jNWX207QhN080IfMW0P1_Kfl207alO080I6AT0P1/K6`206ATI080K6a/0`1TI6@2075a
L@80QXJ60P2[Zj/20;Bd]080[:b/0P2^[Zh20=;BdPP0moOg0P3ooom90?Ogm`l0oooo000=0?ooo`h0
moOg0P3dm?@20?Ogm`80m?Cd7@3gmoL208V9R@80OWin0P1lO7`207EeM@80QXJ60P2VYZH20:ZZZP80
WIfM0P2f][H20:ZZZP80][Jf102m_Kd20;Jf]P80/k>c0P2[Zj/20:VYZ@80Zj^[0P2EUID209nOW`80
ZJVY0P2OWil209FEU@<0WinO0P2EUID2092@T080QXJ60P28R8P2075aL@80UIFE0P1lO7`209FEU@80
QXJ60P1lO7`208f=S@80NWYj0P1/K6`209FEU@80NWYj0P28R8P207alO080NWYj0P21PH4208J6QP80
GemO0P1[Jf/207YjNP80N7Qh0P1WIfL206m_K`80O7al0P1TI6@206a/K080I6AT0P1/K6`306ATI080
LG5a0P26QXH20:^[Z`80];Bd0P2/[:`20:j^[P80d];B203gmoL20?ooodT0moOg3`3oool000d0oooo
103gmoL20?Cdm2/0moOg0P3oool206m_K`80Ph>30P1eMGD206][J`80PH61102=SHd209fMW@80][Jf
0P2h^;P20;>c/`80[:b/0P2[Zj/20:j^[PH0WinO0P2=SHd209FEU@80SHf=0P2EUID208f=S@<0UIFE
0P28R8P209FEU@80NWYj0P1aLG4207inOP80I6AT0P21PH4207YjNP80SHf=0P1aLG4207alO080NWYj
0P1lO7`209FEU@80HV9R101aLG4208R8R080NWYj101[Jf/205YJFP80EUIF0P19BDT204m?C`80HV9R
101EEED405IFEP80I6AT0`1kNg/209FEU@80Zj^[0P37alL209fMW@80[Zj^0P26QXIE0?Ogm`l0oooo
000=0?ooo`@0moOg0P3dm?@[0?Ogm`80oooo0P1_Kfl208>3P`80MGEe0P1[Jf/20861P@@0SHf=0P2M
WId20;Jf]P80^;Rh0P2c/k<20:b/[080Zj^[0P2^[Zh609nOW`80SHf=0P2EUID208f=S@80UIFE0P2=
SHd309FEU@80R8R80P2EUID207YjNP80LG5a0P1nOWh206ATI080PH610P1jNWX208f=S@80LG5a0P1l
O7`207YjNP80O7al0P2EUID2069RHP@0LG5a0P28R8P207YjNP@0Jf][0P1JFUX205IFEP80BDU90P1?
Cdl2069RHP@0EEEE101FEUH206ATI0<0Ng]k0P2EUID20:^[Z`80alO70P2MWId20:j^[P80QXJ6E@3g
moL?0?ooo`003@3ooolc0?Ogm`80oooo0P2BTY8207inOP80O7al0P2PX:0209nOW`80YZJV202h^;P8
09nOW`80UIFE0P2OWil409FEU@@0R8R80P2EUID308J6QP80NWYj0P1lO7`206ATI0@0PH610P1RHV82
04U9B@80O7al0P1JFUX208J6QP80NWYj101lO7`205iNGP80K6a/0P1jNWX204E5A@80BDU90P1VIVH2
05iNGP80FUYJ0P1NGUh206IVIP80I6AT0P1/K6`406ATI080EEEE0P1VIVH206a/K080[:b/0`2EUID2
0:j^[P80_Kfm0P1RHV8209fMW@80PH610P3AdM420?ooo`h0moOg0P3dm?A30?Ogm`l0oooo000=0?oo
oc<0moOg0P3oool209:BTP80OWin0P1lO7`20:2PX080WinO0P2VYZH80;Rh^0P0WinO0P2EUID209nO
W`@0UIFE1028R8P209FEU@<0QXJ60P1jNWX207alO080I6AT1021PH42069RHP80BDU90P1lO7`205YJ
FP80QXJ60P1jNWX407alO080GUiN0P1/K6`207YjNP80ADE50P19BDT206IVIP80GUiN0P1JFUX205iN
GP80IVIV0P1TI6@206a/K0@0I6AT0P1EEED206IVIP80K6a/0P2/[:`309FEU@80[Zj^0P2m_Kd2069R
HP80WIfM0P21PH420=7Ad@80oooo3P3gmoL20?Cdm4<0moOg3`3oool000d0oooo=@3gmoL20:VYZ@80
Ph>30P1OGel207EeM@80K6a/0P21PH420:VYZ@80];Bd0P2f][H20;Rh^080YZJV102EUID208f=S@@0
UIFE0P2=SHd20861P@80QXJ60P2=SHd207alO0D0QXJ60P1RHV8209FEU@80NWYj0P1RHV8209FEU@80
HV9R0P1JFUX207alO0@0HV9R0P1[Jf/205YJFP80GUiN0P1DE5@204E5A@@0EEEE0P1VIVH205EEE@80
EUIF0P1TI6@205iNGP80EEEE0P1ADE4205iNGP80LG5a1026QXH209nOW`80UIFE0`2o_kl20;Rh^080
PH610P1jNWX209fMW@80PH612P3gmoL20?Cdm0@0moOg0P3dm?@L0?Ogm`80m?Cd103gmoL30?ooob00
moOg3`3oool000d0oooo=@3gmoL20:VYZ@80Ph>30P1OGel207EeM@80K6a/0P21PH420:VYZ@80];Bd
0P2f][H20;Rh^080YZJV102EUID208f=S@@0UIFE0P2=SHd20861P@80QXJ60P2=SHd207alO0D0QXJ6
0P1RHV8209FEU@80NWYj0P1RHV8209FEU@80HV9R0P1JFUX207alO0@0HV9R0P1[Jf/205YJFP80GUiN
0P1DE5@204E5A@@0EEEE0P1VIVH205EEE@80EUIF0P1TI6@205iNGP80EEEE0P1ADE4205iNGP80LG5a
1026QXH209nOW`80UIFE0`2o_kl20;Rh^080PH610P1jNWX209fMW@80PH612P3gmoL20?Cdm0@0moOg
0P3dm?@L0?Ogm`80m?Cd103gmoL30?ooob00moOg3`3oool000d0oooo=@3gmoL20?ooo`80E5AD0P1j
NWX209fMW@80OWin0P21PH4209:BTP80[:b/0P2d];@20:^[Z`80YZJV0P1lO7`208R8R080PH61102E
UID208R8R080MGEe0P28R8P208J6QP80O7al0`2=SHd207alO080QXJ60P1JFUX2075aL@80Kfm_0P1R
HV8207YjNP80FUYJ0P1RHV8206ATI080FUYJ0P1OGel205YJFP80Cdm?1P1EEED204U9B@80ADE50P1E
EED205IFEP80EEEE101DE5@2069RHPP0NWYj0P2OWil20;Bd]0D0N7Qh0P21PH420:JVYP80UIFE0P3Y
jNT40?Cdm0@0moOg0P3dm?@40?Ogm`80m?Cd103gmoL20?ooo`P0moOg0P3ooolg0?Ogm`l0oooo000=
0?ooocD0moOg0P3oool205ADE080NWYj0P2MWId207inOP80PH610P2BTY820:b/[080];Bd0P2[Zj/2
0:JVYP80O7al0P28R8P20861P@@0UIFE0P28R8P207EeM@80R8R80P26QXH207alO0<0SHf=0P1lO7`2
08J6QP80FUYJ0P1aLG4206m_K`80HV9R0P1jNWX205YJFP80HV9R0P1TI6@205YJFP80GemO0P1JFUX2
04m?C`H0EEEE0P19BDT204E5A@80EEEE0P1FEUH205EEE@@0E5AD0P1RHV8807YjNP80WinO0P2d];@5
07QhN080PH610P2VYZH209FEU@80jNWY103dm?@40?Ogm`80m?Cd103gmoL20?Cdm0@0moOg0P3oool8
0?Ogm`80oooo=`3gmoL?0?ooo`003@3oooli0?Ogm`80NWYj0P19BDT209:BTP80VYZJ0P2MWId209:B
TP@0^;Rh0P2/[:`207YjNP80SHf=101lO7`208J6QP80NWYj0P1_Kfl40861P@80Kfm_0`1lO7`206m_
K`80O7al0P1JFUX207YjNP80K6a/0P1[Jf/204m?C`80BDU90P1jNWX204m?C`80EUIF0P1JFUX205IF
EP80E5AD1019BDT203dm?@80=SHf1P15ADD205ADE080K6a/0P1JFUX2069RHP80PH610P2OWil209FE
U@80`L710P2d];@209fMW@<0QXJ60P1[Jf/209nOW`80Jf][0P3YjNT40?ooo`80m?CdD`3gmoL?0?oo
o`003@3oooli0?Ogm`80NWYj0P19BDT209:BTP80VYZJ0P2MWId209:BTP@0^;Rh0P2/[:`207YjNP80
SHf=101lO7`208J6QP80NWYj0P1_Kfl40861P@80Kfm_0`1lO7`206m_K`80O7al0P1JFUX207YjNP80
K6a/0P1[Jf/204m?C`80BDU90P1jNWX204m?C`80EUIF0P1JFUX205IFEP80E5AD1019BDT203dm?@80
=SHf1P15ADD205ADE080K6a/0P1JFUX2069RHP80PH610P2OWil209FEU@80`L710P2d];@209fMW@<0
QXJ60P1[Jf/209nOW`80Jf][0P3YjNT40?ooo`80m?CdD`3gmoL?0?ooo`003@3ooole0?Ogm`80m?Cd
0P3gmoL20?ooo`80OWin0P15ADD2079bLP80Ph>30P2BTY820;Bd]080_Kfm0P2/[:`207YjNP80Jf][
0P2BTY8207alO080SHf=0P2BTY8208J6QP80Jf][0P21PH4207YjNP<0HV9R101lO7`2069RHP80LG5a
0P1jNWX206m_K`80IfMW0P0b<S8204U9B@80EUIF0P1jNWX405EEE@80?Cdm0P1EEED204E5A@80?Cdm
0P0b<S8203Hf=P@0<S8b0P19BDT205iNGP80PH610P2EUID208R8R080UIFE0P2d];@209:BTP80GemO
0P1gMgL308J6QP80PH610P1/K6`20:VYZ@`0moOg0P3dm?@20?Ogm`80oooo5P3gmoL20?Cdm1<0moOg
0P3ooolL0?Ogm`l0oooo000=0?ooocD0moOg0P3dm?@20?Ogm`80oooo0P1nOWh204E5A@80LW9b0P23
Ph<209:BTP80];Bd0P2m_Kd20:b/[080NWYj0P1[Jf/209:BTP80O7al0P2=SHd209:BTP80QXJ60P1[
Jf/20861P@80NWYj0`1RHV8407alO080HV9R0P1aLG4207YjNP80Kfm_0P1WIfL2038b<P80BDU90P1F
EUH207YjNP@0EEEE0P0m?Cd205EEE@80ADE50P0m?Cd2038b<P80=SHf100b<S8204U9B@80GUiN0P21
PH4209FEU@80R8R80P2EUID20;Bd]080TY:B0P1OGel207MgM`<0QXJ60P21PH4206a/K080ZJVY303g
moL20?Cdm080moOg0P3ooolF0?Ogm`80m?Cd4`3gmoL20?oooa`0moOg3`3oool000d0oooo2P3gmoL2
0?Cdm2l0moOg0P3AdM42069RHP80EUIF0P1OGel208J6QP80WIfM0P2/[:`20;Rh^080PH610P1[Jf/2
07YjNP80SHf=101_Kfl207alO080IfMW0P1RHV8207EeM@<0Kfm_0P1WIfL206][J`80O7al0P1_Kfl2
069RHP80NWYj0P1aLG4206MWI`80HV9R1019BDT205mOG`@0EEEE0P1NGUh205ADE080K6a/101DE5@2
05iNGP80K6a/0P1iNGT207alO080SHf=0P2OWil20<K6aP80TY:B0P2MWId207YjNP80BDU90P1_Kfl3
0861P@@0TY:B303gmoL20?ooo`80moOg0P3dm?@:0?Ogm`80oooo403gmoL20?ooobd0moOg3`3oool0
00d0oooo2P3gmoL20?Cdm2l0moOg0P3AdM42069RHP80EUIF0P1OGel208J6QP80WIfM0P2/[:`20;Rh
^080PH610P1[Jf/207YjNP80SHf=101_Kfl207alO080IfMW0P1RHV8207EeM@<0Kfm_0P1WIfL206][
J`80O7al0P1_Kfl2069RHP80NWYj0P1aLG4206MWI`80HV9R1019BDT205mOG`@0EEEE0P1NGUh205AD
E080K6a/101DE5@205iNGP80K6a/0P1iNGT207alO080SHf=0P2OWil20<K6aP80TY:B0P2MWId207Yj
NP80BDU90P1_Kfl30861P@@0TY:B303gmoL20?ooo`80moOg0P3dm?@:0?Ogm`80oooo403gmoL20?oo
obd0moOg3`3oool000d0oooo?@3gmoL20<30`080MgMg0P1/K6`2065QH@80GemO0P23Ph<208^;R`80
^;Rh0P1RHV8206MWI`80N7Qh0P26QXH206m_K`80Jf][0P1JFUX405IFEPD0HV9R0P1[Jf/206m_K`@0
HV9R0P1jNWX20861P@80LG5a0P1_Kfl205IFEP80NWYj0P1EEED205ADE080Kfm_0P1[Jf/2069RHP80
I6AT0P1/K6`207YjNP80QXJ60P2OWil208f=S@80UIFE0P2h^;P209fMW@80VYZJ1026QXH205IFEP80
MGEe0P26QXH30861P@80OWin0P3oool20?Ogm`@0oooo0P3gmoL20?Cdm080oooo0P3dm?@20?ooo`80
moOg0P3dm?@20?Ogm`80oooo803gmoL20?ooob<0moOg3`3oool000d0oooo?@3gmoL20<30`080MgMg
0P1/K6`2065QH@80GemO0P23Ph<208^;R`80^;Rh0P1RHV8206MWI`80N7Qh0P26QXH206m_K`80Jf][
0P1JFUX405IFEPD0HV9R0P1[Jf/206m_K`@0HV9R0P1jNWX20861P@80LG5a0P1_Kfl205IFEP80NWYj
0P1EEED205ADE080Kfm_0P1[Jf/2069RHP80I6AT0P1/K6`207YjNP80QXJ60P2OWil208f=S@80UIFE
0P2h^;P209fMW@80VYZJ1026QXH205IFEP80MGEe0P26QXH30861P@80OWin0P3oool20?Ogm`@0oooo
0P3gmoL20?Cdm080oooo0P3dm?@20?ooo`80moOg0P3dm?@20?Ogm`80oooo803gmoL20?ooob<0moOg
3`3oool000d0oooo=@3gmoL20?ooo`P0moOg0P2^[Zh206m_K`80LW9b0P1eMGD20861P@80RHV90P2O
Wil20:JVYP@0IfMW1021PH4206][J`80PH610P1EEED505YJFP80K6a/0P1[Jf/2075aL@80EEEE0P1n
OWh2075aL@80SHf=0P1lO7`208R8R080TY:B0P1[Jf/405iNGP@0LG5a1026QXH408f=S@@0ZJVY0P2V
YZH207alO0@0NWYj0P1NGUh204E5A@80EEEE0P1lO7`20861P@80N7Qh0`2EUID20?ooo`H0moOg103o
ool40?Ogm`80ooooC`3gmoL?0?ooo`003@3ooole0?Ogm`80oooo203gmoL20:j^[P80Kfm_0P1bLW82
07EeM@80PH610P29RHT209nOW`80YZJV101WIfL40861P@80Jf][0P21PH4205EEE@D0FUYJ0P1/K6`2
06][J`80LG5a0P1EEED207inOP80LG5a0P2=SHd207alO080R8R80P2BTY8206][J`@0GUiN101aLG44
08J6QP@0SHf=102YZJT20:JVYP80O7al101jNWX205iNGP80ADE50P1EEED207alO080PH610P1hN7P3
09FEU@80oooo1P3gmoL40?ooo`@0moOg0P3ooom?0?Ogm`l0oooo000=0?ooocD0moOg0P3dm?@40?Og
m`80m?Cd103gmoL20;Zj^P80HF5Q0P1bLW8208J6QP80TY:B0P2MWId20:JVYP80[:b/0P1_Kfl20861
P@80HV9R0P23Ph<206m_K`80O7al0P1[Jf/305EEE@80De=C0P19BDT2069RHP80EUIF0P1eMGD2075a
L@80UIFE0P2=SHd20<K6aP80bLW90P2h^;P209nOW`80][Jf1P2[Zj/40<O7a`80/k>c0P2d];@208J6
QP80IfMW0P1hN7P206][J`80FUYJ0P1FEUH2069RHP80QXJ60P2BTY8207alO080OWin0`3oool40?Og
m`80oooo3P3gmoL20?Cdm0@0moOg103ooom30?Ogm`l0oooo000=0?ooocD0moOg0P3dm?@40?Ogm`80
m?Cd103gmoL20;Zj^P80HF5Q0P1bLW8208J6QP80TY:B0P2MWId20:JVYP80[:b/0P1_Kfl20861P@80
HV9R0P23Ph<206m_K`80O7al0P1[Jf/305EEE@80De=C0P19BDT2069RHP80EUIF0P1eMGD2075aL@80
UIFE0P2=SHd20<K6aP80bLW90P2h^;P209nOW`80][Jf1P2[Zj/40<O7a`80/k>c0P2d];@208J6QP80
IfMW0P1hN7P206][J`80FUYJ0P1FEUH2069RHP80QXJ60P2BTY8207alO080OWin0`3oool40?Ogm`80
oooo3P3gmoL20?Cdm0@0moOg103ooom30?Ogm`l0oooo000=0?ooocd0moOg0P3oool40?Ogm`80lO7a
0P22PX82079bLP80FUYJ0P26QXH40;Bd]080[:b/0P23Ph<208f=S@80Ph>30P29RHT207inOP80UIFE
0`2VYZH207YjNP80De=C0P1WIfL205=CD`80Kfm_0P2BTY820:JVYP80WIfM0P29RHT20;fm_@80`<30
0P2m_Kd20<K6aP80eMGE0P3Bd]820;fm_@80WinO102BTY8208>3P`80LW9b0P1_Kfl206][J`80Cdm?
0P1EEED206m_K`80N7Qh0P2EUID207alO080TY:B1`3gmoL20?Cdm0@0moOg103dm?@60?Ogm`80m?Cd
303gmoL20?Cdm3l0moOg3`3oool000d0oooo?@3gmoL20?ooo`@0moOg0P3alO4208:2PP80LW9b0P1J
FUX208J6QP@0];Bd0P2/[:`208>3P`80SHf=0P23Ph<208V9R@80OWin0P2EUID30:JVYP80NWYj0P1C
De<206MWI`80De=C0P1_Kfl209:BTP80YZJV0P2MWId208V9R@80_Kfm0P30`<020;fm_@80a/K60P3E
eMD20=;BdP80_Kfm0P2OWil409:BTP80Ph>30P1bLW8206m_K`80Jf][0P1?Cdl205EEE@80Kfm_0P1h
N7P209FEU@80O7al0P2BTY870?Ogm`80m?Cd103gmoL40?Cdm0H0moOg0P3dm?@<0?Ogm`80m?Cd?`3g
moL?0?ooo`003@3ooolm0?Ogm`80oooo1P3gmoL20?ooo`80NWYj0P1QHF420820P080RHV90P2/[:`2
0<_;b`@0[:b/0P30`<020:j^[P80bl_;0P30`<030:VYZ@80d];B0P3Hf=P20>o_k`80i^KV0P3Hf=P2
0=;BdP80clo?0P2m_Kd20<_;b`H0a/K60P3?cll20;Bd]080QXJ60P2VYZH208J6QP80N7Qh101jNWX2
069RHP80IfMW0P1DE5@207alO080QXJ61021PH4207alO080oooo103gmoL30?ooo`80m?Cd203gmoL2
0?Cdm0P0moOg0P3dm?@40?Ogm`80oooo103gmoL20?Cdm0@0moOg0P3dm?@20?Ogm`80oooo=@3gmoL?
0?ooo`003@3ooolm0?Ogm`80oooo1P3gmoL20?ooo`80NWYj0P1QHF420820P080RHV90P2/[:`20<_;
b`@0[:b/0P30`<020:j^[P80bl_;0P30`<030:VYZ@80d];B0P3Hf=P20>o_k`80i^KV0P3Hf=P20=;B
dP80clo?0P2m_Kd20<_;b`H0a/K60P3?cll20;Bd]080QXJ60P2VYZH208J6QP80N7Qh101jNWX2069R
HP80IfMW0P1DE5@207alO080QXJ61021PH4207alO080oooo103gmoL30?ooo`80m?Cd203gmoL20?Cd
m0P0moOg0P3dm?@40?Ogm`80oooo103gmoL20?Cdm0@0moOg0P3dm?@20?Ogm`80oooo=@3gmoL?0?oo
o`003@3ooolY0?Ogm`80oooo4P3gmoL20?ooo`X0moOg0P3Ph>02065QH@80KVi^0P2BTY820:FUY@80
`<300P3;bl/20=OGe`80c/k>1`3;bl/20=OGe`80a/K60P39bLT20<o?c`80bLW90P3Hf=P20=gMg@80
emOG0P3;bl/20=;BdP80];Bd0P2PX:020;fm_@80WIfM0P2JVYX20:2PX080K6a/0P1jNWX2069RHP80
IfMW0P1jNWX208>3P`80WIfM0P2OWil208f=S@80PH610P2YZJT40?Ogm`80m?Cd0P3gmoL30?Cdm0h0
moOg0P3dm?@/0?Ogm`80oooo1@3gmoL20?ooo`80moOg0P3dm?@H0?Ogm`l0oooo000=0?ooobT0moOg
0P3ooolB0?Ogm`80oooo2P3gmoL20>3Ph080HF5Q0P1^KVh209:BTP80YJFU0P30`<020<_;b`80emOG
0P3>c/h70<_;b`80emOG0P36a/H20<W9b@80clo?0P39bLT20=SHf080gMgM0P3GemL20<_;b`80d];B
0P2d];@20:2PX080_Kfm0P2MWId209ZJVP80X:2P0P1/K6`207YjNP80HV9R0P1WIfL207YjNP80Ph>3
0P2MWId209nOW`80SHf=0P21PH420:VYZ@@0moOg0P3dm?@20?Ogm`<0m?Cd3P3gmoL20?Cdm2`0moOg
0P3oool50?Ogm`80oooo0P3gmoL20?Cdm1P0moOg3`3oool000d0oooo:@3gmoL20?oooa80moOg0P3o
ool:0?Ogm`80h>3P0P1QHF4206i^KP80TY:B0P2UYJD20<30`080bl_;0P3GemL20<k>cPL0bl_;0P3G
emL20<K6aP80bLW90P3?cll20<W9b@80f=SH0P3MgMd20=OGe`80bl_;0P3Bd]820;Bd]080X:2P0P2m
_Kd209fMW@80VYZJ0P2PX:0206a/K080NWYj0P1RHV8206MWI`80NWYj0P23Ph<209fMW@80WinO0P2=
SHd20861P@80ZJVY103gmoL20?Cdm080moOg0`3dm?@>0?Ogm`80m?Cd;03gmoL20?ooo`D0moOg0P3o
ool20?Ogm`80m?Cd603gmoL?0?ooo`003@3oooli0?Ogm`80oooo0P3gmoL40?ooo`80moOg0P3oool4
0?Ogm`80oooo0P3YjNT208>3P`80P8200P2;Rh/40;Bd]080`<300P33`l<20<_;b`T0emOG0P3Vi^H2
0=gMg@80f][J0P3GemL20=gMg@80d];B0P3;bl/20<30`080`/;20P2JVYX208^;R`80X:2P0P1hN7P2
07YjNP80Kfm_0P26QXH2065QH@80RHV90P2MWId209nOW`80VYZJ0P29RHT209nOW`80h>3P1P3gmoL2
0?Cdm0L0moOg0P3oool20?Ogm`80oooo103gmoL20?Cdm180moOg0P3oool>0?Ogm`80oooo203gmoL2
0?ooo`T0moOg0P3ooolJ0?Ogm`l0oooo000=0?ooocT0moOg0P3oool20?Ogm`@0oooo0P3gmoL20?oo
o`@0moOg0P3oool20>WYj@80Ph>30P20P80208^;R`@0];Bd0P30`<020<?3``80bl_;2@3GemL20>KV
iP80gMgM0P3Jf]X20=OGe`80gMgM0P3Bd]820<_;b`80`<300P32`/8209ZJVP80Rh^;0P2PX:0207Qh
N080NWYj0P1_Kfl208J6QP80HF5Q0P29RHT209fMW@80WinO0P2JVYX208V9R@80WinO0P3Ph>060?Og
m`80m?Cd1`3gmoL20?ooo`80moOg0P3oool40?Ogm`80m?Cd4P3gmoL20?ooo`h0moOg0P3oool80?Og
m`80oooo2@3gmoL20?oooaX0moOg3`3oool000d0ooooA`3gmoL20?Cdm080moOg0P3oool40?Ogm`80
UiNG0P1jNWX208>3P`80^[Zj0P3;bl/40=OGe`<0eMGE0P3Bd]820<_;b`80f][J0P3>c/h20<_;b`80
`<300P2/[:`209fMW@80TY:B0P2VYZH20:b/[080VYZJ0P29RHT206=SH`80OWin0P2JVYX208V9R@@0
[:b/0P2d];@20:b/[080Rh^;0P2/[:`20?Cdm0`0moOg0P3oool90?Ogm`80m?Cd103gmoL20?ooo`80
moOg0P3oool60?Ogm`80m?Cd0P3gmoL20?ooo`X0moOg0P3ooolG0?Ogm`H0oooo0P3dm?@<0?Ogm`80
oooo2P3gmoL?0?ooo`003@3ooom70?Ogm`80m?Cd0P3gmoL20?ooo`@0moOg0P2GUiL207YjNP80Ph>3
0P2j^[X20<_;b`@0emOG0`3EeMD20=;BdP80bl_;0P3Jf]X20<k>cP80bl_;0P30`<020:b/[080WIfM
0P2BTY820:JVYP80[:b/0P2JVYX208V9R@80Hf=S0P1nOWh209ZJVP80RHV9102/[:`20;Bd]080[:b/
0P2;Rh/20:b/[080m?Cd303gmoL20?ooo`T0moOg0P3dm?@40?Ogm`80oooo0P3gmoL20?ooo`H0moOg
0P3dm?@20?Ogm`80oooo2P3gmoL20?oooaL0moOg1P3oool20?Cdm0`0moOg0P3oool:0?Ogm`l0oooo
000=0?ooobL0moOg0P3ooolJ0?Ogm`80m?Cd0P3oool40?Ogm`80oooo2P3gmoL20:2PX080UiNG0P2g
]kL20;Zj^P<0`<30103Jf]X20=OGe`@0f][J0P3GemL40<30`080ZJVY0P2UYJD209NGU`80];Bd0P3;
bl/20:2PX080`<300P3;bl/20<30`080X:2P0P2BTY820;fm_@80jNWY1P3oool60?Ogm`80oooo2`3g
moL20?ooo``0moOg0P3dm?@>0?Ogm`80oooo0P3gmoL:0?ooo`X0moOg0P3oool70?Ogm`@0oooo0P3g
moL20?oooaP0moOg3`3oool000d0oooo9`3gmoL20?oooaX0moOg0P3dm?@20?ooo`@0moOg0P3oool:
0?Ogm`80X:2P0P2GUiL20;Ng]`80^[Zj0`30`<040=[JfP80emOG103Jf]X20=OGe`@0`<300P2YZJT2
0:FUY@80UiNG0P2d];@20<_;b`80X:2P0P30`<020<_;b`80`<300P2PX:0209:BTP80_Kfm0P3YjNT6
0?ooo`H0moOg0P3oool;0?Ogm`80oooo303gmoL20?Cdm0h0moOg0P3oool20?Ogm`X0oooo2P3gmoL2
0?ooo`L0moOg103oool20?Ogm`80oooo603gmoL?0?ooo`003@3ooolU0?Ogm`80m?Cd:P3gmoL20?oo
o`80moOg0P3oool40?Ogm`80[Zj^0P2UYJD30<30`080ZJVY0P2m_Kd40<k>cP80gMgM0P3Jf]X20>KV
iP80kno_0P3Vi^H20=OGe`80bl_;0P3GemL20<k>cP80bl_;0P2YZJT209fMW@80];Bd0P3;bl/20>WY
j@@0moOg103oool20?Cdm0h0moOg0`3dm?@40?Ogm`80m?Cd1P3gmoL20?Cdm0h0moOg0P3dm?@>0?Og
m`80m?Cd0P3gmoL20?ooo`80m?Cd2P3gmoL30?Cdm0P0moOg0P3dm?@F0?Ogm`l0oooo000=0?ooobD0
moOg0P3dm?@Z0?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P2^[Zh20:FUY@<0`<300P2YZJT20;fm_@@0
c/k>0P3MgMd20=[JfP80i^KV0P3_knl20>KViP80emOG0P3;bl/20=OGe`80c/k>0P3;bl/20:VYZ@80
WIfM0P2d];@20<_;b`80jNWY103gmoL40?ooo`80m?Cd3P3gmoL30?Cdm0@0moOg0P3dm?@60?Ogm`80
m?Cd3P3gmoL20?Cdm0h0moOg0P3dm?@20?Ogm`80oooo0P3dm?@:0?Ogm`<0m?Cd203gmoL20?Cdm1H0
moOg3`3oool000d0oooo9`3gmoL20?ooob80moOg0P3dm?@40?Ogm`80oooo103dm?@60?Ogm`L0m?Cd
103YjNT20>3Ph080kno_0P3Vi^H20<_;b`@0`<300P3;bl/20<k>cP@0bl_;0P3AdM420>WYj@80m?Cd
2P3gmoL40?ooo`80moOg1P3oool;0?Ogm`@0m?Cd303gmoL20?Cdm080moOg0P3oool20?Cdm0H0moOg
0P3ooolB0?Ogm`80oooo0P3gmoL20?oooa40moOg0P3oool>0?Ogm`80oooo1P3gmoL?0?ooo`003@3o
oolW0?Ogm`80oooo8P3gmoL20?Cdm0@0moOg0P3oool40?Cdm0H0moOg1`3dm?@40>WYj@80h>3P0P3_
knl20>KViP80bl_;1030`<020<_;b`80c/k>103;bl/20=7Ad@80jNWY0P3dm?@:0?Ogm`@0oooo0P3g
moL60?ooo`/0moOg103dm?@<0?Ogm`80m?Cd0P3gmoL20?ooo`80m?Cd1P3gmoL20?oooa80moOg0P3o
ool20?Ogm`80oooo4@3gmoL20?ooo`h0moOg0P3oool60?Ogm`l0oooo000=0?ooobT0moOg0P3dm?@F
0?Ogm`80oooo0P3dm?@80?Ogm`80m?Cd4`3gmoL20?ooo`X0moOg203dm?@20?ooo``0moOg103oool6
0?Ogm`80oooo203gmoL20?Cdm080moOg0P3oool50?Ogm`80oooo1P3gmoL20?ooo`80moOg0P3oool2
0?Ogm`80oooo0P3gmoL20?Cdm0@0moOg0P3dm?@F0?Ogm`80m?Cd103gmoL20?ooo`T0moOg0P3ooolL
0?Ogm`l0oooo000=0?ooobT0moOg0P3dm?@F0?Ogm`80oooo0P3dm?@80?Ogm`80m?Cd4`3gmoL20?oo
o`X0moOg203dm?@20?ooo``0moOg103oool60?Ogm`80oooo203gmoL20?Cdm080moOg0P3oool50?Og
m`80oooo1P3gmoL20?ooo`80moOg0P3oool20?Ogm`80oooo0P3gmoL20?Cdm0@0moOg0P3dm?@F0?Og
m`80m?Cd103gmoL20?ooo`T0moOg0P3ooolL0?Ogm`l0oooo000=0?oood/0moOg0P3dm?@40?Ogm`80
m?Cd0P3oool60?Ogm`80m?Cd0P3gmoL30?Cdm0@0moOg0P3oool20?Cdm0`0moOg0P3oool40?Ogm`80
m?Cd303gmoL20?ooo`80moOg0P3oool60?Ogm`80m?Cd0P3oool20?Ogm`@0oooo4`3gmoL20?ooo`@0
m?Cd0P3gmoL20?Cdm100moOg0P3oool<0?Ogm`80oooo1`3gmoL20?Cdm080moOg103oool@0?Ogm`80
oooo0P3gmoL20?Cdm080moOg3`3oool000d0ooooB`3gmoL20?Cdm0@0moOg0P3dm?@20?ooo`H0moOg
0P3dm?@20?Ogm`<0m?Cd103gmoL20?ooo`80m?Cd303gmoL20?ooo`@0moOg0P3dm?@<0?Ogm`80oooo
0P3gmoL20?ooo`H0moOg0P3dm?@20?ooo`80moOg103ooolC0?Ogm`80oooo103dm?@20?Ogm`80m?Cd
403gmoL20?ooo``0moOg0P3oool70?Ogm`80m?Cd0P3gmoL40?oooa00moOg0P3oool20?Ogm`80m?Cd
0P3gmoL?0?ooo`003@3oool[0?Ogm`80oooo8P3gmoL40?ooo`H0moOg0P3dm?@40?Ogm`<0oooo1P3g
moL20?ooo`@0moOg0P3oool60?Ogm`80m?Cd303gmoL20?Cdm080moOg0P3oool40?Ogm`@0oooo1P3g
moL20?Cdm0@0moOg0P3dm?@30?Ogm`80oooo203gmoL20?oooa80moOg0P3oool20?Cdm0P0moOg0P3o
ool40?Ogm`80oooo103gmoL20?Cdm0d0moOg0P3dm?@20?oooa@0moOg0P3oool20?Ogm`l0oooo000=
0?ooob/0moOg0P3ooolR0?Ogm`@0oooo1P3gmoL20?Cdm0@0moOg0`3oool60?Ogm`80oooo103gmoL2
0?ooo`H0moOg0P3dm?@<0?Ogm`80m?Cd0P3gmoL20?ooo`@0moOg103oool60?Ogm`80m?Cd103gmoL2
0?Cdm0<0moOg0P3oool80?Ogm`80oooo4P3gmoL20?ooo`80m?Cd203gmoL20?ooo`@0moOg0P3oool4
0?Ogm`80m?Cd3@3gmoL20?Cdm080oooo503gmoL20?ooo`80moOg3`3oool000d0oooo8`3gmoL20?oo
o`@0moOg0P3dm?@40?Ogm`80m?Cd5P3gmoL20?Cdm080oooo1P3gmoL20?Cdm0P0moOg0P3dm?@20?oo
o`<0m?Cd1P3gmoL20?ooo`H0moOg0P3oool20?Ogm`80m?Cd103gmoL20?Cdm1@0moOg0P3oool40?Og
m`80m?Cd0P3gmoL20?ooo`L0moOg0P3dm?@40?ooo`@0moOg0P3dm?@20?ooo`P0moOg0P3oool60?Og
m`80oooo1P3gmoL20?ooo`@0moOg0P3oool40?Ogm`@0oooo103gmoL20?ooo`L0moOg0P3dm?@@0?Og
m`80oooo2P3gmoL?0?ooo`003@3ooolS0?Ogm`80oooo103gmoL20?Cdm0@0moOg0P3dm?@F0?Ogm`80
m?Cd0P3oool60?Ogm`80m?Cd203gmoL20?Cdm080oooo0`3dm?@60?Ogm`80oooo1P3gmoL20?ooo`80
moOg0P3dm?@40?Ogm`80m?Cd503gmoL20?ooo`@0moOg0P3dm?@20?Ogm`80oooo1`3gmoL20?Cdm0@0
oooo103gmoL20?Cdm080oooo203gmoL20?ooo`H0moOg0P3oool60?Ogm`80oooo103gmoL20?ooo`@0
moOg103oool40?Ogm`80oooo1`3gmoL20?Cdm100moOg0P3oool:0?Ogm`l0oooo000=0?ooobd0moOg
0P3oool/0?Ogm`80m?Cd1`3gmoL20?ooo`80m?Cd0P3gmoL20?ooo`P0moOg0P3oool20?Ogm`80oooo
303gmoL20?Cdm080moOg0P3ooolK0?Ogm`80m?Cd303gmoL20?Cdm080oooo0P3dm?@20?ooo`@0moOg
0P3oool40?Ogm`80m?Cd603gmoL30?Cdm180moOg0P3dm?@20?ooo`X0moOg3`3oool000d0oooo;@3g
moL20?ooob`0moOg0P3dm?@70?Ogm`80oooo0P3dm?@20?Ogm`80oooo203gmoL20?ooo`80moOg0P3o
ool<0?Ogm`80m?Cd0P3gmoL20?oooa/0moOg0P3dm?@<0?Ogm`80m?Cd0P3oool20?Cdm080oooo103g
moL20?ooo`@0moOg0P3dm?@H0?Ogm`<0m?Cd4P3gmoL20?Cdm080oooo2P3gmoL?0?ooo`003@3ooolY
0?Ogm`80oooo6P3gmoL20?Cdm1@0moOg103dm?@90?Ogm`80m?Cd103oool40?Ogm`80oooo0P3dm?@:
0?Ogm`80oooo0P3gmoL40?Cdm0@0moOg0P3oool20?Cdm080moOg0P3oool20?Ogm`80oooo103gmoL2
0?ooo`80moOg0`3oool:0?Ogm`80oooo2P3gmoL20?Cdm080moOg0P3oool60?Ogm`80oooo1P3gmoL2
0?ooo`80moOg0P3oool40?Ogm`80oooo0P3dm?@;0?Ogm`80oooo103gmoL20?oooa80moOg103dm?@?
0?ooo`003@3ooolY0?Ogm`80oooo6P3gmoL20?Cdm1@0moOg103dm?@90?Ogm`80m?Cd103oool40?Og
m`80oooo0P3dm?@:0?Ogm`80oooo0P3gmoL40?Cdm0@0moOg0P3oool20?Cdm080moOg0P3oool20?Og
m`80oooo103gmoL20?ooo`80moOg0`3oool:0?Ogm`80oooo2P3gmoL20?Cdm080moOg0P3oool60?Og
m`80oooo1P3gmoL20?ooo`80moOg0P3oool40?Ogm`80oooo0P3dm?@;0?Ogm`80oooo103gmoL20?oo
oa80moOg103dm?@?0?ooo`003@3oool]0?Ogm`80oooo603gmoL20?ooo`@0moOg0P3dm?@20?Ogm`80
m?Cd303gmoL30?ooo`h0moOg0P3dm?@20?oooaH0moOg0P3dm?@20?Ogm`80oooo0P3gmoL20?ooo`H0
moOg0P3dm?@20?ooo`80m?Cd0`3oool60?Ogm`80m?Cd403gmoL20?ooo`@0m?Cd1P3gmoL20?Cdm0P0
moOg0P3oool>0?Ogm`<0oooo603gmoL20?Cdm080moOg0P3oool20?Ogm`l0oooo000=0?ooobd0moOg
0P3ooolH0?Ogm`80oooo103gmoL20?Cdm080moOg0P3dm?@<0?Ogm`<0oooo3P3gmoL20?Cdm080oooo
5P3gmoL20?Cdm080moOg0P3oool20?Ogm`80oooo1P3gmoL20?Cdm080oooo0P3dm?@30?ooo`H0moOg
0P3dm?@@0?Ogm`80oooo103dm?@60?Ogm`80m?Cd203gmoL20?ooo`h0moOg0`3ooolH0?Ogm`80m?Cd
0P3gmoL20?ooo`80moOg3`3oool000d0oooo;`3gmoL20?Cdm100moOg0P3dm?@20?ooo`@0moOg0P3d
m?@40?Ogm`@0m?Cd1P3gmoL40?ooo`L0moOg0P3dm?@80?Ogm`80m?Cd103gmoL20?ooo`80moOg0P3d
m?@20?ooo`X0moOg0P3oool20?Ogm`80oooo0P3gmoL20?Cdm080oooo0P3gmoL20?Cdm080moOg0P3d
m?@40?Ogm`80oooo1@3gmoL20?Cdm0@0moOg0P3oool20?Cdm080oooo0P3gmoL20?Cdm080moOg0P3d
m?@20?ooo`80moOg0P3oool60?Ogm`80m?Cd7`3gmoL20?Cdm1`0moOg3`3oool000d0oooo;`3gmoL2
0?Cdm100moOg0P3dm?@20?ooo`@0moOg0P3dm?@40?Ogm`@0m?Cd1P3gmoL40?ooo`L0moOg0P3dm?@8
0?Ogm`80m?Cd103gmoL20?ooo`80moOg0P3dm?@20?ooo`X0moOg0P3oool20?Ogm`80oooo0P3gmoL2
0?Cdm080oooo0P3gmoL20?Cdm080moOg0P3dm?@40?Ogm`80oooo1@3gmoL20?Cdm0@0moOg0P3oool2
0?Cdm080oooo0P3gmoL20?Cdm080moOg0P3dm?@20?ooo`80moOg0P3oool60?Ogm`80m?Cd7`3gmoL2
0?Cdm1`0moOg3`3oool000d0ooooB@3gmoL20?ooo`80moOg0P3oool20?Ogm`80m?Cd103oool20?Og
m`80m?Cd0P3ooolA0?Ogm`@0oooo203gmoL20?ooo``0moOg0P3oool:0?Ogm`P0oooo2@3gmoL20?Cd
m080moOg0P3oool60?Ogm`P0oooo303gmoL40?ooo`P0moOg0P3dm?@<0?Ogm`80oooo2@3gmoL20?oo
o`P0moOg0P3oool20?Ogm`80oooo103gmoL20?ooo`@0moOg3`3oool000d0ooooB@3gmoL20?ooo`80
moOg0P3oool20?Ogm`80m?Cd103oool20?Ogm`80m?Cd0P3ooolA0?Ogm`@0oooo203gmoL20?ooo``0
moOg0P3oool:0?Ogm`P0oooo2@3gmoL20?Cdm080moOg0P3oool60?Ogm`P0oooo303gmoL40?ooo`P0
moOg0P3dm?@<0?Ogm`80oooo2@3gmoL20?ooo`P0moOg0P3oool20?Ogm`80oooo103gmoL20?ooo`@0
moOg3`3oool000d0oooo9@3gmoL20?ooo`80moOg0P3oool40?Ogm`80m?Cd0P3gmoL20?Cdm0X0moOg
0P3oool<0?Ogm`80m?Cd0P3gmoL20?Cdm080moOg0P3dm?@?0?Ogm`80m?Cd303gmoL20?ooo`P0moOg
0P3oool20?Cdm080moOg103ooolF0?Ogm`80oooo2`3gmoL20?Cdm0`0moOg0P3oool20?Ogm`80oooo
103gmoL20?Cdm080moOg0P3oool60?Ogm`80oooo403gmoL30?Cdm080moOg0P3dm?@L0?Ogm`l0oooo
000=0?ooobD0moOg0P3oool20?Ogm`80oooo103gmoL20?Cdm080moOg0P3dm?@:0?Ogm`80oooo303g
moL20?Cdm080moOg0P3dm?@20?Ogm`80m?Cd3`3gmoL20?Cdm0`0moOg0P3oool80?Ogm`80oooo0P3d
m?@20?Ogm`@0oooo5P3gmoL20?ooo`/0moOg0P3dm?@<0?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3d
m?@20?Ogm`80oooo1P3gmoL20?oooa00moOg0`3dm?@20?Ogm`80m?Cd703gmoL?0?ooo`003@3ooolU
0?Ogm`80oooo103gmoL20?oooa`0moOg0P3dm?@<0?Ogm`80oooo0P3gmoL20?oooaD0moOg103oool6
0?Ogm`80m?Cd103gmoL40?oooaH0moOg1`3ooolF0?Ogm`H0oooo7P3gmoL20?ooo`80moOg0`3dm?@2
0?Ogm`80m?Cd103gmoL20?ooo`@0moOg0P3oool20?Cdm0h0moOg3`3oool000d0oooo9@3gmoL20?oo
o`@0moOg0P3ooolL0?Ogm`80m?Cd303gmoL20?ooo`80moOg0P3ooolE0?Ogm`@0oooo1P3gmoL20?Cd
m0@0moOg103ooolF0?Ogm`L0oooo5P3gmoL60?oooah0moOg0P3oool20?Ogm`<0m?Cd0P3gmoL20?Cd
m0@0moOg0P3oool40?Ogm`80oooo0P3dm?@>0?Ogm`l0oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000h0?ooo`900000
;@3oool2@00007@0oooo0d0000100?ooo`00>P3oool00d000000oooo0?ooo`0/0?ooo`03@000003o
ool0oooo0780oooo00=000000?ooo`3oool0?`3oool002`0oooo0d0000030?ooo`=000000`3oool3
@00000D0oooo00=000000?ooo`3oool00P3oool3@00000@0oooo00=000000?ooo`3oool02@3oool2
@0000080oooo0d0000020?ooo`=000000`3oool3@00000050?oood0000100000@000003oool00T00
00020?ooo`03@000003ooom0000000=0000000@0oooo@0000400001000003`3oool01D000000oooo
@000003ooom000000080oooo0T0000000`3ooom00000@00000020?ooo`03@000003oool0oooo0090
00000P3oool3@00000070?oood0000100000@000003ooom000000?ooo`03@00000<0oooo0T000000
1P3ooom000000?oood000000oooo@0000080oooo0T00000B0?ooo`9000000`3oool5@00000050?oo
od000000oooo@000003oool00d0000020?ooo`=000000`3oool2@00003D0oooo000]0?ooo`03@000
003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003oool0oooo00T0
oooo00=000000?ooo`3oool03P3oool014000000oooo0?oood0000020?ooo`03@000003oool0oooo
0080oooo00E000000?ooo`3oool0oooo@00000020?ooo`04@000003oool0oooo@00000<0oooo00E0
00000?ooo`3ooom000000?ooo`03@00000<0oooo00=000000?ooo`3oool03P3oool01d000000oooo
@000003ooom000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom00000
0080oooo00=000000?oood000000103oool014000000oooo0?oood0000020?ooo`05@000003oool0
oooo0?oood0000000P3oool2@00000060?oood000000oooo@000003ooom000005P3oool00d000000
oooo0?ooo`03@00000080?oood000000oooo@000003ooom000000?oood0000020?ooo`04@000003o
ool0oooo@00000<0oooo00=000000?ooo`3oool0=@3oool002d0oooo00=000000?ooo`3oool00`3o
ool01D000000oooo0?ooo`3ooom000000080oooo00=000000?ooo`3oool01`3oool4@00000l0oooo
00A000000?ooo`3ooom000000P3oool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo0?oo
od0000000P3oool014000000oooo0?oood0000030?ooo`04@000003oool0oooo@00000<0oooo00E0
00000?ooo`3oool0oooo@000000@0?ooo`07@000003ooom000000?oood000000oooo@00000020?oo
o`03@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo@00000040?oo
o`04@000003oool0oooo@0000080oooo00E000000?ooo`3oool0oooo@00000020?ooo`90000000D0
oooo@000003ooom000000?ooo`03@00001<0oooo00=000000?ooo`3oool00`3oool02D000000oooo
@000003ooom000000?oood000000oooo@00000020?ooo`04@000003oool0oooo@00000<0oooo0d00
000e0?ooo`00;@3oool2@00000<0oooo0T0000040?ooo`=000002@3oool00d000000oooo@000000@
0?ooo`05@000003oool0oooo@000003oool0140000000`3ooom00000@00000040?ooo`=0000000<0
oooo@000040000000P3oool4@00000<0oooo0T0000030?ooo`03@000003oool0oooo00h0oooo0T00
00000`3ooom000000?ooo`020?ooo`90000000<0oooo@000040000000T0000030?ooo`9000000P3o
ool3@0000080oooo0d0000020?ooo`A000000P3oool2@00000050?oood00001000000?oood000000
0P3oool3@00001<0oooo0T0000030?ooo`90000000H0oooo@00004000000oooo@000003oool4@000
00<0oooo00A000000?ooo`3oool0oooo0d00000e0?ooo`00;@3oool014000000oooo0?oood00000D
0?ooo`900000403oool014000000oooo0?oood00000P0?ooo`03@000003oool0oooo02P0oooo00=0
00000?ooo`3oool0>`3oool00d000000oooo0?ooo`0i0?ooo`00;03oool5@0000080oooo00=00000
0?ooo`3oool0403oool00d000000oooo0?ooo`0?0?ooo`900000203oool00d000000oooo0?ooo`07
0?ooo`03@000003oool0oooo00/0oooo0T00000Y0?ooo`900000?03oool2@00003/0oooo003o0?oo
ob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.47761, -2.56068, 0.491133, 
  0.491133}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "In order to remove an effect of background in Fig. 4, we apply a round \
shape window to the sample image. \n\tAt first, a window function, we work \
out a 128 by 128 pixels list \[OpenCurlyDoubleQuote]win128\
\[CloseCurlyDoubleQuote] having a window's radius 50.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["win128=window[128,128,50];", "Input",
  CellLabel->"In[47]:="],

Cell[TextData[{
  "\t",
  StyleBox[
  "Convolution between the window and sample image data yields a window \
operated image. Further, we work out the other sample images based on the \
original sample in Fig. 4. Figure 5 shows the monochrome sample images. The \
differences among them are the angle and resolutions.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
monoSampleW=win128*monoSample;
monoSampleWD={monoSampleW,Transpose[monoSampleW],
\tTable[monoSampleW[[dim[[2]]-i+1,j]],{i,1,dim[[2]],2},{j,dim[[3]]}],
\tTable[monoSampleW[[i,dim[[3]]-j+1]],{i,dim[[2]]},{j,1,dim[[3]],2}]};\
\>", "Input",
  CellLabel->"In[48]:=",
  FormatType->InputForm],

Cell["\<\
label={\"(a)\",\"(b)\",\"(c)\",\"(d)\"};
mSamplewDG=Table[ListDensityPlot[monoSampleWD[[i]],PlotRange->All,
\tMesh->False,Frame->False,AspectRatio->dim[[2]]/dim[[3]],
\tPlotLabel->StringForm[\"`1`\",label[[i]]],
\tDisplayFunction->Identity],{i,4}];\
\>", "Input",
  CellLabel->"In[50]:="],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[{{mSamplewDG[[1]],mSamplewDG[[2]]},
\t{mSamplewDG[[3]],mSamplewDG[[4]]}}],
\tPlotLabel->\"Fig.5. Monochrome images\",
\tImageSize->{400,400}];\
\>", "Input",
  CellLabel->"In[52]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[.5 1.0125 -74 0 ]
[.5 1.0125 74 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.5) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Monochrome) show
171.000000 12.812500 moveto
(images) show
207.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.015024 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 64 8 [128 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000009A0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00C6C9CFC9D8DDD7CBD2B4A0BD9D9AA06C7A62677A839D9F
8D81A9F7F7F4000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000083897E95A6
7A5367536F92A69D89BDC0BDC6D5D2BD9F929283726F6B4F
556F78957C92F7F7F7F4F7F7000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000676781816B81555A5A
6C6B71557E718D7C88926B5E5E717186868D8DA9A9A67C7A
7A5E45557C817895FFF7F7F7FFFFF7F70000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000B8816B7A8D6F6F7C6762756F
676B7C6F627A71676249495F55555E546C54545E6C797C8D
9FC6929D7A496F819292F7F7F7F7F7F7FFF7F40000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000092B8B8AC7A8D7C7C867A6F81816F7C
6F7C5A7A6C6B4F497A4F565A565449493D36454545546C5A
62819F95C1B49D866B9F6BE9FFFFF4F7F7F7F7F7F7F70000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000081A9B4B6B8A695958D95958D81868D7C86
8662957A6295625A7C62626B5A5E54455555665556645E55
515E7186869F95BFB8817A9D81F7F7F7F7F7F4F7F7F4F7F7
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000006B818D8D9DB6B8B3ACABAE9F9F9F8D958D958D95
88957A717E64817A8D717C7A7C95627171887A6B6B5A5649
4F6255555656647B95ABC79DAE86F7F7F7F7F7F7F7F7F7F7
F7F7F7000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000056717A628D9FBDC9C9C9C1C1B8B6A9ACABABA9ABA9A9
95958D8D888D88798886716C88718671797C7A7C626B6F79
6F716F71555A676C717A7A95B8B89FF7F7F7F7F4F7F7F7F7
F7F7F7F7F700000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
006B62717C95ABBFB6B8BCBCCACACACAC7C1C1C1C1BCB6B1
B3B3A9A9A3A3A3A1A7A3A1A19599999999908D958D88816C
626F6B546B6B49626C6C716C8D86B3BFEFF7F7F7F7F7F7F7
F7F7F7F7F7F7000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000054
565E7186959FB8BCC1C8C0D0D0CFCFCDCAD0D3D3D8CDCFCA
CAC8C0BCBCBDC8C8C2C0C2BDBCBCB1B7B3ABABA395958D88
797A6C4F4F49493C4532816B716CA395BFF7F7F7F4F7F7FF
F7F7F7F7F7F7F7F700000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000005A7A
567A7A8D9FB3BFC7CAC8CAD3D3D8D3D2D8D3D8D8D8D8D8D3
D3D8D3CAD3CAD3CACAC8CACAC8C8BFC2BABAB6B1AC95A399
887C716C5A494F6B1F171A56557A6C7995C1F4F7F4FFF7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
0000000000000000
00000000000000000000000000000000000000006F6B5A62
5F6279959FB3C8CACAD3D3D8D8D3D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D3D3D3D8D3CACACACAC8CAC2BCBCBCBAB1A3AB95
958D7961555A453636232A0C067A7C648191CFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F700000000000000000000000000
0000000000000000
000000000000000000000000000000000000004F5A564F56
5A6B7195AEC1C1CAD3D3D8D8D8D8D8E0E0D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D3D3D3CDCDCAC8C8CAC1BFBAB7B1B1ACAC
998D88796C5E4936362A1F2A170B6B716C8DB1ECF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
0000000000000000
00000000000000000000000000000000000055555455554F
556C7C8D9FB6C1CAD3D3D8D8D8E0D8E0E0E0E0E0D8E0D8D8
E0D8D8D8D8D8D8D8D3D8D3D0CDCACAC8C8BCBCB6B1B1A9AB
99998D7C7A715E36321F23141F1F7C885E7995BFF7F7F4F7
F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000000000
0000000000000000
000000000000000000000000000000000056565555545A55
62627A8D9FABBFCACFD8D8D8D8E0E0D8E0D8E0D8D8D8E0D8
D8D8D8D8D8D8D8D8D8D0D3D3CACACAC0C8BCBCB3B1B1B1A9
9FA3887C71716C563D32171723176B6B7166959FABF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000000000
0000000000000000
000000000000000000000000000000004F5E6B6B5A625556
6B62718895ABC1CAD3D3D3D8D8D8E0E0D8D8E0E0D8D8E0D8
D8D8D8D8D8D8D8D3D8D3D3CAD3CAC8C8C1BFC1BAB3B1ABA9
95999086866C6C5E493D27170B0B53627A799F95AE95F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000
0000000000000000
000000000000000000000000000000005555555F62555A55
5A557A8195BCC1CDD2D3D8D8D8D8E0E0E0E0E0D8D8E0E0E0
E0E0D8D8D8D8D8D0D3D3D3CDCACACAC0C1BFC1BCB1B3ACA9
9599908D81796C554936451F17173271A186A3817164ACF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000
0000000000000000
000000000000000000000000000000504F5A866B555A565A
5A5E7A71A3C7CFCFD2D8D8D8E0E0D8D8E0E0E0D8E0E0E0E0
D8D8E0D8D8E0D8D8D8D8D8D0D3CDCAC7C1CABCBCB3A9A9A3
A395958D7A79795E6C452A2A1F3227957A5E95796CAE6CBD
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000
0000000000000000
0000000000000000000000000000A67149495F5549494955
5E62717AA9C9CFCFCAA99D9DB6D8E0E0E0E0E0E0E0E0E0E3
D8D8E0E0E0D8D8D8D8D3D0CACACAC7C79F7C797C7C959F95
99A1998D797179553D493D3217171F626F5E7A71959F6C8D
E9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000E9FF3D4B323D49554966
75818D909FCAC6BFCDD8D8D8D0887C6F7AA9C8D3D3D8E0D8
E0D8D8D8D8D3D3C8B78D6155617AACB9C7CACAC0C1B3AC95
7A998D88796C6C5E3D3D2A322A274F5A6B7A715E8D8DAE95
9FF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000F7E6896B494549493D6C
8E999F95ABC9CFCFD8D2CACDC1BCB9BCC1BCA3ACB7C8D8D3
D8D8D8D3CDCABAA1A795A9ABA995959599A3A9A9B1B5B3AB
A9A399908D816162553D3D2A3649453D6C8D6C668C95B371
95DDFFF7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
00000000000000000000000000F7F792C8866F5349555561
8DC0A6A3B1CDCFBCAA904961613C23365567617C95B7C2D3
D3D8D3CAC2BCAC9590796F8B8B362A3636493C54537C8688
99A3A3958881615E5E493D1F363D3D496C796C668179AB64
8DA1E6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7889D716232556139
2AD0B5B5B3D2D8D2C7B98890C0D76D6250737E9F95B9B3C8
D8D8CFCABCAC9588909F65CBE96E6F628559A0716788A9A9
B3B1ABA3A188796C5449320B1F555E456C88866C7A71B150
95AEAEF7F7F7F7F7F7F7F7F7F7F7F7F7F4F7000000000000
0000000000000000
00000000000000000000000000F7F7F7FF6C7C555E556127
5451D099ACCFD8D8D8D8D2C9B6958DABAA95B6B6D2D2CDCD
D8D8D8CAB3A39FA3BFB6C9B9B6A99D888D9F9F9FAABFC1B6
B6B6B1A99F90816155493D32325554625E888D81815EBD5E
559FA1D7FFF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F4F77E8D6C496C4955
32494BC7D0C7D8D8E0D8D8D8D8D2D2C0C7CACACDD2D8CFD3
D8D8D8CAB5B1ABB3B3C1C9CDD2C7C7C1C7C7C7C7CACDC7C7
B8BFB1A9A18E795E512A273D495E665E5E9F9999A151AF61
5E88A9C7F7F7F7F4F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7F7F4717155494555
51324555CDD3D2D8D8D8D8D8D8D8D8D8D2D8D8D8D8D8D8CD
D8D8D8C1B7B3BCC1C1C7CDD2D2D2D8D2D8D2CDCDCACDC7C1
C1B3A9A399816C5545393D3D555E625550AEA195A39FB15E
797981ABEFF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7F7F7715E54325649
49512A3D36CACDD8D8D8D8E0E0D8D8D8E0D8D8D8D8D8D2D8
D8D8D0BCB3BCBFC1C1C7CFD8D2D8D8D8D0D2D2D2CDCAC1BC
B3B1A3A1897A61493D3D3D555466645E6F88A3A1A1AB9171
507A95AEDDF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F4F7F4F4F4F4885E4B4B55
494B512A1F2AACCFCFD8D8D8D8D8E0E0E0D8D8D8D8D3CDD8
D8CAC0B3B3B1BABCC1CACFCDD0D0D8D2D0CDCACAC0BCBCB3
ACA3A18E7A6C641F06322A555E4B5E6654719FA1AFCD7991
5E8679BDCFCBF7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
0000000000000000000000000000F4F7F7F7EF9564643D45
454B514B1F321FCAD0D2D0D8D8D8D8D8D8D8D8D3D3D0D8D8
D8D3CAB7ABACB1ABB3BCCACDCDCFD3CACAC8CAC8C0B7B5B1
ACA1908179714906173656555E644B5449718C99B1C17B81
718195BFC79FCBF7F4F7F4F4F4F7F7F7F400000000000000
0000000000000000
0000000000000000000000000000F7EFF7F7F7D78D64613D
4951454B5132327CC7D0D0D0D8D8D8D8D8D3D3D0D8CDD8D8
D8D0C8BAB9B9B3B1ACACC0CACAD0CACACAC0C0C0BAB5B1A7
9D9D8E8173640B1F17495564456C545E32958DABBF818D79
818695AEC6C6BDCBF7F7F4F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000F7F7F7F7F7E9AE866454
553D4B454B4E3932CDC7CACAD3D0D8D8D3D3D3D0D8A799CA
CAC0B5757590A781A1B1BCC8C8CACACAC8C0BCB7B5ACACA3
A1998E7A714517233249555A6C6C546C5E8DAFA1AF8C8D66
8181A1BDBDE9ACE9B8F7F7F7F7F7F7F7F700000000000000
0000000000000000
000000000000000000000000000000F4F4F7F7E9C6A6956C
66644E4B4B494B3D86C9CDCDD3D3D3D3D8D3CFD3D3D3CACA
BCB1ACB7B3ACB1B7BABCC2C1C8CACAC0C0BCB7B1ACACA3A3
A199897A5E363D3C5A5571647B546655AEBDA1AA91957A81
8D9FA1BFB895DDC1F4E9F7F7F7F7F7F70000000000000000
0000000000000000
00000000000000000000000000000000F4F4EFF4F4CE9F81
666C50513D4B4B4B4BCFCFCDCFD3D0D0D3CFD3D3D3D3D3D3
CFCAC8C8C8BCBFC2BCC1BCC8BCC8BCBCB7B7BAB1ACA7ACA1
99998E6C4536174F5564667966817A99BDBD99A18C8D7B8D
7BA1ABC1AC95A3D7E6E6D5F7F4F7F7000000000000000000
0000000000000000
00000000000000000000000000000000EFF7F4ECEFE6CEAE
866C6C5E5450454B4C54CFCACFCDCACDC8CDD3D3D8D8CDCA
D8CAC8D3D8CDCAC1BCC1BCBABABCBABCBAB7B1B1ACACA3A1
99998154280B5A495A718D668C738CBFBFA1998D7B7B8D99
A199C1C79F9F91DDE6E6E9E6F7F7F7000000000000000000
0000000000000000
0000000000000000000000000000000000F4F7F4F4F4D7C3
A1957964555E503948395ED2D2CFCACAC8A69D795E677579
75757D6F5E565B674D655B4E619DBABABAB1B1B1A3A3A1A3
8E815E1F173D495A8DA95EA981A3BFCD9999758C818D9181
ABBDC1BDA1AB9FB8DDECE6ECF4EC00000000000000000000
0000000000000000
000000000000000000000000000000000000F7F7EFF7E9DD
D5AE957A6C665E4B55453D4BD2CDCACAC8CDCAA69D9D9DCD
C0A6A6B5C09D9D99908D89A3B1B3BABCB3B1B1A9A3999D8E
81492A2A27552AA9B166AE81AAAB8D8C976E8C818D9599A3
AEC1C9958695A1ACE6E6ECECE60000000000000000000000
0000000000000000
00000000000000000000000000000000000000F7F7F4F4E9
D5CBAE957B7B71555E54393D50C9CFCFD3CDCACAC8C1B7B5
ACA7A6A6A6A6A6ACA7ACB1ACBABABCB3B1ACA9A399998E5E
4E4B3D2A3D6299795EA9869781667392867B8D81A195ABA1
ABC7ABA19F9FA1AEC1E6E6EF000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000F7F7F4E9
E9CFCB9F91797B645E5E543D39505ACDCACDD3D3D3D0CDCA
CACACACAC8C0C0C1C8BFC2BCBCB1B5B3B1ACA19994665E66
55543D3D558D816C9F51815E71778671868D668D8DA1A1AC
B1BD8D778D9F95ABBDD7EC00000000000000000000000000
0000000000000000
00000000000000000000000000000000000000000000F7F4
ECE9CBBD958D817364665E5E3D39483D81CFD3CAD3D3D8D8
D8D8D8D8D0D0CACACAC1BCBFBAB5B3ACA390997171736C71
645E51458679817B39274866868C86868C73918D95A1ABBF
BD8D7B8D8695B8BDB4000000000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000000000F1
EFF4F4CFAC958D797373665E66323D4B3D3D8DCDD3D8D3D8
D0D8D0D3D0CAC8CAC0C0B7B5ACAAA1997B7B7B7B867B817B
716C554C7B5E8C4439273271775A7792718D7B8CA1AFBDC1
AE778D8D9991A1AE00000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00F1F1E6C6AB95817B73667B5E5E27453D3D3954B3C7CACA
CAC8C8C0C0C0B9B7B7B1ACA389898689898181818C898186
7B7373865455665E4C393D6E4C6686857B717B92A3AFB1AB
95958177ABAB000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000ECF4DDB8AB8D81736C5E5E665444393D3D44B3B3B1B1
B5B1ACB1ACACA3A5A5999999909494909999909999998E8C
8E8C7B9273546C6C665E4C48326E857285778697A8A3AF8D
8D978D999500000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000EFD5AEA18C81737B5A66665E3232393DBFB3BCB3
BABAB5B5B5ACAFAAA7AAA7A7A5999999A1A1A7A1A1999999
94948E8D7B7371667173736666666E75778592A8A1AF9171
717B91000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000A1A18D7B737354665A4C323D32BFBFBFBF
BFBAC2BDB5BDB5AFB5AFACAFACAFACACACB1AFAAA7A3AAA3
A3A1998C9994817A7B73735E6C6C5A66779292929986867B
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000008D817773544C5A5E543D39C1BCC8C1
BAC2BFBFC2BDC0BDBDB5BDBDB5B5B5B5BDAFB5B1AFB5AAAC
AAA3A1909497A1998C8E8C8C81666C6C7192868575710000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000007B715454444C5132B3BFC1C8
BFBFC2BDBDC2BDBDC2C2BDBDBDBDBDC2BABABABDAFBDAFB5
B1AFACA799A1A1BDBF9499A1A194817A6685750000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000044322739B3B3BABFBF
C1BFC8C2C8C2C2C2C2C2BDC2C2BDC2BDBFBDBABAB5BABABA
BAB5B5AFACAAAAAAAFBFAFA3A1A3A5A50000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000B6B3BABAC1
BFC2C2C2C2C8C2C8C2C2C2C2BFC2C2BDBDBDBDC2C2BFBDBD
BABDB5AFB5BDB5B5BDB5BDBA000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00C8C8C8C8C2C2C8C8C2C2C2C2BDBFC2C8C8C8C2C2C2BFBD
BDBAC2C2C2BD000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000C20000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.015024 0.0192308 0.00751202 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 128 8 [64 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000C2000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000C2C2BDC8C8C2C8C8C8C8C800000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
00BDC2BABDC2C2C8C2BDC2C2C8C2C8C80000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
B5BABABABDBDC8C2BDC2C8C2C2C8C2C2C200000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000BAB5
B5BDAFBDBDBFC2BDBDC2C2C2C8C8C2C2C1BAB60000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000B1BFB5
AAB5B5BABAC0BFC2BDC2C2C2C8C2C2C2BFBFB33200000000
00000000000000000000000000000000
0000000000000000000000000000000000000000A5A3A3BF
AAAAAFB5BABABABDBDBDC2C2C2C2C2BFBFBAB32744000000
00000000000000000000000000000000
0000000000000000000000000000000000000085999999B1
B199ACB5BDAFB5BDBDC0BFBFC2C2C2BFC8BD4B3954750000
00000000000000000000000000000000
00000000000000000000000000000000000000857A94A194
BDA1A7AFB5BDBDBAC2BDBDC2BDC2BDBFC8BF324C54710000
00000000000000000000000000000000
00000000000000000000000000000000000075855E81918E
B394A1B1AFAFAFBABABDBDBDBDC2BDBFBFBA1F5A54667300
00000000000000000000000000000000
00000000000000000000000000000000007185926C668C8E
999790A3ACB5B1AFB5B5BDB5BDBDBFC2C1BC39545A54778D
00000000000000000000000000000000
0000000000000000000000000000000000868C86717B8186
81A392A1AAACACB5B5AFB5B5B5BDB5C2B3BC3239715E738C
00000000000000000000000000000000
000000000000000000000000000000007B869292666C5E73
7A948CA1A3A3AAB1ACAFAFAFAFBDBDBABFBF32325A54738D
A1000000000000000000000000000000
000000000000000000000000000000777B8C8C85665E7371
738C8C94A1A1A1AAA7AAA5ACAFB5BDBABAB6393D5E5E6C8C
A1EF0000000000000000000000000000
0000000000000000000000000000007B71AFA88575666673
66738D949999A1A19999A7AAAAACB5BAB3B33D325E667B81
A1D50000000000000000000000000000
0000000000000000000000000000998C8D99978585544873
73668C8C8E99A19999A1A5A3AAAAACB5BCB3392A4C716C7B
95C1EF00000000000000000000000000
000000000000000000000000000099978DA39777726E485E
6C54928C8C99999990949999A5ACB1B1B1B3443D44665E73
8DB8F400000000000000000000000000
00000000000000000000000000AB8D9195AB9785856B4B48
734B8C7A818C948C8C898CA3ACB5B7B7C1B13D3D3D5E666C
81AEECF1000000000000000000000000
00000000000000000000000000AB7795ABAF927185666E39
5E558673868981818989A3B1B7C0C0C8CAC7543D455E7B73
81ABE6F1000000000000000000000000
00000000000000000000000000A18D95ABAF8C7186667539
4C667B73818189867B99ACB7C0CAD0CAD0CD863D484C5E5E
81A1CFF4000000000000000000000000
000000000000000000000000AE918D77C1AF8C8D925A7127
445E4C6C7B7B7B7B99AAB5C0CACAD3D8D8D8CD3D4B325E73
7995CFF4F10000000000000000000000
000000000000000000000000AE958D91C1A18C8C86514C49
664C48667373737AA3B5B3C8C8D3D0D8D8D8CDC94B325E66
6C95C7E9F70000000000000000000000
000000000000000000000000BD958D8DBFA18D73868C6627
7B79455E71737190ACB5BFC1CAD0D8D8D8D3CACF3D395E66
738DBDE9F40000000000000000000000
0000000000000000000000BDAB9F8D8DC1AB958D858D6E73
99A33250617190A3B1BABCCAC8D0D8D0D0D3D3CD5E3D5E5E
6C8DACDDF1EC00000000000000000000
0000000000000000000000D7AB9F77BDACA18D8D71775E51
6C8D3D54666699ACB3B1BCBFC1C0CACACAD0D3CDCD503D5E
64799FCFE9F700000000000000000000
0000000000000000000000EFAC9595C9AB958171857181A1
8D643D515E94A3ACB1BCBAB1B1ACB1B7BCCACACDCD393D5E
5E7995CFE9F700000000000000000000
00000000000000000000EFE6AE9FA1C7A195817B926697A9
79622A4B5E99A3ACB3BAACACACA6A6A7B5C1CACDCFC93D54
557B95CBE9F4F7000000000000000000
00000000000000000000ECD7BD959FBDAFA17B8D7B959790
A355273D8C99A3B1BABAB189899D9D9D9995C8CACACD443D
556681CED7F4EF000000000000000000
00000000000000000000ECE6AC9595C1A395816E8CAB8166
A9552A498E99A9B1BCB3A38D999DB5A6CD9DA6CDCACD4B45
4B667AAEDDF7F7000000000000000000
00000000000000000000E9E9AC9F9FC1A197738C8DAFAB81
86393D7999A3A9BABAB77D8D7F7D8995959D99C8CACF813D
5E5E7A95CBF7F7000000000000000000
000000000000000000ECECECB8ABBDBD818D8C99CDA3A9A9
5A3D1F81A3A3B1B1BA9D4E6567566F75796779A6CACFD239
395E6495C3F4F4F40000000000000000
000000000000000000F4E6E9D5ABC7AB818D8C79BF816CA3
5A17368EA1A3B5B5BAB1ABA17F7F7F898989A6C0CACFD24E
4B545581BDE9EFF40000000000000000
000000000000000000F7E6E6DD9FC799997B8DA1BF736671
490B5499A1ACB1B7BCBCBAC1C1CDD3CACAD8D3CDCDCDCA54
4B505E6CAEE6ECF70000000000000000
000000000000000000F7EFDDE6AEC79981918CC8B3916671
541F61999DACB1B7BFBCBFBFBCBCCAC8D3D3D3CACAD0CFB8
4B3954649FC6F4EF0000000000000000
000000000000000000F7F7E6D795C1A18D8DA1BD99817964
4F366C99A1A7B1B7BCC8C8C1C2BCC8CAD3D3D3CFD0D3CDCF
4B4B516C81CEF4F40000000000000000
0000000000000000F7F7F4E9D58DC1A39591ABA8955E866B
49277B90A1ACB5BCC8C0C8C0BFB5C8C8D3CFD3D3D3D3CDCF
50393D507BC3EFF4F700000000000000
0000000000000000F7F7F7E9C195BF9F8195AABD55546455
3C367A99A3ACB1BCC0CAC1BCB7ACB7B1CAD3D3D3D3D3CDC9
3D494B646CA6E9F7F400000000000000
0000000000000000F7F7F7D2D7BDBF8C8191CD8C4B665554
23368190A3ACB7C8C8C8C2BAB1A3ACBAC0D3D3D3D3D3D0CD
394B3D556495F4F7F700000000000000
0000000000000000F7F7F7F7E9E9BD81668CA18D6C6C5A49
23457A99A3ACB7C0CACAC8B1819075C0CAA7D0D3D8D0CAC7
324E453D5486E9F7F700000000000000
0000000000000000F7F7F7F7B8C6AC8D6C8197AB5E715E3C
175E8999A3B1BDC8CACACAA3ACB5B1CAD0CFD3D3D8D3D3CA
553D484B6679E0F7F700000000000000
0000000000000000F7F7F7F7CBC6AE867981AB955E6C6449
1F64819DA7B5C0C0CAD0CAACB1B9BAD0D8CDD0D3D8D8D0D0
7C324B513D64D7F7EF00000000000000
0000000000000000F4F7F7F7F4B8AC818DA1AA79546C6645
005E8199ACB7C0C8D0CDCAB7B1B5C1D0E3D8CAD8D8D8D8D3
C92A554B545ED2F7F400000000000000
0000000000000000F7F7F4F7F79FBF8181C1997154645536
067181A1B1B7C8C8CACFCDBCABACB7D3D8D0D3D8D8D8D8D2
CA324B4B456495F7F700000000000000
00000000000000F7F7F7F7F7F7CBAC7A7BCD977A5454492A
0B6C8EACB5C0CACACDD0CACAB3B1BCCDD8D2D8D8D8D8D8D8
CA271751555088F7F7F7000000000000
00000000000000F7F7F7F7F7F7CBBD8691CDA171664B5532
1F6C8EA3B3BCCACDD2D0CDCABCB1B3CAD8D3D8D8E0D8D8D8
CF2A2A4B554B88F4F4F4000000000000
00000000000000F7F4F7F7F7F7ECB17A7BC1A1715E54493D
456CA1A9BAC7CDD2D0D0D8CDBCBABCD0D8D8D8D8D8D8D8E0
D0C01F4B544571F7F4F7000000000000
00000000000000F7F7F7F7F7F7F7AE7A71ABA1885E66553D
497AA1B1BCCAD2D2D8D8D8C7C1BCBCD8D8D8D8D8D8D8E0D8
D8CA3D5149325EF7F7F7000000000000
00000000000000F7F7F7F7F7F7F7AF7973A9A1A164644932
557AA1B1C1CACFD8D0D8D2CAC1B3BCD0D8D8E0D8D8D8E0D8
D8D02A45553D66F7F7F7000000000000
00000000000000F7F7F7F7F7F7F7AB795E9F95AE555E3D39
5581A3B3C1CDCDD2D2D2D2C7C1B3C1D8CDD8D8D8D8D8D8D8
D8D35532554971F4F7F7000000000000
00000000000000F7F7F7F7F7F7F7AC8D4C6CA19F5E6C3D2A
5E8EA9B6C1CACDCDD2D8CFB6B6B1CAD8D3D8D2CDD2D8E0D8
D8CDC736555E62AEF4F7000000000000
00000000000000F7F7F7F7F7F4F7C7886151999F5E5E3D2A
5E8EA9BFC7CDC7C7C1C7CDC1B3B1CAD8D3D8CDCAC0D2D8D8
D8C7C749556C6C7EF4F7000000000000
00000000000000F7F7F7F7F7F7F7D5956C5081956C5E3245
6C90A9BFC1C1B6B1B9C1C9B8ABA7C0D8CDD2C7B3CACDD2D8
D8CDCA66495A5E54F7F4000000000000
00000000000000F7F7F7F7F7F7F7D79F5E5E818862553249
6190A9B6B6BF9F9F88A9B9B6A3A3CAD8CDD2B695AB95C9D8
D8CF99512755556CF7F7000000000000
00000000000000F7F7F7F7F7F7F7E9AB665A7B865E552A49
6C90ABB6B3AB7C7C54CB905E95A3C8D8C7CD9D8362B686CD
D8CFA6BD3249497AF7F7000000000000
00000000000000F7F7F7F7F7F7F7F7AE50716C8845550B49
6C88A3B1A9887159626ECB9F88ACCAD8C8B99F7362D790B9
D2D2B5D03955629DF7F7000000000000
00000000000000F7F7F7F7F7F7F7F7A350717A71492A1751
618E95AB957C28500C506C8D8DBACAD8CD956F6EB3B73695
CAC9A6D055554B81FFF7000000000000
00000000000000F7F7F7F7F7F7F7F7A164796679493D1F49
5E8195A3887C544936368B7995BCCAD8D3B77C67363C6190
BCCDA3C06155538692F7000000000000
00000000000000F7F7F7F7F7F7F7F7A96C8D668145322A55
5E7A99A3998D713C61835F95ACC8CAD8D3CAA96F53537AB3
C7CDA3B55555499A79F7000000000000
0000000000000000F7F7F7F7F7F7F7DD7195668D3D492A3D
628190A3ABB5A9A39595AB95A1CAD3D8D3C8ACBCBCBCCDD2
CFC995996C49456BE600000000000000
0000000000000000F7F7F7F7F7F7F7E97A95647949362A55
5E798D86A9BCBCC1CAC17A71B7D8D8D8D8D8BC7190D8D8D8
D3CF8D9D5E643D5EFF00000000000000
0000000000000000F7F7F7F7F7F7F7F7958D5E7A5A27323D
5E6C889995B3C0CAB97A558DC8D3D8D8D8D8D3A96F88D8D8
BFCA908166553D4BFF00000000000000
0000000000000000F7F7F7F7F7F7F7F773A164795F2A451F
556C8D95887C9089716FA9CDD3D8D8D8E0E0E0D8D3799DA9
95C988615E554945FF00000000000000
0000000000000000F7F7F7F7F7F7F7F78D9F715E62173249
55718DA195957C7CC7CACAD3D8D8E0D8E3E0E0E0E0D89DA9
CFC97A62554955497100000000000000
0000000000000000F7F7F7F7F7F7F7F79FAB6C5E8D17173D
6C7A8195A3B1BCC7CACACFD8D8D8E0E0E0E3E0E0E0D8D8D8
CFCA79625E5567496C00000000000000
0000000000000000F7F7F7F7F7F7F7F7BDAE795E95322A45
5E798D95A3A9BCCAC7CDD0D8D8E0D8D8E0E0D8E0D8E0D8D8
CFC7715E5A5A6B5A5000000000000000
0000000000000000F7F7F7F7F7F7F7F7F4957B6C95173232
6C8181A1A9B1BAC1C7CAD3D3D8D8E0E0E0E0E0E0D8E0D8D2
CFBF7154556262625500000000000000
000000000000000000F7F7F7F7F7F7F7F764818671171F36
55798D99A9B3BCBFC0CACDD3D0D8D8E0E0E0D8E0E0D8D8D3
CDBC815555555F550000000000000000
000000000000000000F7F7F7F7F7F7F7F7648D716F171F49
5E7C8699A9B1BCBCC0CACDD3D8D8D8E0E0E0D8E0D8E0D8D8
CFB18D625A6267550000000000000000
000000000000000000F7F7F7F7F7F7F7F7959579620B173D
5E6C8699A9B1BABFC8CACAD3D3D8D8D8D8D8E0D8E0D8D8D3
CAAB886256626B5E0000000000000000
000000000000000000F7F7F7F7F7F7F7F7DD95646B0B0B32
496B88A1A9B1B3BCC0CAD0D8D8D8D8D8E0D8D8E0D8E0D8D3
CAA98D62665E627A0000000000000000
000000000000000000F7F7F7F7F7F7F7F7F79F666B171732
56717CA3A9B1B3BCC0CAD3D0D8D8D8D8D8D8D8D8D8E0D8D8
CAAB8D62555455560000000000000000
00000000000000000000F7F7F7F7F7F7F7F7B4646B170B1F
3D628895A9ABB3C2C8D3D3D3D8D8D8D8E0D8E0E0D8D8D8D0
CAAE8D6C564F49000000000000000000
00000000000000000000F7F7F7F7F7F7F7F7BF79881F141F
36717C99ABB1B6BCC8CAD0D8D8D8D8D8D8E0E0E0E0E0D8D3
CAB68D6C4F5555000000000000000000
00000000000000000000F7F7F7F7F7F7F7F7D18C86172A23
36627C8DA3B1BAC1CACAD3D3D8D8D8D8D8D8D8D8D8D8D8CF
CAB3956B564F49000000000000000000
00000000000000000000F7F7F7F7F7F7F7F7EC8D710B2A2A
365E798DACB1B7BFCAC8CDD3D3D8D8D8D8D8D8D8E0D8D8D3
CAC1956B56564F000000000000000000
0000000000000000000000F7F7F7F7F7F7F7F79971361732
49557A8DA9A9B3BFC0C8C8D0D3D3D8D8D8D8E0D8D8D8D3D3
CABC8D6B566B00000000000000000000
0000000000000000000000F7F7F7F7F7F7F7F791647A0C23
365A618D95A3BABCC2C8CACAD8D3D8D8D8D8D8D8D8D3D8D3
CAB39562626B00000000000000000000
0000000000000000000000F7F7F7F7F7F7F4F7B864780B2A
325A647CA9ABB3BCC0C8C8CACAD3D3D3D8D8D8D8D8D3CDCA
C0B68D624F5500000000000000000000
000000000000000000000000F7F7F7F7F7FFF7C1797A5617
6B496C7C9995B1BAC2C8CAC8CACACAD8D3D8D8D3D2D8D3C8
C7B38D7A7A0000000000000000000000
000000000000000000000000F7F7F7F7F7F7FFBD8D714536
36555A718895B1B3BAC8CAC8C8CACACAD0D3D3D3D3D8D0C8
C1B38D7C550000000000000000000000
000000000000000000000000F7F7F7F7FFF7F7F7956C6B32
3C494F7A8895A3ABB7BCBDC0C8BDBCC8CACDD3D0CDCFD0C8
BC9F865E540000000000000000000000
00000000000000000000000000F7F7F7F7FFF7F4BF8D6F67
564F5A718688A1A9B1B7ACB5B5BAB7BCCAC8CDCACFC7C8C0
B6AB8155000000000000000000000000
00000000000000000000000000F7F7F7F7F7F7F7BF866C6C
626B546F6C8895909999A1A3A1A3A9B3B1BCC1C1CACABCB8
BF95716B000000000000000000000000
00000000000000000000000000F7F7F7F4F7F7F7BDAC8181
3D7C627C86957C8886818D99A3999FABACBFA9B3C1C1C8B8
957E7A62000000000000000000000000
0000000000000000000000000000F7F7F7F7F4F7F7B8957A
6C5A7171796B7C7C71716C86798D8D95A9ABABACB6C1C9C9
9F627100000000000000000000000000
0000000000000000000000000000F7F7F7F7FFF7F7AEB486
6464646F786B867A88957A7C959588909F9F9FABABB6BDAA
9DA67500000000000000000000000000
000000000000000000000000000000F7F7F7F7F7F7869DAB
7B565562495A6B8871957A717A6471959595959F9FABB3B6
8D810000000000000000000000000000
000000000000000000000000000000F7F7F7F7F7F7D19DBD
956C5564645E5E497A5E7C867C62817C8688959F9F9FB8B8
A6A00000000000000000000000000000
00000000000000000000000000000000F7F4F7F7F7F79D81
BF9F865E55645555455E6B625A957A62868D81958D95B8B4
81000000000000000000000000000000
0000000000000000000000000000000000F7F7F4F7F49581
789F7A7A54555549554F5F645A6271868D867595817CABAC
00000000000000000000000000000000
0000000000000000000000000000000000F7F7F7F7FFE99F
86B495815A54453649545A4F496B7A7C7C816F867C7AB892
00000000000000000000000000000000
000000000000000000000000000000000000FFF4F7F7F76C
865FB48881493232453D5556326F717C6281868D927ABD00
00000000000000000000000000000000
00000000000000000000000000000000000000F7F7F7F792
81499DC68D795E5454555F49677A6F6B6F627C6F7A810000
00000000000000000000000000000000
00000000000000000000000000000000000000FFFFF7FFFF
8175869AB88D866C626F5556717A626B62566B8667B80000
00000000000000000000000000000000
0000000000000000000000000000000000000000F7FFF7F7
9581555E7AA6A98D86715E927C71556B5A556B8167000000
00000000000000000000000000000000
000000000000000000000000000000000000000000F7F7F7
FF7C86566B67B4C7ABAB9FC98D715649557C838100000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000F7F4
F792956F4F6F8392BDD5BDBD9D925353A67E830000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
FFF77C817C677A78A6B4C6C6BDD2E6D8A900000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
00F4F7819F83677AA09DA0D2D7D8CFC60000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000E0899F89867AA09AC0D2D700000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000009A000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000C20000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000C8C8C8C8C8C8C8C2C8C2C2C2C8C8C8C8BDBDC2
C2C200000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00C8C8C8C8C2C2C8C8C2C2C2C2BDBFC2C8C8C8C2C2C2BFBD
BDBAC2C2C2BD000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000BDC2
C8C2C2C2C2C8C2C2C8C2C2C8C2C2BDBDC2C2BFC8C2BDBABD
BABABABABDBABAB5B5000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000B6B3BABAC1
BFC2C2C2C2C8C2C8C2C2C2C2BFC2C2BDBDBDBDC2C2BFBDBD
BABDB5AFB5BDB5B5BDB5BDBA000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000321FB3B3BFBCBF
BFC2C2C2C2C2C8C8C2C2C2C2C2C2C2BDBDC2BDBFBDC0BABA
BABAB5B5B5B5AFAAAFB5AFBFAAB100000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000044322739B3B3BABFBF
C1BFC8C2C8C2C2C2C2C2BDC2C2BDC2BDBFBDBABAB5BABABA
BAB5B5AFACAAAAAAAFBFAFA3A1A3A5A50000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000755A543939484BB6BDBFC8
BFBFC8C2C2C2C2C2C2BFC2BFBAC0C2BDBDBDBDB5BDAFBABD
BAB5B5ACAC99A1B1BFB19499A199A1998685000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000007B715454444C5132B3BFC1C8
BFBFC2BDBDC2BDBDC2C2BDBDBDBDBDC2BABABABDAFBDAFB5
B1AFACA799A1A1BDBF9499A1A194817A6685750000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000007B73666651545A5A441FBFBAC1BF
C2BFC2BDBDC2BDBDBDBDBDBDBDBDBDBABDBABAAFAFAFB5AF
B1B1A7A19494AFB3948E8E918E81795E7385757575000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000008D817773544C5A5E543D39C1BCC8C1
BAC2BFBFC2BDC0BDBDB5BDBDB5B5B5B5BDAFB5B1AFB5AAAC
AAA3A1909497A1998C8E8C8C81666C6C7192868575710000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000998C7B73715E5A715A393932C1BCBFB3
BFC2C2B5B5BDBAB5B5B5AFB5B5AFAFB5ACB5ACACACACAAAA
A1A199928EA391817A867B81647B71717386928C7B868100
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000A1A18D7B737354665A4C323D32BFBFBFBF
BFBAC2BDB5BDB5AFB5AFACAFACAFACACACB1AFAAA7A3AAA3
A3A1998C9994817A7B73735E6C6C5A66779292929986867B
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000EFACA1918C666C5E5E665E483D4839C1B6BFBA
BFBAB5BDB5B5B5AFACACACA5A7AAA7A7ACAAAAA1A5A1A1A1
A194948C998C7B73717164736C5E5E667585928C928C8D7B
7B7700000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000EFD5AEA18C81737B5A66665E3232393DBFB3BCB3
BABAB5B5B5ACAFAAA7AAA7A7A5999999A1A1A7A1A1999999
94948E8D7B7371667173736666666E75778592A8A1AF9171
717B91000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000EFEFC1AB958D7B666C5E71544C2A2A3939BFB3BABC
BAB5B5ACAAAAAAAAA5A3A1A5A1A199999999A1A19999998E
8E8C818C77665E73667373484854728585858C97A199AB8D
7B8C8C990000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000ECF4DDB8AB8D81736C5E5E665444393D3D44B3B3B1B1
B5B1ACB1ACACA3A5A5999999909494909999909999998E8C
8E8C7B9273546C6C665E4C48326E857285778697A8A3AF8D
8D978D999500000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00F1F4ECC9AE9F81816C71665E5E3D3D393D3D3DB3B1B3C1
B7B7B5B7B5B5B1ACACA3948C94898C8C8C8C94948C8C8C81
817A7B8C664B66735448444B5A6B85857B857197A1AB9995
8C91918DABAB000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00F1F1E6C6AB95817B73667B5E5E27453D3D3954B3C7CACA
CAC8C8C0C0C0B9B7B7B1ACA389898689898181818C898186
7B7373865455665E4C393D6E4C6686857B717B92A3AFB1AB
95958177ABAB000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
F1F4F4CFB8A19181795E665E664C3248453D3986CACDD8D0
D0CACAD0CACAC0C0BCB7B1ACA799867B818686897A818681
7B73647B5E667B4C443949755166778675717B8C92AFB1AB
A1957B8DA1A1A10000000000000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000000000F1
EFF4F4CFAC958D797373665E66323D4B3D3D8DCDD3D8D3D8
D0D8D0D3D0CAC8CAC0C0B7B5ACAAA1997B7B7B7B867B817B
716C554C7B5E8C4439273271775A7792718D7B8CA1AFBDC1
AE778D8D9991A1AE00000000000000000000000000000000
0000000000000000
00000000000000000000000000000000000000000000F7F7
F1E9D5C79F95816C5E66665E50324B4B3DC9D3CDD3D8D8D8
D8D8D0D0D0D3CAC8C8C8BFB3B1B5ACA3997A73737B737A73
71664C488C4C94663D49274C86517786758C8C8C97A1BFC1
AB91818D9595ABAEAB000000000000000000000000000000
0000000000000000
00000000000000000000000000000000000000000000F7F4
ECE9CBBD958D817364665E5E3D39483D81CFD3CAD3D3D8D8
D8D8D8D8D0D0CACACAC1BCBFBAB5B3ACA390997171736C71
645E51458679817B39274866868C86868C73918D95A1ABBF
BD8D7B8D8695B8BDB4000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000ECF7F1
ECDDCBAC958D7B6C555E545E2A3D455ECACDD3D3D3D3D8D0
D8D0D0D8D0D0CAC8CACAC8BCBCBAB3B1ACA3999066717161
66504B326CA354996473396E558D6E85868D869581AB97C1
CF8D7B8D919FA1ABAEBD0000000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000F7F7F4E9
E9CFCB9F91797B645E5E543D39505ACDCACDD3D3D3D0CDCA
CACACACAC8C0C0C1C8BFC2BCBCB1B5B3B1ACA19994665E66
55543D3D558D816C9F51815E71778671868D668D8DA1A1AC
B1BD8D778D9F95ABBDD7EC00000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000F4F7F7E9
D7CFB4958179645E5E5E323D3939CDCDD3CDCACAD0CAC2BC
B7B7B1B1B1ACB1B1B1B1BABABABCBAB1B1ACA7A3A1947A5E
5451453D4964998D7AA186814C718C8586718181A395A1AB
C1C98D95A39591ACBFEFDD00000000000000000000000000
0000000000000000
00000000000000000000000000000000000000F7F7F4F4E9
D5CBAE957B7B71555E54393D50C9CFCFD3CDCACAC8C1B7B5
ACA7A6A6A6A6A6ACA7ACB1ACBABABCB3B1ACA9A399998E5E
4E4B3D2A3D6299795EA9869781667392867B8D81A195ABA1
ABC7ABA19F9FA1AEC1E6E6EF000000000000000000000000
0000000000000000
00000000000000000000000000000000000000EFF7F4ECD7
CFCE9F8179667155503D3D444BCDCDCACACACAC8C0958999
999D9D9D9D9D89898989A3B1B1BABABAB3B1ACA3A399908C
4B3D3927395579A38690AB97A195867B8C8D717B8DA18DAF
AEBDC19FAB95A1BDCBD7E9EC000000000000000000000000
0000000000000000
000000000000000000000000000000000000F7F7EFF7E9DD
D5AE957A6C665E4B55453D4BD2CDCACAC8CDCAA69D9D9DCD
C0A6A6B5C09D9D99908D89A3B1B3BABCB3B1B1A9A3999D8E
81492A2A27552AA9B166AE81AAAB8D8C976E8C818D9599A3
AEC1C9958695A1ACE6E6ECECE60000000000000000000000
0000000000000000
000000000000000000000000000000000000F7F7F1F7DACB
AC95867A555E555E323D3D81CFCFCFCAC8C8C8999D9D9995
95959D89897D7F7FA68D8D7DABB7BABABABAB1A9A3A39999
8C793D3D17395E8695818DAB8CAFCD8D7B8C8C73819795A1
A1C1C19F959F95ACE6E9EFE9E90000000000000000000000
0000000000000000
0000000000000000000000000000000000F4F7F4F4F4D7C3
A1957964555E503948395ED2D2CFCACAC8A69D795E677579
75757D6F5E565B674D655B4E619DBABABAB1B1B1A3A3A1A3
8E815E1F173D495A8DA95EA981A3BFCD9999758C818D9181
ABBDC1BDA1AB9FB8DDECE6ECF4EC00000000000000000000
0000000000000000
0000000000000000000000000000000000F4F4EFF4E9D7BD
958164555E544B4B4B4ED2D2CDCFD3CAC8C0C8A68D897F89
7F89997F7F7F7F7F7FA1A9ABB1B1BABAB5B5B1B5ACA3A3A1
998E71361717365A71A3956CA181BFBFCF798C8C818D8D81
ABABC1C795ABA1D5E9E9E6E6F4F400000000000000000000
0000000000000000
00000000000000000000000000000000EFF7F4ECEFE6CEAE
866C6C5E5450454B4C54CFCACFCDCACDC8CDD3D3D8D8CDCA
D8CAC8D3D8CDCAC1BCC1BCBABABCBABCBAB7B1B1ACACA3A1
99998154280B5A495A718D668C738CBFBFA1998D7B7B8D99
A199C1C79F9F91DDE6E6E9E6F7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000F4EFF4F4E9C6BF9F
7964545451394B4B48B8CFCFCFD0D3CAD3CAD3D3D8D3D8D3
D8C8CACACABCBCBCBCBFBCBFC8BCBABFBCB7B7B1ACACA39D
99998161271F495481719F665E918DB3BFC8AB8C8C917B81
8199C1C7A1AE95E6E9DDE6EFF7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000F4F4EFF4F4CE9F81
666C50513D4B4B4B4BCFCFCDCFD3D0D0D3CFD3D3D3D3D3D3
CFCAC8C8C8BCBFC2BCC1BCC8BCC8BCBCB7B7BAB1ACA7ACA1
99998E6C4536174F5564667966817A99BDBD99A18C8D7B8D
7BA1ABC1AC95A3D7E6E6D5F7F4F7F7000000000000000000
0000000000000000
000000000000000000000000000000F7F7F4F4EFCEC3957B
6C505E3D4B394B503DCFCDCDCFD3D3D3D0D3D3D3D3CFD3D3
C8C8BCC8BCB5BABFBCC0C2C8C0C0CAC8BCBCB7B5ACACA3A1
9D908E7B49272A49626B71866C5E649591A8C8AB86916C95
8DA3A1C1AC8DC9D5E9E9E9F4F7F7F7F70000000000000000
0000000000000000
000000000000000000000000000000F4F4F7F7E9C6A6956C
66644E4B4B494B3D86C9CDCDD3D3D3D3D8D3CFD3D3D3CACA
BCB1ACB7B3ACB1B7BABCC2C1C8CACAC0C0BCB7B1ACACA3A3
A199897A5E363D3C5A5571647B546655AEBDA1AA91957A81
8D9FA1BFB895DDC1F4E9F7F7F7F7F7F70000000000000000
0000000000000000
000000000000000000000000000000F7EFF7F4F4BF957964
55554B3D3D4B4B39C9CDCDD0D3D3D3D3D3D3CDD3D3D3CAC0
B9BAA7ACACA3A9B1B1BABCC2C0C8C8C8C0C8BDB7B1ACA3A3
A1908E8161360B2349546C557B66664BA98CA1CD95919181
8D8C95BFBDBDCBD7D7D2F7F7F7F7F7F70000000000000000
0000000000000000
0000000000000000000000000000F7F7F7F7F7E9AE866454
553D4B454B4E3932CDC7CACAD3D0D8D8D3D3D3D0D8A799CA
CAC0B5757590A781A1B1BCC8C8CACACAC8C0BCB7B5ACACA3
A1998E7A714517233249555A6C6C546C5E8DAFA1AF8C8D66
8181A1BDBDE9ACE9B8F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000F7F7F7F7F4E095796466
4B4B3D484B3D3255CDCACFD3D8D3D0D8D0D3CDD3D8CFCDD0
D0CABAB1B3B5BAAC94A3BCCACACACACAC0C8C8BDB5B1ACA3
99998E89715E0B17233C4F5E5571545E2AAB9497BF818D6C
798D95ACC6C6ACB8F7F7F4F7F7F7F7F7F400000000000000
0000000000000000
0000000000000000000000000000F7EFF7F7F7D78D64613D
4951454B5132327CC7D0D0D0D8D8D8D8D8D3D3D0D8CDD8D8
D8D0C8BAB9B9B3B1ACACC0CACAD0CACACAC0C0C0BAB5B1A7
9D9D8E8173640B1F17495564456C545E32958DABBF818D79
818695AEC6C6BDCBF7F7F4F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000F7F4F4F7F4D2795E5E54
4B4B5055482A36C9CDD3D3D8D8D8D8D8D8D8D0CAD8D8D8E3
D8D0CAC1B7B5B3B1ACB7C0CACACDCAD0CAC8C8C0C0B7B5AC
A7999081735E2A001F452A66546C48545E7991AAAAA1818D
798181ACC7B8D2F4F7F7F7F7F7F7F7F4F400000000000000
0000000000000000
0000000000000000000000000000F4F7F7F7EF9564643D45
454B514B1F321FCAD0D2D0D8D8D8D8D8D8D8D8D3D3D0D8D8
D8D3CAB7ABACB1ABB3BCCACDCDCFD3CACAC8CAC8C0B7B5B1
ACA1908179714906173656555E644B5449718C99B1C17B81
718195BFC79FCBF7F4F7F4F4F4F7F7F7F400000000000000
0000000000000000
00000000000000000000000000F7F4F7F7F7F18864503D55
51514B172A2736CAD3D8D8D8D8D8D8D8D8D8D8D8D0D2D0D8
D0CDC0BCABB1B3B3BCCACACACDD0D3CDD0CAC8CAC0C0B7B5
A9AC998E796C550B282A454954546654547A8D97B1CD817B
6C7A86ACC6CBF4F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F4F7F4F4F4F4885E4B4B55
494B512A1F2AACCFCFD8D8D8D8D8E0E0E0D8D8D8D8D3CDD8
D8CAC0B3B3B1BABCC1CACFCDD0D0D8D2D0CDCACAC0BCBCB3
ACA3A18E7A6C641F06322A555E4B5E6654719FA1AFCD7991
5E8679BDCFCBF7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F4F4F7CB715E455454
514B2A1F17C0D2D0D8E0D8D8E0D8D8D8D8D8D8D8D8D8D3D8
D8D0CABCB3BABABCC1CDCDD8D8D0D8D0D8D2D2CDCAC7C0BA
B1A9A3A1816C6645323D49496454665E5571A9A1ABC18D7B
547A81B1D5ECF7F7F7F7F7F7F7F7F7F4F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7F7F7715E54325649
49512A3D36CACDD8D8D8D8E0E0D8D8D8E0D8D8D8D8D8D2D8
D8D8D0BCB3BCBFC1C1C7CFD8D2D8D8D8D0D2D2D2CDCAC1BC
B3B1A3A1897A61493D3D3D555466645E6F88A3A1A1AB9171
507A95AEDDF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7F4F77966493D5E55
4B453D2A83D0D2D8D8D8E0E0D8D8D8D8D8D8E0E0D8D8D8D8
D8D0D0BCB3B3BFC1CACAD2D2D2D8D8D0D0D8D3CFCDCACAC1
B3B1A9A18E7A615532323D49516466645EA1A1A1A1A9AB73
737986AFECF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7F7F4717155494555
51324555CDD3D2D8D8D8D8D8D8D8D8D8D2D8D8D8D8D8D8CD
D8D8D8C1B7B3BCC1C1C7CDD2D2D2D8D2D8D2CDCDCACDC7C1
C1B3A9A399816C5545393D3D555E625550AEA195A39FB15E
797981ABEFF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F4F7AE5E62545E5455
3D3645C7D8CDD8D8D8D8D8E0D8D8D8D2CDCDD2D2D8D8D0D3
D8D8D8CAB7B1B3B6BFB6C9CFCDD8D2D2D2CDC9CDCACACAC1
C1B6B1A99D8E6C5E492A3D3D496C5E5E5E9F95A1A16CBD4C
6C8D95ACF7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F4F77E8D6C496C4955
32494BC7D0C7D8D8E0D8D8D8D8D2D2C0C7CACACDD2D8CFD3
D8D8D8CAB5B1ABB3B3C1C9CDD2C7C7C1C7C7C7C7CACDC7C7
B8BFB1A9A18E795E512A273D495E665E5E9F9999A151AF61
5E88A9C7F7F7F7F4F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F4F4F7F754925E6B5A5E49
2A66B5CAB7CDD8D8D8D8D8D2CFCDCDCAB6B3C1C7CDD2C7CD
D8D8D8C0B3A7AEABACB8C7C9C1C1B8B9B1B1ABB6B6C1C1C1
BFBFB3A999907A6C554517323D5E5E6C5595A3818D50BD6C
5595ABD5F7F7F7F7F7F7F7F7F4F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7FF6C7C555E556127
5451D099ACCFD8D8D8D8D2C9B6958DABAA95B6B6D2D2CDCD
D8D8D8CAB3A39FA3BFB6C9B9B6A99D888D9F9F9FAABFC1B6
B6B6B1A99F90816155493D32325554625E888D81815EBD5E
559FA1D7FFF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7A07A714955496132
5EBDC0A6ABCFD2D8D8CDB9868DB6AE6267839F9D9DCDCDC7
D8D8D8C8BCA3A995A95E7D90ABCB79547E7C7A7C88ABB3B3
B6B6ABAB99907A6C5E49552A2A55555E6C86957B815ABF66
71ABABE9F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7889D716232556139
2AD0B5B5B3D2D8D2C7B98890C0D76D6250737E9F95B9B3C8
D8D8CFCABCAC9588909F65CBE96E6F628559A0716788A9A9
B3B1ABA3A188796C5449320B1F555E456C88866C7A71B150
95AEAEF7F7F7F7F7F7F7F7F7F7F7F7F7F4F7000000000000
0000000000000000
00000000000000000000000000F7F7FFF481544B32555555
61D0ACA6B3C9CFCAB6956F3697B777B30C6E426F8895BCCD
D8D8D3CABFBA958D718D956CC250BD0C6750A0284F7C8D95
A9ABA995958E796155511F171F2A554979717A7A8171AB50
8DA3C6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F792C8866F5349555561
8DC0A6A3B1CDCFBCAA904961613C23365567617C95B7C2D3
D3D8D3CAC2BCAC9590796F8B8B362A3636493C54537C8688
99A3A3958881615E5E493D1F363D3D496C796C668179AB64
8DA1E6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F779A09A5E4962554955
8EB5A3A3B1CDC9C7C1B3957A62535353556F90A9BCCACAD3
D8D8D3CACAC8BAACA395885F7C837A61463C49718D8D9099
A3A395998D7A615E5555452A3632324571817166818DAB6C
8DA9ECF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
0000000000000000000000000000F7E6896B494549493D6C
8E999F95ABC9CFCFD8D2CACDC1BCB9BCC1BCA3ACB7C8D8D3
D8D8D8D3CDCABAA1A795A9ABA995959599A3A9A9B1B5B3AB
A9A399908D816162553D3D2A3649453D6C8D6C668C95B371
95DDFFF7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000FFFF455E323D3D64325E
7A9D998DA9CFC1D3D8D8D8D8D8D8B5907C717ABCC8D8D8D8
E0D8D8D8D3D8C2B79071717A8DC1C7CAC7C1C1BCBCBCB3A9
9586998D81796C5E5455322A2A3627495E796C649195BF7A
9FE9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000E9FF3D4B323D49554966
75818D909FCAC6BFCDD8D8D8D0887C6F7AA9C8D3D3D8E0D8
E0D8D8D8D8D3D3C8B78D6155617AACB9C7CACAC0C1B3AC95
7A998D88796C6C5E3D3D2A322A274F5A6B7A715E8D8DAE95
9FF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000AEFF5445494932554B5E
61617C889FC9D2959FA9A39D7A79A3D3D8D8E0E0E0E0E0E0
D8D8D8D8D8D8D3D3D3CDBCA98D6F5E7171898D90867C7A88
95959D8D796C6C556C1F45453D2A235F6C796C648DA18873
CBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000A67149495F5549494955
5E62717AA9C9CFCFCAA99D9DB6D8E0E0E0E0E0E0E0E0E0E3
D8D8E0E0E0D8D8D8D8D3D0CACACAC7C79F7C797C7C959F95
99A1998D797179553D493D3217171F626F5E7A71959F6C8D
E9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000006C56497A675655495E
5E627979A3CACDCFCFD8D8D8D8D8E0E0E0E0E0E0E0E3E0E0
D8E0E0E0D8D8D8D8D8D8CFCFD3CACACAC1C7C7BCB3B1ABA3
A9958D81797A796C493D271717171F8D625EA16C81AB6C9F
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000
0000000000000000
000000000000000000000000000000504F5A866B555A565A
5A5E7A71A3C7CFCFD2D8D8D8E0E0D8D8E0E0E0D8E0E0E0E0
D8D8E0D8D8E0D8D8D8D8D8D0D3CDCAC7C1CABCBCB3A9A9A3
A395958D7A79795E6C452A2A1F3227957A5E95796CAE6CBD
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000
0000000000000000
000000000000000000000000000000556762716267625A55
54546C7190BFCDCFCFD2D8D8D8E0E0D8E0E0E0E0E0E0E0E0
E0E0E0E0E0D8D8D8D3D3D3D3D3CAC8C7CAC1BFBAB3B1ABA9
A3A199817981716C49323D3217171F957C6CA17B62956CF4
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000
0000000000000000
000000000000000000000000000000005555555F62555A55
5A557A8195BCC1CDD2D3D8D8D8D8E0E0E0E0E0D8D8E0E0E0
E0E0D8D8D8D8D8D0D3D3D3CDCACACAC0C1BFC1BCB1B3ACA9
9599908D81796C554936451F17173271A186A3817164ACF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000675562676B625A5A
5562718D95B1C1CFD2D8D8D8D8E0E0D8D8E0E0D8E0E0D8E0
E0E0D8D8D8D8D8D8D8D3D3CDCACACAC0BCBCBCBCB7B1ABA9
A3998D86867C6C5E3D49271F1F17236F9571958D8164D2F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000
0000000000000000
000000000000000000000000000000004F5E6B6B5A625556
6B62718895ABC1CAD3D3D3D8D8D8E0E0D8D8E0E0D8D8E0D8
D8D8D8D8D8D8D8D3D8D3D3CAD3CAC8C8C1BFC1BAB3B1ABA9
95999086866C6C5E493D27170B0B53627A799F95AE95F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000007A5E625F5E5A66
45627C8D8DA9BFCACFD3D8D8D8E0E0D8E0E0E0D8E0D8D8E0
D8D8D8D8D8D8D8D8D8D8CAD0CDCACAC0C8BCBCB3B3B1ABA9
95A18D88716B5A495532170B230B5F6B6C6495959FDDF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000000000
0000000000000000
000000000000000000000000000000000056565555545A55
62627A8D9FABBFCACFD8D8D8D8E0E0D8E0D8E0D8D8D8E0D8
D8D8D8D8D8D8D8D8D8D0D3D3CACACAC0C8BCBCB3B1B1B1A9
9FA3887C71716C563D32171723176B6B7166959FABF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000000000
0000000000000000
0000000000000000000000000000000000005549544F4956
626C868DA3AEBFCAD3D0D8D8D8D8D8D8D8E0E0E0E0D8D8E0
D8D8D8D8D8D8D8D8D0D3D3D3CAD3CAC8C8C2BCB3B1ABB1A9
A99588887C625E3D321F1F0B1A17786B66649FB4CEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000000000
0000000000000000
00000000000000000000000000000000000055555455554F
556C7C8D9FB6C1CAD3D3D8D8D8E0D8E0E0E0E0E0D8E0D8D8
E0D8D8D8D8D8D8D8D3D8D3D0CDCACAC8C8BCBCB6B1B1A9AB
99998D7C7A715E36321F23141F1F7C885E7995BFF7F7F4F7
F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000000000
0000000000000000
00000000000000000000000000000000000000494F4F5556
4F6B8695A9B3C8CACDCFD3D8D8D8D8D8E0D8E0D8D8D8D8D8
D8D8D8D8D8D8D8D8D3D3CDD3D0CACACAC1C1BFBAB1B1ABA3
A38D8D7C7162553632231F2A2A176C866C8CA9D1F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
0000000000000000
000000000000000000000000000000000000004F5A564F56
5A6B7195AEC1C1CAD3D3D8D8D8D8D8E0E0D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D3D3D3CDCDCAC8C8CAC1BFBAB7B1B1ACAC
998D88796C5E4936362A1F2A170B6B716C8DB1ECF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
0000000000000000
00000000000000000000000000000000000000006B6B6B56
566B818DA3BCC8CACAD3CFD3D8D8D8D8D8D8D8E0D8D8D8D8
D8D8D3D8D3D3D3D3D8D0D3C8C8C8C8C0C1BFBAB3BAA9A9A9
8D8D7C7A6255454932321F17063688717B99ACF7F4F7F7F7
F7F7F7F7F7F7F7F7F7F7F700000000000000000000000000
0000000000000000
00000000000000000000000000000000000000006F6B5A62
5F6279959FB3C8CACAD3D3D8D8D3D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D3D3D3D8D3CACACACAC8CAC2BCBCBCBAB1A3AB95
958D7961555A453636232A0C067A7C648191CFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F700000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000555F4F
62627A8DA3B6C1C0CACAD3CDCDD3D3D8D8D8D3D8D8D8D3D8
CFD3D2D3D3D3CDCACACACAC8CAC8C8C0BCBCBCB3B3ABA3A9
8D7C6C645E5A5A32322A170B88786C648DB8E9F7F4F4F7F7
F7F7F7F7F7F7F7F7F7F70000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000005A7A
567A7A8D9FB3BFC7CAC8CAD3D3D8D3D2D8D3D8D8D8D8D8D3
D3D8D3CAD3CAD3CACAC8CACAC8C8BFC2BABAB6B1AC95A399
887C716C5A494F6B1F171A56557A6C7995C1F4F7F4FFF7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000005555
5F7C7A8DA3B3B6C1CAC8CAD0CAD8CDD3D3D3D3D3D3D3D8D0
D0CACACAC0CAC8C8C8C8C8CAC8C8BABABCB3B3B1A9959588
7971645A5A555536493649457C71868DAEBDF7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000054
565E7186959FB8BCC1C8C0D0D0CFCFCDCAD0D3D3D8CDCFCA
CAC8C0BCBCBDC8C8C2C0C2BDBCBCB1B7B3ABABA395958D88
797A6C4F4F49493C4532816B716CA395BFF7F7F7F4F7F7FF
F7F7F7F7F7F7F7F700000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
6C5571818DABB3B6BCC0C0C8CAC7CACFCACACACDCAC8CACA
C2BCB5B7B7BABDB5B5B5B5ACB1B7A9B1A9A99FA195888686
7A715E5A564F67564967886F7C8DA9BFBDF4F7F7F7FFF7F7
F7F7F7F7F7F7F70000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
006B62717C95ABBFB6B8BCBCCACACACAC7C1C1C1C1BCB6B1
B3B3A9A9A3A3A3A1A7A3A1A19599999999908D958D88816C
626F6B546B6B49626C6C716C8D86B3BFEFF7F7F7F7F7F7F7
F7F7F7F7F7F7000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00626B7A887E8D95B3B8C1C8C7C1C1C1BFB3B3A9B3BFABAC
A9AB959F90998DA38D99818D81818D868688887C8D958186
7A7C62626F7C5A3D558186818DACB8BDF7F7F7F7F7F7F7F4
F7F7F7F7F7F7000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000056717A628D9FBDC9C9C9C1C1B8B6A9ACABABA9ABA9A9
95958D8D888D88798886716C88718671797C7A7C626B6F79
6F716F71555A676C717A7A95B8B89FF7F7F7F7F4F7F7F7F7
F7F7F7F7F700000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000007586A6AA9DB6AAB6BDBDB6B3ABA9AB959FA99F959F
9590868871957C95867C8D7A6C957A887C7A81865F6B7A78
676F7C646C646C647186ABB4ACAED2F7F7F7F7FFF7F7F7F7
F7F7F7F70000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000006B818D8D9DB6B8B3ACABAE9F9F9F8D958D958D95
88957A717E64817A8D717C7A7C95627171887A6B6B5A5649
4F6255555656647B95ABC79DAE86F7F7F7F7F7F7F7F7F7F7
F7F7F7000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000A09FA6B8B8B8B89F9F9F9F959F959588889586
7A7C64818162497C5A867A7C7C5E6C7A4549665E5A5E6664
6C646455666CAC95AEBD629D81D1FFF7F7F7F7F7F7F7F4F7
F7F700000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000081A9B4B6B8A695958D95958D81868D7C86
8662957A6295625A7C62626B5A5E54455555665556645E55
515E7186869F95BFB8817A9D81F7F7F7F7F7F4F7F7F4F7F7
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000092ACB4ABA67C88819595887588867C8D
7C865A716F627A5A62645A5F5A4F55555549455556555454
627A7A7A7A9FB4787881A695E9F4F4F7F7F4F7F7F4F7F700
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000092B8B8AC7A8D7C7C867A6F81816F7C
6F7C5A7A6C6B4F497A4F565A565449493D36454545546C5A
62819F95C1B49D866B9F6BE9FFFFF4F7F7F7F7F7F7F70000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000B4BDAC7A6B927C8D92866B817A62
7C7C62717A6F673249567A55553D55453D32363232495E81
958895B4925F7786816CA9F7F7F7F7F7F7F4F7FFF7000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000B8816B7A8D6F6F7C6762756F
676B7C6F627A71676249495F55555E546C54545E6C797C8D
9FC6929D7A496F819292F7F7F7F7F7F7FFF7F40000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000B8626778866F6B5A565662
626B6F62627A81716F567A55546F6B62646C7A869F8D95B8
9D9A8686567586817EFFF7FFFFF7F4FFF4FF000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000676781816B81555A5A
6C6B71557E718D7C88926B5E5E717186868D8DA9A9A67C7A
7A5E45557C817895FFF7F7F7FFFFF7F70000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000008162836F7C6B55
534962567571958DC6C9B89FB6ABABABC7C7B3B48667786B
5A566286927C7EFFF7F7FFF7F7F700000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000083897E95A6
7A5367536F92A69D89BDC0BDC6D5D2BD9F929283726F6B4F
556F78957C92F7F7F7F4F7F7000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000C0A9
D2D8EFE6D8D2CFBDCBC6C6C6CFB486A686787A7A6267547C
8681817CFFF7F7FFF4000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00C6C9CFC9D8DDD7CBD2B4A0BD9D9AA06C7A62677A839D9F
8D81A9F7F7F4000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000D7DDD2CBC0C29A8BA0787A6F8661899D9F9A89
9FE000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000009A0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000F7F4F7F7F7F7F7F7F4F7F7F7F7F7F700
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000F7F7F7F7F4F4F7F7F7F7F7F7F7F4F7F7F7F7F7F7F7
FFE9AEA60000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
F7F4F7F7F7EFF4F7F7F4F4F7F7F7F4F4F7F7F7F7FF9279E6
FFFFFF716C50550000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000EFF4F4
F7F4EFF7F7F7F4F7F7F4F4F7F4F7F7F7F7FFA088F4C8A089
453D5449564F6755674F0000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000F4F4F7EFF4
F4F7F7F7F7F7F7F7F7F4F7F7F7F4AE7E546C7A9D81869A6B
5E4B4549495A6255555E7A56000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000F7F7F7F4F4F4EF
F4F7F4F7F4F7F4EFF1F4CB7179715E8D927C7171546F5E49
3232495F7A867155626B5E56555500000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000F7EFF7F7F4EFECF4F4
EFE9F4E9E0D7D2958888715E6671626C5E5549624B534945
3D3D4955676B625F676B62554955494F0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000F7F4F7F7EFF1F4F4EFE9F4
CEC6BFAE958D7964645E5E54495554496B5E553232496249
3D493249565567626B5A5F5554544F5A6B6F000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000ECF7F7F4F4F7F7F4E9E6C6CE
C3A6958679645E64504B45323D495E6C5A55495555555549
64555549555A625562625E544F554F566B6B550000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000F7F7F7F4F7F4ECE9DAD7D7CEBF9F
9595796464615E3D3D4B54565E4554495E6161615555493D
32494B4949565A5A5A555A5A4955554F6B5A5F5A55000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000F1F7F4F1E9E9E9D7DDCBC3BDAE9F81
7B6C6454663D54455555544955555555492732395561556C
5E665E555E5A55555A566655564F565656624F7A55540000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000F1EFF1ECECE9D7D5CFD5ACA195867966
6C6655554B494B45514951494B513D322A545E2A618D8E8E
7A75615E5E5A545A556B456262554F5A565F62565F566C00
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000F1F1F4F4E9E9DDCFCFCBCEAE9595816C646C
5064553D4B514B4B514B4B51453236496651BDD0D0C0B599
9D816162625E5455626262626C6C6B6B6B62627A7C5E556B
620000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000ECF4F1F4F4D5CBCBCBB4AE9F958679646C5450
5E4E4B4B3D4550514B512A2A3D45454BB5D0C0B5ACA6A39F
998D7C71797A6C7A71717C7A867C867181797A7A7A717162
6B5600000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000EFF4ECE6CFCFC7BDAC9F9595817A7A64555E5451
3D4B3D45484B554B172A1F3D2A55C7C7CA99A6B5A6A3A395
8D90887A797171818D888D8D8D8D95958D958D8D8D868171
7A7175000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000EFEFDDC9C6B8AC9F959591817B796C55555E54513D
4B4B3D4B4B51481F2A1F173683CDD8D0B7ACABB3B3B1B1AB
A99F9FA9A3A3909595958D9FA39FA9AEA39FA39FA3958D7C
887A866B0000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000EFD5C1B8AEABA195958D8D79797B66665E5E5450394B
39494B4E3D322A32272AC0CAD0D3CDC7CDCFCFD2C9CDCDC9
CFCAC9C9CAC7BFBCB1ABA9ABAEB6B3C1BCB3B6B3B39FAB95
7E62A681A000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000ACAEABAB9F95918D81817B7B6471715E55504B454B4B
4B4B4B393232361F36ACD2CDD2D2D8D8D8D8D2D8CFCFC9CF
C1C6D2CFCDCFCDC1C1C1BFBFBFC1C8C1C8C8C1BFB6B8B3AB
8D8DAA8D9F00000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00A1A1A1958D818181796C736C645E55554B5E394B4B4B4B
503D3932557CC9CACACFD0D8D8D8D8D8D8D8D8D2CABCC7CF
D3BF95CFCFCFCFCDCFCACACACACACACACACAC0C7C1BCB6BF
959F9D8DA681000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
99A1918C8D81817B79735E64555E5E5E505532484B4C484B
3D86C9CDCDC7CDD0D3CFD8D8D8D8D8E0D8D8D8C7B6AAC1D8
D8CD9FCACFD2CFD2D2D3CFCFD3D3CDD3CACACACACAC1BCB6
B3BDB69DB8A9920000000000000000000000000000000000
0000000000000000
00000000000000000000000000000000000000000000008D
8C8D8C817B736C735E7366665E5E5E543D453D394E54B8CF
CFC9CDC7CAD0D3D2D8D8E0D8D8D8D8D8D8D8CDB99590B3D2
D8D8A9A9D8D8D2D3D8D3D3D8D0D3CFD3D3D3CAC8C8C8C0B8
B8C9AAB6B8B4AC9200000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000007B81
7B7B6673666C71666666665E545432393D3D3D5ED2CFCFCF
CDCDCDCACFD0D3D0D8D8D8D8E0D8D8D8D8D2B9886F4995CA
D8D8A39DD8D8D8D8D8D3D8D8D8D8D3D8CFD3D3CACAC0C0BC
C1C9B6B8B8B6B4B8B4000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000007377
73736C7B6C5E667B5E5E5E5E5E3D3D3D444B81D2D2CACFCD
CDCDD0CAD3D0D8D8D8D8D8E0E0D8E0D8D2C9869036617ACD
D8D89D9DD8D8D8D8D8D8D8D8D8D8D8D8D3D8CDD3D0D0C8BC
C8C9BDB3B8B8ABB8BD000000000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000007B6673
71735E5A5E5E5E5E6666503D2A3939504BD2CFD2CDCFCFCF
CFD3D3D3D8D8D8D8D8D8E0E0D8D8D8D8CFB68DC0976162C1
D8D07AB6D8E0D8D8D8D8D8D8D8D8D8D8D8D8CDD3CAD0CACA
C7C1BDAC9FA6A6ACACB80000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000075716654
5E545E6671665E5E4C3232393D5039C9CDCDCFCFCFCDD0D3
D3D3D3D0D3D8D8D8D8D8D8D8D8D8D8D2CD95B6D7B73C53BC
D88879D8D8E0E0D8E0D8E0E0D8E0D8D8D8D3D3D8D8CFC7CA
C1C1B6AB9F957C7A7A81B800000000000000000000000000
0000000000000000
00000000000000000000000000000000000000005A54514C
5A66666654543D27323D4B48455ACDCFCDCACFCAD3CAD3D0
D3D3D3D8D0D8D8D8D8E0D8D8D8D8D8D2CD8DAE6D772353B9
B57CA3E0E0D8E0E0E0E0E0E0D8D8D8D8D8D8D3D3CDCFCACA
C1B8B3AE9F95888D6B6B6200000000000000000000000000
0000000000000000
00000000000000000000000000000000000000445454545A
715A5E5E4C443D45484B4B3D5ECDCDCFCACACACACACDCAD0
D3D3D3D8D8D8D8D8D8E0D8D8D8D8D2C0CAAB6262B33653BC
906FD3E0E0D8D8E0D8E0D8D8D8E0D8E0D8D8D8D2D3CDCFCA
C1B6AB9F9F8D817C927A6767000000000000000000000000
0000000000000000
000000000000000000000000000000000000003239445A5E
5A4C48322A39393D453D3D81CACAD3D3CAC8C8C8C8C8D3D3
D0D8D3D3D0D8D8D8D8E0D8E0D8D2CDC7B6AA67500C5555C1
7C7AD8E0E0E0E0E0D8D8E0E0D8E0E0E0D8D8D8D8D3CACAC7
BFA9A99F9595957C7C8D7867000000000000000000000000
0000000000000000
0000000000000000000000000000000000003227394C5A54
39323D322A3D3D3D3D3DC9CFCDCDCDCDCACDC8A6C0CDCACF
D3D3D3D3D3D3D8D8D8D8D8D8D8D8CDCAB39583736E676FBC
71A9D8E0E0E0E0E0E0D8E0D8E0E0D8D8D8D8D8D3D3D0CAC1
B3ACAB9F9F9595868D6F8681810000000000000000000000
0000000000000000
0000000000000000000000000000000000001F394851443D
393D4839393D3D39398DD3D3D3D3CACACACAC89DC8D3D3D3
D3CFCDD3CDD3D0D8D8D8D8D8E0D8D2CAC1B69F7E426190A3
7AC8E0E0E0E0E0E0E0E0E0E0E0E0E0D8D8D8D3D8D3D3CAC1
B3AB958D958D887A926F6F81620000000000000000000000
0000000000000000
0000000000000000000000000000000000B6B3B34B321F39
3232393D39443D5486CDCDCAD3D3CACAC8A69979A6D3D3D3
D3D3D3D0D3D0CAD3D8D8D8D8E0D8D2CDC7B69D9F6F7CA9AC
BCD3E0E0E0D8E0D8D8E0D8D8E0E0D8D8E0D8D8D8D3D3CDC1
A9AB9F959581756F867C6B6B838300000000000000000000
0000000000000000
0000000000000000000000000000000000B3B3B3B6B3BFC1
C1BFC1BFBFB3B3B3CAD3D3D3D3D3D0C8C09D9D5E8DD8D8D3
D3D3D3D8D8D8D8D3D0D8D8D8D8D8D8D2CDD29D958895BCB7
C8D3E0E0E0E0E0D8E0D8E0D8E0D8D8D8D8D8D8D8D3D8CAC1
B3A9A98D888688816B675A816F8900000000000000000000
0000000000000000
0000000000000000000000000000000000BABFBABDBFBABC
BCBFB6B3B3B3B1C7CDD8D8D3D3D0CAC1959D9D6789D8D3D3
CFD3D3A7CFCDD8D0D2D3D8D8D8D8D8D8D2D2CDB995B7CAC8
D8D8E0E0E3E0E0E0E0D8D8D8D8E0D8D8D8D8D8D8D3CDC8BC
BFAB9F95888D8681816256557C7E00000000000000000000
0000000000000000
00000000000000000000000000000000BDBABCBFBFC1C1C8
BFBFBFBCBAB1B3CAD8D3D8D8D8CDC2B7899D99757FCDD8D3
D3CACA99CDD8D8D8D0CDD3D2D8D8D0CFC7CDCDB3BCC2CAD8
D8E0E0E0E0E0E0E0D8E0D8E0D8D8D8D8D8D8D3D8D8CFCAB6
ABA9958D957C7C6F7A75565A6B95C0000000000000000000
0000000000000000
00000000000000000000000000000000C2C1BFBFC8C8BFC1
B3BFBAB3BCB1C1CAD0D8D8D8D0CABCB599CD957989CAD3D3
D3CAC0CAD0D8E3D8D8D8D8D8D8CDD3D3CDCDC7C8CDD3D3D3
D8D8E0E3E0E0E0E0E0D8E0D8E0D8D8D8D8D8D8D3D0CACAB1
ACA99F9586868D7C626F625A55A6A9000000000000000000
0000000000000000
00000000000000000000000000000000C8BFBFC1BFBFC2BA
BFBFBFBABAB5B7CAD0D0D8D8D8CAB7AC99C095757FD8D8CF
C8BCB9CAD0D8D8D8D0D8D8D8D8D8D8D8D8D8D8D8D8D3D8D8
E0E0D8D8D8D8E0E0E0D8D8D8D8E0D8D8D8D8CFD3D0CAC2B3
A99595887A867C6F7C67626C537AD2000000000000000000
0000000000000000
000000000000000000000000000000C8C2C2C2BFBFBFBFC2
C2BABABAB5B1B7C8CAD8D8D8D0CAB7A79DA6957589CAC8CA
C8B1BAC0CAD0D0D3CDCAD0D8D0D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8E0D8E0E0E0D8D8D8D8D8D8D8D8D8D3D8CAC8BCB3
AB9590957C62867C7C6B6B6B4953D8C60000000000000000
0000000000000000
000000000000000000000000000000C8C2C2C2C8C8C2C2BF
C2C2B5B5B5ACB5C8CAD0D0D8D0CAB1A69DA69D7D99C8CAC8
BCACA7B5BAC8CACAC0C0CAD0D0D8D8D8D8D8D8CFD3D3D3D8
D8D8D8E0E0E0E0D8D8D8D8D8D8D8D8D8D3D8D2D3CAC0B5A9
958D867A64955A5A627C6F716267EFC90000000000000000
0000000000000000
000000000000000000000000000000C8C2C2C2C2C2BDBDBF
B5BDBDB5ACB1B7C0D0D3D0D8D8CAB1A69DB5896F7FD3CAC8
C8B7AC75B1BAC1B7BCB3BCBCBCC1CACAC0CAC8CACACACAD3
D8D8D8E0E0D8E0D8D8D8D8D8D8D8D8D8D8D8D3CACABCB7A9
9F8D8871817A717A716F62555653E6CF0000000000000000
0000000000000000
000000000000000000000000000000C8C2C2C2C8C2BDBDC2
B5B5B5B5AAACB5C0CAD0D0D0D0C8B1A69DC0895E7FD8CAC8
BCB3AC75B3B9B7ABABB3B3B3B3B7B7B5B3B3BCBCBFC2CACD
D3D8D8E0D8D8E0D8D8D8D8D8D8D8D8D8D3D3D3D3C0BCB7A3
9088717E81626F6C7A62627E756FD8C90000000000000000
0000000000000000
0000000000000000000000000000C8C2C8C8C2C2C2C2C2BD
BDBDB5ACAAACB5C0CACAD3D0D0C0ACA69D9D7D567FCDBCBC
B5ACA390B5B9B5ACB1B1BABCB3B3B1B1A7A3A3ACBABCC8CA
D8D3D8D8D8E0D8D8D8D8D8D8D8D8D8D8D3D3D3CACABDBAA3
998D95646295626B6F7A7A717192D2D8D700000000000000
0000000000000000
0000000000000000000000000000C8C2C2C2C8C2C2BDBDC0
BAB5B5AFAAA3B1B9C0C8CACACAC0B1A6899D7F5B7FCABCBF
BAB1A9A7BAB3B3B1B3BABABFBFBCB3ABAE9FA99595ACBABA
C2D3D3D8D8D8D8D8D8D8D8D8D8D8D8D8D3D3CDD3C8C8BDA3
8D887C8149627A4F6771818D95A6CFDDDD00000000000000
0000000000000000
0000000000000000000000000000C8C8C2C8C8C2C2BDBDBD
B5AFAFAAAAA5ACB7C0CAC8CAC8C1B1AC89997F677FC1BCC2
BFB7B181ACB1B1ABB3BCBCC1C1C1B6B3ABA395888D95ACA1
B7C8D3D8D8D8D8D0D8D3D8D8D8D8D8D3D3D8CACAC8C8B5A1
A379957A7C5A5A493267717C8D9DBDD7D200000000000000
0000000000000000
0000000000000000000000000000C8C8C8C2C2C2C2C2BDBD
B5B5ACA7A5A5ACB7BCC0C8CACAC8B1A78990A64D7FBCBCBC
BCBAB1A194ACACB3BCC1C1C1CAC1BFB3ACBFA9907190A3A7
90B7D3D8D8D8D3D3D8D8D8D8D0D3D3D3D8D3CACAC8C2B5A7
8D88868D5A7C627A49626F88C689CBCBCB00000000000000
0000000000000000
0000000000000000000000000000C8C2C2C2C2C2BFC2BDB5
B5AFACAAA399A3B1B7C0C8C1CABFB1AC898D8D65A1C1BFC1
C0BCBAB1A3ACB7BCCACACDC7CAC7B6C1B8B65E9F8D799595
718DCDD3D8D8D3D3D3D3D8D0D3D8D3D3D0CACAC8C8C0B5A3
99867C718662644F56495692C9BDC6D2C000000000000000
0000000000000000
0000000000000000000000000000C8C2C2C2C2BDC2BDBDBD
AFACACA7A19994ACB1B7BFBCC8C2BAB1A3898D5BA9BCBCBC
C2C2BCBCBCC0C0CACACFCDCFD2CDC9C9C7C97D65956F88A9
7161BCD0CFD8D3D3D3D3CAD3D3D3CDCDD3CACACAC8C2B5A1
81718D7C7A625A567A497A6BB8C0C6B4C200000000000000
0000000000000000
0000000000000000000000000000C8C2C8C2C2C2BFBDBDBD
B5AFA5A7A5998CA3ACB5B3BFBCBCBAACB1A37D4EABBABFC8
C8C1C2C8CACACACDCACDD8D8D2D2CFCDC9B990CB6C8B5FAB
7A55A9CACFD0D3CDCDCAD0D3D3D0D3CDC8CAC8CACABDACA1
8D6C7A7A7C6B5F5A555F555E9FBDC6A09A00000000000000
0000000000000000
0000000000000000000000000000C2C2C2BFC2C2BABDBDB5
B5ACA7A5A1909489A7ACB1BABCBCBABAB1B1AB61B1BAC8BC
C0C8C0C8CACACACDCDD0D8D2D2D2CDD2C1B6ABE9C28B7CA9
8D618DCAD3D3D3CACAD3CDCACACDD0CAC8CACAC8C8BCB195
81886C7C7C5A5A565555545EB6C6CFBD8B00000000000000
0000000000000000
0000000000000000000000000000C8BDC2C2C2BDC0BDBDB5
AFAFAA99A194898999AAB5B5BAB1BCBABAB3B79DB1BCBCC8
C0CAC8CACAD0CDCFD0D0D0D8D8D2D8C7C1A9CB6E50368395
C17A6FCACACDCACACACACACAD3CACAC8C8C8C8C8C8BCB799
817195955E5E4F543D556F71ABD5B49DA000000000000000
0000000000000000
0000000000000000000000000000C2BFBDC2C2C2C2BDBDB5
AFACA79999948C8686A1ACB3B3B5BABCBABABABABABABABC
CACAC8CACACACAD3D3D8D8D8D8D8D2C7B89D796FBD2A7A95
C7AC5EC7CACAC8CACAC8CACACACACAC8C8CAC8BFBAB1A999
8D867A626C545549555E6B71ABD2869A7800000000000000
0000000000000000
00000000000000000000000000C2C2C2BDBDBDBDBDC2BAB5
B5ACA79999908C897B99A3ACB1B3B1B3BABCBABABABCBFBC
C8C0C8CACACAD0CACDD2D0D8D0D2D2C1B98854620C366195
CAB971C7CAC7C7C0C0C8C0C0C8C8CACAC0C2C0C2BAB7B199
867188717A45554945546286ABBDA6A07A9A000000000000
0000000000000000
0000000000000000000000000000C2C8C2BDBDBFBDBABDBD
ACACACA199998C89817B99A3ACB1B1B1B3B3BABAB5BABCB7
BCC0C0C8C0CACACAD0D0D8D0D0D8D2C7B18D7E8567364699
C7C7719FC1C1CAC1BCC1C8C8C8C8C1C1C1BCBCBABCB3A999
86797C714555553D3D6C6486C79F866C6F00000000000000
0000000000000000
0000000000000000000000000000C8C8C2BDC2BDBDBABAAF
B5B1AAA199998C81867B7A90A3ACACACB1B1BAB1B5B7B7B7
BCBCC8C0C8C0C8C8CACDD2D2D8D2CDC7B19F7C5950493CA3
C1CA897CC7CAC1BFBCBFBCBCC2BCC1BFBFBCBCBAB3ABA990
887C7A884955493632546C8DC792787A8600000000000000
0000000000000000
0000000000000000000000000000C8C8BFBDBDBABDBABAB5
ACAFAAA7A1909481867B739999A1A7A9ACB1B1B1B1B1B7BA
B7B7BDBCC8C0C8CAC8CAD2D2D3CDC9C7AB9F7AA0A03C49A9
C1CA8D79C7BCBFC1BCC1BCBCBCBCBFBABABCBCB6B3AB9F8D
887A817A6666454536547A8DB3927A626100000000000000
0000000000000000
0000000000000000000000000000C8C2C8C2BFBAB5BDAFB1
ACAAA1A1A1999481897B73719099A3A3A3A9A9B1B5B1B1B1
B5B1B7B7BDC0C0C8CACACDD2CFCDCDC7B69F7C71285471A9
BCC0907CBCBCBABCBCBAB3B3B3B6BAB7B3BAB3B1B1A3A195
7C7C866B5E555545325E86A9B4837A678900000000000000
0000000000000000
0000000000000000000000000000C8C2C2C2BDB5BDAFAFAF
ACA7A5A199998C8C7A867B716694A199A3A3A3A3ACACACAC
ACACB1B5B5BAC0C0C0C0CACDCDCACACAB6AA88674F538DB1
BCC1867CB3B3B3B1B7B3B3B1B1B1B1B1BAB1B3ACA995958D
8D625F6B5A565645326C9FA98672627A9D00000000000000
0000000000000000
0000000000000000000000000000BDC2BDBFC0BAAFBDAFB5
ACA3A19999998C89817B7373716694999999A3A3A3ACACA7
ACACACACB1B5B7B7C0BCC7CACACDCACDC1BFAB887C7C8DB5
BCB37C95B1A9B1B3B1B1B1B1ABB1B1B1A9A3AB9595958888
956B6B5A5E64555449798DA6676F67839F00000000000000
0000000000000000
0000000000000000000000000000BDBFBABDBABABAAFB5AA
AAAAA199998E8C8186817A6C715E7A8E909D99A1A3A3A3AC
A3A3A3ACACB1B5B5B7BCC0C1CAC7CAC7C1C1B3A98D8690B3
B3AC7A9FABA9ABACABABABB1B1A9ABACA9ABA3A3958D8681
816F7A56665E546C5E7C957C786B549D9A00000000000000
0000000000000000
0000000000000000000000000000C2BDBDBDBABABDB5AFAC
AAA3A1998E8C8186817B737161665E5E8C8E99A3A1A19DA1
A1A3A3A3A3A7ACB1B5B3BABCC1C1C1C7C1B6B3A9958899AB
A9958895A3A3A9A9A9A9A9A9A9ABA3ACA995A9998888866C
867978496455545A818DB87A6B4F7C9F8900000000000000
0000000000000000
0000000000000000000000000000C2BDBABABABABAB1B1AA
A1A3A1948E8E817B7B7171646655544E4B818C8E99999999
9DA1A1A1999DA7ACA9ACB1B3B3C1C1B8BFB6B6B3A999A3A9
957A9599A9A3A395A395959FA999A3998D958D8879797A62
7A6F674F6C516262959F9D7A5A55868D9F00000000000000
0000000000000000
0000000000000000000000000000C2BABABDBAB5B5AFB1A3
A1A194948C8C7A73736C665E5054514B3D4979818E999999
90999099999D99A1ACA3A9B1B1B3B6BFBFB6B6B1ABA3A3A3
869995A19595A1999999A1A395998D8D8D8D7C7C717A716F
7C716F62645E7A8188C69A5E566F8181E000000000000000
0000000000000000
000000000000000000000000000000C2BAB5B5B5B5ACA7A1
9999948E817B7B7364554C514B3D453D392A3D5E7181818E
8E898E8E8E8E909099A1A3A3A9A9B1B1B3B1ABABA9A39599
998D9D998D9599908D908D88888D8D887C796C71646C5E6B
626F7C5564717A9F95928645627881A90000000000000000
0000000000000000
000000000000000000000000000000C2BAAFB5AFACA7A190
928C8C8D8C928C867B4C4845323D3D2A272A3D1F3654616C
7B7A817A898181818E8EA1A1A1A3A9A9A9A9ABA395959990
8D888D8D818D818D8686887C887C7C797A61646C5A4F5A54
6271645555867A95B49D865586957CF70000000000000000
0000000000000000
000000000000000000000000000000C2BDB5B5ACAC999494
8E99997B777366545E7B8C866C55493D3927171717282745
495E617171737379797A81898E999DA1999F99A195888D8D
81797979797A7981868671717C7A716C62555E5A5A4F566B
6F556C5666867AC1927A567C927CFFF70000000000000000
0000000000000000
000000000000000000000000000000BDBABDB5AA99A19497
A3948C7366544B55665E4C79A38D64625555393D170B1F36
273636455E645E716C6C6C7A7A818E8E909090888E817A81
796C6C717A7981797C6C6B716271625E555A5A4955494F6B
7C5A64566C9F9FB45F4975817C92F7F40000000000000000
0000000000000000
00000000000000000000000000000000BAB5AFAAA1A1AFA1
91817B715E6C66667B8C948154819999792A5E49365A4917
2A3D0B170B0B2A4955646661616C6C797A817A7979616161
6C6C6C797979716C6C6C5A6C5E5E554945455A4F55496749
5A676C64AC95B49D776F86787EF7F7000000000000000000
0000000000000000
00000000000000000000000000000000B5B5AAAAB1BDB399
817A7366736C735E4C44667B996C8D79A3A9865A5A49544F
493C2323171F00060B1F454955555E5E6C616C6C615E5E62
5E5E55556C5E6C555E5E49563D3636364936326B363C5662
3D6C647B95BF788686818195FFF7FF000000000000000000
0000000000000000
00000000000000000000000000000000B5BDAFAFBFBF948C
7A7B71716666544C44393D39649F7A5E86B1958D715A8155
625A493223171F172806323D3245495155555E54555E5555
543D6C3D496C49493D49553D323232363236321F4945496C
55717195AEB8786B81927EFFF7F7F4000000000000000000
0000000000000000
0000000000000000000000000000000000B5B5BFB1948E8E
86737173735E4839392749277351A1A9906681A9A3717164
6B5554493C4945362A323D3D32392A2A454949495149553D
553D1F493D453236493D32321F1F232A32232A173632676C
817A86ABBD81819F6C92FFF7F7F400000000000000000000
0000000000000000
0000000000000000000000000000000000BDAFAF94998E8C
7B736473734C443D4932274839818686ABAE8D5E958D9F66
71716C554F552A56452A493D3D3D3D27173D55321F3D453D
322A453D272A3D45272717171F231F1F1F2A171A49818871
867AABC7627AA66BA9F7F7F7FFF700000000000000000000
0000000000000000
0000000000000000000000000000000000BABFA399A1918C
815E736648484B6E75714C666E5E81979781ABA96C666679
8664555A5E64665549554955493D3D3D32322A0B171F2A2A
2A324532172A321F1F170B170B142A2A170C0B56456B6F6C
8195B49D9D9D95E9F7F7FFF7F7F700000000000000000000
0000000000000000
000000000000000000000000000000000000AAA1A1A18E81
646C6C6648325A4C5177868655714C81A1AA8C81A18C5E66
6C7B7B6C5545545E545E6454515549493D322A1F1F363636
2A2A3D17171F17171F0B23231A1F2A17060688557C717C8D
8DB8ACAE8181E9FFF7F7FFFFF70000000000000000000000
0000000000000000
000000000000000000000000000000000000B1A399948166
7B6C5E66546E6B66665A518C8D77716695ABAFA381739181
5E54666C716C6C64544B5466645E6C5E5E5555552A3D3249
36272A1717321717170B0B17171F170B367A787A716C8D86
ACB8AE86D1F7F4FFF7F7F7FFF70000000000000000000000
0000000000000000
00000000000000000000000000000000000000A5A181796C
715A5E6E72858586777777866E868C73868DCDBFBF8C8D7A
646666545454484B665E666466625E665E54555E553D3245
274F231F1F271F3223535F6B787C6C6B887C6C6C86A3A9B3
B89FD2F7FFF7F4F4F7F7F4F7000000000000000000000000
0000000000000000
00000000000000000000000000000000000000A5997A5E6C
716666758572858586928686857185927B8C8DCDBFBFB399
95554B6C5E5E545454665E5E64555E5E6C625E454949453D
495A5F628D9595716F626B6B6B888671716464798D95BFBF
BDF7F7F7F7F7F7F7F7F7FFF7000000000000000000000000
0000000000000000
000000000000000000000000000000000000000086667371
7377757785857B7B7571758C868686868C977B99CFBFBFBD
91AEA95E2A325E495454556F5E505E5E555E6C6C796C716C
5E6B6C6F627A7CA1957A6C71665E6C6C7B818D95AEBFBDEF
F7F7F7F7F7F7F7F7F7FFF400000000000000000000000000
0000000000000000
000000000000000000000000000000000000000085858592
8692858585778571718D8C738D8D717B8D6E8C9979A1C8BD
A8BD8C8DAB9579717A717188A1AE9F9F958886887179818D
797A795E5E5E6C867179646664798C8D9991B8C1BDF7F4F7
F7F7F7F7F7F7F4F7F4F7FF00000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000757586
929292928C86717B7B7B8C918666818D718C8C758C99AB99
C8A1A1AF948D918C8D9FA9A3A1A19599A38D95867A6C716C
6C716C7AA195A1A3959F95959F95A9B1ACCFE9F4F7F7F7F7
F7F7F7F7F7F4F7F7F7F40000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000007585
8C928CA8979797928C8C8C8D958D81817B81738C8C8D8CA1
ABAACDA197ABAA9997A1A1A1A195A19981817B6C7A666666
645E64716C797B818D95959FB4BFD1ECF7F7F7F7FFF7F7F7
F7F4FFF7F7F7F7F7FF000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000007575
7B9992A1A1A8A1A392A19795818DA3A18D8D8181817B8C8C
869195AFBFBFAAB1B1AFABA1A1A3A1A18D81817A8181818C
918D8D95816C627181AE9FABCEF7F7F7F4F7F4F4F7F4F7F7
F7F7F7F7F7F7F4F7F7000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000071
86868CAF99A3ABAFAFAFA1A1ABA19595A195978D8D7B918D
9195918C8181A1C1CDCDC1ABA99F6C51505E5A7171798D95
958DA19FABAE95646495DDF7F7F7F7F7F7F7F4FFF7F7FFF7
F7F7F7F7F7F4F7F700000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
81868D91ABAF99B1B1BDBFAB97A1A1AB8D9995918D8D7B7B
6C7A918D8D8D817B81798D91ABB1BDAFBDBDBFB1ABABABB3
BFAE886C6C6C6CACD2F7F7F7F7F4F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F4F7F70000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
007B7B718D8D95ABABC1C1BFC1ACABA1AFA3A1818199818D
958181666C798D817B917B71735E4C616C5E665050646C71
7A95738D9FBDF4F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7
F4F7F7F7F7F7000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00007B717B8D8C95A1AEABBDCFB1C1ABAEAEA1ABABA1817B
8D8D8D81798179716C5E545073796C5E555571958D8D8D95
9F9FCBE9F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F700000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000777B8C9791959577918D8DBDC9C7BDC1C1BDAB9999A1
A39F8C818D8681817A867A7A79798D88959FABAEA3A1A9DD
E9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F700000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000918C8D91817B8D817B7B8D8DABC1C9C1C1C1C1C1AB
A1A195A19595819586798195868195A9ABA1ABAEC6E6ECFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F70000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000099998D778D8D8D8D8D7795A19F959FBDC7C7C7C1
C1BFBFBDACAEACBFACBDB1AEAFABACC7D5D7E9F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000095ABABA1999586918DA39FAB8695A1959FA1AC
ACB8BDBDC6C6C7C7C6CFD5DDECEFF7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F700000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000ABABA19195959F9F959F95959FABAB9FAE95
8D95BDE9C6C6B89FCBCBECF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F70000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000A1A1ABB8A19591A1A1A1959FA19195A3
C9DDCBACACBDD2CBF4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000AEAEBDABABACAEBDACACB8D5DDE6D7
D5C1D7E9B8CBF4F7F7F7F7F7F7F7F7F4F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000ABB4AEBDBFC1CBE6E6DDE9E6E9E6
E9F4D7B8F7F7F7F4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000BDD7EFE6D7E6E9ECE9E6DDE6
E9E9D2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000ECDDE6E9ECEFE6E6E9E6D5
E9F7F7F7F4F4F7F4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000EFECECE9ECE6E6EFF7
F4F7F7F7F7F7F7F4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000E6E9F4F4F7F7F4
F7F7F7F7F7F7F7F4F7F7F7F7F7F7F7F7F4F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000ECF4F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F70000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
F7F7F7F7F7F7F4F7F7F7F4F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F70000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000F7F4F7F4F4F7F7F7F7F7F7F7F7F7F7F7F4F7F7F7F7
F7F7F7F70000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[52]:=",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00703ooonH000002H0ooooV000
000N0?ooo`00703ooonH000002H0ooooV000000N0?ooo`00703ooonH000002H0ooooV000000N0?oo
o`00703ooonH000002H0ooooV000000N0?ooo`00703ooonH000002H0ooooV000000N0?ooo`00703o
oonH000002H0ooooV000000N0?ooo`00703ooonH000002H0ooooV000000N0?ooo`00703ooonH0000
02H0ooooV000000N0?ooo`00703ooonH000002H0ooooV000000N0?ooo`00703ooonH000002H0oooo
V000000N0?ooo`00703ooonH000002H0ooooV000000N0?ooo`00703ooonH000002H0ooooV000000N
0?ooo`00703ooonH000002H0ooooV000000N0?ooo`00703ooonH000002H0ooooV000000N0?ooo`00
703ooonH000002H0ooooV000000N0?ooo`00703ooonH000002H0ooooC00000020<;2`TX000007P3o
ool001`0ooooV000000V0?oood`000000P32`/9:000001h0oooo000L0?oood/0000000<0VYZJ0000
00000000BP00000V0?oood0000001@32`/820;fm_@D0b<S80P32`/8<0<S8b3h000007P3oool001`0
ooooB`0000000`2JVYX000000000001:000002H0oooo>`0000030;fm_@80`/;20`2j^[X20;fm_@D0
`/;20P38b<P20<;2`P<0_Kfm1@32`/820<S8b080`/;21@38b<Pi000001h0oooo000L0?ooocX00000
00L0a/K60<W9b@39bLT0clo?0<W9b@3Hf=P0gMgM0080emOG00D0bl_;0=;BdP2d];@0X:2P0;fm_@02
09fMW@0409ZJVP2PX:00K6a/07YjNP80HV9R00@0IfMW07YjNP23Ph<0WIfM0P2OWil00`2=SHd0PH61
0:VYZ@020?Ogm`80m?Cd>`00000V0?ooocT000000P2e]KD80;Zj^P@0_Kfm0`38b<P20<;2`P80_Kfm
0`32`/820<S8b0D0`/;20P38b<P70<;2`SL000007P3oool001`0oooo>P0000001`36a/H0bLW90<W9
b@3?cll0bLW90=SHf03MgMd00P3GemL01@3;bl/0d];B0;Bd]02PX:00_Kfm0080WIfM00@0VYZJ0:2P
X01/K6`0NWYj0P1RHV80101WIfL0NWYj08>3P`2MWId209nOW`0308f=S@21PH40ZJVY0080moOg0P3d
m?@k000002H0oooo=00000030;Zj^P@0]KFe0`2m_Kd20:n_[`D0_Kfm0P2o_kl30<;2`P@0_Kfm2032
`/840<S8b0D0`/;20P31`L430;Zj^P80][Jf<P00000N0?ooo`00703ooolc0000000808>3P`29RHT0
OWin07inOP2EUID0YZJV07YjNP1CDe<206MWI`0405=CD`1_Kfl0TY:B0:JVYP80WIfM00D0RHV90;fm
_@30`<00_Kfm0<K6aP020=GEe@030=;BdP2m_Kd0WinO00<0TY:B00@0Ph>3079bLP1_Kfl0Jf][0P1?
Cdl01@1EEED0Kfm_07QhN02EUID0O7al0080TY:B0`3gmoL0103dm?@0moOg0?Ogm`3gmoLd000002H0
oooo<P0000020;6a/@<0_kno0P2e]KD20:ZZZPD0]KFe1@2j^[X20<30`0<0_kno0P32`/820;fm_@P0
`/;20P38b<P70<;2`PD0_kno0P2c/k<3038b<Rl000007P3oool001`0oooo<`0000002023Ph<0RHV9
07inOP1nOWh0UIFE0:JVYP1jNWX0De=C0P1WIfL0101CDe<0Kfm_09:BTP2VYZH209fMW@0508V9R@2m
_Kd0`<300;fm_@36a/H00P3EeMD00`3Bd]80_Kfm09nOW`0309:BTP0408>3P`1bLW80Kfm_06][J`80
Cdm?00D0EEEE06m_K`1hN7P0UIFE07alO00209:BTP<0moOg00@0m?Cd0?Ogm`3gmoL0moOg=000000V
0?oooc8000000P2a/K430;no_`80]KFe0P2ZZZX50;Fe]@D0^[Zj0P30`<030;no_`80`/;20P2m_Kd8
0<;2`P80b<S81`32`/850;no_`80/k>c0`0b<S8_000001h0oooo000L0?oooc<0000000P0Ph>308V9
R@1nOWh0OWin09FEU@2VYZH0NWYj05=CD`80IfMW00@0De=C06m_K`2BTY80YZJV0P2MWId01@29RHT0
_Kfm0<30`02m_Kd0a/K60080eMGE00<0d];B0;fm_@2OWil00`2BTY801023Ph<0LW9b06m_K`1[Jf/2
04m?C`0505EEE@1_Kfl0N7Qh09FEU@1lO7`00P2BTY830?Ogm`040?Cdm03gmoL0moOg0?Ogmc@00000
9P3oool`00000080YJFU1@2SXj<20;no_`D0ZZZZ0P2_[jl30;Fe]@L0^[Zj1`2m_Kd<0<;2`P@0_kno
0`2j^[X20;>c/`<09bLW0P14A4@]000001h0oooo000L0?ooobh000000`1WIfL20861P@0406][J`21
PH40EEEE05EEE@80FUYJ00P0K6a/06][J`1aLG40LG5a05EEE@1nOWh0LG5a08f=S@80O7al00<0R8R8
09:BTP1[Jf/00P1NGUh3075aL@80QXJ60`2=SHd20:VYZ@030:JVYP1lO7`0NWYj0080NWYj00@0GUiN
04E5A@1EEED0O7al0P21PH400`1hN7P0UIFE0?ooo`040?Ogm`80oooo0`3gmoL_000002H0oooo;@00
000308F5Q@L0VIVI102a/K4309VIV@80[:b/0`2e]KD20;fm_@80[jn_0`2e]KD40;fm_@<0`<301@2o
_kl70<;2`P80_kno0P38b<P30;fm_@80Bd];0`0i>CT205ADE080MGEe:`00000N0?ooo`00703oool^
000000<0IfMW0P21PH40101[Jf/0PH6105EEE@1EEED205YJFP0806a/K01[Jf/0LG5a075aL@1EEED0
OWin075aL@2=SHd207alO00308R8R02BTY80Jf][0080GUiN0`1aLG4208J6QP<0SHf=0P2YZJT00`2V
YZH0O7al07YjNP0207YjNP0405iNGP15ADD0EEEE07alO080PH6100<0N7Qh09FEU@3oool0103gmoL2
0?ooo`<0moOg;`00000V0?ooobd000000`25QHD207YjNP80U9BD0`2QXJ4209BDU080_Kfm0`2QXJ42
0:NWY`<0[jn_0P2e]KD50;fm_@80^[Zj0P32`/850;fm_@<0`/;20P2m_Kd20<;2`P<0_Kfm0P2o_kl2
0<S8b0<0_kno0P0b<S8304a<C080E5AD0P1aLG4[000001h0oooo000L0?ooob/0000000<0^;Rh0861
P@1[Jf/00P1jNWX01@2=SHd0Kfm_06m_K`1lO7`0IfMW0080HV9R00@0MGEe06m_K`1WIfL0Jf][0P1l
O7`0101_Kfl0HV9R07YjNP1aLG4206MWI`04069RHP19BDT0BDU905mOG`<0EEEE00<0GUiN05ADE01/
K6`00`1DE5@0101NGUh0K6a/07UiN@1lO7`208f=S@0509nOW`36a/H0TY:B09fMW@1jNWX00P19BDT0
101_Kfl0PH6109:BTP2BTY880?Ogm`030?ooo`3gmoL0m?Cd02`000009P3oool[00000080MGEe0`25
QHD205iNGP80PH610`2ATI4208j>SP80/k>c0`2DU9@20:6QX@<0/K6a1`2_[jl40;Zj^PX0_Kfm0P32
`/830;fm_@@0_kno0`2j^[X201lO7`<0FUYJ0P1DE5@206IVIP<0Lg=c:000000N0?ooo`00703oool[
000000030;Rh^021PH40Jf][0080NWYj00D0SHf=06m_K`1_Kfl0O7al06MWI`02069RHP0407EeM@1_
Kfl0IfMW06][J`80O7al00@0Kfm_069RHP1jNWX0LG5a0P1WIfL0101RHV80BDU904U9B@1OGel305EE
E@0305iNGP1DE5@0K6a/00<0E5AD00@0GUiN06a/K01iNGT0O7al0P2=SHd01@2OWil0a/K609:BTP2M
WId0NWYj0080BDU900@0Kfm_0861P@2BTY80TY:B203gmoL00`3oool0moOg0?Cdm00/000002H0oooo
:0000003075aL@80QHF50`2BTY8206a/K080IVIV0`2<S8`208j>SP80VIVI0`2GUiL2092@T0<0Xj>S
0P2/[:`20;Fe]@<0/K6a0P2_[jl50;Fe]@80_Kfm0`2e]KD40;fm_@<0_kno0P32`/820<71`@<0_;bl
0P0i>CT305ADE080FUYJ0P1DE5@307MgM`80SHf=9P00000N0?ooo`00703oool[000000030;Rh^021
PH40Jf][0080NWYj00D0SHf=06m_K`1_Kfl0O7al06MWI`02069RHP0407EeM@1_Kfl0IfMW06][J`80
O7al00@0Kfm_069RHP1jNWX0LG5a0P1WIfL0101RHV80BDU904U9B@1OGel305EEE@0305iNGP1DE5@0
K6a/00<0E5AD00@0GUiN06a/K01iNGT0O7al0P2=SHd01@2OWil0a/K609:BTP2MWId0NWYj0080BDU9
00@0Kfm_0861P@2BTY80TY:B203gmoL00`3oool0moOg0?Cdm00/000002H0oooo:0000003075aL@80
QHF50`2BTY8206a/K080IVIV0`2<S8`208j>SP80VIVI0`2GUiL2092@T0<0Xj>S0P2/[:`20;Fe]@<0
/K6a0P2_[jl50;Fe]@80_Kfm0`2e]KD40;fm_@<0_kno0P32`/820<71`@<0_;bl0P0i>CT305ADE080
FUYJ0P1DE5@307MgM`80SHf=9P00000N0?ooo`00703ooolW0000000709:BTP2h^;P0^;Rh0;Rh^02/
[:`0NWYj08f=S@0307alO00308J6QP1jNWX0Kfm_00<0PH6100@0Kfm_07alO01_Kfl0O7al0P1JFUX0
101jNWX0K6a/06][J`1?Cdl204U9B@0507YjNP1?Cdl0EUIF05YJFP1FEUH00P1DE5@204U9B@0303dm
?@0f=SH0ADE500<0ADE500T0E5AD06a/K01JFUX0FUYJ069RHP21PH40WinO09FEU@31`L400P2d];@0
102MWId0QXJ606][J`2OWil206][J`040>WYj@3oool0oooo0?Cdm0T0moOg:000000V0?ooobP00000
0`26QXH208b<S0<0QXJ60P1aLG4207]kN`<0PH610P26QXH20861P@<0Xj>S0P2BTY830:6QX@80ZZZZ
1@2/[:`40;Fe]@<0[jn_1`2e]KD20;fm_@<0]KFe0P32`/820;>c/`<0_;bl0P0b<S8303Ti>@80LG5a
0P1NGUh307=cL`80S8b<9P00000N0?ooo`00703ooolW0000000709:BTP2h^;P0^;Rh0;Rh^02/[:`0
NWYj08f=S@0307alO00308J6QP1jNWX0Kfm_00<0PH6100@0Kfm_07alO01_Kfl0O7al0P1JFUX0101j
NWX0K6a/06][J`1?Cdl204U9B@0507YjNP1?Cdl0EUIF05YJFP1FEUH00P1DE5@204U9B@0303dm?@0f
=SH0ADE500<0ADE500T0E5AD06a/K01JFUX0FUYJ069RHP21PH40WinO09FEU@31`L400P2d];@0102M
WId0QXJ606][J`2OWil206][J`040>WYj@3oool0oooo0?Cdm0T0moOg:000000V0?ooobH000000P1k
Ng/308J6QPD0TY:B0P1VIVH206a/K0<0GUiN0P1cLg<207YjNP<0U9BD0P2<S8`30:6QX@@0Xj>S0`2Z
ZZX20;6a/@80[:b/2P2_[jl50;fm_@80^[Zj1@2o_kl5038b<P80FUYJ0P1DE5@307=cL`80SHf=0P2Q
XJ4T000001h0oooo000L0?ooobD0000000<0PH610:VYZ@2d];@00P2f][H0102h^;P0YZJV09FEU@2E
UID208f=S@80UIFE00<0SHf=0861P@26QXH00P2=SHd0101lO7`0QXJ608J6QP1RHV8209FEU@0407Yj
NP1RHV80UIFE069RHP80FUYJ00D0O7al069RHP1RHV80Jf][05YJFP0205iNGP0405ADE015ADD0EEEE
05EEE@80IVIV00@0EEEE05IFEP1TI6@0GUiN0P1EEED00`1ADE40GUiN075aL@0208J6QP80WinO00@0
UIFE0;no_`2h^;P0PH610P1jNWX00`2MWId0PH610?Ogm`050?Ogm`030?Cdm03gmoL0moOg0080m?Cd
0P3gmoLV000002H0oooo9000000207MgM`80Ng]k1@2<S8`308F5Q@80IVIV0P1NGUh307=cL`80LG5a
0P1cLg<508b<S0<0U9BD1`2QXJ420:ZZZP80YjNW0`2ZZZX20:FUY@<0[:b/0P2_[jl20;Fe]@<0_Kfm
102j^[X30;Jf]P80>CTi0`0m?Cd405iNGP<0K6a/0P2<S8`20:6QX@<0kno_8@00000N0?ooo`00703o
oolU000000030861P@2YZJT0];Bd0080][Jf00@0^;Rh0:JVYP2EUID0UIFE0P2=SHd209FEU@0308f=
S@21PH40QXJ60080SHf=00@0O7al08J6QP26QXH0HV9R0P2EUID0101jNWX0HV9R09FEU@1RHV8205YJ
FP0507alO01RHV80HV9R06][J`1JFUX00P1NGUh0101DE5@0ADE505EEE@1EEED206IVIP0405EEE@1F
EUH0I6AT05iNGP80EEEE00<0DE5A05iNGP1aLG400P26QXH209nOW`0409FEU@2o_kl0^;Rh0861P@80
NWYj00<0WIfM0861P@3gmoL01@3gmoL00`3dm?@0moOg0?Ogm`020?Cdm080moOg9P00000V0?ooob@0
00000P1kNg/2075aL@<0[jn_0P2XZ:P308F5Q@80MGEe1@1VIVH207=cL`80IVIV0`1cLg<208f=S@<0
U9BD102IVIT50:6QX@D0VIVI0P2WYjL50:ZZZP80[:b/0`2e]KD20;Zj^PD0/k>c0P0m?Cd3038b<P80
GUiN0P1VIVH307]kN`80PH610P2QXJ430=GEeB4000007P3oool001`0oooo8@0000000`1[Jf/0PH61
0861P@0208f=S@0809fMW@2f][H0^;Rh0;Rh^02c/k<0[:b/0:^[Z`2^[Zh409nOW`0308f=S@2EUID0
SHf=0080UIFE00@0SHf=09FEU@28R8P0UIFE0P1jNWX0101aLG40OWin06ATI021PH4207YjNP0508f=
S@1aLG40O7al07YjNP1lO7`00P2EUID0101RHV80LG5a075aL@28R8P207YjNP80Jf][00H0FUYJ05IF
EP19BDT0BDU904m?C`1RHV8205EEE@<0EUIF00@0I6AT07]kN`2EUID0Zj^[0P37alL00`2MWId0[Zj^
08J6QP0@0?Ogmb8000009P3ooolQ000000<0VIVI0P2<S8`208f=S@<0VIVI0P2GUiL508F5Q@80E5AD
0`18B4P407=cL`<0IVIV1@2<S8`208j>SP80VIVI0`2QXJ4409VIV@<0XJ6Q0P2UYJD30:>SX`@0ZZZZ
0`2/[:`20;Fe]@80_;bl0`2c/k<203Ti>@<0:RXZ0P1<C4`2075aL@<0K6a/0P1kNg/209FEU@<0`L71
0P3_knlO000001h0oooo000L0?ooob40000000<0Jf][0861P@21PH400P2=SHd0202MWId0][Jf0;Rh
^02h^;P0/k>c0:b/[02[Zj/0[Zj^102OWil00`2=SHd0UIFE08f=S@0209FEU@0408f=S@2EUID0R8R8
09FEU@80NWYj00@0LG5a07inOP1TI6@0PH610P1jNWX01@2=SHd0LG5a07alO01jNWX0O7al0080UIFE
00@0HV9R075aL@1aLG40R8R80P1jNWX206][J`0605YJFP1FEUH0BDU904U9B@1?Cdl0HV9R0P1EEED3
05IFEP0406ATI01kNg/0UIFE0:^[Z`80alO700<0WIfM0:j^[P26QXH0403gmoLR000002H0oooo8@00
000309VIV@80UiNG0P2=SHd30:>SX`80UiNG0`1gMgL2079bLP80KVi^0`18B4P205iNGP80K6a/0`1D
E5@209:BTPD0S8b<1`2IVIT2092@T0<0U9BD1@2IVIT20:FUY@80[:b/1`2a/K430;>c/`80A4A40`0m
?Cd204A4A080IVIV0`1NGUh207=cL`80SHf=0`2h^;P20?Cdm1l000007P3oool001`0oooo8@000000
0`1[Jf/0PH610861P@0208f=S@0809fMW@2f][H0^;Rh0;Rh^02c/k<0[:b/0:^[Z`2^[Zh409nOW`03
08f=S@2EUID0SHf=0080UIFE00@0SHf=09FEU@28R8P0UIFE0P1jNWX0101aLG40OWin06ATI021PH42
07YjNP0508f=S@1aLG40O7al07YjNP1lO7`00P2EUID0101RHV80LG5a075aL@28R8P207YjNP80Jf][
00H0FUYJ05IFEP19BDT0BDU904m?C`1RHV8205EEE@<0EUIF00@0I6AT07]kN`2EUID0Zj^[0P37alL0
0`2MWId0[Zj^08J6QP0@0?Ogmb8000009P3ooolQ000000<0VIVI0P2GUiL208f=S@<0Xj>S0P2GUiL3
07MgM`80LW9b0P1^KVh304Q8B080GUiN0P1/K6`305ADE080TY:B1@2<S8`709VIV@80T92@0`2DU9@5
09VIV@80YJFU0P2/[:`70;6a/@<0/k>c0P14A4@303dm?@80A4A40P1VIVH305iNGP80Lg=c0P2=SHd3
0;Rh^080m?Cd7`00000N0?ooo`00703ooolO0000000305IFEP1aLG40NWYj0080HV9R00<0SHf=09nO
W`2m_Kd01039bLT20<71`@050;Rh^02f][H0][Jf0:VYZ@2/[:`00P2[Zj/00`2YZJT0Zj^[0:^[Z`02
0:VYZ@80UIFE0`2=SHd00`28R8P0SHf=08R8R00207UiN@0508R8R026QXH0LG5a06a/K028R8P00P1a
LG401026QXH0LG5a07UiN@1lO7`207YjNP0407alO01RHV80Jf][06m_K`80NGUi00D0Kfm_075aL@1_
Kfl0LG5a05EEE@0205YJFP0306MWI`1/K6`0LG5a00<0NWYj00@0UIFE0;Rh^02h^;P0WinO1@3gmoL0
0`3dm?@0moOg0?Ogm`090?Ogmb0000009P3ooolO00000080Zj^[0`2=SHd2096AT@80UIFE0`2[Zj/2
09NGU`D0QHF50P1[Jf/304];B`80B4Q80P1cLg<304];B`80S8b<0`1jNWX20861P@80S8b<0`2DU9@4
08b<S0<0RHV90P2<S8`30:>SX`80[:b/0P2e]KD50;Ng]`80`L710`2a/K4703dm?@80GUiN0`1VIVH2
06a/K080PH610`2^[Zh20>c/k0<0lO7a7000000N0?ooo`00703ooolO0000000305IFEP1aLG40NWYj
0080HV9R00<0SHf=09nOW`2m_Kd01039bLT20<71`@050;Rh^02f][H0][Jf0:VYZ@2/[:`00P2[Zj/0
0`2YZJT0Zj^[0:^[Z`020:VYZ@80UIFE0`2=SHd00`28R8P0SHf=08R8R00207UiN@0508R8R026QXH0
LG5a06a/K028R8P00P1aLG401026QXH0LG5a07UiN@1lO7`207YjNP0407alO01RHV80Jf][06m_K`80
NGUi00D0Kfm_075aL@1_Kfl0LG5a05EEE@0205YJFP0306MWI`1/K6`0LG5a00<0NWYj00@0UIFE0;Rh
^02h^;P0WinO1@3gmoL00`3dm?@0moOg0?Ogm`090?Ogmb0000009P3ooolO00000080Zj^[0`1gMgL2
09FEU@80Zj^[0`2_[jl209:BTP<0LG5a0P25QHD206IVIP<0KVi^0P0i>CT205iNGP<0EEEE0P26QXH3
07=cL`80QXJ60P29RHT50861P@D0RHV90P2SXj<30;6a/@80]kNg1@30`<020<S8b080b/[:0`37alL2
05ADE0<0?Cdm0P15ADD205iNGP<0Ng]k0P1cLg<20861P@<0Zj^[0P3Vi^H30?7alA`000007P3oool0
01`0oooo7P000000101[Jf/0HV9R075aL@1lO7`209FEU@040:^[Z`2o_kl0][Jf0;Rh^0<0_;bl1@3:
b/X00`37alL0`L710<71`@020<71`@80_;bl00@0][Jf0;6a/@2c/k<0/k>c0`2YZJT30:>SX`80XJ6Q
00D0YjNW0:>SX`2QXJ40XJ6Q09FEU@0509VIV@07092@T02=SHd0SHf=09FEU@2=SHd0R8R80861P@02
06a/K004069RHP1_Kfl0Jf][05ADE0<0Jf][00@0BDU9069RHP1/K6`0K6a/0P1aLG40101/K6`0SHf=
08J6QP2c/k<20;no_`030>o_k`3gmoL0moOg00d0moOg7`00000V0?oooal000000P2QXJ4308f=S@80
UIFE0P2[Zj/30:n_[`80S8b<0`1aLG4208J6QP80IVIV0`1eMGD203Ti>@80C4a<0`1VIVH207]kN`<0
Lg=c1021PH4308V9R@80QXJ60P1kNg/309VIV@80[:b/0`2g]kL20<30`080b/[:0`3@d=020<[:bP80
d=3@0`3=cLd208J6QP<0?Cdm0P18B4P204a<C0D0GUiN0P21PH430:6QX@80clo?0`3dm?@L000001h0
oooo000L0?oooah0000000@0Jf][069RHP1aLG40O7al0P2EUID0102[Zj/0_kno0;Jf]P2h^;P30;bl
_0D0b/[:00<0alO70<71`@31`L400P31`L420;bl_0040;Jf]P2a/K40/k>c0;>c/`<0ZJVY0`2SXj<2
0:6QX@050:NWY`2SXj<0XJ6Q0:6QX@2EUID01@2IVIT01`2@T900SHf=08f=S@2EUID0SHf=08R8R021
PH400P1/K6`0101RHV80Kfm_06][J`1DE5@306][J`0404U9B@1RHV80K6a/06a/K080LG5a00@0K6a/
08f=S@26QXH0/k>c0P2o_kl00`3_knl0moOg0?Ogm`0=0?Ogmal000009P3ooolM00000080[Zj^0P2A
TI4308f=S@80MgMg0P31`L430:n_[`80S8b<0`2=SHd209:BTP80FUYJ0`1aLG4202LW9`80A4A40`1N
GUh204a<C0<0K6a/2@1kNg/209VIV@<0ZZZZ0P2e]KD30<30`0@0b/[:0`3Cdm<70=SHf080cLg=0`0m
?Cd204];B`80<S8b0`1NGUh207=cL`80NGUi0`2EUID20<o?c`<0m?Cd0P3alO4J000001h0oooo000L
0?oooa/000000P1DE5@01@1FEUH0GUiN075aL@26QXH0UIFE0080WinO00@0^;Rh0;bl_031`L40b<S8
0P30`<020=3@d080clo?0P3=cLd01@3:b/X0d=3@0=?Cd`3Cdm<0f=SH0080cLg=00@0clo?0<[:bP3:
b/X0b<S80P30`<020;bl_0080;fm_@38b<P0b<S80<S8b032`/80`<300<;2`P2m_Kd30;bl_0030;6a
/@2g]kL0/k>c00<0Zj^[00@0Xj>S09FEU@2EUID0SHf=0P28R8P00`1iNGT0NWYj06a/K00204m?C`<0
BDU900<0?3`l04E5A@0b<S800P21PH40101[Jf/0LG5a06a/K02SXj<209FEU@050;no_`3gmoL0moOg
0?Ogm`3dm?@00`3gmoL00`3oool0moOg0?Ogm`080?Ogma`000009P3ooolM00000080[Zj^0P2EUID3
08f=S@80TI6A0P31`L430:6QX@D0S8b<0P26QXH2055AD@<0C4a<0P19BDT206IVIP<0C4a<0P18B4P3
06IVIPL0Lg=c0P1jNWX20:>SX`<0]KFe0P2c/k<50<S8b080dm?C0`3@d=070=SHf080cLg=0`39bLT2
04];B`80<S8b0`1NGUh206IVIP80K6a/0`2EUID20<O7a`<0jNWY0P3gmoLJ000001h0oooo000L0?oo
oa/000000P1DE5@01@1FEUH0GUiN075aL@26QXH0UIFE0080WinO00@0^;Rh0;bl_031`L40b<S80P30
`<020=3@d080clo?0P3=cLd01@3:b/X0d=3@0=?Cd`3Cdm<0f=SH0080cLg=00@0clo?0<[:bP3:b/X0
b<S80P30`<020;bl_0080;fm_@38b<P0b<S80<S8b032`/80`<300<;2`P2m_Kd30;bl_0030;6a/@2g
]kL0/k>c00<0Zj^[00@0Xj>S09FEU@2EUID0SHf=0P28R8P00`1iNGT0NWYj06a/K00204m?C`<0BDU9
00<0?3`l04E5A@0b<S800P21PH40101[Jf/0LG5a06a/K02SXj<209FEU@050;no_`3gmoL0moOg0?Og
m`3dm?@00`3gmoL00`3oool0moOg0?Ogm`080?Ogma`000009P3ooolM00000080[Zj^0P2EUID308f=
S@80TI6A0P31`L430:6QX@D0S8b<0P26QXH2055AD@<0C4a<0P19BDT206IVIP<0C4a<0P18B4P306IV
IPL0Lg=c0P1jNWX20:>SX`<0]KFe0P2c/k<50<S8b080dm?C0`3@d=070=SHf080cLg=0`39bLT204];
B`80<S8b0`1NGUh206IVIP80K6a/0`2EUID20<O7a`<0jNWY0P3gmoLJ000001h0oooo000L0?oooa/0
00000P1DE5@01@1FEUH0GUiN075aL@26QXH0UIFE0080WinO00@0^;Rh0;bl_031`L40b<S80P30`<02
0=3@d080clo?0P3=cLd01@3:b/X0d=3@0=?Cd`3Cdm<0f=SH0080cLg=00@0clo?0<[:bP3:b/X0b<S8
0P30`<020;bl_0080;fm_@38b<P0b<S80<S8b032`/80`<300<;2`P2m_Kd30;bl_0030;6a/@2g]kL0
/k>c00<0Zj^[00@0Xj>S09FEU@2EUID0SHf=0P28R8P00`1iNGT0NWYj06a/K00204m?C`<0BDU900<0
?3`l04E5A@0b<S800P21PH40101[Jf/0LG5a06a/K02SXj<209FEU@050;no_`3gmoL0moOg0?Ogm`3d
m?@00`3gmoL00`3oool0moOg0?Ogm`080?Ogma`000009P3ooolM00000080_Kfm0P2EUID508f=S@80
_kno0`2QXJ4208f=S@<0Lg=c0P26QXH208b<S0<0IVIV0P0W9bL207]kN`<0NGUi0P15ADD305iNGP80
LG5a0P1cLg<3075aL@80T92@0P2/[:`30;Fe]@80_kno0`31`L420<[:bP80d=3@1`3Hf=P30=?Cd`80
b/[:0`3?cll203dm?@80>CTi0`1NGUh206IVIP80Lg=c0`2=SHd20;fm_@<0jNWY0P3dm?@J000001h0
oooo000L0?oooaX0000000@0FUYJ07YjNP1jNWX0EUIF0P1jNWX0202=SHd0WinO0;>c/`2c/k<0_kno
0<O7a`3:b/X0b<S80P3:b/X20=?Cd`060=SHf03Cdm<0d];B0=;BdP3Hf=P0dm?C1P3Hf=P20=?Cd`07
0=SHf03Cdm<0dm?C0<[:bP3Cdm<0b/[:0=?Cd`030<[:bP030<S8b03:b/X0b/[:00<0b<S800@0_kno
0<;2`P2j^[X0^[Zj0P2f][H0102a/K40[:b/09FEU@2SXj<209VIV@0508R8R01lO7`0LG5a06a/K01J
FUX00P19BDT0101?Cdl0Jf][01lO7`0G5aL201XJ6P0405IFEP1EEED0NWYj06a/K080NGUi00D0UIFE
0<71`@3dm?@0moOg0?Cdm0020?ooo`d0moOg6`00000V0?oooaX000000`2m_Kd20:^[Z`80WinO1@2=
SHd20<71`@<0Zj^[0P2EUID308f=S@80QHF50P2=SHd306i^KP80Lg=c0P2IVIT30:>SX`80<S8b0`1@
D502065QH@80LG5a0`2@T9020:>SX`80/K6a0`2j^[X20;bl_0<0b/[:0P38b<P20=3@d0<0f=SH103@
d=050=?Cd`<0cLg=0P1NGUh203dm?@D0GUiN0P1/K6`308f=S@80[:b/0`3MgMd20?7al@80k>c/6000
000N0?ooo`00703ooolJ0000000405YJFP1jNWX0NWYj05IFEP80NWYj00P0SHf=09nOW`2c/k<0/k>c
0;no_`37alL0b/[:0<S8b080b/[:0P3Cdm<01P3Hf=P0dm?C0=;BdP3Bd]80f=SH0=?Cd`H0f=SH0P3C
dm<01`3Hf=P0dm?C0=?Cd`3:b/X0dm?C0<[:bP3Cdm<00`3:b/X00`38b<P0b/[:0<[:bP030<S8b004
0;no_`32`/80^[Zj0;Zj^P80][Jf00@0/K6a0:b/[02EUID0Xj>S0P2IVIT01@28R8P0O7al075aL@1/
K6`0FUYJ0080BDU900@0Cdm?06][J`0O7al05aLG0P0J6QX0101FEUH0EEEE07YjNP1/K6`207UiN@05
09FEU@31`L40m?Cd0?Ogm`3dm?@00P3oool=0?Ogma/000009P3ooolJ000000<0emOG0P2[Zj/209nO
W`<0MgMg0P2m_Kd20:b/[0<0XJ6Q1@2=SHd2075aL@80MgMg0`1NGUh2055AD@80K6a/0`2=SHd203dm
?@<0E5AD101VIVH309VIV@80[:b/0P2c/k<30;6a/@80_;bl0`2o_kl20<71`@80`<301`3:b/X30=3@
d080dm?C1@3=cLd2051@D0<0?Cdm0P1NGUh206ATI0<0NGUi0P2OWil30<o?c`80jNWY0P3gmoLH0000
01h0oooo000L0?oooaP0000000<0Kfm_06][J`1JFUX00P1RHV801@1OGel0HV9R07UiN@2EUID0WinO
0080/k>c00<0b<S80<[:bP3:b/X00`3Cdm<20=SHf0030=?Cd`3Hf=P0f=SH00l0f=SH0`3Cdm<20=SH
f0030=?Cd`3:b/X0b/[:0080b/[:0P38b<P00`3:b/X0`/;20;bl_0030;bl_0040;Zj^P2a/K40Xj>S
0:^[Z`<0UIFE00@0SHf=07UiN@1QHF40EEEE0P1JFUX01015ADD0=SHf03Hf=P0S8b<202XZ:P0400`<
30061PH0NWYj07alO080I6AT00<0PH61096AT@3?cll04`3gmoLI000002H0oooo6P0000030>o_k`80
[:b/1@2EUID20<W9b@80Zj^[0`2EUID20861P@<0LG5a0P25QHD2075aL@<0PH610P2QXJ4208f=S@<0
I6AT0P0m?Cd3055AD@80GUiN0P2DU9@30:>SX`80[:b/0P2a/K430;bl_080^[Zj1@2a/K420:b/[0<0
/K6a0P2g]kL20;bl_0D0b/[:1@3=cLd203Ti>@<0?Cdm101NGUh307UiN@80UIFE0`3?cll20>WYj@80
moOg6000000N0?ooo`00703ooolH0000000306m_K`1[Jf/0FUYJ0080HV9R00D0GemO069RHP1iNGT0
UIFE09nOW`020;>c/`030<S8b03:b/X0b/[:00<0dm?C0P3Hf=P00`3Cdm<0f=SH0=SHf00?0=SHf0<0
dm?C0P3Hf=P00`3Cdm<0b/[:0<[:bP020<[:bP80b<S800<0b/[:0<;2`P2l_;`00`2l_;`0102j^[X0
/K6a0:>SX`2[Zj/309FEU@0408f=S@1iNGT0HF5Q05EEE@80FUYJ00@0ADE503Hf=P0f=SH08b<S0P0Z
:RX0100<30`01PH607YjNP1lO7`206ATI0030861P@2ATI40clo?01<0moOg6@00000V0?oooaP00000
0P3_knl30>KViP80[Zj^0P2OWil30:6QX@80alO70P2QXJ4309FEU@80PH610`1kNg/209:BTP80IVIV
0`2GUiL20:VYZ@80NGUi0`1RHV8202XZ:P<0Bd];0P1NGUh209VIV@<0Xj>S0P2/[:`20;>c/`<0^[Zj
1`2/[:`50:JVYP80YjNW0P2e]KD30<71`@80b/[:0`3=cLd20<o?c`80bLW90`0m?Cd205ADE080EEEE
0`1kNg/209FEU@<0bl_;0P3YjNT20?Cdm0<0moOg5@00000N0?ooo`00703ooolH0000000306m_K`1[
Jf/0FUYJ0080HV9R00D0GemO069RHP1iNGT0UIFE09nOW`020;>c/`030<S8b03:b/X0b/[:00<0dm?C
0P3Hf=P00`3Cdm<0f=SH0=SHf00?0=SHf0<0dm?C0P3Hf=P00`3Cdm<0b/[:0<[:bP020<[:bP80b<S8
00<0b/[:0<;2`P2l_;`00`2l_;`0102j^[X0/K6a0:>SX`2[Zj/309FEU@0408f=S@1iNGT0HF5Q05EE
E@80FUYJ00@0ADE503Hf=P0f=SH08b<S0P0Z:RX0100<30`01PH607YjNP1lO7`206ATI0030861P@2A
TI40clo?01<0moOg6@00000V0?oooaP000000P3_knl30>KViP80[Zj^0P2OWil30:6QX@80alO70P2Q
XJ4309FEU@80PH610`1kNg/209:BTP80IVIV0`2GUiL20:VYZ@80NGUi0`1RHV8202XZ:P<0Bd];0P1N
GUh209VIV@<0Xj>S0P2/[:`20;>c/`<0^[Zj1`2/[:`50:JVYP80YjNW0P2e]KD30<71`@80b/[:0`3=
cLd20<o?c`80bLW90`0m?Cd205ADE080EEEE0`1kNg/209FEU@<0bl_;0P3YjNT20?Cdm0<0moOg5@00
000N0?ooo`00703ooolG0000000404m?C`1JFUX0EUIF04m?C`80EUIF00D0FUYJ06][J`1aLG40UIFE
0:j^[P030<71`@030<[:bP3Cdm<0dm?C00H0f=SH0`3Ph>0@0=SHf0@0dm?C0P3=cLd01`3:b/X0b<S8
0<S8b038b<P0b/[:0<71`@2o_kl00P2j^[X00`2g]kL0/K6a0;6a/@030:b/[00509VIV@2=SHd0R8R8
07UiN@1/K6`00P1NGUh01019BDT0=SHf03Hf=P0Z:RX201lO7`0402XZ:P0G5aL02`/;06][J`80LG5a
00@0K6a/08f=S@2a/K40k>c/4`3gmoLH000002H0oooo600000020>c/k0<0emOG0P2m_Kd209FEU@<0
WinO0P2m_Kd20:n_[`<0XJ6Q0P1kNg/308f=S@80Ng]k0P2EUID309NGU`80T92@0P2SXj<305EEE@80
9bLW0`0m?Cd208b<S080VIVI0`2SXj<20;6a/@D0^[Zj0P2a/K4508V9R@L0WIfM0P2IVIT309FEU@80
b<S81@3:b/X20<g=c@<0A4A40P0m?Cd205EEE@<0IVIV0P21PH430<k>cP80emOG0P3dm?@30>o_kaD0
00007P3oool001`0oooo5`000000101?Cdl0FUYJ05IFEP1?Cdl205IFEP0505YJFP1[Jf/0LG5a09FE
U@2^[Zh00`31`L400`3:b/X0dm?C0=?Cd`060=SHf0<0h>3P403Hf=P40=?Cd`80cLg=00L0b/[:0<S8
b038b<P0b<S80<[:bP31`L40_kno0080^[Zj00<0]kNg0;6a/@2a/K400`2/[:`01@2IVIT0SHf=08R8
R01iNGT0K6a/0080GUiN00@0BDU903Hf=P0f=SH0:RXZ0P0O7al0100Z:RX05aLG00/;2`1[Jf/2075a
L@0406a/K02=SHd0/K6a0>c/k1<0moOg6000000V0?oooaP000000P3/k>`30>KViP80[:b/1@2EUID2
0<71`@80Xj>S0`2EUID20861P@<0KVi^0P2<S8`20:^[Z`<0PH610P1VIVH20:VYZ@<0EEEE0P0Z:RX3
04U9B@80SXj>0P2IVIT30:VYZ@80/K6a0P2l_;`30;>c/`80Xj>S0`2=SHd209VIV@80WIfM0`2e]KD2
0:JVYP80cLg=0`2MWId20:JVYP<0cLg=0P3:b/X20<g=c@<0Bd];0P15ADD204];B`<0IVIV0P1jNWX3
0:j^[P80gMgM1@3gmoLE000001h0oooo000L0?oooaD000000`1EEED00`1DE5@0EEEE05EEE@0204m?
C`0505EEE@1/K6`0O7al08f=S@2OWil00P2f][H01031`L40b/[:0=?Cd`3Cdm<40=SHf0030>3Ph03H
f=P0h>3P00D0h>3P00<0f=SH0>3Ph03Ph>000P3Hf=P00`3Ph>00f=SH0=SHf0070=SHf0050=?Cd`3H
f=P0dm?C0=3@d03=cLd00`3:b/X20<S8b0<0_;bl00@0][Jf0;6a/@2a/K40ZJVY0P2[Zj/209VIV@03
08f=S@1lO7`0NWYj0080LG5a00@0GUiN03Hf=P0b<S807alO0P0S8b<0100D51@07alO01lO7`1lO7`2
08R8R00405iNGP1iNGT0UIFE0;no_`<0moOg00<0m?Cd0?Ogm`3gmoL03P3gmoLG000002H0oooo6000
00050>WYj@80[:b/1@2OWil20<71`@80XJ6Q0`2GUiL207=cL`<0S8b<0P2=SHd20:n_[`<0Zj^[0P21
PH4208J6QP<0>CTi0P0m?Cd307UiN@80VIVI0P2SXj<30:VYZ@@0^[Zj0`2g]kL207emO@<0SHf=0P1o
Ogl207emO@<0RHV9102EUID309fMW@80VIVI0`38b<P20<[:bP80clo?0`21PH4203dm?@D0GUiN0P1j
NWX309FEU@80bl_;1@3gmoLE000001h0oooo000L0?oooaD000000`1EEED00`1DE5@0EEEE05EEE@02
04m?C`0505EEE@1/K6`0O7al08f=S@2OWil00P2f][H01031`L40b/[:0=?Cd`3Cdm<40=SHf0030>3P
h03Hf=P0h>3P00D0h>3P00<0f=SH0>3Ph03Ph>000P3Hf=P00`3Ph>00f=SH0=SHf0070=SHf0050=?C
d`3Hf=P0dm?C0=3@d03=cLd00`3:b/X20<S8b0<0_;bl00@0][Jf0;6a/@2a/K40ZJVY0P2[Zj/209VI
V@0308f=S@1lO7`0NWYj0080LG5a00@0GUiN03Hf=P0b<S807alO0P0S8b<0100D51@07alO01lO7`1l
O7`208R8R00405iNGP1iNGT0UIFE0;no_`<0moOg00<0m?Cd0?Ogm`3gmoL03P3gmoLG000002H0oooo
5@0000080>c/k080^;Rh0P2[Zj/50;fm_@80PH610`2=SHd208b<S0<0VIVI0P3=cLd20:>SX`D0ZJVY
0P1JFUX303dm?@807alO0`21PH440:>SX`D0/K6a0P2j^[X309fMW@80CTi>0`1UIFD206MWI`80EUIF
0`1_Kfl207EeM@80NGUi0`1WIfL207UiN@<0YZJV0P3:b/X20<o?c`<0d];B100i>CT305iNGP80I6AT
0`2EUID20<?3``L0m?Cd4`00000N0?ooo`00703ooolD000000<0EUIF0P1EEED0101DE5@0FUYJ05EE
E@1EEED2069RHP0307YjNP2=SHd0WinO0080Zj^[00<0_kno0<[:bP3?cll01@3Hf=P20>3Ph080f=SH
00<0h>3P0=SHf03Ph>00103Hf=P00`3Ph>00f=SH0=SHf00:0=SHf0030=3@d03Cdm<0dm?C00@0b/[:
00<0`<300<S8b02l_;`00P2l_;`0102c/k<0/K6a0;6a/@2a/K420:VYZ@0409nOW`2SXj<0R8R807al
O0<0LG5a00@0K6a/05IFEP0m?Cd0<S8b0`0G5aL00`0S8b<05aLG06][J`0206][J`05075aL@1VIVH0
UIFE09nOW`2[Zj/05@3gmoLE000002H0oooo5@0000030?Cdm080i^KV0`3YjNT20=GEe@80Zj^[0`37
alL20:^[Z`80PH610`2=SHd208b<S0<0NGUi0P2o_kl20861P@<0K6a/0P2SXj<205YJFP<05aLG0P0f
=SH308j>SP80XJ6Q0P2SXj<50;Fe]@80^[Zj0`2a/K420:^[Z`<0XJ6Q1`1oOgl708V9R@80YZJV0`30
`<020<[:bP80clo?0`3Bd]8204i>CP80Bd];0`1DE5@205EEE@<0PH610P2m_Kd20>WYj@<0kno_0P3d
m?@C000001h0oooo000L0?oooa@000000`1FEUH205EEE@0405ADE01JFUX0EEEE05EEE@80HV9R00<0
NWYj08f=S@2OWil00P2[Zj/00`2o_kl0b/[:0<o?c`050=SHf080h>3P0P3Hf=P00`3Ph>00f=SH0>3P
h0040=SHf0030>3Ph03Hf=P0f=SH00X0f=SH00<0d=3@0=?Cd`3Cdm<0103:b/X00`30`<00b<S80;bl
_0020;bl_0040;>c/`2a/K40/K6a0;6a/@80ZJVY00@0WinO0:>SX`28R8P0O7al0`1aLG40101/K6`0
EUIF03dm?@0b<S8301LG5`0302<S8`0G5aL0Jf][0080Jf][00D0LG5a06IVIP2EUID0WinO0:^[Z`0E
0?OgmaD000009P3ooolE000000<0moOg1@3Vi^H20=gMg@80WinO0`37alL409VIV@<0Ng]k0P2=SHd3
0:6QX@80_kno0P1cLg<306IVIP80LG5a0P19BDT300/;2`80E5AD0`2IVIT20:6QX@80[:b/0`2a/K42
0;Ng]`D0_;bl0P2j^[X50<71`@80cLg=0`3Cdm<40<[:bP<0f=SH0P3Cdm<70<g=c@<0b/[:0P1DE5@2
04];B`<0D51@0P1NGUh306a/K080[Zj^0P3Vi^H30>c/k080moOg4`00000N0?ooo`00703ooolD0000
00<0EUIF0P1EEED0101DE5@0FUYJ05EEE@1EEED2069RHP0307YjNP2=SHd0WinO0080Zj^[00<0_kno
0<[:bP3?cll01@3Hf=P20>3Ph080f=SH00<0h>3P0=SHf03Ph>00103Hf=P00`3Ph>00f=SH0=SHf00:
0=SHf0030=3@d03Cdm<0dm?C00@0b/[:00<0`<300<S8b02l_;`00P2l_;`0102c/k<0/K6a0;6a/@2a
/K420:VYZ@0409nOW`2SXj<0R8R807alO0<0LG5a00@0K6a/05IFEP0m?Cd0<S8b0`0G5aL00`0S8b<0
5aLG06][J`0206][J`05075aL@1VIVH0UIFE09nOW`2[Zj/05@3gmoLE000002H0oooo5@0000030?Og
m`D0i^KV0P3MgMd209nOW`<0alO7102IVIT307]kN`80SHf=0`2QXJ420;no_`80Lg=c0`1VIVH2075a
L@80BDU90`0;2`/205ADE0<0VIVI0P2QXJ420:b/[0<0/K6a0P2g]kL50;bl_080^[Zj1@31`L420<g=
c@<0dm?C103:b/X30=SHf080dm?C1`3=cLd30<[:bP80E5AD0P1;Bd/3051@D080GUiN0`1/K6`20:j^
[P80i^KV0`3/k>`20?Ogma<000007P3oool001`0oooo4`0000000`1?Cdl0GUiN06][J`0206][J`03
05YJFP1RHV80EEEE0080EUIF00D0Jf][069RHP1aLG40R8R809FEU@020:^[Z`030<71`@3:b/X0dm?C
00<0dm?C0`3Hf=P30>3Ph080f=SH0P3Ph>030=SHf0030>3Ph03Hf=P0f=SH00L0f=SH0P3Cdm<01@3H
f=P0dm?C0=?Cd`3:b/X0dm?C0080b/[:0P38b<P02031`L40_kno0<71`@31`L40^[Zj0;>c/`2a/K40
Zj^[0P2YZJT00`2EUID0VIVI092@T00208J6QP<0K6a/00<0GUiN04U9B@0m?Cd00P0W9bL0100G5aL0
2`/;00/;2`1CDe<2069RHP0507YjNP1iNGT0WinO09FEU@2^[Zh00P2EUIDD0?Ogma@000009P3ooolE
000000<0moOg0P3_knl30=gMg@80i^KV0P2^[Zh30<O7a`80VIVI0P21PH43096AT@80S8b<0`38b<P2
0;>c/`80TI6A0`1VIVH2075aL@80E5AD0`0O7al2065QH@<0VIVI0P2MWId20:b/[0<0/K6a0P2g]kL2
0;no_`<0_;bl1@2o_kl40;bl_0<0b/[:0P38b<P70=?Cd`D0b/[:0P3@d=030<o?c`80^;Rh0P1;Bd/3
03Ti>@80E5AD0`1TI6@209nOW`80a/K60`3dm?@20>o_ka<000007P3oool001`0oooo4`0000000`1?
Cdl0GUiN06][J`0206][J`0305YJFP1RHV80EEEE0080EUIF00D0Jf][069RHP1aLG40R8R809FEU@02
0:^[Z`030<71`@3:b/X0dm?C00<0dm?C0`3Hf=P30>3Ph080f=SH0P3Ph>030=SHf0030>3Ph03Hf=P0
f=SH00L0f=SH0P3Cdm<01@3Hf=P0dm?C0=?Cd`3:b/X0dm?C0080b/[:0P38b<P02031`L40_kno0<71
`@31`L40^[Zj0;>c/`2a/K40Zj^[0P2YZJT00`2EUID0VIVI092@T00208J6QP<0K6a/00<0GUiN04U9
B@0m?Cd00P0W9bL0100G5aL02`/;00/;2`1CDe<2069RHP0507YjNP1iNGT0WinO09FEU@2^[Zh00P2E
UIDD0?Ogma@000009P3ooolE000000D0moOg0`3Vi^H20=OGe`80UIFE0`31`L420:6QX@D0SHf=0P2Q
XJ430;fm_@80VIVI0P21PH4307UiN@80I6AT0P1?Cdl303Hf=P80K6a/0`2IVIT20:6QX@80YjNW0`2a
/K420;Ng]`80_;bl1@38b<P30<71`@80`/;20P2l_;`30<S8b080b/[:1`3Cdm<30<o?c`80d=3@0P3C
dm<30<g=c@80clo?1@1;Bd/2055AD@<0K6a/0P21PH420<k>cPD0m?Cd4`00000N0?ooo`00703ooolC
000000@0EEEE00@0GemO069RHP1EEED0FUYJ0P1EEED01@1JFUX0EEEE07YjNP21PH40UIFE0080_;bl
00@0`L710<g=c@3Bd]80dm?C1@3Hf=P60>3Ph080f=SH1P3Ph>060=SHf080d=3@0`3Cdm<00`3=cLd0
b/[:0<[:bP020<[:bP030<30`031`L40_kno0080`L7100@0_;bl0;6a/@2c/k<0[:b/0P2YZJT01@2E
UID0VIVI092@T02=SHd0PH610080NGUi00@0K6a/05EEE@19BDT0=SHf0P15ADD0100O7al05aLG01LG
5`0b<S82075aL@050:6QX@26QXH0Xj>S0861P@1aLG400P1TI6@00`2/[:`0moOg0?Ogm`0A0?Ogma@0
00009P3ooolC000000D0moOg0P3dm?@30>WYj@80eMGE0P2=SHd30<71`@80Xj>S0P2EUID3096AT@80
Zj^[0`2XZ:P209FEU@80GUiN0`26QXH206][J`80BDU90`0W9bL207]kN`<0T92@0P2QXJ420:b/[0<0
]KFe0P2l_;`20<S8b0<0`<300P38b<P30<30`080_kno0P2e]KD50<S8b080dm?C0`3?cll90=?Cd`<0
cLg=0P3?cll2051@D0<0>CTi0P0m?Cd3051@D080Ng]k0P33`l<30>o_k`80m?Cd0P3gmoLA000001h0
oooo000L0?oooa<00000101EEED0101OGel0HV9R05EEE@1JFUX205EEE@0505YJFP1EEED0NWYj0861
P@2EUID00P2l_;`01031`L40cLg=0=;BdP3Cdm<50=SHf0H0h>3P0P3Hf=P60>3Ph0H0f=SH0P3@d=03
0=?Cd`030<g=c@3:b/X0b/[:0080b/[:00<0`<300<71`@2o_kl00P31`L40102l_;`0/K6a0;>c/`2/
[:`20:VYZ@0509FEU@2IVIT0T92@08f=S@21PH400P1iNGT0101/K6`0EEEE04U9B@0f=SH204E5A@04
01lO7`0G5aL05aLG038b<P80LG5a00D0XJ6Q08J6QP2SXj<0PH61075aL@0206ATI0030:b/[03gmoL0
moOg0140moOg5000000V0?oooa<000001`3gmoL30>WYj@80`L710P2EUID30;no_`80WinO0P21PH43
09FEU@80ZZZZ0`2m_Kd205EEE@80E5AD0`1TI6@205EEE@80?3`l0`0f=SH207YjNP<0VIVI0P2SXj<2
0:b/[0<0/K6a0P2l_;`20<30`0<0b/[:0P31`L430;bl_080]kNg0P2/[:`30;Ng]`80/K6a0P3:b/X<
0=?Cd`<0cLg=0P39bLT203dm?@<0BDU90P1;Bd/306ATI080K6a/0P2VYZH30>WYj@80moOg0P3dm?@A
000001h0oooo000L0?oooa80000000<0D51@04m?C`1JFUX00P26QXH0101[Jf/0EEEE05YJFP1FEUH3
05YJFP0405iNGP1jNWX0LG5a0:>SX`80alO70P3?cll00`3Bd]80f=SH0=SHf0020=SHf080h>3P0`3H
f=P30>3Ph0030=SHf03Ph>00h>3P00<0h>3P0P3Hf=P20>3Ph080f=SH00<0h>3P0=SHf03Hf=P0103H
f=P0203@d=00dm?C0<g=c@3=cLd0b/[:0<O7a`31`L40b/[:0`2l_;`00`2c/k<0ZJVY0:VYZ@030:>S
X`80UIFE00<0SHf=07YjNP1iNGT00P1iNGT00`1NGUh0K6a/04E5A@0302XZ:P0301lO7`0b<S809bLW
0080UIFE00D0NWYj05iNGP2EUID0NGUi06a/K0020:j^[P0306a/K02m_Kd0oooo0180moOg4`00000V
0?oooa<000001`3gmoL30=;BdP80emOG0P2m_Kd30;no_`80S8b<0P21PH43096AT@80cLg=0`2<S8`2
04];B`80IVIV0`1EEED205ADE0808b<S0`0f=SH20861P@<0T92@0P2SXj<20:b/[0<0]kNg1`38b<P2
0<;2`P<0^[Zj0P2a/K420:>SX`<0[:b/0P2j^[X20<30`0`0dm?C0`3@d=020<g=c@80>CTi0`1;Bd/2
03dm?@<0EEEE0P1TI6@209FEU@<0m?Cd103gmoLA000001h0oooo000L0?oooa80000000<0D51@04m?
C`1JFUX00P26QXH0101[Jf/0EEEE05YJFP1FEUH305YJFP0405iNGP1jNWX0LG5a0:>SX`80alO70P3?
cll00`3Bd]80f=SH0=SHf0020=SHf080h>3P0`3Hf=P30>3Ph0030=SHf03Ph>00h>3P00<0h>3P0P3H
f=P20>3Ph080f=SH00<0h>3P0=SHf03Hf=P0103Hf=P0203@d=00dm?C0<g=c@3=cLd0b/[:0<O7a`31
`L40b/[:0`2l_;`00`2c/k<0ZJVY0:VYZ@030:>SX`80UIFE00<0SHf=07YjNP1iNGT00P1iNGT00`1N
GUh0K6a/04E5A@0302XZ:P0301lO7`0b<S809bLW0080UIFE00D0NWYj05iNGP2EUID0NGUi06a/K002
0:j^[P0306a/K02m_Kd0oooo0180moOg4`00000V0?oooa<000001`3gmoL30=;BdP80emOG0P2m_Kd3
0;no_`80S8b<0P21PH43096AT@80cLg=0`2<S8`204];B`80IVIV0`1EEED205ADE0808b<S0`0f=SH2
0861P@<0T92@0P2SXj<20:b/[0<0]kNg1`38b<P20<;2`P<0^[Zj0P2a/K420:>SX`<0[:b/0P2j^[X2
0<30`0`0dm?C0`3@d=020<g=c@80>CTi0`1;Bd/203dm?@<0EEEE0P1TI6@209FEU@<0m?Cd103gmoLA
000001h0oooo000L0?oooa80000000<0D51@04m?C`1JFUX00P26QXH0101[Jf/0EEEE05YJFP1FEUH3
05YJFP0405iNGP1jNWX0LG5a0:>SX`80alO70P3?cll00`3Bd]80f=SH0=SHf0020=SHf080h>3P0`3H
f=P30>3Ph0030=SHf03Ph>00h>3P00<0h>3P0P3Hf=P20>3Ph080f=SH00<0h>3P0=SHf03Hf=P0103H
f=P0203@d=00dm?C0<g=c@3=cLd0b/[:0<O7a`31`L40b/[:0`2l_;`00`2c/k<0ZJVY0:VYZ@030:>S
X`80UIFE00<0SHf=07YjNP1iNGT00P1iNGT00`1NGUh0K6a/04E5A@0302XZ:P0301lO7`0b<S809bLW
0080UIFE00D0NWYj05iNGP2EUID0NGUi06a/K0020:j^[P0306a/K02m_Kd0oooo0180moOg4`00000V
0?oooa<000002P3gmoL40>WYj@<0_Kfm0P21PH4206IVIP<0S8b<0P2QXJ4308f=S@@0K6a/0`1JFUX2
04U9B@808b<S0`15ADD207YjNP<0VIVI0P2SXj<20:b/[0<0]kNg0P30`<050<[:bP80b<S80`2a/K42
0861P@80T92@0`1eMGD20<30`080b/[:0`2WYjL20=3@d0<0dm?C0P3Hf=P20=3@d0<0b/[:0P37alL2
038b<P<0CTi>0P15ADD303dm?@80E5AD0P26QXH30>WYj@@0moOg4@00000N0?ooo`00703ooolA0000
00040:JVYP1aLG40BDU904U9B@80GemO00@0EEEE04U9B@19BDT0BDU90P1EEED01@1NGUh0HV9R075a
L@1jNWX0ZJVY0080bLW90P3?cll00`3:b/X0ZJVY09fMW@0209fMW@030;Jf]P3Hf=P0h>3P00X0h>3P
00<0hn?S0=SHf03Hf=P0103Ph>050=SHf0030=?Cd`3@d=00b/[:00<0b/[:0P37alL0102OWil0O7al
07UiN@1iNGT207alO00909FEU@2OWil0UIFE09FEU@2IVIT0XJ6Q09VIV@2=SHd0NGUi0080LG5a00@0
NGUi05EEE@0m?Cd0BDU90P0m?Cd0100b<S805aLG01LG5`0O7al2069RHP0506m_K`1NGUh0NWYj075a
L@2EUID00P2OWil00`1/K6`0SHf=0>WYj@0C0?Ogma8000009P3ooolC000000X0moOg0P2h^;P20<K6
aP<0[:b/0P2=SHd206a/K0<0PH610P2GUiL30:^[Z`80GUiN0P1aLG4305iNGP80?3`l0P0G5aL305iN
GP80RHV90`2IVIT20:>SX`80/K6a0`2m_Kd20<S8b0L0b/[:0`2SXj<20:b/[080]KFe0`2a/K420<[:
bP80d=3@0`3?cll50=?Cd`80f=SH1@3Cdm<20<[:bP80EEEE0`0m?Cd204Q8B0<0Bd];0P1VIVH207Ui
N@<0h>3P103gmoLA000001h0oooo000L0?oooa40000000@0YZJV075aL@19BDT0BDU90P1OGel0101E
EED0BDU904U9B@19BDT205EEE@0505iNGP1RHV80LG5a07YjNP2YZJT00P39bLT20<o?c`030<[:bP2Y
ZJT0WIfM0080WIfM00<0][Jf0=SHf03Ph>002P3Ph>000`3Shn<0f=SH0=SHf0040>3Ph0D0f=SH00<0
dm?C0=3@d03:b/X00`3:b/X20<O7a`0409nOW`1lO7`0NGUi07UiN@80O7al00T0UIFE09nOW`2EUID0
UIFE09VIV@2QXJ40VIVI08f=S@1iNGT00P1aLG40101iNGT0EEEE03dm?@19BDT203dm?@04038b<P0G
5aL05aLG01lO7`80HV9R00D0Kfm_05iNGP1jNWX0LG5a09FEU@0209nOW`0306a/K02=SHd0jNWY01<0
moOg4P00000V0?oooa<000002P3gmoL20<_;b`80a/K60`2^[Zh208J6QP80NGUi0`21PH420:^[Z`<0
UIFE0P1NGUh206a/K0<0I6AT0P19BDT201lO7`<0I6AT0P21PH4309fMW@80YjNW0P2e]KD50<30`080
b/[:0`3@d=020<[:bP<0[:b/0P2a/K420;Vi^@<0^[Zj0P3@d=020=SHf0<0cLg=0P3@d=030=?Cd`@0
f=SH1@3@d=0207alO0<0<S8b0P1;Bd/3055AD@80?Cdm0P1TI6@30=OGe`80moOg0P3_knlA000001h0
oooo000L0?oooa40000000@0jNWY0?ooo`0m?Cd0Bd];0P0b<S80100m?Cd0BDU905EEE@19BDT206IV
IP0507EeM@21PH40SHf=092@T02OWil00P3:b/X00`36a/H0_kno0<g=c@040=SHf0030=3@d028R8P0
O7al0080Kfm_00<0NWYj0:VYZ@38b<P00P3Cdm<20=SHf0030>3Ph03Hf=P0h>3P00D0f=SH0P3Cdm<2
0<S8b0050;Ng]`2=SHd0HF5Q05EEE@1QHF400P1jNWX00`2/[:`0^KVi0<O7a`030<[:bP040<30`031
`L40/k>c0:b/[080UIFE00D0NWYj09VIV@2=SHd0R8R807UiN@0306a/K00305iNGP0m?Cd0?Cdm0080
:RXZ00@0<S8b02XZ:P0W9bL0Cdm?0P1JFUX0101[Jf/0NWYj075aL@1NGUh308f=S@030:j^[P2EUID0
WinO01<0moOg4P00000V0?oooa<000000P3dm?@80?Ogm`80m?Cd0P2h^;P30:b/[080PH610P2=SHd3
0:6QX@80ZZZZ0`1iNGT205ADE080K6a/0`1VIVH204E5A@8000000`1NGUh20861P@<0VIVI0P2/[:`2
0;Ng]`<0`<300P38b<P20=3@d0<0cLg=0P3:b/X30;Ng]`80/K6a0P2e]KD30<71`@80d=3@0P3Shn<3
0=SHf080b/[:2P3Hf=P20=?Cd`80bLW90`0Z:RX205EEE@<0Bd];0P1DE5@205iNGP<0d];B0P3gmoL2
0?Cdm14000007P3oool001`0oooo4@000000103YjNT0oooo03dm?@1;Bd/2038b<P0403dm?@19BDT0
EEEE04U9B@80IVIV00D0MGEe0861P@2=SHd0T92@09nOW`020<[:bP030<K6aP2o_kl0cLg=00@0f=SH
00<0d=3@08R8R01lO7`00P1_Kfl00`1jNWX0ZJVY0<S8b0020=?Cd`80f=SH00<0h>3P0=SHf03Ph>00
1@3Hf=P20=?Cd`80b<S800D0]kNg08f=S@1QHF40EEEE065QH@0207YjNP030:b/[02i^KT0alO700<0
b/[:00@0`<300<71`@2c/k<0[:b/0P2EUID01@1jNWX0VIVI08f=S@28R8P0NGUi00<0K6a/00<0GUiN
03dm?@0m?Cd00P0Z:RX0100b<S80:RXZ02LW9`1?Cdl205YJFP0406][J`1jNWX0LG5a05iNGP<0SHf=
00<0[Zj^09FEU@2OWil04`3gmoLB000002H0oooo4`0000050?Ogm`80m?Cd1@3gmoL209nOW`<0_kno
1021PH430<71`@80VIVI0`1aLG4205ADE080I6AT0`1EEED203Hf=P801PH60`1aLG420861P@<0XJ6Q
0P2a/K420;Ng]`D0b<S80P3:b/X30<o?c`80cLg=0`2l_;`20:^[Z`80[:b/0`2g]kL20=?Cd`80f=SH
0`3@d=020=?Cd`X0f=SH0P3Bd]820<[:bP<0<S8b1@1;Bd/204E5A@80I6AT0`2EUID40?Ogma400000
7P3oool001`0oooo4@000000103YjNT0oooo03dm?@1;Bd/2038b<P0403dm?@19BDT0EEEE04U9B@80
IVIV00D0MGEe0861P@2=SHd0T92@09nOW`020<[:bP030<K6aP2o_kl0cLg=00@0f=SH00<0d=3@08R8
R01lO7`00P1_Kfl00`1jNWX0ZJVY0<S8b0020=?Cd`80f=SH00<0h>3P0=SHf03Ph>001@3Hf=P20=?C
d`80b<S800D0]kNg08f=S@1QHF40EEEE065QH@0207YjNP030:b/[02i^KT0alO700<0b/[:00@0`<30
0<71`@2c/k<0[:b/0P2EUID01@1jNWX0VIVI08f=S@28R8P0NGUi00<0K6a/00<0GUiN03dm?@0m?Cd0
0P0Z:RX0100b<S80:RXZ02LW9`1?Cdl205YJFP0406][J`1jNWX0LG5a05iNGP<0SHf=00<0[Zj^09FE
U@2OWil04`3gmoLB000002H0oooo4`0000050?Ogm`80m?Cd1@3gmoL209nOW`<0_kno1021PH430<71
`@80VIVI0`1aLG4205ADE080I6AT0`1EEED203Hf=P801PH60`1aLG420861P@<0XJ6Q0P2a/K420;Ng
]`D0b<S80P3:b/X30<o?c`80cLg=0`2l_;`20:^[Z`80[:b/0`2g]kL20=?Cd`80f=SH0`3@d=020=?C
d`X0f=SH0P3Bd]820<[:bP<0<S8b1@1;Bd/204E5A@80I6AT0`2EUID40?Ogma4000007P3oool001`0
oooo4@000000103gmoL0i^KV08V9R@1[Jf/204U9B@0404E5A@19BDT0BDU903dm?@80K6a/00D0SXj>
09VIV@2OWil0UIFE0:^[Z`020<W9b@80clo?00P0f=SH0=;BdP3:b/X0b/[:0<g=c@31`L40_;bl0;Vi
^@80_;bl00D0`L710;bl_02SXj<0[:b/0;Ng]`020<S8b0030=SHf03Cdm<0f=SH00<0f=SH00@0dm?C
0<g=c@3:b/X0^[Zj0P2QXJ401@2WYjL0UIFE0:VYZ@2[Zj/0ZJVY00@0UIFE00<0VIVI0:>SX`2YZJT0
0P2YZJT00`2a/K40]KFe0;>c/`020:^[Z`050:VYZ@2SXj<0VIVI092@T02=SHd00P21PH400`1QHF40
HV9R05EEE@0303dm?@0402XZ:P0f=SH0BDU904E5A@80?Cdm00D0K6a/08f=S@1/K6`0IVIV08b<S002
09FEU@040;>c/`1aLG40UIFE0=gMg@80oooo403gmoLB000002H0oooo4@00000>0?Ogm`80bl_;0`2/
[:`207YjNP80Ng]k0`3=cLd209NGU`<0NWYj101DE5@304U9B@80:RXZ0P0;2`/306a/K080SXj>0`2/
[:`20;Fe]@80`<301@3:b/X20<g=c@<0d=3@1@3:b/X20;>c/`80/K6a0`2l_;`20<g=c@80f=SH0`3B
d]8>0=SHf080b/[:0`0W9bL201LG5`<0DE5A0P1EEED2051@D0<0R8R81`3gmoL>000001h0oooo000L
0?oooa40000000@0moOg0>KViP29RHT0Jf][0P19BDT01015ADD0BDU904U9B@0m?Cd206a/K00508j>
SP2IVIT0WinO09FEU@2[Zj/00P39bLT20<o?c`080=SHf03Bd]80b/[:0<[:bP3=cLd0`L710;bl_02i
^KT20;bl_0050<71`@2l_;`0Xj>S0:b/[02g]kL00P38b<P00`3Hf=P0dm?C0=SHf0030=SHf0040=?C
d`3=cLd0b/[:0;Zj^P80XJ6Q00D0YjNW09FEU@2YZJT0Zj^[0:VYZ@0409FEU@0309VIV@2SXj<0ZJVY
0080ZJVY00<0/K6a0;Fe]@2c/k<00P2[Zj/01@2YZJT0Xj>S09VIV@2@T900SHf=0080PH6100<0HF5Q
069RHP1EEED00`0m?Cd0100Z:RX0=SHf04U9B@15ADD203dm?@0506a/K02=SHd0K6a/06IVIP2<S8`0
0P2EUID0102c/k<0LG5a09FEU@3MgMd20?oooa00moOg4P00000V0?oooa4000003P3gmoL20<_;b`<0
_Kfm0P26QXH2096AT@<0cLg=0P2QXJ43075aL@80IVIV0P1;Bd/305EEE@80<S8b0P0O7al306a/K080
SXj>0`2SXj<20;>c/`80_;bl0`3:b/X20<g=c@80d];B0`3@d=020<g=c@<0b/[:0P2l_;`20;6a/@<0
/k>c0P3:b/X20=SHf0<0dm?C1@3Hf=P20>3Ph0L0f=SH0P3?cll502XZ:P<0Bd];0P1EEED204];B`<0
R8R81`3dm?@>000001h0oooo000L0?ooo`l000000`3gmoL00`2BTY80b<S808J6QP0206m_K`0405=C
D`19BDT0EEEE05EEE@80HF5Q00D0SHf=0<30`02VYZH0Xj>S0;6a/@020<g=c@040<o?c`2l_;`0ZZZZ
092@T080BDU90P1QHF402@0l?3`08b<S03Hf=P0f=SH0EEEE06MWI`1QHF40O7al09FEU@020;Ng]`04
0<;2`P3Cdm<0dm?C0=SHf080dm?C00@0b/[:0<;2`P2l_;`0[:b/0P2EUID00`2@T900NGUi06m_K`02
08^;R`80=SHf00@0:RXZ03Hf=P0f=SH0BDU90P0l?3`0101DE5@0De=C07alO026QXH208R8R00509VI
V@2SXj<0Xj>S09FEU@28R8P00P21PH40101QHF40GUiN05iNGP19BDT203dm?@0401lO7`0f=SH0?Cdm
03dm?@80BDU900D0K6a/07UiN@1/K6`0IVIV0861P@0207UiN@040:^[Z`1TI6@0SHf=0:6QX@80i^KV
4@3gmoLA000002H0oooo4@0000020?Ogm`80m?Cd2P3gmoL20>c/k0<0/K6a0P1jNWX207]kN`<0`L71
0P2QXJ43075aL@80GUiN0P1DE5@304U9B@80?Cdm0P15ADD306a/K080XJ6Q0`2YZJT20;Zj^P80alO7
0`3=cLd20=;BdPD0d=3@0P3Hf=P30<g=c@80_;bl0P2j^[X30;bl_080d=3@4@3Hf=P20>3Ph080d=3@
0`30`<0201lO7`<0Bd];0P1DE5@204E5A@<0LG5a0P3gmoL20?Cdm0<0moOg3P00000N0?ooo`00703o
ool?000000<0moOg00<0TY:B0<S8b026QXH00P1_Kfl0101CDe<0BDU905EEE@1EEED2065QH@0508f=
S@30`<00YZJV0:>SX`2a/K400P3=cLd0103?cll0_;bl0:ZZZP2@T90204U9B@80HF5Q00T0?3`l02<S
8`0f=SH0=SHf05EEE@1WIfL0HF5Q07alO02EUID00P2g]kL01032`/80dm?C0=?Cd`3Hf=P20=?Cd`04
0<[:bP32`/80_;bl0:b/[080UIFE00<0T92@07UiN@1_Kfl00P2;Rh/203Hf=P0402XZ:P0f=SH0=SHf
04U9B@80?3`l00@0E5AD05=CD`1lO7`0QXJ60P28R8P01@2IVIT0Xj>S0:>SX`2EUID0R8R80080PH61
00@0HF5Q05iNGP1NGUh0BDU90P0m?Cd0100O7al0=SHf03dm?@0m?Cd204U9B@0506a/K01iNGT0K6a/
06IVIP21PH400P1iNGT0102[Zj/0I6AT08f=S@2QXJ420>KViQ40moOg4@00000V0?oooa400000403g
moL30:j^[P80NWYj0P1aLG430:^[Z`80XJ6Q0`28R8P205iNGP80IVIV0`1EEED203dm?@80BDU90`1j
NWX20:6QX@<0/K6a0P2l_;`20<[:bPD0d];B1`3Hf=P30<O7a`80`L711@2l_;`@0=SHf0<0h>3P103H
f=P30<[:bP80?Cdm0`1ADE4204U9B@80<S8b0`1NGUh70?Ogm`h000007P3oool001`0oooo3`000004
0?Ogm`0808R8R02MWId0LG5a075aL@1RHV80<S8b05EEE@1QHF4203Ti>@0502XZ:P3@d=00]KFe0;Fe
]@2c/k<00P3Bd]80103Hf=P0d];B0<O7a`2i^KT208R8R004092@T030`<00emOG06e]K@80HV9R00D0
D51@07=cL`1nOWh0WinO09FEU@020;Vi^@040;>c/`38b<P0f=SH0=SHf080clo?00@0b/[:0;bl_02/
[:`0UIFE0P28R8P01@2@T900WinO06EUI@3;bl/0jNWY0080KVi^00@0Kfm_069RHP25QHD0FEUI0P2P
X:000`1aLG40IfMW08R8R0030:VYZ@050;>c/`2a/K40Zj^[0:>SX`2QXJ400P28R8P0101iNGT0K6a/
05ADE019BDT2038b<P0400/;2`0O7al0EEEE05iNGP80ADE500D0K6a/08R8R026QXH0K6a/07YjNP02
075aL@030;6a/@1@D500UIFE00<0[Zj^3`3gmoL00`3dm?@0moOg0000000@000002H0oooo4@00000@
0?Ogm`<0[jn_0P1iNGT207=cL`<0ZJVY1@2QXJ4406ATI0<0BDU90P0b<S8205EEE@<0NWYj0P2QXJ43
0;6a/@80`L710P3:b/X30<o?c`80f=SH0P3@d=030=SHf080d];B0`3:b/X20<71`@80/k>c0`2l_;`2
0=3@d0D0f=SH0P3Ph>070=SHf0<0h>3P103Hf=P30=3@d080:RXZ0`15ADD205EEE@80?Cdm0`1VIVH7
0?Ogm`h000007P3oool001`0oooo3`0000040?Ogm`0808R8R02MWId0LG5a075aL@1RHV80<S8b05EE
E@1QHF4203Ti>@0502XZ:P3@d=00]KFe0;Fe]@2c/k<00P3Bd]80103Hf=P0d];B0<O7a`2i^KT208R8
R004092@T030`<00emOG06e]K@80HV9R00D0D51@07=cL`1nOWh0WinO09FEU@020;Vi^@040;>c/`38
b<P0f=SH0=SHf080clo?00@0b/[:0;bl_02/[:`0UIFE0P28R8P01@2@T900WinO06EUI@3;bl/0jNWY
0080KVi^00@0Kfm_069RHP25QHD0FEUI0P2PX:000`1aLG40IfMW08R8R0030:VYZ@050;>c/`2a/K40
Zj^[0:>SX`2QXJ400P28R8P0101iNGT0K6a/05ADE019BDT2038b<P0400/;2`0O7al0EEEE05iNGP80
ADE500D0K6a/08R8R026QXH0K6a/07YjNP02075aL@030;6a/@1@D500UIFE00<0[Zj^3`3gmoL00`3d
m?@0moOg0000000@000002H0oooo4@00000@0?Ogm`<0Zj^[0P1iNGT205iNGP<0WinO0P2EUID30:j^
[P80EEEE0P1NGUh303dm?@80>CTi0P1EEED30861P@80Xj>S0`2c/k<20<71`@D0cLg=2@3Bd]830<O7
a`80`L710P2c/k<30<71`@80f=SH0P3=cLdC0=SHf0<0dm?C0P1EEED3038b<P80EEEE0P19BDT3075a
L@80m?Cd1@3gmoL>000001h0oooo000L0?ooo`l00000103gmoL02028R8P0WIfM075aL@1aLG40HV9R
038b<P1EEED0HF5Q0P0i>CT01@0Z:RX0d=3@0;Fe]@2e]KD0/k>c0080d];B00@0f=SH0=;BdP37alL0
^KVi0P28R8P0102@T900`<300=OGe`1]KFd2069RHP05051@D01cLg<0OWin09nOW`2EUID00P2i^KT0
102c/k<0b<S80=SHf03Hf=P20<o?c`040<[:bP2l_;`0[:b/09FEU@80R8R800D0T92@09nOW`1UIFD0
bl_;0>WYj@0206i^KP0406m_K`1RHV80QHF505UIF@80X:2P00<0LG5a06MWI`28R8P00`2YZJT01@2c
/k<0/K6a0:^[Z`2SXj<0XJ6Q0080R8R800@0NGUi06a/K01DE5@0BDU90P0b<S80100;2`/07alO05EE
E@1NGUh204E5A@0506a/K028R8P0QXJ606a/K01jNWX00P1aLG400`2a/K40D51@09FEU@030:j^[Pl0
moOg00<0m?Cd0?Ogm`0000004000000V0?oooa400000403gmoL30:^[Z`80NGUi0P1NGUh309nOW`80
UIFE0`2^[Zh205EEE@80GUiN0`0m?Cd203Ti>@80EEEE0`21PH420:>SX`<0/k>c0P31`L450<g=c@T0
d];B0`37alL20<71`@80/k>c0`31`L420=SHf080cLg=4`3Hf=P30=?Cd`80EEEE0`0b<S8205EEE@80
BDU90`1aLG420?Cdm0D0moOg3P00000N0?ooo`00703oool?000000@0moOg00P0oooo06a/K01lO7`0
O7al05EEE@1NGUh0EEEE065QH@809bLW00D0E5AD055AD@3@d=00VIVI0:b/[0020<o?c`@0f=SH0P3B
d]801039bLT0][Jf09FEU@2=SHd20:^[Z`040:ZZZP2EUID0][Jf0;Jf]P<0d];B0P3=cLd40=SHf004
0<[:bP2c/k<0Xj>S09nOW`80Xj>S00D0_kno0;Jf]P39bLT0^KVi0;Jf]P020:VYZ@0309fMW@28R8P0
SHf=00@0WinO00<0ZZZZ0;no_`31`L40102f][H00`2a/K40ZJVY09nOW`02092@T0040861P@1QHF40
EEEE04U9B@80?Cdm0P0b<S801`1EEED0E5AD069RHP1RHV80GUiN08R8R02=SHd00P21PH4205iNGP04
0;fm_@1NGUh0EEEE09nOW`80XJ6Q00<0emOG0?ooo`3gmoL03P3gmoLA000002H0oooo4@00000@0?Og
m`<0[:b/0P2=SHd204a<C0<0K6a/0P2QXJ4309nOW`80GUiN0P1/K6`303dm?@80:RXZ0P1NGUh308j>
SP80ZJVY0`2f][H20<71`@80b/[:1@3=cLd20=;BdP<0f=SH0P3?cll50;Jf]P80/K6a0`3:b/X20=SH
f080dm?C0`3Hf=P20=;BdP<0cLg=0P3Bd]820=SHf0<0h>3P103Hf=P30<g=c@80alO70`0f=SH205EE
E@80GUiN0`1RHV820:j^[P80m?Cd0`3gmoL>000001h0oooo000L0?ooo`l00000103gmoL0203oool0
K6a/07alO01lO7`0EEEE05iNGP1EEED0HF5Q0P0W9bL01@1DE5@0DE5A0=3@d02IVIT0[:b/0080clo?
103Hf=P20=;BdP040<W9b@2f][H0UIFE08f=S@80Zj^[00@0ZZZZ09FEU@2f][H0][Jf0`3Bd]820<g=
c@@0f=SH00@0b/[:0;>c/`2SXj<0WinO0P2SXj<01@2o_kl0][Jf0<W9b@2i^KT0][Jf0080ZJVY00<0
WIfM08R8R02=SHd0102OWil00`2ZZZX0_kno0<71`@040;Jf]P030;6a/@2YZJT0WinO0080T92@00@0
PH61065QH@1EEED0BDU90P0m?Cd2038b<P0705EEE@1DE5@0HV9R069RHP1NGUh0R8R808f=S@020861
P@80GUiN00@0_Kfm05iNGP1EEED0WinO0P2QXJ400`3GemL0oooo0?Ogm`0>0?Ogma4000009P3ooolA
000000`0moOg0P3dm?@20?Ogm`<0alO70P28R8P2065QH@<0DE5A0P2IVIT309nOW`@0GUiN0`0m?Cd2
02XZ:P80GUiN0`2>SXh20:VYZ@<0_kno0P37alL20<g=c@D0alO70P31`L430<O7a`80cLg=0`31`L42
0;>c/`80/K6a0`3:b/X20=SHf080dm?C0`3Hf=P20<g=c@<0b/[:0P30`<020=;BdPL0f=SH1@37alL3
04U9B@80EEEE1@1/K6`207inOP80m?Cd0`3gmoL>000001h0oooo000L0?ooo`l000000`3gmoL00`3d
m?@0moOg07inOP0208f=S@0406a/K019BDT0K6a/04U9B@80EEEE00D0<S8b04U9B@1;Bd/0alO70=3@
d0020<O7a`80f=SH00<0h>3P0=SHf03Hf=P00`3Hf=P20=;BdP80`<3000D0alO70<[:bP3:b/X0cLg=
0=;BdP020=SHf0030<o?c`3Cdm<0f=SH00<0f=SH00@0b/[:0;Fe]@2a/K40Zj^[0`2c/k<01031`L40
bLW90<g=c@3Bd]830<O7a`030<71`@37alL0alO700<0alO700<0b/[:0<g=c@37alL00P37alL01@2h
^;P0_kno0;6a/@2YZJT0XJ6Q0080SXj>00@0NGUi05iNGP1ADE40:RXZ0P0W9bL0100m?Cd0BDU905iN
GP1VIVH305iNGP0409nOW`2IVIT0VIVI0:6QX@80DE5A00@0[jn_065QH@1NGUh0R8R80P2YZJT01037
alL0moOg0?Ogm`3gmoL20?Cdm0/0moOg4@00000V0?oooa400000403gmoL30=GEe@80UIFE0P1/K6`3
051@D080PH610`2EUID206a/K080GUiN0`0b<S8204E5A@80K6a/0`2@T9020:VYZ@<0_kno1031`L43
0;Jf]P80/K6a0P2i^KT30<71`@80bLW90`2h^;P20:^[Z`80YjNW0`30`<020=SHf080cLg=0`3Bd]82
0<O7a`<0/k>c0P3:b/X20<g=c@<0d];B103Hf=P30<g=c@80b/[:0`1VIVH204U9B@80FUYJ0`1NGUh2
05ADE080moOg0`3dm?@>000001h0oooo000L0?ooo`l000000`3gmoL00`3dm?@0moOg07inOP0208f=
S@0406a/K019BDT0K6a/04U9B@80EEEE00D0<S8b04U9B@1;Bd/0alO70=3@d0020<O7a`80f=SH00<0
h>3P0=SHf03Hf=P00`3Hf=P20=;BdP80`<3000D0alO70<[:bP3:b/X0cLg=0=;BdP020=SHf0030<o?
c`3Cdm<0f=SH00<0f=SH00@0b/[:0;Fe]@2a/K40Zj^[0`2c/k<01031`L40bLW90<g=c@3Bd]830<O7
a`030<71`@37alL0alO700<0alO700<0b/[:0<g=c@37alL00P37alL01@2h^;P0_kno0;6a/@2YZJT0
XJ6Q0080SXj>00@0NGUi05iNGP1ADE40:RXZ0P0W9bL0100m?Cd0BDU905iNGP1VIVH305iNGP0409nO
W`2IVIT0VIVI0:6QX@80DE5A00@0[jn_065QH@1NGUh0R8R80P2YZJT01037alL0moOg0?Ogm`3gmoL2
0?Cdm0/0moOg4@00000V0?oooa400000403gmoL30=OGe`80WinO1@1NGUh20861P@<0R8R80P1RHV82
05EEE@<0<S8b0P19BDT2065QH@<0T92@0P2YZJT50;Jf]P80_kno1@2OWil208R8R0<0ZJVY0P2i^KT3
0;Jf]P@0Xj>S0`3:b/X20=SHf080cLg=0`3Bd]820;Jf]P<0UIFE0P2[Zj/209FEU@<0bLW9103Hf=P3
0<o?c`80VIVI0`1ADE4202LW9`D0EEEE0P1/K6`50?Ogm`h000007P3oool001`0oooo3`0000050?Og
m`070?Cdm01aLG40LG5a075aL@1EEED0BDU904E5A@0205EEE@05055AD@0b<S80ADE505EEE@3=cLd0
0P3Cdm<00`3Bd]80f=SH0=SHf0090=SHf0030=;BdP3Hf=P0f=SH00D0f=SH00<0cLg=0=SHf03Hf=P0
0P3Hf=P01031`L40]kNg0;>c/`2l_;`30<71`@030<O7a`3=cLd0d];B00<0d];B00@0f=SH0=;BdP3H
f=P0d];B0`3=cLd00`3:b/X0cLg=0<O7a`030<71`@040;>c/`2YZJT0Xj>S09VIV@80PH6100@0K6a/
05EEE@15ADD0>CTi0`0m?Cd00`1EEED0GUiN069RHP0205EEE@05051@D02^[Zh0XJ6Q09FEU@2SXj<0
0P2OWil0102a/K40GUiN07UiN@1iNGT20861P@030:^[Z`3_knl0moOg00h0moOg4@00000V0?oooa40
0000403gmoL30>WYj@80Zj^[0P1VIVH305YJFP80Ng]k0`26QXH205iNGP80EEEE0`0Z:RX204U9B@80
K6a/0`2@T9020:^[Z`<0][Jf0P2c/k<20:^[Z`D0O7al0P1DE5@30<_;b`80T92@0`1NGUh209FEU@80
Xj>S0`38b<P20=SHf080alO70`3=cLd209fMW@<0Ph>30P1RHV820;Jf]P<0QXJ60P3=cLd20=SHf0<0
clo?0P2VYZH30;fm_@80<S8b1@19BDT207YjNPD0moOg3P00000N0?ooo`00703oool?000000D0moOg
00L0m?Cd075aL@1aLG40LG5a05EEE@19BDT0ADE50080EEEE00D0DE5A038b<P15ADD0EEEE0<g=c@02
0=?Cd`030=;BdP3Hf=P0f=SH00T0f=SH00<0d];B0=SHf03Hf=P01@3Hf=P00`3=cLd0f=SH0=SHf002
0=SHf0040<71`@2g]kL0/k>c0;bl_0<0`L7100<0alO70<g=c@3Bd]800`3Bd]80103Hf=P0d];B0=SH
f03Bd]830<g=c@030<[:bP3=cLd0alO700<0`L7100@0/k>c0:VYZ@2SXj<0VIVI0P21PH40101/K6`0
EEEE04E5A@0i>CT303dm?@0305EEE@1NGUh0HV9R0080EEEE00D0D51@0:j^[P2QXJ40UIFE0:>SX`02
09nOW`040;6a/@1NGUh0NGUi07UiN@80PH6100<0Zj^[0>o_k`3gmoL03P3gmoLA000002H0oooo4@00
000@0?Ogm`<0jNWY0P2[Zj/206IVIP<0FUYJ0P1kNg/308J6QP80GUiN0P1EEED302XZ:P80BDU90P1/
K6`3092@T080Zj^[0`2f][H20;>c/`80Zj^[1@1lO7`205ADE0<0bl_;0P2@T90305iNGP80UIFE0P2S
Xj<30<S8b080f=SH0P37alL30<g=c@80WIfM0`23Ph<2069RHP80][Jf0`26QXH20<g=c@80f=SH0`3?
cll20:JVYP<0_Kfm0P0b<S8504U9B@80NWYj1@3gmoL>000001h0oooo000L0?ooo`l000001@3gmoL0
1`3dm?@0LG5a075aL@1aLG40EEEE04U9B@15ADD00P1EEED01@1ADE40<S8b04E5A@1EEED0cLg=0080
dm?C00<0d];B0=SHf03Hf=P02@3Hf=P00`3Bd]80f=SH0=SHf0050=SHf0030<g=c@3Hf=P0f=SH0080
f=SH00@0`L710;Ng]`2c/k<0_;bl0`31`L400`37alL0cLg=0=;BdP030=;BdP040=SHf03Bd]80f=SH
0=;BdP<0cLg=00<0b/[:0<g=c@37alL00`31`L40102c/k<0ZJVY0:>SX`2IVIT20861P@0406a/K01E
EED0ADE503Ti>@<0?Cdm00<0EEEE05iNGP1RHV800P1EEED01@1@D500[Zj^0:6QX@2EUID0Xj>S0080
WinO00@0/K6a05iNGP1iNGT0NGUi0P21PH400`2[Zj/0kno_0?Ogm`0>0?Ogma4000009P3ooolA0000
01<0moOg0P2^[Zh2051@D0<0LG5a0P1/K6`308R8R080ADE50P1EEED300/;2`80BDU90P1/K6`308R8
R080Xj>S0`2a/K420:VYZ@80R8R80`1aLG4205UIF@80HV9R0`1^KVh20<_;b`<0WinO0P28R8P20:b/
[0<0b/[:0P3Hf=P20<S8b0<0^KVi0P2OWil307=cL`80HV9R0P3GemL3092@T080^KVi1@3Bd]820;Fe
]@<0d=3@0P0i>CT205EEE@<0HV9R0P2MWId50?Ogm`h000007P3oool001`0oooo3`0000060?Ogm`80
LG5a00@0GUiN05ADE00b<S80EUIF0`19BDT0101ADE40:RXZ03dm?@0f=SH20<[:bP030<g=c@3Hf=P0
f=SH00<0f=SH0P3Ph>040=SHf0030>3Ph03Hf=P0f=SH00@0f=SH00@0d];B0=SHf03Hf=P0f=SH0P3@
d=00102l_;`0/k>c0;bl_02o_kl30<71`@040<O7a`3?cll0f=SH0=;BdP@0f=SH00<0d=3@0=;BdP3B
d]800P3Bd]800`3=cLd0b/[:0<71`@020;bl_0050;>c/`2a/K40Xj>S0:6QX@29RHT00P1jNWX00`1Q
HF40BDU903dm?@0303dm?@0405EEE@1DE5@0IVIV06ATI080GUiN00<0Kfm_08R8R02SXj<00P2QXJ42
0:^[Z`04096AT@1aLG40D51@07YjNP80UIFE00<0[Zj^0=gMg@3gmoL03P3gmoLA000002H0oooo4@00
000C0?Ogm`80Xj>S0P1@D503075aL@80NWYj0`1aLG4204U9B@80:RXZ0`0G5aL2055AD@80HF5Q0`2>
SXh209FEU@<0Zj^[0P2EUID207alO0<0:2PX0P1@D50200`<30<0D51@0P1/K6`508f=S@80^[Zj0`3:
b/X20=SHf080cLg=0`2EUID206m_K`<0KVi^0P2c/k<20;Ng]`<0=SHf0P2EUID20<[:bP<0bLW90P2V
YZH30=3@d0@0EEEE0`1;Bd/20861P@80oooo0`3gmoL>000001h0oooo000L0?ooo`l000001P3gmoL2
075aL@0405iNGP1DE5@0<S8b05IFEP<0BDU900@0DE5A02XZ:P0m?Cd0=SHf0P3:b/X00`3=cLd0f=SH
0=SHf0030=SHf080h>3P103Hf=P00`3Ph>00f=SH0=SHf0040=SHf0040=;BdP3Hf=P0f=SH0=SHf080
d=3@00@0_;bl0;>c/`2l_;`0_kno0`31`L401037alL0clo?0=SHf03Bd]840=SHf0030=3@d03Bd]80
d];B0080d];B00<0cLg=0<[:bP31`L400P2l_;`01@2c/k<0/K6a0:>SX`2QXJ40RHV90080NWYj00<0
HF5Q04U9B@0m?Cd00`0m?Cd0101EEED0E5AD06IVIP1TI6@205iNGP0306m_K`28R8P0Xj>S0080XJ6Q
0P2[Zj/0102ATI40LG5a051@D01jNWX209FEU@030:j^[P3MgMd0moOg00h0moOg4@00000V0?oooa40
00004`3gmoL20:6QX@80I6AT0`1iNGT206IVIP<0NGUi0P19BDT203dm?@<07alO0P19BDT205iNGP<0
PH610P2EUID30:>SX`80R8R80P1lO7`305ADE080BDU91@0f=SH208^;R`<0NGUi0P2EUID20;bl_0<0
b/[:0P3Hf=P20=?Cd`<0]kNg0P1lO7`306MWI`80=SHf0P0l?3`3065QH@80T92@0P2l_;`30<g=c@80
Xj>S0`30`<02065QH@80EEEE0`1CDe<208J6QP80TY:B0`3gmoL>000001h0oooo000L0?ooo`l00000
0P3dm?@00`3gmoL0m?Cd0?Cdm0030?Cdm00408R8R01NGUh0Bd];04];B`80EEEE00D0BDU904];B`1A
DE40:RXZ01lO7`0202XZ:P030:b/[03?cll0clo?00H0f=SH103Ph>040=SHf080dm?C00@0cLg=0=SH
f03Hf=P0b/[:0P30`<020;>c/`080;6a/@2j^[X0_;bl0;bl_031`L40b/[:0<o?c`3=cLd30=3@d004
0=SHf03Bd]80d=3@0<g=c@<0b/[:00<0`<300;bl_02l_;`00P2c/k<01@2/[:`0Xj>S0:6QX@2>SXh0
NWYj0080K6a/00@0I6AT01lO7`061PH0<S8b0P0Z:RX0101EEED0GUiN04];B`1NGUh206IVIP0505AD
E01aLG40WinO0:6QX@2_[jl00P3=cLd0101iNGT0TI6A05iNGP26QXH207UiN@030;fm_@3?cll0bl_;
00h0moOg4@00000V0?oooa4000004`3gmoL20:VYZ@80K6a/0`2=SHd206IVIP<0PH610P15ADD2038b
<P<0:RXZ0P1EEED205iNGP<0NWYj0P2IVIT30:>SX`80VIVI0P2=SHd3075aL@80?3`l0P1QHF4308>3
P`80GemO0`2EUID20:b/[080b<S80`3:b/X20=SHf080dm?C0`3:b/X20:VYZ@<0Kfm_101CDe<307Yj
NP80/k>c0P37alL30<g=c@80Xj>S0`2e]KD405EEE@<0BDU90P2JVYX207UiN@<0moOg3P00000N0?oo
o`00703oool?00000080m?Cd00<0moOg0?Cdm03dm?@00`3dm?@01028R8P0GUiN04];B`1;Bd/205EE
E@0504U9B@1;Bd/0DE5A02XZ:P0O7al00P0Z:RX00`2/[:`0clo?0<o?c`060=SHf0@0h>3P103Hf=P2
0=?Cd`040<g=c@3Hf=P0f=SH0<[:bP80`<300P2c/k<0202a/K40^[Zj0;bl_02l_;`0`L710<[:bP3?
cll0cLg=0`3@d=00103Hf=P0d];B0=3@d03=cLd30<[:bP030<30`02l_;`0_;bl0080/k>c00D0[:b/
0:>SX`2QXJ40SXj>07YjNP0206a/K00406ATI00O7al01PH6038b<P80:RXZ00@0EEEE05iNGP1;Bd/0
GUiN0P1VIVH01@1DE5@0LG5a09nOW`2QXJ40[jn_0080cLg=00@0NGUi096AT@1NGUh0QXJ60P1iNGT0
0`2m_Kd0clo?0<_;b`0>0?Ogma4000009P3ooolC00000140moOg0P3MgMd2075aL@<0UIFE0P1VIVH3
08f=S@80?Cdm0P19BDT302XZ:P80?Cdm0P1RHV830861P@80T92@0`2SXj<20:^[Z`80]KFe0`2YZJT2
0:>SX`D0UIFE0P2[Zj/309FEU@80XJ6Q0P3:b/X30=?Cd`80f=SH0P3Cdm<30<S8b080[:b/1`2l_;`3
0<g=c@80d];B0P3?cll30<W9b@80UIFE0`2IVIT206a/K080BDU90`15ADD206][J`80i^KV4@00000N
0?ooo`00703oool?00000080m?Cd00<0moOg0?Cdm03dm?@00`3dm?@01028R8P0GUiN04];B`1;Bd/2
05EEE@0504U9B@1;Bd/0DE5A02XZ:P0O7al00P0Z:RX00`2/[:`0clo?0<o?c`060=SHf0@0h>3P103H
f=P20=?Cd`040<g=c@3Hf=P0f=SH0<[:bP80`<300P2c/k<0202a/K40^[Zj0;bl_02l_;`0`L710<[:
bP3?cll0cLg=0`3@d=00103Hf=P0d];B0=3@d03=cLd30<[:bP030<30`02l_;`0_;bl0080/k>c00D0
[:b/0:>SX`2QXJ40SXj>07YjNP0206a/K00406ATI00O7al01PH6038b<P80:RXZ00@0EEEE05iNGP1;
Bd/0GUiN0P1VIVH01@1DE5@0LG5a09nOW`2QXJ40[jn_0080cLg=00@0NGUi096AT@1NGUh0QXJ60P1i
NGT00`2m_Kd0clo?0<_;b`0>0?Ogma4000009P3ooolC00000140moOg0P3MgMd2075aL@<0UIFE0P1V
IVH308f=S@80?Cdm0P19BDT302XZ:P80?Cdm0P1RHV830861P@80T92@0`2SXj<20:^[Z`80]KFe0`2Y
ZJT20:>SX`D0UIFE0P2[Zj/309FEU@80XJ6Q0P3:b/X30=?Cd`80f=SH0P3Cdm<30<S8b080[:b/1`2l
_;`30<g=c@80d];B0P3?cll30<W9b@80UIFE0`2IVIT206a/K080BDU90`15ADD206][J`80i^KV4@00
000N0?ooo`00703ooolA000000040?Cdm03gmoL0moOg0?Ogm`80kno_00@0UIFE06ATI01TI6@0?Cdm
0`15ADD0101;Bd/0DE5A04];B`0O7al2038b<P0401lO7`3:b/X0d=3@0=;BdP80d=3@2@3Hf=P20=?C
d`80d=3@0`3Hf=P01`3Cdm<0b/[:0<[:bP2g]kL0Zj^[0:b/[02a/K400P2[Zj/00`2c/k<0_;bl0<[:
bP020<g=c@80clo?00@0dm?C0<[:bP3:b/X0b<S80P3:b/X01038b<P0`<300;Ng]`2e]KD20;6a/@05
0:b/[02QXJ40T92@0861P@1iNGT00P1aLG401019BDT01PH601LG5`0f=SH205IFEP0405EEE@1NGUh0
I6AT04];B`80E5AD00D0BDU9075aL@2<S8`0VIVI0;6a/@020<71`@0407]kN`21PH40LG5a0861P@80
UIFE00@0_kno0<O7a`2OWil0bl_;0P3gmoL00`3dm?@0moOg0?Cdm0020?Cdm0@0moOg00<0m?Cd0000
000000004000000V0?oooa<000004@3gmoL20>WYj@80NWYj0`2EUID206ATI0<0NGUi0P19BDT203Hf
=P<0:RXZ0P1EEED205iNGP<0NGUi0P2=SHd308J6QP80ZJVY1@2l_;`20<71`@80b/[:0`31`L4207Yj
NP<0LG5a0P2g]kL<0=SHf080_;bl0`1aLG42092@T0L0f=SH0P3Cdm<30<o?c`80SHf=0`2MWId205iN
GP80I6AT0`0m?Cd205iNGP80oooo4@00000N0?ooo`00703ooolA000000040?Cdm03gmoL0moOg0?Og
m`80kno_00@0UIFE06ATI01TI6@0?Cdm0`15ADD0101;Bd/0DE5A04];B`0O7al2038b<P0401lO7`3:
b/X0d=3@0=;BdP80d=3@2@3Hf=P20=?Cd`80d=3@0`3Hf=P01`3Cdm<0b/[:0<[:bP2g]kL0Zj^[0:b/
[02a/K400P2[Zj/00`2c/k<0_;bl0<[:bP020<g=c@80clo?00@0dm?C0<[:bP3:b/X0b<S80P3:b/X0
1038b<P0`<300;Ng]`2e]KD20;6a/@050:b/[02QXJ40T92@0861P@1iNGT00P1aLG401019BDT01PH6
01LG5`0f=SH205IFEP0405EEE@1NGUh0I6AT04];B`80E5AD00D0BDU9075aL@2<S8`0VIVI0;6a/@02
0<71`@0407]kN`21PH40LG5a0861P@80UIFE00@0_kno0<O7a`2OWil0bl_;0P3gmoL00`3dm?@0moOg
0?Cdm0020?Cdm0@0moOg00<0m?Cd0000000000004000000V0?oooa<000004`3gmoL209FEU@<0SHf=
0P1NGUh307YjNP80FUYJ0P0W9bL3038b<P80?Cdm0P1NGUh306a/K080R8R80`2IVIT209FEU@80/k>c
0`30`<020<[:bP80^KVi0`1jNWX205EEE@<0SHf=0P38b<P20=?Cd`X0f=SH0P3Cdm<30:VYZ@80Kfm_
0P28R8P50=SHf080_kno0`3:b/X2092@T0<0PH610P1VIVH205EEE@<0?Cdm0P1;Bd/20?oooa400000
7P3oool001`0oooo4@0000000`3gmoL0kno_0?Ogm`030?Ogm`040=OGe`2=SHd0I6AT065QH@80?Cdm
00D0BDU9055AD@15ADD0Bd];055AD@03038b<P0307alO037alL0d=3@00<0d=3@1P3Hf=P20=?Cd`04
0=3@d03Hf=P0cLg=0<g=c@<0f=SH00@0d=3@0<S8b038b<P0^[Zj0P2i^KT00`2c/k<0/K6a0;6a/@02
0:b/[0030<30`03:b/X0b/[:0080d=3@0`3:b/X40<30`0030;Zj^P2e]KD0/K6a0080YjNW0P2MWId0
0`2>SXh0PH6107=cL`0206ATI00400/;2`0O7al05aLG04U9B@80EEEE00@0I6AT04E5A@1/K6`0E5AD
0P1NGUh01@0b<S80UIFE08f=S@2[Zj/0_kno0080PH6100@0SHf=07UiN@21PH40QXJ60P2EUID0102^
[Zh0a/K60<K6aP2m_Kd20<_;b`80moOg00<0m?Cd0?Ogm`3gmoL01@3gmoLB000002H0oooo4`00000C
0?Ogm`80Lg=c0`2QXJ4206ATI0<0NGUi0P1OGel202XZ:P<0ADE50P0O7al205EEE@<0K6a/0P2=SHd3
09FEU@80R8R80P1lO7`3092@T080RHV90P1aLG4306m_K`80ZJVY0`3=cLd20=?Cd`L0f=SH1`3Ph>03
0=SHf080dm?C0P1iNGT309fMW@80ZJVY0P2EUID30<W9b@80R8R80`1QHF4205iNGP80EEEE0`19BDT2
04E5A@80oooo4@00000N0?ooo`00703ooolA000000030?Ogm`3_knl0moOg00<0moOg00@0emOG08f=
S@1TI6@0HF5Q0P0m?Cd01@19BDT0DE5A04E5A@1;Bd/0DE5A00<0<S8b00<0O7al0<O7a`3@d=000`3@
d=060=SHf080dm?C00@0d=3@0=SHf03=cLd0cLg=0`3Hf=P0103@d=00b<S80<S8b02j^[X20;Vi^@03
0;>c/`2a/K40/K6a0080[:b/00<0`<300<[:bP3:b/X00P3@d=030<[:bP@0`<3000<0^[Zj0;Fe]@2a
/K400P2WYjL209fMW@0308j>SP21PH40Lg=c0080I6AT00@02`/;01lO7`0G5aL0BDU90P1EEED0101T
I6@0ADE506a/K01DE5@205iNGP05038b<P2EUID0SHf=0:^[Z`2o_kl00P21PH40102=SHd0NGUi0861
P@26QXH209FEU@040:j^[P36a/H0a/K60;fm_@80bl_;0P3gmoL00`3dm?@0moOg0?Ogm`050?Ogma80
00009P3ooolC000001<0moOg0P2=SHd309nOW`80LG5a0`1NGUh2069RHP805aLG0`0b<S8204U9B@80
EEEE0`1aLG4208f=S@<0XJ6Q102EUID507alO080alO71@3:b/X30=?Cd`@0f=SH0`3Ph>020=SHf080
hn?S2P3Ph>020=SHf0<0WIfM0P2YZJT20<o?c`<0bLW90P1jNWX3069RHP80EEEE0P19BDT305EEE@80
BDU90P1aLG4A000001h0oooo000L0?oooa4000001P3gmoL0103YjNT0[Zj^08J6QP1TI6@205ADE005
05EEE@0m?Cd0Bd];04E5A@1;Bd/00P1>CTh0100i>CT0<S8b0<g=c@37alL30<[:bP030=?Cd`3@d=00
f=SH0080f=SH0`3Cdm<01@3@d=00f=SH0:NWY`2WYjL0VIVI0080b/[:00<0`<300;Fe]@2e]KD00P1e
MGD01`2@T900YjNW0861P@21PH40XJ6Q0;6a/@2l_;`00P38b<P40<[:bP060<S8b030`<00_;bl0;bl
_02g]kL0]KFe0P2/[:`20:>SX`050:6QX@2IVIT0SXj>07YjNP1aLG400P15ADD0100G5aL08b<S038b
<P19BDT205EEE@0405YJFP1/K6`0K6a/05ADE080K6a/00D0GUiN08f=S@2_[jl0XJ6Q0:n_[`0208b<
S00408f=S@1VIVH0PH610861P@80XJ6Q0P2m_Kd01@3YjNT0[:b/0>WYj@3YjNT0^;Rh00T0moOg4P00
000V0?oooa<000004`3gmoL209nOW`<0Zj^[0P1/K6`305iNGP80SHf=1@0G5aL203dm?@80K6a/0`1j
NWX20861P@<0UIFE0P2SXj<20;6a/@<0_;bl0P37alL50<[:bP80clo?1`3Hf=P70>3Ph0<0hn?S1`3P
h>070=SHf080clo?0`3:b/X207UiN@<0HV9R0P1NGUh205EEE@<0IfMW0P19BDT206a/K14000007P3o
ool001`0oooo4@0000060?Ogm`040>WYj@2^[Zh0QXJ606ATI080E5AD00D0EEEE03dm?@1;Bd/0ADE5
04];B`0204i>CP0403Ti>@0b<S80cLg=0<O7a`<0b/[:00<0dm?C0=3@d03Hf=P00P3Hf=P30=?Cd`05
0=3@d03Hf=P0YjNW0:NWY`2IVIT00P3:b/X00`30`<00]KFe0;Fe]@0207EeM@07092@T02WYjL0PH61
0861P@2QXJ40/K6a0;bl_0020<S8b0@0b/[:00H0b<S80<30`02l_;`0_;bl0;Ng]`2e]KD20:b/[080
Xj>S00D0XJ6Q09VIV@2>SXh0NWYj075aL@0204E5A@0401LG5`0S8b<0<S8b04U9B@80EEEE00@0FUYJ
06a/K01/K6`0E5AD0P1/K6`01@1NGUh0SHf=0:n_[`2QXJ40[jn_0080S8b<00@0SHf=06IVIP21PH40
PH610P2QXJ420;fm_@050>WYj@2/[:`0jNWY0>WYj@2h^;P02@3gmoLB000002H0oooo4`00000C0?Og
m`80_Kfm0`2^[Zh207UiN@<0GUiN0P2EUID2038b<P<0:RXZ0P15ADD205iNGP<0NGUi0P2=SHd309FE
U@80Xj>S0P2YZJT30;bl_080b/[:0P37alL30<g=c@80d=3@1@3Hf=P20>3Ph0D0f=SH1@3Ph>020=SH
f0<0h>3P0P3Hf=P20>3Ph0D0f=SH0P3?cll30<O7a`80LG5a0`1NGUh405YJFP<0Jf][0P1JFUX2051@
D14000007P3oool001`0oooo4@0000060?Ogm`040>WYj@2^[Zh0QXJ606ATI080E5AD00D0EEEE03dm
?@1;Bd/0ADE504];B`0204i>CP0403Ti>@0b<S80cLg=0<O7a`<0b/[:00<0dm?C0=3@d03Hf=P00P3H
f=P30=?Cd`050=3@d03Hf=P0YjNW0:NWY`2IVIT00P3:b/X00`30`<00]KFe0;Fe]@0207EeM@07092@
T02WYjL0PH610861P@2QXJ40/K6a0;bl_0020<S8b0@0b/[:00H0b<S80<30`02l_;`0_;bl0;Ng]`2e
]KD20:b/[080Xj>S00D0XJ6Q09VIV@2>SXh0NWYj075aL@0204E5A@0401LG5`0S8b<0<S8b04U9B@80
EEEE00@0FUYJ06a/K01/K6`0E5AD0P1/K6`01@1NGUh0SHf=0:n_[`2QXJ40[jn_0080S8b<00@0SHf=
06IVIP21PH40PH610P2QXJ420;fm_@050>WYj@2/[:`0jNWY0>WYj@2h^;P02@3gmoLB000002H0oooo
4`00000C0?Ogm`80_Kfm0`2^[Zh207UiN@<0GUiN0P2EUID2038b<P<0:RXZ0P15ADD205iNGP<0NGUi
0P2=SHd309FEU@80Xj>S0P2YZJT30;bl_080b/[:0P37alL30<g=c@80d=3@1@3Hf=P20>3Ph0D0f=SH
1@3Ph>020=SHf0<0h>3P0P3Hf=P20>3Ph0D0f=SH0P3?cll30<O7a`80LG5a0`1NGUh405YJFP<0Jf][
0P1JFUX2051@D14000007P3oool001`0oooo4P0000020?Cdm0<0moOg00@0jNWY0<K6aP2VYZH0UIFE
0P1/K6`00`1VIVH0I6AT04i>CP0204];B`80BDU900@0Bd];03dm?@26QXH0bLW90`3=cLd50=?Cd`03
0=SHf03Cdm<0clo?00@0dm?C0P3:b/X0202l_;`0/K6a0:b/[02/[:`0]kNg0;>c/`2/[:`0/K6a0P2g
]kL01@2j^[X0_;bl0<;2`P31`L40b<S800<0b/[:0P30`<00102l_;`0]kNg0;Ng]`2a/K420:b/[0<0
Xj>S00D0XJ6Q09VIV@29RHT0NWYj05iNGP0203Hf=P0403dm?@0l?3`0FUYJ05EEE@80LG5a00@0I6AT
07]kN`1DE5@0IVIV0P1EEED01@2^[Zh0_Kfm0:6QX@2ZZZX0TI6A0080UIFE00@0NWYj0861P@2=SHd0
WinO0P2QXJ40102o_kl0^;Rh09FEU@3MgMd20<71`@030?Cdm03YjNT0moOg00H0moOg4`00000V0?oo
oa<000004`3gmoL20?Cdm0<0UIFE0P1kNg/306a/K080UIFE0P0G5aL5038b<P80K6a/1@21PH430:6Q
X@80ZJVY0P2a/K430;Zj^P80`L710P37alL30<[:bPD0dm?C103Hf=P?0>3Ph080f=SH0P3Ph>030=SH
f080d];B0P3?cll30;no_`80LG5a0`1DE5@205EEE@L0HV9R0P1EEEDA000001h0oooo000L0?oooa80
00000P3dm?@30?Ogm`040>WYj@36a/H0YZJV09FEU@80K6a/00<0IVIV06ATI01>CTh00P1;Bd/204U9
B@0404];B`0m?Cd0QXJ60<W9b@<0cLg=1@3Cdm<00`3Hf=P0dm?C0<o?c`040=?Cd`80b/[:00P0_;bl
0;6a/@2/[:`0[:b/0;Ng]`2c/k<0[:b/0;6a/@80]kNg00D0^[Zj0;bl_032`/80`L710<S8b0030<[:
bP80`<3000@0_;bl0;Ng]`2g]kL0/K6a0P2/[:`30:>SX`050:6QX@2IVIT0RHV907YjNP1NGUh00P0f
=SH0100m?Cd0?3`l05YJFP1EEED2075aL@0406ATI01kNg/0E5AD06IVIP80EEEE00D0[Zj^0;fm_@2Q
XJ40ZZZZ096AT@0209FEU@0407YjNP21PH40SHf=09nOW`80XJ6Q00@0_kno0;Rh^02EUID0gMgM0P31
`L400`3dm?@0jNWY0?Ogm`060?Ogma<000009P3ooolE000001<0moOg0`1TI6@20861P@<0QXJ60P1a
LG4201LG5`<07alO0P0f=SH205EEE@<0NGUi0P2=SHd309VIV@80ZJVY0P2c/k<30;bl_080_kno0P30
`<030<[:bP80cLg=0`3Cdm<20=3@d0D0f=SH1`3Ph>020=SHf0D0h>3P1@3Hf=P20=?Cd`80cLg=0`2l
_;`20861P@L0EEEE0`1OGel205EEEA<000007P3oool001`0oooo4`0000020?Cdm080kno_0P3dm?@0
2@3>c/h0WinO0861P@21PH40IVIV06a/K01@D500DE5A03dm?@0504];B`<0clo?00<0cLg=0<o?c`3C
dm<00`3@d=000`3Cdm<0clo?0=?Cd`060=?Cd`030<o?c`3:b/X0b<S800<0b<S800T0_;bl0;no_`32
`/80`/;20;bl_031`L40_;bl0<S8b02l_;`00P38b<P20;bl_080]kNg0P2j^[X0102a/K40[:b/0:NW
Y`2/[:`20:6QX@80VIVI00<0SXj>06a/K015ADD00P0f=SH0100G5aL0Cdm?05EEE@1TI6@206IVIP04
07UiN@1VIVH0PH6107YjNP80VIVI0P2m_Kd00`2IVIT0XJ6Q08b<S00208f=S@0407]kN`2=SHd0Ng]k
0:6QX@80Zj^[00@0`L710:b/[02EUID0Xj>S0P3GemL20>KViP030=GEe@3gmoL0m?Cd00<0moOg5000
000V0?oooaD000004`3gmoL306ATI080SHf=0`1aLG4206m_K`805aLG0`0O7al204U9B@80GUiN0`1l
O7`208J6QP<0VIVI0P2YZJT20;6a/@D0_;bl0P30`<030<[:bP80cLg=0`3Cdm<70=SHf0L0h>3P0P3H
f=P30>3Ph080f=SH0P3Ph>050=SHf080clo?0`2a/K4208f=S@<0HV9R0P1JFUX2069RHP<0IfMW0P1E
EEDC000001h0oooo000L0?oooa<000000P3dm?@20>o_k`80m?Cd00T0c/k>09nOW`21PH40PH6106IV
IP1/K6`0D51@055AD@0m?Cd01@1;Bd/30<o?c`030<g=c@3?cll0dm?C00<0d=3@00<0dm?C0<o?c`3C
dm<01P3Cdm<00`3?cll0b/[:0<S8b0030<S8b0090;bl_02o_kl0`/;20<;2`P2l_;`0`L710;bl_038
b<P0_;bl0080b<S80P2l_;`20;Ng]`80^[Zj00@0/K6a0:b/[02WYjL0[:b/0P2QXJ4209VIV@0308j>
SP1/K6`0ADE50080=SHf00@05aLG04m?C`1EEED0I6AT0P1VIVH0101iNGT0IVIV0861P@1jNWX209VI
V@80_Kfm00<0VIVI0:6QX@2<S8`00P2=SHd0101kNg/0SHf=07]kN`2QXJ420:^[Z`040<71`@2/[:`0
UIFE0:>SX`80emOG0P3Vi^H00`3EeMD0moOg0?Cdm0030?Ogma@000009P3ooolE000001<0moOg1@2E
UID307UiN@80HV9R0P0;2`/301LG5`80?Cdm0P1NGUh306a/K080QXJ60`2IVIT20:VYZ@80/K6a0`2j
^[X20;no_`80b<S81@3:b/X50=?Cd``0f=SH0P3Ph>030=SHf080h>3P1@3Hf=P20=?Cd`80b/[:0`2[
Zj/208R8R0<0HV9R0P1FEUH2069RHP<0Jf][0P1NGUhC000001h0oooo000L0?oooa<0000000P0kno_
0?Ogm`3dm?@0m?Cd0>c/k03_knl0i^KV0<k>cP80[Zj^00D0QXJ606a/K01/K6`0GUiN05ADE002051@
D00404E5A@1;Bd/0C4a<05ADE080clo?00@0b/[:0<o?c`3=cLd0b/[:0P3=cLd01038b<P0cLg=0=?C
d`3Cdm<30=SHf0040<g=c@3:b/X0f=SH0<[:bP80b<S800@0dm?C0=SHf03=cLd0b/[:0P31`L400`2l
_;`0`L710;bl_0020;Zj^P80_;bl00@0^[Zj0;bl_02j^[X0]kNg0`2a/K420:b/[0030:>SX`2QXJ40
XJ6Q0080VIVI00<0PH6105ADE00X:2P00P0;2`/0101JFUX0BDU905YJFP1aLG4208f=S@0406IVIP2<
S8`0Lg=c08b<S0<0_kno00<0XJ6Q09VIV@2=SHd00`1kNg/0102=SHd0VIVI0:6QX@2IVIT20<71`@04
0<O7a`2OWil0WinO096AT@80gMgM0P3Vi^H00`3YjNT0i^KV0?Ogm`030?Ogma@000009P3ooolE0000
01<0moOg0`3MgMd209FEU@<0I6AT0P1[Jf/500/;2`80<S8b0P19BDT306][J`80R8R80`2QXJ420:VY
Z@80/K6a0`2c/k<20;bl_080`<300`3:b/X20=3@d0`0f=SH0P3Ph>050=SHf0<0h>3P0P3Hf=P20>3P
h0<0f=SH0P3Cdm<20<[:bP<0ZJVY0P2=SHd3069RHP80IVIV0P1NGUh3069RHP80NWYj4`00000N0?oo
o`00703ooolC000000080>o_k`3gmoL0m?Cd0?Cdm03/k>`0kno_0>KViP3>c/h20:j^[P0508J6QP1/
K6`0K6a/05iNGP1DE5@00P1@D5001015ADD0Bd];04a<C01DE5@20<o?c`040<[:bP3?cll0cLg=0<[:
bP80cLg=00@0b<S80<g=c@3Cdm<0dm?C0`3Hf=P0103=cLd0b/[:0=SHf03:b/X20<S8b0040=?Cd`3H
f=P0cLg=0<[:bP80`L7100<0_;bl0<71`@2l_;`00P2j^[X20;bl_0040;Zj^P2l_;`0^[Zj0;Ng]`<0
/K6a0P2/[:`00`2SXj<0XJ6Q0:6QX@0209VIV@030861P@1DE5@0:2PX00802`/;00@0FUYJ04U9B@1J
FUX0LG5a0P2=SHd0101VIVH0S8b<07=cL`2<S8`30;no_`030:6QX@2IVIT0SHf=00<0Ng]k00@0SHf=
09VIV@2QXJ40VIVI0P31`L401037alL0WinO09nOW`2ATI420=gMg@80i^KV00<0jNWY0>KViP3gmoL0
0`3gmoLD000002H0oooo5@00000C0?Ogm`<0gMgM0P2EUID306ATI080Jf][1@0;2`/2038b<P80BDU9
0`1[Jf/208R8R0<0XJ6Q0P2YZJT20;6a/@<0/k>c0P2l_;`20<30`0<0b/[:0P3@d=0<0=SHf080h>3P
1@3Hf=P30>3Ph080f=SH0P3Ph>030=SHf080dm?C0P3:b/X30:VYZ@80SHf=0`1RHV8206IVIP80GUiN
0`1RHV8207YjNQ<000007P3oool001`0oooo4`000000203_knl0moOg0?Cdm03dm?@0k>c/0>o_k`3V
i^H0c/k>0P2^[Zh01@26QXH0K6a/06a/K01NGUh0E5AD0080D51@00@0ADE504];B`1<C4`0E5AD0P3?
cll0103:b/X0clo?0<g=c@3:b/X20<g=c@040<S8b03=cLd0dm?C0=?Cd`<0f=SH00@0cLg=0<[:bP3H
f=P0b/[:0P38b<P0103Cdm<0f=SH0<g=c@3:b/X20<71`@030;bl_031`L40_;bl0080^[Zj0P2l_;`0
102j^[X0_;bl0;Zj^P2g]kL30;6a/@80[:b/00<0Xj>S0:6QX@2QXJ400P2IVIT00`21PH40E5AD02PX
:00200/;2`0405YJFP19BDT0FUYJ075aL@80SHf=00@0IVIV08b<S01cLg<0S8b<0`2o_kl00`2QXJ40
VIVI08f=S@0307]kN`0408f=S@2IVIT0XJ6Q09VIV@80`L7100@0alO709nOW`2OWil0TI6A0P3MgMd2
0>KViP030>WYj@3Vi^H0moOg00<0moOg5000000V0?oooaD000005P3gmoL209nOW`<0IVIV0P1[Jf/5
01LG5`80<S8b0P1FEUH3075aL@80O7al0`2SXj<20:VYZ@80/K6a0`2c/k<20;bl_080`<300`3:b/X2
0=?Cd`<0d=3@5@3Hf=P20>3Ph0D0f=SH0P3:b/X30:^[Z`80SHf=0`1RHV8205EEE@80E5AD0`1EEED2
05IFEQ<000007P3oool001`0oooo500000000`3dm?@0moOg0?Ogm`030?Cdm0080=OGe`33`l<0`l?3
0:6QX@2EUID0NGUi06ATI01EEED205iNGP04051@D00i>CT0B4Q803Ti>@80GUiN0P3Bd]802@3?cll0
b/[:0<[:bP3:b/X0b<S80:JVYP2MWId0NGUi05iNGP0206MWI`0407EeM@1iNGT0MGEe07EeM@80OGem
00@0Kfm_05iNGP1FEUH0Fe]K0P1WIfL01@1=CDd0IFEU05]KF`1>CTh0HF5Q0080WIfM0`2j^[X40;6a
/@80Xj>S00P0XJ6Q0:>SX`2SXj<0SXj>0861P@1NGUh07alO01LG5`80?Cdm00@0BDU905YJFP2=SHd0
ZJVY0P1NGUh0102YZJT0PH610:>SX`2o_kl20<g=c@80VIVI00<0MGEe08b<S021PH400P2=SHd0102A
TI40PH610:^[Z`2m_Kd20<71`@040;fm_@2QXJ40Zj^[09nOW`80^;Rh00D0gMgM0>c/k03Vi^H0k>c/
0?Cdm0020>c/k1D000009P3ooolH000001<0moOg0P2d];@306ATI080Jf][0P0G5aL300/;2`807alO
0P0m?Cd3069RHP80R8R80`2EUID20:VYZ@80Zj^[0`2c/k<20<;2`P80b<S8203Cdm<90=SHf080h>3P
0`3Hf=P50>3Ph0L0f=SH0P3@d=020<[:bP<0[Zj^0P2=SHd306a/K080EUIF0P1?Cdl304U9BAD00000
7P3oool001`0oooo500000000`3dm?@0moOg0?Ogm`030?Cdm0080=OGe`33`l<0`l?30:6QX@2EUID0
NGUi06ATI01EEED205iNGP04051@D00i>CT0B4Q803Ti>@80GUiN0P3Bd]802@3?cll0b/[:0<[:bP3:
b/X0b<S80:JVYP2MWId0NGUi05iNGP0206MWI`0407EeM@1iNGT0MGEe07EeM@80OGem00@0Kfm_05iN
GP1FEUH0Fe]K0P1WIfL01@1=CDd0IFEU05]KF`1>CTh0HF5Q0080WIfM0`2j^[X40;6a/@80Xj>S00P0
XJ6Q0:>SX`2SXj<0SXj>0861P@1NGUh07alO01LG5`80?Cdm00@0BDU905YJFP2=SHd0ZJVY0P1NGUh0
102YZJT0PH610:>SX`2o_kl20<g=c@80VIVI00<0MGEe08b<S021PH400P2=SHd0102ATI40PH610:^[
Z`2m_Kd20<71`@040;fm_@2QXJ40Zj^[09nOW`80^;Rh00D0gMgM0>c/k03Vi^H0k>c/0?Cdm0020>c/
k1D000009P3ooolH000001<0moOg0P2o_kl307UiN@80R8R80P0O7al301@D50807alO0P0f=SH3075a
L@80O7al0`2IVIT20:^[Z`80/K6a0`2f][H20;bl_080b<S80`3:b/X20=3@d0h0f=SH303Ph>030=SH
f080dm?C0P3:b/X30;Jf]P80SHf=0`1/K6`204m?C`D0EEEE5@00000N0?ooo`00703ooolE000000<0
moOg00<0kno_0?Ogm`3YjNT00P3MgMd01@3EeMD0[Zj^09FEU@1jNWX0K6a/0080IVIV00@0GUiN04];
B`1EEED0ADE50P0m?Cd00`1;Bd/0d];B0<g=c@030<[:bP040<S8b03=cLd0b/[:0:JVYP@0WIfM00<0
cLg=0<30`02VYZH00P2VYZH0102e]KD0`<3009fMW@2MWId209VIV@05092@T02=SHd0RHV90:>SX`2a
/K400P2c/k<00`2j^[X0_;bl0;>c/`030;6a/@040:VYZ@2SXj<0VIVI09fMW@80SXj>00D0PH6104U9
B@0Z:RX0:RXZ02LW9`0205EEE@0402XZ:P2YZJT0/K6a06IVIP80[Zj^00@0PH610:ZZZP2[Zj/0SHf=
0P2<S8`01@2GUiL0KVi^08b<S021PH40SHf=0080UIFE00@0VIVI0:>SX`2^[Zh0`L710P39bLT0102E
UID0QXJ609FEU@2QXJ420:b/[080i^KV0P3/k>`00`3Vi^H000000000000E000002H0oooo6000000C
0?Ogm`80dM7A0`2<S8`208J6QP805aLG0`0Z:RX202<S8`80=SHf0`1RHV8207alO0<0SHf=0P2SXj<2
0;6a/@<0^[Zj0P31`L450<[:bPD0dm?C6P3Hf=P20<o?c`80b/[:0`2c/k<209FEU@<0Jf][0P1FEUH2
04m?C`<0BDU95@00000N0?ooo`00703ooolE000000<0moOg00<0kno_0?Ogm`3YjNT00P3MgMd01@3E
eMD0[Zj^09FEU@1jNWX0K6a/0080IVIV00@0GUiN04];B`1EEED0ADE50P0m?Cd00`1;Bd/0d];B0<g=
c@030<[:bP040<S8b03=cLd0b/[:0:JVYP@0WIfM00<0cLg=0<30`02VYZH00P2VYZH0102e]KD0`<30
09fMW@2MWId209VIV@05092@T02=SHd0RHV90:>SX`2a/K400P2c/k<00`2j^[X0_;bl0;>c/`030;6a
/@040:VYZ@2SXj<0VIVI09fMW@80SXj>00D0PH6104U9B@0Z:RX0:RXZ02LW9`0205EEE@0402XZ:P2Y
ZJT0/K6a06IVIP80[Zj^00@0PH610:ZZZP2[Zj/0SHf=0P2<S8`01@2GUiL0KVi^08b<S021PH40SHf=
0080UIFE00@0VIVI0:>SX`2^[Zh0`L710P39bLT0102EUID0QXJ609FEU@2QXJ420:b/[080i^KV0P3/
k>`00`3Vi^H000000000000E000002H0oooo6000000C0?Ogm`80k>c/0`2=SHd2075aL@802`/;1@0Z
:RX203Hf=P<0GUiN0P1iNGT308f=S@80[:b/0P2a/K430;Ng]`80_kno0P3:b/X30<S8b080cLg=1@3C
dm<A0=SHf080h>3P1@3Hf=P20=?Cd`80b/[:0`31`L4209FEU@<0Jf][101FEUH304m?CaD000007P3o
ool001`0oooo5@0000030?Ogm`030>o_k`3gmoL0jNWY0080gMgM00D0eMGE0:j^[P2EUID0NWYj06a/
K00206IVIP0405iNGP1;Bd/0EEEE04E5A@80?Cdm00<0Bd];0=;BdP3=cLd00`3:b/X01038b<P0cLg=
0<[:bP2VYZH409fMW@030<g=c@30`<00YZJV0080YZJV00@0]KFe0<30`02MWId0WIfM0P2IVIT01@2@
T900SHf=08V9R@2SXj<0/K6a0080/k>c00<0^[Zj0;bl_02c/k<00`2a/K40102YZJT0Xj>S09VIV@2M
WId208j>SP050861P@19BDT0:RXZ02XZ:P0W9bL00P1EEED0100Z:RX0ZJVY0;6a/@1VIVH20:j^[P04
0861P@2ZZZX0Zj^[08f=S@80S8b<00D0UiNG06i^KP2<S8`0PH6108f=S@0209FEU@0409VIV@2SXj<0
[Zj^0<71`@80bLW900@0UIFE08J6QP2EUID0XJ6Q0P2/[:`20>KViP80k>c/00<0i^KV000000000000
5@00000V0?oooaP000004`3gmoL20>c/k0<0SHf=0P1aLG4200/;2`D0:RXZ0P0f=SH305iNGP80NGUi
0`2=SHd20:b/[080/K6a0`2g]kL20;no_`80b/[:0`38b<P20<g=c@D0dm?C4@3Hf=P20>3Ph0D0f=SH
0P3Cdm<20<[:bP<0`L710P2EUID306][J`@0EUIF0`1?CdlE000001h0oooo000L0?oooaL000000P3g
moL20?Cdm080jNWY00@0eMGE0<_;b`2^[Zh0UIFE0`1kNg/0101aLG40EEEE05iNGP1DE5@203Ti>@03
03dm?@1@D500bLW900<0clo?00D0dm?C0<g=c@3:b/X0b/[:0<S8b0020<71`@040;Ng]`2e]KD0[:b/
0:NWY`H0YZJV0P2/[:`0102WYjL0[:b/0;6a/@2/[:`30;Zj^P040;bl_02c/k<0/K6a0:b/[080ZJVY
00@0Xj>S09VIV@2IVIT0SXj>0P1NGUh01@1>CTh0Bd];03dm?@0Z:RX0?Cdm0080HV9R00@0VIVI07Ui
N@1NGUh0ZJVY0P26QXH0102GUiL0PH6106IVIP1cLg<209:BTP0508J6QP1kNg/0SHf=0861P@2QXJ40
0P2EUID0102[Zj/0XJ6Q0:^[Z`37alL20:^[Z`040:6QX@2OWil0WinO0:6QX@80[Zj^00@0`L710>KV
iP3Vi^H0kno_6000000V0?oooaX000004`3gmoL309VIV@80LG5a0P0f=SH301LG5`80<S8b0P19BDT3
05EEE@80NWYj0`2=SHd40:VYZ@<0/k>c0P2o_kl20<30`0D0b<S80`3@d=040=?Cd`X0f=SH0P3Ph>07
0=SHf0D0dm?C0P3:b/X30;bl_080SHf=0`1[Jf/205IFEP80Jf][6000000N0?ooo`00703ooolG0000
0080moOg0P3dm?@20>WYj@040=GEe@3;bl/0[Zj^09FEU@<0Ng]k00@0LG5a05EEE@1NGUh0E5AD0P0i
>CT00`0m?Cd0D51@0<W9b@030<o?c`050=?Cd`3=cLd0b/[:0<[:bP38b<P00P31`L40102g]kL0]KFe
0:b/[02WYjL60:JVYP80[:b/00@0YjNW0:b/[02a/K40[:b/0`2j^[X0102l_;`0/k>c0;6a/@2/[:`2
0:VYZ@040:>SX`2IVIT0VIVI08j>SP80GUiN00D0CTi>04];B`0m?Cd0:RXZ03dm?@02069RHP0409VI
V@1iNGT0GUiN0:VYZ@80QXJ600@0UiNG0861P@1VIVH0Lg=c0P2BTY801@26QXH0Ng]k08f=S@21PH40
XJ6Q0080UIFE00@0Zj^[0:6QX@2[Zj/0alO70P2[Zj/0102QXJ40WinO09nOW`2QXJ420:j^[P040<71
`@3Vi^H0i^KV0>o_kaP000009P3ooolJ000001<0moOg0`2ATI4206ATI080NWYj0`0<30`202<S8`80
=SHf0`1JFUX2065QH@<0SHf=0P2EUID20:>SX`<0^[Zj0P2l_;`20<;2`P<0b<S81@3:b/X20=SHf080
dm?C4@3Hf=P20=?Cd`<0f=SH0P3Cdm<20<[:bP<0/k>c0P2EUID5069RHP80Jf][6000000N0?ooo`00
703ooolH00000080moOg00P0m?Cd0>WYj@3YjNT0jNWY0<o?c`3;bl/0WinO096AT@80NGUi00@0Ng]k
06ATI01NGUh0GUiN0P1DE5@0100m?Cd0>CTi051@D01JFUX20<g=c@030<[:bP3=cLd0dm?C0080dm?C
0P3@d=000`3=cLd0b/[:0<[:bP040<[:bP030<S8b030`<00`<300080`L7100<0b<S80;no_`32`/80
0P2l_;`20;6a/@040;Fe]@2c/k<0/K6a0:b/[080XJ6Q00@0VIVI09BDU01VIVH0GUiN0P1VIVH01@1E
EED0E5AD03dm?@0m?Cd0EEEE0080SHf=00@0PH6106a/K02OWil0DE5A0P21PH40101NGUh0LG5a07Mg
M`26QXH2075aL@0308J6QP2=SHd0IVIV0080SHf=0`2QXJ400`2/[:`0/K6a0;fm_@0208f=S@0407Mg
M`2=SHd0WinO09FEU@80Zj^[00<0_Kfm0=OGe`3/k>`06@00000V0?oooaX000003P3gmoL30?Cdm080
moOg0`2h^;P206ATI080N7Qh0`0;2`/202XZ:P80<S8b0`1JFUX206ATI0<0O7al0P2YZJT20:^[Z`<0
/k>c0P2l_;`20<30`0D0b<S81@3:b/X70=?Cd``0f=SH0P3Cdm<30<g=c@80b/[:0P30`<030;Jf]P80
SHf=0`1RHV8204m?C`80EEEE6000000N0?ooo`00703ooolH00000080moOg00P0m?Cd0>WYj@3YjNT0
jNWY0<o?c`3;bl/0WinO096AT@80NGUi00@0Ng]k06ATI01NGUh0GUiN0P1DE5@0100m?Cd0>CTi051@
D01JFUX20<g=c@030<[:bP3=cLd0dm?C0080dm?C0P3@d=000`3=cLd0b/[:0<[:bP040<[:bP030<S8
b030`<00`<300080`L7100<0b<S80;no_`32`/800P2l_;`20;6a/@040;Fe]@2c/k<0/K6a0:b/[080
XJ6Q00@0VIVI09BDU01VIVH0GUiN0P1VIVH01@1EEED0E5AD03dm?@0m?Cd0EEEE0080SHf=00@0PH61
06a/K02OWil0DE5A0P21PH40101NGUh0LG5a07MgM`26QXH2075aL@0308J6QP2=SHd0IVIV0080SHf=
0`2QXJ400`2/[:`0/K6a0;fm_@0208f=S@0407MgM`2=SHd0WinO09FEU@80Zj^[00<0_Kfm0=OGe`3/
k>`06@00000V0?oooad000002`3gmoL30?ooo`80moOg0`31`L4207UiN@80NWYj0`1FEUH201LG5`80
Jf][0`19BDT206a/K0<0O7al0P2IVIT209FEU@<0/K6a0P2j^[X20<;2`P<0b<S80P3:b/X30<S8b0L0
b/[:0P3Hf=P20=?Cd`D0f=SH0`3Cdm<20=;BdP80f=SH0`3Cdm<20<S8b080alO70`2c/k<208f=S@D0
NWYj6P00000N0?ooo`00703ooolJ000000080?Ogm`3dm?@0m?Cd0>c/k03YjNT0bl_;0;fm_@2EUID2
08f=S@040861P@1cLg<0I6AT06IVIP<0GUiN00<0?Cdm03Ti>@18B4P00P0m?Cd01021PH40clo?0=?C
d`3:b/X30=?Cd`L0f=SH0P3@d=040<[:bP040<71`@2l_;`0_kno0;Zj^P80]KFe00@0/k>c0:b/[02S
Xj<0T92@0P2IVIT2075aL@0907=cL`1/K6`0LG5a075aL@1TI6@0GUiN055AD@15ADD0QXJ60080NGUi
00@0PH6107]kN`0i>CT09bLW0P18B4P00`1VIVH0QXJ608b<S00308J6QP0508b<S01cLg<0TI6A08f=
S@2EUID00P2QXJ40102[Zj/0_kno0;fm_@2=SHd207]kN`0408f=S@26QXH0UIFE0;Rh^080_Kfm00<0
];Bd0000000000006@00000V0?oooad000003P3gmoL20?ooo`<0_Kfm0P2=SHd2075aL@<0ADE5100f
=SH305EEE@80FUYJ0`1aLG4208R8R080UIFE0`2a/K420;>c/`80^[Zj0`38b<P20<[:bPD0b<S81`3:
b/X20=3@d0X0dm?C0P3Hf=P30=3@d080b<S80P31`L430;>c/`80SHf=0`1lO7`205EEEAX000007P3o
ool001`0oooo6P000000203gmoL0m?Cd0?Cdm03/k>`0jNWY0<_;b`2m_Kd0UIFE0P2=SHd01021PH40
Lg=c06ATI01VIVH305iNGP0303dm?@0i>CT0B4Q80080?Cdm00@0PH610<o?c`3Cdm<0b/[:0`3Cdm<7
0=SHf080d=3@103:b/X01031`L40_;bl0;no_`2j^[X20;Fe]@040;>c/`2/[:`0Xj>S092@T080VIVI
0P1aLG402@1cLg<0K6a/075aL@1aLG40I6AT05iNGP1ADE40ADE508J6QP0207UiN@040861P@1kNg/0
>CTi02LW9`80B4Q800<0IVIV08J6QP2<S8`00`26QXH01@2<S8`0Lg=c096AT@2=SHd0UIFE0080XJ6Q
00@0Zj^[0;no_`2m_Kd0SHf=0P1kNg/0102=SHd0QXJ609FEU@2h^;P20;fm_@030;Bd]00000000000
01T000009P3ooolM000000T0moOg0P3oool80?Ogm`80UIFE0P1/K6`306][J`80<S8b0P0l?3`304U9
B@80Cdm?0`1jNWX208R8R080UIFE0`2SXj<20:^[Z`80]kNg0`2l_;`20;fm_@<0`<300P38b<P20;fm
_@<0_;bl0P38b<P20<[:bP<0cLg=0P3Cdm<30=3@d080cLg=0P3?cll30=3@d080b<S80P2l_;`309nO
W`80QXJ60`1NGUh205ADE1X000007P3oool001`0oooo6P000000203gmoL0m?Cd0?Cdm03/k>`0jNWY
0<_;b`2m_Kd0UIFE0P2=SHd01021PH40Lg=c06ATI01VIVH305iNGP0303dm?@0i>CT0B4Q80080?Cdm
00@0PH610<o?c`3Cdm<0b/[:0`3Cdm<70=SHf080d=3@103:b/X01031`L40_;bl0;no_`2j^[X20;Fe
]@040;>c/`2/[:`0Xj>S092@T080VIVI0P1aLG402@1cLg<0K6a/075aL@1aLG40I6AT05iNGP1ADE40
ADE508J6QP0207UiN@040861P@1kNg/0>CTi02LW9`80B4Q800<0IVIV08J6QP2<S8`00`26QXH01@2<
S8`0Lg=c096AT@2=SHd0UIFE0080XJ6Q00@0Zj^[0;no_`2m_Kd0SHf=0P1kNg/0102=SHd0QXJ609FE
U@2h^;P20;fm_@030;Bd]0000000000001T000009P3ooolM000000T0moOg0P3oool80?Ogm`80UIFE
0P1/K6`306][J`80<S8b0P0l?3`304U9B@80Cdm?0`1jNWX208R8R080UIFE0`2SXj<20:^[Z`80]kNg
0`2l_;`20;fm_@<0`<300P38b<P20;fm_@<0_;bl0P38b<P20<[:bP<0cLg=0P3Cdm<30=3@d080cLg=
0P3?cll30=3@d080b<S80P2l_;`309nOW`80QXJ60`1NGUh205ADE1X000007P3oool001`0oooo6`00
00020?7al@050>o_k`3dm?@0m?Cd0<o?c`2/[:`00P2EUID0102=SHd0NGUi07=cL`1cLg<206IVIP04
05iNGP1VIVH0<S8b03dm?@80Bd];0P0m?Cd00`2=SHd0cLg=0=?Cd`020=SHf0040=?Cd`3Hf=P0d=3@
0=SHf080d=3@00@0dm?C0=3@d03:b/X0b<S80P3:b/X20<30`0030;Ng]`2e]KD0[:b/0080ZZZZ00<0
XJ6Q09VIV@1kNg/0101kNg/00`26QXH0Ng]k0861P@0207]kN`05075aL@1/K6`0EEEE04a<C01kNg/0
0P1NGUh0102<S8`0A4A403Ti>@0W9bL2038b<P04075aL@1gMgL0FUYJ07MgM`80TY:B00D0LG5a08f=
S@1kNg/0S8b<0:6QX@020:n_[`040;fm_@31`L40[Zj^07MgM`<0SHf=00<0VIVI096AT@2QXJ400P2^
[ZhL000002H0oooo7`0000090?Ogm`<0oooo0P3gmoL30?Cdm080_kno0P2=SHd306m_K`80IfMW0P1F
EUH304m?C`80FUYJ0`1aLG4208J6QP80R8R80`2QXJ420:VYZ@80/K6a0`2g]kL20:b/[0D0]KFe0P2j
^[X30;Ng]`80_;bl0P3:b/X30<S8b080cLg=0`3:b/X20<o?c`80alO70`38b<P20<30`080][Jf0`2[
Zj/20861P@<0EEEE7000000N0?ooo`00703ooolK00000080lO7a00D0kno_0?Cdm03dm?@0clo?0:b/
[00209FEU@0408f=S@1iNGT0Lg=c07=cL`80IVIV00@0GUiN06IVIP0b<S80?Cdm0P1;Bd/203dm?@03
08f=S@3=cLd0dm?C0080f=SH00@0dm?C0=SHf03@d=00f=SH0P3@d=00103Cdm<0d=3@0<[:bP38b<P2
0<[:bP80`<3000<0]kNg0;Fe]@2/[:`00P2ZZZX00`2QXJ40VIVI07]kN`0407]kN`0308J6QP1kNg/0
PH610080Ng]k00D0LG5a06a/K01EEED0C4a<07]kN`0205iNGP0408b<S014A4@0>CTi02LW9`80<S8b
00@0LG5a07MgM`1JFUX0MgMg0P2BTY801@1aLG40SHf=07]kN`2<S8`0XJ6Q0080[jn_00@0_Kfm0<71
`@2^[Zh0MgMg0`2=SHd00`2IVIT0TI6A0:6QX@020:j^[Q`000009P3ooolO00000140moOg0P2o_kl2
08J6QPD0K6a/0P1RHV8306][J`80E5AD0`1_Kfl206a/K080R8R80`2EUID2092@T0D0VIVI0P2QXJ43
0:>SX`80XJ6Q0P2SXj<30:VYZ@80/k>c0P2a/K430;bl_0D0`L71103:b/X30;bl_080^;Rh0P2o_kl3
09FEU@80LG5a0`1[Jf/L000001h0oooo000L0?oooah000000P3alO40203Vi^H0a/K60:^[Z`2[Zj/0
UIFE0861P@1kNg/0Lg=c0P1VIVH0101kNg/0GUiN05iNGP0W9bL204E5A@80?Cdm00<0>CTi05ADE02c
/k<00P37alL30<[:bP<0b<S80`30`<001`2i^KT0]kNg0;Ng]`2g]kL0/K6a0:b/[02SXj<00`29RHT0
0`26QXH0RHV908V9R@040861P@0308b<S029RHT0PH610080QXJ600D0Ng]k07=cL`1cLg<0QXJ605AD
E00205EEE@0406IVIP1NGUh0C4a<03Ti>@80?Cdm00@0KVi^04a<C01VIVH0QXJ60P25QHD01@1kNg/0
LG5a07]kN`2BTY80Xj>S0080[jn_00@0/K6a0:^[Z`2EUID0UIFE0P21PH400`1gMgL0Zj^[0:^[Z`0O
000002H0oooo7`0000070?Ogm`80m?Cd203gmoL20;fm_@80[:b/1@21PH4203dm?@<0O7al0P1RHV83
07alO080QXJ60P2EUID307alO080R8R80P26QXH30861P@80SHf=0`2IVIT20:>SX`80VIVI0`2OWil2
0:^[Z`80[:b/0`2o_kl20:VYZ@<0/k>c1031`L430<S8b080^;Rh0P2EUID307inOP80NWYj0`1RHV8L
000001h0oooo000L0?oooah000000P3alO40203Vi^H0a/K60:^[Z`2[Zj/0UIFE0861P@1kNg/0Lg=c
0P1VIVH0101kNg/0GUiN05iNGP0W9bL204E5A@80?Cdm00<0>CTi05ADE02c/k<00P37alL30<[:bP<0
b<S80`30`<001`2i^KT0]kNg0;Ng]`2g]kL0/K6a0:b/[02SXj<00`29RHT00`26QXH0RHV908V9R@04
0861P@0308b<S029RHT0PH610080QXJ600D0Ng]k07=cL`1cLg<0QXJ605ADE00205EEE@0406IVIP1N
GUh0C4a<03Ti>@80?Cdm00@0KVi^04a<C01VIVH0QXJ60P25QHD01@1kNg/0LG5a07]kN`2BTY80Xj>S
0080[jn_00@0/K6a0:^[Z`2EUID0UIFE0P21PH400`1gMgL0Zj^[0:^[Z`0O000002H0oooo8@00000:
0?Ogm`80m?Cd1@3gmoL20;Rh^0<0UIFE0P1jNWX206a/K0<0FUYJ1@1aLG4207UiN@80Jf][1@1lO7`5
075aL@80K6a/0`26QXH207UiN@D0SHf=0P2EUID20:VYZ@D0Zj^[0`2/[:`20;Jf]P80`L711@39bLT2
09nOW`<0HV9R0P1aLG4O000001h0oooo000L0?oooal0000000<0k>c/0?Cdm03MgMd00P2h^;P0102[
Zj/0SHf=0861P@1cLg<206a/K080GUiN00D0IVIV05ADE014A4@0A4A403Ti>@0203dm?@0404A4A02c
/k<0/k>c0;>c/`80/K6a00D0]KFe0;6a/@2/[:`0[:b/0;6a/@020:b/[0040:>SX`2UYJD0YJFU0:FU
Y@<0VIVI00D0T92@09BDU02DU9@0U9BD092@T00209VIV@80T92@0`2IVIT0202>SXh0S8b<08b<S02>
SXh0S8b<07]kN`2BTY80Lg=c0P1DE5@206a/K00806IVIP1NGUh0C4a<04a<C018B4P0<S8b06i^KP25
QHD2079bLP0508F5Q@1gMgL0QXJ609NGU`2XZ:P00P2SXj<0102_[jl0SHf=08f=S@2GUiL208f=S@03
09VIV@2EUID0000001l000009P3ooolQ000000X0moOg0P3oool50?Ogm`80[Zj^0`2d];@208J6QPL0
I6AT0`1_Kfl207QhN080Jf][0`26QXH207YjNP80R8R80`2EUID207YjNP<0O7al102EUID308R8R080
T92@1`2OWil50:^[Z`80][Jf0`2m_Kd20:ZZZP80WIfM0`2VYZH207EeMAl000007P3oool001`0oooo
7`0000000`3/k>`0m?Cd0=gMg@020;Rh^0040:^[Z`2=SHd0PH6107=cL`80K6a/0P1NGUh01@1VIVH0
E5AD04A4A014A4@0>CTi0080?Cdm00@0A4A40;>c/`2c/k<0/k>c0P2a/K401@2e]KD0/K6a0:b/[02/
[:`0/K6a0080[:b/00@0Xj>S0:FUY@2UYJD0YJFU0`2IVIT01@2@T900U9BD09BDU02DU9@0T92@0080
VIVI0P2@T90309VIV@0808j>SP2<S8`0S8b<08j>SP2<S8`0Ng]k09:BTP1cLg<205ADE080K6a/00P0
IVIV05iNGP1<C4`0C4a<04Q8B00b<S80KVi^08F5Q@80LW9b00D0QHF507MgM`26QXH0UiNG0:RXZ002
0:>SX`040:n_[`2=SHd0SHf=09NGU`80SHf=00<0VIVI09FEU@0000007`00000V0?ooob4000002P3g
moL20?ooo`D0moOg0P2^[Zh30;Bd]080QXJ61`1TI6@306m_K`80N7Qh0P1[Jf/308J6QP80NWYj0P28
R8P309FEU@80NWYj0`1lO7`409FEU@<0R8R80P2@T90709nOW`D0Zj^[0P2f][H30;fm_@80ZZZZ0P2M
WId30:JVYP80MGEe7`00000N0?ooo`00703ooolO000000030>c/k03dm?@0gMgM0080^;Rh00@0Zj^[
08f=S@21PH40Lg=c0P1/K6`205iNGP0506IVIP1DE5@0A4A404A4A00i>CT00P0m?Cd01014A4@0/k>c
0;>c/`2c/k<20;6a/@050;Fe]@2a/K40[:b/0:b/[02a/K400P2/[:`0102SXj<0YJFU0:FUY@2UYJD3
09VIV@05092@T02DU9@0U9BD09BDU02@T9000P2IVIT2092@T0<0VIVI00P0SXj>08b<S02<S8`0SXj>
08b<S01kNg/0TY:B07=cL`80E5AD0P1/K6`0201VIVH0GUiN04a<C01<C4`0B4Q8038b<P1^KVh0QHF5
0P1bLW801@25QHD0MgMg08J6QP2GUiL0Z:RX0080Xj>S00@0[jn_08f=S@2=SHd0UiNG0P2=SHd00`2I
VIT0UIFE0000000O000002H0oooo9000000>0?Ogm`80QXJ60`2MWId20:^[Z`80Ng]k0`1FEUH205EE
E@<0HV9R0P19BDT205YJFP<0Jf][0P28R8P2075aL@<0UIFE0P1jNWX3075aL@80NWYj0P1TI6@3075a
L@T0UIFE1@2OWil20:^[Z`<0/k>c0P2f][H208f=S@<0PH618@00000N0?ooo`00703ooolQ00000007
0>o_k`3EeMD0eMGE0:j^[P2QXJ40S8b<0861P@0207=cL`0407]kN`1JFUX0IVIV06IVIP80GUiN0P0b
<S800`0i>CT0?Cdm0;no_`020;>c/`040;bl_02c/k<0^[Zj0;Zj^P@0]KFe00H0[:b/0:n_[`2ZZZX0
ZZZZ0:NWY`2ZZZX20:NWY`030:FUY@2IVIT0VIVI0080VIVI0P2QXJ420:NWY`80XJ6Q102IVIT209BD
U00308j>SP2=SHd0Ng]k0080Lg=c00<0LG5a06IVIP1aLG400`1cLg<306IVIP0806i^KP1eMGD0MGEe
07MgM`25QHD0TY:B0:RXZ02QXJ420:n_[`04096AT@1aLG40LG5a07]kN`80TI6A8P00000V0?ooob@0
00003P3gmoL20=7Ad@<0WIfM0P2m_Kd209FEU@<0K6a/0P1EEED506ATI0D0GUiN0P19BDT207YjNP<0
GUiN0P1lO7`308J6QP80O7al0P1RHV830861P@80O7al0P26QXH308R8R080UIFE1`2OWil50;Rh^080
YZJV0`2PX:0Q000001h0oooo000L0?ooob40000000L0kno_0=GEe@3EeMD0[Zj^0:6QX@2<S8`0PH61
0080Lg=c00@0Ng]k05YJFP1VIVH0IVIV0P1NGUh2038b<P0303Ti>@0m?Cd0_kno0080/k>c00@0_;bl
0;>c/`2j^[X0^[Zj102e]KD01P2/[:`0[jn_0:ZZZP2ZZZX0YjNW0:ZZZP80YjNW00<0YJFU09VIV@2I
VIT00P2IVIT20:6QX@80YjNW0P2QXJ4409VIV@80U9BD00<0SXj>08f=S@1kNg/00P1cLg<00`1aLG40
IVIV075aL@0307=cL`<0IVIV00P0KVi^07EeM@1eMGD0MgMg08F5Q@2BTY80Z:RX0:6QX@80[jn_00@0
TI6A075aL@1aLG40Ng]k0P2ATI4R000002H0oooo9P0000020?Ogm`<0m?Cd2@3gmoL309fMW@80PH61
0P2o_kl309nOW`80QXJ60`1NGUh205EEE@80I6AT1@1EEED204E5A@<0GUiN0P1[Jf/3069RHP80FUYJ
0P2EUID307YjNP80HV9R0P26QXH308f=S@80PH610`2EUID208f=S@80UIFE0`2h^;P20;Bd]080PH61
9000000N0?ooo`00703ooolU00000080XJ6Q00<0SHf=07]kN`1kNg/00P1cLg<0201DE5@0IVIV05YJ
FP1JFUX0C4a<038b<P0m?Cd0<S8b1P2o_kl01`2j^[X0`/;20<;2`P2m_Kd0]KFe0;fm_@2e]KD00P2_
[jl01@2e]KD0[jn_0:b/[02_[jl0[:b/0080[jn_0`2/[:`01`2a/K40[jn_0:n_[`2ZZZX0YjNW0:>S
X`2ZZZX00`2SXj<0102QXJ40VIVI08b<S02IVIT209BDU0030861P@1jNWX0Ng]k00<0Lg=c00@0GUiN
06a/K01/K6`0FUYJ0P1VIVH01@1gMgL0TY:B09:BTP2BTY80VIVI00<0QXJ600<0Ng]k000000000000
9000000V0?ooobP000001@3gmoL30?Cdm080moOg0P3dm?@309FEU@80PH610P1hN7P309nOW`D0NWYj
0P1DE5@505EEE@80BDU90P1EEED304m?C`80GemO0`1TI6@205YJFP80HV9R0`1aLG4208J6QP80SHf=
0`26QXH207EeM@<0UIFE0P21PH4207alO0<0Zj^[0P2/[:`V000001h0oooo000L0?ooobD000000P2Q
XJ400`2=SHd0Ng]k07]kN`0207=cL`0805ADE01VIVH0FUYJ05YJFP1<C4`0<S8b03dm?@0b<S860;no
_`070;Zj^P32`/80`/;20;fm_@2e]KD0_Kfm0;Fe]@020:n_[`050;Fe]@2_[jl0[:b/0:n_[`2/[:`0
0P2_[jl30:b/[0070;6a/@2_[jl0[jn_0:ZZZP2WYjL0Xj>S0:ZZZP030:>SX`040:6QX@2IVIT0S8b<
09VIV@80U9BD00<0PH6107YjNP1kNg/00`1cLg<0101NGUh0K6a/06a/K01JFUX206IVIP0507MgM`2B
TY80TY:B09:BTP2IVIT00`26QXH00`1kNg/000000000000T000002H0oooo:000000:0?Ogm`80oooo
0`3YjNT209nOW`80QXJ60`2d];@209FEU@<0PH610P1JFUX205ADE0<0ADE50P0f=SH204U9B@<0E5AD
0P1JFUX304m?C`80BDU90P1[Jf/307YjNP@0O7al0`21PH4206m_K`<0QXJ60P1lO7`207YjNP<0^;Rh
0P2BTY8V000001h0oooo000L0?ooobD000000P2QXJ400`2=SHd0Ng]k07]kN`0207=cL`0805ADE01V
IVH0FUYJ05YJFP1<C4`0<S8b03dm?@0b<S860;no_`070;Zj^P32`/80`/;20;fm_@2e]KD0_Kfm0;Fe
]@020:n_[`050;Fe]@2_[jl0[:b/0:n_[`2/[:`00P2_[jl30:b/[0070;6a/@2_[jl0[jn_0:ZZZP2W
YjL0Xj>S0:ZZZP030:>SX`040:6QX@2IVIT0S8b<09VIV@80U9BD00<0PH6107YjNP1kNg/00`1cLg<0
101NGUh0K6a/06a/K01JFUX206IVIP0507MgM`2BTY80TY:B09:BTP2IVIT00`26QXH00`1kNg/00000
0000000T000002H0oooo:000000:0?Ogm`80oooo0`3YjNT209nOW`80QXJ60`2d];@209FEU@<0PH61
0P1JFUX205ADE0<0ADE50P0f=SH204U9B@<0E5AD0P1JFUX304m?C`80BDU90P1[Jf/307YjNP@0O7al
0`21PH4206m_K`<0QXJ60P1lO7`207YjNP<0^;Rh0P2BTY8V000001h0oooo000L0?ooobL0000000L0
SHf=0861P@21PH40MgMg07=cL`1DE5@0C4a<0080FUYJ00D0GUiN05ADE00m?Cd0>CTi0<71`@020;bl
_0040<S8b031`L40^[Zj0<;2`P<0_kno00<0`/;20;fm_@30`<000`2m_Kd00`2e]KD0_Kfm0;fm_@05
0;Fe]@080;fm_@2_[jl0]KFe0;Fe]@2a/K40[jn_0;Fe]@2ZZZX20:b/[0050:ZZZP2SXj<0XJ6Q092@
T02DU9@00P2GUiL0102QXJ40VIVI08b<S02>SXh308b<S0030861P@1VIVH0K6a/0080K6a/00D0LG5a
09:BTP26QXH0QHF507EeM@02075aLBP000009P3oool[00000080oooo0`3dm?@70?Ogm`80K6a/0P26
QXH305mOG`80];Bd0`28R8P20861P@80BDU91@0b<S8204E5A@<0?Cdm0P1EEED305IFEP80<S8b0P1_
Kfl3075aL@80O7al0P1RHV830861P@80QXJ60`2=SHd209:BTP80NWYj0`2m_KdX000001h0oooo000L
0?ooobL0000000L0SHf=0861P@21PH40MgMg07=cL`1DE5@0C4a<0080FUYJ00D0GUiN05ADE00m?Cd0
>CTi0<71`@020;bl_0040<S8b031`L40^[Zj0<;2`P<0_kno00<0`/;20;fm_@30`<000`2m_Kd00`2e
]KD0_Kfm0;fm_@050;Fe]@080;fm_@2_[jl0]KFe0;Fe]@2a/K40[jn_0;Fe]@2ZZZX20:b/[0050:ZZ
ZP2SXj<0XJ6Q092@T02DU9@00P2GUiL0102QXJ40VIVI08b<S02>SXh308b<S0030861P@1VIVH0K6a/
0080K6a/00D0LG5a09:BTP26QXH0QHF507EeM@02075aLBP000009P3oool]000000X0moOg0P2BTY82
0861P@<0BDU90P2MWId30<K6aP80SHf=0P1iNGT305iNGP@0E5AD0`1EEED205mOG`<0BDU90P1WIfL2
07YjNP<0Kfm_0P1[Jf/206m_K`<0HV9R0P1lO7`306m_K`80NWYj0P21PH4[000001h0oooo000L0?oo
ob/0000000<0Ng]k075aL@1DE5@00P1DE5@01@14A4@0C4a<055AD@0b<S80/k>c0080_kno00@0`L71
0<S8b02o_kl0_kno0P32`/820;fm_@040<;2`P2m_Kd0_Kfm0;fm_@80`/;21P2m_Kd00`32`/80^[Zj
0;Zj^P020;Zj^P040;fm_@2_[jl0_Kfm0:n_[`80]KFe00D0/K6a0:n_[`2/[:`0YjNW09VIV@030:6Q
X@030;fm_@2o_kl0U9BD0080VIVI0P2QXJ401`2DU9@0PH6107YjNP1jNWX0IVIV08F5Q@1eMGD0;000
000V0?ooobd000001@3oool20?Ogm`D0oooo0P21PH4307EeM@80QXJ60`2JVYX20;Rh^080SHf=0`26
QXH206a/K080HV9R0`1_Kfl205EEE@<0EUIF0P1aLG4207YjNP<0HV9R0P1[Jf/2069RHP<0EUIF0P1[
Jf/308J6QP80IfMW0P2h^;P[000001h0oooo000L0?ooob/0000000<0Ng]k075aL@1DE5@00P1DE5@0
1@14A4@0C4a<055AD@0b<S80/k>c0080_kno00@0`L710<S8b02o_kl0_kno0P32`/820;fm_@040<;2
`P2m_Kd0_Kfm0;fm_@80`/;21P2m_Kd00`32`/80^[Zj0;Zj^P020;Zj^P040;fm_@2_[jl0_Kfm0:n_
[`80]KFe00D0/K6a0:n_[`2/[:`0YjNW09VIV@030:6QX@030;fm_@2o_kl0U9BD0080VIVI0P2QXJ40
1`2DU9@0PH6107YjNP1jNWX0IVIV08F5Q@1eMGD0;000000V0?oooc0000000P3gmoL20?ooo`D0moOg
0P2EUID30861P@80EEEE0`1NGUh207YjNP80YZJV0`2YZJT208f=S@80QXJ60`1aLG4205iNGP<0TY:B
0P1lO7`2075aL@<0EEEE0P1[Jf/205YJFP<0EEEE0P1[Jf/30861P@80IfMW;@00000N0?ooo`00703o
ool^00000080A4A400<0<S8b02LW9`0i>CT00P2c/k<20;Zj^P80_kno00H0`L710;no_`38b<P0b<S8
0<;2`P38b<P60<;2`P030;fm_@32`/80`/;20080_Kfm00@0`/;20;fm_@2o_kl0_Kfm0`2j^[X00`2e
]KD0^[Zj0;Zj^P030;Zj^P80]KFe00<0[jn_0:b/[02ZZZX00`2ZZZX01`2_[jl0_kno0:n_[`2_[jl0
Xj>S0:6QX@2SXj<00`2UYJD_000002H0oooo<P0000070?Ogm`80oooo0`1lO7`208J6QP<0EUIF0P1[
Jf/206MWI`<0];Bd0P37alL50:^[Z`80WinO0`39bLT208f=S@80LG5a0`1FEUH204U9B@80EEEE0`1l
O7`208>3P`<0PH61;`00000N0?ooo`00703oool^00000080A4A400<0<S8b02LW9`0i>CT00P2c/k<2
0;Zj^P80_kno00H0`L710;no_`38b<P0b<S80<;2`P38b<P60<;2`P030;fm_@32`/80`/;20080_Kfm
00@0`/;20;fm_@2o_kl0_Kfm0`2j^[X00`2e]KD0^[Zj0;Zj^P030;Zj^P80]KFe00<0[jn_0:b/[02Z
ZZX00`2ZZZX01`2_[jl0_kno0:n_[`2_[jl0Xj>S0:6QX@2SXj<00`2UYJD_000002H0oooo=0000003
0?Ogm`80m?Cd0P3gmoL309:BTP80UIFE0`1_Kfl204m?C`80Kfm_0`23Ph<209:BTP80_Kfm0`3EeMD5
0;fm_@80WIfM0P2BTY8505=CD`80YZJV0`1nOWh208>3Pc8000007P3oool001`0oooo;P00000204A4
A003038b<P0W9bL0>CTi0080/k>c0P2j^[X20;no_`060<71`@2o_kl0b<S80<S8b032`/80b<S81P32
`/800`2m_Kd0`/;20<;2`P020;fm_@040<;2`P2m_Kd0_kno0;fm_@<0^[Zj00<0]KFe0;Zj^P2j^[X0
0`2j^[X20;Fe]@030:n_[`2/[:`0ZZZZ00<0ZZZZ00L0[jn_0;no_`2_[jl0[jn_0:>SX`2QXJ40Xj>S
00<0YJFU;`00000V0?oooc@000000`3gmoL20?Cdm080moOg0`2BTY8209FEU@<0Kfm_0P1?Cdl206m_
K`<0Ph>30P2BTY820;fm_@<0eMGE1@2m_Kd209fMW@80TY:B1@1CDe<20:JVYP<0OWin0P23Ph<b0000
01h0oooo000L0?oooc<0000000<0][Jf0;>c/`2j^[X00P2j^[X00`31`L40_kno0<;2`P040<;2`P04
0<S8b032`/80b<S80<S8b0@0`/;200@0_kno0<;2`P32`/80`/;21@2m_Kd20<;2`P090;no_`2m_Kd0
_Kfm0;fm_@2j^[X0_Kfm0;Fe]@2_[jl0]KFe0080_Kfm0P2e]KD01@2m_Kd0]KFe0;fm_@2m_Kd0^[Zj
03@000009P3oooli00000080oooo0`3gmoL207alO0<0PH610P1lO7`206MWI`<0NWYj0P1hN7P20:JV
YP<0];Bd1@36a/H20;fm_@80d];B0`3Vi^H20=SHf080ZJVY=`00000N0?ooo`00703ooolc00000003
0;Jf]P2c/k<0^[Zj0080^[Zj00<0`L710;no_`32`/801032`/801038b<P0`/;20<S8b038b<P40<;2
`P040;no_`32`/80`/;20<;2`PD0_Kfm0P32`/802@2o_kl0_Kfm0;fm_@2m_Kd0^[Zj0;fm_@2e]KD0
[jn_0;Fe]@020;fm_@80]KFe00D0_Kfm0;Fe]@2m_Kd0_Kfm0;Zj^P0d000002H0oooo>`0000030?Cd
m080moOg0`21PH4209nOW`80Ph>30`1WIfL207YjNP80X:2P0`2MWId20:2PX0<0d];B0P3GemL20=SH
f0<0clo?0P36a/Hi000001h0oooo000L0?ooocX000001@38b<P20<;2`P<0b<S81032`/820;fm_@03
0;no_`32`/80b<S800<0b<S80`32`/801@2o_kl0_Kfm0;fm_@2m_Kd0^[Zj00<0`/;20P2m_Kdk0000
02H0oooo@00000030>3Ph080RHV90P2OWil308V9R@80QXJ60P1jNWX30:2PX080VYZJ0`30`<020=;B
dP80emOG?P00000N0?ooo`00703ooolj000000D0b<S80P32`/830<S8b0@0`/;20P2m_Kd00`2o_kl0
`/;20<S8b0030<S8b0<0`/;200D0_kno0;fm_@2m_Kd0_Kfm0;Zj^P030<;2`P80_Kfm>`00000V0?oo
od`000000P2JVYY:000001h0oooo000L0?oood/0000000<0`/;2000000000000BP00000V0?oooiP0
00007P3oool001`0ooooB`0000000`32`/8000000000001:000002H0ooooV000000N0?ooo`00703o
oom;000000030<;2`P000000000004X000009P3ooonH000001h0oooo000L0?oooiP000009P3ooonH
000001h0oooo000L0?oooiP000009P3ooonH000001h0oooo000L0?oooiP000009P3ooonH000001h0
oooo000L0?oooiP000009P3ooonH000001h0oooo000L0?oooiP000009P3ooonH000001h0oooo000L
0?oooiP000009P3ooonH000001h0oooo000L0?oooiP000009P3ooonH000001h0oooo000L0?oooiP0
00009P3ooonH000001h0oooo000L0?oooiP000009P3ooonH000001h0oooo000L0?oooiP000009P3o
oonH000001h0oooo000L0?oooiP000009P3ooonH000001h0oooo000L0?oooiP000009P3ooonH0000
01h0oooo000L0?oooiP000009P3ooonH000001h0oooo000L0?oooiP000009P3ooonH000001h0oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo001S0?ooo`03@000003oool0oooo00H0oooo00=000000?oo
o`3oool0/P3oool00d000000oooo0?ooo`060?ooo`03@000003oool0oooo06<0oooo001R0?ooo`03
@000003oool0oooo00P0oooo00=000000?ooo`3oool0/03oool00d000000oooo0?ooo`080?ooo`03
@000003oool0oooo0680oooo001Q0?ooo`03@000003oool0oooo0080oooo0d0000050?ooo`03@000
003oool0oooo0:h0oooo00=000000?ooo`3oool00`3oool3@00000@0oooo00=000000?ooo`3oool0
H@3oool00640oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`050?ooo`03@000003o
ool0oooo0:h0oooo00=000000?ooo`3oool00P3oool014000000oooo0?oood0000040?ooo`03@000
003oool0oooo0640oooo001Q0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool01@3o
ool00d000000oooo0?ooo`2^0?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3ooom00000
103oool00d000000oooo0?ooo`1Q0?ooo`00H@3oool00d000000oooo0?ooo`020?ooo`=000001@3o
ool00d000000oooo0?ooo`2^0?ooo`03@000003oool0oooo00<0oooo0d0000040?ooo`03@000003o
ool0oooo0640oooo001R0?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool0/03oool0
0d000000oooo0?ooo`040?ooo`05@000003oool0oooo0?oood000000I03oool006<0oooo00=00000
0?ooo`3oool01P3oool00d000000oooo0?ooo`2b0?ooo`03@000003oool0oooo0080oooo0T000002
0?ooo`03@000003oool0oooo06<0oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
000L0?oooiP000009P3ooonH000001h0oooo000L0?oooiP000009P3ooonH000001h0oooo000L0?oo
oiP000009P3ooonH000001h0oooo000L0?oooiP000009P3ooonH000001h0oooo000L0?oooiP00000
9P3ooonH000001h0oooo000L0?oooiP000009P3ooonH000001h0oooo000L0?oooiP000009P3ooonH
000001h0oooo000L0?oooiP000009P3ooonH000001h0oooo000L0?oooiP000009P3ooonH000001h0
oooo000L0?oooiP000009P3ooonH000001h0oooo000L0?oooiP000009P3ooonH000001h0oooo000L
0?oooiP000009P3ooonH000001h0oooo000L0?oooiP000009P3ooonH000001h0oooo000L0?oooiP0
00009P3ooonH000001h0oooo000L0?oooiP000009P3ooonH000001h0oooo000L0?oooiP000009P3o
oonH000001h0oooo000L0?oood/0000000<0`/;2000000000000BP00000V0?oood<0000000<0moOg
0?Cdm03gmoL01P3gmoL00`3dm?@0moOg0?Ogm`050?Ogmd@000007P3oool001`0oooo?`0000080<S8
b0030<;2`P38b<P0b<S800<0`/;21@38b<P20;fm_@@0`/;2@000000V0?ooocd00000103gmoL30?Cd
m0P0moOg00<0m?Cd0?Ogm`3gmoL01`3gmoL0103oool0jNWY0:j^[P2VYZHn000001h0oooo000L0?oo
ocX000001@38b<P20<;2`P<0b<S81032`/820;fm_@030;no_`32`/80b<S800<0b<S80`32`/801@2o
_kl0_Kfm0;fm_@2m_Kd0^[Zj00<0`/;20P2m_Kdk000002H0oooo>@0000000`3gmoL0m?Cd0?Ogm`03
0?Ogm`030>o_k`3dm?@0moOg0080moOg0P3dm?@40?Ogm`80m?Cd1@3gmoL00`3oool0TY:B07UiN@02
0>KViP<0oooo00D0LG5a06a/K01@D500D51@05EEE@0j000001h0oooo000L0?ooocL0000000<0_Kfm
0<;2`P38b<P01@32`/801@38b<P0`/;20<;2`P32`/80b<S80080`/;200@0b<S80<;2`P32`/80`/;2
0P2m_Kd20<;2`P80_kno00@0b<S80<;2`P2m_Kd0^[Zj0P2m_Kd40;Zj^P040;fm_@2j^[X0^[Zj0;Zj
^P80]KFe>000000V0?ooocD000000P3_knl20?Cdm0040?Ogm`3dm?@0kno_0>o_k`<0moOg00@0m?Cd
0?Ogm`3gmoL0moOg0P3dm?@00`3gmoL0m?Cd0?Ogm`040?Ogm`070?ooo`2PX:00X:2P08R8R03dm?@0
b<S80:2PX00208V9R@0504E5A@0m?Cd0E5AD04U9B@1FEUH00P1?Cdl0101WIfL0EEEE06MWI`1?Cdlg
000001h0oooo000L0?oooc<0000000<0][Jf0;>c/`2j^[X00P2j^[X00`31`L40_kno0<;2`P040<;2
`P040<S8b032`/80b<S80<S8b0@0`/;200@0_kno0<;2`P32`/80`/;21@2m_Kd20<;2`P090;no_`2m
_Kd0_Kfm0;fm_@2j^[X0_Kfm0;Fe]@2_[jl0]KFe0080_Kfm0P2e]KD01@2m_Kd0]KFe0;fm_@2m_Kd0
^[Zj03@000009P3ooolc00000080m?Cd0P3gmoL00`3_knl0m?Cd0?Cdm00:0?Ogm`040?Cdm03gmoL0
moOg0?Ogm`80m?Cd00@0[Zj^07inOP1DE5@0K6a/0P1jNWX0102MWId0PH6108J6QP2JVYX206][J`03
05iNGP1;Bd/0ADE50080BDU90P1JFUX0101RHV80EEEE05EEE@1NGUh207YjNP0305IFEP0000000000
038000007P3oool001`0oooo<`0000000`2f][H0/k>c0;Zj^P020;Zj^P030<71`@2o_kl0`/;200@0
`/;200@0b<S80<;2`P38b<P0b<S81032`/80102o_kl0`/;20<;2`P32`/850;fm_@80`/;200T0_kno
0;fm_@2m_Kd0_Kfm0;Zj^P2m_Kd0]KFe0:n_[`2e]KD00P2m_Kd20;Fe]@050;fm_@2e]KD0_Kfm0;fm
_@2j^[X0=000000V0?oooc<000000P3dm?@20?Ogm`030>o_k`3dm?@0m?Cd00X0moOg00@0m?Cd0?Og
m`3gmoL0moOg0P3dm?@0102^[Zh0OWin05ADE01/K6`207YjNP0409fMW@21PH40QXJ609ZJVP80Jf][
00<0GUiN04];B`15ADD00P19BDT205YJFP04069RHP1EEED0EEEE05iNGP80NWYj00<0EUIF00000000
0000<P00000N0?ooo`00703ooola00000004038b<P0O7al0/k>c0;>c/`80_kno00<0_;bl0;no_`2o
_kl01P32`/830<S8b0P0`/;20P2m_Kd01P32`/80_Kfm0;fm_@2o_kl0_Kfm0<30`0D0^[Zj1@2e]KD0
102_[jl0ZZZZ0:n_[`2e]KD20:n_[`030;no_`2ZZZX0/K6a038000009P3ooola000000<0moOg103d
m?@00`3_knl0m?Cd0?Ogm`020?Cdm0040?Ogm`3dm?@0moOg0?Cdm080kno_00D0lO7a0?Cdm03;bl/0
LG5a07UiN@02075aL@0405iNGP2=SHd0TY:B07alO0<0LG5a00<0E5AD06m_K`1NGUh00P19BDT2038b
<P0304U9B@1OGel0NWYj0080QXJ600@0LG5a05EEE@1RHV80Jf][0P1NGUh00`1FEUH0EEEE05EEE@0b
000001h0oooo000L0?ooobh000000P14A4@00`0b<S809bLW03Ti>@020;>c/`80^[Zj0P2o_kl01P31
`L40_kno0<S8b038b<P0`/;20<S8b0H0`/;200<0_Kfm0<;2`P32`/800P2m_Kd01032`/80_Kfm0;no
_`2m_Kd30;Zj^P030;Fe]@2j^[X0^[Zj00<0^[Zj0P2e]KD00`2_[jl0[:b/0:ZZZP030:ZZZP070:n_
[`2o_kl0[jn_0:n_[`2SXj<0XJ6Q0:>SX`030:FUYBl000009P3oool^00000080moOg00D0kno_0?Og
m`3gmoL0m?Cd0>o_k`020>c/k080m?Cd00P0kno_0>WYj@3dm?@0m?Cd0>WYj@3Ph>00emOG0=;BdP80
UIFE0P28R8P00`1aLG40GUiN06IVIP02075aL@04069RHP1/K6`0GUiN05EEE@80BDU900@0HV9R04];
B`1CDe<0BDU90P15ADD203dm?@0304U9B@1EEED0IfMW0080Jf][00@0HV9R05mOG`1WIfL0Jf][0P1R
HV80101EEED0BDU905EEE@19BDT204m?Cbl000007P3oool001`0oooo;0000000101eMGD0FUYJ05AD
E01DE5@203Ti>@0304Q8B01;Bd/0][Jf0080_Kfm00@0_kno0<S8b02o_kl0_kno0P38b<P70<;2`P04
0;no_`32`/80_kno0;Zj^P80`<3000<0`/;20;fm_@2m_Kd00`2m_Kd0102e]KD0_Kfm0:n_[`2j^[X2
0;fm_@030;Zj^P2e]KD0]KFe0080[:b/0P2IVIT0102QXJ40/K6a0;no_`2a/K4209BDU00409VIV@2Q
XJ40VIVI0:6QX@80VIVI00<0QXJ608F5Q@000000;000000V0?ooob`0000000<0moOg0?Cdm03gmoL0
0P3gmoL0103_knl0lO7a0?Cdm03dm?@20>o_k`040>WYj@3dm?@0c/k>0<K6aP80_kno00@0[Zj^09FE
U@2=SHd0NGUi0`1TI6@205iNGP0805ADE019BDT0EEEE05EEE@1DE5@0BDU906][J`1NGUh205EEE@80
<S8b00T0BDU9069RHP19BDT0BDU903dm?@19BDT0<S8b04U9B@1FEUH00P1EEED0101WIfL0HV9R06][
J`1JFUX205mOG`0405EEE@1DE5@0E5AD04m?C`80FUYJ00<0Jf][06m_K`000000;000000N0?ooo`00
703oool[0000000307]kN`1aLG40E5AD0080E5AD00D0A4A404a<C01ADE40<S8b0;>c/`020;no_`04
0<71`@38b<P0_kno0;no_`80`/;20P2m_Kd01032`/80_Kfm0;fm_@2m_Kd20<;2`PH0_Kfm00<0`/;2
0;Zj^P2j^[X00P2j^[X0102m_Kd0[jn_0;fm_@2_[jl20;Fe]@050;6a/@2_[jl0[:b/0:NWY`2IVIT0
0`2QXJ400`2m_Kd0_kno09BDU00209VIV@80XJ6Q00L0U9BD0861P@1jNWX0NWYj06IVIP25QHD0MGEe
02`000009P3oool[000000030>c/k03gmoL0moOg00<0m?Cd0P3gmoL0203dm?@0jNWY0>KViP3Vi^H0
a/K60<k>cP33`l<0YZJV0P2EUID01026QXH0NGUi06ATI01NGUh206ATI005051@D01;Bd/0ADE5038b
<P0m?Cd00P19BDT0101NGUh0K6a/05YJFP1EEED204U9B@@0EEEE0P19BDT01@1TI6@0EEEE05EEE@19
BDT0EEEE0080FUYJ00@0HV9R05EEE@1RHV80HV9R0P1NGUh0101DE5@0Cdm?05EEE@1?Cdl205IFEP80
Jf][00<0EEEE000000000000:P00000N0?ooo`00703ooolX00000080Ng]k00@0Lg=c06IVIP1VIVH0
DE5A0P1DE5@205YJFP0304A4A00O7al0_kno0080^[Zj00@0`L710;no_`32`/80_kno0P32`/820;fm
_@030<;2`P2m_Kd0_Kfm00T0_Kfm00<0^[Zj0;fm_@2j^[X00P2j^[X30:n_[`030;Fe]@2_[jl0[jn_
0080/K6a00<0YjNW0:6QX@2DU9@00P2DU9@00`2_[jl0/k>c09BDU00308j>SP04096AT@2>SXh0PH61
07UiN@80GUiN00<0Lg=c08F5Q@1eMGD00P1eMGDZ000002H0oooo:00000040?Ogm`070?Cdm03gmoL0
m?Cd0?Cdm03/k>`0jNWY0=[JfP020=OGe`80c/k>00@0_kno09nOW`2EUID0UIFE0P1iNGT206ATI003
065QH@1NGUh0?Cdm0080?Cdm00@0Bd];05ADE01FEUH0GUiN0P15ADD00`1DE5@0BDU905iNGP04065Q
H@80EEEE00H0BDU903dm?@0m?Cd0<S8b04U9B@1;Bd/204U9B@80EUIF0`1JFUX01@1EEED0FUYJ05YJ
FP1JFUX0BDU90080EEEE0P1?Cdl01@1[Jf/0FUYJ05mOG`1JFUX0EEEE02X000007P3oool001`0oooo
9`0000001`2=SHd0PH610861P@1gMgL0Lg=c05ADE01<C4`00P1JFUX01@1NGUh0E5AD03dm?@0i>CT0
`L710080_;bl00@0b<S80<71`@2j^[X0`/;20`2o_kl00`32`/80_Kfm0<30`0030;fm_@030;Fe]@2m
_Kd0_Kfm00D0]KFe00P0_Kfm0:n_[`2e]KD0]KFe0;6a/@2_[jl0]KFe0:ZZZP80[:b/00D0ZZZZ0:>S
X`2QXJ40T92@09BDU00209NGU`040:6QX@2IVIT0S8b<08j>SP<0S8b<00<0PH6106IVIP1/K6`00P1/
K6`01@1aLG40TY:B08J6QP25QHD0MGEe0080LG5a:000000V0?ooobL0000000D0lO7a0?Ogm`3gmoL0
m?Cd0?7al@040>WYj@050=OGe`3MgMd0bl_;0<?3``2m_Kd00P2^[Zh0102OWil0PH6107]kN`1/K6`2
06ATI00405ADE01VIVH0?Cdm05ADE080ADE50P1EEED00`1DE5@0BDU905EEE@0405EEE@0804U9B@0W
9bL0<S8b038b<P0i>CT0EEEE065QH@1EEED206a/K00505iNGP1VIVH0GUiN05EEE@1NGUh00P1JFUX2
05EEE@0705YJFP1FEUH0IVIV06IVIP1EEED0EUIF04m?C`0405IFEP04069RHP1?Cdl0NWYj05EEE@80
E5AD:000000N0?ooo`00703ooolW0000000708f=S@21PH40PH6107MgM`1cLg<0E5AD04a<C00205YJ
FP0505iNGP1DE5@0?Cdm03Ti>@31`L400P2l_;`01038b<P0`L710;Zj^P32`/830;no_`030<;2`P2m
_Kd0`<3000<0_Kfm00<0]KFe0;fm_@2m_Kd01@2e]KD0202m_Kd0[jn_0;Fe]@2e]KD0/K6a0:n_[`2e
]KD0ZZZZ0P2/[:`01@2ZZZX0Xj>S0:6QX@2@T900U9BD0080UiNG00@0XJ6Q09VIV@2<S8`0SXj>0`2<
S8`00`21PH40IVIV06a/K00206a/K005075aL@2BTY80QXJ608F5Q@1eMGD00P1aLG4X000002H0oooo
9`0000001@3alO40moOg0?Ogm`3dm?@0lO7a00@0jNWY00D0emOG0=gMg@3;bl/0`l?30;fm_@020:j^
[P0409nOW`21PH40Ng]k06a/K080I6AT00@0E5AD06IVIP0m?Cd0E5AD0P15ADD205EEE@0305ADE019
BDT0EEEE00@0EEEE00P0BDU902LW9`0b<S80<S8b03Ti>@1EEED0HF5Q05EEE@80K6a/00D0GUiN06IV
IP1NGUh0EEEE05iNGP0205YJFP80EEEE00L0FUYJ05IFEP1VIVH0IVIV05EEE@1FEUH0Cdm?00@0EUIF
00@0HV9R04m?C`1jNWX0EEEE0P1DE5@X000001h0oooo000L0?ooobH0000000P0VIVI08b<S01kNg/0
Ng]k07=cL`1aLG40GUiN05YJFP80LG5a00D0FUYJ03Ti>@0i>CT0<S8b0<71`@020;bl_0030;no_`2c
/k<0_kno00<0`/;20P2e]KD00`2m_Kd0^[Zj0;Fe]@030;Fe]@030:n_[`2e]KD0]KFe00<0[jn_00<0
]KFe0:b/[02e]KD01@2/[:`30:ZZZP80XJ6Q00<0VIVI09:BTP2>SXh00P2SXj<0102ATI40PH6107Yj
NP26QXH207]kN`030861P@1TI6@0Ng]k00<0LG5a00D0Lg=c08J6QP2BTY80S8b<07]kN`0208J6QP03
0861P@000000000002D000009P3ooolV000000040?7al@3_knl0lO7a0?7al@80k>c/00T0jNWY0=OG
e`3EeMD0eMGE0<o?c`3EeMD0[:b/0:6QX@2EUID00P26QXH0101iNGT0IVIV06a/K01VIVH305EEE@03
04];B`19BDT0Bd];0080ADE500D0DE5A04U9B@1ADE40BDU904];B`02055AD@0403dm?@0b<S80:RXZ
05ADE080GUiN00<0:RXZ065QH@2=SHd00`2>SXh00`1jNWX0MGEe065QH@0205iNGP80FUYJ00@0E5AD
05YJFP1EEED0Jf][0P15ADD2069RHP0905EEE@1?Cdl0FUYJ05YJFP1FEUH0GemO069RHP1FEUH0GemO
0080EUIF00<0K6a/0000000000009@00000N0?ooo`00703ooolU00000080XJ6Q00<0SHf=07]kN`1k
Ng/00P1cLg<0201DE5@0IVIV05YJFP1JFUX0C4a<038b<P0m?Cd0<S8b1P2o_kl01`2j^[X0`/;20<;2
`P2m_Kd0]KFe0;fm_@2e]KD00P2_[jl01@2e]KD0[jn_0:b/[02_[jl0[:b/0080[jn_0`2/[:`01`2a
/K40[jn_0:n_[`2ZZZX0YjNW0:>SX`2ZZZX00`2SXj<0102QXJ40VIVI08b<S02IVIT209BDU0030861
P@1jNWX0Ng]k00<0Lg=c00@0GUiN06a/K01/K6`0FUYJ0P1VIVH01@1gMgL0TY:B09:BTP2BTY80VIVI
00<0QXJ600<0Ng]k0000000000009000000V0?ooob@000000P3alO420?Cdm0<0jNWY00<0gMgM0<o?
c`3?cll00P3;bl/01@3>c/h0[Zj^09FEU@2EUID0PH610080K6a/00@0I6AT06a/K01@D500I6AT0P1E
EED00`0m?Cd0Bd];055AD@0304];B`05055AD@1;Bd/0Bd];055AD@15ADD00P0b<S80100f=SH0BDU9
06IVIP1ADE420;fm_@80d=3@00L0`<300;Fe]@2IVIT0VIVI09fMW@21PH40HF5Q0080HV9R0P1NGUh0
0`1DE5@0EEEE069RHP04069RHP80K6a/101[Jf/2069RHP0707YjNP1lO7`0GUiN05iNGP1EEED0Jf][
069RHP0U000001h0oooo000L0?ooob8000000P3_knl0102/[:`0XJ6Q096AT@2<S8`206IVIP0406a/
K01NGUh0GUiN06IVIP80GUiN00D0B4Q803dm?@18B4P0>CTi0<71`@020;Jf]P040;no_`2j^[X0_kno
0;Zj^P80]KFe00@0_Kfm0;Fe]@2e]KD0]KFe0P2_[jl30:b/[0040:FUY@2WYjL0ZZZZ0:ZZZP80YjNW
00H0[:b/0:ZZZP2ZZZX0ZZZZ0:6QX@2UYJD50:6QX@80U9BD00H0S8b<09VIV@2<S8`0S8b<07]kN`1c
Lg<2075aL@80I6AT00@0Lg=c06a/K01NGUh0GUiN0P1VIVH01@1eMGD0QHF509:BTP2<S8`0TY:B0080
S8b<00@0SHf=07]kN`1kNg/0MgMg9000000V0?ooob8000000P3/k>`0103dm?@0lO7a0?Cdm03dm?@2
0=GEe@<0bl_;00P0];Bd0:j^[P2^[Zh0WinO09FEU@26QXH0NGUi06ATI080K6a/00@0E5AD051@D01N
GUh0CTi>0`1;Bd/00`0m?Cd0ADE5051@D002055AD@0504];B`1ADE40:RXZ02XZ:P0m?Cd00`15ADD0
0`1;Bd/0]KFe0=3@d0020<30`0040;Fe]@2/[:`0YZJV0:>SX`80WinO00D0VIVI08f=S@1lO7`0LG5a
07UiN@0207YjNP0406a/K01jNWX0LG5a075aL@80O7al00@0NWYj08J6QP1lO7`0QXJ60P1aLG400`21
PH40NGUi07YjNP0207YjNP<0LG5a00<0HV9R06][J`1FEUH09000000N0?ooo`00703ooolQ00000007
0>o_k`3EeMD0eMGE0:j^[P2QXJ40S8b<0861P@0207=cL`0407]kN`1JFUX0IVIV06IVIP80GUiN0P0b
<S800`0i>CT0?Cdm0;no_`020;>c/`040;bl_02c/k<0^[Zj0;Zj^P@0]KFe00H0[:b/0:n_[`2ZZZX0
ZZZZ0:NWY`2ZZZX20:NWY`030:FUY@2IVIT0VIVI0080VIVI0P2QXJ420:NWY`80XJ6Q102IVIT209BD
U00308j>SP2=SHd0Ng]k0080Lg=c00<0LG5a06IVIP1aLG400`1cLg<306IVIP0806i^KP1eMGD0MGEe
07MgM`25QHD0TY:B0:RXZ02QXJ420:n_[`04096AT@1aLG40LG5a07]kN`80TI6A8P00000V0?ooob40
000000D0kno_0?Cdm03dm?@0k>c/0>KViP020<o?c`80alO700<0_Kfm0:b/[02OWil00`2EUID01@21
PH40NWYj07YjNP1TI6@0EEEE0080GUiN00@0E5AD055AD@0m?Cd0Bd];0P0m?Cd01015ADD0B4Q804];
B`1EEED204];B`0501LG5`0Z:RX07alO03dm?@0Z:RX00P1EEED20<O7a`060<[:bP2IVIT0YZJV0:JV
YP2e]KD0YZJV0P2SXj<209FEU@0508f=S@2@T900R8R807YjNP1iNGT00`1aLG400`21PH40SHf=08R8
R00508f=S@<0UIFE00<0SHf=09FEU@2=SHd00P2=SHd208J6QP040861P@1aLG40NWYj075aL@80MGEe
8P00000N0?ooo`00703ooolP00000080kno_0P31`L40102[Zj/0UIFE08f=S@1kNg/206IVIP0406a/
K01NGUh0LG5a05ADE080C4a<0P0Z:RX203Ti>@060;no_`2c/k<0/k>c0;Zj^P2l_;`0^[Zj0`2e]KD0
0`2/[:`0ZZZZ0:ZZZP030:ZZZP040:FUY@2SXj<0XJ6Q0:FUY@<0XJ6Q102IVIT30:6QX@<0VIVI0`2>
SXh0102<S8`0PH6108b<S01gMgL206IVIP0305iNGP1cLg<0IVIV00<0Lg=c0P18B4P00`1DE5@0LW9b
08F5Q@0308F5Q@0308b<S02GUiL0XJ6Q0080VIVI00<0Zj^[08f=S@1kNg/00`2<S8`00`2IVIT00000
0000000O000002H0oooo800000020>o_k`80gMgM00@0bLW90<K6aP2h^;P0[:b/0P2OWil209FEU@06
096AT@21PH40Ng]k07]kN`1iNGT0K6a/0P1EEED01@1NGUh0E5AD05ADE01ADE40?Cdm0080Bd];0P0m
?Cd204];B`09055AD@18B4P07alO01lO7`0Z:RX07alO01LG5`0f=SH0Ph>30080cLg=00@0f=SH0=3@
d02g]kL0[:b/0P2[Zj/20;>c/`80/K6a0P2[Zj/0102YZJT0WinO09nOW`2YZJT30:>SX`04092@T02E
UID0UIFE09FEU@80SHf=00@0WinO0:>SX`2OWil0ZJVY0P2^[Zh01@2SXj<0WinO0:>SX`2OWil0Xj>S
0080UIFE00@0SHf=07alO028R8P0NWYj0P26QXH00`1[Jf/000000000000O000001h0oooo000L0?oo
ob0000000P3_knl20<71`@040:^[Z`2EUID0SHf=07]kN`80IVIV00@0K6a/05iNGP1aLG40E5AD0P1<
C4`202XZ:P80>CTi00H0_kno0;>c/`2c/k<0^[Zj0;bl_02j^[X30;Fe]@030:b/[02ZZZX0ZZZZ00<0
ZZZZ00@0YJFU0:>SX`2QXJ40YJFU0`2QXJ4409VIV@<0XJ6Q0`2IVIT308j>SP0408b<S021PH40S8b<
07MgM`80IVIV00<0GUiN07=cL`1VIVH00`1cLg<204Q8B00305ADE01bLW80QHF500<0QHF500<0S8b<
09NGU`2QXJ400P2IVIT00`2[Zj/0SHf=07]kN`0308b<S00309VIV@000000000001l000009P3ooolP
00000080kno_0P3MgMd01039bLT0a/K60;Rh^02/[:`209nOW`80UIFE00H0TI6A0861P@1kNg/0Ng]k
07UiN@1/K6`205EEE@0505iNGP1DE5@0E5AD055AD@0m?Cd00P1;Bd/203dm?@80Bd];00T0DE5A04Q8
B00O7al07alO02XZ:P0O7al05aLG03Hf=P23Ph<00P3=cLd0103Hf=P0d=3@0;Ng]`2/[:`20:^[Z`80
/k>c0P2a/K420:^[Z`040:VYZ@2OWil0WinO0:VYZ@<0Xj>S00@0T92@09FEU@2EUID0UIFE0P2=SHd0
102OWil0Xj>S09nOW`2YZJT20:j^[P050:>SX`2OWil0Xj>S09nOW`2SXj<00P2EUID0102=SHd0O7al
08R8R01jNWX208J6QP0306][J`000000000001l000007P3oool001`0oooo7`0000000`3/k>`0m?Cd
0=gMg@020;Rh^0040:^[Z`2=SHd0PH6107=cL`80K6a/0P1NGUh01@1VIVH0E5AD04A4A014A4@0>CTi
0080?Cdm00@0A4A40;>c/`2c/k<0/k>c0P2a/K401@2e]KD0/K6a0:b/[02/[:`0/K6a0080[:b/00@0
Xj>S0:FUY@2UYJD0YJFU0`2IVIT01@2@T900U9BD09BDU02DU9@0T92@0080VIVI0P2@T90309VIV@08
08j>SP2<S8`0S8b<08j>SP2<S8`0Ng]k09:BTP1cLg<205ADE080K6a/00P0IVIV05iNGP1<C4`0C4a<
04Q8B00b<S80KVi^08F5Q@80LW9b00D0QHF507MgM`26QXH0UiNG0:RXZ0020:>SX`040:n_[`2=SHd0
SHf=09NGU`80SHf=00<0VIVI09FEU@0000007`00000V0?oooal0000000<0kno_0=GEe@31`L400P2h
^;P00`2^[Zh0Zj^[0:6QX@0309FEU@80SHf=0P1iNGT207]kN`80IVIV0P1NGUh01`1DE5@0D51@051@
D00i>CT0Bd];03Ti>@19BDT00P1;Bd/0101>CTh0?Cdm038b<P0Z:RX2038b<P0502LW9`0Z:RX0`<30
0<[:bP3@d=000P3Cdm<00`3=cLd0alO70<g=c@030<o?c`040=;BdP39bLT0cLg=0<g=c@80bLW900D0
clo?0<[:bP39bLT0bLW90<[:bP020<O7a`040;no_`2l_;`0/K6a0:^[Z`80ZJVY00@0Zj^[0:j^[P2f
][H0/k>c0P31`L400`2l_;`0/k>c0;Jf]P020;>c/`80WinO00@0Zj^[09FEU@1nOWh0HV9R0P2VYZH0
0`21PH40X:2P0000000O000001h0oooo000L0?oooah0000000@0lO7a0?Cdm03/k>`0bLW90P2^[Zh0
102OWil0PH610861P@1/K6`2075aL@0306IVIP1NGUh0GUiN00<0?Cdm00D0>CTi03dm?@0m?Cd0?Cdm
0;>c/`020;6a/@040;>c/`31`L40]kNg0;Ng]`80]KFe00@0]kNg0;Fe]@2e]KD0/K6a0`2/[:`0102S
Xj<0U9BD08b<S02DU9@208V9R@@0S8b<0`2DU9@308b<S0<0PH6100@0NWYj07]kN`2<S8`0IVIV0P1;
Bd/0101VIVH0Lg=c05ADE018B4P204A4A00304];B`1JFUX0Jf][00<0QHF500D0Ng]k08F5Q@1aLG40
UiNG0:6QX@020:^[Z`0309VIV@2EUID0S8b<00<0TI6A00<0SHf=0:^[Z`2[Zj/07`00000V0?oooal0
000000<0[:b/0:j^[P2[Zj/00P2[Zj/0102OWil0UIFE096AT@2=SHd30861P@80Ng]k00P0I6AT075a
L@1aLG40LG5a05iNGP1EEED0D51@04];B`80ADE51P1;Bd/0100i>CT0<S8b038b<P0f=SH201lO7`04
03Hf=P2/[:`0d];B0<g=c@<0d];B103Hf=P20=;BdP040=SHf03?cll0clo?0<W9b@80clo?00D0`L71
0<K6aP3Bd]80clo?0<g=c@020<o?c`040<g=c@31`L40`L710<71`@@0_kno00@0`L710<S8b031`L40
`L710P38b<P00`31`L40_kno0;Jf]P020;Rh^0040;>c/`2[Zj/0SHf=08f=S@80ZZZZ00<0SHf=09nO
W`0000007`00000N0?ooo`00703ooolN00000080lO7a00P0i^KV0<K6aP2[Zj/0Zj^[09FEU@21PH40
Ng]k07=cL`80IVIV00@0Ng]k05iNGP1NGUh09bLW0P15ADD203dm?@0303Ti>@1DE5@0/k>c0080alO7
0`3:b/X30<S8b0<0`<3000L0^KVi0;Ng]`2g]kL0]kNg0;6a/@2/[:`0Xj>S00<0RHV900<0QXJ608V9
R@29RHT01021PH400`2<S8`0RHV90861P@0208J6QP0507]kN`1cLg<0Lg=c08J6QP1DE5@00P1EEED0
101VIVH0GUiN04a<C00i>CT203dm?@0406i^KP1<C4`0IVIV08J6QP80QHF500D0Ng]k075aL@1kNg/0
TY:B0:>SX`020:n_[`040;6a/@2[Zj/0UIFE09FEU@80PH6100<0MgMg0:^[Z`2[Zj/07`00000V0?oo
oah000000`2QXJ400`2EUID0SHf=08f=S@030861P@0707UiN@1/K6`0K6a/07=cL`1/K6`0I6AT05iN
GP0305EEE@0304];B`1NGUh0>CTi00D0Bd];00P0D51@03dm?@0i>CT0>CTi038b<P1EEED0O7al0<W9
b@<0b/[:00<0clo?0=3@d03Hf=P02@3Hf=P0103Bd]80b/[:0;bl_037alL20<o?c`030=?Cd`2o_kl0
UIFE00D0clo?00<0cLg=0<o?c`3:b/X02P3:b/X00`30`<00alO70<71`@020;bl_0040;Jf]P2o_kl0
UIFE09nOW`80WIfM00<0SHf=0:JVYP21PH407`00000N0?ooo`00703ooolM000000050?7al@3dm?@0
m?Cd0<o?c`2h^;P00P2QXJ40102ATI40PH6107UiN@1NGUh206IVIP0405iNGP1VIVH0C4a<038b<P80
B4Q800D0ADE503dm?@0i>CT0QXJ60<[:bP020<g=c@030=SHf03@d=00d=3@00<0b/[:00<0d=3@0<[:
bP3:b/X00`30`<001@2l_;`0]kNg0;6a/@2/[:`0YjNW0080VIVI00<0QXJ607]kN`21PH400`26QXH0
1029RHT0NWYj0861P@26QXH20861P@0507]kN`1cLg<0I6AT07]kN`1NGUh00P1VIVH0101kNg/0C4a<
04A4A00i>CT204U9B@0407EeM@1ADE40IVIV07MgM`80QXJ600D0MGEe075aL@1kNg/0S8b<09:BTP02
0:n_[`040;6a/@2[Zj/0XJ6Q09FEU@80Ng]k00@0SHf=0:6QX@2QXJ40XJ6Q7P00000V0?oooad00000
00D0VIVI0:6QX@2ATI40S8b<08f=S@030861P@0307]kN`1iNGT0Lg=c0080GUiN00<0I6AT05EEE@1N
GUh00`1NGUh01@1@D500EEEE038b<P18B4P0Bd];0080C4a<00@0B4Q804];B`0m?Cd0QXJ60P39bLT2
0<g=c@060<O7a`3=cLd0d=3@0=3@d03Cdm<0clo?1P3Hf=P00`3Ph>00f=SH0=SHf0020=SHf0040<O7
a`2f][H0ZZZZ0<71`@<0f=SH00@0cLg=09nOW`3:b/X0clo?0P3Bd]80103?cll0d];B0=;BdP3Cdm<3
0<o?c`80dm?C00<0cLg=0=?Cd`3Cdm<01@3:b/X20<71`@040;bl_02f][H0/k>c0;fm_@80][Jf00@0
WIfM0;Rh^02YZJT0TY:B7P00000N0?ooo`00703ooolK00000080lO7a00D0kno_0?Cdm03dm?@0clo?
0:b/[00209FEU@0408f=S@1iNGT0Lg=c07=cL`80IVIV00@0GUiN06IVIP0b<S80?Cdm0P1;Bd/203dm
?@0308f=S@3=cLd0dm?C0080f=SH00@0dm?C0=SHf03@d=00f=SH0P3@d=00103Cdm<0d=3@0<[:bP38
b<P20<[:bP80`<3000<0]kNg0;Fe]@2/[:`00P2ZZZX00`2QXJ40VIVI07]kN`0407]kN`0308J6QP1k
Ng/0PH610080Ng]k00D0LG5a06a/K01EEED0C4a<07]kN`0205iNGP0408b<S014A4@0>CTi02LW9`80
<S8b00@0LG5a07MgM`1JFUX0MgMg0P2BTY801@1aLG40SHf=07]kN`2<S8`0XJ6Q0080[jn_00@0_Kfm
0<71`@2^[Zh0MgMg0`2=SHd00`2IVIT0TI6A0:6QX@020:j^[Q`000009P3ooolK00000080SHf=00D0
S8b<08f=S@2<S8`0PH6107]kN`0207=cL`0406a/K01cLg<0GUiN07=cL`<0IVIV0`1NGUh205ADE005
03dm?@15ADD0?Cdm03Ti>@1>CTh00P1DE5@0102h^;P0clo?0<o?c`39bLT20<g=c@040<O7a`3:b/X0
d=3@0=?Cd`80d];B0P3Hf=P00`3Ph>00f=SH0=SHf0060=SHf080cLg=00@0^KVi09FEU@2@T900/k>c
0P3Bd]820=SHf080ZJVY0`3Hf=P00`3Bd]80dm?C0=SHf0030=?Cd`040=SHf03@d=00dm?C0<o?c`@0
dm?C00<0b/[:0<S8b038b<P00P38b<P01030`<00^;Rh0;Rh^039bLT20:ZZZP040;Jf]P2h^;P0];Bd
0:b/[080TY:B7000000N0?ooo`00703ooolK00000080lO7a00D0kno_0?Cdm03dm?@0clo?0:b/[002
09FEU@0408f=S@1iNGT0Lg=c07=cL`80IVIV00@0GUiN06IVIP0b<S80?Cdm0P1;Bd/203dm?@0308f=
S@3=cLd0dm?C0080f=SH00@0dm?C0=SHf03@d=00f=SH0P3@d=00103Cdm<0d=3@0<[:bP38b<P20<[:
bP80`<3000<0]kNg0;Fe]@2/[:`00P2ZZZX00`2QXJ40VIVI07]kN`0407]kN`0308J6QP1kNg/0PH61
0080Ng]k00D0LG5a06a/K01EEED0C4a<07]kN`0205iNGP0408b<S014A4@0>CTi02LW9`80<S8b00@0
LG5a07MgM`1JFUX0MgMg0P2BTY801@1aLG40SHf=07]kN`2<S8`0XJ6Q0080[jn_00@0_Kfm0<71`@2^
[Zh0MgMg0`2=SHd00`2IVIT0TI6A0:6QX@020:j^[Q`000009P3ooolK00000080SHf=00D0S8b<08f=
S@2<S8`0PH6107]kN`0207=cL`0406a/K01cLg<0GUiN07=cL`<0IVIV0`1NGUh205ADE00503dm?@15
ADD0?Cdm03Ti>@1>CTh00P1DE5@0102h^;P0clo?0<o?c`39bLT20<g=c@040<O7a`3:b/X0d=3@0=?C
d`80d];B0P3Hf=P00`3Ph>00f=SH0=SHf0060=SHf080cLg=00@0^KVi09FEU@2@T900/k>c0P3Bd]82
0=SHf080ZJVY0`3Hf=P00`3Bd]80dm?C0=SHf0030=?Cd`040=SHf03@d=00dm?C0<o?c`@0dm?C00<0
b/[:0<S8b038b<P00P38b<P01030`<00^;Rh0;Rh^039bLT20:ZZZP040;Jf]P2h^;P0];Bd0:b/[080
TY:B7000000N0?ooo`00703ooolJ000000<0moOg00D0lO7a0>WYj@3EeMD0alO709nOW`0209FEU@03
0861P@1/K6`0GUiN00<0IVIV00<0GUiN051@D00b<S800`1;Bd/01@0m?Cd0bLW90=?Cd`3=cLd0dm?C
00H0f=SH103@d=000`3Cdm<0b/[:0<S8b0030<S8b0030;no_`2c/k<0/K6a0080]KFe00@0[:b/0:>S
X`2IVIT0NWYj0`1cLg<00`1kNg/0Lg=c07YjNP0207=cL`05075aL@1VIVH0C4a<04Q8B02<S8`00P1<
C4`0102DU9@0IVIV03dm?@19BDT202LW9`0404a<C026QXH0DE5A07MgM`80QXJ600D0MGEe08b<S02<
S8`0S8b<09NGU`020:6QX@040;no_`31`L40Zj^[096AT@80PH6100@0SHf=09FEU@2EUID0Zj^[0P2^
[Zh00`2[Zj/000000000000I000002H0oooo6P0000000`1kNg/0PH610861P@0207]kN`0306IVIP1c
Lg<0IVIV0080K6a/00<0LG5a06IVIP1VIVH00`1VIVH0101NGUh0E5AD05ADE00b<S8203Ti>@<0?Cdm
00<0GUiN0=;BdP3?cll00`3?cll40<g=c@040<[:bP3?cll0d=3@0=?Cd`80d=3@103Hf=P00`3Ph>00
f=SH0=SHf0030=SHf0070=;BdP2i^KT0^KVi08R8R01_Kfl0BDU909FEU@020<[:bP80f=SH00<0Xj>S
09fMW@3Hf=P01@3Hf=P00`3Cdm<0f=SH0=SHf0030=SHf0040=?Cd`3Hf=P0f=SH0<o?c`80dm?C0P3:
b/X30<30`0030;bl_031`L40bLW90080][Jf0P2h^;P01@2f][H0];Bd0;Rh^02h^;P0];Bd01/00000
7P3oool001`0oooo6P000000203gmoL0m?Cd0?Cdm03/k>`0jNWY0<_;b`2m_Kd0UIFE0P2=SHd01021
PH40Lg=c06ATI01VIVH305iNGP0303dm?@0i>CT0B4Q80080?Cdm00@0PH610<o?c`3Cdm<0b/[:0`3C
dm<70=SHf080d=3@103:b/X01031`L40_;bl0;no_`2j^[X20;Fe]@040;>c/`2/[:`0Xj>S092@T080
VIVI0P1aLG402@1cLg<0K6a/075aL@1aLG40I6AT05iNGP1ADE40ADE508J6QP0207UiN@040861P@1k
Ng/0>CTi02LW9`80B4Q800<0IVIV08J6QP2<S8`00`26QXH01@2<S8`0Lg=c096AT@2=SHd0UIFE0080
XJ6Q00@0Zj^[0;no_`2m_Kd0SHf=0P1kNg/0102=SHd0QXJ609FEU@2h^;P20;fm_@030;Bd]0000000
000001T000009P3ooolJ0000000307=cL`1gMgL0MgMg0080Lg=c00<0K6a/07]kN`1/K6`00P1NGUh0
0`1VIVH0Ng]k05iNGP0505iNGP@0?Cdm00<0A4A404];B`21PH400P3Bd]820<[:bP040<o?c`3=cLd0
cLg=0<g=c@80d=3@00<0b/[:0=?Cd`3@d=001P3Hf=P20>3Ph080f=SH00@0h>3P0=SHf03Bd]80bLW9
0P26QXH0102@T900=SHf065QH@1jNWX20<g=c@80f=SH0P2MWId?0=SHf0040=?Cd`3Hf=P0cLg=0=?C
d`<0d=3@00@0b<S80;bl_038b<P0bLW90P2m_Kd0102c/k<0^;Rh0;Rh^02[Zj/20;Rh^0030;fm_@00
0000000001T000007P3oool001`0oooo6@0000002@3/k>`0moOg0?7al@3alO40k>c/0=gMg@3;bl/0
[:b/09FEU@0208f=S@0407]kN`1/K6`0EEEE05iNGP80E5AD00@0GUiN02XZ:P0m?Cd0ADE50P1NGUh0
0`3:b/X0cLg=0=?Cd`040=?Cd`030=SHf03@d=00f=SH00<0d=3@00@0f=SH0=3@d03@d=00b/[:0P38
b<P20<[:bP030<S8b02l_;`0_;bl0080^[Zj00@0/k>c0;6a/@2/[:`0Xj>S0P2IVIT0102@T900IVIV
075aL@1aLG42065QH@0506IVIP1@D500Bd];038b<P1/K6`00P2SXj<0101DE5@0VIVI06ATI01cLg<2
03Ti>@0406i^KP1EEED0SHf=06i^KP80QHF500D0QXJ608f=S@26QXH0UIFE0861P@020:^[Z`0409NG
U`31`L40clo?08f=S@80Ng]k00@0SHf=096AT@2OWil0XJ6Q0P2[Zj/00`2^[Zh0_Kfm0000000I0000
02H0oooo6@000000201kNg/0IVIV07=cL`1cLg<0LG5a07=cL`1NGUh0FUYJ1@1NGUh206IVIP80D51@
00@0?Cdm02XZ:P0i>CT0>CTi0P1@D5001@1;Bd/0d];B0<o?c`3Bd]80cLg=00D0clo?103Cdm<70=SH
f080h>3P1@3Hf=P0203?cll0][Jf08f=S@2=SHd0`<3009NGU`1QHF40HV9R0P31`L401@3Hf=P0d=3@
07YjNP2f][H0f=SH0080h>3P3P3Hf=P00`3=cLd0dm?C0<[:bP020=3@d080b/[:00H0alO70<71`@2m
_Kd0_Kfm0:b/[02OWil20:JVYP<0[:b/00<0^;Rh0000000000006000000N0?ooo`00703ooolH0000
0080moOg00P0m?Cd0>WYj@3YjNT0jNWY0<o?c`3;bl/0WinO096AT@80NGUi00@0Ng]k06ATI01NGUh0
GUiN0P1DE5@0100m?Cd0>CTi051@D01JFUX20<g=c@030<[:bP3=cLd0dm?C0080dm?C0P3@d=000`3=
cLd0b/[:0<[:bP040<[:bP030<S8b030`<00`<300080`L7100<0b<S80;no_`32`/800P2l_;`20;6a
/@040;Fe]@2c/k<0/K6a0:b/[080XJ6Q00@0VIVI09BDU01VIVH0GUiN0P1VIVH01@1EEED0E5AD03dm
?@0m?Cd0EEEE0080SHf=00@0PH6106a/K02OWil0DE5A0P21PH40101NGUh0LG5a07MgM`26QXH2075a
L@0308J6QP2=SHd0IVIV0080SHf=0`2QXJ400`2/[:`0/K6a0;fm_@0208f=S@0407MgM`2=SHd0WinO
09FEU@80Zj^[00<0_Kfm0=OGe`3/k>`06@00000V0?oooaP0000000<0MGEe075aL@1VIVH00P1DE5@0
1@1NGUh0E5AD05iNGP1VIVH0LG5a0080IVIV0P1NGUh0201<C4`0<S8b038b<P0b<S80>CTi03dm?@1@
D500>CTi0P39bLT20<g=c@<0clo?0P3=cLd00`3@d=00dm?C0=?Cd`030=?Cd`030=3@d03Cdm<0f=SH
00/0f=SH00<0d];B0<g=c@2EUID00P2f][H0103GemL0]kNg03`l?01CDe<20;bl_0030=SHf028R8P0
NGUi0080f=SH0`3Ph>000`3Hf=P0h>3P0=SHf0030>3Ph0030=SHf03Ph>00f=SH00<0f=SH0P3Cdm<2
0=SHf080clo?00@0alO70<[:bP31`L40`L710P2f][H0102[Zj/0WinO09FEU@1lO7`307YjNP030861
P@2h^;P0000001P000007P3oool001`0oooo600000000`3dm?@0moOg0?Ogm`020>WYj@050=OGe`3?
cll0];Bd09FEU@21PH400P1iNGT0101TI6@0GUiN05iNGP1NGUh2038b<P0303dm?@0i>CT0>CTi00<0
cLg=00D0dm?C0<g=c@3:b/X0b/[:0=3@d0020<[:bP040<;2`P2l_;`0]kNg0;Ng]`@0/K6a00<0[:b/
0;6a/@2a/K400`2a/K430;Zj^P80_;bl00@0^[Zj0;6a/@2a/K40[:b/0P2WYjL0102SXj<0XJ6Q09BD
U01jNWX205iNGP0505ADE01ADE40ADE503dm?@19BDT00P1TI6@0102IVIT0SHf=07YjNP2QXJ4208J6
QP040861P@1<C4`0LG5a08b<S080QHF500D0QXJ6075aL@21PH40PH610:>SX`0209FEU@040:6QX@2[
Zj/0`L710<W9b@80SHf=00@0UIFE0:>SX`2EUID0TI6A0P2/[:`00`2o_kl0kno_0=gMg@0I000002H0
oooo600000000`1JFUX0E5AD055AD@0204a<C00405YJFP1VIVH0IVIV06IVIP<0E5AD00@0?Cdm02LW
9`0b<S80?Cdm0P1;Bd/01018B4P0ADE505YJFP3=cLd20<o?c`050<g=c@3:b/X0clo?0<[:bP3Cdm<0
0P3:b/X00`3Cdm<0d=3@0=?Cd`030=?Cd`030=SHf03@d=00f=SH00@0f=SH00<0h>3P0=SHf03Hf=P0
103Hf=P00`3Bd]80cLg=08f=S@020:j^[P0406e]K@1gMgL08b<S05=CD`80^KVi00<0]KFe07alO02S
Xj<00P3Ph>020=SHf0L0h>3P1`3Hf=P20=?Cd`030<g=c@3?cll0clo?0080b/[:00P0`L710;Rh^02c
/k<0/k>c0:j^[P2OWil0UIFE08R8R080SHf=0P1[Jf/00`1RHV8000000000000G000001h0oooo000L
0?oooaP0000000<0m?Cd0?Ogm`3gmoL00P3YjNT01@3GemL0clo?0;Bd]02EUID0PH610080NGUi00@0
I6AT05iNGP1NGUh0GUiN0P0b<S800`0m?Cd0>CTi03Ti>@030<g=c@050=?Cd`3=cLd0b/[:0<[:bP3@
d=000P3:b/X01032`/80_;bl0;Ng]`2g]kL40;6a/@030:b/[02a/K40/K6a00<0/K6a0`2j^[X20;bl
_0040;Zj^P2a/K40/K6a0:b/[080YjNW00@0Xj>S0:6QX@2DU9@0NWYj0P1NGUh01@1DE5@0DE5A04E5
A@0m?Cd0BDU90080I6AT00@0VIVI08f=S@1jNWX0XJ6Q0P26QXH01021PH40C4a<075aL@2<S8`208F5
Q@0508J6QP1aLG40PH610861P@2SXj<00P2EUID0102QXJ40Zj^[0<71`@39bLT208f=S@0409FEU@2S
Xj<0UIFE096AT@80[:b/00<0_kno0>o_k`3MgMd06@00000V0?oooaP0000000<0FUYJ05ADE01ADE40
0P1<C4`0101JFUX0IVIV06IVIP1VIVH305ADE00403dm?@0W9bL0<S8b03dm?@80Bd];00@0B4Q804E5
A@1JFUX0cLg=0P3?cll01@3=cLd0b/[:0<o?c`3:b/X0dm?C0080b/[:00<0dm?C0=3@d03Cdm<00`3C
dm<00`3Hf=P0d=3@0=SHf0040=SHf0030>3Ph03Hf=P0f=SH00@0f=SH00<0d];B0<g=c@2=SHd00P2^
[Zh0101]KFd0MgMg02<S8`1CDe<20;Vi^@030;Fe]@1lO7`0Xj>S0080h>3P0P3Hf=P70>3Ph0L0f=SH
0P3Cdm<00`3=cLd0clo?0<o?c`020<[:bP080<71`@2h^;P0/k>c0;>c/`2^[Zh0WinO09FEU@28R8P2
08f=S@80Jf][00<0HV9R0000000000005`00000N0?ooo`00703ooolG00000080moOg0P3dm?@20>WY
j@040=GEe@3;bl/0[Zj^09FEU@<0Ng]k00@0LG5a05EEE@1NGUh0E5AD0P0i>CT00`0m?Cd0D51@0<W9
b@030<o?c`050=?Cd`3=cLd0b/[:0<[:bP38b<P00P31`L40102g]kL0]KFe0:b/[02WYjL60:JVYP80
[:b/00@0YjNW0:b/[02a/K40[:b/0`2j^[X0102l_;`0/k>c0;6a/@2/[:`20:VYZ@040:>SX`2IVIT0
VIVI08j>SP80GUiN00D0CTi>04];B`0m?Cd0:RXZ03dm?@02069RHP0409VIV@1iNGT0GUiN0:VYZ@80
QXJ600@0UiNG0861P@1VIVH0Lg=c0P2BTY801@26QXH0Ng]k08f=S@21PH40XJ6Q0080UIFE00@0Zj^[
0:6QX@2[Zj/0alO70P2[Zj/0102QXJ40WinO09nOW`2QXJ420:j^[P040<71`@3Vi^H0i^KV0>o_kaP0
00009P3ooolG0000000404A4A01DE5@0E5AD05ADE080FUYJ00D0LG5a05YJFP1NGUh0GUiN04a<C002
04A4A00303dm?@15ADD0B4Q800<0Bd];00@0?Cdm05iNGP3=cLd0cLg=0P3?cll50<[:bP80cLg=00<0
b/[:0=3@d03Cdm<00`3Cdm<70=SHf0030>3Ph03Hf=P0f=SH00<0f=SH00@0d];B0<30`03:b/X0Zj^[
0`1RHV800`2c/k<0=SHf05=CD`020;bl_003092@T01_Kfl0dm?C0080h>3P0`3Hf=P00`3Ph>00f=SH
0>3Ph0040=SHf0040>3Ph03Hf=P0h>3P0>3Ph0<0f=SH00P0d];B0=?Cd`3=cLd0cLg=0<o?c`3:b/X0
`L710;Jf]P80Zj^[0P2OWil01P2=SHd0PH6107alO01lO7`0TY:B07YjNP80IfMW6000000N0?ooo`00
703ooolG000000040>o_k`3gmoL0m?Cd0>c/k080emOG00D0clo?0<k>cP2OWil0PH6107UiN@0206IV
IP03075aL@1EEED0D51@00<0?Cdm00@0A4A404];B`3=cLd0cLg=1@3:b/X01@38b<P0`<3009FEU@2E
UID0RHV90080VIVI1P2MWId508V9R@030:>SX`2a/K40/K6a00@0^[Zj00@0/k>c0;6a/@2/[:`0[:b/
0P2SXj<02@2IVIT0T92@08b<S02<S8`0Bd];03dm?@0i>CT09bLW03Ti>@0205EEE@0407UiN@2SXj<0
QXJ6092@T080Zj^[00@0UiNG0:6QX@2EUID0QXJ60P1kNg/01@2<S8`0SHf=075aL@1kNg/0SHf=0080
XJ6Q00@0SHf=0:n_[`2^[Zh0_Kfm0P31`L40102OWil0Zj^[09FEU@2QXJ420;fm_@040<_;b`3GemL0
jNWY0>c/k1P000009P3ooolG00000004038b<P0i>CT0A4A405YJFP80GUiN00D0FUYJ04a<C018B4P0
<S8b02XZ:P0303Ti>@0303dm?@15ADD0?Cdm0080?Cdm00<0PH610<[:bP3:b/X00`3Cdm<00`3:b/X0
b<S80<S8b0040<S8b080dm?C00<0d=3@0=SHf03Cdm<00P3Cdm<00`3@d=00f=SH0=SHf0030=SHf004
0>3Ph03Hf=P0h>3P0=SHf080d];B00@0cLg=0<O7a`2f][H0ZZZZ0P1WIfL0101@D50030`<05EEE@1E
EED20<71`@0307alO01jNWX0f=SH00H0h>3P0P3Hf=P30>3Ph0030=SHf03Ph>00h>3P0080h>3P103H
f=P01P3Cdm<0b/[:0<[:bP3:b/X0alO70;no_`<0ZJVY00@0WinO09FEU@2EUID0UIFE0`1lO7`00`2=
SHd0N7Qh06MWI`0H000001h0oooo000L0?oooaD000000`3gmoL00`3_knl0moOg0>WYj@020=gMg@05
0=GEe@2^[Zh0UIFE07YjNP1/K6`00P1VIVH0101NGUh0Bd];05EEE@15ADD203dm?@0304];B`3Bd]80
cLg=00<0b/[:00@0b<S80<g=c@3:b/X0YZJV102MWId00`3=cLd0`<300:JVYP020:JVYP040;Fe]@30
`<00WIfM09fMW@80VIVI00D0T92@08f=S@29RHT0Xj>S0;6a/@020;>c/`030;Zj^P2l_;`0/k>c00<0
/K6a00@0ZJVY0:>SX`2IVIT0WIfM0P2>SXh01@21PH40BDU902XZ:P0Z:RX09bLW0080EEEE00@0:RXZ
0:VYZ@2a/K40IVIV0P2^[Zh01021PH40ZZZZ0:^[Z`2=SHd208b<S00509NGU`1^KVh0S8b<0861P@2=
SHd00P2EUID0102IVIT0Xj>S0:j^[P31`L420<W9b@0409FEU@26QXH0UIFE0:6QX@80[:b/0P3Vi^H2
0>c/k0030>KViP000000000001D000009P3ooolE00000080<S8b00@09bLW03Ti>@1<C4`0FUYJ0P1D
E5@01@0i>CT0<S8b03dm?@0b<S80:RXZ00H0?Cdm0P39bLT00`3?cll0cLg=0<g=c@030<g=c@050<[:
bP3=cLd0b<S80:JVYP30`<000P3=cLd00`3:b/X0clo?0=?Cd`060=?Cd`X0f=SH00@0cLg=0<[:bP2c
/k<0UIFE0P23Ph<0101cLg<0KVi^06MWI`1_Kfl20;bl_003075aL@2YZJT0f=SH00L0h>3P00@0f=SH
0>3Ph03Ph>00f=SH0P3Ph>060=SHf080dm?C0P3@d=00103:b/X0`L710;>c/`2/[:`20:^[Z`80WinO
0P2EUID208J6QP0308f=S@1_Kfl0QXJ60080PH615`00000N0?ooo`00703ooolE000000<0moOg00<0
lO7a0?Ogm`3Jf]X00P3;bl/01@2/[:`0UIFE08J6QP1jNWX0EEEE0080GUiN00<0EEEE05iNGP0b<S80
0`0m?Cd01021PH40clo?0<o?c`3?cll20<[:bP<0b<S800D0VIVI09fMW@2MWId0WIfM09VIV@0309FE
U@80WIfM0P29RHT01@1mOGd0Ogmo07moO`1oOgl0YZJV0080SHf=00@0OGem0:^[Z`2g]kL0]kNg102j
^[X20;6a/@030:VYZ@2SXj<0Xj>S00<0VIVI00D0S8b<07UiN@0m?Cd0?Cdm01LG5`0203Ti>@0405iN
GP26QXH0UIFE0861P@80SHf=00@0Zj^[08b<S02_[jl0cLg=0P2=SHd01@1kNg/0S8b<08b<S01cLg<0
PH610080UiNG00<0UIFE0:6QX@2QXJ400`31`L40102OWil0UIFE09nOW`2EUID20:b/[0030>KViP3Y
jNT0kno_0080jNWY5`00000V0?oooaD000000P0O7al0100i>CT0B4Q8055AD@14A4@203dm?@0303Ti
>@0m?Cd0B4Q80080>CTi0`0m?Cd203Ti>@0308f=S@3Cdm<0dm?C00<0dm?C1@3:b/X00`38b<P0WIfM
0<S8b0050=?Cd`070<o?c`3=cLd0cLg=0=?Cd`3=cLd0dm?C0=3@d0060=SHf0070>3Ph03Hf=P0f=SH
0=;BdP3:b/X0`L710;Jf]P0209nOW`0407inOP12@T80HF5Q092@T080Xj>S00<0NWYj0<S8b03Ph>00
3P3Ph>040=SHf0030=?Cd`3Hf=P0dm?C0080dm?C00@0b/[:0<71`@2c/k<0Zj^[0P2EUID0102=SHd0
UIFE08f=S@28R8P207YjNP0509:BTP1_Kfl0Kfm_0861P@1RHV805`00000N0?ooo`00703ooolD0000
00030?Cdm03gmoL0moOg00<0m?Cd00P0emOG0<?3``33`l<0XJ6Q09FEU@1iNGT0I6AT05EEE@80GUiN
00@0D51@03Ti>@18B4P0>CTi0P1NGUh20=;BdP090<o?c`3:b/X0b/[:0<[:bP38b<P0YZJV09fMW@1i
NGT0GUiN0080IfMW00@0MGEe07UiN@1eMGD0MGEe0P1mOGd0101_Kfl0GUiN05IFEP1KFe/206MWI`05
04e=C@1UIFD0Fe]K04i>CP1QHF400P2MWId30;Zj^P@0/K6a0P2SXj<0202QXJ40Xj>S0:>SX`2>SXh0
PH6105iNGP0O7al05aLG0P0m?Cd01019BDT0FUYJ08f=S@2YZJT205iNGP040:VYZ@21PH40Xj>S0;no
_`80cLg=0P2IVIT00`1eMGD0S8b<0861P@0208f=S@04096AT@21PH40Zj^[0;fm_@80`L7100@0_Kfm
0:6QX@2[Zj/0WinO0P2h^;P01@3MgMd0k>c/0>KViP3/k>`0m?Cd0080k>c/5@00000V0?oooa@00000
00L0][Jf0;>c/`2c/k<0/k>c04];B`0b<S807alO0080>CTi0P0b<S800`0i>CT0?Cdm03Ti>@0204A4
A00303dm?@1DE5@0QXJ600<0cLg=00<0b/[:0=?Cd`3Cdm<00`3:b/X01@38b<P0YZJV09VIV@1iNGT0
YZJV00P0dm?C00@0d=3@0=?Cd`3@d=00b/[:0P3Cdm<40=SHf0070>3Ph03Hf=P0f=SH0=;BdP3=cLd0
alO70;Jf]P0209fMW@0409nOW`1_Kfl0O7al0:VYZ@80[:b/00<0_;bl0=?Cd`3Ph>000P3Ph>020=SH
f0040>3Ph03Hf=P0f=SH0>3Ph0<0f=SH0P3Ph>030=SHf0040>3Ph03Hf=P0f=SH0=SHf0<0dm?C00@0
cLg=0<71`@2YZJT0Zj^[0P2OWil209FEU@060861P@1eMGD0Kfm_06m_K`26QXH0O7al0P1[Jf/308>3
PaD000007P3oool001`0oooo500000000`3dm?@0moOg0?Ogm`030?Cdm0080=OGe`33`l<0`l?30:6Q
X@2EUID0NGUi06ATI01EEED205iNGP04051@D00i>CT0B4Q803Ti>@80GUiN0P3Bd]802@3?cll0b/[:
0<[:bP3:b/X0b<S80:JVYP2MWId0NGUi05iNGP0206MWI`0407EeM@1iNGT0MGEe07EeM@80OGem00@0
Kfm_05iNGP1FEUH0Fe]K0P1WIfL01@1=CDd0IFEU05]KF`1>CTh0HF5Q0080WIfM0`2j^[X40;6a/@80
Xj>S00P0XJ6Q0:>SX`2SXj<0SXj>0861P@1NGUh07alO01LG5`80?Cdm00@0BDU905YJFP2=SHd0ZJVY
0P1NGUh0102YZJT0PH610:>SX`2o_kl20<g=c@80VIVI00<0MGEe08b<S021PH400P2=SHd0102ATI40
PH610:^[Z`2m_Kd20<71`@040;fm_@2QXJ40Zj^[09nOW`80^;Rh00D0gMgM0>c/k03Vi^H0k>c/0?Cd
m0020>c/k1D000009P3ooolD000000070;Jf]P2c/k<0/k>c0;>c/`1;Bd/0<S8b01lO7`0203Ti>@80
<S8b00<0>CTi03dm?@0i>CT00P14A4@00`0m?Cd0E5AD08J6QP030<g=c@030<[:bP3Cdm<0dm?C00<0
b/[:00D0b<S80:JVYP2IVIT0NGUi0:JVYP080=?Cd`040=3@d03Cdm<0d=3@0<[:bP80dm?C103Hf=P0
1`3Ph>00f=SH0=SHf03Bd]80cLg=0<O7a`2f][H00P2MWId0102OWil0Kfm_07alO02YZJT20:b/[003
0;bl_03Cdm<0h>3P0080h>3P0P3Hf=P0103Ph>00f=SH0=SHf03Ph>030=SHf080h>3P0`3Hf=P0103P
h>00f=SH0=SHf03Hf=P30=?Cd`040<g=c@31`L40ZJVY0:^[Z`80WinO0P2EUID01P21PH40MGEe06m_
K`1_Kfl0QXJ607alO080Jf][0`23Ph<E000001h0oooo000L0?oooa@000000`3dm?@0103_knl0m?Cd
0>WYj@3GemL20;fm_@0509FEU@21PH40I6AT05EEE@1NGUh00P1DE5@304];B`0704i>CP3Bd]80d];B
0=;BdP3=cLd0clo?0=?Cd`020<[:bP050<S8b030`<00b<S80:JVYP2=SHd00P29RHT0101oOgl0RHV9
07moO`29RHT209VIV@L0Ogmo00<0XJ6Q0:VYZ@2[Zj/00`2a/K420;Zj^P80]KFe0P2a/K40102e]KD0
[:b/0:>SX`2SXj<20:6QX@0409VIV@2>SXh0LG5a03Hf=P<05aLG00@0=SHf05YJFP1aLG40Xj>S0P2E
UID00`1/K6`0XJ6Q0861P@030;no_`050<o?c`1iNGT0S8b<08b<S021PH400`2=SHd00`21PH40Zj^[
0:^[Z`020<71`@040<O7a`2EUID0Zj^[0:6QX@80eMGE0P3YjNT20>KViP<0m?Cd5@00000V0?oooa@0
0000102c/k<00`2f][H0/k>c0;no_`030<71`@040;no_`31`L40_kno0;no_`@0/k>c00<0b/[:0=?C
d`3Cdm<0103Cdm<0103@d=00b<S80<S8b030`<0209fMW@0305iNGP2=SHd0f=SH0080f=SH1@3Cdm<4
0=SHf080dm?C00<0d=3@0=SHf03Hf=P01@3Hf=P00`3Bd]80cLg=0=;BdP0209fMW@0409FEU@28R8P0
UIFE0;bl_080]kNg00<0b<S80=?Cd`3Ph>001@3Ph>000`3Hf=P0h>3P0=SHf0020>3Ph0030=SHf03P
h>00f=SH00L0f=SH00H0dm?C0=SHf03Hf=P0b/[:0<71`@2c/k<30:VYZ@0408f=S@28R8P0QXJ608R8
R080PH6100D0Jf][06MWI`1JFUX0PH6106m_K`0208V9RAD000007P3oool001`0oooo4`000000203_
knl0moOg0?Cdm03dm?@0k>c/0>o_k`3Vi^H0c/k>0P2^[Zh01@26QXH0K6a/06a/K01NGUh0E5AD0080
D51@00@0ADE504];B`1<C4`0E5AD0P3?cll0103:b/X0clo?0<g=c@3:b/X20<g=c@040<S8b03=cLd0
dm?C0=?Cd`<0f=SH00@0cLg=0<[:bP3Hf=P0b/[:0P38b<P0103Cdm<0f=SH0<g=c@3:b/X20<71`@03
0;bl_031`L40_;bl0080^[Zj0P2l_;`0102j^[X0_;bl0;Zj^P2g]kL30;6a/@80[:b/00<0Xj>S0:6Q
X@2QXJ400P2IVIT00`21PH40E5AD02PX:00200/;2`0405YJFP19BDT0FUYJ075aL@80SHf=00@0IVIV
08b<S01cLg<0S8b<0`2o_kl00`2QXJ40VIVI08f=S@0307]kN`0408f=S@2IVIT0XJ6Q09VIV@80`L71
00@0alO709nOW`2OWil0TI6A0P3MgMd20>KViP030>WYj@3Vi^H0moOg00<0moOg5000000V0?oooa@0
000000L0^[Zj0;no_`2o_kl0^[Zj0;fm_@2o_kl0^[Zj00<0_;bl00<0_kno0;Jf]P2c/k<00`2c/k<0
0`2a/K40alO70<g=c@030=SHf080dm?C00D0d=3@0<[:bP31`L40`L7109FEU@0209fMW@0406MWI`29
RHT0f=SH0=SHf080dm?C00P0clo?0=?Cd`3Cdm<0dm?C0:NWY`3?cll0cLg=0=SHf080d=3@00<0d];B
0=?Cd`3Hf=P01P3Hf=P20=;BdP80cLg=00@0^KVi09FEU@2g]kL0b/[:0P38b<P20=SHf080h>3P00<0
hn?S0>3Ph03Ph>000`3Ph>050=SHf0030>3Ph03Hf=P0f=SH00D0f=SH00L0dm?C0<g=c@3=cLd0b<S8
0;bl_02o_kl0Zj^[0080WinO00@0UIFE08R8R02=SHd0QXJ60`21PH40101RHV80EUIF05EEE@1lO7`2
07inOQD000007P3oool001`0oooo4`0000000`3dm?@0kno_0?Cdm0020?Cdm0030>WYj@36a/H0_kno
0080WinO00D0NGUi06ATI01DE5@0E5AD055AD@0203Ti>@80Bd];00<0B4Q80;Rh^03?cll00`3?cll0
1P3@d=00dm?C0<[:bP3:b/X0dm?C0<[:bP80dm?C00L0f=SH0=?Cd`3Cdm<0f=SH0=?Cd`3Hf=P0b<S8
00@0b/[:1@2l_;`0102o_kl0_;bl0;no_`38b<P20;bl_0030;Zj^P2o_kl0_;bl00<0]kNg00@0/K6a
0:b/[02/[:`0Xj>S0P2MWId209VIV@030861P@1QHF409bLW00807alO00@0BDU905ADE021PH40LG5a
0P2OWil0101VIVH0GUiN096AT@2=SHd20;>c/`030;no_`38b<P0Zj^[0080S8b<0P2ATI40101kNg/0
PH610861P@2IVIT20<71`@040<O7a`2QXJ40[Zj^09FEU@80i^KV00@0jNWY0=gMg@3Vi^H0kno_103g
moLD000002H0oooo4`000000102m_Kd0^[Zj0;bl_02l_;`20;no_`80`L710P38b<P30;no_`080;bl
_02j^[X0/K6a0;6a/@2c/k<0b/[:0=SHf03Cdm<40=SHf0090<g=c@32`/80]kNg0;Ng]`29RHT0WIfM
09VIV@1eMGD0Ogmo0080cLg=00<0f=SH0=?Cd`3Cdm<00`3:b/X00`2IVIT0cLg=0=SHf0030=SHf004
0=3@d03=cLd0dm?C0=;BdP<0f=SH00<0d=3@0<o?c`37alL00`3=cLd0102c/k<0_;bl0<;2`P3:b/X3
0=SHf0P0h>3P00D0f=SH0>3Ph03Hf=P0f=SH0>3Ph0070=SHf0030=?Cd`3Hf=P0f=SH0080clo?00@0
b/[:0;Jf]P2[Zj/0ZJVY0P2EUID0102=SHd0UIFE07alO01lO7`206m_K`0507YjNP1eMGD0EUIF05YJ
FP1[Jf/00P2EUID00`30`<0000000000000B000001h0oooo000L0?oooa<000000P3dm?@20>o_k`80
m?Cd00T0c/k>09nOW`21PH40PH6106IVIP1/K6`0D51@055AD@0m?Cd01@1;Bd/30<o?c`030<g=c@3?
cll0dm?C00<0d=3@00<0dm?C0<o?c`3Cdm<01P3Cdm<00`3?cll0b/[:0<S8b0030<S8b0090;bl_02o
_kl0`/;20<;2`P2l_;`0`L710;bl_038b<P0_;bl0080b<S80P2l_;`20;Ng]`80^[Zj00@0/K6a0:b/
[02WYjL0[:b/0P2QXJ4209VIV@0308j>SP1/K6`0ADE50080=SHf00@05aLG04m?C`1EEED0I6AT0P1V
IVH0101iNGT0IVIV0861P@1jNWX209VIV@80_Kfm00<0VIVI0:6QX@2<S8`00P2=SHd0101kNg/0SHf=
07]kN`2QXJ420:^[Z`040<71`@2/[:`0UIFE0:>SX`80emOG0P3Vi^H00`3EeMD0moOg0?Cdm0030?Og
ma@000009P3ooolC000000030<;2`P31`L40_kno0080_kno0P38b<P0202o_kl0`L710<71`@2c/k<0
_kno0;Zj^P2c/k<0_;bl0P2a/K400`31`L40b/[:0=3@d0040=SHf0030=3@d03:b/X0_;bl0080]KFe
00D0VIVI0<g=c@2EUID0NGUi08V9R@020<[:bP<0dm?C00L0b/[:0<30`030`<00b/[:0=3@d03Hf=P0
hn?S00L0f=SH0P3=cLd20=?Cd`80cLg=0P37alL00`38b<P0cLg=0=?Cd`030=?Cd`80f=SH00<0h>3P
0>?Sh`3Ph>001@3Ph>001@3Hf=P0h>3P0>3Ph03Hf=P0h>3P00L0f=SH00<0dm?C0=3@d03:b/X00P3:
b/X00`2a/K40[:b/0:VYZ@0209nOW`0409FEU@26QXH0QXJ608f=S@80O7al00D0HV9R06m_K`1RHV80
FUYJ05EEE@020:JVYP030:VYZ@0000000000018000007P3oool001`0oooo4P0000020?Ogm`<0m?Cd
00@0kno_0<k>cP33`l<0UIFE0P1kNg/01@1/K6`0D51@05iNGP0m?Cd0Bd];0080>CTi00@0Bd];051@
D00m?Cd0clo?0`3=cLd00`3?cll0dm?C0=?Cd`020=?Cd`030=3@d03Cdm<0dm?C0080dm?C0P3?cll2
0=?Cd`80b<S80P2l_;`01038b<P0_;bl0;Fe]@2j^[X20;no_`040;bl_030`<00`/;20<S8b0<0`<30
00@0b/[:0<S8b02l_;`0_;bl0P2g]kL0102e]KD0[:b/0:b/[02SXj<20:6QX@0509fMW@2@T900SXj>
07]kN`19BDT00P0W9bL0100Z:RX0BDU9069RHP1[Jf/2075aL@0408J6QP1/K6`0GUiN06ATI080UIFE
00D0TI6A0:RXZ038b<P0Zj^[08J6QP02096AT@0406a/K02EUID0SHf=0:>SX`80XJ6Q00@0`L710:b/
[02=SHd0bLW90P3EeMD30>WYj@030?Cdm03gmoL0moOg00<0moOg4`00000V0?oooa<0000000D0b<S8
0;no_`2o_kl0_kno0<71`@020;no_`030<;2`P2j^[X0^[Zj00<0_kno0P2j^[X20;Fe]@040;Ng]`3:
b/X0d=3@0=3@d0@0f=SH00T0b/[:0;Ng]`2/[:`0[:b/09VIV@30`<00UIFE07EeM@1oOgl00`3Hf=P0
0`3?cll0b<S80;bl_0020;Vi^@030<[:bP3@d=00f=SH00<0f=SH00<0d=3@0=SHf03Hf=P0303Hf=P0
103Cdm<0f=SH0=SHf03Hf=P20>3Ph0D0f=SH0`3Ph>050=SHf0030>3Ph03Hf=P0f=SH00<0f=SH00<0
clo?0=?Cd`3@d=000P3:b/X00`32`/80/k>c0:VYZ@0309FEU@0408R8R01jNWX0QXJ607alO080Kfm_
00D0O7al06MWI`1RHV80K6a/05=CD`0207YjNP030=;BdP0000000000018000007P3oool001`0oooo
4P0000020?Ogm`<0m?Cd00@0kno_0<k>cP33`l<0UIFE0P1kNg/01@1/K6`0D51@05iNGP0m?Cd0Bd];
0080>CTi00@0Bd];051@D00m?Cd0clo?0`3=cLd00`3?cll0dm?C0=?Cd`020=?Cd`030=3@d03Cdm<0
dm?C0080dm?C0P3?cll20=?Cd`80b<S80P2l_;`01038b<P0_;bl0;Fe]@2j^[X20;no_`040;bl_030
`<00`/;20<S8b0<0`<3000@0b/[:0<S8b02l_;`0_;bl0P2g]kL0102e]KD0[:b/0:b/[02SXj<20:6Q
X@0509fMW@2@T900SXj>07]kN`19BDT00P0W9bL0100Z:RX0BDU9069RHP1[Jf/2075aL@0408J6QP1/
K6`0GUiN06ATI080UIFE00D0TI6A0:RXZ038b<P0Zj^[08J6QP02096AT@0406a/K02EUID0SHf=0:>S
X`80XJ6Q00@0`L710:b/[02=SHd0bLW90P3EeMD30>WYj@030?Cdm03gmoL0moOg00<0moOg4`00000V
0?oooa<0000000D0b<S80;no_`2o_kl0_kno0<71`@020;no_`030<;2`P2j^[X0^[Zj00<0_kno0P2j
^[X20;Fe]@040;Ng]`3:b/X0d=3@0=3@d0@0f=SH00T0b/[:0;Ng]`2/[:`0[:b/09VIV@30`<00UIFE
07EeM@1oOgl00`3Hf=P00`3?cll0b<S80;bl_0020;Vi^@030<[:bP3@d=00f=SH00<0f=SH00<0d=3@
0=SHf03Hf=P0303Hf=P0103Cdm<0f=SH0=SHf03Hf=P20>3Ph0D0f=SH0`3Ph>050=SHf0030>3Ph03H
f=P0f=SH00<0f=SH00<0clo?0=?Cd`3@d=000P3:b/X00`32`/80/k>c0:VYZ@0309FEU@0408R8R01j
NWX0QXJ607alO080Kfm_00D0O7al06MWI`1RHV80K6a/05=CD`0207YjNP030=;BdP00000000000180
00007P3oool001`0oooo4P0000020?Cdm0<0moOg00@0jNWY0<K6aP2VYZH0UIFE0P1/K6`00`1VIVH0
I6AT04i>CP0204];B`80BDU900@0Bd];03dm?@26QXH0bLW90`3=cLd50=?Cd`030=SHf03Cdm<0clo?
00@0dm?C0P3:b/X0202l_;`0/K6a0:b/[02/[:`0]kNg0;>c/`2/[:`0/K6a0P2g]kL01@2j^[X0_;bl
0<;2`P31`L40b<S800<0b/[:0P30`<00102l_;`0]kNg0;Ng]`2a/K420:b/[0<0Xj>S00D0XJ6Q09VI
V@29RHT0NWYj05iNGP0203Hf=P0403dm?@0l?3`0FUYJ05EEE@80LG5a00@0I6AT07]kN`1DE5@0IVIV
0P1EEED01@2^[Zh0_Kfm0:6QX@2ZZZX0TI6A0080UIFE00@0NWYj0861P@2=SHd0WinO0P2QXJ40102o
_kl0^;Rh09FEU@3MgMd20<71`@030?Cdm03YjNT0moOg00H0moOg4`00000V0?oooa80000000<0b<S8
0<;2`P32`/800P32`/840;no_`<0`/;20`2j^[X01P2e]KD0/K6a0;6a/@2g]kL0b<S80<[:bP@0f=SH
00<0d=3@0<[:bP2g]kL00P2WYjL01@2MWId0YZJV09FEU@1eMGD0RHV90080b/[:00@0b<S80<[:bP38
b<P0/K6a0P2j^[X01030`<00b/[:0=3@d03@d=020=?Cd`050<g=c@3:b/X0d=3@0=SHf03@d=004P3H
f=P00`3Ph>00f=SH0=SHf0030>3Ph0/0f=SH00<0dm?C0=SHf03:b/X00P38b<P0102l_;`0/k>c0:^[
Z`2EUID2092@T00409FEU@1lO7`0HV9R08J6QP<0O7al0`1[Jf/01@19BDT0De=C05=CD`3Hf=P0a/K6
01<000007P3oool001`0oooo4P0000000`3gmoL0kno_0?Ogm`030?Cdm0030;no_`2EUID0NGUi0080
I6AT0P1EEED00`1;Bd/0?Cdm03dm?@0304];B`0303Ti>@39bLT0cLg=0080cLg=00<0d=3@0=?Cd`3C
dm<01@3Cdm<00`3=cLd0dm?C0=?Cd`020=?Cd`040<[:bP30`<00^KVi0;Zj^P80YjNW0P2/[:`00`2S
Xj<0ZJVY0;6a/@020;6a/@040;Zj^P2l_;`0`/;20<30`0@0b<S800L0`<300<S8b02m_Kd0_Kfm0;Ng
]`2a/K40[:b/00<0Xj>S00D0XJ6Q092@T02>SXh0PH61065QH@0203Hf=P0400/;2`0S8b<0BDU905AD
E080K6a/00@0EEEE07]kN`1VIVH0IVIV0P1;Bd/01@2YZJT0S8b<0:6QX@3=cLd0UIFE00<0TI6A00<0
PH6108f=S@2<S8`00P2EUID0102o_kl0_Kfm0;fm_@3;bl/30=OGe`030=;BdP3gmoL0moOg00D0moOg
4`00000V0?oooa80000000<0b<S80<;2`P32`/800P32`/820<S8b080`/;20P2o_kl20<;2`P<0]KFe
0P2/[:`00`2e]KD0b<S80<[:bP030=3@d0040=SHf03@d=00b/[:0;6a/@80YZJV00D0WIfM0:JVYP2M
WId0OGem09VIV@020<S8b0040<[:bP38b<P0_;bl0:b/[080YjNW00<0]KFe0;Zj^P38b<P00`3:b/X2
0<30`0030<[:bP3@d=00d=3@00P0f=SH00@0clo?0=?Cd`3Cdm<0dm?C1@3Hf=P50>3Ph0/0f=SH00D0
dm?C0=SHf03Bd]80dm?C0<[:bP020<30`0040;Fe]@2YZJT0UIFE08f=S@80QXJ600<0NWYj06ATI02E
UID00`1JFUX01@1RHV80O7al06m_K`1aLG40HV9R0080IfMW00<0kno_0<W9b@0000004P00000N0?oo
o`00703ooolA000000H0moOg00@0jNWY0:j^[P26QXH0I6AT0P1DE5@01@1EEED0?Cdm04];B`15ADD0
Bd];0080CTi>00@0>CTi038b<P3=cLd0alO70`3:b/X00`3Cdm<0d=3@0=SHf0020=SHf0<0dm?C00D0
d=3@0=SHf02WYjL0YjNW09VIV@020<[:bP030<30`02e]KD0]KFe0080MGEe00L0T92@0:NWY`21PH40
PH610:6QX@2a/K40_;bl0080b<S8103:b/X01P38b<P0`<300;bl_02l_;`0]kNg0;Fe]@80[:b/0P2S
Xj<01@2QXJ40VIVI08j>SP1jNWX0LG5a0080ADE500@05aLG02<S8`0b<S80BDU90P1EEED0101JFUX0
K6a/06a/K01DE5@206a/K00505iNGP2=SHd0[jn_0:6QX@2_[jl00P2<S8`0102=SHd0IVIV0861P@21
PH420:6QX@80_Kfm00D0jNWY0:b/[03YjNT0jNWY0;Rh^0090?Ogma8000009P3ooolB000000030<S8
b032`/80`/;200@0`/;20P2m_Kd20;no_`050;Fe]@2m_Kd0_Kfm0;Fe]@2/[:`00P2a/K40102g]kL0
`<300=3@d03Cdm<20=3@d080f=SH00T0b/[:0;6a/@2VYZH0YZJV09fMW@2e]KD0RHV906m_K`1oOgl0
0P3Cdm<0103:b/X0b<S80<S8b02g]kL20:b/[00407EeM@2a/K40^[Zj0<71`@80]kNg00<0_;bl0;>c
/`2l_;`00P2l_;`20<71`@80b/[:00@0`<300<[:bP38b<P0b<S8103:b/X20=?Cd`<0f=SH0P3Ph>02
0=SHf0030>3Ph03Hf=P0f=SH00/0f=SH00<0dm?C0<[:bP3:b/X00P2l_;`0102g]kL0ZJVY09nOW`2=
SHd208R8R004075aL@21PH40NWYj075aL@80NWYj00D0LG5a06m_K`1RHV80EEEE05IFEP0205=CD`03
0>KViP3?cll00000018000007P3oool001`0oooo4@0000040?Ogm`80m?Cd00@0h>3P09FEU@1iNGT0
I6AT0P1VIVH204];B`0303dm?@18B4P0Bd];0080?Cdm00@0<S8b05EEE@3=cLd0b/[:0P3?cll0103C
dm<0f=SH0=?Cd`3@d=020=SHf0050=3@d03Cdm<0cLg=0=?Cd`3Hf=P00P3?cll0103=cLd0d=3@0=3@
d03:b/X20;Zj^P040;6a/@2c/k<0]KFe0;Zj^P80[:b/00<0U9BD0:>SX`2l_;`01P3:b/X02030`<00
b<S80<S8b038b<P0_Kfm0;Fe]@2a/K40[:b/0P2SXj<209VIV@0308j>SP29RHT0LG5a0080GUiN00@0
2`/;01LG5`0S8b<0?3`l0P1?Cdl0101NGUh0EEEE075aL@1DE5@205iNGP0502XZ:P2[Zj/0U9BD09NG
U`2o_kl00P21PH40102=SHd0K6a/07UiN@2=SHd209FEU@040:b/[036a/H0a/K60:b/[080^;Rh0P3g
moL00`3dm?@0moOg0?Ogm`040?Ogm`030?Cdm00000000000010000009P3ooolB000000030<S8b032
`/80`/;20080`/;200@0b<S80<;2`P2m_Kd0_Kfm0P32`/840;Fe]@060:ZZZP2/[:`0[:b/0;Fe]@30
`<00b/[:1@3@d=002@38b<P0/K6a0:JVYP2VYZH0WIfM0<30`029RHT0GUiN07moO`020=SHf0040<[:
bP38b<P0_;bl0;>c/`80[:b/00@0MGEe0;>c/`2i^KT0]kNg0`2[Zj/40;>c/`<0]kNg00<0]KFe0;>c
/`2c/k<00`2l_;`00`2o_kl0`/;20<[:bP020<g=c@040=?Cd`3Hf=P0f=SH0>3Ph0<0f=SH00<0h>3P
0=SHf03Hf=P02@3Hf=P40=?Cd`070<30`02l_;`0_;bl0;Ng]`2SXj<0T92@08R8R002075aL@0407in
OP21PH40HV9R06m_K`80K6a/00D0NWYj069RHP1RHV80OWin07EeM@0206m_K`030=SHf039bLT00000
018000007P3oool001`0oooo4@0000000`3gmoL0kno_0?Ogm`030?Ogm`040=OGe`2=SHd0I6AT065Q
H@80?Cdm00D0BDU9055AD@15ADD0Bd];055AD@03038b<P0307alO037alL0d=3@00<0d=3@1P3Hf=P2
0=?Cd`040=3@d03Hf=P0cLg=0<g=c@<0f=SH00@0d=3@0<S8b038b<P0^[Zj0P2i^KT00`2c/k<0/K6a
0;6a/@020:b/[0030<30`03:b/X0b/[:0080d=3@0`3:b/X40<30`0030;Zj^P2e]KD0/K6a0080YjNW
0P2MWId00`2>SXh0PH6107=cL`0206ATI00400/;2`0O7al05aLG04U9B@80EEEE00@0I6AT04E5A@1/
K6`0E5AD0P1NGUh01@0b<S80UIFE08f=S@2[Zj/0_kno0080PH6100@0SHf=07UiN@21PH40QXJ60P2E
UID0102^[Zh0a/K60<K6aP2m_Kd20<_;b`80moOg00<0m?Cd0?Ogm`3gmoL01@3gmoLB000002H0oooo
4@0000001038b<P0`/;20<S8b038b<P60<;2`P@0_Kfm00<0]KFe0:b/[02ZZZX00P2/[:`0102e]KD0
`<300<[:bP3:b/X20=?Cd`80d=3@00@0`<300:b/[02VYZH0YZJV0P2MWId00`1mOGd0EUIF07moO`02
0<g=c@80_;bl00P0]KFe0:b/[02SXj<0Xj>S092@T02e]KD0^KVi0;Fe]@80[:b/0P2a/K400`2j^[X0
_;bl0;>c/`020;>c/`80/K6a00P0YjNW0:>SX`2SXj<0Xj>S0:b/[02j^[X0_;bl0<S8b080b/[:00<0
f=SH0=?Cd`3Hf=P00P3Hf=P20>3Ph0`0f=SH0`3Cdm<20<[:bP80_Kfm00@0^[Zj0:>SX`2IVIT0SHf=
0P2EUID0101TI6@0HV9R09FEU@1RHV8206][J`0306m_K`1jNWX0NWYj0080LG5a0P2BTY800`3Bd]80
f=SH0=OGe`0B000001h0oooo000L0?oooa40000000<0moOg0>o_k`3gmoL00`3gmoL0103GemL0SHf=
06ATI01QHF4203dm?@0504U9B@1ADE40ADE504];B`1ADE400`0b<S800`1lO7`0alO70=3@d0030=3@
d0H0f=SH0P3Cdm<0103@d=00f=SH0<g=c@3=cLd30=SHf0040=3@d038b<P0b<S80;Zj^P80^KVi00<0
/k>c0;6a/@2a/K400P2/[:`00`30`<00b/[:0<[:bP020=3@d0<0b/[:1030`<000`2j^[X0]KFe0;6a
/@020:NWY`80WIfM00<0SXj>0861P@1cLg<00P1TI6@0100;2`/07alO01LG5`19BDT205EEE@0406AT
I015ADD0K6a/05ADE080GUiN00D0<S8b09FEU@2=SHd0Zj^[0;no_`020861P@0408f=S@1iNGT0PH61
08J6QP80UIFE00@0[Zj^0<K6aP36a/H0_Kfm0P3;bl/20?Ogm`030?Cdm03gmoL0moOg00D0moOg4P00
000V0?oooa40000000@0b<S80<;2`P38b<P0b<S81P32`/840;fm_@030;Fe]@2/[:`0ZZZZ0080[:b/
00@0]KFe0<30`03:b/X0b/[:0P3Cdm<20=3@d0040<30`02/[:`0YZJV0:JVYP80WIfM00<0OGem05IF
EP1oOgl00P3=cLd20;bl_0080;Fe]@2/[:`0Xj>S0:>SX`2@T900]KFe0;Vi^@2e]KD20:b/[080/K6a
00<0^[Zj0;bl_02c/k<00P2c/k<20;6a/@080:NWY`2SXj<0Xj>S0:>SX`2/[:`0^[Zj0;bl_038b<P2
0<[:bP030=SHf03Cdm<0f=SH0080f=SH0P3Ph>0<0=SHf0<0dm?C0P3:b/X20;fm_@040;Zj^P2SXj<0
VIVI08f=S@80UIFE00@0I6AT069RHP2EUID0HV9R0P1[Jf/00`1_Kfl0NWYj07YjNP02075aL@80TY:B
00<0d];B0=SHf03GemL04P00000N0?ooo`00703ooolA000000040?Ogm`3dm?@0m?Cd0?Ogm`80m?Cd
00@0d];B07UiN@1NGUh0GUiN0P1DE5@204];B`03051@D01EEED0B4Q80080:RXZ00<0=SHf0<W9b@3=
cLd00`3Cdm<80=SHf0030=3@d03:b/X0f=SH00<0f=SH00<0hn?S0=SHf03@d=000P3:b/X01031`L40
]kNg0;Fe]@2c/k<20;6a/@030:b/[02g]kL0`<300080b/[:0P3=cLd00`3:b/X0d=3@0<[:bP030<S8
b080`<3000T0]kNg0;Fe]@2/[:`0[:b/0:NWY`2IVIT0T92@0861P@1cLg<00P1NGUh0100Z:RX00000
01lO7`15ADD202XZ:P0406IVIP1DE5@0K6a/04Q8B080E5AD00<0GUiN07UiN@2ATI400P2ZZZX20:6Q
X@030861P@2=SHd0NGUi00<0PH6100@0[:b/0<O7a`2h^;P0d];B0P3dm?@80?Ogm`80m?Cd4P00000V
0?oooa40000000@0b<S80<;2`P32`/80`/;20P38b<P20<;2`P80_Kfm0P30`<001@2j^[X0]KFe0;Fe
]@2_[jl0ZZZZ0080Xj>S00@0/K6a0;Vi^@30`<00b<S8103:b/X02@30`<00/K6a0:JVYP2VYZH0RHV9
09fMW@1oOgl0Fe]K07moO`020<[:bP040;bl_02o_kl0^[Zj0;6a/@80ZJVY00@0YjNW0;Zj^P2c/k<0
/k>c0P2a/K400`2c/k<0^[Zj0;Zj^P020;no_`80_;bl00@0/k>c0:^[Z`2^[Zh0WinO0P2YZJT209FE
U@050:b/[02j^[X0^[Zj0;Zj^P32`/800P3Cdm<@0=SHf080dm?C00<0cLg=0=?Cd`38b<P00P38b<P0
102m_Kd0Xj>S08f=S@28R8P207alO0040861P@19BDT0HV9R07YjNP80Cdm?00D0IfMW075aL@21PH40
SHf=09FEU@020:JVYP030<o?c`3MgMd0gMgM018000007P3oool001`0oooo4@000000103dm?@0moOg
0?Ogm`3gmoL20>o_k`0409FEU@1TI6@0I6AT03dm?@<0ADE500@0Bd];055AD@1;Bd/07alO0P0b<S80
100O7al0b/[:0=3@d03Bd]820=3@d0T0f=SH0P3Cdm<20=3@d0<0f=SH00L0dm?C0<[:bP3:b/X0]kNg
0:^[Z`2/[:`0/K6a0080Zj^[00<0/k>c0;bl_03:b/X00P3=cLd20<o?c`040=?Cd`3:b/X0b/[:0<S8
b080b/[:00@0b<S80<30`02g]kL0]KFe0P2a/K401@2/[:`0XJ6Q092@T021PH40NGUi0080LG5a00@0
BDU900H61P0G5aL0=SHf0P1FEUH0101EEED0GUiN06ATI01;Bd/205ADE00504U9B@1aLG40S8b<09VI
V@2a/K400P31`L40101kNg/0PH61075aL@21PH4209FEU@040;no_`37alL0WinO0<_;b`80moOg00<0
m?Cd0?Ogm`3dm?@00P3dm?@40?Ogm`030?Cdm00000000000010000009P3ooolA00000080b<S800@0
`/;20<S8b038b<P0b<S80P32`/840;fm_@030;Fe]@2_[jl0[jn_0080ZZZZ0P2UYJD0102/[:`0]kNg
0<30`03:b/X20<S8b0040<[:bP38b<P0`L710;6a/@80[:b/00D0RHV909VIV@1oOgl0IfMW07moO`02
0<71`@040;bl_032`/80_kno0;Ng]`80/K6a00@0PH610:b/[02a/K40/K6a0P2[Zj/00`2c/k<0_;bl
0;bl_0040<71`@040;Jf]P2c/k<0Zj^[0:>SX`80UIFE00@0R8R808f=S@2EUID0[:b/0P2QXJ400`2g
]kL0b<S80=?Cd`050=SHf0030=3@d03Hf=P0dm?C00H0f=SH0`3Cdm<00`3Hf=P0b/[:0<[:bP030<S8
b0040;Fe]@2QXJ40Xj>S07UiN@80UIFE00@0NWYj07alO01JFUX0FUYJ0P19BDT01@0b<S80IfMW075a
L@1lO7`0SHf=0080WIfM00<0_Kfm0=OGe`3Bd]804P00000N0?ooo`00703oool?00000080moOg00@0
m?Cd0?Ogm`3gmoL0moOg0P3alO401028R8P0I6AT051@D00m?Cd205EEE@80DE5A00<0Bd];01LG5`0Z
:RX00P0W9bL00`0f=SH0b/[:0=?Cd`0=0=SHf0070=3@d03Bd]80d];B0=3@d03Hf=P0d=3@0<g=c@02
0<30`0030;bl_02[Zj/0/K6a00<0/k>c00D0_;bl0<[:bP3:b/X0b/[:0<g=c@020=3@d0040=?Cd`3=
cLd0d=3@0<[:bP80b<S800@0b/[:0<30`030`<00]kNg0P2e]KD01@2YZJT0[:b/09VIV@2>SXh0NGUi
0080K6a/00@0EEEE00/;2`0X:2P0:RXZ0P15ADD01019BDT0E5AD05ADE01VIVH305ADE00407YjNP2=
SHd0UiNG0;6a/@80cLg=00@0PH6107]kN`1/K6`0NWYj0P26QXH0102/[:`0a/K60<_;b`3dm?@=0?Og
ma4000009P3ooolA000000<0b<S81P32`/830;fm_@80]KFe00<0[:b/0:NWY`2UYJD00P2UYJD0102/
[:`0]kNg0;bl_030`<020<S8b080b/[:00T0b<S80;6a/@2WYjL0YjNW08V9R@2@T900YZJV04e=C@1o
Ogl01@2l_;`01@2j^[X0/K6a0;6a/@2QXJ40U9BD0080[:b/0P2c/k<01@2l_;`0`L710<71`@31`L40
b/[:0080`L7100@0_kno0;>c/`2/[:`0_kno0P2YZJT0102@T900LG5a092@T02SXj<20:NWY`03092@
T02g]kL0dm?C00@0f=SH0P3Cdm<50=SHf0030=3@d03Cdm<0dm?C0080dm?C00D0f=SH0=?Cd`3:b/X0
b/[:0<S8b0020<;2`P040;Fe]@2WYjL0SHf=08R8R080QXJ600@0SHf=05YJFP1lO7`0HV9R0P1jNWX0
1@19BDT0HV9R06m_K`28R8P0a/K60080RHV90`3;bl/B000001h0oooo000L0?ooo`l000000P3dm?@0
0`3gmoL0m?Cd0?Cdm0030?Cdm00408R8R01NGUh0Bd];04];B`80EEEE00D0BDU904];B`1ADE40:RXZ
01lO7`0202XZ:P030:b/[03?cll0clo?00H0f=SH103Ph>040=SHf080dm?C00@0cLg=0=SHf03Hf=P0
b/[:0P30`<020;>c/`080;6a/@2j^[X0_;bl0;bl_031`L40b/[:0<o?c`3=cLd30=3@d0040=SHf03B
d]80d=3@0<g=c@<0b/[:00<0`<300;bl_02l_;`00P2c/k<01@2/[:`0Xj>S0:6QX@2>SXh0NWYj0080
K6a/00@0I6AT01lO7`061PH0<S8b0P0Z:RX0101EEED0GUiN04];B`1NGUh206IVIP0505ADE01aLG40
WinO0:6QX@2_[jl00P3=cLd0101iNGT0TI6A05iNGP26QXH207UiN@030;fm_@3?cll0bl_;00h0moOg
4@00000V0?oooa40000000<0b<S80<;2`P32`/801032`/800`2o_kl0`/;20;fm_@030;Fe]@040:n_
[`2/[:`0ZZZZ0:>SX`80VIVI00@0Xj>S0;6a/@2g]kL0`<300P38b<P01031`L40b/[:0;no_`2a/K42
0:b/[00508V9R@2=SHd0SHf=06EUI@2QXJ400P31`L40102o_kl0`L710<30`02l_;`20;Zj^P040;6a
/@2SXj<0[:b/0;Ng]`80_;bl0P3:b/X00`3=cLd0alO70<[:bP020<O7a`040;Jf]P31`L40^;Rh0;Jf
]P80GUiN00<0WinO08f=S@1iNGT00`2EUID0101aLG40SHf=0<g=c@3Cdm<30=SHf0@0dm?C0P3Hf=P0
0`3@d=00dm?C0=SHf0030=?Cd`030=3@d03:b/X0b/[:0080b<S80P30`<00102e]KD0Xj>S09VIV@26
QXH207alO004075aL@26QXH0HV9R06ATI080Cdm?00D0EUIF04U9B@1FEUH0TY:B0<W9b@020;fm_@03
0<K6aP3Bd]80`<30018000007P3oool001`0oooo3`0000030?Ogm`80m?Cd00H0moOg0<_;b`3;bl/0
LG5a05iNGP15ADD305ADE005055AD@1;Bd/0:RXZ01lO7`0G5aL00P30`<00103Bd]80d=3@0=SHf03P
h>030=SHf0030>3Ph03Hf=P0f=SH00T0f=SH00@0dm?C0=SHf03Hf=P0d=3@0P3:b/X0102l_;`0/k>c
0;Zj^P2j^[X20;bl_0030<71`@3=cLd0cLg=0080f=SH0P3@d=000`3Hf=P0d=3@0=SHf0030=;BdP04
0<g=c@3:b/X0alO70<30`080^[Zj00D0/K6a0:VYZ@2SXj<0XJ6Q0861P@0206a/K00406IVIP15ADD0
<S8b03dm?@<0BDU900<0I6AT05ADE01VIVH00P1NGUh01@1EEED0LG5a0:VYZ@2QXJ40Zj^[0080`L71
00@0SHf=07]kN`1DE5@0NWYj0P21PH400`2a/K40eMGE0>c/k00;0?Ogm`030?Cdm03gmoL0moOg0140
00009P3ooolA000000030<S8b032`/80`/;200<0`/;200<0_Kfm0<;2`P2m_Kd00`2m_Kd01@2_[jl0
[:b/0:b/[02WYjL0XJ6Q0080VIVI00@0U9BD0:b/[02a/K40]kNg0P2o_kl0102l_;`0b<S80<;2`P2j
^[X20;6a/@050:>SX`29RHT0SHf=05]KF`2YZJT0102l_;`20<;2`P@0_;bl0P30`<030<[:bP040<o?
c`3=cLd0clo?0=;BdP80cLg=0P39bLT02037alL0bLW907emO@1mOGd0IFEU09FEU@1_Kfl0R8R80P2Y
ZJT01@1aLG40HF5Q0;bl_03@d=00clo?0080f=SH103Cdm<20<[:bP<0dm?C0`3=cLd01@3Cdm<0b/[:
0<[:bP3:b/X0b<S80080`/;200@0]KFe0:6QX@21PH40LG5a0P2=SHd0101lO7`0NWYj069RHP1JFUX2
05IFEP0507YjNP19BDT0NWYj06][J`2h^;P00P30`<000`36a/H0];Bd0<;2`P0B000001h0oooo000L
0?ooo`l000000`3gmoL20?Cdm0060?Ogm`3;bl/0bl_;075aL@1NGUh0ADE50`1DE5@01@1ADE40Bd];
02XZ:P0O7al05aLG0080`<3000@0d];B0=3@d03Hf=P0h>3P0`3Hf=P00`3Ph>00f=SH0=SHf0090=SH
f0040=?Cd`3Hf=P0f=SH0=3@d080b/[:00@0_;bl0;>c/`2j^[X0^[Zj0P2l_;`00`31`L40cLg=0<g=
c@020=SHf080d=3@00<0f=SH0=3@d03Hf=P00`3Bd]80103=cLd0b/[:0<O7a`30`<020;Zj^P050;6a
/@2YZJT0Xj>S0:6QX@21PH400P1/K6`0101VIVH0ADE5038b<P0m?Cd304U9B@0306ATI01DE5@0IVIV
0080GUiN00D0EEEE075aL@2YZJT0XJ6Q0:^[Z`020<71`@0408f=S@1kNg/0E5AD07YjNP80PH6100<0
/K6a0=GEe@3/k>`02`3gmoL00`3dm?@0moOg0?Ogm`0A000002H0oooo4@0000000`38b<P0`/;20<;2
`P030<;2`P030;fm_@32`/80_Kfm00<0_Kfm00D0[jn_0:b/[02/[:`0YjNW0:6QX@0209VIV@0409BD
U02/[:`0/K6a0;Ng]`80_kno00@0_;bl0<S8b032`/80^[Zj0P2a/K401@2SXj<0RHV908f=S@1KFe/0
ZJVY00@0_;bl0P32`/840;bl_080`<300`3:b/X0103?cll0cLg=0<o?c`3Bd]820<g=c@80bLW900P0
alO70<W9b@1mOGd0OGem06EUI@2EUID0Kfm_08R8R080ZJVY00D0LG5a065QH@2l_;`0d=3@0<o?c`02
0=SHf0@0dm?C0P3:b/X30=?Cd`<0cLg=00D0dm?C0<[:bP3:b/X0b/[:0<S8b0020<;2`P040;Fe]@2Q
XJ40PH61075aL@80SHf=00@0O7al07YjNP1RHV80FUYJ0P1FEUH01@1jNWX0BDU907YjNP1[Jf/0^;Rh
0080`<3000<0a/K60;Bd]032`/804P00000N0?ooo`00703oool?000000H0moOg0P1aLG40101NGUh0
E5AD038b<P1FEUH304U9B@04055AD@0Z:RX0?Cdm03Hf=P80b/[:00<0cLg=0=SHf03Hf=P00`3Hf=P2
0>3Ph0@0f=SH00<0h>3P0=SHf03Hf=P0103Hf=P0103Bd]80f=SH0=SHf03Hf=P20=3@d0040;bl_02c
/k<0_;bl0;no_`<0`L7100@0alO70<o?c`3Hf=P0d];B103Hf=P00`3@d=00d];B0=;BdP020=;BdP03
0<g=c@3:b/X0`L710080_;bl00D0/k>c0;6a/@2SXj<0XJ6Q08V9R@0207YjNP03065QH@19BDT0?Cdm
00<0?Cdm00@0EEEE05ADE01VIVH0I6AT0P1NGUh00`1_Kfl0R8R80:>SX`020:6QX@80Zj^[00@0TI6A
075aL@1@D500NWYj0P2EUID00`2^[Zh0gMgM0?Ogm`0>0?Ogma4000009P3ooolA000000030<S8b032
`/80b<S800@0`/;200<0_kno0;fm_@2m_Kd00P2m_Kd01@2e]KD0[jn_0:FUY@2WYjL0YJFU0080VIVI
00@0S8b<0:>SX`2/[:`0]KFe0P2c/k<0102o_kl0_;bl0;bl_02j^[X20:b/[0050;6a/@2SXj<0OGem
04i>CP2[Zj/00P2j^[X0102o_kl0b<S80<S8b031`L420<;2`P040<S8b03:b/X0b/[:0<[:bP80cLg=
00@0b/[:0<g=c@3Hf=P0f=SH0`3Bd]80103?cll0cLg=0<W9b@2i^KT2092@T0040<_;b`1/K6`0Rh^;
05mOG`80Zj^[00D0NWYj05EEE@2YZJT0b/[:0<o?c`020=3@d0040=?Cd`3=cLd0cLg=0<[:bP80d=3@
0P3Cdm<01`3@d=00dm?C0<g=c@3=cLd0b<S80<[:bP38b<P00P3:b/X20;fm_@040:b/[02QXJ40SHf=
06a/K0<0NWYj00<0O7al06][J`1OGel00P1JFUX01@1EEED0GemO05EEE@1NGUh0WinO0080_Kfm00<0
a/K60:2PX02JVYX04P00000N0?ooo`00703oool?000000@0moOg00P0m?Cd0?Ogm`1iNGT0NGUi06IV
IP19BDT0?Cdm05iNGP80EEEE00D0Bd];04E5A@0m?Cd0:RXZ08>3P`020=3@d0040=;BdP3Hf=P0f=SH
0=SHf0<0h>3P1`3Hf=P20>3Ph0H0f=SH0`3@d=00102l_;`0/k>c0;>c/`2o_kl20<71`@80b/[:0`3B
d]830=SHf080d=3@00D0f=SH0=?Cd`3Cdm<0clo?0<g=c@020<[:bP80`L7100D0/k>c0;6a/@2YZJT0
XJ6Q08j>SP0207YjNP04065QH@1EEED0<S8b038b<P80?Cdm00@0BDU9055AD@1TI6@0IVIV0P1TI6@0
0`1NGUh0XJ6Q0:6QX@020:6QX@80ZJVY00@0Zj^[07=cL`1cLg<0NGUi0P26QXH00`2_[jl0k>c/0?Og
m`0>0?Ogma4000009P3ooolA000000<0`/;200D0_kno0<;2`P32`/80`/;20;Zj^P020;fm_@<0]KFe
00@0[:b/0:NWY`2UYJD0XJ6Q0P2@T900102DU9@0RHV90:NWY`2/[:`20;6a/@030;Zj^P2l_;`0_;bl
00<0^[Zj0P2a/K400`2[Zj/0HF5Q0;6a/@020;Zj^P040<S8b02l_;`0`<300<S8b080`<3000@0b<S8
0<[:bP3:b/X0b/[:0`3=cLd00`3@d=00f=SH0=;BdP030=;BdP040<g=c@3Bd]80`L710;Jf]P80Zj^[
00@0jNWY0<;2`P2;Rh/0O7al0P2YZJT0102=SHd0HF5Q08f=S@3:b/X40=?Cd`80b/[:00<0dm?C0<g=
c@3=cLd00P3:b/X01@3=cLd0d=3@0<[:bP3:b/X0b<S80080b/[:0P38b<P20;bl_0040;6a/@2EUID0
PH6108R8R080K6a/0P1lO7`205YJFP80EUIF0P1EEED00`1DE5@0GUiN0;Jf]P020<K6aP030<o?c`2m
_Kd0Rh^;018000007P3oool001`0oooo3`0000050?Ogm`070?Cdm01aLG40LG5a075aL@1EEED0BDU9
04E5A@0205EEE@05055AD@0b<S80ADE505EEE@3=cLd00P3Cdm<00`3Bd]80f=SH0=SHf0090=SHf003
0=;BdP3Hf=P0f=SH00D0f=SH00<0cLg=0=SHf03Hf=P00P3Hf=P01031`L40]kNg0;>c/`2l_;`30<71
`@030<O7a`3=cLd0d];B00<0d];B00@0f=SH0=;BdP3Hf=P0d];B0`3=cLd00`3:b/X0cLg=0<O7a`03
0<71`@040;>c/`2YZJT0Xj>S09VIV@80PH6100@0K6a/05EEE@15ADD0>CTi0`0m?Cd00`1EEED0GUiN
069RHP0205EEE@05051@D02^[Zh0XJ6Q09FEU@2SXj<00P2OWil0102a/K40GUiN07UiN@1iNGT20861
P@030:^[Z`3_knl0moOg00h0moOg4@00000V0?oooa40000000<0b<S80;fm_@32`/800`32`/80102m
_Kd0`<300;fm_@2m_Kd20;Fe]@80[jn_00<0ZZZZ09VIV@2QXJ400P2DU9@208V9R@0309VIV@2ZZZX0
]KFe0080]KFe00<0^[Zj0;6a/@2l_;`00`2j^[X0102c/k<0]kNg09fMW@2a/K430;bl_0030<S8b030
`<00b/[:0080b<S80P3:b/X0103@d=00cLg=0<o?c`3?cll30=3@d080f=SH0P3Bd]80103Hf=P0alO7
0<71`@2YZJT20<_;b`0406i^KP1@D500=SHf08>3P`80UIFE00<0`L7107YjNP1_Kfl00P3:b/X20<g=
c@L0b/[:00<0dm?C0<[:bP3:b/X01`38b<P20;bl_0040;Ng]`2IVIT0PH61075aL@<0UIFE0P1NGUh0
201?Cdl0E5AD05ADE00m?Cd0EEEE06m_K`1aLG40Zj^[0P3EeMD00`2d];@0WIfM0:2PX00B000001h0
oooo000L0?ooo`l000000`3gmoL00`3dm?@0moOg0:j^[P0205iNGP04069RHP1DE5@0GUiN05ADE080
EEEE00D0?Cdm03Hf=P15ADD0alO70=SHf0020<g=c@H0f=SH00@0h>3P0=SHf03Hf=P0f=SH0P3Bd]82
0<g=c@80d];B0`3Hf=P00`3@d=00dm?C0=SHf0030=SHf0040<[:bP2g]kL0/K6a0;>c/`80][Jf00D0
_kno0;Jf]P39bLT0clo?0<g=c@020=SHf0<0d];B00@0cLg=0<W9b@39bLT0cLg=0`3:b/X30<71`@04
0;Jf]P2a/K40ZJVY09fMW@80SXj>00@0K6a/05iNGP19BDT0:RXZ0`0m?Cd00`19BDT0K6a/05iNGP03
05iNGP0409nOW`2EUID0XJ6Q0:6QX@80K6a/00@0_Kfm04a<C01/K6`0SHf=0P2EUID00`2/[:`0moOg
0?Ogm`0>0?Ogma4000009P3ooolA000000030<;2`P2o_kl0_Kfm00D0`/;20P2m_Kd20;Fe]@030:n_
[`2/[:`0YjNW0080VIVI0P2DU9@0102<S8`0QXJ608J6QP2QXJ420:b/[080/k>c00@0]KFe0;Zj^P2l
_;`0_;bl202j^[X00`2l_;`0b/[:0<[:bP020<S8b0@0b/[:0`3Cdm<60=SHf0040=;BdP37alL0^;Rh
09fMW@80NGUi00@0Kfm_0;fm_@0Z:RX0NWYj0P2EUID01037alL0[:b/05iNGP37alL30<[:bP040<S8
b03:b/X0b/[:0<S8b0H0b/[:0`38b<P0103:b/X0b<S80;no_`2j^[X20;6a/@040:VYZ@2IVIT0SHf=
08J6QP80NWYj00@0HV9R06a/K01DE5@0EEEE0P19BDT01@1EEED0GUiN06][J`1aLG40Zj^[0080d];B
00<0QXJ609ZJVP1hN7P04P00000N0?ooo`00703oool?000000<0moOg00<0m?Cd0?Ogm`1nOWh00P2=
SHd0101/K6`0BDU906a/K019BDT205EEE@05038b<P19BDT0Bd];0<O7a`3@d=000P37alL20=SHf003
0>3Ph03Hf=P0f=SH00<0f=SH0P3Bd]820<30`0050<O7a`3:b/X0b/[:0<g=c@3Bd]800P3Hf=P00`3?
cll0dm?C0=SHf0030=SHf0040<[:bP2e]KD0/K6a0:^[Z`<0/k>c00@0`L710<W9b@3=cLd0d];B0`37
alL00`31`L40alO70<O7a`030<O7a`030<[:bP3=cLd0alO70080alO700D0^;Rh0;no_`2a/K40ZJVY
0:6QX@0208j>SP0407UiN@1NGUh0DE5A02XZ:P809bLW00@0?Cdm04U9B@1NGUh0IVIV0`1NGUh0102O
Wil0VIVI09VIV@2QXJ42055AD@040:n_[`1QHF40GUiN08R8R080ZJVY00@0alO70?Ogm`3gmoL0moOg
0P3dm?@;0?Ogma4000009P3oool?000000@0`/;21P2m_Kd00`32`/80^[Zj0;Fe]@020;Fe]@040:b/
[02WYjL0VIVI09VIV@80T92@00@0S8b<08V9R@1kNg/0VIVI0P2SXj<0102/[:`0/K6a0;>c/`2a/K42
0;>c/`030;Zj^P2l_;`0^[Zj0080^[Zj0P2l_;`0102o_kl0_;bl0<S8b030`<020<S8b0<0b/[:00P0
d=3@0<[:bP3:b/X0cLg=0=;BdP3@d=00f=SH0=3@d0<0d];B00<0`L710;Vi^@28R8P00P1DE5@0101R
HV8030`<03Hf=P1QHF4209FEU@050<[:bP2i^KT0LG5a0<O7a`3:b/X00`37alL20<30`0040<S8b030
`<00`<300<30`080b<S80`3:b/X01@30`<00`/;20<30`032`/80^[Zj0080]kNg00@0/K6a09VIV@26
QXH0LG5a0P28R8P0101aLG40NWYj04E5A@1EEED204U9B@0504E5A@1DE5@0HV9R08J6QP2[Zj/00P2m
_Kd0102VYZH0X:2P07YjNP2JVYXA000001h0oooo000L0?ooo`l000000`3gmoL00`3dm?@0moOg07in
OP0208f=S@0406a/K019BDT0K6a/04U9B@80EEEE00D0<S8b04U9B@1;Bd/0alO70=3@d0020<O7a`80
f=SH00<0h>3P0=SHf03Hf=P00`3Hf=P20=;BdP80`<3000D0alO70<[:bP3:b/X0cLg=0=;BdP020=SH
f0030<o?c`3Cdm<0f=SH00<0f=SH00@0b/[:0;Fe]@2a/K40Zj^[0`2c/k<01031`L40bLW90<g=c@3B
d]830<O7a`030<71`@37alL0alO700<0alO700<0b/[:0<g=c@37alL00P37alL01@2h^;P0_kno0;6a
/@2YZJT0XJ6Q0080SXj>00@0NGUi05iNGP1ADE40:RXZ0P0W9bL0100m?Cd0BDU905iNGP1VIVH305iN
GP0409nOW`2IVIT0VIVI0:6QX@80DE5A00@0[jn_065QH@1NGUh0R8R80P2YZJT01037alL0moOg0?Og
m`3gmoL20?Cdm0/0moOg4@00000V0?ooo`l000001032`/860;fm_@030<;2`P2j^[X0]KFe0080]KFe
00@0[:b/0:NWY`2IVIT0VIVI0P2@T900102<S8`0RHV907]kN`2IVIT20:>SX`040:b/[02a/K40/k>c
0;6a/@80/k>c00<0^[Zj0;bl_02j^[X00P2j^[X20;bl_0040;no_`2l_;`0b<S80<30`080b<S80`3:
b/X0203@d=00b/[:0<[:bP3=cLd0d];B0=3@d03Hf=P0d=3@0`3Bd]800`31`L40^KVi08R8R00205AD
E004069RHP0<30`0=SHf065QH@80UIFE00D0b/[:0;Vi^@1aLG40alO70<[:bP030<O7a`80`<3000@0
b<S80<30`030`<00`<300P38b<P30<[:bP050<30`032`/80`<300<;2`P2j^[X00P2g]kL0102a/K40
VIVI08J6QP1aLG4208R8R004075aL@1jNWX0ADE505EEE@80BDU900D0ADE505ADE01RHV80QXJ60:^[
Z`020;fm_@040:JVYP2PX:00NWYj09ZJVQ4000007P3oool001`0oooo3`0000030?Cdm080moOg00L0
E5AD09:BTP2BTY80GUiN06][J`1JFUX0GUiN0080BDU900D0:RXZ06IVIP2e]KD0b/[:0;Ng]`020<g=
c@H0f=SH00@0d];B0<o?c`3=cLd0cLg=0P3:b/X01@2f][H0/k>c0<71`@37alL0cLg=0080d];B00<0
alO70<g=c@3Hf=P00`3Hf=P01030`<00/k>c0:NWY`2^[Zh20:^[Z`040:b/[02h^;P0alO70<W9b@<0
`L7100@0^;Rh0;Vi^@2a/K40/K6a0P2[Zj/20;Jf]P@0`L710P2o_kl00`2c/k<0ZJVY09VIV@02092@
T00407YjNP1/K6`0EEEE04E5A@805aLG00@0<S8b03dm?@1NGUh0GUiN0P1/K6`01@1EEED0UIFE0:>S
X`21PH40SHf=0080D51@00@0_Kfm06a/K01EEED0UIFE0P2[Zj/00`3EeMD0moOg0?Ogm`070?Ogm`03
0?Cdm03gmoL0moOg00@0moOg4@00000V0?oooa40000000<0`/;20<S8b032`/800`2m_Kd00`2o_kl0
_Kfm0;Zj^P030;fm_@<0[:b/00P0XJ6Q09VIV@2IVIT0VIVI08b<S029RHT0PH6107]kN`80VIVI00<0
Xj>S0:b/[02a/K400`2a/K420;>c/`80^[Zj00H0]KFe0;Zj^P2j^[X0_;bl0;Ng]`2l_;`30<30`003
0<S8b030`<00b/[:00<0b/[:0P3@d=000`3Hf=P0d=3@0=3@d0020=SHf0040=;BdP37alL0/K6a08f=
S@80OWin00@0QHF506MWI`0f=SH0ATI60P2IVIT20<O7a`03075aL@2OWil0`L710080`L7100@0b/[:
0<71`@2l_;`0`L711@38b<P40<71`@80_;bl00P0^[Zj0;bl_02c/k<0/k>c0:VYZ@2IVIT0QXJ607Ui
N@80O7al00@0LG5a04E5A@1EEED0EEEE0`0m?Cd0101/K6`0I6AT08J6QP37alL209nOW`0308J6QP1/
K6`0Kfm_018000007P3oool001`0oooo3`0000040?Ogm`080?ooo`1/K6`0O7al07alO01EEED0GUiN
05EEE@1QHF4202LW9`0505ADE01ADE40d=3@09VIV@2/[:`00P3?cll40=SHf080d];B00@0bLW90;Jf
]P2EUID0SHf=0P2[Zj/0102ZZZX0UIFE0;Jf]P2f][H30=;BdP80cLg=103Hf=P0103:b/X0/k>c0:>S
X`2OWil20:>SX`050;no_`2f][H0bLW90;Vi^@2f][H00P2YZJT00`2MWId0R8R808f=S@0409nOW`03
0:ZZZP2o_kl0`L7100@0][Jf00<0/K6a0:VYZ@2OWil00P2@T9001021PH40HF5Q05EEE@19BDT203dm
?@80<S8b00L0EEEE05ADE01RHV80HV9R05iNGP28R8P0SHf=0080PH610P1NGUh0102m_Kd0GUiN05EE
E@2OWil20:6QX@030=OGe`3oool0moOg00h0moOg4@00000V0?oooa4000000P38b<P01032`/80_Kfm
0<;2`P32`/820;fm_@80^[Zj0P2_[jl0102e]KD0/K6a0:ZZZP2QXJ4309VIV@0408b<S021PH40QXJ6
07]kN`80NWYj00<0T92@0:>SX`2/[:`00`2/[:`20;6a/@030;Zj^P2a/K40]KFe00@0]kNg0P2l_;`2
0<S8b0030<30`038b<P0`<3000<0b<S800D0b/[:0<g=c@3Bd]80d];B0=SHf0020=;BdP040<g=c@37
alL0/K6a09nOW`80O7al00@0FEUI051@D019BDT0?3`l0P2SXj<01@31`L40b/[:08V9R@1lO7`0alO7
0080b/[:00@0`L710;no_`2l_;`0_kno0`2l_;`00`32`/80_;bl0<71`@030;no_`80_;bl00P0^[Zj
0;>c/`2[Zj/0Zj^[0:VYZ@2@T900R8R807alO080NWYj00@0R8R804U9B@1EEED0BDU90P0f=SH01@0b
<S80E5AD06a/K02=SHd0alO70080TY:B00<0N7Qh07YjNP26QXH04P00000N0?ooo`00703oool?0000
00@0moOg00P0X:2P07YjNP1aLG40LG5a04U9B@1EEED0BDU9065QH@80<S8b00D0GUiN0;fm_@30`<00
YZJV0:^[Z`020<o?c`040=;BdP3Hf=P0f=SH0<g=c@80^KVi00@0QXJ608f=S@2f][H0[Zj^0P1RHV80
0`1WIfL0Ph>309nOW`0209fMW@<0cLg=00<0alO70=SHf03Hf=P00P3Hf=P01038b<P0_;bl0:>SX`2Y
ZJT209FEU@050:VYZ@1NGUh0OGem092@T02[Zj/00P3;bl/0101iNGT0E5AD07inOP1lO7`207YjNP03
07alO028R8P0Zj^[00<0/k>c0P2f][H20:^[Z`0709VIV@2@T900T92@07YjNP1/K6`0GUiN04U9B@02
05EEE@80:RXZ0P1EEED205iNGP0506a/K026QXH0UIFE07]kN`21PH400P1JFUX00`2o_kl0IVIV075a
L@030:^[Z`030>WYj@3gmoL0moOg00h0moOg4@00000V0?oooa4000000P38b<P01P2o_kl0_Kfm0;fm
_@2m_Kd0^[Zj0;fm_@80^[Zj0P2e]KD01@2/[:`0[jn_0:ZZZP2WYjL0XJ6Q0080T92@00@0U9BD0861
P@26QXH0Ng]k0P1cLg<209VIV@050:6QX@2WYjL0ZJVY0:VYZ@2/[:`01P2a/K40102g]kL0^[Zj0;Ng
]`2g]kL20;fm_@040;bl_038b<P0`<300<S8b080b/[:00D0b<S80<[:bP3Bd]80d];B0=?Cd`020<g=
c@040<W9b@37alL0Zj^[09nOW`80NWYj0P2PX:002@0l?3`0BDU90:VYZ@2YZJT0`L710<[:bP2=SHd0
NGUi0<O7a`020;bl_0040;no_`31`L40_;bl0<71`@D0_;bl00@0_kno0;Zj^P2j^[X0^[Zj0P2l_;`0
202f][H0/k>c0:^[Z`2[Zj/0WinO08f=S@28R8P0NWYj0P21PH400`1jNWX0IVIV06IVIP0304E5A@05
03Hf=P1DE5@0NWYj08f=S@2c/k<00P2BTY800`1jNWX0HV9R065QH@0B000001h0oooo000L0?ooo`l0
0000103gmoL02028R8P0WIfM075aL@1aLG40HV9R038b<P1EEED0HF5Q0P0i>CT01@0Z:RX0d=3@0;Fe
]@2e]KD0/k>c0080d];B00@0f=SH0=;BdP37alL0^KVi0P28R8P0102@T900`<300=OGe`1]KFd2069R
HP05051@D01cLg<0OWin09nOW`2EUID00P2i^KT0102c/k<0b<S80=SHf03Hf=P20<o?c`040<[:bP2l
_;`0[:b/09FEU@80R8R800D0T92@09nOW`1UIFD0bl_;0>WYj@0206i^KP0406m_K`1RHV80QHF505UI
F@80X:2P00<0LG5a06MWI`28R8P00`2YZJT01@2c/k<0/K6a0:^[Z`2SXj<0XJ6Q0080R8R800@0NGUi
06a/K01DE5@0BDU90P0b<S80100;2`/07alO05EEE@1NGUh204E5A@0506a/K028R8P0QXJ606a/K01j
NWX00P1aLG400`2a/K40D51@09FEU@030:j^[Pl0moOg00<0m?Cd0?Ogm`0000004000000V0?oooa40
000000@0b<S80<;2`P38b<P0`/;20P2o_kl0102j^[X0]KFe0;fm_@2_[jl20;6a/@030:b/[02ZZZX0
XJ6Q0080XJ6Q0P2IVIT0102DU9@0PH6108V9R@1kNg/207=cL`03075aL@2@T900VIVI00@0Xj>S0P2Y
ZJT00`2a/K40]KFe0;6a/@030;6a/@030;Fe]@2a/K40]kNg0080]kNg00<0_Kfm0<30`030`<000P38
b<P20<[:bP030<g=c@3Bd]80clo?00<0cLg=00<0alO70;Jf]P2OWil00P1lO7`0101aLG40:2PX05AD
E01aLG420:VYZ@040;bl_030`<00T92@07alO0<0_;bl00@0^[Zj0;bl_02l_;`0^[Zj102c/k<01`2f
][H0^[Zj0;Ng]`2g]kL0/k>c0;Zj^P2c/k<00P2a/K420:>SX`040:6QX@2EUID0O7al07alO080QXJ6
00@0Jf][05iNGP1EEED0EEEE0P15ADD01@0b<S80GUiN08J6QP2YZJT0];Bd0080Ph>300<0NWYj06MW
I`29RHT04P00000N0?ooo`00703oool?000000<0moOg00<0oooo0?Cdm021PH400P1DE5@00`1;Bd/0
<S8b05EEE@0305EEE@05065QH@3@d=00[:b/0:JVYP2c/k<00P39bLT0103?cll0b/[:0;Jf]P2EUID2
06m_K`0403Hf=P2GUiL0]kNg07MgM`80/k>c00D030`<06i^KP12@T80Kfm_08R8R00209FEU@040;bl
_03=cLd0f=SH0=SHf080dm?C00@0b/[:0;no_`2j^[X0UIFE0P2=SHd01@1aLG40SHf=09FEU@1/K6`0
`/;20080D51@00@0_Kfm00`<301WIfL0D51@0P2PX:00100X:2P0Cdm?07alO02=SHd209FEU@030:VY
Z@2[Zj/0ZJVY0080UIFE0P2>SXh0101iNGT0HF5Q05EEE@1ADE4201lO7`0401LG5`0O7al0:RXZ05EE
E@80BDU900D0NGUi075aL@1jNWX0NWYj0861P@02075aL@040:^[Z`1@D500SHf=0:>SX`80a/K64@3g
moLA000002H0oooo4@0000001038b<P0`/;20<;2`P32`/820;fm_@030;Fe]@2m_Kd0[jn_00<0[jn_
00@0[:b/0:NWY`2UYJD0XJ6Q0`2IVIT208b<S00807YjNP26QXH0Ng]k07]kN`1aLG40IVIV09BDU02Q
XJ4209VIV@@0Xj>S1`2/[:`20;6a/@80]KFe00<0^[Zj0<30`030`<000`30`<000`3:b/X0cLg=0<g=
c@040<[:bP080;Jf]P2ZZZX0R8R808R8R01WIfL0Cdm?05=CD`2=SHd20;6a/@040;bl_031`L40QXJ6
07alO0@0/k>c00<0/K6a0;Ng]`2c/k<00P2c/k<60;6a/@050;Zj^P2a/K40/k>c0:b/[02YZJT00`2E
UID208f=S@05069RHP1OGel0GemO06][J`1JFUX00P1FEUH204E5A@05038b<P1/K6`0WinO0:VYZ@26
QXH00P1bLW800`1RHV80NWYj09fMW@0B000001h0oooo000L0?ooo`l000000`3gmoL00`2BTY80b<S8
08J6QP0206m_K`0405=CD`19BDT0EEEE05EEE@80HF5Q00D0SHf=0<30`02VYZH0Xj>S0;6a/@020<g=
c@040<o?c`2l_;`0ZZZZ092@T080BDU90P1QHF402@0l?3`08b<S03Hf=P0f=SH0EEEE06MWI`1QHF40
O7al09FEU@020;Ng]`040<;2`P3Cdm<0dm?C0=SHf080dm?C00@0b/[:0<;2`P2l_;`0[:b/0P2EUID0
0`2@T900NGUi06m_K`0208^;R`80=SHf00@0:RXZ03Hf=P0f=SH0BDU90P0l?3`0101DE5@0De=C07al
O026QXH208R8R00509VIV@2SXj<0Xj>S09FEU@28R8P00P21PH40101QHF40GUiN05iNGP19BDT203dm
?@0401lO7`0f=SH0?Cdm03dm?@80BDU900D0K6a/07UiN@1/K6`0IVIV0861P@0207UiN@040:^[Z`1T
I6@0SHf=0:6QX@80i^KV4@3gmoLA000002H0oooo4@000000102m_Kd0`/;20;fm_@2o_kl20<30`004
0;Zj^P2_[jl0_Kfm0:n_[`80]KFe00<0[:b/0:>SX`2QXJ40102IVIT0102<S8`0RHV90861P@1kNg/3
07=cL`03075aL@1VIVH0U9BD00@0VIVI0`2SXj<30:b/[0030:NWY`2/[:`0[:b/00<0[:b/00<0/K6a
0;Fe]@2g]kL00P2g]kL00`30`<00_;bl0<O7a`020<[:bP80cLg=00@0b/[:0<g=c@31`L40_kno0P2[
Zj/01028R8P0O7al07alO02=SHd20;Fe]@050;bl_02c/k<0O7al09FEU@2a/K400P2YZJT00`2a/K40
/k>c0;6a/@040;6a/@030:^[Z`2a/K40/K6a0080/K6a00<0ZJVY0:>SX`2[Zj/0102EUID208R8R008
09FEU@1[Jf/0Jf][06][J`1JFUX0GUiN06ATI01EEED205ADE00504U9B@1iNGT0SHf=0:JVYP1WIfL0
0P1_Kfl00`1WIfL0Ph>309nOW`0B000001h0oooo000L0?ooo`l000000`3gmoL00`2BTY80b<S808J6
QP0206m_K`0405=CD`19BDT0EEEE05EEE@80HF5Q00D0SHf=0<30`02VYZH0Xj>S0;6a/@020<g=c@04
0<o?c`2l_;`0ZZZZ092@T080BDU90P1QHF402@0l?3`08b<S03Hf=P0f=SH0EEEE06MWI`1QHF40O7al
09FEU@020;Ng]`040<;2`P3Cdm<0dm?C0=SHf080dm?C00@0b/[:0<;2`P2l_;`0[:b/0P2EUID00`2@
T900NGUi06m_K`0208^;R`80=SHf00@0:RXZ03Hf=P0f=SH0BDU90P0l?3`0101DE5@0De=C07alO026
QXH208R8R00509VIV@2SXj<0Xj>S09FEU@28R8P00P21PH40101QHF40GUiN05iNGP19BDT203dm?@04
01lO7`0f=SH0?Cdm03dm?@80BDU900D0K6a/07UiN@1/K6`0IVIV0861P@0207UiN@040:^[Z`1TI6@0
SHf=0:6QX@80i^KV4@3gmoLA000002H0oooo4@000000102m_Kd0`/;20;fm_@2o_kl20<30`0040;Zj
^P2_[jl0_Kfm0:n_[`80]KFe00<0[:b/0:>SX`2QXJ40102IVIT0102<S8`0RHV90861P@1kNg/307=c
L`03075aL@1VIVH0U9BD00@0VIVI0`2SXj<30:b/[0030:NWY`2/[:`0[:b/00<0[:b/00<0/K6a0;Fe
]@2g]kL00P2g]kL00`30`<00_;bl0<O7a`020<[:bP80cLg=00@0b/[:0<g=c@31`L40_kno0P2[Zj/0
1028R8P0O7al07alO02=SHd20;Fe]@050;bl_02c/k<0O7al09FEU@2a/K400P2YZJT00`2a/K40/k>c
0;6a/@040;6a/@030:^[Z`2a/K40/K6a0080/K6a00<0ZJVY0:>SX`2[Zj/0102EUID208R8R00809FE
U@1[Jf/0Jf][06][J`1JFUX0GUiN06ATI01EEED205ADE00504U9B@1iNGT0SHf=0:JVYP1WIfL00P1_
Kfl00`1WIfL0Ph>309nOW`0B000001h0oooo000L0?ooo`l000000`3gmoL00`1iNGT0X:2P09ZJVP02
05iNGP0404U9B@1RHV80EEEE04U9B@80EEEE00D0SXj>0;Fe]@2SXj<0Xj>S0;6a/@020<g=c@040<W9
b@37alL0`L710;>c/`80UIFE00<0NWYj069RHP1CDe<00`1CDe<01@1EEED0Kfm_092@T02YZJT0_;bl
00<0b/[:00<0dm?C0=SHf03Hf=P00P3Cdm<20<[:bP090<S8b02j^[X0[:b/0:b/[02SXj<0UIFE08R8
R01OGel0O7al0080Ph>300@0NWYj065QH@16ATH0?3`l0P19BDT0101aLG40SHf=08f=S@2@T90209VI
V@80Xj>S00<0UIFE09VIV@2=SHd00P1jNWX0101QHF40GUiN05EEE@1EEED204E5A@0402XZ:P0f=SH0
<S8b038b<P80ADE500D0LG5a0861P@1aLG40IVIV0861P@0208f=S@040:^[Z`1/K6`0SHf=0:VYZ@80
k>c/4@3gmoLA000002H0oooo4@000000102m_Kd0_kno0;Zj^P2m_Kd40;Zj^P030:n_[`2e]KD0ZZZZ
00<0ZZZZ00<0XJ6Q09VIV@2IVIT00P2>SXh0102<S8`0PH6108J6QP21PH4207YjNP0406a/K01aLG40
GUiN07YjNP80SXj>00@0T92@09fMW@2IVIT0XJ6Q102SXj<00`2/[:`0Xj>S0:>SX`020:>SX`80[:b/
00T0/K6a0;Fe]@2e]KD0]KFe0;Ng]`2l_;`0`<300<71`@3:b/X00P37alL0103:b/X0alO70<71`@31
`L420;>c/`040:VYZ@2=SHd0QXJ6092@T0<0/k>c00@0[:b/07YjNP2OWil0Zj^[0P2YZJT00`2[Zj/0
[:b/0:^[Z`030:^[Z`80/K6a00H0ZJVY0:^[Z`2/[:`0[:b/0:VYZ@2[Zj/20:>SX`0409FEU@2=SHd0
SHf=08J6QP80PH6100L0Kfm_07YjNP1jNWX0EUIF06IVIP1NGUh0E5AD0080K6a/00D0GUiN07alO02E
UID0O7al07QhN00206][J`0305ADE02MWId0VYZJ018000007P3oool001`0oooo4@000000103gmoL0
i^KV08V9R@1[Jf/204U9B@0404E5A@19BDT0BDU903dm?@80K6a/00D0SXj>09VIV@2OWil0UIFE0:^[
Z`020<W9b@80clo?00P0f=SH0=;BdP3:b/X0b/[:0<g=c@31`L40_;bl0;Vi^@80_;bl00D0`L710;bl
_02SXj<0[:b/0;Ng]`020<S8b0030=SHf03Cdm<0f=SH00<0f=SH00@0dm?C0<g=c@3:b/X0^[Zj0P2Q
XJ401@2WYjL0UIFE0:VYZ@2[Zj/0ZJVY00@0UIFE00<0VIVI0:>SX`2YZJT00P2YZJT00`2a/K40]KFe
0;>c/`020:^[Z`050:VYZ@2SXj<0VIVI092@T02=SHd00P21PH400`1QHF40HV9R05EEE@0303dm?@04
02XZ:P0f=SH0BDU904E5A@80?Cdm00D0K6a/08f=S@1/K6`0IVIV08b<S00209FEU@040;>c/`1aLG40
UIFE0=gMg@80oooo403gmoLB000002H0oooo4@0000001032`/80_Kfm0;fm_@2m_Kd30;Zj^P030;fm
_@2e]KD0[jn_0080[:b/00D0ZZZZ0:>SX`2QXJ40VIVI08j>SP0208b<S0040861P@26QXH0PH6107]k
N`80Lg=c00<0LG5a065QH@1VIVH00`1NGUh0102<S8`0SXj>09VIV@2SXj<30:6QX@0309fMW@2QXJ40
XJ6Q00D0Xj>S00P0YjNW0:b/[02a/K40/K6a0;Fe]@2c/k<0^[Zj0;bl_0@0`L7100<0alO70<71`@2f
][H00P2c/k<0102YZJT0UIFE08R8R02IVIT20:^[Z`040:VYZ@2EUID0R8R809FEU@<0Xj>S202YZJT0
202[Zj/0Xj>S0:b/[02/[:`0ZJVY09FEU@2YZJT0VIVI0`28R8P01026QXH0K6a/08J6QP1iNGT207Qh
N00404U9B@1TI6@0EEEE05ADE080FUYJ00D0PH6108f=S@2h^;P0NWYj06][J`0204m?C`0307alO02O
Wil0RHV9018000007P3oool001`0oooo4@0000020?ooo`0404E5A@1NGUh0<S8b038b<P80?Cdm00T0
I6AT038b<P1NGUh0GUiN07YjNP2MWId0VIVI08f=S@2YZJT00P3?cll00`31`L40dm?C0=SHf0060=SH
f0080;Fe]@2@T900T92@07alO01aLG40NWYj0;bl_038b<P40=SHf0030>3Ph03Hf=P0f=SH0080f=SH
00<0dm?C0=SHf032`/800P2g]kL01@2@T900LG5a075aL@1jNWX0SHf=0080`L7100<0alO70<[:bP37
alL00`31`L430;bl_0080;>c/`2YZJT0ZJVY09FEU@26QXH0VIVI08f=S@21PH4207UiN@0406a/K01N
GUh0E5AD05EEE@80<S8b0P0Z:RX02@0f=SH09bLW04U9B@19BDT0GUiN07UiN@1/K6`0I6AT096AT@02
09FEU@040;no_`1jNWX0WinO0>WYjA80moOg4P00000V0?oooa40000000<0`/;20;fm_@2j^[X01@2j
^[X20;6a/@80ZZZZ00@0XJ6Q0:>SX`2QXJ40U9BD0`2>SXh00`21PH40Ng]k07]kN`03075aL@0406AT
I01VIVH0EEEE05ADE080CTi>00@0Bd];0861P@2<S8`0SXj>1@2IVIT00`2MWId0XJ6Q0:6QX@020:6Q
X@0309VIV@2MWId0YjNW0080[:b/00<0ZJVY0:b/[02a/K400P2c/k<30<71`@030;Rh^02o_kl0][Jf
0080][Jf00@0/k>c0:VYZ@2IVIT0Xj>S0P2YZJT01@2EUID0NWYj09FEU@2IVIT0ZJVY00<0Xj>S00<0
UIFE0:>SX`2EUID00P2EUID0102OWil0ZJVY09VIV@2SXj<209VIV@0408f=S@2EUID0SHf=08R8R0<0
NGUi00@0NWYj069RHP1jNWX0Kfm_0P1WIfL00`1?Cdl0K6a/055AD@03069RHP0509FEU@2OWil0WIfM
07YjNP1JFUX00P1EEED00`26QXH0SHf=09nOW`0B000001h0oooo000L0?oooa40000000@0jNWY0?oo
o`0m?Cd0Bd];0P0b<S80100m?Cd0BDU905EEE@19BDT206IVIP0507EeM@21PH40SHf=092@T02OWil0
0P3:b/X00`36a/H0_kno0<g=c@040=SHf0030=3@d028R8P0O7al0080Kfm_00<0NWYj0:VYZ@38b<P0
0P3Cdm<20=SHf0030>3Ph03Hf=P0h>3P00D0f=SH0P3Cdm<20<S8b0050;Ng]`2=SHd0HF5Q05EEE@1Q
HF400P1jNWX00`2/[:`0^KVi0<O7a`030<[:bP040<30`031`L40/k>c0:b/[080UIFE00D0NWYj09VI
V@2=SHd0R8R807UiN@0306a/K00305iNGP0m?Cd0?Cdm0080:RXZ00@0<S8b02XZ:P0W9bL0Cdm?0P1J
FUX0101[Jf/0NWYj075aL@1NGUh308f=S@030:j^[P2EUID0WinO01<0moOg4P00000V0?oooa400000
00@0`/;20;Zj^P2j^[X0_Kfm0P2j^[X20;Fe]@040:n_[`2a/K40Xj>S0:>SX`80XJ6Q0P2DU9@308b<
S00407YjNP1cLg<0Lg=c06a/K080IVIV00@0GUiN051@D01DE5@0DE5A0P1;Bd/01@0m?Cd0BDU907Ui
N@21PH40SXj>00@0VIVI00@0T92@09VIV@2@T900T92@0P2IVIT01`2MWId0VIVI0:6QX@2QXJ40[:b/
0:>SX`2YZJT00P2a/K420;>c/`030;Jf]P2o_kl0_kno00<0][Jf00<0/K6a0:^[Z`2SXj<00`2SXj<0
1026QXH0VIVI09FEU@2QXJ4309FEU@040:6QX@2IVIT0VIVI09VIV@80XJ6Q00<0Xj>S09FEU@2IVIT0
1@2=SHd207alO007075aL@1jNWX0NWYj075aL@1_Kfl0O7al075aL@0206m_K`04069RHP1TI6@0GUiN
07YjNP80PH6100D0R8R80<K6aP2JVYX0GUiN05IFEP0206m_K`80PH6100<0h>3P0000000000004000
000N0?ooo`00703ooolA000000040:j^[P3oool0E5AD04E5A@<0BDU900<0<S8b05EEE@1;Bd/00P1N
GUh2065QH@0307alO028R8P0WinO0080bLW900@0d];B09FEU@2OWil0ZJVY0P2SXj<0102MWId0NWYj
07UiN@2SXj<20=?Cd`80f=SH1`3Ph>070=SHf0@0dm?C00@0cLg=0;bl_02YZJT0SHf=0P1_Kfl0101N
GUh0LG5a075aL@29RHT208f=S@04092@T026QXH0O7al07YjNP80R8R80P2EUID00`2MWId0SHf=07Ui
N@0306a/K00305EEE@1/K6`07alO00<0ADE500<0?Cdm02XZ:P0S8b<00P1OGel01@1/K6`0NGUi06a/
K01TI6@0SHf=0080XJ6Q00<0R8R807=cL`3;bl/04`3gmoLB000002H0oooo4P0000000`32`/80^[Zj
0;Fe]@040;Fe]@040:b/[02WYjL0XJ6Q0:6QX@80VIVI00<0U9BD08j>SP21PH400`1kNg/00`1cLg<0
I6AT05EEE@0204a<C004055AD@1;Bd/0?Cdm04E5A@80?Cdm00D0>CTi02XZ:P0m?Cd0GUiN075aL@03
0861P@80SXj>00<0RHV908j>SP2>SXh00`2>SXh3092@T00409VIV@2QXJ40Xj>S0:>SX`<0ZJVY0P2a
/K400`2c/k<0/K6a0:^[Z`020:^[Z`030:VYZ@2SXj<0UIFE00<0VIVI00@0SHf=09fMW@2IVIT0SHf=
0P2EUID0102IVIT0T92@08f=S@2@T90208f=S@80R8R80P2=SHd208R8R00507alO01iNGT0K6a/075a
L@1TI6@00P1/K6`0101NGUh0Jf][069RHP1_Kfl207alO00405EEE@1TI6@0LG5a07YjNP80WinO00D0
UIFE09:BTP26QXH0ADE5069RHP0207QhN0030861P@2YZJT00000018000007P3oool001`0oooo4@00
0000102^[Zh0oooo05ADE015ADD304U9B@03038b<P1EEED0Bd];0080GUiN0P1QHF400`1lO7`0R8R8
09nOW`020<W9b@040=;BdP2EUID0WinO0:VYZ@80Xj>S00@0WIfM07YjNP1iNGT0Xj>S0P3Cdm<20=SH
f0L0h>3P1`3Hf=P40=?Cd`040<g=c@2l_;`0ZJVY08f=S@80Kfm_00@0GUiN075aL@1aLG40RHV90P2=
SHd0102@T900QXJ607alO01jNWX208R8R080UIFE00<0WIfM08f=S@1iNGT00`1/K6`00`1EEED0K6a/
01lO7`0304E5A@0303dm?@0Z:RX08b<S0080GemO00D0K6a/07UiN@1/K6`0I6AT08f=S@020:6QX@03
08R8R01cLg<0bl_;01<0moOg4P00000V0?oooa80000000<0`/;20;Zj^P2e]KD0102e]KD0102/[:`0
YjNW0:6QX@2QXJ4209VIV@0309BDU02>SXh0PH6100<0Ng]k00<0Lg=c06ATI01EEED00P1<C4`0101A
DE40Bd];03dm?@15ADD203dm?@0503Ti>@0Z:RX0?Cdm05iNGP1aLG400`21PH4208j>SP0308V9R@2>
SXh0SXj>00<0SXj>0`2@T900102IVIT0XJ6Q0:>SX`2SXj<30:VYZ@80/K6a00<0/k>c0;6a/@2[Zj/0
0P2[Zj/00`2YZJT0Xj>S09FEU@0309VIV@0408f=S@2MWId0VIVI08f=S@80UIFE00@0VIVI092@T02=
SHd0T92@0P2=SHd208R8R080SHf=0P28R8P01@1lO7`0NGUi06a/K01aLG40I6AT0080K6a/00@0GUiN
06][J`1RHV80Kfm_0P1lO7`0101EEED0I6AT075aL@1jNWX209nOW`0509FEU@2BTY80QXJ604E5A@1R
HV800P1hN7P00`21PH40ZJVY0000000B000001h0oooo000L0?oooa40000000@0YZJV075aL@19BDT0
BDU90P1OGel0101EEED0BDU904U9B@19BDT205EEE@0505iNGP1RHV80LG5a07YjNP2YZJT00P39bLT2
0<o?c`030<[:bP2YZJT0WIfM0080WIfM00<0][Jf0=SHf03Ph>002P3Ph>000`3Shn<0f=SH0=SHf004
0>3Ph0D0f=SH00<0dm?C0=3@d03:b/X00`3:b/X20<O7a`0409nOW`1lO7`0NGUi07UiN@80O7al00T0
UIFE09nOW`2EUID0UIFE09VIV@2QXJ40VIVI08f=S@1iNGT00P1aLG40101iNGT0EEEE03dm?@19BDT2
03dm?@04038b<P0G5aL05aLG01lO7`80HV9R00D0Kfm_05iNGP1jNWX0LG5a09FEU@0209nOW`0306a/
K02=SHd0jNWY01<0moOg4P00000V0?oooa80000000<0`/;20;Zj^P2_[jl00P2e]KD0102_[jl0[:b/
0:NWY`2QXJ42092@T00509:BTP2<S8`0S8b<08f=S@2<S8`00P2BTY80102<S8`0QXJ607]kN`1<C4`2
04Q8B00404E5A@0b<S80?Cdm03dm?@80:RXZ00D09bLW02XZ:P0m?Cd07alO03Hf=P0205ADE004065Q
H@1/K6`0Ng]k07YjNP80PH6100<0NWYj08V9R@21PH400`21PH4208j>SP<0XJ6Q0P2SXj<40:VYZ@80
Zj^[00@0Xj>S09FEU@2EUID0VIVI0P2@T9001@2=SHd0R8R808f=S@2=SHd0PH610080SHf=00@0PH61
08f=S@26QXH0QXJ60P28R8P0101lO7`0R8R807alO01lO7`207UiN@0507YjNP1QHF40I6AT06a/K01J
FUX00P1?Cdl0101JFUX0E5AD069RHP1aLG4206ATI080EEEE00T0QXJ607YjNP2EUID0UIFE0;Bd]02M
WId0QXJ605EEE@26QXH00P2EUID00`1lO7`0moOg0000000B000001h0oooo000L0?oooa80000000<0
K6a/05IFEP19BDT00P1jNWX0101WIfL0EUIF05EEE@19BDT305iNGP04069RHP1iNGT0NGUi0:>SX`80
b/[:00<0cLg=0<o?c`3?cll01P3Hf=P80>3Ph080hn?S0P3Ph>000`3Hf=P0h>3P0>3Ph0020>3Ph0L0
f=SH0P3?cll00`3Cdm<0b/[:0<[:bP020<[:bP080<71`@37alL0alO70<O7a`2l_;`0/k>c0;6a/@2[
Zj/20:>SX`050:VYZ@2EUID0SHf=0861P@1iNGT00P1jNWX0101iNGT0K6a/04U9B@0m?Cd202LW9`<0
5aLG00P07alO08f=S@2=SHd0HV9R05iNGP2QXJ40K6a/0861P@80Zj^[00<0K6a/09nOW`3gmoL04P3g
moLC000002H0oooo4P0000000`32`/80_Kfm0;Fe]@020;Fe]@80[:b/00D0VIVI09BDU02DU9@0U9BD
08j>SP0209VIV@0807]kN`1gMgL0Lg=c07=cL`1VIVH0E5AD05iNGP1kNg/208b<S00408J6QP1/K6`0
EEEE04U9B@80?Cdm00<0>CTi02LW9`0G5aL00P0G5aL202PX:00402LW9`15ADD0BDU905iNGP80HF5Q
0P1aLG4207=cL`<0NGUi00@0NWYj0861P@29RHT0SXj>0P2IVIT0102MWId0XJ6Q09VIV@2OWil209VI
V@030:6QX@2EUID0R8R800<0SHf=00<0PH6107UiN@1iNGT00P1iNGT207YjNP0407UiN@21PH40QXJ6
08J6QP<0LG5a00<0O7al07YjNP1aLG400P1/K6`00`1RHV80EEEE05iNGP0205YJFP80Cdm?00@0EUIF
06][J`1_Kfl0EEEE0P1/K6`0101FEUH0IVIV08J6QP1jNWX20<71`@0509:BTP1jNWX0EUIF07alO02B
TY800P1lO7`00`3oool0moOg0000000B000001h0oooo000L0?oooa80000000<0D51@04m?C`1JFUX0
0P26QXH0101[Jf/0EEEE05YJFP1FEUH305YJFP0405iNGP1jNWX0LG5a0:>SX`80alO70P3?cll00`3B
d]80f=SH0=SHf0020=SHf080h>3P0`3Hf=P30>3Ph0030=SHf03Ph>00h>3P00<0h>3P0P3Hf=P20>3P
h080f=SH00<0h>3P0=SHf03Hf=P0103Hf=P0203@d=00dm?C0<g=c@3=cLd0b/[:0<O7a`31`L40b/[:
0`2l_;`00`2c/k<0ZJVY0:VYZ@030:>SX`80UIFE00<0SHf=07YjNP1iNGT00P1iNGT00`1NGUh0K6a/
04E5A@0302XZ:P0301lO7`0b<S809bLW0080UIFE00D0NWYj05iNGP2EUID0NGUi06a/K0020:j^[P03
06a/K02m_Kd0oooo0180moOg4`00000V0?oooa80000000<0_Kfm0;Zj^P2m_Kd00P2e]KD0102ZZZX0
VIVI0:6QX@2DU9@209NGU`050:>SX`2DU9@0S8b<07=cL`1VIVH00P1DE5@0101;Bd/0EEEE06IVIP1N
GUh204a<C00407UiN@2SXj<0SHf=06ATI080HV9R0P1EEED00`0i>CT0?Cdm01LG5`0200/;2`0301lO
7`0f=SH09bLW00<0=SHf00@0ADE505iNGP1TI6@0GUiN0P1aLG4306a/K080NWYj0P21PH4208j>SP@0
T92@00@0R8R808j>SP21PH40NWYj0P21PH401@1iNGT0K6a/06a/K01aLG40NWYj0080NGUi00@0PH61
07UiN@1lO7`0K6a/0P1[Jf/0101aLG40HV9R075aL@1RHV8205iNGP0505EEE@1JFUX0FUYJ04U9B@1E
EED00P19BDT0101?Cdl0Jf][07alO01JFUX206ATI00405IFEP1/K6`0WinO09nOW`80];Bd00D0GemO
04U9B@1eMGD0PH6107alO00209:BTP030?Ogm`3dm?@00000018000007P3oool001`0oooo4P000000
0`1EEED0IfMW069RHP02075aL@04069RHP1WIfL0HV9R05YJFP80EEEE0P1DE5@00`1/K6`0LG5a092@
T0020;no_`040<g=c@3?cll0clo?0=;BdP@0f=SH0P3Ph>020=SHf0l0h>3P103Hf=P50=?Cd`80b/[:
00@0b<S80<O7a`3:b/X0`L710P2o_kl0102j^[X0/k>c0;6a/@2[Zj/20:VYZ@050:>SX`2QXJ40VIVI
0861P@1iNGT00P21PH40101aLG40K6a/04U9B@0b<S8203dm?@04038b<P0G5aL05aLG01lO7`80UIFE
00D0O7al06a/K02QXJ40Ng]k069RHP0209FEU@0306a/K03dm?@0moOg0180moOg4`00000V0?oooa<0
000000D0^[Zj0;Fe]@2_[jl0[jn_0:ZZZP020:6QX@080:n_[`2QXJ40XJ6Q096AT@21PH40Ng]k075a
L@1NGUh206a/K080IVIV00L0Ng]k08b<S02DU9@0U9BD0861P@1DE5@0PH6100<0VIVI00D0NGUi02XZ
:P1NGUh0BDU903Hf=P0205YJFP0404U9B@0G5aL0:RXZ03dm?@802`/;00@05aLG00/;2`0;2`/0:RXZ
0P19BDT00`1EEED0I6AT06IVIP02065QH@<0K6a/00<0NGUi07YjNP21PH400P1jNWX207UiN@@0HF5Q
0`1/K6`407UiN@04075aL@1/K6`0K6a/06a/K080FUYJ00@0K6a/05iNGP1NGUh0EEEE0P19BDT204E5
A@0305YJFP1?Cdl0EEEE0080BDU900@0IfMW04U9B@1JFUX0IfMW0P1/K6`0101TI6@0[:b/09FEU@2d
];@209fMW@0507MgM`1_Kfl0QXJ607QhN01nOWh00`3gmoLD000001h0oooo000L0?oooa<00000101E
EED0101OGel0HV9R05EEE@1JFUX205EEE@0505YJFP1EEED0NWYj0861P@2EUID00P2l_;`01031`L40
cLg=0=;BdP3Cdm<50=SHf0H0h>3P0P3Hf=P60>3Ph0H0f=SH0P3@d=030=?Cd`030<g=c@3:b/X0b/[:
0080b/[:00<0`<300<71`@2o_kl00P31`L40102l_;`0/K6a0;>c/`2/[:`20:VYZ@0509FEU@2IVIT0
T92@08f=S@21PH400P1iNGT0101/K6`0EEEE04U9B@0f=SH204E5A@0401lO7`0G5aL05aLG038b<P80
LG5a00D0XJ6Q08J6QP2SXj<0PH61075aL@0206ATI0030:b/[03gmoL0moOg0140moOg5000000V0?oo
oa<000000P2e]KD30:ZZZP030;6a/@2m_Kd0/k>c0080VIVI00D0PH6107YjNP1cLg<0IVIV07=cL`02
06a/K00407=cL`1NGUh0C4a<04A4A080IVIV00@0Ng]k09VIV@1/K6`0SHf=0P1iNGT00`2SXj<0ZJVY
08J6QP0205YJFP80BDU900@0E5AD04m?C`19BDT0?3`l0`0S8b<00`0G5aL07alO0000000200H61P04
00/;2`0O7al0ADE504U9B@<0EEEE0P1NGUh00`1/K6`0HF5Q06a/K00206a/K003065QH@1NGUh0GUiN
0080HV9R0P1NGUh205EEE@0506a/K01NGUh0GUiN06a/K01EEED00P1NGUh204U9B@0305IFEP0m?Cd0
=SHf00<0=SHf00D0BDU903Hf=P0b<S80Jf][03Hf=P0203`l?00405IFEP1RHV80?Cdm06a/K080I6AT
00@0Ng]k09FEU@2o_kl0N7Qh0`26QXH20861P@0509FEU@3oool0moOg0?Ogm`3oool05000000N0?oo
o`00703ooolC000000@0EEEE00@0GemO069RHP1EEED0FUYJ0P1EEED01@1JFUX0EEEE07YjNP21PH40
UIFE0080_;bl00@0`L710<g=c@3Bd]80dm?C1@3Hf=P60>3Ph080f=SH1P3Ph>060=SHf080d=3@0`3C
dm<00`3=cLd0b/[:0<[:bP020<[:bP030<30`031`L40_kno0080`L7100@0_;bl0;6a/@2c/k<0[:b/
0P2YZJT01@2EUID0VIVI092@T02=SHd0PH610080NGUi00@0K6a/05EEE@19BDT0=SHf0P15ADD0100O
7al05aLG01LG5`0b<S82075aL@050:6QX@26QXH0Xj>S0861P@1aLG400P1TI6@00`2/[:`0moOg0?Og
m`0A0?Ogma@000009P3ooolC00000080]KFe0`2ZZZX00`2a/K40_Kfm0;>c/`0209VIV@050861P@1j
NWX0Lg=c06IVIP1cLg<00P1/K6`0101cLg<0GUiN04a<C014A4@206IVIP0407]kN`2IVIT0K6a/08f=
S@80NGUi00<0Xj>S0:VYZ@26QXH00P1JFUX204U9B@0405ADE01?Cdl0BDU903`l?0<08b<S00<05aLG
01lO7`0000000P061PH0100;2`/07alO04E5A@19BDT305EEE@80GUiN00<0K6a/065QH@1/K6`00P1/
K6`00`1QHF40GUiN05iNGP02069RHP80GUiN0P1EEED01@1/K6`0GUiN05iNGP1/K6`0EEEE0080GUiN
0P19BDT00`1FEUH0?Cdm03Hf=P0303Hf=P0504U9B@0f=SH0<S8b06][J`0f=SH00P0l?3`0101FEUH0
HV9R03dm?@1/K6`206ATI00407]kN`2EUID0_kno07QhN0<0QXJ60P21PH401@2EUID0oooo0?Ogm`3g
moL0oooo01@000007P3oool001`0oooo4`0000001`1WIfL0EEEE069RHP1RHV80IfMW06][J`1RHV80
0`1JFUX01@1EEED0HV9R075aL@2=SHd0UIFE0080/K6a00<0`L710<o?c`3Bd]801@3Hf=P20>3Ph0<0
f=SH0P3Ph>001@3Hf=P0h>3P0>3Ph03Ph>00f=SH00<0h>3P2@3Hf=P20=?Cd`030<g=c@3:b/X0b/[:
0080b/[:00<0`<300;bl_02l_;`00`2l_;`00`2g]kL0/K6a0:^[Z`020:VYZ@030:>SX`2IVIT0SHf=
0080QXJ60P1lO7`0101/K6`0GUiN03dm?@19BDT202LW9`807alO00T05aLG02<S8`1_Kfl0Kfm_09FE
U@1aLG40UIFE08f=S@21PH400P1TI6@00`3Bd]80moOg0?Ogm`0A0?Ogma@000009P3ooolC00000003
0;Fe]@2m_Kd0[jn_0080[jn_0P2o_kl01@2DU9@0S8b<08b<S01jNWX0Ng]k0080LG5a0`1VIVH0101D
E5@0C4a<04A4A00i>CT203dm?@0403Ti>@1TI6@0WinO07YjNP80GUiN00D0QXJ60;6a/@2EUID0SHf=
075aL@0205YJFP040861P@1EEED0HV9R05YJFP80BDU900@0<S8b02<S8`0G5aL07alO0P0G5aL01@0X
:2P01PH6038b<P0m?Cd0<S8b0080ADE500@0BDU9055AD@1EEED0EEEE0P1NGUh00`1DE5@0EEEE05iN
GP0305EEE@0505ADE00m?Cd0K6a/03dm?@19BDT00P1/K6`204U9B@0503dm?@19BDT0EEEE05EEE@0m
?Cd00`0b<S8203Hf=P05038b<P0f=SH0<S8b01lO7`19BDT00P15ADD00`19BDT0K6a/05EEE@03075a
L@0409FEU@2^[Zh0^;Rh07QhN080Jf][00@0PH6109:BTP1nOWh0oooo0`3gmoL00`3dm?@000000000
000B000001h0oooo000L0?oooa<0000000<0Cdm?05iNGP1[Jf/00P1[Jf/00`1JFUX0HV9R05EEE@02
05IFEP0506][J`1RHV80LG5a08R8R02EUID00P2[Zj/00`31`L40b/[:0=?Cd`030=?Cd`<0f=SH0`3P
h>020=SHf080h>3P0`3Hf=P00`3Ph>00f=SH0=SHf0070=SHf080dm?C00D0f=SH0=?Cd`3Cdm<0b/[:
0=?Cd`020<[:bP80b<S800P0`L710;no_`31`L40`L710;Zj^P2c/k<0/K6a0:^[Z`80ZJVY00<0UIFE
09VIV@2@T9000P26QXH306a/K00305iNGP19BDT0?Cdm00809bLW00@05aLG00/;2`0;2`/0De=C0P1R
HV801@1jNWX0NGUi09nOW`2EUID0[Zj^0080UIFE503gmoLD000002H0oooo500000030;Fe]@030;no
_`2a/K40U9BD00<0SXj>00<0QXJ607=cL`1aLG400P1cLg<205iNGP0404Q8B00i>CT0>CTi02LW9`80
BDU900@09bLW07=cL`1ADE40XJ6Q0P2YZJT01@2@T900IVIV0861P@2YZJT0Xj>S00<0LG5a00<0I6AT
06][J`1EEED00P1DE5@01019BDT0?3`l04U9B@15ADD203Hf=P0502XZ:P0b<S80?Cdm03dm?@0b<S80
0P0i>CT202XZ:P0304E5A@19BDT0BDU90080BDU900<0DE5A04U9B@1EEED00P0m?Cd01@1EEED0?Cdm
01lO7`19BDT0?Cdm0080ADE500@0<S8b03Hf=P19BDT0?Cdm0`0b<S8201lO7`0802<S8`0Z:RX0:RXZ
038b<P0S8b<0:RXZ01LG5`0f=SH2038b<P0406MWI`1/K6`0PH6107YjNP80QXJ600@0Zj^[0;fm_@21
PH40PH610P2OWil00`1/K6`0TY:B0?ooo`020?Ogm`80m?Cd5@00000N0?ooo`00703ooolD00000007
07YjNP1NGUh0GUiN069RHP1OGel0GUiN05YJFP0206IVIP0304E5A@1RHV80O7al0080SHf=0P2YZJT0
102o_kl0b/[:0<o?c`3Cdm<40=SHf080h>3P0P3Hf=P30>3Ph0030=SHf03Ph>00f=SH0080f=SH00<0
h>3P0=SHf03Hf=P02P3Hf=P00`3:b/X0d=3@0<g=c@030<[:bP030<30`038b<P0_;bl0080_;bl0P2c
/k<02@2a/K40Zj^[0:VYZ@2YZJT0UIFE0:6QX@2=SHd0R8R8075aL@0206][J`0405YJFP19BDT0EEEE
038b<P805aLG00@02`/;02<S8`0;2`/0GemO0P1[Jf/01@1/K6`0I6AT09FEU@2EUID0WinO0080gMgM
4`3gmoLE000002H0oooo500000001`2m_Kd0[jn_0:n_[`2_[jl0U9BD09VIV@2>SXh00P2<S8`00`1k
Ng/0Lg=c06ATI00207=cL`80C4a<00@0A4A403dm?@19BDT0<S8b0P0W9bL00`18B4P0>CTi0861P@03
08J6QP050:^[Z`2^[Zh0SHf=05iNGP2EUID00P2=SHd0102OWil0IVIV075aL@1aLG4206a/K00405EE
E@1?Cdl0EEEE02XZ:P80EUIF00<0ADE502XZ:P19BDT01@0m?Cd00`0W9bL05aLG03dm?@0205EEE@04
038b<P0O7al0?Cdm04E5A@80?Cdm00D0<S8b02XZ:P15ADD0?Cdm02LW9`0202XZ:P0403dm?@15ADD0
9bLW02LW9`<05aLG00<07alO02<S8`0O7al00`0O7al0100Z:RX05aLG01XJ6P19BDT20861P@0408R8
R01aLG40QXJ607YjNP80Zj^[00@0alO7069RHP1jNWX0YZJV0P1[Jf/01@2YZJT0moOg0?Ogm`3gmoL0
oooo0080moOg5@00000N0?ooo`00703ooolD000000<0EUIF0P1EEED0101DE5@0FUYJ05EEE@1EEED2
069RHP0307YjNP2=SHd0WinO0080Zj^[00<0_kno0<[:bP3?cll01@3Hf=P20>3Ph080f=SH00<0h>3P
0=SHf03Ph>00103Hf=P00`3Ph>00f=SH0=SHf00:0=SHf0030=3@d03Cdm<0dm?C00@0b/[:00<0`<30
0<S8b02l_;`00P2l_;`0102c/k<0/K6a0;6a/@2a/K420:VYZ@0409nOW`2SXj<0R8R807alO0<0LG5a
00@0K6a/05IFEP0m?Cd0<S8b0`0G5aL00`0S8b<05aLG06][J`0206][J`05075aL@1VIVH0UIFE09nO
W`2[Zj/05@3gmoLE000002H0oooo500000001`2j^[X0_kno0;no_`2SXj<0VIVI0:6QX@2ATI400P2<
S8`01021PH40GUiN07=cL`1VIVH304Q8B00404];B`1^KVh0MGEe075aL@80C4a<00@0IVIV06i^KP1N
GUh0PH610`2GUiL01021PH40Zj^[0:VYZ@1/K6`306IVIP0307UiN@26QXH0I6AT0080EEEE00@0FUYJ
05iNGP1TI6@0IVIV0P1EEED01@19BDT0EEEE04U9B@1EEED0BDU900@0?Cdm0P0b<S8202XZ:P0300/;
2`0G5aL07alO00@0:RXZ00@0<S8b04E5A@0b<S805aLG0P0Z:RX0100b<S807alO01lO7`0G5aL200/;
2`0301LG5`0;2`/051@D00<0:RXZ00D05aLG00`<300;2`/0EUIF04E5A@0206][J`0406m_K`1/K6`0
PH6109FEU@80];Bd0`2MWId00`2EUID0jNWY0>WYj@020?Ogm`030?ooo`3gmoL0moOg0080moOg5@00
000N0?ooo`00703ooolE00000080EEEE00@0BDU905ADE01?Cdl0BDU90P1FEUH01@1RHV80K6a/08J6
QP2=SHd0Xj>S0080[Zj^00@0_kno0<[:bP3Cdm<0d=3@2@3Hf=P40>3Ph0<0f=SH00<0h>3P0=SHf03H
f=P0203Hf=P01@3@d=00dm?C0=?Cd`3Cdm<0b/[:0080dm?C00@0b/[:0<S8b038b<P0`/;20P2l_;`0
102c/k<0/K6a0:^[Z`2a/K430:VYZ@0409FEU@28R8P0R8R807alO080HV9R00<0GUiN03dm?@0b<S80
0`0O7al0100;2`/06QXJ01LG5`1hN7P206][J`0506IVIP1TI6@0WinO0;Bd]03>c/h04`3gmoLG0000
02H0oooo5@0000020:ZZZP<0XJ6Q00@0SXj>0861P@21PH40I6AT0P1/K6`0201VIVH0B4Q8038b<P0b
<S80FUYJ04a<C01ADE40MgMg0`26QXH00`1EEED0LG5a04a<C0020861P@050:6QX@2ZZZX0S8b<0861
P@2QXJ400P2<S8`00`1NGUh0IVIV06a/K00307]kN`0406a/K01EEED0ADE505ADE080GUiN00D0E5AD
05iNGP1TI6@0E5AD055AD@0205EEE@80BDU900@0?Cdm038b<P0Z:RX0:RXZ0P0O7al403Hf=P80:RXZ
00<0?Cdm01LG5`0G5aL00P0O7al201LG5`0301lO7`0;2`/08b<S00808b<S00<06QXJ01lO7`0Z:RX0
0P0G5aL200H61P0308R8R01EEED0O7al0080LG5a00@0O7al08f=S@2=SHd0^;Rh0P2/[:`0102^[Zh0
PH610861P@3YjNT20?ooo`80moOg0P3oool00`3gmoL000000000000E000001h0oooo000L0?oooaD0
00000P1EEED01019BDT0E5AD04m?C`19BDT205IFEP05069RHP1/K6`0QXJ608f=S@2SXj<00P2^[Zh0
102o_kl0b/[:0=?Cd`3@d=090=SHf0@0h>3P0`3Hf=P00`3Ph>00f=SH0=SHf0080=SHf0050=3@d03C
dm<0dm?C0=?Cd`3:b/X00P3Cdm<0103:b/X0b<S80<S8b032`/820;bl_0040;>c/`2a/K40Zj^[0;6a
/@<0ZJVY00@0UIFE08R8R028R8P0O7al0P1RHV800`1NGUh0?Cdm038b<P0301lO7`0400/;2`0J6QX0
5aLG07QhN080Jf][00D0IVIV06ATI02OWil0];Bd0<k>cP0C0?OgmaL000009P3ooolE00000080ZZZZ
0`2QXJ40102>SXh0PH610861P@1TI6@206a/K00806IVIP18B4P0<S8b038b<P1JFUX0C4a<055AD@1g
MgL308J6QP0305EEE@1aLG40C4a<0080PH6100D0XJ6Q0:ZZZP2<S8`0PH610:6QX@0208b<S00305iN
GP1VIVH0K6a/00<0Ng]k00@0K6a/05EEE@15ADD0E5AD0P1NGUh01@1DE5@0GUiN06ATI01DE5@0DE5A
0080EEEE0P19BDT0100m?Cd0<S8b02XZ:P0Z:RX201lO7`@0=SHf0P0Z:RX00`0m?Cd05aLG01LG5`02
01lO7`805aLG00<07alO00/;2`0S8b<00P0S8b<00`0J6QX07alO02XZ:P0201LG5`801PH600<0R8R8
05EEE@1lO7`00P1aLG40101lO7`0SHf=08f=S@2h^;P20:b/[0040:j^[P21PH40PH610>WYj@80oooo
0P3gmoL20?ooo`030?Ogm`000000000001D000007P3oool001`0oooo5@00000305EEE@0305ADE01E
EED0EEEE0080Cdm?00D0EEEE06a/K01lO7`0SHf=09nOW`020;Jf]P040<71`@3:b/X0dm?C0=?Cd`@0
f=SH00<0h>3P0=SHf03Ph>001@3Ph>000`3Hf=P0h>3P0>3Ph0020=SHf0030>3Ph03Hf=P0f=SH00L0
f=SH00D0dm?C0=SHf03Cdm<0d=3@0<g=c@030<[:bP80b<S80`2l_;`0102f][H0/K6a0;6a/@2YZJT2
0:^[Z`80VIVI00<0SHf=07alO01jNWX00P1aLG40101NGUh0=SHf038b<P0O7al202<S8`0401@D500O
7al07alO07alO080R8R800@0GUiN07UiN@2EUID0_kno0`3gmoL00`3dm?@0moOg0?Ogm`0>0?OgmaL0
00009P3ooolE00000080/K6a00@0Xj>S09VIV@2DU9@0PH610P1VIVH01@1kNg/0K6a/05iNGP1VIVH0
E5AD0080KVi^00@0Jf][06IVIP1VIVH0FUYJ0P1ADE40102<S8`0SHf=07MgM`1aLG4206IVIP0509FE
U@2[Zj/0[jn_0:>SX`21PH400P1cLg<0102ATI40PH6105iNGP1DE5@206IVIP0406a/K01aLG40K6a/
06a/K080I6AT00D0E5AD04];B`1DE5@0IVIV06ATI00205iNGP0306a/K01NGUh0GUiN00@0EEEE00<0
:RXZ03dm?@0b<S800P19BDT00`0f=SH09bLW02XZ:P0201LG5`80<S8b0`0G5aL300/;2`805aLG00T0
7alO01LG5`0;2`/02`/;03Hf=P1jNWX0N7Qh07YjNP1aLG400P1/K6`0102=SHd0QXJ60:b/[02h^;P2
0:j^[P0408J6QP3AdM40moOg0?Cdm080oooo0`3gmoL00`3oool0moOg0000000F000001h0oooo000L
0?oooaL0000000@0BDU904m?C`1?Cdl0EEEE0P1FEUH01@1?Cdl0Jf][08J6QP2EUID0ZJVY0080/k>c
00@0b<S80<[:bP3=cLd0clo?0P3Cdm<60=SHf0030>3Ph03Hf=P0h>3P0100f=SH0P3Cdm<00`3=cLd0
dm?C0=3@d0040<[:bP80`L710P2o_kl0102j^[X0/K6a0;6a/@2[Zj/30:>SX`80SHf=00P0O7al075a
L@1RHV80HV9R05EEE@0f=SH0<S8b02<S8`807alO0P0Z:RX0200G5aL0K6a/08J6QP26QXH0K6a/08b<
S02YZJT0dM7A4`3gmoLH000002H0oooo5`000000102UYJD0XJ6Q0861P@1iNGT206a/K005075aL@1J
FUX0GUiN06i^KP1bLW800`25QHD00`26QXH0MgMg07MgM`0207MgM`0408J6QP1^KVh0QXJ608b<S080
Lg=c00<0QXJ608f=S@3=cLd00P2o_kl208b<S00308f=S@1jNWX0I6AT00<0IVIV0`1DE5@02018B4P0
Bd];04];B`1VIVH0GUiN06IVIP1TI6@0IVIV0P1RHV80101NGUh0IVIV05iNGP1DE5@205EEE@0405iN
GP1EEED0?Cdm038b<P80ADE500<09bLW04m?C`0S8b<00P0O7al202LW9`0401lO7`0b<S808b<S05=C
D`80GemO00@0Jf][07QhN01lO7`0K6a/0P1[Jf/01@28R8P0O7al06a/K01/K6`0QXJ60080Xj>S00@0
ZJVY0;>c/`2h^;P0WinO0P3Bd]800`3gmoL0oooo0?Ogm`030?Cdm080moOg00<0m?Cd0?Ogm`000000
5`00000N0?ooo`00703ooolG0000000404m?C`1JFUX0EUIF04m?C`80EUIF00D0FUYJ06][J`1aLG40
UIFE0:j^[P030<71`@030<[:bP3Cdm<0dm?C00H0f=SH0`3Ph>0@0=SHf0@0dm?C0P3=cLd01`3:b/X0
b<S80<S8b038b<P0b/[:0<71`@2o_kl00P2j^[X00`2g]kL0/K6a0;6a/@030:b/[00509VIV@2=SHd0
R8R807UiN@1/K6`00P1NGUh01019BDT0=SHf03Hf=P0Z:RX201lO7`0402XZ:P0G5aL02`/;06][J`80
LG5a00@0K6a/08f=S@2a/K40k>c/4`3gmoLH000002H0oooo5`000000102UYJD0VIVI07YjNP1NGUh2
06a/K005075aL@1VIVH0IVIV07EeM@25QHD00P1bLW8208F5Q@0308J6QP2BTY80QXJ60080QXJ600<0
QHF5075aL@25QHD00P2BTY80101kNg/0S8b<08f=S@3=cLd30;no_`040;>c/`2IVIT0UIFE05EEE@80
Bd];00<0K6a/05iNGP1NGUh0101DE5@0101VIVH0GUiN05iNGP1TI6@205EEE@80GUiN00D0K6a/069R
HP1NGUh0GUiN04E5A@0204U9B@0804E5A@0m?Cd0?Cdm04U9B@1JFUX0GemO069RHP2=SHd309FEU@03
075aL@1_Kfl0HV9R00@0Jf][00<0R8R808J6QP1aLG400P1aLG4206ATI00407UiN@2=SHd0UIFE09FE
U@80_kno00<0_Kfm0?Ogm`3gmoL02@3gmoL00`3oool0moOg0000000G000001h0oooo000L0?oooaP0
00000`1[Jf/305IFEP0406][J`21PH40SHf=0:>SX`80_;bl00@0b<S80<[:bP3:b/X0dm?C0P3?cll0
0`3Cdm<0f=SH0=SHf0060=SHf0030>3Ph03Hf=P0f=SH00D0f=SH0P3Cdm<00`3Hf=P0dm?C0=?Cd`03
0=?Cd`030=SHf03@d=00dm?C00D0b<S800<0`<300<71`@2o_kl00P2j^[X00`2c/k<0^[Zj0:VYZ@03
0:VYZ@80SHf=00<0O7al07YjNP1RHV800P1EEED01015ADD0BDU9038b<P0b<S8201lO7`0401LG5`06
1PH0=SHf08R8R080LG5a00D0Ng]k09VIV@2/[:`0moOg0?Cdm00A0?OgmaT000009P3ooolH00000003
08J6QP1VIVH0Lg=c0080LG5a00@0Lg=c07MgM`1eMGD0MgMg0`25QHD207]kN`0507EeM@1aLG40MGEe
07EeM@2<S8`01@26QXH01@2<S8`0UiNG07]kN`2IVIT0clo?00<0_kno00<0_Kfm096AT@2^[Zh00P2Y
ZJT0101NGUh0:RXZ038b<P1NGUh204U9B@80E5AD00<0EEEE06m_K`1NGUh00P1@D50205iNGP0305EE
E@1NGUh0K6a/0080K6a/00<0NGUi06a/K01aLG400P1/K6`01@1NGUh0Jf][06a/K01_Kfl0HV9R0080
NWYj00@0O7al0:6QX@2EUID0NWYj0P1/K6`00`1aLG40IVIV05iNGP0306a/K00507]kN`21PH40SHf=
09FEU@2^[Zh00P2o_kl00`2m_Kd0kno_0?Ogm`0:0?Ogm`030?ooo`3dm?@0000001P000007P3oool0
01`0oooo600000000`1_Kfl0Jf][05YJFP02069RHP0505mOG`1RHV80NGUi09FEU@2OWil00P2c/k<0
0`38b<P0b/[:0<[:bP030=?Cd`80f=SH00<0dm?C0=SHf03Hf=P03`3Hf=P30=?Cd`80f=SH00<0dm?C
0<[:bP3:b/X00P3:b/X20<S8b0030<[:bP32`/80_;bl00<0_;bl00@0^[Zj0;6a/@2SXj<0Zj^[0`2E
UID0102=SHd0NGUi065QH@1EEED205YJFP0404E5A@0f=SH0=SHf02<S8`80:RXZ00@030`<00H61P1j
NWX0O7al0P1TI6@00`21PH40TI6A0<o?c`0C0?OgmaT000009P3ooolH000000<0QHF50P2BTY800`26
QXH0TY:B08F5Q@0208F5Q@80MgMg00@0QHF5075aL@1aLG40SHf=0P2<S8`0101cLg<0SHf=08f=S@1a
LG4207]kN`0508f=S@1^KVh0S8b<09VIV@1iNGT00P2QXJ401038b<P0_Kfm0:RXZ02m_Kd208b<S004
08f=S@2[Zj/0UIFE07UiN@80LG5a00D0NWYj075aL@1aLG40R8R80:6QX@020:j^[P80WinO00P0UIFE
08R8R026QXH0QXJ608R8R01aLG40NGUi0861P@80SHf=00<0NGUi07YjNP1iNGT0101NGUh0101/K6`0
QXJ6075aL@1iNGT206ATI00406IVIP1TI6@0NGUi08b<S080SHf=00D0VIVI096AT@2h^;P0`L710;fm
_@020?Ogm`030?Cdm03gmoL0moOg00H0moOg00H0m?Cd0?Ogm`3gmoL0m?Cd0?Ogm`3ooolI000001h0
oooo000L0?oooaP0000000<0Kfm_06][J`1JFUX00P1RHV801@1OGel0HV9R07UiN@2EUID0WinO0080
/k>c00<0b<S80<[:bP3:b/X00`3Cdm<20=SHf0030=?Cd`3Hf=P0f=SH00l0f=SH0`3Cdm<20=SHf003
0=?Cd`3:b/X0b/[:0080b/[:0P38b<P00`3:b/X0`/;20;bl_0030;bl_0040;Zj^P2a/K40Xj>S0:^[
Z`<0UIFE00@0SHf=07UiN@1QHF40EEEE0P1JFUX01015ADD0=SHf03Hf=P0S8b<202XZ:P0400`<3006
1PH0NWYj07alO080I6AT00<0PH61096AT@3?cll04`3gmoLI000002H0oooo6000000308F5Q@80TY:B
00<0QXJ609:BTP25QHD00P25QHD207MgM`0408F5Q@1aLG40LG5a08f=S@80S8b<00@0Lg=c08f=S@2=
SHd0LG5a0P1kNg/01@2=SHd0KVi^08b<S02IVIT0NGUi0080XJ6Q00@0b<S80;fm_@2XZ:P0_Kfm0P2<
S8`0102=SHd0Zj^[09FEU@1iNGT2075aL@0507YjNP1aLG40LG5a08R8R02QXJ400P2^[Zh209nOW`08
09FEU@28R8P0QXJ608J6QP28R8P0LG5a07UiN@21PH4208f=S@0307UiN@1jNWX0NGUi00@0GUiN00@0
K6a/08J6QP1aLG40NGUi0P1TI6@0101VIVH0I6AT07UiN@2<S8`208f=S@0509VIV@2ATI40^;Rh0<71
`@2m_Kd00P3gmoL00`3dm?@0moOg0?Ogm`060?Ogm`060?Cdm03gmoL0moOg0?Cdm03gmoL0oooo6@00
000N0?ooo`00703ooolI0000000405EEE@1OGel0Cdm?04m?C`80HV9R00<0NWYj08f=S@2SXj<00P2f
][H01031`L40`<300<[:bP3:b/X20=?Cd`80cLg=0P3Cdm<40=SHf0030=?Cd`3Hf=P0f=SH0080f=SH
00@0dm?C0=SHf03?cll0dm?C0P3Bd]830=?Cd`030<g=c@3:b/X0b/[:00<0b/[:00<0b<S80<[:bP38
b<P00P38b<P00`30`<00_;bl0;bl_0020;bl_080/k>c00T0Zj^[0:>SX`2YZJT0ZJVY08f=S@1lO7`0
K6a/06ATI01NGUh00`1JFUX2038b<P0702XZ:P0G5aL05aLG00/;2`28R8P0N7Qh06a/K00206ATI004
08f=S@2h^;P0jNWY0?Ogm`<0m?Cd3P3gmoLJ000002H0oooo6@00000207EeM@80QXJ6102BTY80102<
S8`0QXJ608J6QP1aLG4307]kN`80S8b<00@0TI6A08J6QP1VIVH0PH610P2=SHd01@1aLG40S8b<08b<
S01eMGD0S8b<0080VIVI00<0Zj^[09VIV@38b<P00`2QXJ40102_[jl0U9BD08f=S@2ATI4208b<S004
08f=S@2OWil0ZJVY0:>SX`<0XJ6Q00@0UIFE09VIV@2SXj<0SHf=0P2EUID01026QXH0NWYj06a/K01a
LG4306a/K004075aL@1/K6`0NWYj0:6QX@80UIFE00@0XJ6Q0:>SX`2EUID0WinO0`2EUID00`2OWil0
UIFE0:VYZ@020;6a/@040:b/[03?cll0jNWY0?Cdm0/0moOg00<0m?Cd0?Ogm`3gmoL00P3gmoL00`3d
m?@000000000000H000001h0oooo000L0?oooaX0000000@0FUYJ07YjNP1jNWX0EUIF0P1jNWX0202=
SHd0WinO0;>c/`2c/k<0_kno0<O7a`3:b/X0b<S80P3:b/X20=?Cd`060=SHf03Cdm<0d];B0=;BdP3H
f=P0dm?C1P3Hf=P20=?Cd`070=SHf03Cdm<0dm?C0<[:bP3Cdm<0b/[:0=?Cd`030<[:bP030<S8b03:
b/X0b/[:00<0b<S800@0_kno0<;2`P2j^[X0^[Zj0P2f][H0102a/K40[:b/09FEU@2SXj<209VIV@05
08R8R01lO7`0LG5a06a/K01JFUX00P19BDT0101?Cdl0Jf][01lO7`0G5aL201XJ6P0405IFEP1EEED0
NWYj06a/K080NGUi00D0UIFE0<71`@3dm?@0moOg0?Cdm0020?ooo`d0moOg6`00000V0?oooaX00000
00L0MGEe08F5Q@25QHD0S8b<09:BTP2<S8`0Z:RX00@0UiNG00<0TY:B08b<S02<S8`00P2<S8`00`2=
SHd0UIFE08f=S@030861P@0307]kN`21PH40Lg=c0080S8b<0P2=SHd0102<S8`0XJ6Q0:^[Z`2ZZZX2
0<g=c@040:6QX@2GUiL0Zj^[0:ZZZP80VIVI00<0UiNG0:6QX@2QXJ400P2QXJ4209FEU@040:6QX@2I
VIT0PH610861P@80Ng]k00<0K6a/07YjNP1VIVH00`1VIVH01@1TI6@0GUiN06ATI01aLG40K6a/0080
NGUi00<0Ng]k0861P@2=SHd00`2EUID0102OWil0];Bd0;no_`3AdM420>c/k0@0moOg00<0oooo0?Og
m`3gmoL00`3gmoL00`3dm?@0oooo0?ooo`060?Ogm`030?ooo`000000000001T000007P3oool001`0
oooo6P00000305EEE@0505mOG`1lO7`0NWYj08f=S@2SXj<00P2c/k<0102f][H0`L710<[:bP38b<P2
0<[:bP040=3@d03:b/X0f=SH0<g=c@T0dm?C00<0f=SH0=3@d03@d=00103:b/X00`30`<00b/[:0<S8
b0050<S8b0040<[:bP38b<P0b<S80<S8b080^[Zj00H0_;bl0;>c/`2c/k<0/k>c0;6a/@2YZJT209FE
U@80R8R800<0NGUi075aL@1TI6@00P1JFUX305EEE@0303Hf=P19BDT0=SHf0080BDU900@0ADE507al
O01aLG40QXJ60P2=SHd0102^[Zh0_Kfm0?Ogm`3oool@0?Ogma/000009P3ooolJ000000<0MGEe00<0
Ng]k09VIV@2BTY800P2QXJ420:RXZ0040:6QX@2SXj<0TY:B0:6QX@80UiNG00@0UIFE0861P@2=SHd0
Xj>S0P2QXJ4208f=S@<0PH610P1kNg/208b<S00508J6QP2ATI40UIFE09FEU@2_[jl00P2o_kl01P2Z
ZZX0/K6a0;6a/@2a/K40[jn_0:^[Z`80XJ6Q0P2SXj<20:6QX@0508f=S@21PH40PH610861P@1jNWX0
0`21PH4208b<S005096AT@2=SHd0SHf=09FEU@21PH400P1/K6`0101RHV80LG5a0861P@2^[Zh209nO
W`030:^[Z`3>c/h0moOg00<0moOg00D0m?Cd0?Ogm`3dm?@0m?Cd0?Ogm`020?Cdm0T0moOg00@0m?Cd
0?Ogm`3gmoL0moOg6`00000N0?ooo`00703ooolK00000080E5AD00D0EUIF05iNGP1aLG40QXJ609FE
U@0209nOW`040;Rh^02l_;`0`L710<S8b080`<300P3@d=020<o?c`80cLg=00D0b/[:0=3@d03Cdm<0
dm?C0=SHf0020<g=c@040<o?c`3:b/X0b/[:0<S8b080`<300P2l_;`0202m_Kd0b<S80<S8b038b<P0
`/;20<30`032`/80_Kfm0`2l_;`00`2a/K40]kNg0;>c/`030:^[Z`040:>SX`2EUID0UIFE08f=S@80
R8R800<0NGUi07YjNP1/K6`00P1?Cdl304U9B@0303`l?015ADD0<S8b0080PH6100@0Jf][075aL@1/
K6`0Xj>S0P2EUID01@2o_kl0moOg0?Ogm`3gmoL0m?Cd00<0moOg00<0oooo0?Ogm`3gmoL0203gmoLL
000002H0oooo6`000002075aL@80QXJ600<0S8b<0:n_[`2IVIT00P2SXj<0102[Zj/0[jn_0:n_[`2_
[jl30:6QX@030:^[Z`2QXJ40UIFE0080UIFE00<0XJ6Q09FEU@2GUiL00P2=SHd207]kN`04096AT@2=
SHd0TI6A09FEU@80TI6A00@0S8b<0861P@21PH40XJ6Q0P31`L420<g=c@030<71`@2[Zj/0ZJVY0080
WinO00@0K6a/055AD@1@D500GUiN0P1JFUX2075aL@0307UiN@2=SHd0UIFE0080UIFE00@0SHf=0:6Q
X@2OWil0Zj^[0P2^[Zh0102EUID0I6AT06ATI02EUID20=gMg@P0moOg00<0m?Cd0?ooo`3gmoL00P3g
moL00`3oool0moOg0?Ogm`050?Ogm`040?Cdm03gmoL0moOg0?Ogma`000007P3oool001`0oooo7@00
00001@1/K6`0EEEE075aL@21PH40SHf=0080Zj^[00<0/k>c0;Jf]P2l_;`00`30`<001038b<P0b/[:
0<O7a`3:b/X20<o?c`<0b/[:00@0cLg=0<[:bP38b<P0b<S80P3:b/X01032`/80_;bl0;Fe]@2e]KD2
0;Ng]`030;Zj^P2m_Kd0]KFe00@0]KFe00H0[:b/0;6a/@2g]kL0]kNg0:VYZ@2a/K420:VYZ@80WinO
00<0XJ6Q09FEU@28R8P00`26QXH01@1jNWX0LG5a05iNGP1JFUX0EUIF0080Cdm?00@0IfMW05IFEP19
BDT0IfMW0P28R8P0101_Kfl0O7al08f=S@2YZJT20;no_`030;fm_@3dm?@0moOg0080moOg0P3oool:
0?Ogmah000009P3ooolM000000050861P@26QXH0SHf=096AT@2[Zj/00P2_[jl0102IVIT0/K6a0;6a
/@2m_Kd20;no_`040:^[Z`2GUiL0XJ6Q0:6QX@80Zj^[00@0SHf=09VIV@2EUID0TI6A0`2=SHd207]k
N`0406a/K01jNWX0TI6A096AT@<0SHf=00P0PH6107]kN`1kNg/0PH6107UiN@2=SHd0TI6A0:^[Z`80
/K6a00@0_Kfm0:n_[`2m_Kd0_Kfm0P2o_kl0102a/K40Zj^[0:^[Z`2[Zj/20;>c/`030;no_`2^[Zh0
R8R800D0K6a/00<0[:b/0=;BdP3gmoL0103gmoL00`3dm?@0moOg0?Ogm`0?0?Ogm`030?Cdm03gmoL0
moOg01h000007P3oool001`0oooo7@0000001@1/K6`0EEEE075aL@21PH40SHf=0080Zj^[00<0/k>c
0;Jf]P2l_;`00`30`<001038b<P0b/[:0<O7a`3:b/X20<o?c`<0b/[:00@0cLg=0<[:bP38b<P0b<S8
0P3:b/X01032`/80_;bl0;Fe]@2e]KD20;Ng]`030;Zj^P2m_Kd0]KFe00@0]KFe00H0[:b/0;6a/@2g
]kL0]kNg0:VYZ@2a/K420:VYZ@80WinO00<0XJ6Q09FEU@28R8P00`26QXH01@1jNWX0LG5a05iNGP1J
FUX0EUIF0080Cdm?00@0IfMW05IFEP19BDT0IfMW0P28R8P0101_Kfl0O7al08f=S@2YZJT20;no_`03
0;fm_@3dm?@0moOg0080moOg0P3oool:0?Ogmah000009P3ooolM000000050861P@26QXH0SHf=096A
T@2[Zj/00P2_[jl0102IVIT0/K6a0;6a/@2m_Kd20;no_`040:^[Z`2GUiL0XJ6Q0:6QX@80Zj^[00@0
SHf=09VIV@2EUID0TI6A0`2=SHd207]kN`0406a/K01jNWX0TI6A096AT@<0SHf=00P0PH6107]kN`1k
Ng/0PH6107UiN@2=SHd0TI6A0:^[Z`80/K6a00@0_Kfm0:n_[`2m_Kd0_Kfm0P2o_kl0102a/K40Zj^[
0:^[Z`2[Zj/20;>c/`030;no_`2^[Zh0R8R800D0K6a/00<0[:b/0=;BdP3gmoL0103gmoL00`3dm?@0
moOg0?Ogm`0?0?Ogm`030?Cdm03gmoL0moOg01h000007P3oool001`0oooo7P000000101[Jf/0HV9R
075aL@1lO7`209FEU@040:^[Z`2o_kl0][Jf0;Rh^0<0_;bl1@3:b/X00`37alL0`L710<71`@020<71
`@80_;bl00@0][Jf0;6a/@2c/k<0/k>c0`2YZJT30:>SX`80XJ6Q00D0YjNW0:>SX`2QXJ40XJ6Q09FE
U@0509VIV@07092@T02=SHd0SHf=09FEU@2=SHd0R8R80861P@0206a/K004069RHP1_Kfl0Jf][05AD
E0<0Jf][00@0BDU9069RHP1/K6`0K6a/0P1aLG40101/K6`0SHf=08J6QP2c/k<20;no_`030>o_k`3g
moL0moOg00d0moOg7`00000V0?oooah000000P1kNg/01@1aLG40SHf=08f=S@2=SHd0UIFE0080Zj^[
0`31`L40102o_kl0`L710:b/[02[Zj/20:6QX@030:n_[`2SXj<0XJ6Q0080PH610P2IVIT00`21PH40
SHf=09FEU@030861P@0406IVIP1/K6`0NGUi08f=S@80PH6100D0Ng]k096AT@1kNg/0LG5a07=cL`02
05iNGP0404a<C01QHF40K6a/05iNGP80IVIV0P1@D5002@1TI6@0K6a/075aL@1aLG40NWYj09FEU@1c
Lg<0SHf=09nOW`020;fm_@030?Cdm03gmoL0moOg00h0moOg0P3oool20?Ogm`030?Cdm03gmoL0moOg
00@0moOg7`00000N0?ooo`00703ooolN00000004069RHP1[Jf/0NWYj08R8R080OWin00@0SHf=09FE
U@2c/k<0^;Rh0P31`L400`38b<P0alO70<71`@030<71`@050;no_`2c/k<0/k>c0:VYZ@2c/k<00P2o
_kl0102[Zj/0[:b/0:VYZ@2[Zj/209FEU@0409nOW`2@T900VIVI08f=S@80Xj>S00@0SHf=09VIV@21
PH40SHf=0`21PH400`2=SHd0QXJ608J6QP0308R8R00407alO02=SHd0UIFE0861P@80QXJ600D0NWYj
07alO01RHV80HV9R06m_K`0207alO00405YJFP0m?Cd0EEEE0861P@80QXJ600@0PH6108f=S@2/[:`0
^;Rh0P2m_Kd80?Ogm`030?Cdm03gmoL0moOg00D0moOg7`00000V0?oooal0000000<0Ng]k075aL@1k
Ng/00P2=SHd0102<S8`0UIFE0:6QX@2^[Zh20:^[Z`040;fm_@3?cll0/K6a0<71`@80Zj^[0P2^[Zh0
0`2QXJ40Zj^[0:^[Z`020:6QX@030861P@1kNg/0SHf=00<0SHf=00@0PH6107UiN@21PH40NGUi0P1a
LG401@1/K6`0GUiN05ADE01@D500Lg=c0080NGUi00@0K6a/05iNGP1EEED0EEEE0P1aLG40102EUID0
SHf=08f=S@2=SHd209FEU@80WinO00<0bl_;0>WYj@3gmoL00P3ooolK0?Ogmb0000007P3oool001`0
oooo7`0000000`1FEUH0LG5a07YjNP02069RHP0308f=S@2OWil0_Kfm00@0bLW90P31`L401@2h^;P0
][Jf0;Jf]P2YZJT0[:b/0080Zj^[00<0ZJVY0:^[Z`2[Zj/00P2YZJT209FEU@<0SHf=00<0R8R808f=
S@28R8P00P1iNGT01@28R8P0QXJ6075aL@1/K6`0R8R80080LG5a00@0QXJ6075aL@1iNGT0O7al0P1j
NWX0101lO7`0HV9R06][J`1_Kfl207UiN@0506m_K`1aLG40Kfm_075aL@1EEED00P1JFUX00`1WIfL0
K6a/075aL@0307YjNP0409FEU@2h^;P0^;Rh09nOW`D0moOg00<0m?Cd0?Ogm`3gmoL02@3gmoLP0000
02H0oooo7`0000000`1gMgL0Ng]k08b<S00209NGU`04096AT@2EUID0UIFE07MgM`80TI6A0P2=SHd0
1@2m_Kd0bLW90<O7a`37alL0_Kfm0080`L7100<0_Kfm0:^[Z`2IVIT00P2IVIT00`2QXJ40Xj>S09nO
W`0208b<S0030861P@2=SHd0QXJ600<0PH6100@0NWYj08J6QP1jNWX0NWYj0`1iNGT0102=SHd0R8R8
09FEU@2OWil20:^[Z`040:j^[P2SXj<0XJ6Q0:VYZ@80gMgM00<0jNWY0?Ogm`3gmoL07`3gmoLP0000
01h0oooo000L0?ooob00000000P0MGEe08J6QP2VYZH0YZJV0:ZZZP2MWId0][Jf0:ZZZP80][Jf0P2m
_Kd02@2f][H0/k>c0:^[Z`2[Zj/0ZJVY0:^[Z`2EUID0WinO0:VYZ@0209nOW`0409FEU@2OWil0UIFE
092@T080QXJ600@0R8R8075aL@2EUID0O7al0P2EUID01@26QXH0O7al08f=S@1jNWX0K6a/0080UIFE
00@0NWYj08R8R01lO7`0NWYj0P21PH401026QXH0GemO06][J`1jNWX207QhN00506MWI`1_Kfl0O7al
06ATI01/K6`00P1TI6@0101/K6`0I6AT075aL@26QXH20:^[Z`040;Bd]02/[:`0[Zj^0=;BdPD0moOg
00<0oooo0?Ogm`3gmoL0203gmoLQ000002H0oooo80000000202ATI40S8b<08f=S@2=SHd0TI6A0861
P@1kNg/0SHf=0P21PH4207]kN`80SHf=0P2[Zj/00`31`L40bLW90<71`@050<71`@030:^[Z`2QXJ40
XJ6Q0080UIFE00@0XJ6Q09FEU@2EUID0PH610P2EUID01@26QXH0NGUi0861P@2EUID0QXJ60080PH61
00@0UIFE0:VYZ@2[Zj/0XJ6Q0P2[Zj/0102^[Zh0a/K60>KViP3/k>`20?ooob40moOg8@00000N0?oo
o`00703ooolQ0000000306][J`21PH40PH610080SHf=00P0WIfM0;Jf]P2h^;P0^;Rh0;>c/`2/[:`0
Zj^[0:j^[P@0WinO00<0SHf=09FEU@2=SHd00P2EUID0102=SHd0UIFE08R8R02EUID207YjNP04075a
L@1nOWh0I6AT0861P@80NWYj00D0SHf=075aL@1lO7`0NWYj07alO00209FEU@04069RHP1aLG40LG5a
08R8R080NWYj0P1[Jf/01P1JFUX0EUIF04U9B@19BDT0Cdm?069RHP80EEEE0`1FEUH0101TI6@0Ng]k
09FEU@2[Zj/20<O7a`0309fMW@2^[Zh0QXJ60100moOg8P00000V0?ooob4000000`2IVIT00`2=SHd0
MgMg08f=S@0508f=S@0807MgM`2EUID0XJ6Q0:6QX@2OWil0UIFE09nOW`2m_Kd40<O7a`80`L710`2o
_kl0102m_Kd0[:b/0:j^[P2/[:`20;no_`050:b/[02m_Kd0/K6a0:j^[P2_[jl00P2[Zj/0102/[:`0
alO70=GEe@3GemL20>WYjBH0moOg8P00000N0?ooo`00703ooolQ0000000306][J`21PH40PH610080
SHf=00P0WIfM0;Jf]P2h^;P0^;Rh0;>c/`2/[:`0Zj^[0:j^[P@0WinO00<0SHf=09FEU@2=SHd00P2E
UID0102=SHd0UIFE08R8R02EUID207YjNP04075aL@1nOWh0I6AT0861P@80NWYj00D0SHf=075aL@1l
O7`0NWYj07alO00209FEU@04069RHP1aLG40LG5a08R8R080NWYj0P1[Jf/01P1JFUX0EUIF04U9B@19
BDT0Cdm?069RHP80EEEE0`1FEUH0101TI6@0Ng]k09FEU@2[Zj/20<O7a`0309fMW@2^[Zh0QXJ60100
moOg8P00000V0?ooob4000000`2IVIT00`2=SHd0MgMg08f=S@0508f=S@0807MgM`2EUID0XJ6Q0:6Q
X@2OWil0UIFE09nOW`2m_Kd40<O7a`80`L710`2o_kl0102m_Kd0[:b/0:j^[P2/[:`20;no_`050:b/
[02m_Kd0/K6a0:j^[P2_[jl00P2[Zj/0102/[:`0alO70=GEe@3GemL20>WYjBH0moOg8P00000N0?oo
o`00703ooolR00000080X:2P00<0WinO0:JVYP2h^;P0102h^;P509nOW`0409FEU@2OWil0UIFE09FE
U@<0R8R800@0UIFE08J6QP1jNWX0O7al0P1TI6@20861P@07069RHP19BDT0O7al07alO01JFUX0QXJ6
07YjNP0207alO080GUiN00@0K6a/07YjNP15ADD0BDU90P1VIVH0101NGUh0FUYJ05iNGP1VIVH206AT
I00506a/K01TI6@0I6AT05EEE@1VIVH00P1/K6`0102/[:`0UIFE0:j^[P2m_Kd2069RHP0409fMW@21
PH40dM7A0?ooo`T0moOg00@0m?Cd0?Ogm`3gmoL0moOg9000000V0?ooob8000000P2EUID20:^[Z`08
0:6QX@2IVIT0UIFE09FEU@26QXH0TI6A08f=S@2SXj<209nOW`050:^[Z`26QXH0UIFE0:6QX@2EUID0
0P2OWil0102QXJ40[:b/0:b/[02h^;P30;fm_@80a/K60`37alL01@36a/H0clo?0=GEe@3MgMd0k>c/
0080kno_0`3gmoL00`3oool0moOg0?Ogm`0T0?Ogmb@000007P3oool001`0oooo9@0000000`21PH40
ZJVY0;Bd]0020;Jf]P040;Rh^02VYZH0UIFE09FEU@80SHf=0P2EUID00`2=SHd0PH6108J6QP0208f=
S@0407alO026QXH0QXJ6069RHP80UIFE00@0NWYj069RHP2EUID0HV9R0P1JFUX01@1lO7`0HV9R069R
HP1[Jf/0FUYJ0080GUiN00@0E5AD04E5A@1EEED0EEEE0P1VIVH0101EEED0EUIF06ATI01NGUh205EE
E@03055AD@1NGUh0LG5a0080QXJ60P2OWil0102EUID0_kno0;Rh^021PH4207YjNP0309fMW@21PH40
moOg00D0moOg00<0m?Cd0?Ogm`3gmoL00P3dm?@20?OgmbH000009P3ooolT00000080Zj^[00<0XJ6Q
096AT@2EUID00P2EUID209nOW`0309FEU@2OWil0WinO0080UIFE00<0WinO0:^[Z`2[Zj/00P2OWil0
102^[Zh0UIFE08f=S@2EUID20;fm_@040>WYj@36a/H0a/K60;Rh^080WinO0P3;bl/00`3/k>`0moOg
0?Ogm`0[0?OgmbD000007P3oool001`0oooo9P000000202BTY80[:b/0;Bd]02d];@0Zj^[0:JVYP1l
O7`0R8R80P21PH4209FEU@0308R8R01eMGD0R8R80080QXJ600@0O7al08f=S@1lO7`0QXJ60P1JFUX0
101aLG40Kfm_069RHP1jNWX205YJFP05069RHP1TI6@0FUYJ05mOG`1JFUX00P1?Cdl305EEE@0604U9
B@15ADD0ADE505EEE@1FEUH0EEEE0`1DE5@00`1RHV80NWYj07YjNP0207YjNP80WinO00@0];Bd07Qh
N01hN7P0PH610P2VYZH0102EUID0jNWY0?Cdm03dm?@30?Ogm`040?Cdm03gmoL0moOg0?Cdm0<0moOg
9`00000V0?ooobH000000P2QXJ420:^[Z`040;Rh^02QXJ40UIFE096AT@@0XJ6Q00<0UIFE09nOW`2Q
XJ400P2ATI40102EUID0Xj>S0<W9b@3MgMd20<_;b`80[:b/00D0_Kfm0=;BdP3;bl/0bl_;0?Cdm00]
0?OgmbL000007P3oool001`0oooo9`0000001`2BTY80^;Rh0;Rh^02h^;P0[:b/07YjNP2=SHd00`1l
O7`00`26QXH0NWYj06m_K`030861P@0406m_K`1lO7`0Kfm_07alO080FUYJ00@0NWYj06a/K01[Jf/0
Cdm?0P19BDT01@1jNWX0Cdm?05IFEP1JFUX0EUIF0080E5AD0P19BDT00`0m?Cd0=SHf04E5A@0304E5
A@0905ADE01/K6`0FUYJ05YJFP1RHV80PH6109nOW`2EUID0`L710080];Bd00@0WIfM08J6QP1[Jf/0
WinO0P1[Jf/0103YjNT0oooo0?ooo`3dm?@90?OgmbP000009P3ooolW000000<0[Zj^00@0_Kfm0:^[
Z`2[Zj/0[:b/0P2^[Zh01@2m_Kd0[:b/0:b/[02h^;P0eMGE0080gMgM00@0i^KV0=OGe`3EeMD0`L71
0P3GemL0103YjNT0^;Rh0<_;b`3dm?@:0?Ogm`030?Cdm03gmoL0moOg0280moOg:000000N0?ooo`00
703ooolX00000080];Bd00@0_Kfm0:b/[01jNWX0Jf][0P2BTY801@1lO7`0SHf=09:BTP26QXH0Jf][
0080PH6100@0NWYj069RHP1lO7`0O7al0P1RHV80101aLG40NWYj06m_K`1WIfL2038b<P0304U9B@1F
EUH0NWYj0080EEEE0P0m?Cd0101EEED0ADE503dm?@0b<S8203Hf=P80<S8b00T0BDU905iNGP21PH40
PH6109FEU@28R8P0UIFE0;Bd]02BTY800P1OGel0101gMgL0QXJ60861P@1/K6`20:VYZ@L0moOg00@0
m?Cd0?Ogm`3oool0moOg:P00000V0?ooobP000000P2[Zj/0102d];@0[Zj^0;fm_@2o_kl20<71`@05
0<_;b`3Vi^H0i^KV0=gMg@3YjNT00P3Vi^H0103YjNT0i^KV0>WYj@3dm?@20=OGe`040;Rh^03gmoL0
moOg0?Ogm`80m?Cd:`3gmoLZ000001h0oooo000L0?ooobP000000P2d];@0102m_Kd0[:b/07YjNP1[
Jf/209:BTP0507alO02=SHd0TY:B08J6QP1[Jf/00P21PH40101jNWX0HV9R07alO01lO7`2069RHP04
075aL@1jNWX0Kfm_06MWI`80<S8b00<0BDU905IFEP1jNWX00P1EEED203dm?@0405EEE@15ADD0?Cdm
038b<P80=SHf0P0b<S802@19BDT0GUiN0861P@21PH40UIFE08R8R02EUID0];Bd09:BTP0205mOG`04
07MgM`26QXH0PH6106a/K080ZJVY1`3gmoL0103dm?@0moOg0?ooo`3gmoLZ000002H0oooo:0000002
0:^[Z`040;Bd]02^[Zh0_Kfm0;no_`80`L7100D0bl_;0>KViP3Vi^H0gMgM0>WYj@020>KViP040>WY
j@3Vi^H0jNWY0?Cdm080emOG00@0^;Rh0?Ogm`3gmoL0moOg0P3dm?@[0?OgmbX000007P3oool001`0
oooo:`0000000`2h^;P0PH6106][J`0207YjNP0508f=S@1_Kfl0Kfm_07alO01WIfL00P1RHV80101e
MGD0Kfm_06MWI`1[Jf/207alO00406m_K`1RHV80NWYj075aL@80IfMW00@0HV9R04U9B@19BDT0GemO
0`1EEED00`1NGUh0E5AD06a/K00305ADE00405iNGP1/K6`0NGUi07alO080SHf=00D0WinO0<K6aP2B
TY80WIfM07YjNP0204U9B@0406m_K`21PH40TY:B09:BTPP0moOg00<0oooo0?Ogm`3dm?@0;000000V
0?ooob/0000000<0_Kfm0=OGe`3_knl00P3Vi^H01@3GemL0i^KV0>WYj@3/k>`0jNWY0080i^KV00@0
gMgM0>KViP3YjNT0jNWY0P3Bd]8_0?Ogmb`000007P3oool001`0oooo;00000002@2h^;P0HV9R06MW
I`1WIfL0N7Qh08J6QP1_Kfl0Jf][05YJFP0305IFEP80HV9R00<0Jf][06m_K`1_Kfl00P1RHV802@1j
NWX0PH61075aL@1aLG40Kfm_05IFEP1jNWX0EEEE05ADE00206m_K`0406][J`1RHV80I6AT06a/K080
NWYj00@0QXJ609nOW`2=SHd0UIFE0P2h^;P01@2MWId0VYZJ08J6QP26QXH0EUIF0080MGEe00@0QXJ6
0861P@1nOWh0oooo0P3gmoL20?ooo`060?Ogm`3dm?@0oooo0?ooo`3dm?@0oooo;@00000V0?ooob`0
000000L0k>c/0=gMg@3Vi^H0i^KV0>WYj@3/k>`0kno_0080i^KV0P3YjNT00`3Vi^H0eMGE0>WYj@04
0?Ogm`80m?Cd00<0moOg0?Cdm03dm?@0:03gmoL]000001h0oooo000L0?ooobh000000`1WIfL20861
P@0406][J`21PH40EEEE05EEE@80FUYJ00P0K6a/06][J`1aLG40LG5a05EEE@1nOWh0LG5a08f=S@80
O7al00<0R8R809:BTP1[Jf/00P1NGUh3075aL@80QXJ60`2=SHd20:VYZ@030:JVYP1lO7`0NWYj0080
NWYj00@0GUiN04E5A@1EEED0O7al0P21PH400`1hN7P0UIFE0?ooo`040?Ogm`80oooo0`3gmoL_0000
02H0oooo;P0000020>o_k`80k>c/00<0jNWY0>c/k03Vi^H00P3Vi^H00`3_knl0moOg0?Cdm0070?Og
m`80m?Cd9P3gmoL_000001h0oooo000L0?oooc40000000@0PH61069RHP23Ph<0Kfm_0P1lO7`0101[
Jf/0EEEE05=CD`19BDT2069RHP0405IFEP1eMGD0LG5a09FEU@80SHf=00D0a/K60<W9b@2h^;P0WinO
0;Jf]P040:^[Z`80alO70P2c/k<0102d];@0QXJ606MWI`1hN7P206][J`0505YJFP1FEUH0HV9R08J6
QP2BTY800P1lO7`0101nOWh0oooo0?Ogm`3gmoL20?ooo`<0moOg<P00000V0?oooc40000000@0i^KV
0>WYj@3dm?@0m?Cd0`3gmoL00`3dm?@0moOg0?Ogm`060?Ogm`80m?Cd2@3gmoL00`3dm?@0moOg0?Og
m`0G0?Ogmc8000007P3oool001`0oooo<`0000002023Ph<0RHV907inOP1nOWh0UIFE0:JVYP1jNWX0
De=C0P1WIfL0101CDe<0Kfm_09:BTP2VYZH209fMW@0508V9R@2m_Kd0`<300;fm_@36a/H00P3EeMD0
0`3Bd]80_Kfm09nOW`0309:BTP0408>3P`1bLW80Kfm_06][J`80Cdm?00D0EEEE06m_K`1hN7P0UIFE
07alO00209:BTP<0moOg00@0m?Cd0?Ogm`3gmoL0moOg=000000V0?oooc<0000000<0k>c/0?Cdm03g
moL0;P3gmoLd000001h0oooo000L0?ooocL0000000@0`<300:VYZ@3Bd]80f=SH0P3_knl0103Vi^H0
f=SH0=;BdP3?cll20;fm_@050<_;b`36a/H0a/K60<K6aP3?cll00P2d];@01026QXH0YZJV08J6QP1h
N7P307YjNP03069RHP1WIfL0E5AD0080O7al00D0QXJ60861P@21PH40O7al0?ooo`030?Ogm`030?oo
o`3dm?@0000003L000009P3ooole000002`0moOg=`00000N0?ooo`00703ooolg000000040<30`02Y
ZJT0d];B0=SHf080kno_00@0i^KV0=SHf03Bd]80clo?0P2m_Kd01@3;bl/0a/K60<K6aP36a/H0clo?
0080];Bd00@0QXJ60:JVYP26QXH0N7Qh0`1jNWX00`1RHV80IfMW05ADE00207alO00508J6QP21PH40
PH6107alO03oool00`3gmoL00`3oool0m?Cd0000000g000002H0oooo=@00000/0?OgmcL000007P3o
ool001`0oooo>P0000001`36a/H0bLW90<W9b@3?cll0bLW90=SHf03MgMd00P3GemL01@3;bl/0d];B
0;Bd]02PX:00_Kfm0080WIfM00@0VYZJ0:2PX01/K6`0NWYj0P1RHV80101WIfL0NWYj08>3P`2MWId2
09nOW`0308f=S@21PH40ZJVY0080moOg0P3dm?@k000002H0oooo>@0000070?Ogm`030?Cdm03gmoL0
moOg0080moOg00<0m?Cd0?Ogm`3gmoL05P3gmoLj000001h0oooo000L0?ooocl0000000T0emOG0=gM
g@3Bd]80d];B0<_;b`30`<00`/;209ZJVP2;Rh/00P2PX:00101hN7P0NWYj06m_K`26QXH2065QH@04
08V9R@2MWId0WinO09ZJVP80RHV900<0WinO0>3Ph0000000?`00000V0?ooocd0000000<0moOg0?Cd
m03gmoL00`3dm?@=0?Ogm`030?Cdm03gmoL0moOg00L0moOg?P00000N0?ooo`00703ooom;00000003
09ZJVP000000000004X000009P3ooom300000140moOgA000000N0?ooo`00703ooonH000002H0oooo
V000000N0?ooo`00703ooonH000002H0ooooV000000N0?ooo`00703ooonH000002H0ooooV000000N
0?ooo`00703ooonH000002H0ooooV000000N0?ooo`00703ooonH000002H0ooooV000000N0?ooo`00
703ooonH000002H0ooooV000000N0?ooo`00703ooonH000002H0ooooV000000N0?ooo`00703ooonH
000002H0ooooV000000N0?ooo`00703ooonH000002H0ooooV000000N0?ooo`00703ooonH000002H0
ooooV000000N0?ooo`00703ooonH000002H0ooooV000000N0?ooo`00703ooonH000002H0ooooV000
000N0?ooo`00703ooonH000002H0ooooV000000N0?ooo`00703ooonH000002H0ooooV000000N0?oo
o`00703ooonH000002H0ooooV000000N0?ooo`00703ooonH000002H0ooooV000000N0?ooo`00703o
oonH000002H0ooooV000000N0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00H`3oool00d000000oooo0?ooo`060?oo
o`03@000003oool0oooo0;80oooo00=000000?ooo`3oool01P3oool00d000000oooo0?ooo`1S0?oo
o`00HP3oool00d000000oooo0?ooo`080?ooo`03@000003oool0oooo0;00oooo00=000000?ooo`3o
ool0203oool00d000000oooo0?ooo`1R0?ooo`00H@3oool00d000000oooo0?ooo`020?ooo`A00000
103oool00d000000oooo0?ooo`2^0?ooo`04@000003oool0oooo0?ooo`A000001@3oool00d000000
oooo0?ooo`1Q0?ooo`00H@3oool00d000000oooo0?ooo`020?ooo`=000001@3oool00d000000oooo
0?ooo`2^0?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3ooom00000103oool00d000000
oooo0?ooo`1Q0?ooo`00H@3oool00d000000oooo0?ooo`040?ooo`03@000003oool0oooo00<0oooo
00=000000?ooo`3oool0[P3oool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo@00000@0
oooo00=000000?ooo`3oool0H@3oool00640oooo00=000000?ooo`3oool00`3oool2@00000D0oooo
00=000000?ooo`3oool0[P3oool00d000000oooo0?ooo`020?ooo`=000001@3oool00d000000oooo
0?ooo`1Q0?ooo`00HP3oool00d000000oooo0?ooo`080?ooo`03@000003oool0oooo0;00oooo00E0
00000?ooo`3oool0oooo@00000060?ooo`03@000003oool0oooo0680oooo001S0?ooo`03@000003o
ool0oooo00H0oooo00=000000?ooo`3oool0/P3oool014000000oooo@000040000050?ooo`03@000
003oool0oooo06<0oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo002;0?ooo`900000K`3oool2@0000980oooo002=0?ooo`03@000003oool0oooo06h0oooo00=0
00000?ooo`3oool0S`3oool007l0oooo0d0000030?ooo`=000000`3oool3@00000D0oooo00=00000
0?ooo`3oool00P3oool00d000000oooo0?ooo`040?ooo`03@000003oool0oooo00L0oooo0T000000
0`3ooom00000@00000020?ooo`90000000<0oooo@000040000000P3oool00d000000oooo0?ooo`02
@0000080oooo0d0000001`3ooom00000@00004000000oooo@000003oool00d0000030?ooo`900000
00H0oooo@000003ooom000000?oood0000020?ooo`9000004P3oool3@00000070?oood000000oooo
@000003ooom000000?ooo`04@0000080oooo0d0000020?ooo`9000000P3oool2@00008T0oooo0020
0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003o
ool0oooo00L0oooo00=000000?oood0000003`3oool01d000000oooo0?ooo`3ooom000000?oood00
00000P3oool00d000000oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oood00
0000103oool014000000oooo0?oood0000020?ooo`05@000003oool0oooo0?oood0000000P3oool2
@00000060?oood000000oooo@000003ooom000005@3oool02D000000oooo0?oood000000oooo@000
003ooom000000?ooo`03@0000080oooo00I000000?ooo`3ooom000000?oood0000060?ooo`03@000
003oool0oooo08H0oooo00200?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo
@00000020?ooo`03@000003oool0oooo00T0oooo00=000000?ooo`3oool03@3oool01d000000oooo
@000003ooom000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom00000
0080oooo00=000000?oood000000103oool014000000oooo0?oood0000020?ooo`05@000003oool0
oooo0?oood0000000P3oool2@00000050?oood000000oooo@000003oool00d00000C0?ooo`08@000
003oool0oooo@000003ooom000000?oood0000030?ooo`04@000003oool0oooo@0000080oooo00=0
00000?oood0000000T0000030?ooo`03@000003oool0oooo08L0oooo00200?ooo`9000000`3oool2
@00000@0oooo0d0000090?ooo`900000403oool2@00000030?oood00001000000080oooo0T000000
0`3ooom00000@0000002@00000<0oooo0T0000020?ooo`=000000P3oool3@0000080oooo14000002
0?ooo`90000000D0oooo@00004000000oooo@00000020?ooo`=000004P3oool2@0000080oooo0T00
00000`3ooom000000?ooo`020?ooo`9000000`3oool3@00000040?oood0000100000@00000<0oooo
0T0000280?ooo`00P03oool014000000oooo0?oood00000C0?ooo`03@000003oool0oooo00l0oooo
0T0000000`3ooom00000@000000E0?ooo`03@000003oool0oooo0<X0oooo001o0?ooo`E000000P3o
ool00d000000oooo0?ooo`0>0?ooo`=000003`3oool2@00000030?oood000010000001@0oooo0T00
000Y0?ooo`03@000003oool0oooo0:00oooo003o0?oooi40oooo003o0?oooi40oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0976966, -0.0500106, 
  0.00550224, 0.00550224}, {{17.75, 190.813}, {389.875, 
  216.813}} -> {-23.5737, -5.11187, 0.839784, 0.419893}, {{208.125, 
  381.188}, {389.875, 216.813}} -> {-91.7241, -10.2237, 0.419893, 
  0.839784}, {{17.75, 190.813}, {199.5, 26.375}} -> {-23.5396, -170.032, 
  0.839457, 0.839457}, {{208.125, 381.188}, {199.5, 
  26.375}} -> {-183.351, -170.032, 0.839457, 0.839457}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Eigen patterns",
  FormatType->InputForm,
  FontFamily->"Times New Roman"]], "Subsubsection",
  FormatType->InputForm],

Cell[TextData[{
  "\t",
  StyleBox[
  "In order to extract the eigen patterns of the images in Fig. 5, we set the \
resolutions of the x- and y-axes to the values of 16 and 16, respectively. \
After rearranging the sample image data into one-dimensional form, we compute \
their eigen patterns. Consequently obtained eigen patterns take a \
one-dimensional form, so that we rearrange the eigen patterns into a \
two-dimensional form. Figure 6 shows the eigen patterns of the monochrome \
image samples in Fig. 5.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
xReso=16;
yReso=16;
resolution=xReso*yReso;
eigen2D=Table[eigenPattern[Flatten[monoSampleWD[[i]]],
\tresolution],{i,4}];\
\>", "Input",
  CellLabel->"In[53]:=",
  FormatType->InputForm],

Cell["\<\
eigen2DG=Table[ListPlot3D[convert2D[eigen2D[[i]],xReso,yReso],
\tPlotRange->All,Mesh->False,Boxed->False,
\tPlotLabel->StringForm[\"`1`\",label[[i]]],
\tDisplayFunction->Identity],{i,4}];\
\>", "Input",
  CellLabel->"In[57]:=",
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[{{eigen2DG[[1]],eigen2DG[[2]]},{eigen2DG[[3]],
\teigen2DG[[4]]}}],PlotLabel->\"Fig.6. Eigen patterns\",
\tImageSize->{400,400}];\
\>", "Input",
  CellLabel->"In[58]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[.5 .82364 -65 0 ]
[.5 .82364 65 12.5625 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.6) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Eigen) show
141.000000 12.812500 moveto
(patterns) show
189.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -11 0 ]
[.5 .82364 11 12.5625 ]
[.18671 .18355 -5.87859 -9 ]
[.18671 .18355 .12141 0 ]
[.40046 .09948 -10.9232 -9 ]
[.40046 .09948 1.07679 0 ]
[.63268 .00821 -10.0892 -9 ]
[.63268 .00821 1.91076 0 ]
[.78828 .12893 0 -6.13096 ]
[.78828 .12893 6 2.86904 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 12 3.00782 ]
[.96661 .40202 0 -5.87517 ]
[.96661 .40202 12 3.12483 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01628 .3142 -18 -2.78382 ]
[.01628 .3142 0 6.21618 ]
[.00819 .36489 -18 -2.82681 ]
[.00819 .36489 0 6.17319 ]
[-0.00016 .41725 -18 -2.87136 ]
[-0.00016 .41725 0 6.12864 ]
[-0.00879 .47136 -18 -2.91756 ]
[-0.00879 .47136 0 6.08244 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.19579 .19302 m
.20033 .19776 L
s
[(5)] .18671 .18355 .95953 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(10)] .40046 .09948 .82054 1 Mshowa
.64007 .01906 m
.64377 .02448 L
s
[(15)] .63268 .00821 .68154 1 Mshowa
.125 Mabswid
.23703 .17687 m
.23971 .17975 L
s
.27893 .16047 m
.28157 .16339 L
s
.32151 .14379 m
.32411 .14675 L
s
.36479 .12685 m
.36734 .12985 L
s
.4535 .09211 m
.45595 .0952 L
s
.49897 .07431 m
.50137 .07743 L
s
.54521 .0562 m
.54755 .05937 L
s
.59224 .03779 m
.59452 .041 L
s
.1552 .20892 m
.15797 .21172 L
s
.11524 .22456 m
.11804 .22733 L
s
.0759 .23997 m
.07874 .24269 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.77594 .1334 m
.76978 .13563 L
s
[(5)] .78828 .12893 -1 .36244 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(10)] .88369 .27502 -1 .3316 Mshowa
.95406 .40586 m
.94779 .40778 L
s
[(15)] .96661 .40202 -1 .30559 Mshowa
.125 Mabswid
.79613 .16428 m
.79242 .1656 L
s
.81573 .19425 m
.81201 .19555 L
s
.83476 .22337 m
.83104 .22465 L
s
.85326 .25166 m
.84953 .25292 L
s
.88871 .30589 m
.88497 .30711 L
s
.90572 .33191 m
.90197 .33311 L
s
.92227 .35722 m
.91851 .3584 L
s
.93838 .38186 m
.93462 .38303 L
s
.75514 .10158 m
.75145 .10294 L
s
.73369 .06877 m
.73001 .07015 L
s
.71157 .03492 m
.70789 .03634 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02854 .30953 m
.03467 .30719 L
s
[(100)] .01628 .3142 1 -0.38137 Mshowa
.02049 .36032 m
.02664 .35803 L
s
[(200)] .00819 .36489 1 -0.37182 Mshowa
.01218 .41278 m
.01835 .41055 L
s
[(300)] -0.00016 .41725 1 -0.36192 Mshowa
.00358 .46701 m
.00977 .46483 L
s
[(400)] -0.00879 .47136 1 -0.35165 Mshowa
.125 Mabswid
.0348 .27005 m
.03847 .26862 L
s
.03325 .27983 m
.03692 .2784 L
s
.03169 .28966 m
.03536 .28825 L
s
.03012 .29956 m
.0338 .29816 L
s
.02695 .31956 m
.03063 .31816 L
s
.02535 .32965 m
.02903 .32826 L
s
.02374 .33981 m
.02743 .33842 L
s
.02212 .35003 m
.02581 .34865 L
s
.01885 .37068 m
.02254 .36931 L
s
.0172 .3811 m
.02089 .37974 L
s
.01554 .39159 m
.01923 .39024 L
s
.01386 .40215 m
.01756 .40081 L
s
.01048 .42349 m
.01419 .42215 L
s
.00877 .43426 m
.01248 .43293 L
s
.00706 .4451 m
.01077 .44378 L
s
.00533 .45602 m
.00904 .45471 L
s
.00183 .47807 m
.00555 .47677 L
s
7e-005 .48921 m
.00379 .48792 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.859 .995 .819 r
.38346 .61252 .40512 .60371 .43939 .59476 .41918 .57408 Mtetra
.659 .727 .899 r
.41918 .57408 .43939 .59476 .47416 .583 .4542 .56386 Mtetra
.668 .747 .909 r
.4542 .56386 .47416 .583 .50935 .57244 .48969 .55259 Mtetra
.664 .741 .908 r
.48969 .55259 .50935 .57244 .54512 .58348 .52564 .54164 Mtetra
.604 .575 .794 r
.52564 .54164 .54512 .58348 .58111 .55092 .56214 .53736 Mtetra
.731 .831 .927 r
.56214 .53736 .58111 .55092 .6234 .74656 .59898 .51929 Mtetra
.592 .417 .613 r
.59898 .51929 .6234 .74656 .65477 .52882 .63638 .5079 Mtetra
.584 .713 .931 r
.63638 .5079 .65477 .52882 .69233 .51755 .6746 .50323 Mtetra
.73 .834 .929 r
.6746 .50323 .69233 .51755 .73041 .50613 .71272 .48463 Mtetra
.664 .741 .908 r
.71272 .48463 .73041 .50613 .76899 .49455 .75168 .47276 Mtetra
.615 .723 .922 r
.75168 .47276 .76899 .49455 .80811 .48282 .79154 .46537 Mtetra
.707 .805 .926 r
.79154 .46537 .80811 .48282 .84775 .47092 .83121 .44853 Mtetra
.664 .741 .908 r
.83121 .44853 .84775 .47092 .88795 .45886 .87181 .43616 Mtetra
.612 .719 .922 r
.87181 .43616 .88795 .45886 .92871 .44664 .91359 .42876 Mtetra
.711 .814 .929 r
.91359 .42876 .92871 .44664 .97086 .44031 .95473 .41089 Mtetra
.669 .654 .826 r
.36283 .58131 .38346 .61252 .41918 .57408 .39792 .56875 Mtetra
.463 0 0 r
.39792 .56875 .41918 .57408 .4542 .56386 .43262 .58592 Mtetra
.809 .955 .62 r
.43262 .58592 .4542 .56386 .48969 .55259 .46955 .53226 Mtetra
.639 .734 .917 r
.46955 .53226 .48969 .55259 .52564 .54164 .5058 .52331 Mtetra
.686 .77 .915 r
.5058 .52331 .52564 .54164 .56214 .53736 .54255 .50966 Mtetra
.661 .683 .86 r
.54255 .50966 .56214 .53736 .59898 .51929 .57979 .49813 Mtetra
.912 .511 .138 r
.57979 .49813 .59898 .51929 .63638 .5079 .621 .60995 Mtetra
0 0 .165 r
.621 .60995 .63638 .5079 .6746 .50323 .6558 .4746 Mtetra
.661 .683 .86 r
.6558 .4746 .6746 .50323 .71272 .48463 .69459 .46259 Mtetra
.664 .741 .908 r
.69459 .46259 .71272 .48463 .75168 .47276 .73392 .45042 Mtetra
.73392 .45042 .75168 .47276 .79154 .46537 .77379 .43807 Mtetra
.639 .691 .882 r
.77379 .43807 .79154 .46537 .83121 .44853 .81448 .42836 Mtetra
.681 .776 .923 r
.81448 .42836 .83121 .44853 .87181 .43616 .85534 .4138 Mtetra
.672 .754 .912 r
.85534 .4138 .87181 .43616 .91359 .42876 .89683 .39998 Mtetra
.662 .697 .872 r
.89683 .39998 .91359 .42876 .95473 .41089 .93903 .38692 Mtetra
.373 .484 .843 r
.34209 .54503 .36283 .58131 .39792 .56875 .37613 .5591 Mtetra
.639 .857 .982 r
.37613 .5591 .39792 .56875 .43262 .58592 .41201 .54752 Mtetra
.76 .661 .753 r
.41201 .54752 .43262 .58592 .46955 .53226 .44892 .51142 Mtetra
.664 .741 .908 r
.44892 .51142 .46955 .53226 .5058 .52331 .48549 .49991 Mtetra
.626 .708 .905 r
.48549 .49991 .5058 .52331 .54255 .50966 .52255 .49193 Mtetra
.507 .725 .97 r
.52255 .49193 .54255 .50966 .57979 .49813 .56027 .49032 Mtetra
.241 .708 .945 r
.56027 .49032 .57979 .49813 .621 .60995 .59882 .49149 Mtetra
.663 .497 .65 r
.59882 .49149 .621 .60995 .6558 .4746 .63685 .45277 Mtetra
.602 .723 .93 r
.63685 .45277 .6558 .4746 .69459 .46259 .67627 .44605 Mtetra
0 .104 .586 r
.67627 .44605 .69459 .46259 .73392 .45042 .71884 .48112 Mtetra
0 0 0 r
.71884 .48112 .73392 .45042 .77379 .43807 .75623 .41858 Mtetra
.487 .704 .966 r
.75623 .41858 .77379 .43807 .81448 .42836 .7982 .4185 Mtetra
.741 .917 .952 r
.7982 .4185 .81448 .42836 .85534 .4138 .83893 .39603 Mtetra
.697 .817 .94 r
.83893 .39603 .85534 .4138 .89683 .39998 .88063 .37903 Mtetra
.523 .711 .957 r
.88063 .37903 .89683 .39998 .93903 .38692 .92475 .37708 Mtetra
.864 .98 .851 r
.31845 .55063 .34209 .54503 .37613 .5591 .35548 .51317 Mtetra
.642 .583 .774 r
.35548 .51317 .37613 .5591 .41201 .54752 .39138 .50169 Mtetra
.486 .502 .799 r
.39138 .50169 .41201 .54752 .44892 .51142 .42717 .51039 Mtetra
.54 .913 .947 r
.42717 .51039 .44892 .51142 .48549 .49991 .46431 .4968 Mtetra
.736 .952 .947 r
.46431 .4968 .48549 .49991 .52255 .49193 .50199 .47465 Mtetra
.741 .805 .903 r
.50199 .47465 .52255 .49193 .56027 .49032 .53996 .45418 Mtetra
.505 .567 .852 r
.53996 .45418 .56027 .49032 .59882 .49149 .57867 .45872 Mtetra
.753 .698 .799 r
.57867 .45872 .59882 .49149 .63685 .45277 .61737 .42943 Mtetra
.322 .577 .933 r
.61737 .42943 .63685 .45277 .67627 .44605 .65784 .43989 Mtetra
.853 .943 .878 r
.65784 .43989 .67627 .44605 .71884 .48112 .69699 .40396 Mtetra
.621 .509 .705 r
.69699 .40396 .71884 .48112 .75623 .41858 .73766 .39096 Mtetra
.126 .412 .859 r
.73766 .39096 .75623 .41858 .7982 .4185 .78195 .41602 Mtetra
.807 .99 .879 r
.78195 .41602 .7982 .4185 .83893 .39603 .82241 .38202 Mtetra
.557 .815 .994 r
.82241 .38202 .83893 .39603 .88063 .37903 .86569 .37379 Mtetra
.669 .956 .947 r
.86569 .37379 .88063 .37903 .92475 .37708 .90813 .35187 Mtetra
.377 .435 .794 r
.29746 .50347 .31845 .55063 .35548 .51317 .33152 .52056 Mtetra
.87 .988 .831 r
.33152 .52056 .35548 .51317 .39138 .50169 .36938 .48009 Mtetra
.209 .537 .925 r
.36938 .48009 .39138 .50169 .42717 .51039 .40522 .49189 Mtetra
.811 .793 .835 r
.40522 .49189 .42717 .51039 .46431 .4968 .44323 .45838 Mtetra
.665 .632 .807 r
.44323 .45838 .46431 .4968 .50199 .47465 .48101 .44379 Mtetra
.517 .613 .887 r
.48101 .44379 .50199 .47465 .53996 .45418 .51924 .44541 Mtetra
.785 .908 .926 r
.51924 .44541 .53996 .45418 .57867 .45872 .55807 .41968 Mtetra
.516 .562 .841 r
.55807 .41968 .57867 .45872 .61737 .42943 .59779 .42341 Mtetra
.742 .944 .948 r
.59779 .42341 .61737 .42943 .65784 .43989 .63756 .40005 Mtetra
.632 .62 .82 r
.63756 .40005 .65784 .43989 .69699 .40396 .67827 .38976 Mtetra
.651 .843 .974 r
.67827 .38976 .69699 .40396 .73766 .39096 .71945 .37596 Mtetra
.337 .692 .981 r
.71945 .37596 .73766 .39096 .78195 .41602 .7625 .37926 Mtetra
.744 .692 .802 r
.7625 .37926 .78195 .41602 .82241 .38202 .80376 .34968 Mtetra
.656 .683 .864 r
.80376 .34968 .82241 .38202 .86569 .37379 .84688 .33624 Mtetra
.721 .683 .813 r
.84688 .33624 .86569 .37379 .90813 .35187 .88931 .31104 Mtetra
.791 .886 .914 r
.27329 .49531 .29746 .50347 .33152 .52056 .31031 .47 Mtetra
.582 .542 .775 r
.31031 .47 .33152 .52056 .36938 .48009 .34634 .46676 Mtetra
.75 .843 .921 r
.34634 .46676 .36938 .48009 .40522 .49189 .38383 .44569 Mtetra
.616 .578 .788 r
.38383 .44569 .40522 .49189 .44323 .45838 .42123 .43748 Mtetra
0 .223 .706 r
.42123 .43748 .44323 .45838 .48101 .44379 .45856 .46382 Mtetra
.822 .965 .643 r
.45856 .46382 .48101 .44379 .51924 .44541 .49803 .40793 Mtetra
.636 .632 .829 r
.49803 .40793 .51924 .44541 .55807 .41968 .53719 .39734 Mtetra
.124 .481 .898 r
.53719 .39734 .55807 .41968 .59779 .42341 .57742 .41379 Mtetra
.884 .897 .834 r
.57742 .41379 .59779 .42341 .63756 .40005 .61722 .36947 Mtetra
.668 .694 .866 r
.61722 .36947 .63756 .40005 .67827 .38976 .65808 .355 Mtetra
.657 .665 .846 r
.65808 .355 .67827 .38976 .71945 .37596 .69957 .34128 Mtetra
.657 .668 .849 r
.69957 .34128 .71945 .37596 .7625 .37926 .74167 .32736 Mtetra
.579 .55 .786 r
.74167 .32736 .7625 .37926 .80376 .34968 .78528 .32381 Mtetra
.531 .683 .935 r
.78528 .32381 .80376 .34968 .84688 .33624 .82998 .32164 Mtetra
.837 .902 .884 r
.82998 .32164 .84688 .33624 .88931 .31104 .87197 .28577 Mtetra
.151 .38 .832 r
.25056 .4598 .27329 .49531 .31031 .47 .28444 .4809 Mtetra
.882 .99 .802 r
.28444 .4809 .31031 .47 .34634 .46676 .32368 .4352 Mtetra
.646 .668 .857 r
.32368 .4352 .34634 .46676 .38383 .44569 .36094 .42404 Mtetra
.643 .748 .926 r
.36094 .42404 .38383 .44569 .42123 .43748 .39874 .41319 Mtetra
.607 .715 .921 r
.39874 .41319 .42123 .43748 .45856 .46382 .43704 .40547 Mtetra
.608 .541 .753 r
.43704 .40547 .45856 .46382 .49803 .40793 .47603 .39667 Mtetra
.782 .888 .921 r
.47603 .39667 .49803 .40793 .53719 .39734 .51575 .37059 Mtetra
.472 .64 .93 r
.51575 .37059 .53719 .39734 .57742 .41379 .556 .37284 Mtetra
.718 .66 .791 r
.556 .37284 .57742 .41379 .61722 .36947 .59661 .34675 Mtetra
.695 .773 .912 r
.59661 .34675 .61722 .36947 .65808 .355 .63782 .32952 Mtetra
.654 .738 .911 r
.63782 .32952 .65808 .355 .69957 .34128 .67978 .31638 Mtetra
.048 .405 .858 r
.67978 .31638 .69957 .34128 .74167 .32736 .72473 .34002 Mtetra
.581 .888 .603 r
.72473 .34002 .74167 .32736 .78528 .32381 .7665 .30013 Mtetra
.726 .791 .904 r
.7665 .30013 .78528 .32381 .82998 .32164 .80987 .27813 Mtetra
.686 .647 .806 r
.80987 .27813 .82998 .32164 .87197 .28577 .85381 .25686 Mtetra
.827 .983 .88 r
.2237 .46436 .25056 .4598 .28444 .4809 .26231 .43067 Mtetra
.669 .594 .762 r
.26231 .43067 .28444 .4809 .32368 .4352 .29993 .41188 Mtetra
.52 .692 .947 r
.29993 .41188 .32368 .4352 .36094 .42404 .33695 .40984 Mtetra
.742 .846 .928 r
.33695 .40984 .36094 .42404 .39874 .41319 .37565 .38874 Mtetra
.668 .739 .903 r
.37565 .38874 .39874 .41319 .43704 .40547 .41445 .37501 Mtetra
.678 .699 .862 r
.41445 .37501 .43704 .40547 .47603 .39667 .45384 .35918 Mtetra
.617 .632 .844 r
.45384 .35918 .47603 .39667 .51575 .37059 .49369 .35029 Mtetra
.44 .697 .975 r
.49369 .35029 .51575 .37059 .556 .37284 .53427 .35088 Mtetra
.671 .776 .929 r
.53427 .35088 .556 .37284 .59661 .34675 .5756 .3359 Mtetra
.767 .912 .938 r
.5756 .3359 .59661 .34675 .63782 .32952 .61721 .31006 Mtetra
.199 .573 .94 r
.61721 .31006 .63782 .32952 .67978 .31638 .66073 .32094 Mtetra
.839 .998 .779 r
.66073 .32094 .67978 .31638 .72473 .34002 .70235 .2746 Mtetra
.629 .545 .741 r
.70235 .2746 .72473 .34002 .7665 .30013 .74597 .25918 Mtetra
.636 .638 .835 r
.74597 .25918 .7665 .30013 .80987 .27813 .79049 .24643 Mtetra
.681 .718 .878 r
.79049 .24643 .80987 .27813 .85381 .25686 .83529 .22859 Mtetra
.6 .565 .786 r
.20106 .41525 .2237 .46436 .26231 .43067 .23748 .40804 Mtetra
.559 .718 .947 r
.23748 .40804 .26231 .43067 .29993 .41188 .27437 .40309 Mtetra
.802 .896 .91 r
.27437 .40309 .29993 .41188 .33695 .40984 .31353 .3747 Mtetra
.558 .62 .87 r
.31353 .3747 .33695 .40984 .37565 .38874 .3515 .37174 Mtetra
.753 .828 .91 r
.3515 .37174 .37565 .38874 .41445 .37501 .39113 .34859 Mtetra
.308 .57 .931 r
.39113 .34859 .41445 .37501 .45384 .35918 .43013 .35785 Mtetra
.845 .97 .878 r
.43013 .35785 .45384 .35918 .49369 .35029 .4711 .32074 Mtetra
.67 .713 .881 r
.4711 .32074 .49369 .35029 .53427 .35088 .51199 .30554 Mtetra
.645 .615 .805 r
.51199 .30554 .53427 .35088 .5756 .3359 .55348 .29108 Mtetra
.533 .562 .831 r
.55348 .29108 .5756 .3359 .61721 .31006 .59595 .29143 Mtetra
.787 .847 .896 r
.59595 .29143 .61721 .31006 .66073 .32094 .63839 .26197 Mtetra
.436 .452 .777 r
.63839 .26197 .66073 .32094 .70235 .2746 .68336 .27675 Mtetra
.827 1 .807 r
.68336 .27675 .70235 .2746 .74597 .25918 .72605 .23293 Mtetra
.673 .762 .917 r
.72605 .23293 .74597 .25918 .79049 .24643 .7708 .21634 Mtetra
.568 .686 .92 r
.7708 .21634 .79049 .24643 .83529 .22859 .81728 .21031 Mtetra
.61 .722 .925 r
.17544 .3909 .20106 .41525 .23748 .40804 .21221 .38243 Mtetra
.692 .737 .886 r
.21221 .38243 .23748 .40804 .27437 .40309 .25031 .36572 Mtetra
.567 .613 .858 r
.25031 .36572 .27437 .40309 .31353 .3747 .28794 .36168 Mtetra
.724 .865 .948 r
.28794 .36168 .31353 .3747 .3515 .37174 .32735 .34169 Mtetra
0 .306 .798 r
.32735 .34169 .3515 .37174 .39113 .34859 .36492 .36659 Mtetra
.872 .985 .705 r
.36492 .36659 .39113 .34859 .43013 .35785 .40719 .30822 Mtetra
.642 .597 .788 r
.40719 .30822 .43013 .35785 .4711 .32074 .44786 .29331 Mtetra
.659 .732 .904 r
.44786 .29331 .4711 .32074 .51199 .30554 .48913 .27915 Mtetra
.489 .674 .946 r
.48913 .27915 .51199 .30554 .55348 .29108 .53107 .27838 Mtetra
.765 .901 .936 r
.53107 .27838 .55348 .29108 .59595 .29143 .57364 .2521 Mtetra
.676 .668 .834 r
.57364 .2521 .59595 .29143 .63839 .26197 .6168 .23336 Mtetra
.663 .737 .905 r
.6168 .23336 .63839 .26197 .68336 .27675 .6607 .21779 Mtetra
.505 .498 .782 r
.6607 .21779 .68336 .27675 .72605 .23293 .70652 .22265 Mtetra
.644 .915 .979 r
.70652 .22265 .72605 .23293 .7708 .21634 .75192 .20365 Mtetra
.812 .936 .912 r
.75192 .20365 .7708 .21634 .81728 .21031 .79661 .16955 Mtetra
.663 .733 .902 r
.1492 .36542 .17544 .3909 .21221 .38243 .18672 .35186 Mtetra
.659 .697 .874 r
.18672 .35186 .21221 .38243 .25031 .36572 .2248 .33809 Mtetra
.662 .722 .893 r
.2248 .33809 .25031 .36572 .28794 .36168 .26345 .32412 Mtetra
.504 .59 .874 r
.26345 .32412 .28794 .36168 .32735 .34169 .30162 .32488 Mtetra
.791 .84 .889 r
.30162 .32488 .32735 .34169 .36492 .36659 .34249 .29555 Mtetra
.617 .524 .726 r
.34249 .29555 .36492 .36659 .40719 .30822 .38291 .28094 Mtetra
.645 .731 .912 r
.38291 .28094 .40719 .30822 .44786 .29331 .42389 .26804 Mtetra
.301 .592 .945 r
.42389 .26804 .44786 .29331 .48913 .27915 .46515 .27597 Mtetra
.854 .968 .871 r
.46515 .27597 .48913 .27915 .53107 .27838 .50795 .23574 Mtetra
.65 .641 .829 r
.50795 .23574 .53107 .27838 .57364 .2521 .55094 .2202 Mtetra
.542 .663 .915 r
.55094 .2202 .57364 .2521 .6168 .23336 .59488 .2162 Mtetra
.731 .868 .945 r
.59488 .2162 .6168 .23336 .6607 .21779 .63913 .1928 Mtetra
.687 .787 .927 r
.63913 .1928 .6607 .21779 .70652 .22265 .68414 .17405 Mtetra
.657 .627 .808 r
.68414 .17405 .70652 .22265 .75192 .20365 .72984 .15553 Mtetra
.564 .582 .831 r
.72984 .15553 .75192 .20365 .79661 .16955 .77741 .1506 Mtetra
.438 .661 .955 r
.12213 .34022 .1492 .36542 .18672 .35186 .15825 .34117 Mtetra
.799 .882 .906 r
.15825 .34117 .18672 .35186 .2248 .33809 .19838 .31214 Mtetra
.664 .741 .908 r
.19838 .31214 .2248 .33809 .26345 .32412 .23736 .29778 Mtetra
.23736 .29778 .26345 .32412 .30162 .32488 .27694 .2832 Mtetra
.581 .609 .845 r
.27694 .2832 .30162 .32488 .34249 .29555 .31657 .27664 Mtetra
.742 .829 .918 r
.31657 .27664 .34249 .29555 .38291 .28094 .35792 .25337 Mtetra
.664 .741 .908 r
.35792 .25337 .38291 .28094 .42389 .26804 .39936 .23811 Mtetra
.662 .726 .896 r
.39936 .23811 .42389 .26804 .46515 .27597 .44144 .2226 Mtetra
.586 .565 .797 r
.44144 .2226 .46515 .27597 .50795 .23574 .48409 .2147 Mtetra
.737 .829 .921 r
.48409 .2147 .50795 .23574 .55094 .2202 .52762 .19086 Mtetra
.664 .741 .908 r
.52762 .19086 .55094 .2202 .59488 .2162 .57175 .17461 Mtetra
.382 .517 .869 r
.57175 .17461 .59488 .2162 .63913 .1928 .61743 .18543 Mtetra
.866 .965 .861 r
.61743 .18543 .63913 .1928 .68414 .17405 .66216 .14131 Mtetra
.662 .726 .896 r
.66216 .14131 .68414 .17405 .72984 .15553 .70847 .12424 Mtetra
.664 .741 .908 r
.70847 .12424 .72984 .15553 .77741 .1506 .75556 .1069 Mtetra
.09432 .31433 .12213 .34022 .15825 .34117 .13248 .3 Mtetra
.648 .639 .828 r
.13248 .3 .15825 .34117 .19838 .31214 .17121 .28546 Mtetra
.639 .734 .918 r
.17121 .28546 .19838 .31214 .23736 .29778 .2103 .27311 Mtetra
.688 .767 .912 r
.2103 .27311 .23736 .29778 .27694 .2832 .25047 .2557 Mtetra
.664 .741 .908 r
.25047 .2557 .27694 .2832 .31657 .27664 .29103 .24047 Mtetra
.614 .664 .875 r
.29103 .24047 .31657 .27664 .35792 .25337 .3319 .22989 Mtetra
.707 .793 .918 r
.3319 .22989 .35792 .25337 .39936 .23811 .37402 .20978 Mtetra
.668 .747 .909 r
.37402 .20978 .39936 .23811 .44144 .2226 .41655 .19334 Mtetra
.561 .702 .935 r
.41655 .19334 .44144 .2226 .48409 .2147 .45953 .18649 Mtetra
.739 .776 .883 r
.45953 .18649 .48409 .2147 .52762 .19086 .50361 .16065 Mtetra
.664 .741 .908 r
.50361 .16065 .52762 .19086 .57175 .17461 .5482 .14391 Mtetra
.5482 .14391 .57175 .17461 .61743 .18543 .59353 .12689 Mtetra
.633 .583 .78 r
.59353 .12689 .61743 .18543 .66216 .14131 .6396 .10959 Mtetra
.664 .741 .908 r
.6396 .10959 .66216 .14131 .70847 .12424 .68645 .092 Mtetra
.68645 .092 .70847 .12424 .75556 .1069 .73408 .07411 Mtetra
.06574 .28771 .09432 .31433 .13248 .3 .10421 .27298 Mtetra
.10421 .27298 .13248 .3 .17121 .28546 .14328 .25802 Mtetra
.659 .74 .91 r
.14328 .25802 .17121 .28546 .2103 .27311 .1829 .24331 Mtetra
.667 .728 .895 r
.1829 .24331 .2103 .27311 .25047 .2557 .22324 .2274 Mtetra
.664 .741 .908 r
.22324 .2274 .25047 .2557 .29103 .24047 .26417 .21173 Mtetra
.582 .713 .933 r
.26417 .21173 .29103 .24047 .3319 .22989 .30521 .20317 Mtetra
.727 .778 .893 r
.30521 .20317 .3319 .22989 .37402 .20978 .34799 .17964 Mtetra
.663 .737 .905 r
.34799 .17964 .37402 .20978 .41655 .19334 .39091 .1632 Mtetra
.664 .741 .908 r
.39091 .1632 .41655 .19334 .45953 .18649 .43453 .1465 Mtetra
.651 .673 .859 r
.43453 .1465 .45953 .18649 .50361 .16065 .47886 .13002 Mtetra
.668 .747 .909 r
.47886 .13002 .50361 .16065 .5482 .14391 .52394 .11227 Mtetra
.664 .741 .908 r
.52394 .11227 .5482 .14391 .59353 .12689 .56976 .09472 Mtetra
.56976 .09472 .59353 .12689 .6396 .10959 .61635 .07688 Mtetra
.591 .71 .926 r
.61635 .07688 .6396 .10959 .68645 .092 .66409 .06625 Mtetra
.728 .825 .925 r
.66409 .06625 .68645 .092 .73408 .07411 .71195 .04079 Mtetra
.664 .741 .908 r
.03634 .26033 .06574 .28771 .10421 .27298 .07513 .24518 Mtetra
.07513 .24518 .10421 .27298 .14328 .25802 .11454 .22979 Mtetra
.11454 .22979 .14328 .25802 .1829 .24331 .15456 .21416 Mtetra
.663 .738 .905 r
.15456 .21416 .1829 .24331 .22324 .2274 .19522 .19828 Mtetra
.664 .741 .908 r
.19522 .19828 .22324 .2274 .26417 .21173 .23652 .18214 Mtetra
.649 .737 .913 r
.23652 .18214 .26417 .21173 .30521 .20317 .27838 .16722 Mtetra
.67 .703 .871 r
.27838 .16722 .30521 .20317 .34799 .17964 .32115 .14909 Mtetra
.664 .741 .908 r
.32115 .14909 .34799 .17964 .39091 .1632 .3645 .13215 Mtetra
.3645 .13215 .39091 .1632 .43453 .1465 .40857 .11494 Mtetra
.635 .731 .917 r
.40857 .11494 .43453 .1465 .47886 .13002 .4533 .10042 Mtetra
.691 .77 .912 r
.4533 .10042 .47886 .13002 .52394 .11227 .49893 .07965 Mtetra
.659 .74 .909 r
.49893 .07965 .52394 .11227 .56976 .09472 .54525 .06205 Mtetra
.668 .747 .909 r
.54525 .06205 .56976 .09472 .61635 .07688 .59236 .04315 Mtetra
.664 .741 .908 r
.59236 .04315 .61635 .07688 .66409 .06625 .64029 .02443 Mtetra
.656 .688 .868 r
.64029 .02443 .66409 .06625 .71195 .04079 .68905 .00539 Mtetra
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.19579 .19302 m
.20033 .19776 L
s
[(5)] .18671 .18355 .95953 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(10)] .40046 .09948 .82054 1 Mshowa
.64007 .01906 m
.64377 .02448 L
s
[(15)] .63268 .00821 .68154 1 Mshowa
.125 Mabswid
.23703 .17687 m
.23971 .17975 L
s
.27893 .16047 m
.28157 .16339 L
s
.32151 .14379 m
.32411 .14675 L
s
.36479 .12685 m
.36734 .12985 L
s
.4535 .09211 m
.45595 .0952 L
s
.49897 .07431 m
.50137 .07743 L
s
.54521 .0562 m
.54755 .05937 L
s
.59224 .03779 m
.59452 .041 L
s
.1552 .20892 m
.15797 .21172 L
s
.11524 .22456 m
.11804 .22733 L
s
.0759 .23997 m
.07874 .24269 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -11 0 ]
[.5 .82364 11 12.5625 ]
[.18671 .18355 -5.87859 -9 ]
[.18671 .18355 .12141 0 ]
[.40046 .09948 -10.9232 -9 ]
[.40046 .09948 1.07679 0 ]
[.63268 .00821 -10.0892 -9 ]
[.63268 .00821 1.91076 0 ]
[.78828 .12893 0 -6.13096 ]
[.78828 .12893 6 2.86904 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 12 3.00782 ]
[.96661 .40202 0 -5.87517 ]
[.96661 .40202 12 3.12483 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01628 .3142 -18 -2.78382 ]
[.01628 .3142 0 6.21618 ]
[.00819 .36489 -18 -2.82681 ]
[.00819 .36489 0 6.17319 ]
[-0.00016 .41725 -18 -2.87136 ]
[-0.00016 .41725 0 6.12864 ]
[-0.00879 .47136 -18 -2.91756 ]
[-0.00879 .47136 0 6.08244 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.19579 .19302 m
.20033 .19776 L
s
[(5)] .18671 .18355 .95953 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(10)] .40046 .09948 .82054 1 Mshowa
.64007 .01906 m
.64377 .02448 L
s
[(15)] .63268 .00821 .68154 1 Mshowa
.125 Mabswid
.23703 .17687 m
.23971 .17975 L
s
.27893 .16047 m
.28157 .16339 L
s
.32151 .14379 m
.32411 .14675 L
s
.36479 .12685 m
.36734 .12985 L
s
.4535 .09211 m
.45595 .0952 L
s
.49897 .07431 m
.50137 .07743 L
s
.54521 .0562 m
.54755 .05937 L
s
.59224 .03779 m
.59452 .041 L
s
.1552 .20892 m
.15797 .21172 L
s
.11524 .22456 m
.11804 .22733 L
s
.0759 .23997 m
.07874 .24269 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.77594 .1334 m
.76978 .13563 L
s
[(5)] .78828 .12893 -1 .36244 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(10)] .88369 .27502 -1 .3316 Mshowa
.95406 .40586 m
.94779 .40778 L
s
[(15)] .96661 .40202 -1 .30559 Mshowa
.125 Mabswid
.79613 .16428 m
.79242 .1656 L
s
.81573 .19425 m
.81201 .19555 L
s
.83476 .22337 m
.83104 .22465 L
s
.85326 .25166 m
.84953 .25292 L
s
.88871 .30589 m
.88497 .30711 L
s
.90572 .33191 m
.90197 .33311 L
s
.92227 .35722 m
.91851 .3584 L
s
.93838 .38186 m
.93462 .38303 L
s
.75514 .10158 m
.75145 .10294 L
s
.73369 .06877 m
.73001 .07015 L
s
.71157 .03492 m
.70789 .03634 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02854 .30953 m
.03467 .30719 L
s
[(100)] .01628 .3142 1 -0.38137 Mshowa
.02049 .36032 m
.02664 .35803 L
s
[(200)] .00819 .36489 1 -0.37182 Mshowa
.01218 .41278 m
.01835 .41055 L
s
[(300)] -0.00016 .41725 1 -0.36192 Mshowa
.00358 .46701 m
.00977 .46483 L
s
[(400)] -0.00879 .47136 1 -0.35165 Mshowa
.125 Mabswid
.0348 .27005 m
.03847 .26862 L
s
.03325 .27983 m
.03692 .2784 L
s
.03169 .28966 m
.03536 .28825 L
s
.03012 .29956 m
.0338 .29816 L
s
.02695 .31956 m
.03063 .31816 L
s
.02535 .32965 m
.02903 .32826 L
s
.02374 .33981 m
.02743 .33842 L
s
.02212 .35003 m
.02581 .34865 L
s
.01885 .37068 m
.02254 .36931 L
s
.0172 .3811 m
.02089 .37974 L
s
.01554 .39159 m
.01923 .39024 L
s
.01386 .40215 m
.01756 .40081 L
s
.01048 .42349 m
.01419 .42215 L
s
.00877 .43426 m
.01248 .43293 L
s
.00706 .4451 m
.01077 .44378 L
s
.00533 .45602 m
.00904 .45471 L
s
.00183 .47807 m
.00555 .47677 L
s
7e-005 .48921 m
.00379 .48792 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.858 .991 .838 r
.38353 .61071 .40512 .60371 .43938 .5952 .41918 .57408 Mtetra
.65 .72 .9 r
.41918 .57408 .43938 .5952 .47416 .583 .45418 .56475 Mtetra
.677 .759 .912 r
.45418 .56475 .47416 .583 .50935 .57244 .48969 .55259 Mtetra
.664 .741 .908 r
.48969 .55259 .50935 .57244 .54511 .5812 .52564 .54164 Mtetra
.617 .591 .801 r
.52564 .54164 .54511 .5812 .58111 .55092 .56212 .53554 Mtetra
.713 .807 .923 r
.56212 .53554 .58111 .55092 .6234 .74656 .59898 .51929 Mtetra
.592 .417 .613 r
.59898 .51929 .6234 .74656 .65477 .52882 .63638 .5079 Mtetra
.566 .705 .935 r
.63638 .5079 .65477 .52882 .69233 .51755 .67467 .50462 Mtetra
.743 .853 .931 r
.67467 .50462 .69233 .51755 .73041 .50613 .71272 .48463 Mtetra
.664 .741 .908 r
.71272 .48463 .73041 .50613 .76899 .49455 .75168 .47276 Mtetra
.615 .723 .922 r
.75168 .47276 .76899 .49455 .80811 .48282 .79154 .46537 Mtetra
.707 .805 .926 r
.79154 .46537 .80811 .48282 .84775 .47092 .83121 .44853 Mtetra
.664 .741 .908 r
.83121 .44853 .84775 .47092 .88795 .45886 .87181 .43616 Mtetra
.617 .722 .921 r
.87181 .43616 .88795 .45886 .92871 .44664 .91354 .42829 Mtetra
.706 .807 .928 r
.91354 .42829 .92871 .44664 .97118 .44265 .95473 .41089 Mtetra
.702 .7 .845 r
.36266 .58494 .38353 .61071 .41918 .57408 .39792 .56875 Mtetra
.437 0 0 r
.39792 .56875 .41918 .57408 .45418 .56475 .43265 .585 Mtetra
.83 .968 .65 r
.43265 .585 .45418 .56475 .48969 .55259 .46955 .53226 Mtetra
.639 .734 .917 r
.46955 .53226 .48969 .55259 .52564 .54164 .5058 .52331 Mtetra
.686 .77 .915 r
.5058 .52331 .52564 .54164 .56212 .53554 .54255 .50966 Mtetra
.662 .697 .872 r
.54255 .50966 .56212 .53554 .59898 .51929 .57979 .49813 Mtetra
.909 .505 .129 r
.57979 .49813 .59898 .51929 .63638 .5079 .62093 .60748 Mtetra
0 0 .158 r
.62093 .60748 .63638 .5079 .67467 .50462 .6558 .4746 Mtetra
.66 .673 .852 r
.6558 .4746 .67467 .50462 .71272 .48463 .69459 .46259 Mtetra
.664 .741 .908 r
.69459 .46259 .71272 .48463 .75168 .47276 .73392 .45042 Mtetra
.73392 .45042 .75168 .47276 .79154 .46537 .77379 .43807 Mtetra
.643 .693 .881 r
.77379 .43807 .79154 .46537 .83121 .44853 .81444 .42789 Mtetra
.681 .771 .919 r
.81444 .42789 .83121 .44853 .87181 .43616 .85529 .41333 Mtetra
.668 .747 .91 r
.85529 .41333 .87181 .43616 .91354 .42829 .89683 .39998 Mtetra
.655 .697 .877 r
.89683 .39998 .91354 .42829 .95473 .41089 .93915 .38786 Mtetra
.456 .508 .823 r
.34209 .54503 .36266 .58494 .39792 .56875 .37631 .55496 Mtetra
.61 .8 .972 r
.37631 .55496 .39792 .56875 .43265 .585 .41204 .5466 Mtetra
.757 .66 .754 r
.41204 .5466 .43265 .585 .46955 .53226 .44892 .51142 Mtetra
.664 .741 .908 r
.44892 .51142 .46955 .53226 .5058 .52331 .48549 .49991 Mtetra
.631 .71 .903 r
.48549 .49991 .5058 .52331 .54255 .50966 .52255 .49147 Mtetra
.512 .721 .967 r
.52255 .49147 .54255 .50966 .57979 .49813 .56027 .48986 Mtetra
.054 .579 .869 r
.56027 .48986 .57979 .49813 .62093 .60748 .59893 .49667 Mtetra
.679 .512 .653 r
.59893 .49667 .62093 .60748 .6558 .4746 .63683 .4523 Mtetra
.591 .715 .929 r
.63683 .4523 .6558 .4746 .69459 .46259 .67629 .44651 Mtetra
0 .07 .548 r
.67629 .44651 .69459 .46259 .73392 .45042 .71896 .48305 Mtetra
0 0 0 r
.71896 .48305 .73392 .45042 .77379 .43807 .7562 .41811 Mtetra
.408 .658 .961 r
.7562 .41811 .77379 .43807 .81444 .42789 .79856 .42278 Mtetra
.73 .964 .939 r
.79856 .42278 .81444 .42789 .85529 .41333 .83916 .3984 Mtetra
.713 .855 .95 r
.83916 .3984 .85529 .41333 .89683 .39998 .88068 .37951 Mtetra
.553 .731 .958 r
.88068 .37951 .89683 .39998 .93915 .38786 .92451 .37516 Mtetra
.865 .982 .847 r
.31842 .55109 .34209 .54503 .37631 .55496 .35548 .51317 Mtetra
.646 .601 .789 r
.35548 .51317 .37631 .55496 .41204 .5466 .39138 .50169 Mtetra
.507 .518 .802 r
.39138 .50169 .41204 .5466 .44892 .51142 .42724 .50807 Mtetra
.397 .834 .948 r
.42724 .50807 .44892 .51142 .48549 .49991 .46424 .50099 Mtetra
.748 .981 .912 r
.46424 .50099 .48549 .49991 .52255 .49147 .50198 .47511 Mtetra
.742 .814 .909 r
.50198 .47511 .52255 .49147 .56027 .48986 .53996 .45465 Mtetra
.491 .566 .859 r
.53996 .45465 .56027 .48986 .59893 .49667 .57869 .46013 Mtetra
.749 .678 .782 r
.57869 .46013 .59893 .49667 .63683 .4523 .61737 .42943 Mtetra
.315 .578 .935 r
.61737 .42943 .63683 .4523 .67629 .44651 .65784 .43989 Mtetra
.854 .938 .878 r
.65784 .43989 .67629 .44651 .71896 .48305 .69699 .40396 Mtetra
.62 .506 .702 r
.69699 .40396 .71896 .48305 .7562 .41811 .73766 .39096 Mtetra
.136 .423 .865 r
.73766 .39096 .7562 .41811 .79856 .42278 .78188 .41505 Mtetra
.803 .951 .916 r
.78188 .41505 .79856 .42278 .83916 .3984 .82268 .3849 Mtetra
.621 .848 .986 r
.82268 .3849 .83916 .3984 .88068 .37951 .86554 .37234 Mtetra
.658 .937 .967 r
.86554 .37234 .88068 .37951 .92451 .37516 .90824 .35284 Mtetra
.428 .462 .794 r
.29746 .50347 .31842 .55109 .35548 .51317 .33173 .51683 Mtetra
.86 .974 .861 r
.33173 .51683 .35548 .51317 .39138 .50169 .36938 .48009 Mtetra
.166 .511 .913 r
.36938 .48009 .39138 .50169 .42724 .50807 .40517 .49329 Mtetra
.831 .824 .842 r
.40517 .49329 .42724 .50807 .46424 .50099 .44324 .45791 Mtetra
.656 .608 .789 r
.44324 .45791 .46424 .50099 .50198 .47511 .48101 .44379 Mtetra
.563 .631 .877 r
.48101 .44379 .50198 .47511 .53996 .45465 .51925 .44165 Mtetra
.753 .861 .928 r
.51925 .44165 .53996 .45465 .57869 .46013 .55807 .41968 Mtetra
.505 .548 .834 r
.55807 .41968 .57869 .46013 .61737 .42943 .59783 .42483 Mtetra
.75 .957 .939 r
.59783 .42483 .61737 .42943 .65784 .43989 .63756 .40005 Mtetra
.619 .613 .823 r
.63756 .40005 .65784 .43989 .69699 .40396 .67836 .39166 Mtetra
.64 .862 .983 r
.67836 .39166 .69699 .40396 .73766 .39096 .71956 .37787 Mtetra
.413 .757 .995 r
.71956 .37787 .73766 .39096 .78188 .41505 .76229 .37636 Mtetra
.741 .682 .793 r
.76229 .37636 .78188 .41505 .82268 .3849 .80346 .34632 Mtetra
.634 .635 .834 r
.80346 .34632 .82268 .3849 .86554 .37234 .84678 .33527 Mtetra
.716 .684 .818 r
.84678 .33527 .86554 .37234 .90824 .35284 .88931 .31104 Mtetra
.795 .89 .913 r
.27325 .49578 .29746 .50347 .33173 .51683 .31031 .47 Mtetra
.592 .561 .788 r
.31031 .47 .33173 .51683 .36938 .48009 .34642 .46536 Mtetra
.737 .827 .921 r
.34642 .46536 .36938 .48009 .40517 .49329 .38383 .44569 Mtetra
.606 .567 .785 r
.38383 .44569 .40517 .49329 .44324 .45791 .42119 .43888 Mtetra
0 .171 .644 r
.42119 .43888 .44324 .45791 .48101 .44379 .45851 .46622 Mtetra
.809 .951 .61 r
.45851 .46622 .48101 .44379 .51925 .44165 .49803 .40793 Mtetra
.619 .646 .855 r
.49803 .40793 .51925 .44165 .55807 .41968 .5372 .39969 Mtetra
.224 .57 .94 r
.5372 .39969 .55807 .41968 .59783 .42483 .57737 .41042 Mtetra
.855 .859 .843 r
.57737 .41042 .59783 .42483 .63756 .40005 .61725 .37042 Mtetra
.676 .704 .869 r
.61725 .37042 .63756 .40005 .67836 .39166 .65808 .355 Mtetra
.655 .653 .836 r
.65808 .355 .67836 .39166 .71956 .37787 .69957 .34128 Mtetra
.655 .656 .839 r
.69957 .34128 .71956 .37787 .76229 .37636 .74167 .32736 Mtetra
.582 .562 .797 r
.74167 .32736 .76229 .37636 .80346 .34632 .78524 .32333 Mtetra
.563 .726 .951 r
.78524 .32333 .80346 .34632 .84678 .33527 .82961 .31775 Mtetra
.805 .869 .895 r
.82961 .31775 .84678 .33527 .88931 .31104 .87202 .28626 Mtetra
.084 .335 .809 r
.25056 .4598 .27325 .49578 .31031 .47 .28423 .48375 Mtetra
.883 .992 .776 r
.28423 .48375 .31031 .47 .34642 .46536 .32368 .4352 Mtetra
.634 .673 .869 r
.32368 .4352 .34642 .46536 .38383 .44569 .36087 .42545 Mtetra
.623 .757 .942 r
.36087 .42545 .38383 .44569 .42119 .43888 .39863 .41601 Mtetra
.677 .75 .906 r
.39863 .41601 .42119 .43888 .45851 .46622 .43715 .4017 Mtetra
.553 .492 .742 r
.43715 .4017 .45851 .46622 .49803 .40793 .47595 .40239 Mtetra
.823 .941 .904 r
.47595 .40239 .49803 .40793 .5372 .39969 .51575 .37059 Mtetra
.448 .608 .915 r
.51575 .37059 .5372 .39969 .57737 .41042 .55602 .37524 Mtetra
.745 .698 .806 r
.55602 .37524 .57737 .41042 .61725 .37042 .5966 .34627 Mtetra
.69 .759 .904 r
.5966 .34627 .61725 .37042 .65808 .355 .63782 .32952 Mtetra
.659 .74 .909 r
.63782 .32952 .65808 .355 .69957 .34128 .67976 .3159 Mtetra
0 .296 .788 r
.67976 .3159 .69957 .34128 .74167 .32736 .72516 .34693 Mtetra
.554 .82 .46 r
.72516 .34693 .74167 .32736 .78524 .32333 .76627 .29722 Mtetra
.712 .765 .894 r
.76627 .29722 .78524 .32333 .82961 .31775 .80974 .27667 Mtetra
.682 .657 .819 r
.80974 .27667 .82961 .31775 .87202 .28626 .85381 .25686 Mtetra
.808 .968 .906 r
.22401 .46104 .25056 .4598 .28423 .48375 .26228 .43114 Mtetra
.667 .586 .755 r
.26228 .43114 .28423 .48375 .32368 .4352 .29993 .41188 Mtetra
.476 .674 .951 r
.29993 .41188 .32368 .4352 .36087 .42545 .33682 .4122 Mtetra
.777 .856 .909 r
.33682 .4122 .36087 .42545 .39863 .41601 .37574 .38685 Mtetra
.639 .692 .883 r
.37574 .38685 .39863 .41601 .43715 .4017 .41441 .37596 Mtetra
.692 .738 .886 r
.41441 .37596 .43715 .4017 .47595 .40239 .45384 .35918 Mtetra
.624 .607 .812 r
.45384 .35918 .47595 .40239 .51575 .37059 .4937 .34886 Mtetra
.444 .684 .967 r
.4937 .34886 .51575 .37059 .55602 .37524 .53427 .34991 Mtetra
.671 .746 .907 r
.53427 .34991 .55602 .37524 .5966 .34627 .57558 .33493 Mtetra
.754 .906 .944 r
.57558 .33493 .5966 .34627 .63782 .32952 .61722 .31054 Mtetra
.249 .61 .955 r
.61722 .31054 .63782 .32952 .67976 .3159 .66065 .31898 Mtetra
.835 .999 .803 r
.66065 .31898 .67976 .3159 .72516 .34693 .70238 .27508 Mtetra
.626 .529 .725 r
.70238 .27508 .72516 .34693 .76627 .29722 .74597 .25918 Mtetra
.645 .658 .848 r
.74597 .25918 .76627 .29722 .80974 .27667 .79041 .24546 Mtetra
.658 .712 .888 r
.79041 .24546 .80974 .27667 .85381 .25686 .83549 .23054 Mtetra
.612 .582 .795 r
.20111 .41478 .22401 .46104 .26228 .43114 .23765 .40616 Mtetra
.489 .668 .943 r
.23765 .40616 .26228 .43114 .29993 .41188 .27415 .40595 Mtetra
.822 .918 .901 r
.27415 .40595 .29993 .41188 .33682 .4122 .31353 .3747 Mtetra
.494 .574 .865 r
.31353 .3747 .33682 .4122 .37574 .38685 .35119 .37748 Mtetra
.805 .901 .909 r
.35119 .37748 .37574 .38685 .41441 .37596 .39115 .34812 Mtetra
.294 .548 .92 r
.39115 .34812 .41441 .37596 .45384 .35918 .4301 .35882 Mtetra
.848 .975 .871 r
.4301 .35882 .45384 .35918 .4937 .34886 .4711 .32074 Mtetra
.671 .724 .89 r
.4711 .32074 .4937 .34886 .53427 .34991 .51199 .30554 Mtetra
.646 .62 .809 r
.51199 .30554 .53427 .34991 .57558 .33493 .55348 .29108 Mtetra
.545 .573 .834 r
.55348 .29108 .57558 .33493 .61722 .31054 .59591 .28997 Mtetra
.774 .828 .894 r
.59591 .28997 .61722 .31054 .66065 .31898 .63839 .26197 Mtetra
.452 .468 .785 r
.63839 .26197 .66065 .31898 .70238 .27508 .68324 .27428 Mtetra
.83 .997 .844 r
.68324 .27428 .70238 .27508 .74597 .25918 .72608 .23342 Mtetra
.677 .768 .919 r
.72608 .23342 .74597 .25918 .79041 .24546 .7708 .21634 Mtetra
.598 .708 .921 r
.7708 .21634 .79041 .24546 .83549 .23054 .81699 .20736 Mtetra
.633 .733 .92 r
.17544 .3909 .20111 .41478 .23765 .40616 .21239 .38053 Mtetra
.676 .733 .893 r
.21239 .38053 .23765 .40616 .27415 .40595 .25031 .36572 Mtetra
.573 .6 .841 r
.25031 .36572 .27415 .40595 .31353 .3747 .28798 .3612 Mtetra
.709 .859 .953 r
.28798 .3612 .31353 .3747 .35119 .37748 .32729 .34265 Mtetra
.031 .33 .813 r
.32729 .34265 .35119 .37748 .39115 .34812 .36488 .36757 Mtetra
.866 .981 .69 r
.36488 .36757 .39115 .34812 .4301 .35882 .40719 .30822 Mtetra
.641 .593 .784 r
.40719 .30822 .4301 .35882 .4711 .32074 .44786 .29331 Mtetra
.659 .732 .904 r
.44786 .29331 .4711 .32074 .51199 .30554 .48913 .27915 Mtetra
.559 .706 .938 r
.48913 .27915 .51199 .30554 .55348 .29108 .53106 .27351 Mtetra
.733 .849 .935 r
.53106 .27351 .55348 .29108 .59591 .28997 .57363 .25113 Mtetra
.671 .668 .839 r
.57363 .25113 .59591 .28997 .63839 .26197 .6168 .23336 Mtetra
.663 .737 .905 r
.6168 .23336 .63839 .26197 .68324 .27428 .6607 .21779 Mtetra
.484 .494 .792 r
.6607 .21779 .68324 .27428 .72608 .23342 .70667 .22513 Mtetra
.606 .919 .975 r
.70667 .22513 .72608 .23342 .7708 .21634 .75218 .20713 Mtetra
.83 .965 .893 r
.75218 .20713 .7708 .21634 .81699 .20736 .79661 .16955 Mtetra
.663 .733 .902 r
.1492 .36542 .17544 .3909 .21239 .38053 .18672 .35186 Mtetra
.661 .711 .885 r
.18672 .35186 .21239 .38053 .25031 .36572 .2248 .33809 Mtetra
.662 .722 .893 r
.2248 .33809 .25031 .36572 .28798 .3612 .26345 .32412 Mtetra
.533 .607 .873 r
.26345 .32412 .28798 .3612 .32729 .34265 .30179 .32246 Mtetra
.769 .81 .886 r
.30179 .32246 .32729 .34265 .36488 .36757 .34249 .29555 Mtetra
.616 .522 .724 r
.34249 .29555 .36488 .36757 .40719 .30822 .38291 .28094 Mtetra
.635 .728 .915 r
.38291 .28094 .40719 .30822 .44786 .29331 .42386 .26901 Mtetra
.332 .62 .955 r
.42386 .26901 .44786 .29331 .48913 .27915 .46517 .27499 Mtetra
.85 .963 .877 r
.46517 .27499 .48913 .27915 .53106 .27351 .50795 .23574 Mtetra
.655 .67 .853 r
.50795 .23574 .53106 .27351 .57363 .25113 .55094 .2202 Mtetra
.521 .661 .924 r
.55094 .2202 .57363 .25113 .6168 .23336 .59491 .21767 Mtetra
.749 .886 .942 r
.59491 .21767 .6168 .23336 .6607 .21779 .63911 .1923 Mtetra
.687 .783 .924 r
.63911 .1923 .6607 .21779 .70667 .22513 .68412 .17356 Mtetra
.65 .611 .797 r
.68412 .17356 .70667 .22513 .75218 .20713 .72984 .15553 Mtetra
.568 .569 .814 r
.72984 .15553 .75218 .20713 .79661 .16955 .77736 .1501 Mtetra
.416 .651 .955 r
.12213 .34022 .1492 .36542 .18672 .35186 .15814 .34213 Mtetra
.806 .889 .904 r
.15814 .34213 .18672 .35186 .2248 .33809 .19838 .31214 Mtetra
.664 .741 .908 r
.19838 .31214 .2248 .33809 .26345 .32412 .23736 .29778 Mtetra
.23736 .29778 .26345 .32412 .30179 .32246 .27694 .2832 Mtetra
.566 .616 .861 r
.27694 .2832 .30179 .32246 .34249 .29555 .31647 .2781 Mtetra
.755 .843 .918 r
.31647 .2781 .34249 .29555 .38291 .28094 .35792 .25337 Mtetra
.664 .741 .908 r
.35792 .25337 .38291 .28094 .42386 .26901 .39936 .23811 Mtetra
.662 .718 .891 r
.39936 .23811 .42386 .26901 .46517 .27499 .44144 .2226 Mtetra
.583 .567 .802 r
.44144 .2226 .46517 .27499 .50795 .23574 .48408 .21519 Mtetra
.741 .834 .922 r
.48408 .21519 .50795 .23574 .55094 .2202 .52762 .19086 Mtetra
.664 .741 .908 r
.52762 .19086 .55094 .2202 .59491 .21767 .57175 .17461 Mtetra
.42 .53 .863 r
.57175 .17461 .59491 .21767 .63911 .1923 .61735 .18293 Mtetra
.855 .953 .876 r
.61735 .18293 .63911 .1923 .68412 .17356 .66216 .14131 Mtetra
.663 .73 .899 r
.66216 .14131 .68412 .17356 .72984 .15553 .70847 .12424 Mtetra
.664 .741 .908 r
.70847 .12424 .72984 .15553 .77736 .1501 .75556 .1069 Mtetra
.09432 .31433 .12213 .34022 .15814 .34213 .13248 .3 Mtetra
.646 .634 .824 r
.13248 .3 .15814 .34213 .19838 .31214 .17121 .28546 Mtetra
.644 .736 .916 r
.17121 .28546 .19838 .31214 .23736 .29778 .21035 .27262 Mtetra
.683 .762 .911 r
.21035 .27262 .23736 .29778 .27694 .2832 .25047 .2557 Mtetra
.664 .741 .908 r
.25047 .2557 .27694 .2832 .31647 .2781 .29103 .24047 Mtetra
.622 .658 .865 r
.29103 .24047 .31647 .2781 .35792 .25337 .33197 .22891 Mtetra
.697 .783 .917 r
.33197 .22891 .35792 .25337 .39936 .23811 .37402 .20978 Mtetra
.668 .747 .909 r
.37402 .20978 .39936 .23811 .44144 .2226 .41655 .19334 Mtetra
.548 .696 .937 r
.41655 .19334 .44144 .2226 .48408 .21519 .45951 .18747 Mtetra
.746 .782 .882 r
.45951 .18747 .48408 .21519 .52762 .19086 .50361 .16065 Mtetra
.664 .741 .908 r
.50361 .16065 .52762 .19086 .57175 .17461 .5482 .14391 Mtetra
.5482 .14391 .57175 .17461 .61735 .18293 .59353 .12689 Mtetra
.636 .594 .789 r
.59353 .12689 .61735 .18293 .66216 .14131 .6396 .10959 Mtetra
.664 .741 .908 r
.6396 .10959 .66216 .14131 .70847 .12424 .68645 .092 Mtetra
.68645 .092 .70847 .12424 .75556 .1069 .73408 .07411 Mtetra
.06574 .28771 .09432 .31433 .13248 .3 .10421 .27298 Mtetra
.10421 .27298 .13248 .3 .17121 .28546 .14328 .25802 Mtetra
.659 .74 .91 r
.14328 .25802 .17121 .28546 .21035 .27262 .1829 .24331 Mtetra
.667 .731 .898 r
.1829 .24331 .21035 .27262 .25047 .2557 .22324 .2274 Mtetra
.664 .741 .908 r
.22324 .2274 .25047 .2557 .29103 .24047 .26417 .21173 Mtetra
.569 .708 .936 r
.26417 .21173 .29103 .24047 .33197 .22891 .30514 .20416 Mtetra
.737 .795 .899 r
.30514 .20416 .33197 .22891 .37402 .20978 .34799 .17964 Mtetra
.663 .737 .905 r
.34799 .17964 .37402 .20978 .41655 .19334 .39091 .1632 Mtetra
.664 .741 .908 r
.39091 .1632 .41655 .19334 .45951 .18747 .43453 .1465 Mtetra
.653 .669 .852 r
.43453 .1465 .45951 .18747 .50361 .16065 .47887 .12952 Mtetra
.664 .741 .908 r
.47887 .12952 .50361 .16065 .5482 .14391 .52394 .11227 Mtetra
.52394 .11227 .5482 .14391 .59353 .12689 .56976 .09472 Mtetra
.56976 .09472 .59353 .12689 .6396 .10959 .61635 .07688 Mtetra
.612 .719 .922 r
.61635 .07688 .6396 .10959 .68645 .092 .66399 .06424 Mtetra
.705 .801 .924 r
.66399 .06424 .68645 .092 .73408 .07411 .71198 .04129 Mtetra
.664 .741 .908 r
.03634 .26033 .06574 .28771 .10421 .27298 .07513 .24518 Mtetra
.07513 .24518 .10421 .27298 .14328 .25802 .11454 .22979 Mtetra
.11454 .22979 .14328 .25802 .1829 .24331 .15456 .21416 Mtetra
.663 .738 .905 r
.15456 .21416 .1829 .24331 .22324 .2274 .19522 .19828 Mtetra
.664 .741 .908 r
.19522 .19828 .22324 .2274 .26417 .21173 .23652 .18214 Mtetra
.659 .74 .91 r
.23652 .18214 .26417 .21173 .30514 .20416 .27846 .16624 Mtetra
.66 .686 .864 r
.27846 .16624 .30514 .20416 .34799 .17964 .32115 .14909 Mtetra
.664 .741 .908 r
.32115 .14909 .34799 .17964 .39091 .1632 .3645 .13215 Mtetra
.3645 .13215 .39091 .1632 .43453 .1465 .40857 .11494 Mtetra
.62 .725 .922 r
.40857 .11494 .43453 .1465 .47887 .12952 .45326 .10192 Mtetra
.706 .79 .917 r
.45326 .10192 .47887 .12952 .52394 .11227 .49893 .07965 Mtetra
.655 .738 .911 r
.49893 .07965 .52394 .11227 .56976 .09472 .54526 .06255 Mtetra
.673 .752 .91 r
.54526 .06255 .56976 .09472 .61635 .07688 .59236 .04315 Mtetra
.664 .741 .908 r
.59236 .04315 .61635 .07688 .66399 .06424 .64029 .02443 Mtetra
.659 .702 .878 r
.64029 .02443 .66399 .06424 .71198 .04129 .68905 .00539 Mtetra
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.19579 .19302 m
.20033 .19776 L
s
[(5)] .18671 .18355 .95953 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(10)] .40046 .09948 .82054 1 Mshowa
.64007 .01906 m
.64377 .02448 L
s
[(15)] .63268 .00821 .68154 1 Mshowa
.125 Mabswid
.23703 .17687 m
.23971 .17975 L
s
.27893 .16047 m
.28157 .16339 L
s
.32151 .14379 m
.32411 .14675 L
s
.36479 .12685 m
.36734 .12985 L
s
.4535 .09211 m
.45595 .0952 L
s
.49897 .07431 m
.50137 .07743 L
s
.54521 .0562 m
.54755 .05937 L
s
.59224 .03779 m
.59452 .041 L
s
.1552 .20892 m
.15797 .21172 L
s
.11524 .22456 m
.11804 .22733 L
s
.0759 .23997 m
.07874 .24269 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -11 0 ]
[.5 .82364 11 12.5625 ]
[.18671 .18355 -5.87859 -9 ]
[.18671 .18355 .12141 0 ]
[.40046 .09948 -10.9232 -9 ]
[.40046 .09948 1.07679 0 ]
[.63268 .00821 -10.0892 -9 ]
[.63268 .00821 1.91076 0 ]
[.78828 .12893 0 -6.13096 ]
[.78828 .12893 6 2.86904 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 12 3.00782 ]
[.96661 .40202 0 -5.87517 ]
[.96661 .40202 12 3.12483 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01613 .31515 -18 -2.78462 ]
[.01613 .31515 0 6.21538 ]
[.00788 .36685 -18 -2.82847 ]
[.00788 .36685 0 6.17153 ]
[-0.00064 .42028 -18 -2.87394 ]
[-0.00064 .42028 0 6.12606 ]
[-0.00946 .47554 -18 -2.92114 ]
[-0.00946 .47554 0 6.07886 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.19579 .19302 m
.20033 .19776 L
s
[(5)] .18671 .18355 .95953 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(10)] .40046 .09948 .82054 1 Mshowa
.64007 .01906 m
.64377 .02448 L
s
[(15)] .63268 .00821 .68154 1 Mshowa
.125 Mabswid
.23703 .17687 m
.23971 .17975 L
s
.27893 .16047 m
.28157 .16339 L
s
.32151 .14379 m
.32411 .14675 L
s
.36479 .12685 m
.36734 .12985 L
s
.4535 .09211 m
.45595 .0952 L
s
.49897 .07431 m
.50137 .07743 L
s
.54521 .0562 m
.54755 .05937 L
s
.59224 .03779 m
.59452 .041 L
s
.1552 .20892 m
.15797 .21172 L
s
.11524 .22456 m
.11804 .22733 L
s
.0759 .23997 m
.07874 .24269 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.77594 .1334 m
.76978 .13563 L
s
[(5)] .78828 .12893 -1 .36244 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(10)] .88369 .27502 -1 .3316 Mshowa
.95406 .40586 m
.94779 .40778 L
s
[(15)] .96661 .40202 -1 .30559 Mshowa
.125 Mabswid
.79613 .16428 m
.79242 .1656 L
s
.81573 .19425 m
.81201 .19555 L
s
.83476 .22337 m
.83104 .22465 L
s
.85326 .25166 m
.84953 .25292 L
s
.88871 .30589 m
.88497 .30711 L
s
.90572 .33191 m
.90197 .33311 L
s
.92227 .35722 m
.91851 .3584 L
s
.93838 .38186 m
.93462 .38303 L
s
.75514 .10158 m
.75145 .10294 L
s
.73369 .06877 m
.73001 .07015 L
s
.71157 .03492 m
.70789 .03634 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02839 .31048 m
.03452 .30814 L
s
[(200)] .01613 .31515 1 -0.38119 Mshowa
.02018 .36228 m
.02633 .35999 L
s
[(400)] .00788 .36685 1 -0.37145 Mshowa
.0117 .41582 m
.01787 .41359 L
s
[(600)] -0.00064 .42028 1 -0.36135 Mshowa
.00292 .47119 m
.00911 .46902 L
s
[(800)] -0.00946 .47554 1 -0.35086 Mshowa
.125 Mabswid
.03437 .27272 m
.03804 .27129 L
s
.0324 .2852 m
.03607 .28379 L
s
.0304 .29779 m
.03408 .29638 L
s
.02636 .32327 m
.03004 .32187 L
s
.02432 .33616 m
.028 .33478 L
s
.02226 .34917 m
.02595 .34779 L
s
.01809 .3755 m
.02178 .37413 L
s
.01597 .38883 m
.01967 .38747 L
s
.01384 .40227 m
.01754 .40092 L
s
.00953 .42949 m
.01324 .42816 L
s
.00735 .44327 m
.01105 .44195 L
s
.00514 .45717 m
.00885 .45586 L
s
.00068 .48533 m
.0044 .48404 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.86 .996 .805 r
.38341 .61375 .40512 .60371 .43937 .59547 .41918 .57408 Mtetra
.657 .72 .895 r
.41918 .57408 .43937 .59547 .47416 .583 .45419 .56409 Mtetra
.671 .75 .91 r
.45419 .56409 .47416 .583 .50935 .57244 .48969 .55259 Mtetra
.664 .741 .908 r
.48969 .55259 .50935 .57244 .54513 .58505 .52564 .54164 Mtetra
.617 .575 .785 r
.52564 .54164 .54513 .58505 .58111 .55092 .56212 .5354 Mtetra
.712 .805 .923 r
.56212 .5354 .58111 .55092 .6234 .74656 .59898 .51929 Mtetra
.592 .417 .613 r
.59898 .51929 .6234 .74656 .65477 .52882 .63638 .5079 Mtetra
.573 .708 .934 r
.63638 .5079 .65477 .52882 .69233 .51755 .67464 .50407 Mtetra
.738 .846 .931 r
.67464 .50407 .69233 .51755 .73041 .50613 .71272 .48463 Mtetra
.664 .741 .908 r
.71272 .48463 .73041 .50613 .76899 .49455 .75168 .47276 Mtetra
.619 .724 .921 r
.75168 .47276 .76899 .49455 .80811 .48282 .79151 .46498 Mtetra
.703 .799 .925 r
.79151 .46498 .80811 .48282 .84775 .47092 .83121 .44853 Mtetra
.664 .741 .908 r
.83121 .44853 .84775 .47092 .88795 .45886 .87181 .43616 Mtetra
.608 .718 .923 r
.87181 .43616 .88795 .45886 .92871 .44664 .91363 .4291 Mtetra
.714 .818 .93 r
.91363 .4291 .92871 .44664 .97104 .44162 .95473 .41089 Mtetra
.685 .668 .828 r
.36271 .58393 .38341 .61375 .41918 .57408 .3979 .56926 Mtetra
.495 0 0 r
.3979 .56926 .41918 .57408 .45419 .56409 .43259 .58722 Mtetra
.805 .949 .605 r
.43259 .58722 .45419 .56409 .48969 .55259 .46955 .53226 Mtetra
.638 .734 .918 r
.46955 .53226 .48969 .55259 .52564 .54164 .5058 .52335 Mtetra
.687 .771 .915 r
.5058 .52335 .52564 .54164 .56212 .5354 .54255 .50966 Mtetra
.662 .698 .873 r
.54255 .50966 .56212 .5354 .59898 .51929 .57979 .49813 Mtetra
.911 .509 .134 r
.57979 .49813 .59898 .51929 .63638 .5079 .62097 .6091 Mtetra
0 0 .163 r
.62097 .6091 .63638 .5079 .67464 .50407 .6558 .4746 Mtetra
.658 .676 .856 r
.6558 .4746 .67464 .50407 .71272 .48463 .6946 .46283 Mtetra
.666 .744 .909 r
.6946 .46283 .71272 .48463 .75168 .47276 .73392 .45042 Mtetra
.664 .741 .908 r
.73392 .45042 .75168 .47276 .79151 .46498 .77379 .43807 Mtetra
.642 .695 .884 r
.77379 .43807 .79151 .46498 .83121 .44853 .81444 .42794 Mtetra
.679 .771 .92 r
.81444 .42794 .83121 .44853 .87181 .43616 .85531 .41358 Mtetra
.67 .751 .911 r
.85531 .41358 .87181 .43616 .91363 .4291 .89683 .39998 Mtetra
.658 .693 .871 r
.89683 .39998 .91363 .4291 .95473 .41089 .93909 .3874 Mtetra
.424 .496 .829 r
.34209 .54503 .36271 .58393 .3979 .56926 .37622 .557 Mtetra
.603 .817 .982 r
.37622 .557 .3979 .56926 .43259 .58722 .41198 .54846 Mtetra
.762 .661 .75 r
.41198 .54846 .43259 .58722 .46955 .53226 .44892 .51142 Mtetra
.664 .741 .908 r
.44892 .51142 .46955 .53226 .5058 .52335 .48549 .49991 Mtetra
.623 .707 .906 r
.48549 .49991 .5058 .52335 .54255 .50966 .52255 .49224 Mtetra
.549 .745 .967 r
.52255 .49224 .54255 .50966 .57979 .49813 .56025 .48822 Mtetra
.057 .564 .882 r
.56025 .48822 .57979 .49813 .62097 .6091 .59893 .49657 Mtetra
.677 .51 .652 r
.59893 .49657 .62097 .6091 .6558 .4746 .63684 .45254 Mtetra
.598 .72 .929 r
.63684 .45254 .6558 .4746 .6946 .46283 .67627 .44616 Mtetra
0 .107 .59 r
.67627 .44616 .6946 .46283 .73392 .45042 .71885 .48117 Mtetra
0 0 0 r
.71885 .48117 .73392 .45042 .77379 .43807 .75627 .41913 Mtetra
.465 .7 .97 r
.75627 .41913 .77379 .43807 .81444 .42794 .79833 .42003 Mtetra
.741 .939 .95 r
.79833 .42003 .81444 .42794 .85531 .41358 .83899 .39665 Mtetra
.694 .826 .946 r
.83899 .39665 .85531 .41358 .89683 .39998 .88072 .37982 Mtetra
.528 .722 .962 r
.88072 .37982 .89683 .39998 .93909 .3874 .92475 .37711 Mtetra
.865 .981 .848 r
.31844 .55089 .34209 .54503 .37622 .557 .35548 .51317 Mtetra
.644 .592 .781 r
.35548 .51317 .37622 .557 .41198 .54846 .39138 .50169 Mtetra
.474 .492 .796 r
.39138 .50169 .41198 .54846 .44892 .51142 .42713 .51172 Mtetra
.406 .856 .898 r
.42713 .51172 .44892 .51142 .48549 .49991 .46423 .50119 Mtetra
.75 .983 .91 r
.46423 .50119 .48549 .49991 .52255 .49224 .50198 .47504 Mtetra
.742 .806 .903 r
.50198 .47504 .52255 .49224 .56025 .48822 .53996 .45442 Mtetra
.491 .575 .867 r
.53996 .45442 .56025 .48822 .59893 .49657 .57868 .45952 Mtetra
.745 .674 .782 r
.57868 .45952 .59893 .49657 .63684 .45254 .61737 .42943 Mtetra
.262 .544 .924 r
.61737 .42943 .63684 .45254 .67627 .44616 .65795 .44251 Mtetra
.866 .962 .862 r
.65795 .44251 .67627 .44616 .71885 .48117 .69699 .40396 Mtetra
.621 .509 .705 r
.69699 .40396 .71885 .48117 .75627 .41913 .73766 .39096 Mtetra
.169 .435 .868 r
.73766 .39096 .75627 .41913 .79833 .42003 .78182 .41429 Mtetra
.817 .969 .9 r
.78182 .41429 .79833 .42003 .83899 .39665 .82237 .38162 Mtetra
.545 .797 .991 r
.82237 .38162 .83899 .39665 .88072 .37982 .86579 .37472 Mtetra
.669 .957 .945 r
.86579 .37472 .88072 .37982 .92475 .37711 .90822 .35265 Mtetra
.381 .436 .793 r
.29746 .50347 .31844 .55089 .35548 .51317 .33153 .5204 Mtetra
.869 .987 .832 r
.33153 .5204 .35548 .51317 .39138 .50169 .36938 .48009 Mtetra
.21 .537 .925 r
.36938 .48009 .39138 .50169 .42713 .51172 .40522 .49186 Mtetra
.808 .782 .829 r
.40522 .49186 .42713 .51172 .46423 .50119 .44323 .45819 Mtetra
.658 .609 .789 r
.44323 .45819 .46423 .50119 .50198 .47504 .48101 .44379 Mtetra
.549 .625 .88 r
.48101 .44379 .50198 .47504 .53996 .45442 .51924 .4428 Mtetra
.765 .877 .928 r
.51924 .4428 .53996 .45442 .57868 .45952 .55806 .41946 Mtetra
.493 .544 .837 r
.55806 .41946 .57868 .45952 .61737 .42943 .59785 .42568 Mtetra
.752 .964 .934 r
.59785 .42568 .61737 .42943 .65795 .44251 .63756 .40019 Mtetra
.62 .602 .811 r
.63756 .40019 .65795 .44251 .69699 .40396 .67835 .3914 Mtetra
.615 .851 .988 r
.67835 .3914 .69699 .40396 .73766 .39096 .71965 .3793 Mtetra
.356 .744 .987 r
.71965 .3793 .73766 .39096 .78182 .41429 .76248 .37902 Mtetra
.756 .705 .803 r
.76248 .37902 .78182 .41429 .82237 .38162 .80358 .34768 Mtetra
.649 .669 .856 r
.80358 .34768 .82237 .38162 .86579 .37472 .84675 .33497 Mtetra
.709 .667 .806 r
.84675 .33497 .86579 .37472 .90822 .35265 .88931 .31104 Mtetra
.802 .899 .911 r
.27318 .49675 .29746 .50347 .33153 .5204 .31031 .47 Mtetra
.594 .549 .774 r
.31031 .47 .33153 .5204 .36938 .48009 .34643 .46503 Mtetra
.734 .824 .92 r
.34643 .46503 .36938 .48009 .40522 .49186 .38383 .44569 Mtetra
.601 .57 .792 r
.38383 .44569 .40522 .49186 .44323 .45819 .42116 .43971 Mtetra
0 .246 .707 r
.42116 .43971 .44323 .45819 .48101 .44379 .45856 .46367 Mtetra
.823 .966 .645 r
.45856 .46367 .48101 .44379 .51924 .4428 .49803 .40793 Mtetra
.63 .644 .846 r
.49803 .40793 .51924 .4428 .55806 .41946 .5372 .39834 Mtetra
.223 .557 .934 r
.5372 .39834 .55806 .41946 .59785 .42568 .57736 .40999 Mtetra
.851 .847 .839 r
.57736 .40999 .59785 .42568 .63756 .40019 .61724 .36997 Mtetra
.672 .699 .866 r
.61724 .36997 .63756 .40019 .67835 .3914 .65808 .355 Mtetra
.655 .655 .838 r
.65808 .355 .67835 .3914 .71965 .3793 .69957 .34128 Mtetra
.654 .647 .831 r
.69957 .34128 .71965 .3793 .76248 .37902 .74167 .32736 Mtetra
.581 .552 .787 r
.74167 .32736 .76248 .37902 .80358 .34768 .78525 .32352 Mtetra
.559 .713 .944 r
.78525 .32352 .80358 .34768 .84675 .33497 .82969 .3186 Mtetra
.812 .882 .896 r
.82969 .3186 .84675 .33497 .88931 .31104 .87203 .28629 Mtetra
.127 .354 .816 r
.25056 .4598 .27318 .49675 .31031 .47 .28431 .48275 Mtetra
.883 .992 .786 r
.28431 .48275 .31031 .47 .34643 .46503 .32368 .4352 Mtetra
.645 .679 .868 r
.32368 .4352 .34643 .46503 .38383 .44569 .36093 .42431 Mtetra
.634 .748 .931 r
.36093 .42431 .38383 .44569 .42116 .43971 .3987 .41421 Mtetra
.624 .71 .908 r
.3987 .41421 .42116 .43971 .45856 .46367 .43705 .40515 Mtetra
.578 .523 .757 r
.43705 .40515 .45856 .46367 .49803 .40793 .47596 .40153 Mtetra
.818 .934 .907 r
.47596 .40153 .49803 .40793 .5372 .39834 .51575 .37059 Mtetra
.45 .62 .924 r
.51575 .37059 .5372 .39834 .57736 .40999 .55602 .37461 Mtetra
.744 .696 .806 r
.55602 .37461 .57736 .40999 .61724 .36997 .59659 .34584 Mtetra
.686 .758 .906 r
.59659 .34584 .61724 .36997 .65808 .355 .63782 .32952 Mtetra
.657 .739 .91 r
.63782 .32952 .65808 .355 .69957 .34128 .67977 .31615 Mtetra
0 .327 .809 r
.67977 .31615 .69957 .34128 .74167 .32736 .72505 .34504 Mtetra
.524 .82 .487 r
.72505 .34504 .74167 .32736 .78525 .32352 .76652 .30039 Mtetra
.724 .795 .908 r
.76652 .30039 .78525 .32352 .82969 .3186 .80993 .27874 Mtetra
.696 .67 .82 r
.80993 .27874 .82969 .3186 .87203 .28629 .85381 .25686 Mtetra
.824 .972 .893 r
.2239 .46222 .25056 .4598 .28431 .48275 .26236 .43007 Mtetra
.662 .583 .756 r
.26236 .43007 .28431 .48275 .32368 .4352 .29993 .41188 Mtetra
.524 .694 .946 r
.29993 .41188 .32368 .4352 .36093 .42431 .33697 .40956 Mtetra
.752 .841 .919 r
.33697 .40956 .36093 .42431 .3987 .41421 .37571 .38735 Mtetra
.637 .709 .899 r
.37571 .38735 .3987 .41421 .43705 .40515 .41439 .37675 Mtetra
.691 .717 .87 r
.41439 .37675 .43705 .40515 .47596 .40153 .45383 .35967 Mtetra
.628 .615 .818 r
.45383 .35967 .47596 .40153 .51575 .37059 .4937 .34893 Mtetra
.419 .672 .966 r
.4937 .34893 .51575 .37059 .55602 .37461 .53427 .35125 Mtetra
.669 .763 .92 r
.53427 .35125 .55602 .37461 .59659 .34584 .57561 .3365 Mtetra
.753 .925 .946 r
.57561 .3365 .59659 .34584 .63782 .32952 .61725 .31167 Mtetra
.16 .565 .932 r
.61725 .31167 .63782 .32952 .67977 .31615 .66081 .32281 Mtetra
.826 .994 .75 r
.66081 .32281 .67977 .31615 .72505 .34504 .70238 .2751 Mtetra
.627 .534 .729 r
.70238 .2751 .72505 .34504 .76652 .30039 .74597 .25918 Mtetra
.637 .637 .833 r
.74597 .25918 .76652 .30039 .80993 .27874 .79048 .24623 Mtetra
.659 .703 .88 r
.79048 .24623 .80993 .27874 .85381 .25686 .83555 .23108 Mtetra
.605 .575 .793 r
.20108 .41504 .2239 .46222 .26236 .43007 .23756 .40722 Mtetra
.503 .695 .955 r
.23756 .40722 .26236 .43007 .29993 .41188 .27418 .40556 Mtetra
.82 .915 .903 r
.27418 .40556 .29993 .41188 .33697 .40956 .31353 .3747 Mtetra
.523 .606 .877 r
.31353 .3747 .33697 .40956 .37571 .38735 .35134 .37461 Mtetra
.782 .87 .913 r
.35134 .37461 .37571 .38735 .41439 .37675 .39115 .34813 Mtetra
.304 .546 .917 r
.39115 .34813 .41439 .37675 .45383 .35967 .4301 .35881 Mtetra
.85 .972 .873 r
.4301 .35881 .45383 .35967 .4937 .34893 .4711 .32076 Mtetra
.671 .724 .889 r
.4711 .32076 .4937 .34893 .53427 .35125 .51199 .30554 Mtetra
.645 .613 .804 r
.51199 .30554 .53427 .35125 .57561 .3365 .55348 .29108 Mtetra
.554 .571 .825 r
.55348 .29108 .57561 .3365 .61725 .31167 .59589 .28899 Mtetra
.764 .807 .888 r
.59589 .28899 .61725 .31167 .66081 .32281 .63839 .26198 Mtetra
.442 .449 .771 r
.63839 .26198 .66081 .32281 .70238 .2751 .68335 .27658 Mtetra
.834 .999 .813 r
.68335 .27658 .70238 .2751 .74597 .25918 .72603 .23272 Mtetra
.675 .761 .915 r
.72603 .23272 .74597 .25918 .79048 .24623 .77076 .21586 Mtetra
.577 .688 .917 r
.77076 .21586 .79048 .24623 .83555 .23108 .81715 .20901 Mtetra
.626 .731 .923 r
.17542 .39115 .20108 .41504 .23756 .40722 .21231 .38133 Mtetra
.684 .733 .888 r
.21231 .38133 .23756 .40722 .27418 .40556 .25033 .36552 Mtetra
.557 .593 .845 r
.25033 .36552 .27418 .40556 .31353 .3747 .28787 .36264 Mtetra
.735 .875 .946 r
.28787 .36264 .31353 .3747 .35134 .37461 .32736 .34155 Mtetra
.031 .345 .823 r
.32736 .34155 .35134 .37461 .39115 .34813 .36499 .36519 Mtetra
.873 .987 .715 r
.36499 .36519 .39115 .34813 .4301 .35881 .4072 .30799 Mtetra
.639 .591 .784 r
.4072 .30799 .4301 .35881 .4711 .32076 .44786 .29331 Mtetra
.661 .732 .903 r
.44786 .29331 .4711 .32076 .51199 .30554 .48913 .27891 Mtetra
.516 .684 .943 r
.48913 .27891 .51199 .30554 .55348 .29108 .53106 .27642 Mtetra
.749 .88 .94 r
.53106 .27642 .55348 .29108 .59589 .28899 .57364 .25216 Mtetra
.681 .684 .846 r
.57364 .25216 .59589 .28899 .63839 .26198 .6168 .23336 Mtetra
.663 .737 .905 r
.6168 .23336 .63839 .26198 .68335 .27658 .6607 .21779 Mtetra
.495 .492 .783 r
.6607 .21779 .68335 .27658 .72603 .23272 .7066 .22406 Mtetra
.632 .925 .974 r
.7066 .22406 .72603 .23272 .77076 .21586 .752 .20475 Mtetra
.817 .95 .907 r
.752 .20475 .77076 .21586 .81715 .20901 .79661 .16955 Mtetra
.661 .731 .901 r
.1492 .36542 .17542 .39115 .21231 .38133 .1867 .3521 Mtetra
.663 .707 .881 r
.1867 .3521 .21231 .38133 .25033 .36552 .2248 .33809 Mtetra
.662 .724 .895 r
.2248 .33809 .25033 .36552 .28787 .36264 .26345 .32412 Mtetra
.518 .59 .866 r
.26345 .32412 .28787 .36264 .32736 .34155 .30168 .32393 Mtetra
.782 .833 .891 r
.30168 .32393 .32736 .34155 .36499 .36519 .34248 .29579 Mtetra
.62 .529 .73 r
.34248 .29579 .36499 .36519 .4072 .30799 .38291 .28094 Mtetra
.623 .726 .92 r
.38291 .28094 .4072 .30799 .44786 .29331 .42382 .27005 Mtetra
.35 .64 .963 r
.42382 .27005 .44786 .29331 .48913 .27891 .46517 .27469 Mtetra
.848 .963 .879 r
.46517 .27469 .48913 .27891 .53106 .27642 .50795 .23574 Mtetra
.652 .653 .838 r
.50795 .23574 .53106 .27642 .57364 .25216 .55094 .2202 Mtetra
.524 .654 .917 r
.55094 .2202 .57364 .25216 .6168 .23336 .59491 .21768 Mtetra
.746 .885 .943 r
.59491 .21768 .6168 .23336 .6607 .21779 .63913 .19263 Mtetra
.692 .788 .924 r
.63913 .19263 .6607 .21779 .7066 .22406 .68411 .17334 Mtetra
.65 .614 .801 r
.68411 .17334 .7066 .22406 .752 .20475 .72984 .15553 Mtetra
.57 .581 .825 r
.72984 .15553 .752 .20475 .79661 .16955 .77734 .14981 Mtetra
.421 .653 .955 r
.12213 .34022 .1492 .36542 .1867 .3521 .15816 .34194 Mtetra
.804 .885 .904 r
.15816 .34194 .1867 .3521 .2248 .33809 .19838 .31214 Mtetra
.664 .741 .908 r
.19838 .31214 .2248 .33809 .26345 .32412 .23736 .29778 Mtetra
.23736 .29778 .26345 .32412 .30168 .32393 .27694 .2832 Mtetra
.587 .617 .849 r
.27694 .2832 .30168 .32393 .34248 .29579 .31661 .27605 Mtetra
.737 .821 .917 r
.31661 .27605 .34248 .29579 .38291 .28094 .35792 .25337 Mtetra
.664 .741 .908 r
.35792 .25337 .38291 .28094 .42382 .27005 .39936 .23811 Mtetra
.661 .711 .885 r
.39936 .23811 .42382 .27005 .46517 .27469 .44144 .2226 Mtetra
.58 .567 .804 r
.44144 .2226 .46517 .27469 .50795 .23574 .48408 .2156 Mtetra
.745 .838 .922 r
.48408 .2156 .50795 .23574 .55094 .2202 .52762 .19086 Mtetra
.664 .741 .908 r
.52762 .19086 .55094 .2202 .59491 .21768 .57175 .17461 Mtetra
.411 .525 .862 r
.57175 .17461 .59491 .21768 .63913 .19263 .61737 .18366 Mtetra
.859 .956 .872 r
.61737 .18366 .63913 .19263 .68411 .17334 .66216 .14131 Mtetra
.663 .731 .901 r
.66216 .14131 .68411 .17334 .72984 .15553 .70847 .12424 Mtetra
.664 .741 .908 r
.70847 .12424 .72984 .15553 .77734 .14981 .75556 .1069 Mtetra
.09432 .31433 .12213 .34022 .15816 .34194 .13248 .3 Mtetra
.647 .635 .824 r
.13248 .3 .15816 .34194 .19838 .31214 .17121 .28546 Mtetra
.635 .733 .919 r
.17121 .28546 .19838 .31214 .23736 .29778 .21027 .2734 Mtetra
.691 .77 .912 r
.21027 .2734 .23736 .29778 .27694 .2832 .25047 .2557 Mtetra
.664 .741 .908 r
.25047 .2557 .27694 .2832 .31661 .27605 .29103 .24047 Mtetra
.618 .67 .878 r
.29103 .24047 .31661 .27605 .35792 .25337 .33193 .22948 Mtetra
.7 .788 .919 r
.33193 .22948 .35792 .25337 .39936 .23811 .37401 .21004 Mtetra
.671 .75 .91 r
.37401 .21004 .39936 .23811 .44144 .2226 .41655 .19334 Mtetra
.542 .694 .938 r
.41655 .19334 .44144 .2226 .48408 .2156 .4595 .18792 Mtetra
.749 .783 .88 r
.4595 .18792 .48408 .2156 .52762 .19086 .50361 .16065 Mtetra
.664 .741 .908 r
.50361 .16065 .52762 .19086 .57175 .17461 .5482 .14391 Mtetra
.5482 .14391 .57175 .17461 .61737 .18366 .59353 .12689 Mtetra
.635 .591 .787 r
.59353 .12689 .61737 .18366 .66216 .14131 .6396 .10959 Mtetra
.664 .741 .908 r
.6396 .10959 .66216 .14131 .70847 .12424 .68645 .092 Mtetra
.68645 .092 .70847 .12424 .75556 .1069 .73408 .07411 Mtetra
.06574 .28771 .09432 .31433 .13248 .3 .10421 .27298 Mtetra
.10421 .27298 .13248 .3 .17121 .28546 .14328 .25802 Mtetra
.661 .741 .909 r
.14328 .25802 .17121 .28546 .21027 .2734 .18292 .24307 Mtetra
.664 .723 .893 r
.18292 .24307 .21027 .2734 .25047 .2557 .22324 .2274 Mtetra
.664 .741 .908 r
.22324 .2274 .25047 .2557 .29103 .24047 .26417 .21173 Mtetra
.567 .708 .936 r
.26417 .21173 .29103 .24047 .33193 .22948 .30513 .20432 Mtetra
.738 .792 .896 r
.30513 .20432 .33193 .22948 .37401 .21004 .34799 .17964 Mtetra
.663 .735 .904 r
.34799 .17964 .37401 .21004 .41655 .19334 .39091 .1632 Mtetra
.664 .741 .908 r
.39091 .1632 .41655 .19334 .4595 .18792 .43453 .1465 Mtetra
.649 .664 .851 r
.43453 .1465 .4595 .18792 .50361 .16065 .47886 .13003 Mtetra
.668 .747 .909 r
.47886 .13003 .50361 .16065 .5482 .14391 .52394 .11227 Mtetra
.664 .741 .908 r
.52394 .11227 .5482 .14391 .59353 .12689 .56976 .09472 Mtetra
.56976 .09472 .59353 .12689 .6396 .10959 .61635 .07688 Mtetra
.592 .71 .926 r
.61635 .07688 .6396 .10959 .68645 .092 .66409 .06614 Mtetra
.724 .823 .926 r
.66409 .06614 .68645 .092 .73408 .07411 .71197 .04106 Mtetra
.664 .741 .908 r
.03634 .26033 .06574 .28771 .10421 .27298 .07513 .24518 Mtetra
.07513 .24518 .10421 .27298 .14328 .25802 .11454 .22979 Mtetra
.11454 .22979 .14328 .25802 .18292 .24307 .15456 .21416 Mtetra
.663 .739 .907 r
.15456 .21416 .18292 .24307 .22324 .2274 .19522 .19828 Mtetra
.664 .741 .908 r
.19522 .19828 .22324 .2274 .26417 .21173 .23652 .18214 Mtetra
.654 .738 .912 r
.23652 .18214 .26417 .21173 .30513 .20432 .27841 .16675 Mtetra
.664 .69 .865 r
.27841 .16675 .30513 .20432 .34799 .17964 .32115 .14909 Mtetra
.664 .741 .908 r
.32115 .14909 .34799 .17964 .39091 .1632 .3645 .13215 Mtetra
.3645 .13215 .39091 .1632 .43453 .1465 .40857 .11494 Mtetra
.632 .73 .918 r
.40857 .11494 .43453 .1465 .47886 .13003 .45329 .10074 Mtetra
.694 .773 .912 r
.45329 .10074 .47886 .13003 .52394 .11227 .49893 .07965 Mtetra
.657 .739 .91 r
.49893 .07965 .52394 .11227 .56976 .09472 .54526 .06232 Mtetra
.671 .75 .91 r
.54526 .06232 .56976 .09472 .61635 .07688 .59236 .04315 Mtetra
.664 .741 .908 r
.59236 .04315 .61635 .07688 .66409 .06614 .64029 .02443 Mtetra
.657 .689 .869 r
.64029 .02443 .66409 .06614 .71197 .04106 .68905 .00539 Mtetra
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.19579 .19302 m
.20033 .19776 L
s
[(5)] .18671 .18355 .95953 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(10)] .40046 .09948 .82054 1 Mshowa
.64007 .01906 m
.64377 .02448 L
s
[(15)] .63268 .00821 .68154 1 Mshowa
.125 Mabswid
.23703 .17687 m
.23971 .17975 L
s
.27893 .16047 m
.28157 .16339 L
s
.32151 .14379 m
.32411 .14675 L
s
.36479 .12685 m
.36734 .12985 L
s
.4535 .09211 m
.45595 .0952 L
s
.49897 .07431 m
.50137 .07743 L
s
.54521 .0562 m
.54755 .05937 L
s
.59224 .03779 m
.59452 .041 L
s
.1552 .20892 m
.15797 .21172 L
s
.11524 .22456 m
.11804 .22733 L
s
.0759 .23997 m
.07874 .24269 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -11 0 ]
[.5 .82364 11 12.5625 ]
[.18671 .18355 -5.87859 -9 ]
[.18671 .18355 .12141 0 ]
[.40046 .09948 -10.9232 -9 ]
[.40046 .09948 1.07679 0 ]
[.63268 .00821 -10.0892 -9 ]
[.63268 .00821 1.91076 0 ]
[.78828 .12893 0 -6.13096 ]
[.78828 .12893 6 2.86904 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 12 3.00782 ]
[.96661 .40202 0 -5.87517 ]
[.96661 .40202 12 3.12483 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01613 .31515 -18 -2.78462 ]
[.01613 .31515 0 6.21538 ]
[.00788 .36685 -18 -2.82847 ]
[.00788 .36685 0 6.17153 ]
[-0.00064 .42028 -18 -2.87394 ]
[-0.00064 .42028 0 6.12606 ]
[-0.00946 .47554 -18 -2.92114 ]
[-0.00946 .47554 0 6.07886 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.19579 .19302 m
.20033 .19776 L
s
[(5)] .18671 .18355 .95953 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(10)] .40046 .09948 .82054 1 Mshowa
.64007 .01906 m
.64377 .02448 L
s
[(15)] .63268 .00821 .68154 1 Mshowa
.125 Mabswid
.23703 .17687 m
.23971 .17975 L
s
.27893 .16047 m
.28157 .16339 L
s
.32151 .14379 m
.32411 .14675 L
s
.36479 .12685 m
.36734 .12985 L
s
.4535 .09211 m
.45595 .0952 L
s
.49897 .07431 m
.50137 .07743 L
s
.54521 .0562 m
.54755 .05937 L
s
.59224 .03779 m
.59452 .041 L
s
.1552 .20892 m
.15797 .21172 L
s
.11524 .22456 m
.11804 .22733 L
s
.0759 .23997 m
.07874 .24269 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.77594 .1334 m
.76978 .13563 L
s
[(5)] .78828 .12893 -1 .36244 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(10)] .88369 .27502 -1 .3316 Mshowa
.95406 .40586 m
.94779 .40778 L
s
[(15)] .96661 .40202 -1 .30559 Mshowa
.125 Mabswid
.79613 .16428 m
.79242 .1656 L
s
.81573 .19425 m
.81201 .19555 L
s
.83476 .22337 m
.83104 .22465 L
s
.85326 .25166 m
.84953 .25292 L
s
.88871 .30589 m
.88497 .30711 L
s
.90572 .33191 m
.90197 .33311 L
s
.92227 .35722 m
.91851 .3584 L
s
.93838 .38186 m
.93462 .38303 L
s
.75514 .10158 m
.75145 .10294 L
s
.73369 .06877 m
.73001 .07015 L
s
.71157 .03492 m
.70789 .03634 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02839 .31048 m
.03452 .30814 L
s
[(200)] .01613 .31515 1 -0.38119 Mshowa
.02018 .36228 m
.02633 .35999 L
s
[(400)] .00788 .36685 1 -0.37145 Mshowa
.0117 .41582 m
.01787 .41359 L
s
[(600)] -0.00064 .42028 1 -0.36135 Mshowa
.00292 .47119 m
.00911 .46902 L
s
[(800)] -0.00946 .47554 1 -0.35086 Mshowa
.125 Mabswid
.03437 .27272 m
.03804 .27129 L
s
.0324 .2852 m
.03607 .28379 L
s
.0304 .29779 m
.03408 .29638 L
s
.02636 .32327 m
.03004 .32187 L
s
.02432 .33616 m
.028 .33478 L
s
.02226 .34917 m
.02595 .34779 L
s
.01809 .3755 m
.02178 .37413 L
s
.01597 .38883 m
.01967 .38747 L
s
.01384 .40227 m
.01754 .40092 L
s
.00953 .42949 m
.01324 .42816 L
s
.00735 .44327 m
.01105 .44195 L
s
.00514 .45717 m
.00885 .45586 L
s
.00068 .48533 m
.0044 .48404 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.86 .996 .805 r
.38341 .61375 .40512 .60371 .43937 .59547 .41918 .57408 Mtetra
.657 .72 .895 r
.41918 .57408 .43937 .59547 .47416 .583 .45419 .56409 Mtetra
.671 .75 .91 r
.45419 .56409 .47416 .583 .50935 .57244 .48969 .55259 Mtetra
.664 .741 .908 r
.48969 .55259 .50935 .57244 .54513 .58505 .52564 .54164 Mtetra
.617 .575 .785 r
.52564 .54164 .54513 .58505 .58111 .55092 .56212 .5354 Mtetra
.712 .805 .923 r
.56212 .5354 .58111 .55092 .6234 .74656 .59898 .51929 Mtetra
.592 .417 .613 r
.59898 .51929 .6234 .74656 .65477 .52882 .63638 .5079 Mtetra
.573 .708 .934 r
.63638 .5079 .65477 .52882 .69233 .51755 .67464 .50407 Mtetra
.738 .846 .931 r
.67464 .50407 .69233 .51755 .73041 .50613 .71272 .48463 Mtetra
.664 .741 .908 r
.71272 .48463 .73041 .50613 .76899 .49455 .75168 .47276 Mtetra
.619 .724 .921 r
.75168 .47276 .76899 .49455 .80811 .48282 .79151 .46498 Mtetra
.703 .799 .925 r
.79151 .46498 .80811 .48282 .84775 .47092 .83121 .44853 Mtetra
.664 .741 .908 r
.83121 .44853 .84775 .47092 .88795 .45886 .87181 .43616 Mtetra
.608 .718 .923 r
.87181 .43616 .88795 .45886 .92871 .44664 .91363 .4291 Mtetra
.714 .818 .93 r
.91363 .4291 .92871 .44664 .97104 .44162 .95473 .41089 Mtetra
.685 .668 .828 r
.36271 .58393 .38341 .61375 .41918 .57408 .3979 .56926 Mtetra
.495 0 0 r
.3979 .56926 .41918 .57408 .45419 .56409 .43259 .58722 Mtetra
.805 .949 .605 r
.43259 .58722 .45419 .56409 .48969 .55259 .46955 .53226 Mtetra
.638 .734 .918 r
.46955 .53226 .48969 .55259 .52564 .54164 .5058 .52335 Mtetra
.687 .771 .915 r
.5058 .52335 .52564 .54164 .56212 .5354 .54255 .50966 Mtetra
.662 .698 .873 r
.54255 .50966 .56212 .5354 .59898 .51929 .57979 .49813 Mtetra
.911 .509 .134 r
.57979 .49813 .59898 .51929 .63638 .5079 .62097 .6091 Mtetra
0 0 .163 r
.62097 .6091 .63638 .5079 .67464 .50407 .6558 .4746 Mtetra
.658 .676 .856 r
.6558 .4746 .67464 .50407 .71272 .48463 .6946 .46283 Mtetra
.666 .744 .909 r
.6946 .46283 .71272 .48463 .75168 .47276 .73392 .45042 Mtetra
.664 .741 .908 r
.73392 .45042 .75168 .47276 .79151 .46498 .77379 .43807 Mtetra
.642 .695 .884 r
.77379 .43807 .79151 .46498 .83121 .44853 .81444 .42794 Mtetra
.679 .771 .92 r
.81444 .42794 .83121 .44853 .87181 .43616 .85531 .41358 Mtetra
.67 .751 .911 r
.85531 .41358 .87181 .43616 .91363 .4291 .89683 .39998 Mtetra
.658 .693 .871 r
.89683 .39998 .91363 .4291 .95473 .41089 .93909 .3874 Mtetra
.424 .496 .829 r
.34209 .54503 .36271 .58393 .3979 .56926 .37622 .557 Mtetra
.603 .817 .982 r
.37622 .557 .3979 .56926 .43259 .58722 .41198 .54846 Mtetra
.762 .661 .75 r
.41198 .54846 .43259 .58722 .46955 .53226 .44892 .51142 Mtetra
.664 .741 .908 r
.44892 .51142 .46955 .53226 .5058 .52335 .48549 .49991 Mtetra
.623 .707 .906 r
.48549 .49991 .5058 .52335 .54255 .50966 .52255 .49224 Mtetra
.549 .745 .967 r
.52255 .49224 .54255 .50966 .57979 .49813 .56025 .48822 Mtetra
.057 .564 .882 r
.56025 .48822 .57979 .49813 .62097 .6091 .59893 .49657 Mtetra
.677 .51 .652 r
.59893 .49657 .62097 .6091 .6558 .4746 .63684 .45254 Mtetra
.598 .72 .929 r
.63684 .45254 .6558 .4746 .6946 .46283 .67627 .44616 Mtetra
0 .107 .59 r
.67627 .44616 .6946 .46283 .73392 .45042 .71885 .48117 Mtetra
0 0 0 r
.71885 .48117 .73392 .45042 .77379 .43807 .75627 .41913 Mtetra
.465 .7 .97 r
.75627 .41913 .77379 .43807 .81444 .42794 .79833 .42003 Mtetra
.741 .939 .95 r
.79833 .42003 .81444 .42794 .85531 .41358 .83899 .39665 Mtetra
.694 .826 .946 r
.83899 .39665 .85531 .41358 .89683 .39998 .88072 .37982 Mtetra
.528 .722 .962 r
.88072 .37982 .89683 .39998 .93909 .3874 .92475 .37711 Mtetra
.865 .981 .848 r
.31844 .55089 .34209 .54503 .37622 .557 .35548 .51317 Mtetra
.644 .592 .781 r
.35548 .51317 .37622 .557 .41198 .54846 .39138 .50169 Mtetra
.474 .492 .796 r
.39138 .50169 .41198 .54846 .44892 .51142 .42713 .51172 Mtetra
.406 .856 .898 r
.42713 .51172 .44892 .51142 .48549 .49991 .46423 .50119 Mtetra
.75 .983 .91 r
.46423 .50119 .48549 .49991 .52255 .49224 .50198 .47504 Mtetra
.742 .806 .903 r
.50198 .47504 .52255 .49224 .56025 .48822 .53996 .45442 Mtetra
.491 .575 .867 r
.53996 .45442 .56025 .48822 .59893 .49657 .57868 .45952 Mtetra
.745 .674 .782 r
.57868 .45952 .59893 .49657 .63684 .45254 .61737 .42943 Mtetra
.262 .544 .924 r
.61737 .42943 .63684 .45254 .67627 .44616 .65795 .44251 Mtetra
.866 .962 .862 r
.65795 .44251 .67627 .44616 .71885 .48117 .69699 .40396 Mtetra
.621 .509 .705 r
.69699 .40396 .71885 .48117 .75627 .41913 .73766 .39096 Mtetra
.169 .435 .868 r
.73766 .39096 .75627 .41913 .79833 .42003 .78182 .41429 Mtetra
.817 .969 .9 r
.78182 .41429 .79833 .42003 .83899 .39665 .82237 .38162 Mtetra
.545 .797 .991 r
.82237 .38162 .83899 .39665 .88072 .37982 .86579 .37472 Mtetra
.669 .957 .945 r
.86579 .37472 .88072 .37982 .92475 .37711 .90822 .35265 Mtetra
.381 .436 .793 r
.29746 .50347 .31844 .55089 .35548 .51317 .33153 .5204 Mtetra
.869 .987 .832 r
.33153 .5204 .35548 .51317 .39138 .50169 .36938 .48009 Mtetra
.21 .537 .925 r
.36938 .48009 .39138 .50169 .42713 .51172 .40522 .49186 Mtetra
.808 .782 .829 r
.40522 .49186 .42713 .51172 .46423 .50119 .44323 .45819 Mtetra
.658 .609 .789 r
.44323 .45819 .46423 .50119 .50198 .47504 .48101 .44379 Mtetra
.549 .625 .88 r
.48101 .44379 .50198 .47504 .53996 .45442 .51924 .4428 Mtetra
.765 .877 .928 r
.51924 .4428 .53996 .45442 .57868 .45952 .55806 .41946 Mtetra
.493 .544 .837 r
.55806 .41946 .57868 .45952 .61737 .42943 .59785 .42568 Mtetra
.752 .964 .934 r
.59785 .42568 .61737 .42943 .65795 .44251 .63756 .40019 Mtetra
.62 .602 .811 r
.63756 .40019 .65795 .44251 .69699 .40396 .67835 .3914 Mtetra
.615 .851 .988 r
.67835 .3914 .69699 .40396 .73766 .39096 .71965 .3793 Mtetra
.356 .744 .987 r
.71965 .3793 .73766 .39096 .78182 .41429 .76248 .37902 Mtetra
.756 .705 .803 r
.76248 .37902 .78182 .41429 .82237 .38162 .80358 .34768 Mtetra
.649 .669 .856 r
.80358 .34768 .82237 .38162 .86579 .37472 .84675 .33497 Mtetra
.709 .667 .806 r
.84675 .33497 .86579 .37472 .90822 .35265 .88931 .31104 Mtetra
.802 .899 .911 r
.27318 .49675 .29746 .50347 .33153 .5204 .31031 .47 Mtetra
.594 .549 .774 r
.31031 .47 .33153 .5204 .36938 .48009 .34643 .46503 Mtetra
.734 .824 .92 r
.34643 .46503 .36938 .48009 .40522 .49186 .38383 .44569 Mtetra
.601 .57 .792 r
.38383 .44569 .40522 .49186 .44323 .45819 .42116 .43971 Mtetra
0 .246 .707 r
.42116 .43971 .44323 .45819 .48101 .44379 .45856 .46367 Mtetra
.823 .966 .645 r
.45856 .46367 .48101 .44379 .51924 .4428 .49803 .40793 Mtetra
.63 .644 .846 r
.49803 .40793 .51924 .4428 .55806 .41946 .5372 .39834 Mtetra
.223 .557 .934 r
.5372 .39834 .55806 .41946 .59785 .42568 .57736 .40999 Mtetra
.851 .847 .839 r
.57736 .40999 .59785 .42568 .63756 .40019 .61724 .36997 Mtetra
.672 .699 .866 r
.61724 .36997 .63756 .40019 .67835 .3914 .65808 .355 Mtetra
.655 .655 .838 r
.65808 .355 .67835 .3914 .71965 .3793 .69957 .34128 Mtetra
.654 .647 .831 r
.69957 .34128 .71965 .3793 .76248 .37902 .74167 .32736 Mtetra
.581 .552 .787 r
.74167 .32736 .76248 .37902 .80358 .34768 .78525 .32352 Mtetra
.559 .713 .944 r
.78525 .32352 .80358 .34768 .84675 .33497 .82969 .3186 Mtetra
.812 .882 .896 r
.82969 .3186 .84675 .33497 .88931 .31104 .87203 .28629 Mtetra
.127 .354 .816 r
.25056 .4598 .27318 .49675 .31031 .47 .28431 .48275 Mtetra
.883 .992 .786 r
.28431 .48275 .31031 .47 .34643 .46503 .32368 .4352 Mtetra
.645 .679 .868 r
.32368 .4352 .34643 .46503 .38383 .44569 .36093 .42431 Mtetra
.634 .748 .931 r
.36093 .42431 .38383 .44569 .42116 .43971 .3987 .41421 Mtetra
.624 .71 .908 r
.3987 .41421 .42116 .43971 .45856 .46367 .43705 .40515 Mtetra
.578 .523 .757 r
.43705 .40515 .45856 .46367 .49803 .40793 .47596 .40153 Mtetra
.818 .934 .907 r
.47596 .40153 .49803 .40793 .5372 .39834 .51575 .37059 Mtetra
.45 .62 .924 r
.51575 .37059 .5372 .39834 .57736 .40999 .55602 .37461 Mtetra
.744 .696 .806 r
.55602 .37461 .57736 .40999 .61724 .36997 .59659 .34584 Mtetra
.686 .758 .906 r
.59659 .34584 .61724 .36997 .65808 .355 .63782 .32952 Mtetra
.657 .739 .91 r
.63782 .32952 .65808 .355 .69957 .34128 .67977 .31615 Mtetra
0 .327 .809 r
.67977 .31615 .69957 .34128 .74167 .32736 .72505 .34504 Mtetra
.524 .82 .487 r
.72505 .34504 .74167 .32736 .78525 .32352 .76652 .30039 Mtetra
.724 .795 .908 r
.76652 .30039 .78525 .32352 .82969 .3186 .80993 .27874 Mtetra
.696 .67 .82 r
.80993 .27874 .82969 .3186 .87203 .28629 .85381 .25686 Mtetra
.824 .972 .893 r
.2239 .46222 .25056 .4598 .28431 .48275 .26236 .43007 Mtetra
.662 .583 .756 r
.26236 .43007 .28431 .48275 .32368 .4352 .29993 .41188 Mtetra
.524 .694 .946 r
.29993 .41188 .32368 .4352 .36093 .42431 .33697 .40956 Mtetra
.752 .841 .919 r
.33697 .40956 .36093 .42431 .3987 .41421 .37571 .38735 Mtetra
.637 .709 .899 r
.37571 .38735 .3987 .41421 .43705 .40515 .41439 .37675 Mtetra
.691 .717 .87 r
.41439 .37675 .43705 .40515 .47596 .40153 .45383 .35967 Mtetra
.628 .615 .818 r
.45383 .35967 .47596 .40153 .51575 .37059 .4937 .34893 Mtetra
.419 .672 .966 r
.4937 .34893 .51575 .37059 .55602 .37461 .53427 .35125 Mtetra
.669 .763 .92 r
.53427 .35125 .55602 .37461 .59659 .34584 .57561 .3365 Mtetra
.753 .925 .946 r
.57561 .3365 .59659 .34584 .63782 .32952 .61725 .31167 Mtetra
.16 .565 .932 r
.61725 .31167 .63782 .32952 .67977 .31615 .66081 .32281 Mtetra
.826 .994 .75 r
.66081 .32281 .67977 .31615 .72505 .34504 .70238 .2751 Mtetra
.627 .534 .729 r
.70238 .2751 .72505 .34504 .76652 .30039 .74597 .25918 Mtetra
.637 .637 .833 r
.74597 .25918 .76652 .30039 .80993 .27874 .79048 .24623 Mtetra
.659 .703 .88 r
.79048 .24623 .80993 .27874 .85381 .25686 .83555 .23108 Mtetra
.605 .575 .793 r
.20108 .41504 .2239 .46222 .26236 .43007 .23756 .40722 Mtetra
.503 .695 .955 r
.23756 .40722 .26236 .43007 .29993 .41188 .27418 .40556 Mtetra
.82 .915 .903 r
.27418 .40556 .29993 .41188 .33697 .40956 .31353 .3747 Mtetra
.523 .606 .877 r
.31353 .3747 .33697 .40956 .37571 .38735 .35134 .37461 Mtetra
.782 .87 .913 r
.35134 .37461 .37571 .38735 .41439 .37675 .39115 .34813 Mtetra
.304 .546 .917 r
.39115 .34813 .41439 .37675 .45383 .35967 .4301 .35881 Mtetra
.85 .972 .873 r
.4301 .35881 .45383 .35967 .4937 .34893 .4711 .32076 Mtetra
.671 .724 .889 r
.4711 .32076 .4937 .34893 .53427 .35125 .51199 .30554 Mtetra
.645 .613 .804 r
.51199 .30554 .53427 .35125 .57561 .3365 .55348 .29108 Mtetra
.554 .571 .825 r
.55348 .29108 .57561 .3365 .61725 .31167 .59589 .28899 Mtetra
.764 .807 .888 r
.59589 .28899 .61725 .31167 .66081 .32281 .63839 .26198 Mtetra
.442 .449 .771 r
.63839 .26198 .66081 .32281 .70238 .2751 .68335 .27658 Mtetra
.834 .999 .813 r
.68335 .27658 .70238 .2751 .74597 .25918 .72603 .23272 Mtetra
.675 .761 .915 r
.72603 .23272 .74597 .25918 .79048 .24623 .77076 .21586 Mtetra
.577 .688 .917 r
.77076 .21586 .79048 .24623 .83555 .23108 .81715 .20901 Mtetra
.626 .731 .923 r
.17542 .39115 .20108 .41504 .23756 .40722 .21231 .38133 Mtetra
.684 .733 .888 r
.21231 .38133 .23756 .40722 .27418 .40556 .25033 .36552 Mtetra
.557 .593 .845 r
.25033 .36552 .27418 .40556 .31353 .3747 .28787 .36264 Mtetra
.735 .875 .946 r
.28787 .36264 .31353 .3747 .35134 .37461 .32736 .34155 Mtetra
.031 .345 .823 r
.32736 .34155 .35134 .37461 .39115 .34813 .36499 .36519 Mtetra
.873 .987 .715 r
.36499 .36519 .39115 .34813 .4301 .35881 .4072 .30799 Mtetra
.639 .591 .784 r
.4072 .30799 .4301 .35881 .4711 .32076 .44786 .29331 Mtetra
.661 .732 .903 r
.44786 .29331 .4711 .32076 .51199 .30554 .48913 .27891 Mtetra
.516 .684 .943 r
.48913 .27891 .51199 .30554 .55348 .29108 .53106 .27642 Mtetra
.749 .88 .94 r
.53106 .27642 .55348 .29108 .59589 .28899 .57364 .25216 Mtetra
.681 .684 .846 r
.57364 .25216 .59589 .28899 .63839 .26198 .6168 .23336 Mtetra
.663 .737 .905 r
.6168 .23336 .63839 .26198 .68335 .27658 .6607 .21779 Mtetra
.495 .492 .783 r
.6607 .21779 .68335 .27658 .72603 .23272 .7066 .22406 Mtetra
.632 .925 .974 r
.7066 .22406 .72603 .23272 .77076 .21586 .752 .20475 Mtetra
.817 .95 .907 r
.752 .20475 .77076 .21586 .81715 .20901 .79661 .16955 Mtetra
.661 .731 .901 r
.1492 .36542 .17542 .39115 .21231 .38133 .1867 .3521 Mtetra
.663 .707 .881 r
.1867 .3521 .21231 .38133 .25033 .36552 .2248 .33809 Mtetra
.662 .724 .895 r
.2248 .33809 .25033 .36552 .28787 .36264 .26345 .32412 Mtetra
.518 .59 .866 r
.26345 .32412 .28787 .36264 .32736 .34155 .30168 .32393 Mtetra
.782 .833 .891 r
.30168 .32393 .32736 .34155 .36499 .36519 .34248 .29579 Mtetra
.62 .529 .73 r
.34248 .29579 .36499 .36519 .4072 .30799 .38291 .28094 Mtetra
.623 .726 .92 r
.38291 .28094 .4072 .30799 .44786 .29331 .42382 .27005 Mtetra
.35 .64 .963 r
.42382 .27005 .44786 .29331 .48913 .27891 .46517 .27469 Mtetra
.848 .963 .879 r
.46517 .27469 .48913 .27891 .53106 .27642 .50795 .23574 Mtetra
.652 .653 .838 r
.50795 .23574 .53106 .27642 .57364 .25216 .55094 .2202 Mtetra
.524 .654 .917 r
.55094 .2202 .57364 .25216 .6168 .23336 .59491 .21768 Mtetra
.746 .885 .943 r
.59491 .21768 .6168 .23336 .6607 .21779 .63913 .19263 Mtetra
.692 .788 .924 r
.63913 .19263 .6607 .21779 .7066 .22406 .68411 .17334 Mtetra
.65 .614 .801 r
.68411 .17334 .7066 .22406 .752 .20475 .72984 .15553 Mtetra
.57 .581 .825 r
.72984 .15553 .752 .20475 .79661 .16955 .77734 .14981 Mtetra
.421 .653 .955 r
.12213 .34022 .1492 .36542 .1867 .3521 .15816 .34194 Mtetra
.804 .885 .904 r
.15816 .34194 .1867 .3521 .2248 .33809 .19838 .31214 Mtetra
.664 .741 .908 r
.19838 .31214 .2248 .33809 .26345 .32412 .23736 .29778 Mtetra
.23736 .29778 .26345 .32412 .30168 .32393 .27694 .2832 Mtetra
.587 .617 .849 r
.27694 .2832 .30168 .32393 .34248 .29579 .31661 .27605 Mtetra
.737 .821 .917 r
.31661 .27605 .34248 .29579 .38291 .28094 .35792 .25337 Mtetra
.664 .741 .908 r
.35792 .25337 .38291 .28094 .42382 .27005 .39936 .23811 Mtetra
.661 .711 .885 r
.39936 .23811 .42382 .27005 .46517 .27469 .44144 .2226 Mtetra
.58 .567 .804 r
.44144 .2226 .46517 .27469 .50795 .23574 .48408 .2156 Mtetra
.745 .838 .922 r
.48408 .2156 .50795 .23574 .55094 .2202 .52762 .19086 Mtetra
.664 .741 .908 r
.52762 .19086 .55094 .2202 .59491 .21768 .57175 .17461 Mtetra
.411 .525 .862 r
.57175 .17461 .59491 .21768 .63913 .19263 .61737 .18366 Mtetra
.859 .956 .872 r
.61737 .18366 .63913 .19263 .68411 .17334 .66216 .14131 Mtetra
.663 .731 .901 r
.66216 .14131 .68411 .17334 .72984 .15553 .70847 .12424 Mtetra
.664 .741 .908 r
.70847 .12424 .72984 .15553 .77734 .14981 .75556 .1069 Mtetra
.09432 .31433 .12213 .34022 .15816 .34194 .13248 .3 Mtetra
.647 .635 .824 r
.13248 .3 .15816 .34194 .19838 .31214 .17121 .28546 Mtetra
.635 .733 .919 r
.17121 .28546 .19838 .31214 .23736 .29778 .21027 .2734 Mtetra
.691 .77 .912 r
.21027 .2734 .23736 .29778 .27694 .2832 .25047 .2557 Mtetra
.664 .741 .908 r
.25047 .2557 .27694 .2832 .31661 .27605 .29103 .24047 Mtetra
.618 .67 .878 r
.29103 .24047 .31661 .27605 .35792 .25337 .33193 .22948 Mtetra
.7 .788 .919 r
.33193 .22948 .35792 .25337 .39936 .23811 .37401 .21004 Mtetra
.671 .75 .91 r
.37401 .21004 .39936 .23811 .44144 .2226 .41655 .19334 Mtetra
.542 .694 .938 r
.41655 .19334 .44144 .2226 .48408 .2156 .4595 .18792 Mtetra
.749 .783 .88 r
.4595 .18792 .48408 .2156 .52762 .19086 .50361 .16065 Mtetra
.664 .741 .908 r
.50361 .16065 .52762 .19086 .57175 .17461 .5482 .14391 Mtetra
.5482 .14391 .57175 .17461 .61737 .18366 .59353 .12689 Mtetra
.635 .591 .787 r
.59353 .12689 .61737 .18366 .66216 .14131 .6396 .10959 Mtetra
.664 .741 .908 r
.6396 .10959 .66216 .14131 .70847 .12424 .68645 .092 Mtetra
.68645 .092 .70847 .12424 .75556 .1069 .73408 .07411 Mtetra
.06574 .28771 .09432 .31433 .13248 .3 .10421 .27298 Mtetra
.10421 .27298 .13248 .3 .17121 .28546 .14328 .25802 Mtetra
.661 .741 .909 r
.14328 .25802 .17121 .28546 .21027 .2734 .18292 .24307 Mtetra
.664 .723 .893 r
.18292 .24307 .21027 .2734 .25047 .2557 .22324 .2274 Mtetra
.664 .741 .908 r
.22324 .2274 .25047 .2557 .29103 .24047 .26417 .21173 Mtetra
.567 .708 .936 r
.26417 .21173 .29103 .24047 .33193 .22948 .30513 .20432 Mtetra
.738 .792 .896 r
.30513 .20432 .33193 .22948 .37401 .21004 .34799 .17964 Mtetra
.663 .735 .904 r
.34799 .17964 .37401 .21004 .41655 .19334 .39091 .1632 Mtetra
.664 .741 .908 r
.39091 .1632 .41655 .19334 .4595 .18792 .43453 .1465 Mtetra
.649 .664 .851 r
.43453 .1465 .4595 .18792 .50361 .16065 .47886 .13003 Mtetra
.668 .747 .909 r
.47886 .13003 .50361 .16065 .5482 .14391 .52394 .11227 Mtetra
.664 .741 .908 r
.52394 .11227 .5482 .14391 .59353 .12689 .56976 .09472 Mtetra
.56976 .09472 .59353 .12689 .6396 .10959 .61635 .07688 Mtetra
.592 .71 .926 r
.61635 .07688 .6396 .10959 .68645 .092 .66409 .06614 Mtetra
.724 .823 .926 r
.66409 .06614 .68645 .092 .73408 .07411 .71197 .04106 Mtetra
.664 .741 .908 r
.03634 .26033 .06574 .28771 .10421 .27298 .07513 .24518 Mtetra
.07513 .24518 .10421 .27298 .14328 .25802 .11454 .22979 Mtetra
.11454 .22979 .14328 .25802 .18292 .24307 .15456 .21416 Mtetra
.663 .739 .907 r
.15456 .21416 .18292 .24307 .22324 .2274 .19522 .19828 Mtetra
.664 .741 .908 r
.19522 .19828 .22324 .2274 .26417 .21173 .23652 .18214 Mtetra
.654 .738 .912 r
.23652 .18214 .26417 .21173 .30513 .20432 .27841 .16675 Mtetra
.664 .69 .865 r
.27841 .16675 .30513 .20432 .34799 .17964 .32115 .14909 Mtetra
.664 .741 .908 r
.32115 .14909 .34799 .17964 .39091 .1632 .3645 .13215 Mtetra
.3645 .13215 .39091 .1632 .43453 .1465 .40857 .11494 Mtetra
.632 .73 .918 r
.40857 .11494 .43453 .1465 .47886 .13003 .45329 .10074 Mtetra
.694 .773 .912 r
.45329 .10074 .47886 .13003 .52394 .11227 .49893 .07965 Mtetra
.657 .739 .91 r
.49893 .07965 .52394 .11227 .56976 .09472 .54526 .06232 Mtetra
.671 .75 .91 r
.54526 .06232 .56976 .09472 .61635 .07688 .59236 .04315 Mtetra
.664 .741 .908 r
.59236 .04315 .61635 .07688 .66409 .06614 .64029 .02443 Mtetra
.657 .689 .869 r
.64029 .02443 .66409 .06614 .71197 .04106 .68905 .00539 Mtetra
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.19579 .19302 m
.20033 .19776 L
s
[(5)] .18671 .18355 .95953 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(10)] .40046 .09948 .82054 1 Mshowa
.64007 .01906 m
.64377 .02448 L
s
[(15)] .63268 .00821 .68154 1 Mshowa
.125 Mabswid
.23703 .17687 m
.23971 .17975 L
s
.27893 .16047 m
.28157 .16339 L
s
.32151 .14379 m
.32411 .14675 L
s
.36479 .12685 m
.36734 .12985 L
s
.4535 .09211 m
.45595 .0952 L
s
.49897 .07431 m
.50137 .07743 L
s
.54521 .0562 m
.54755 .05937 L
s
.59224 .03779 m
.59452 .041 L
s
.1552 .20892 m
.15797 .21172 L
s
.11524 .22456 m
.11804 .22733 L
s
.0759 .23997 m
.07874 .24269 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[58]:=",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00MP3oool5@0000080oooo00=000000?ooo`3oool0
_@3oool5@0000080oooo00=000000?ooo`3oool0B@3oool007P0oooo00M000000?ooo`3oool0oooo
@000003ooom000000<00oooo00M000000?ooo`3oool0oooo@000003ooom0000004X0oooo001h0?oo
o`03@000003oool0oooo00<0oooo00=000000?ooo`3oool0_P3oool00d000000oooo0?ooo`030?oo
o`03@000003oool0oooo04P0oooo001h0?ooo`04@000003oool0oooo0?ooo`900000`@3oool01400
0000oooo0?ooo`3oool2@00004/0oooo001h0?ooo`05@000003oool0oooo0?oood000000`P3oool0
1D000000oooo0?ooo`3ooom0000004`0oooo001g0?ooo`9000000`3oool3@0000;l0oooo0T000003
0?ooo`=00000BP3oool00?l0ooooT@3oool008H0oooo00<00000@000003oool0a03oool00`000010
00000?ooo`100?ooo`00Q03oool200000080oooo00<000000?ooo`3oool0`03oool200000080oooo
00<000000?ooo`3oool0?P3oool00840oooo0`0000001@3oool0Yk3N0:N`gP2W/=h000000;l0oooo
0`0000001@3oool0Z;?P0:Rch02X/n0000000400oooo001o0?ooo`80000000<0oooo0:N`gP2W/=h0
102W/=h00`3oool000000?ooo`2k0?ooo`80000000<0oooo0:Rch02X/n00102X/n000`3oool00000
0?ooo`0n0?ooo`00O03oool3000000030:N`gT000000Yk3N00L0Yk3N00<0oooo0000003oool0]`3o
ool3000000030:Rch4000000Z;?P00L0Z;?P00<0oooo0000003oool0?@3oool007T0oooo0`000000
103oool0ZKgX0:Vmj02Y_NP90:N`gP030?oood000000oooo0;@0oooo0`000000103oool0ZKgX0:Vm
j02Y_NP90:Rch0030?oood000000oooo03d0oooo001g0?ooo`03000004000000ZKgX00H0ZKgX2P2W
/=h00`3oool000000?ooo`2a0?ooo`03000004000000ZKgX00H0ZKgX2P2X/n000`3oool000000?oo
o`0l0?ooo`00D@3oool5@0000080oooo00=000000?ooo`3oool06@3oool300000080ZkoX202Y_NP8
0:N`gP80^]?/00<0oooo0000003oool0RP3oool5@0000080oooo00=000000?ooo`3oool06@3oool3
00000080[<3X202Y_NP80:Rch080]<g/00<0oooo0000003oool0>`3oool005<0oooo00M000000?oo
o`3oool0oooo@000003ooom0000001L0oooo0`0000050:^oj0T0ZKgX1@2W/=h50;[Ck0030000003o
ool0oooo08/0oooo00M000000?ooo`3oool0oooo@000003ooom0000001L0oooo0`0000050:c0j0T0
ZKgX1@2X/n050;C=k0030000003oool0oooo03X0oooo001C0?ooo`07@000003oool0oooo0?oood00
0000oooo@000000E0?ooo`80000000=000000:^oj02[_nP01P2[_nP80:Vmj0<0Yk3N1`2jdn`00`3o
ool000000?ooo`2;0?ooo`07@000003oool0oooo0?oood000000oooo@000000E0?ooo`80000000=0
00000:c0j02/`>P01P2/`>P80:Vmj0<0Z;?P1`2dcN`00`3oool000000?ooo`0j0?ooo`00D`3oool0
1d000000oooo0?ooo`3ooom000000?oood0000004`3oool2000000<0Z;gX2@2[_nP80:Vmj0X0^]?/
00<0oooo0000003oool0RP3oool01d000000oooo0?ooo`3ooom000000?oood0000004`3oool20000
00<0YkcY2@2/`>P80:Vmj0X0]<g/00<0oooo0000003oool0>@3oool005<0oooo00M000000?ooo`3o
ool0oooo@000003ooom000000100oooo0`0000050:Rmj0T0ZkoX1P2Y_NP309Nek@X0^]?/00<00000
0?ooo`3oool0R@3oool01d000000oooo0?ooo`3ooom000000?oood000000403oool3000000D0YkcY
2@2/`>P60:Vmj0<0W;S/2P2dcN`00`000000oooo0?ooo`0h0?ooo`00DP3oool2@00000@0oooo00=0
00000?ooo`3oool0303oool300000003@000002X_NP0Z;gX00H0Z;gX2@2[_nP909Nek@L0^]?/0`2Y
_NP00`000000oooo0?ooo`270?ooo`900000103oool00d000000oooo0?ooo`0<0?ooo`<0000000=0
00000:Nlj@2W_>T01P2W_>T90:c0j0T0W;S/1`2dcN`30:Vmj0030000003oool0oooo03L0oooo001U
0?ooo`80000000@0oooo0;35j@2`aNT0/<GY202X_NP60:^oj0@0ZKgX202G]Nd40;[Ck0H0ZKgX00<0
00000?ooo`3oool0VP3oool200000080oooo0P2db^X80:Nlj@H0[<3X102Y_NP809bhk0@0]<g/1P2Y
_NP00`000000oooo0?ooo`0g0?ooo`00HP3oool01000001000000000003oool50;35j@T0Z;gX2@2Y
_NP909Nek@X0ZKgX00<000000?ooo`3oool0UP3oool00`0000100000000000020?ooo`@0]<[Z2@2W
_>T90:Vmj0T0W;S/2P2Y_NP00`000000oooo0?ooo`0f0?ooo`00H03oool2000000030?ooo`2`aNT0
/<GY00L0/<GY1P2X_NP<0:Vmj0H0UkG]302Y_NP00`3oool000000?ooo`2D0?ooo`8000000`3oool7
0;C:jPH0YkcY302Y_NP609bhk0`0ZKgX00<0oooo0000003oool0=P3oool005d0oooo0`000000103o
ool0X[_Z0::kjP2R^nX80;35j@@0Z;gX3P2Y_NP409Nek@l0ZKgX00<000000?ooo`3oool0103oool0
0d000000oooo0?ooo`290?ooo`<000000`3oool90;C:jP@0YkcY3P2Y_NP409bhk0l0ZKgX00<00000
0?ooo`3oool0103oool00d000000oooo0?ooo`0^0?ooo`00F`3oool01000001000000?ooo`3oool5
0::kjPT0/<GY902Y_NP00`3oool000000?ooo`030?ooo`03@000003ooom0000008P0oooo00<00000
@000003oool00`3oool309jik0T0]<[Z902Y_NP00`3oool000000?ooo`030?ooo`03@000003ooom0
000002l0oooo001H0?ooo`<0000000<0oooo0::kjP2R^nX01`2R^nX60;35j@<0ZkoX3`2Y_NP30::E
aa80ZKgX00<0oooo0000003oool0103oool00d000000oooo0?ooo`230?ooo`<0000000<0oooo09ji
k02N^N`01`2N^N`60;C:jQ80ZKgX0`2RV<TB0:Vmj0030?ooo`000000oooo00@0oooo00=000000?oo
o`3oool0;@3oool005D0oooo0`0000020?ooo`<0ZKgX202R^nX40;35j@H0ZkoX2@2Y_NP90::Eaa40
ZKgX00<0oooo0000003oool00P3oool2@00008<0oooo0`0000020?ooo`<0ZKgX202N^N`40;C:jPl0
ZKgX2@2RV<TA0:Vmj0030?ooo`000000oooo0080oooo0T00000`0?ooo`00=`3oool00d000000oooo
0?ooo`0I0?ooo`80000000=000000:Vmj02Y_NP01P2Y_NP80::kjPT0ZkoX2@2Y_NP90::Ea`L0ZKgX
0`2Y^ND80:Vmj0050?ooo`000000oooo0?oood000000IP3oool00d000000oooo0?ooo`0I0?ooo`80
000000=000000:Vmj02Y_NP01P2Y_NP809jik180ZKgX2@2RV<T70:Vmj0<0ZK[V202Y_NP01@3oool0
00000?ooo`3ooom000000340oooo000f0?ooo`03@000003ooom0000001L0oooo0`00000<0:Vmj0D0
X[_Z0`2V[=/90:^oj0T0ZKgX2@2RULL40:Vmj0D0ZKWU202Y_NP014000000oooo0000003oool3@000
06<0oooo00=000000?oood0000005`3oool3000000`0ZKgX1@2N^N`30:N[fQ80ZKgX2@2RV<T40:Vm
j0D0ZK[V202Y_NP014000000oooo0000003oool3@00002l0oooo000h0?ooo`03@000003oool0oooo
01<0oooo00<00000@000003oool03`2Y_NP80:J/f`T0ZkoX202Y_NP:0::Ea`T0ZKWU202Y_NP00`3o
ool000000?ooo`1X0?ooo`03@000003oool0oooo01<0oooo00<00000@000003oool03`2Y_NP80:N[
fQ40ZKgX2P2RV<T90:VjiPP0ZKgX00<0oooo0000003oool0<P3oool003H0oooo0T00000C0?ooo`<0
00004P2Y_NP80:J/f`L0ZkoX2`2Y_NP80::Ea`80gOOL202Y^ND80:Vmj080oooo00<000000?ooo`3o
ool0I03oool2@00001<0oooo0`00000B0:Vmj0P0Yj_J4P2Y_NP80::Hb@80f_?P202Y^^H80:Vmj080
oooo00<000000?ooo`3oool0<03oool003H0oooo00=000000?ooo`3oool0403oool2000000040?oo
o`2[/mh0Zk?N0:^cgQ80ZKgX202V[=/40:^oj0d0ZKgX1`2RULL30=ggg0T0ZKWU202@U=@20?ooo`03
0000003oool0oooo06<0oooo00=000000?ooo`3oool0403oool2000000040?ooo`2X[md0Z:oM0:R_
gA80ZKgX202WZmXA0:Vmj0L0XYS90`3Jln090:VjiPP0TI7@0P3oool00`000000oooo0?ooo`0_0?oo
o`00=P3oool3@00000d0oooo0P0000000d000000oooo0:^cgP050:^cgQ40ZKgX2@2V[=/A0:Vmj0D0
XYG71@3Mmm`60:Vii@80Z:3>2@2@U=@00`3ooom000000?ooo`1T0?ooo`=000003@3oool200000003
@000002X[md0Z:oM00D0Z:oM4@2Y_NP90:N[fQ40ZKgX1@2RV<T50=[ch0H0ZK[V0P2VW<`9096Ad003
0?oood000000oooo0300oooo00140?ooo`8000000P3oool90:^cgPH0ZKgX0`2Y_>L80:Vmj0L0YZcK
0P2ma^8@0:Vmj0<0XYG71`3Mmm`40:Vii@D0Z:3>2@2@U=@00`3oool000000?ooo`1a0?ooo`800000
0`2X_NP80:R_g@H0ZKgX0`2Y_>L80:Vmj0L0Yj_J0P2nb>4@0:Vmj0<0XYS91`3Jln040:VjiPD0YYc<
2@2ATM000`3oool000000?ooo`0_0?ooo`00@@3oool00`0000100000000000020?ooo`<0Y[cY2@2[
/mh90:Vli`L0ZKgX1@2V[=/50;g6hQ00ZKgX00<0XYG70=ggg03Mmm`01`3Mmm`80:RPcPP0T9CD0P3?
knT00`3oool000000?ooo`1]0?ooo`03000004000000000000D0Z;gX2@2X[md90:Vli`L0ZKgX1@2W
ZmX50;k8hA00ZKgX00<0XYS90=[ch03Jln001`3Jln080:JLc0P0TI7@0P3Dmn@00`3oool000000?oo
o`0^0?ooo`00?P3oool3000000T0Y[cY1`2[/mh20;[7i0P0ZKcW202Y_NP20:J/f`P0_LKR2@2Y_NP6
0664gPP0gOOL0P2_bNd90:RPcPD0T9CD103?knT00`3oool000000?ooo`1Z0?ooo`<000002@2X_NP7
0:R_g@80_<_V202Y_>L80:Vmj080Yj_J202nb>490:Vmj0H0JhOL203Jln020:o8k0T0YYc<1P2ATM03
0=Cgi0030?ooo`000000oooo02h0oooo000l0?ooo`80000000@0oooo0:Vmj02Y_NP0ZKgX202V_>T5
0:^cgPD0^/OT202Y_>L70:Vmj0/0_LKR202Y_NP90664gPP0[lW]202XX<h4092De0H0cnoY00<0oooo
0000003oool0I`3oool2000000040?ooo`2Y_NP0ZKgX0:Vmj0T0Z;gX102X[md50;c;iPP0ZKcW1`2Y
_NP;0;k8h@P0ZKgX2@1[Qm`80:o8k0P0YYc<1@2ATM050=Cgi0030?ooo`000000oooo02d0oooo000i
0?ooo`<0000000=000000:Vmj02Y_NP0102Y_NP80:Jlj@<0Zk?N1P2jan@90:Vli`L0Sk?_2@2ma^82
0;cDj`P0ZKgX1`1QQ=h20;_Nl@L0[lW]2@2XX<h2092De0L0cnoY00<0oooo@00000000000I03oool3
00000003@000002Y_NP0ZKgX00@0ZKgX202X_NP30:R_g@H0_<_V2@2Y_>L708bbk`T0_/SQ0P2meN`8
0:Vmj0L0JhOL0P2oh_470:o8k0P0YYc<0`2ATM070=Cgi0030?oood000000000002d0oooo000g0?oo
o`8000000`2Y_>L80:Vmj0P0Y[cY2@2jan@60:Vli`<0ZkoX1`2?/nl60;g6hPD0_=C[1`2Y_NP50664
gPD0^mka1`2_bNd80:RPcPX0cnoY00<0oooo0000003oool0H@3oool2000000<0ZKcW202Y_NP80:Rm
j0T0_<_V1P2Y_>L30:^oj0L0S;;_1P2nb>450;gEk0L0ZKgX1@1[Qm`50;oRl@L0[lS/202VW<`00`2A
TM00e?OT0=Cgi0070=Cgi0030?ooo`000000oooo02`0oooo000d0?ooo`03000004000000000000H0
ZKcW202Y_NP809BfkPT0^/OT2@2[_nP708nck`<0_LKR1`2le>/80:Vmj080HHCN1`2kg_470:o9k@H0
Z:3>0`2Tj_X90<o_j@80oooo00<000000?ooo`3oool0G03oool00`0000100000000000060:Vli`P0
ZKgX202A]Nl90;c;iPT0ZkoX1`2</^l30;k8h@L0_MG/202Y_NP206^7g0L0_n;a1`2_b>`80:JLc0X0
e?OT0P3oool00`000000oooo0?ooo`0Z0?ooo`00<P3oool2000000030?ooo`2Y_>L0ZKcW00H0ZKcW
2@2Y_NP809BfkPH0^/OT0`2dbn/90:^oj0L0Sk?_2P2le>/70:Vmj0X0^mka1`2_bNd30:RPcPL0Y>[j
202A[n/20?ooo`030000003oool0oooo05T0oooo0P0000000`3oool0ZKcW0:Vli`060:Vli`T0ZKgX
202A]Nl60;c;iP<0//SZ2@2[_nP708bbk`X0_MG/1`2Y_NP:0;oRl@L0[lS/1@2VW<`509_[n@P0VKG[
0P3oool00`000000oooo0?ooo`0Y0?ooo`00;`3oool3000000040?ooo`2Y_NP0ZKgX0:Vmj0P0ZKcW
2@2Y_NP809BfkP<0^/OT1P2dbn/90:^oj0L0UY3<2P2le>/708ZYjPL0^mka0P2Y_>L7085ob0P0Y>[j
0`2/`nX8096_j`030?oood000000oooo05L0oooo0`000000103oool0ZKgX0:Vmj02Y_NP80:Vli`T0
ZKgX202A]Nl30;c;iPH0//SZ2@2[_nP709FAc@X0_MG/1`25ZN`70;oRl@80ZKcW1`1kO/X809_[n@<0
[LC[202I]N/00`3ooom000000?ooo`0Z0?ooo`00;03oool300000003@000002Y_NP0ZKgX00D0ZKgX
202Y_>L90:Vmj0P0U;K^2@2dbn/60:^oj080ZKWU2@2FT<`60;cDj`<0YZCD202:ZNX30;_Nl@D0ZKcW
1`21OlP50:CZnPD0[<?Z2@2A[n/00`3oool000000?ooo`1C0?ooo`<0000000=000000:Vmj02Y_NP0
1@2Y_NP80:Vli`T0ZKgX202A]Nl90;;8jPH0ZkoX0P2Y]n@909FAc@H0_MG/0`2WZmX808FYk0<0_n;a
1@2Y_>L707]nbPD0Vn_i1@2]a>/909Vej`030?ooo`000000oooo02T0oooo000Z0?ooo`80000000<0
oooo0:Vmj02Y_NP02@2Y_NP50:Vli`<0Z[[U2@2Y_NP509BfkP<0WJWO2@2dbn/80:Vii@T0UY3<202V
Y=@908ZYjPL0ZKcW2@21OlP90:c3jPH0TJo[0`2^]n000`000000oooo0?ooo`1@0?ooo`80000000<0
oooo0:Vmj02Y_NP02@2Y_NP50:Vli`<0Z[_U2@2Y_NP5096ek`<0WjSM2@2bb>X80:Vgi0T0UI7=2@2W
ZmX808FYk0L0ZKcW2@1kO/X90:g4j`H0VKG[0`2X]^<00`000000oooo0?ooo`0X0?ooo`009`3oool2
00000003@000003oool0ZKgX00d0ZKgX202Z^^D90:Vmj0P0WJWO1P2dbn/30:Vmj0L0ZKWU202FT<`0
0`3Jmmh0YZCD0:JTe0070:JTe0H0RZWZ0`2]ZmD70:Vli`L0PGo80P3Colh80:c3jP@0TJo[1P2^]n00
0`000000oooo0?ooo`1<0?ooo`80000000=000000?ooo`2Y_NP03@2Y_NP80:Zki@T0ZKgX202OZ=d6
0;;8jP<0ZKgX1`2Y]n@809FAc@80fOKP202WZmX608FYk0<0Zj_F1`2Y_>L707]nbP80e?oH202]a>/4
09Vej`H0Z;KS00<000000?ooo`3oool09`3oool002D0oooo0P0000000`3oool0ZKgX0:Vmj00=0:Vm
j0<0Z;gX202Z^^D90:Vmj0P0WJWO0`2dbn/60:Vmj0L0ZKWU1P2FT<`30=[ggPP0YZCD102:ZNX60:f[
e@H0ZKcW1P21OlP40=?ocPP0[<?Z2@2^]n000`3oool000000?ooo`030?ooo`E000000P3oool00d00
0000oooo0?ooo`0m0?ooo`80000000<0oooo0:Vmj02Y_NP03@2Y_NP30:Rmj0P0Z[_U2@2Y_NP809nX
g@<0//SZ1P2Y_NP70:Vgi0H0UI7=0`3Im^090:N[fPT0Zj_F1P2Y_>L607]nbP@0e?oH202]a>/90:Rf
h`030?ooo`000000oooo00<0oooo1D0000020?ooo`03@000003oool0oooo01X0oooo000S0?ooo`80
000000<0oooo0:Vmj02Y_NP02`2Y_NP80:Rmj0P0Z[[U2@2Y_NP809fYg`P0ZKgX1`2Y^ND509J@c0@0
f_ON2@2VY=@90:f[e@L0ZKcW1021OlP50=?ocPH0[<?Z0`2RXmD90:jgh0030000003oool0oooo00@0
oooo00M000000?ooo`3oool0oooo@000003ooom0000003`0oooo0P0000000`3oool0ZKgX0:Vmj00;
0:Vmj0P0Z;gX202Z^nD80:Vmj0T0WjSM202Y_NP70:Vgi0D0UI7=1@3Im^070:N[fP80^mW_202[ZmH7
0:Vli`@0Ngk:1@3DomP60:g4j`<0YJSI2@2X]^<00`000000oooo0?ooo`040?ooo`07@000003oool0
oooo0?oood000000oooo@000000K0?ooo`008P3ooolB0:Vmj0L0Z;gX1P2Z^^D30;34j@P0ZKgX1P2M
ZMl30;gDj`P0ZKgX1P2Y^ND309J@c0L0f_ON1`2VY=@20<?Vk`T0[J_E1P2Y_>L3085ob0L0doo>202R
XmD80:jgh080[jG>00<000000?ooo`3oool00`3oool01d000000oooo0?ooo`3ooom000000?oood00
0000>`3ooolB0:Vmj0L0Z;gX1P2Z^nD30:k3j@P0ZKgX1`2OZ=d20<7Gj`P0ZKgX1P2Y]n@309FAc@L0
fOKP1@2WZmX40;_Ik`T0Zj_F1P2Y_>L307]nbPL0e?oH2@2UZ=T60:Rfh`<0[ZSA00<000000?ooo`3o
ool00`3oool01d000000oooo0?ooo`3ooom000000?oood0000006`3oool001h0oooo00E000000?oo
o`3oool0oooo0000000B0:Vmj0L0Z;gX0`2Z^^D60;34j@P0ZKgX0`2MZMl60;gDj`P0ZKgX1P2Y^ND0
0`2FT<`0f_ON0=[ggP060=[ggPD0YZCD1033i^l80:f[e@030<WHi@1_LlH0Kg?600D0ZKcW00<0PGo8
0=?ocP3Colh0103Colh30:6;_@P0XZ?E1@2^]n040:nUcP030?ooo`000000oooo00<0oooo00M00000
0?ooo`3oool0oooo@000003ooom0000003L0oooo00E000000?ooo`3oool0oooo0000000B0:Vmj0L0
Z;gX0`2Z^nD60:k3j@P0ZKgX102OZ=d50<7Gj`P0ZKgX1P2Y]n@00`2ETLd0fOKP0=Wfh0070=Wfh080
Yj_J1`2kfNl70:^[eP030<KCi01cMlP0LgO800D0ZKcW00<0Ngk:0=Cof03DomP0103DomP30:27^@P0
YJSI102X]^<50:jXd@030?ooo`000000oooo00<0oooo00M000000?ooo`3oool0oooo@000003ooom0
000001/0oooo000M0?ooo`03@000003ooom000000080oooo00<000000?ooo`2Y_NP0402Y_NP80:Rm
j0T0/<CY202Y_NP90;gDj`D0ZKgX0`2U^nT504fGl@X0f_ON0P2VY=@70<?Vk`D0[J_E1039f>D606mc
aP<0doo>1`2QRkd80::Se@<0[[OP1`2_YLh00`000000oooo0?ooo`020?ooo`07@000003oool0oooo
0?oood000000oooo@000000f0?ooo`03@000003ooom000000080oooo00<000000?ooo`2Y_NP0402Y
_NP80:Rmj0T0[/?Y1`2Y_NP309nXg@L0`MO[1@2Y_NP30::jjPD0E9kd2P3Im^090;_Ik`D0Zj_F1036
dn@607=gb0<0e?oH1`2PQkT90:FXf@T0[ZSA00<000000?ooo`3oool00P3oool01d000000oooo0?oo
o`3ooom000000?oood0000006`3oool001d0oooo00=000000?oood0000000P3oool0100000100000
0?ooo`3oool@0:Vmj0D0Z;gX0`2S^n/90;34j@P0U9_H2@2me>/80:Fkj@P0CIOa1P3Jmmh90<?Vk`@0
[J_E1@39f>D806mcaP030=Koa`2QRkd0XH^m00H0XH^m202RXmD90:nUcP04@00000000000oooo0?oo
o`900000103oool00d000000oooo0?ooo`0e0?ooo`03@000003ooom000000080oooo00@00000@000
003oool0oooo402Y_NP50:Rmj0<0Y;cZ2@2^`nT70:Vmj0X0`MO[202R^^X805BNm0L0SkC`2@2kfNl2
0:^[ePH0a]?T201cMlP00`3Eold0X8Ni0:27^@060:27^@L0YJSI00<0]/?T0:jXd@2^Z=401`2^Z=40
1400000000000?ooo`3oool2@00000@0oooo00=000000?ooo`3oool06P3oool001d0oooo00=00000
0?oood0000000P3oool00d000000oooo0?ooo`020?oooa00ZKgX202S^n/60;34j@<0ZKgX2@2DVmP5
0;gDj`<0WHJi202U^nT504fGl@<0Z;_W1`1m[?880<?Vk`80[J_E1P39f>D706mcaP<0e_o7202QRkd5
0::Se@<0^L[W2@2_YLh00`3oool000000?ooo`0n0?ooo`03@000003ooom000000080oooo00=00000
0?ooo`3oool00P3oool@0:Vmj0P0Y;cZ1P2^`nT30:Vmj0P0T9gL1P31en/309f5^@P0X[[Z1@1DW_@3
0:Rki`P0SkC`1`2kfNl80<KCi0L0LgO80`3Eold80:27^@@0YJSI102f`n@90:jXd@030?ooo`000000
oooo02<0oooo000M0?ooo`03@000003ooom000000080oooo00<000000?ooo`3oool00`3oool=0:Vm
j0<0YJ?C202S^n/30;34j@D0ZKgX2P2DVmP809f6^@P0YK_Y202X^nL807f/lPH0`nK_2@39f>D506mc
aP@0e_o7202QRkd30::Se@D0^L[W202_YLh20=KVhP030000003oool0oooo03d0oooo00=000000?oo
od0000000P3oool00`000000oooo0?ooo`030?ooo`d0ZKgX0`2UX]880:BljP<0[/?Y1@2Y_NP:092M
g0P0WHFi202R^^X80:Rki`P0SkC`1`2;T]D80<KCi0D0LgO8103Eold80:27^@<0YJSI1@2f`n@80:jX
d@80c]kU00<000000?ooo`3oool08P3oool001h0oooo00E000000?ooo`3oool0oooo@00000060?oo
o`P0ZKgX202UXm<80:>kj`P0ZKgX202DVmP00`3:en<0WHJi09f6^@0609f6^@H0YK_Y0`2TV<T80:Rk
i`D0OJcb0`2UWLh708R?e0L0bMSU101_LlH50=Koa`T0XH^m202ib^L50:nUcPD0e^KR00<000000?oo
o`3oool0?@3oool01D000000oooo0?ooo`3ooom0000000H0oooo202Y_NP80:FRdPP0Y;cZ202Y_NP8
092Mg0030<C?hP2MQKT0WHFi00H0WHFi1P2R^^X30:BGb0P0Z;_W1@2?]?030:FNc`L0Ri;E1`36dn@4
07=gb0D0eOo=2@2PQkT80;K3i0D0[ZSA1@3>g^D00`000000oooo0?ooo`0Q0?ooo`008@3oool00`00
001000000?ooo`060?ooo`P0ZKgX202UXm<50:>kj`X0ZKgX1P2DVmP40<[Gh`P0WHJi2@2TV<T80:Rk
i`L0YIg>2@28Sm@50<WHi@<0Kg?61`3FolL70:6;_@80U>>J1`2ib^L40:nUcPH0e^KR00=000000000
003oool0@03oool00`00001000000?ooo`060?ooo`P0ZKgX202UX]850:BljP/0ZKgX1@2@WM`40<C?
hPP0WHFi2@2TUlP80:Rki`L0YIk?202;T]D60<KCi0<0LgO81P3Eold80:27^@80SM5e1`2f`n@40:jX
d@H0c]kU00=000000000003oool08@3oool00100oooo1D0000020?ooo`03@000003oool0oooo0080
oooo00=000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`L0ZKgX2@2UXm<?0:Vmj0@0
U9_H1@3:en<709f6^@80gobd202TV<T60:Rki`80ZkKQ202UWLh708R?e080a>W`00<0<Y;`0<WHi@39
f>D00P39f>D00`1_LlH0e_o70=Koa`060=Koa`H0XH^m102DhiX70;W:i`80[jG>203Fi^800`000000
oooo0?ooo`0^0?ooo`E000000P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080
oooo00<000000?ooo`3oool01`3oool70:Vmj0T0YJ;B3`2Y_NP3092Mg0H0a<oR1`2MQKT20=gk/0P0
Y9O81P2X^nL20:^ih`P0YIk?202;T]D60<KCi00307=gb03Eold0eOo=00H0eOo=1P2PQkT408gAM@L0
]/?T0P2^Z=480<kNi@030000003oool0oooo0200oooo000B0?ooo`07@000003oool0oooo0?oood00
0000oooo@00000020?ooo`03@000003ooom0000000<0oooo00<00000@000003oool0203oool70:Vm
j0L0YJ?C0P3<hNL>0:Vmj0<0U9_H1P3:en<709f6^@80gobd2@2TV<T80:^fh@L0YIg>1@28Sm@50<CY
l0D0<Y;`0`2W_>T50=Koa`D0XH^m1@2DhiX70;W:i`T0e^KR00<0^:k@0?ooo`000000<@3oool01d00
0000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@00000030?ooo`0300000400
0000oooo00P0oooo1`2Y_NP70:FRdP80c^?W3`2Y_NP80<C?hPL0WHFi0P3Mnk090:BGb0P0ZkWS1`2U
W/l608^Be@<0`NOa1P0oW?@30:Rmj0D0eOo=1@2PQkT508gAM@L0]/?T203>g^D20;N_d@030?ooo`00
0000oooo0200oooo000B0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000
003ooom0000000<0oooo00=000000?ooo`3oool02@3oool70:Vmj0@0YJ?C1@3<hNL>0:Vmj0P0b]OS
1P2MQ[T40=ol]0L0Y9S90P3Hn>070:^fh@P0YIg>0P28Sm@80<CYl0P0YkcY00@036OK0=Koa`3FolL0
e_o70`2QRkd809CSVPL0Qjk_1P3Fi^840;R^d0030?ooo`000000oooo02l0oooo00M000000?ooo`3o
ool0oooo@000003ooom000000080oooo00=000000?oood0000000`3oool00d000000oooo0?ooo`09
0?ooo`L0ZKgX102UX]850<kSi`P0ZKgX1`28Vml70<C?hPH0WHFi103Mnk070:BGb080fOWN1`2[^N<8
0:FNc`<0Ri;E1`31io480:Rmj004001;b@3Eold0eOo=0=Goc@@0X8Ni1`2=dGD7092il`D0c]kU1@2g
[m400`3oool000000?ooo`0O0?ooo`004P3oool01d000000oooo0?ooo`3ooom000000?oood000000
0P3oool00d000000oooo@00000030?ooo`030000003oool0oooo00/0oooo1@2Y_NP30:FSd`L0c>7W
1@2Y_NP30:Vhi0L0PIOO1`3:en<409f6^@D0gobd1P2TV<T40=Shh0L0ZkKQ1`2UWLh80<CYl0<0/LGY
1`2W_>T300aWf`80e_o700<0XH^m09CSVP2XZmT0202DS<T708N^k`<0e^KR1P2h[]000d0000000000
0?ooo`0_0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000003ooom00000
00<0oooo00<000000?ooo`3oool02`3oool50:Vmj0<0YJ;B1`3>hnL50:Vmj0<0ZKST2028Vml60<C?
hP@0WHFi1@3Mnk060:BGb0@0fOWN1`2[^N<70:FNc`P0`NOa0`2``^L70:Rmj08004_90P3Eold30:27
^@030:NWeP2DSl`0U8o<00H0U8o<202@^O<80;N_d@03@00000000000oooo01l0oooo000B0?ooo`07
@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000003ooom0000000<0oooo00=00000
0?ooo`3oool0303oool50:Vmj0X0c>7W202Y^>@8086Gg`D0b]OS102MQ[T60=ol]0@0Y9S91@3Hn>07
0:^fh@D0YIg>102[a^d40<CYl0H0/LGY1`2W_>T80:R[f@L0U8c92027[^l80;R^d080oooo00<00000
0?ooo`3oool0;@3oool01d000000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo
@00000030?ooo`03@000003oool0oooo00`0oooo1@2Y_NP:0<kSi`P0ZKST2028Vml50<C?hP@0WHFi
1P3Mnk040:BGb0H0fOWN1P2[^N<50:FNc`@0ZkkX1031io460;32i`L0Z;gX0P2WYmH20=Goc@040:27
^@2WYmH0YjOF0:NWePL0U8o<1P2@^O<30::Re@L0]joA0P3oool00`000000oooo0?ooo`0M0?ooo`00
4@3oool2@00000@0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03@000
003oool0oooo00d0oooo1P1`ZO@60<cQi`<0Z;;O1`2Y^>@6086Gg`<0^Mgb103:en<309f6^@L0gobd
0`2TV<T70=Shh0L0ZkKQ0P2UWLh80:_6k@P0/LGY1@2W_>T30:RZf0L0Z:_I202DS<T508N^k`<0YjkM
202h[]020?ooo`030000003oool0oooo02/0oooo0T0000040?ooo`03@000003oool0oooo0080oooo
00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`0=0?ooo`H0JZKd1P3>hnL30:VfhPL0ZKST
1P28Vml30;GKl`@0a<oR0`2MQKT70=gk/0<0Y9O8203InMh60:^ih`80YIk?202[_^P80;32i`D0Z;gX
2P2WYmH809B?c0P0XZ;E202g[m420?ooo`030000003oool0oooo01`0oooo000P0?ooo`030000003o
ool0oooo00l0oooo201`ZO@70:Rbg`L0ZKST0`21Uml60;WMlP03001>c03:en<0b]OS0080WHJi0P3O
o;@20<3Cj00304jAkP3Oo;@0gobd0080gobd00<0Y9S90=Shh03Hn>001`3Hn>060:^fh@T0ZlK]0P2g
Z<X80;75j@L0Z:[H202XZmT709B<b@P0YjkM202h[]020?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool03`3oool806ZVm0L0ZKKR1`2Y^>@308RKg`D0]M_c0P07E=020<C?hP80WHFi0P3M
nk020<kVj00304^<j`3Mnk00gO^`0080gO^`00<0Y9O80=WigP3InMh01@3InMh309nKc`D0LJog2@2[
_^P20;jbcPP0/<;W3`2WYmH609B?c080_Jk;202RX]D70;N_d@80oooo00<000000?ooo`3oool0703o
ool00200oooo00<00000@000003oool0403oool5072Ym0<0ZK_V1`2X/]l70:Vhi0P0^Mgb0P00C/`2
0<[Gh`0309f6^@30dnP0`=?X00<0`=?X101>TNh40=Shh0L0WJ7H1P1`/_T60:_6k@D0]jS:1@2aaNT3
0:^ag@L0Z:[H1`2XZmT609B<b@80_[7=202W[]d50;R^d0<0ZoCb00<0oooo@00000000000>`3oool0
0`00001000000?ooo`0@0?ooo`D0JZKd0`2Y^nH70:VfhPL0ZKST202efo<200MDd080a<oR00<0WHFi
00MDd03>i^P00`3>i^P404^<j`@0fOWN202OVll5076_m`H0ZkkX1@2n//h50;32i`<0[KCN3P2WYmH5
09B?c0<0_Jk;202RX]D50;N_d@<0Z>og00<0oooo@000000000007@3oool00100oooo0d0000030?oo
o`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?oo
o`P0ZK_V1`2X/]l8096Lf`L0^Mgb0`00C/`70<3Cj0D0CY7^0`2]/]`709fQf0H0L;;i0`2[a^d70;NX
bP<0/LGY1@2[/Md70:RZf0L0Z:_I102DS<T40;jac@P0YjkM0`2h[]060:_dlP030?ooo`000000oooo
02X0oooo0d0000030?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0A0?ooo`P0ZK_V1`2Y]^8809:Ie`L0]M_c0`07E=060<kVj0H0Bhc[0P2a_>8809nK
c`H0LJog0`2[_^P70;jbcP<0/<;W1@2]]=h>0:NWeP<0U8o<1P2m[//80::Re@80]joA1P2XkoL00`3o
ool000000?ooo`0L0?ooo`00403oool00d000000oooo0?ooo`020?ooo`03@000003ooom000000080
oooo00=000000?oood0000000`3oool00d000000oooo0?ooo`0B0?ooo`L0ZK_V1P2X/]l20;6lhPT0
TIcK1P2igO8:0<3Cj0L0[K;L202MXMP6072bn@X0]jS:202[/Md70:RZf0L0Z:_I0P2DS<T60;jac@P0
YjkM202[m?820?ooo`030000003oool0oooo02P0oooo00=000000?ooo`3oool00P3oool00d000000
oooo@00000020?ooo`03@000003ooom0000000<0oooo00=000000?ooo`3oool04P3oool80:VkiP@0
ZKKR0`2]^n@909:Ie`D0]M_c0P07E=080<kVj0<0Bhc[1@2a_>8809nKc`H0LJog2P2n//h80:fdgPh0
YjOF00<0U8o<0;f^b`2m[//01@2m[//80::Re@T0Z>og00<0oooo0000003oool06`3oool00140oooo
00M000000?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood0000000`3oool00d00
0000oooo0?ooo`0C0?ooo`L0ZK_V0`2X/]l40;6lhPP0TIcK0P3=iNP608jNgPL0`=?X0`2[_NL70:fb
g0H0WJ7H0P38hn/607RSkPP0]jS:0P3RiMD70:^ag@L0Z:[H1`2XZmT80;jac@H0YjkM102>d?h70:_d
lP80oooo00@000000?ooo`3oool0oooo1D0000020?ooo`03@000003oool0oooo01d0oooo00M00000
0?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood0000000`3oool00d000000oooo
0?ooo`0C0?ooo`P0ZK_V1P2]^n@809:Ie`80d^_V1@1nT]d:0<kVj0L0/KcR1`2OVll20=;`i`H0LY_Z
202n//h20=[Ke`L0[KCN3P2WYmH90;f^b`D0XZ;E102NfO`808fkm@030?ooo`000000oooo0080oooo
1D0000020?ooo`03@000003oool0oooo00h0oooo000A0?ooo`07@000003oool0oooo0?oood000000
oooo@00000020?ooo`03@000003ooom0000000<0oooo00<000000?ooo`3oool0503oool70:VkiPL0
/KcR1P2AW=/30<gUj0P0SYkN0`30dnP50:^mi`L0[K;L102MXMP50<SSj`D0N:?^1`2gZ<X40>;Ue@L0
Zk7M102XZ]P30:KGn@L0E[7k202n/Ld708k@oP<0/]7`2025]_@00`000000oooo0?ooo`030?ooo`07
@000003oool0oooo0?oood000000oooo@000000N0?ooo`07@000003oool0oooo0?oood000000oooo
@00000020?ooo`03@000003ooom0000000<0oooo00<000000?ooo`3oool0503oool50:VkiP<0X[_[
1P2]^n@609:Ie`<0d^_V2@1nT]d70:>ahPL0/KcR1@2OVll40=;`i`D0LY_Z1`2n//h40=[Ke`L0[KCN
102WYmH30:?Ln`L0JL7n202m[//709kIo0<0]][c202=^oD00`000000oooo0?ooo`030?ooo`07@000
003oool0oooo0?oood000000oooo@000000?0?ooo`00403oool00d000000oooo@00000020?ooo`03
@000003ooom000000080oooo00=000000?oood0000000P3oool00`00001000000?ooo`0F0?ooo`L0
W;S/1`2a_>83096Lf`H0cNGX202>W]h80:^mi`L0[K;L0P2MXMP60<SSj`H0N:?^1@2gZ<X50>;Ue@L0
Zk7M2@2VeoT505Jan`L0_[7=0P3>oN4408k@oPH0/]7`1@25]_@30:Vbg`030000003oool0oooo0080
oooo00=000000?ooo`3oool00`3oool00d000000oooo0?ooo`0K0?ooo`03@000003ooom000000080
oooo00=000000?oood0000000P3oool00d000000oooo@00000020?ooo`03000004000000oooo01H0
oooo202R^n/60:fki0<0TYWG1P3BjnH707jBg@80a]_X1`2S/N860;6lhP<0Wi_?1P3Bl>L607:KjPD0
_[;>1@3JfmL70:fdgPT0Xmck1@1Y`Oh70;f^b`80cO?Z102NfO`60;KJl`D0SK_e0`2W/^000`000000
oooo0?ooo`020?ooo`03@000003oool0oooo00<0oooo00=000000?ooo`3oool03@3oool00140oooo
00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`06@000003oool0oooo0?ooo`00
00100000603oool709bhk0H0/KcR0P2AW=/80<gUj0D0SYkN0`2mf>d70:^mi`L0[K;L2@38hn/607RS
kP<0]jS:1`3RiMD70:6Nd@H0Y]Oi0`2NP[@505Jan`D0_[7=1@3>oN490;;Al0P0ZK;O00D000000?oo
o`3oool0oooo@00000030?ooo`9000007`3oool00d000000oooo0?ooo`020?ooo`03@000003oool0
oooo0080oooo00I000000?ooo`3oool0oooo00000400000H0?ooo`L0X[_[1P2]^n@209:Ie`P0d^_V
101nT]d40<KKj0L0Xk7R1`2a_>800`2OVll0d_3W0=;`i`060=;`i`H0LY_Z0`2n//h70=[Ke`L0WYcB
1P2Sg?/309j1/`D0JL7n1@2m[//50<gcjPT0]][c202W/^001@000000oooo0?ooo`3ooom0000000<0
oooo0T00000@0?ooo`007`3oool00`000000oooo0?ooo`0H0?ooo`H0W;S/1`2a_>890<gUj0<0SYkN
1P2mf>d70:^mi`L0Vh[01P38hn/30::Qe00301mki@1hXnh0N:?^0080N:?^0P2gZ<X70>;Ue@80_O7b
202QW]4809j2]004021Yf`1F/O/0E[7k05Jan`<0_[7=1@3>oN430;gZl`H0/]7`0P2/`NT80:Vbg`05
0000003oool0oooo0?oood0000000`3oool00d000000oooo0?ooo`0/0?ooo`030000003oool0oooo
01P0oooo1`2R^n/60:fki0T0d^_V0`1nT]d60<KKj0L0Xk7R1P2a_>870=;`i`<0WZGJ00<0>I7`07:K
jP1bVnX00P1bVnX20;jbcPL0f]_G0P2om?0809jLdPP0WX6c00@08VcM06W1oP1Y`Oh0JL7n0`2m[//6
0<gcjP80^_K`1P2ff_<20:^oj0P0Yk;P00D000000?ooo`3oool0oooo@00000030?ooo`03@000003o
ool0oooo00l0oooo000O0?ooo`03000004000000oooo01T0oooo1P2L^>`:08nglPH0cNGX2@2mf>d6
09^gj`T0Vh[02@2RXM@401mki@H0h^GE102mlO870:6Nd@030=[ah02NP[@0WX:d00H0WX:d0`0PJM/2
05Jan`030;jac@3>oN40c_gQ0080c_gQ1P2mj_<80:c1j@P0ZK;O00@000000?oood00001000000`3o
ool3@00002`0oooo00<00000@000003oool06@3oool40::kj`<0W9C;2@1mZo460=;[iPP0a]_X1@2S
/N820:foi`T0SGfm2@2NYMX403VAl0H0f]_G102om?0709jLdP030=[`h02NPK<0WX6c00H0WX6c0`0R
K=d206W1oP030;f^b`3=lnX0cO?Z00<0cO?Z1@2jm_080:^oj0P0Yk;P00@000000?oood0000100000
0`3oool3@00000l0oooo000?0?ooo`900000103oool00d000000oooo0?ooo`020?ooo`03@000003o
ool0oooo0080oooo00<000000?ooo`3oool06P3oool609V@b@L0SkOb0`2[V<<608FalPH0_MS]0`2T
_nd609^gj`L0Vh[00P3Bmj@90::Qe0@07g_U103RiMD60;galPD0XIkA0`3JlN0809j2]0@086WK0`3>
oN460;gZl`<0[/K/1`2/`NT60:Vbg`<0]]3]00<000000?ooo`3oool08P3oool2@00000@0oooo00=0
00000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo1`2L
U</607f[l@<0ZYK11P1i[?<80<KKj0L0[KoW1`2=OKd20<ocW0T0WZGJ100iTO040=[Ke`H0_oC`1@2N
W=830=[`h0P0WX6c100RK=d50<gcjP@0^_K`0`2^aN/70:^oj0H0Yk;P0P2dc^d00`3oool000000?oo
o`0F0?ooo`004@3oool01T000000oooo0?oood000000oooo@0000080oooo00=000000?oood000000
0`3oool00d000000oooo0?ooo`0J0?ooo`P0VI390`2?]o860:^H``L0QK7b202T_nd509^gj`L0Vh[0
0`3Bmj@70::Qe080b>S]1@24SmL80;galP<0XIkA1@3JlN0709j2]08000001`1l]?L30;gZl`H0[/K/
1`2/`NT30:Vbg`D0]]3]00<000000?ooo`3oool0903oool01T000000oooo0?oood000000oooo@000
0080oooo00=000000?oood0000000`3oool00d000000oooo0?ooo`0J0?ooo`P0W9C;0`1mZo460:ZF
`@L0NJcc1`2O`O460:foi`L0SGfm0`3?li`709jUfP030<3Lk@21S=D0PHcE00@0PHcE202om?0309jL
dPD0f_3P1`2NPK<2000000H0J:Sf102jm_060:k5j`L0ZkoX0`2W/^050;C>k@030000003oool0oooo
01D0oooo000@0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000003ooom0
00000080oooo00<00000@000003oool0703oool809V@b@T0ZiS31025/O830:F[f`P0Y;o]102K]n/6
09^:`0@0d_NT1@2RXM@40<SXk@P0Q8oG1P2mlO800`2QW]40f_7P0=[ah0040=[ah0L0WX:d0`000007
07bdm`P0[/K/1`2/`NT90;K@k@03@000003oool0oooo0280oooo00M000000?ooo`3oool0oooo@000
003ooom000000080oooo00=000000?oood0000000P3oool00`00001000000?ooo`0L0?ooo`P0W9C;
2@2ZU/4407V/l`<0XZcN202O`O440:foi`H0SGfm103?li`509jUfP@0`=c]2021S=D60;odl00309jL
dP3Jl>00f_3P00@0f_3P1`2NPK<3000000L0J:Sf202^aN/70:^oj0P0]<k]00<0oooo@000003oool0
5@3oool00140oooo00I000000?ooo`3ooom000000?oood0000020?ooo`03@000003ooom000000080
oooo00<000000?ooo`3oool0703oool709V@b@80do_Q2@2[V<<80:F[f`L0Y;o]102K]n/409^:`0H0
d_NT0`2RXM@60<SXk@H0Q8oG0P30//`505:CkPL0f_7P1P2NP[@5000000L0Xk3Q202^a^`709bhk0P0
]]3]9P3oool01T000000oooo0?oood000000oooo@0000080oooo00=000000?oood0000000P3oool0
0`000000oooo0?ooo`0L0?ooo`L0W9C;0P3>mnL90:ZF`@P0XZcN1`2O`O440:foi`@0SGfm1P3?li`3
09jUfPD0`=c]1`21S=D20;n]b0D0D9?_1`3Jl>0609j1/`D000001`2T/N480:k5j`L0WKS[202dc^dG
0?ooo`003`3oool00d000000oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oo
od0000000P3oool00`00001000000?ooo`0M0?ooo`D0VI390`3Cnn480:^H``80hOg=202UZm/709fC
b@<0VkO[0`2KR/080=;gY0P0b>S]1024SmL50<2bc0L0DY?^1@3JlN0509j2]0<000000`2Y_NP70:>`
h@D0[/K/0`2Y_NP809bhk2X0oooo00=000000?oood0000000P3oool00d000000oooo@00000020?oo
o`03@000003ooom000000080oooo00<00000@000003oool07@3oool509bDb`<0c_OW202ZU/420>;m
aPP0XZcN1`2KTLP30:foi`<0SGfm203?li`80<3Lk@D0PHcE102o[LP7052Ck`D0f_3P1@2NPK<30000
00<0ZKgX1`2T/N450:k5j`<0ZKgX202M^>/60;C>kAL0oooo000@0?ooo`03@000003oool0oooo0080
oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3oool0000001l0oooo0`2IT<T60=?k
h@H0ZiS30`3QoLd70:F[f`030;oGj`2MTlT0WI?900H0WI?90P2K]n/309^:`0030=;gY02ZXLh0ZZ7>
00H0Q9cS2038j>d208B?e`L0`;;<1`2J^Nh40=[ah0@0WX:d1`2Y_NP80:>`h@L0ZKgX1P2L^>`]0?oo
o`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3oool0
000001l0oooo0`2LU</60<kgi`H0ZYK1103RoLH50::/gP80_=?[202KTLP20:foi`<0SGfm00<0co>L
0:NKb@2WVlT01P2@XN070<3Lk@<0PHcE1`2o[LP709Ngk@@0f_3P102NPK<70:Vmj0P0Y;7Q1`2Y_NP6
09fhjal0oooo000N0?ooo`03@000003oool0oooo01h0oooo00<0VI390=?kh@3Cnn401@3Cnn450:^H
``D0hOg=102UZm/40;oGj`P0WI?900<0ZZ7>09^gj`2KR/00102ZXLh808BLh`H0b>S]2030//`20:Uo
YPL0V[W^0`3JlN0309j2]0T0ZKgX1@2S/>430;C>k@L0ZKgX@03oool00d000000oooo0?ooo`0N0?oo
o`0309bDb`3>mnL0c_OW00D0c_OW1@2ZU/450>;maP<0XZcN1@2ldn/809^Ab0030:NKb@2]_nL0SGfm
00@0Yi_9202@XN060<3Lk@03086<e@2o[LP0_jg800D0_jg80P2]PjL709Ngk@<0f_3P0`2NPK<90:Vm
j0D0Y;7Q0`2dc^d70:Vmj2@0oooo000N0?ooo`03@000003oool0oooo02<0oooo103Cnn440:^H``D0
hOg=0`2UZm/50;oGj`L0WI?90P3?bmD70:ZQcPD0Q9cS0`2mc^L6086AfPH0`;;<102YOjH709ZikP80
f_7P0`2NP[@90:Vmj0P0]<k]1@2Y_NQ20?ooo`03@000003oool0oooo02<0oooo103>mnL40:ZF`@H0
h_g61`2ldn/709^Ab0030=CBe`2WVlT0Yi_900H0Yi_91@2@XN030;g@j0D0OI3K1`2o[LP40:f3Y`L0
UkO]0P3Jl>0309j1/`T0ZKgX202dc^d50:Vmj2H0oooo000?0?ooo`=000000P3oool00d000000oooo
0?ooo`020?ooo`05@000003oool0oooo0?ooo`0000009P3oool202IQe080do_Q0`2[V<<70>7mc@P0
_mO[1@2MTlT30<o;e@L0ZZ7>0`24W><50;g>i`H0PI7J1@30//`50:UoYPD0V[W^0`2Y[]`20=[ah003
09j2]02Y_NP0ZKgX0080ZKgX1`2M^N`80;C>kCL0oooo0d0000020?ooo`03@000003oool0oooo0080
oooo00E000000?ooo`3oool0oooo0000000V0?ooo`805EG?0P3>mnL30:ZF`@80h_g61P2GSlT70;cC
j`D0Vi780`3Dd]L70:NKb@<0T:7P1@2md>P607f@f`D0_jg81@2]PjL509Ngk@<0Z:cJ0P3Jl>000`2N
PK<0ZKgX0:Vmj0020:Vmj0L0WKW/202dc^dZ0?ooo`00403oool01T000000oooo0?oood000000oooo
@0000080oooo00=000000?oood0000000P3oool00`00001000000?ooo`0U0?ooo`809V7D0P3Cnn40
102[V<<0hOg=02IQe03:h^T709B:aPH0_mO[0`2MTlT60<o;e@L0ZZ7>202mc^L6086AfP<0`;;<1`2Y
OjH70:V^g0030:Vmj03JlN00WX:d00D0ZKgX1`2M^N`50;C>kCX0oooo00I000000?ooo`3ooom00000
0?oood0000020?ooo`03@000003ooom000000080oooo00<00000@000003oool09@3oool201EEc`80
c_OW00@0ZYK10>;maP0EELl0bn?Y202GSlT50;cCj`@0Vi78103Dd]L80:NKb@P0_M3X1@1mT=/50;n]
b0H0[H>W1`2X[=X00`2Y_NP0f_3P09j1/`050:Vmj0L0WKW/1@2dc^d/0?ooo`003P3oool4@0000004
0?oood000000oooo@0000080oooo00=000000?oood0000000P3oool00`000000oooo0?ooo`0V0?oo
o`@09V7D103:h^T809B:aPD0_mO[00<0WI?90<o;e@3?bmD01@3?bmD50:ZQcP<0_??b1`2mc^L6086A
fP80`;;<202YOjH00`0002X0ZJkL0:V^g0050:V^g0P0ZKgX1`2M^N`l0?ooo`A0000000@0oooo@000
003ooom000000P3oool00d000000oooo@00000020?ooo`030000003oool0oooo02H0oooo100EELl4
0<_Sj@P0Uho9102ldn/309^Ab0H0e=;G1P2WVlT20;okj@L0_M3X1P1mT=/30;n]b0L0[H>W00<0000X
0:R/fP2X[=X01@2X[=X80:Vmj0L0WKW/<03oool000h0oooo00=000000?oood0000000P3oool00d00
0000oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?ooo`3oool09P3oool302IQ
e0D0b^;Y1`2DR/H20=kle0@0=HW/2@3?bmD20:ZQcPL0_??b1P2mc^L6086AfPP0ZGnV0`0002X50:V^
g080^]G]1`2Y_NP509fik3h0oooo00=000000?oood0000000P3oool00d000000oooo@00000020?oo
o`03@000003ooom000000080oooo00=000000?ooo`3oool09P3oool301EEc`D0bn?Y1`2GSlT20=ci
g00502Z2j@2ldn/0_=?[0;cCj`2KTLP01`3Dd]L40:NKb@H0_o_Y1P2md>P507f@f`80_jg81`2]PjL3
0000:0D0Z:cJ0P2nf^h70:Vmj0D0WKW/<P3oool000l0oooo0T0000020?ooo`03@000003ooom00000
0080oooo00=000000?oood000000;03oool80<[Rj@D0U8[6103No=@403F9k0P0cl_E1`2llo830:2e
i`P0PKWh0`0m]O480:UoYP<0000Z0`2Y[]`50;[Ek@L0ZKgX@`3oool2@0000080oooo00=000000?oo
od0000000P3oool00d000000oooo@000000/0?ooo`P0bn?Y1@2GSlT40=cig0<0:X;Y2@3Dd]L20:NK
b@D0_o_Y0`2Q]NL808>hm`<03ICN202]PjL30000:0<0Z:cJ1@2nf^h70:Vmj3H0oooo000@0?ooo`05
@000003oool0oooo0?oood000000103oool00d000000oooo0?ooo`0_0?ooo`@0b^;Y102DR/H60=kl
e0D0=HW/103?bmD508[YlPP0X;GW1@21^OP20:V^g0<0?KGa202YOjH40000:PL0^]G]1@2Y_NQ60?oo
o`05@000003oool0oooo0?oood000000103oool00d000000oooo0?ooo`0_0?ooo`@0bn?Y0`2GSlT7
0=cig0@0:X;Y1`3Dd]L30;okj@P0XKGW1@23^?L20:Vbg`<03ICN202]PjL40000:0L0_][^1@2Y_NPh
0?ooo`00B`3oool0101PKl/0b^;Y0<[Rj@3:h^T309B:aPD0g_cD0P2TULH607b0c0<0R^Wb1P2Y_NP8
0:2ei`L0ZJkL0P0m]O480:UoYPD0UKK^1`2jeNf50?ooo`80KGK;0`3;hnT00`2GSlT0g?WL0=cig004
0=cig080YIW91P21Q<d306GElPH0ZKgX202Q]NL70:Vbg`803ICN202]PjL5092dk`L0_][^?03oool0
04`0oooo0P1PKl/20<[Rj@0409B:aP3No=@0g_cD0=kle0H0Y9G61`1lP<`20<:Y`0L0ZKgX102P]NL3
0:o5jPH0ZJkL0`0m]O460:UoYPL0UKK^S03oool406efb`@0g?WL1P2UVLT70864c@80`JS11`2Y_NP4
0:6ei`<0[lGZ1P2Y/]l300fDgPH0[H>W1`2@]>m20?ooo`00C03oool7061_b`030=gjf@2TULH0Y9G6
00@0Y9G61P1lP<`40<:Y`0L0ZKgX1`2_aNX50:V^g0<0?KGa1P2YOjH509FfkXh0oooo1`1]M//20=gk
f0D0YIW91P21Q<d40<6X`@L0ZKgX1`2_aNX50:Vbg`<03ICN1P2]PjL5092dkd@0oooo001=0?ooo`D0
H6o;0`3Mn]T60:BEaP@0O83<1@32ZL050:Vmj0<0Xk_Z1P2_aNX50:V^g0030;_Dk@0m]O40?KGa00H0
ZGnV00<0UfZL0?ooo`3oool0T@3oool506efb`<0gO_H1P2UVLT40864c@D0`JS11@2Y_NP30:>kjPH0
[lGZ1@2Y/]l00`2fc^`03ICN00fDgP060:f3Y`0309MZW03oool0oooo04H0oooo001=0?ooo`<0H6o;
1@3Mn]T60:BEaP<0O83<1`32ZL080:>kjPH0[lGZ1@2ke>d203fel@D0ZGnV0P2GJYbC0?ooo`@0KGK;
1@3MnmP50:FIb@<0PHC=1`31Z<480:>kjPH0[lGZ1@2fc^`200fDgPD0[H>W0P2GJYa80?ooo`00CP3o
ool00`1PKl/0gO[I0=gjf@050=gjf@H0Y9G600<0O83<0<:Y`032ZL001@32ZL020<odWPP0Xk_Z1P2J
Tl/40;_Dk@80?KGa1@2YOjH209MZW9<0oooo0`1]M//60=gkf0H0YIW900<0PHC=0<6X`@31Z<401@31
Z<420=CgYPP0Xk_Z1P2MUld40;K>k0803ICN1@2]PjL209MZW4P0oooo001>0?ooo`P0gO[I1P2TULH8
0<:Y`0<0coBN1@2S^nX30:Vmj0L0VY?;0`2ke>d00`0m]O40ZGnV0:UoYP030:UoYP80UfZLU03oool0
0`1]M//0gO_H0=gkf0060=gkf0D0YIW92031Z<430=CgYPD0Xk_Z0`2Y_NP709fGc@<0]/k/00<03ICN
0:f3Y`2]PjL00`2]PjL209MZW4P0oooo001B0?ooo`0305mke`3Mn]T0gO[I0080gO[I0`2TULH30:?K
n`H0`ZW01@3?m9h70:Vmj0H0VY?;00@0oooo0;_Dk@2ke>d0^mC]0P0m]O440:UoYP80UfZLV03oool5
07B2dPH0W<ch1P31Z<450=CgYPL0ZKgX1P2MUld0103oool0]/k/0;K>k02fc^`200fDgP<0[H>W0`2G
JYa80?ooo`00D`3oool405mke`H0Xm_k1@32ZL000`3?m9h0ZkoX0:^oj0040:^oj0L0ZKgX102JTl/2
0?ooo`<0^mC]0P0m]O430:UoYP80UfZLV@3oool607B2dPD0W<ch1@31Z<440=CgYP<0[L;Y1`2Y_NP4
09fGc@80oooo102fc^`0100=U=h0[H>W0:f3Y`2]PjL209MZW4T0oooo001C0?ooo`L0Gg_G102Sfo/3
0<:Y`0030<odWP2X^^H0Z;[V00H0ZkoX1P2Y_NP309ZCb`@0oooo0`2ke>d0100m]O40ZGnV0:UoYP2Y
OjH209MZW9X0oooo1`1dP]8409c<n0<0`JS10P3DmjH70:g2j@H0ZKgX0`2MUld40?ooo`<0]/k/00@0
3ICN0:f3Y`2]PjL0[H>W0P2GJYa90?ooo`00E03oool405mke`<0ZjOC0`2Sfo/30<:Y`0@0Z;[V1P2[
_nP60:Vmj00309ZCb`3oool0oooo00<0oooo0`2ke>d0100m]O40ZGnV0:UoYP2YOjH209MZW9/0oooo
1@1dP]820;>cf0<0W<ch0`31Z<400`3DmjH0Y[SV0:JhiP070:g2j@H0ZKgX00<0WIO=0?ooo`3oool0
0`3oool30;K>k00400fDgP2]PjL0[H>W0:f3Y`80UfZLB@3oool005D0oooo1`2[Ym<0103Ko]40Xm_k
0:?Kn`32ZL060:RjiQ40oooo0`2ke>d00`0m]O40ZGnV0:UoYP0309MZW9/0oooo0`1dP]850;>cf004
0=_meP2Lc?P0W<ch0<6X`@H0Y[SV4@3oool30;K>k00309MZW02]PjL0[H>W00<0UfZLB@3oool005H0
oooo1@2[Ym<40=_nd@D0Z;[V4`3oool30;_Dk@0309MZW02YOjH0ZGnV00<0UfZLW03oool60;>cf0@0
fogF1@2V^>HC0?ooo`<0]/k/00<0UfZL0:f3Y`2]PjL00`2GJYa90?ooo`00EP3oool50:^Wd`D0fokA
603oool20;_Dk@0309MZW00m]O40ZGnV00<0UfZLW@3oool50;>cf0D0fogF603oool20;K>k00309MZ
W00=U=h0[H>W00<0UfZLB@3oool005L0oooo0`2[Ym<40=_ndAX0oooo0P2ke>d00`2GJY`0?KGa0:Uo
YP0309MZW9h0oooo0`2c/mP40=_meQX0oooo0P2fc^`609MZW4T0oooo001G0?ooo`80ZjOC0P3Ko]4M
0?ooo`80^mC]1P2GJYbN0?ooo`80/k?H0P3KoMHM0?ooo`80]/k/1P2GJYa90?ooo`00N03oool30;_D
k@@0UfZL`03oool30;K>k0@0UfZLBP3oool007P0oooo0`2ke>d409MZW<00oooo0`2fc^`409MZW4X0
oooo001i0?ooo`80^mC]102GJYc10?ooo`80]/k/102GJYa:0?ooo`00N@3oool20;_Dk@@0UfZL`@3o
ool20;K>k0@0UfZLBP3oool007T0oooo0P2ke>d409MZW<40oooo0P2fc^`409MZW4X0oooo001i0?oo
o`80^mC]102GJYc10?ooo`80]/k/102GJYa:0?ooo`00NP3oool00`2ke>d0UfZL09MZW00209MZW<80
oooo00<0]/k/09MZW02GJY`00P2GJYa:0?ooo`00NP3oool00`2ke>d0UfZL09MZW00209MZW<80oooo
00<0]/k/09MZW02GJY`00P2GJYa:0?ooo`00NP3oool20;_Dk@<0UfZL`P3oool20;K>k0<0UfZLBP3o
ool007X0oooo0P2ke>d209MZW<<0oooo0P2fc^`209MZW4/0oooo001k0?ooo`030;_Dk@2GJY`0UfZL
0<@0oooo00<0]/k/09MZW02GJY`0B`3oool007/0oooo00<0^mC]09MZW02GJY`0a03oool00`2fc^`0
UfZL09MZW01;0?ooo`00N`3oool00`2ke>d0UfZL09MZW0340?ooo`030;K>k02GJY`0UfZL04/0oooo
001k0?ooo`030;_Dk@2GJY`0UfZL0<@0oooo00<0]/k/09MZW02GJY`0B`3oool007/0oooo00<0^mC]
09MZW02GJY`0a03oool00`2fc^`0UfZL09MZW01;0?ooo`00O03oool209MZW<D0oooo0P2GJYa;0?oo
o`00O03oool209MZW<D0oooo0P2GJYa;0?ooo`00O03oool00`2ke>d0oooo0?ooo`340?ooo`030;K>
k03oool0oooo04X0oooo001l0?ooo`030;_Dk@3oool0oooo0<@0oooo00<0]/k/0?ooo`3oool0BP3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool006D0oooo00=000000?ooo`3oool01P3oool00d000000oooo0?ooo`2k0?oo
o`03@000003oool0oooo00H0oooo00=000000?ooo`3oool0F03oool006@0oooo00=000000?ooo`3o
ool0203oool00d000000oooo0?ooo`2i0?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3o
ool0E`3oool006<0oooo00=000000?ooo`3oool00P3oool3@00000D0oooo00=000000?ooo`3oool0
]`3oool00d000000oooo0?ooo`030?ooo`=00000103oool00d000000oooo0?ooo`1F0?ooo`00H`3o
ool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00D0oooo00=000000?ooo`3oool0]`3o
ool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo@00000@0oooo00=000000?ooo`3oool0
EP3oool006<0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`050?ooo`03@000003o
ool0oooo0;L0oooo00=000000?ooo`3oool00P3oool014000000oooo0?oood0000040?ooo`03@000
003oool0oooo05H0oooo001S0?ooo`03@000003oool0oooo0080oooo0d0000050?ooo`03@000003o
ool0oooo0;L0oooo00=000000?ooo`3oool00`3oool3@00000@0oooo00=000000?ooo`3oool0EP3o
ool006@0oooo00=000000?ooo`3oool0203oool00d000000oooo0?ooo`2i0?ooo`03@000003oool0
oooo00@0oooo00E000000?ooo`3oool0oooo@000001I0?ooo`00I@3oool00d000000oooo0?ooo`06
0?ooo`03@000003oool0oooo0;/0oooo00=000000?ooo`3oool00P3oool2@0000080oooo00=00000
0?ooo`3oool0F03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool007H0oooo1D00
00020?ooo`03@000003oool0oooo0;d0oooo1D0000020?ooo`03@000003oool0oooo04T0oooo001h
0?ooo`07@000003oool0oooo0?oood000000oooo@00000300?ooo`07@000003oool0oooo0?oood00
0000oooo@000001:0?ooo`00N03oool00d000000oooo0?ooo`030?ooo`03@000003oool0oooo0;h0
oooo00=000000?ooo`3oool00`3oool00d000000oooo0?ooo`180?ooo`00N03oool014000000oooo
0?ooo`3oool2@0000<40oooo00A000000?ooo`3oool0oooo0T00001;0?ooo`00N03oool01D000000
oooo0?ooo`3ooom000000<80oooo00E000000?ooo`3oool0oooo@000001<0?ooo`00M`3oool2@000
00<0oooo0d00002o0?ooo`9000000`3oool3@00004X0oooo00260?ooo`03000004000000oooo0<@0
oooo00<00000@000003oool0@03oool008@0oooo0P0000020?ooo`030000003oool0oooo0<00oooo
0P0000020?ooo`030000003oool0oooo03h0oooo00210?ooo`<0000000D0oooo0:R`gP2X/=h0Z;3N
0000002o0?ooo`<0000000D0oooo0:R`gP2X/=h0Z;3N000000100?ooo`00O`3oool2000000030?oo
o`2X/=h0Z;3N00@0Z;3N00<0oooo0000003oool0^`3oool2000000030?ooo`2X/=h0Z;3N00@0Z;3N
00<0oooo0000003oool0?P3oool007`0oooo0`0000000`2X/=i000000:R`gP070:R`gP030?ooo`00
0000oooo0;L0oooo0`0000000`2X/=i000000:R`gP070:R`gP030?ooo`000000oooo03d0oooo001i
0?ooo`<0000000@0oooo0:Vmj02Y_NP0ZKgX2@2X/=h00`3oool000000?ooo`2d0?ooo`<0000000@0
oooo0:Vmj02Y_NP0ZKgX2@2X/=h00`3oool000000?ooo`0m0?ooo`00M`3oool200000080oooo1@2Y
_NP:0:R`gP03@00000000000oooo0;40oooo0P0000020?ooo`D0ZKgX2P2X/=h00d00000000000?oo
o`0l0?ooo`00M03oool3000000030?oood000000ZKgX00L0ZKgX2@2X/=h20?ooo`030000003oool0
oooo0:`0oooo0`0000000`3ooom000000:Vmj0070:Vmj0T0Z;3N0P3oool00`000000oooo0?ooo`0j
0?ooo`00D@3oool5@0000080oooo00=000000?ooo`3oool05`3oool200000080oooo0`2[_nP90:Vm
j0H0Z;3N0`2id^d00`3oool000000?ooo`2:0?ooo`E000000P3oool00d000000oooo0?ooo`0G0?oo
o`8000000P3oool30:^oj0T0ZKgX1P2X/=h30;WBk@030?ooo`000000oooo03/0oooo001C0?ooo`07
@000003oool0oooo0?oood000000oooo@000000E0?ooo`80000000=000000?ooo`3oool01P2[_nP8
0:Vmj0@0Z;3N1P2id^d00`3oool000000?ooo`2;0?ooo`07@000003oool0oooo0?oood000000oooo
@000000E0?ooo`80000000=000000?ooo`3oool01P2[_nP80:Vmj0@0Z;3N1P2id^d00`3oool00000
0?ooo`0j0?ooo`00D`3oool01d000000oooo0?ooo`3ooom000000?oood0000004`3oool200000080
oooo2@2[_nP90:Vmj0T0^M;]0P3oool00`000000oooo0?ooo`290?ooo`07@000003oool0oooo0?oo
od000000oooo@000000C0?ooo`8000000P3oool90:^oj0T0ZKgX2@2id^d20?ooo`030000003oool0
oooo03P0oooo001C0?ooo`07@000003oool0oooo0?oood000000oooo@000000@0?ooo`<000000P3o
ool30:Rmj0T0ZkoX1P2Y_NP309Nek@T0^M;]00=000000000003oool0RP3oool01d000000oooo0?oo
o`3ooom000000?oood000000403oool300000080oooo0`2X_NP90:^oj0H0ZKgX0`2G]Nd90;WBk@03
@00000000000oooo03T0oooo001C0?ooo`07@000003oool0oooo0?oood000000oooo@000000=0?oo
o`<0000000=000000?ooo`3oool01@2X_NP:0:^oj0T0UkG]2@2id^d00`3oool000000?ooo`290?oo
o`07@000003oool0oooo0?oood000000oooo@000000=0?ooo`<0000000=000000?ooo`3oool01@2X
_NP:0:^oj0T0UkG]2@2id^d00`3oool000000?ooo`0h0?ooo`00DP3oool2@00000@0oooo00=00000
0?ooo`3oool02P3oool2000000<0oooo2@2X_NP70:^oj0<0ZKgX202G]Nd60;WBk@@0ZKgX00<00000
0?ooo`3oool0Q`3oool2@00000@0oooo00=000000?ooo`3oool02P3oool2000000<0oooo2@2X_NP7
0:^oj0<0ZKgX202G]Nd60;WBk@@0ZKgX00<000000?ooo`3oool0=`3oool00680oooo0`0000030?oo
o`<0/LGY202X_NP40:^oj0H0ZKgX2@2G]Nd90:Vmj0030?ooo`000000oooo09L0oooo0`0000030?oo
o`<0/LGY202X_NP40:^oj0H0ZKgX2@2G]Nd90:Vmj0030?ooo`000000oooo03L0oooo001P0?ooo`80
000000@0oooo@000003oool0oooo1@2aaNT90:Rmj0X0ZKgX1P2G]Nd<0:Vmj0030?ooo`000000oooo
09@0oooo0P000000103ooom000000?ooo`3oool50;75j@T0Z;gX2P2Y_NP609Nek@`0ZKgX00<0oooo
0000003oool0=P3oool005d0oooo0`0000030?ooo`T0/LGY1P2X_NP<0:Vmj0@0UkG]3P2Y_NP00d00
000000000?ooo`050?ooo`03@000003oool0oooo08T0oooo0`0000030?ooo`T0/LGY1P2X_NP<0:Vm
j0@0UkG]3P2Y_NP00d00000000000?ooo`050?ooo`03@000003oool0oooo02h0oooo001K0?ooo`80
0000103oool30:6jj`P0/LGY102X_NPQ0:Vmj0030?ooo`000000oooo00<0oooo00=000000?oood00
0000R03oool2000000@0oooo0`2Q^^/80;75j@@0Z;gX8@2Y_NP00`3oool000000?ooo`030?ooo`03
@000003ooom0000002l0oooo001H0?ooo`<0000000<0oooo@000002Q^^/01`2Q^^/80;75jA00ZKgX
0`2RUlTB0:Vmj0030?ooo`000000oooo00@0oooo00=000000?ooo`3oool0P`3oool3000000030?oo
od000000XK[[00L0XK[[202aaNT@0:Vmj0<0XYO94P2Y_NP00`3oool000000?ooo`040?ooo`03@000
003oool0oooo02d0oooo001E0?ooo`<000000P3oool30:Vmj0T0XK[[1@2aaNT30:^oj0d0ZKgX1P2R
UlTA0:Vmj0030?ooo`000000oooo0080oooo0T0000230?ooo`<000000P3oool30:Vmj0T0XK[[1@2a
aNT30:^oj0d0ZKgX1P2RUlTA0:Vmj0030?ooo`000000oooo0080oooo0T00000`0?ooo`00=`3oool0
0d000000oooo0?ooo`0I0?ooo`80000000=000000?ooo`3oool01P2Y_NP90:6jj`P0ZkoX2@2Y_NP9
0::Gb@L0ZKgX0`2Y^nH80:Vmj0050?ooo`000000oooo0?oood000000IP3oool00d000000oooo0?oo
o`0I0?ooo`80000000=000000?ooo`3oool01P2Y_NP90:6jj`P0ZkoX2@2Y_NP90::Gb@L0ZKgX0`2Y
^nH80:Vmj0050?ooo`000000oooo0?oood000000<@3oool003H0oooo00=000000?oood0000005`3o
ool300000080oooo2@2Y_NP70:6jj`<0YZWI202[_nP80:Vmj0X0XYO9102Y_NP50:VkiPP0ZKgX00A0
0000000000000000oooo0d00001S0?ooo`03@000003ooom0000001L0oooo0`0000020?ooo`T0ZKgX
1`2Q^^/30:JYf@P0ZkoX202Y_NP:0::Gb@@0ZKgX1@2Y^nH80:Vmj004@0000000000000000?ooo`=0
0000;`3oool003P0oooo00=000000?ooo`3oool04`3oool2000000<0oooo302Y_NP40:6jj`D0YZWI
2@2[_nP80:Vmj0X0XYO92@2Y^nH80:Vmj0030?ooo`000000oooo06P0oooo00=000000?ooo`3oool0
4`3oool2000000<0oooo302Y_NP40:6jj`D0YZWI2@2[_nP80:Vmj0X0XYO92@2Y^nH80:Vmj0030?oo
o`000000oooo0380oooo000f0?ooo`9000004`3oool3000000030:Vmj4000000ZKgX00l0ZKgX2@2V
ZMT60:^oj0X0ZKgX2@2RUlT20=_dg`P0ZK_V202Y_NP20?ooo`030000003oool0oooo06@0oooo0T00
000C0?ooo`<0000000<0ZKgX@000002Y_NP03`2Y_NP90:JYf@H0ZkoX2P2Y_NP90::Gb@80foCO202Y
^nH80:Vmj080oooo00<000000?ooo`3oool0<03oool003H0oooo00=000000?ooo`3oool0403oool2
000000040?ooo`2Y/=d0ZK3M0:V`gA80ZKgX202VZMT40:^oj0d0ZKgX1`2RUlT30=_dg`T0ZK_V202A
U=<20?ooo`030000003oool0oooo06<0oooo00=000000?ooo`3oool0403oool2000000040?ooo`2Y
/=d0ZK3M0:V`gA80ZKgX202VZMT40:^oj0d0ZKgX1`2RUlT30=_dg`T0ZK_V202AU=<20?ooo`030000
003oool0oooo02l0oooo000f0?ooo`=000003@3oool200000003@000003oool0ZK3M00D0ZK3M4@2Y
_NP90:JYfA00ZKgX1P2RUlT50=_dg`H0ZK_V0P2VWLd9096Dd`030?ooo`000000oooo06@0oooo0d00
000=0?ooo`80000000=000000?ooo`2Y/=d01@2Y/=dA0:Vmj0T0YZWI402Y_NP60::Gb@D0foCO1P2Y
^nH20:JMc@T0TICC00<0oooo0000003oool0<03oool004@0oooo0P0000020?ooo`P0ZK3M1`2Y_NP3
0:Vli`P0ZKgX1`2VZMT20;o8hA00ZKgX102RUlT60=_dg`@0ZK_V1@2VWLd9096Dd`03@00000000000
oooo0740oooo0P0000020?ooo`P0ZK3M1`2Y_NP30:Vli`P0ZKgX1`2VZMT20;o8hA00ZKgX102RUlT6
0=_dg`@0ZK_V1@2VWLd9096Dd`03@00000000000oooo02l0oooo00110?ooo`<000000P3oool30:Nl
j@P0ZK3M102Y_NP60:Vli`P0ZKgX102VZMT50;o8h@l0ZKgX0`2RUlT80=_dg`P0YYg=202AU=<20=7c
j0030?ooo`000000oooo06d0oooo0`0000020?ooo`<0YkcY202Y/=d40:Vmj0H0ZKcW202Y_NP40:JY
f@D0_lSQ3`2Y_NP30::Gb@P0foCO202VWLd8096Dd`80dO?X00<0oooo0000003oool0;P3oool003h0
oooo0`0000000`2W_>U000000:Nlj@050:Nlj@T0ZK3M2@2Y_>L80:Vmj0<0YZWI1P2ob>490:Vmj080
JHKL1@2Y_NP00`2RUlT0foCO0=_dg`050=_dg`80/LW/2@2VWLd6096Dd`<0dO?X00<0oooo0000003o
ool0JP3oool3000000030:NljD000000YkcY00D0YkcY2@2Y/=d90:Vli`P0ZKgX0`2VZMT60;o8h@T0
ZKgX0P1YQ]`50:Vmj0030::Gb@3Km=l0foCO00D0foCO0P2abN`90:JMc@H0TICC0`3AlnP00`3oool0
00000?ooo`0^0?ooo`00?03oool2000000040?ooo`2Y_NP0ZKgX0:Vmj0P0YkcY1`2Y/=d20;c:i@T0
ZKcW202Y_NP90;o8h@T0ZKgX1P1YQ]`60=_dg`D0/LW/202VWLd5096Dd`D0dO?X00<0oooo0000003o
ool0I`3oool2000000040?ooo`2Y_NP0ZKgX0:Vmj0P0YkcY1`2Y/=d20;c:i@T0ZKcW202Y_NP90;o8
h@T0ZKgX1P1YQ]`60=_dg`D0/LW/202VWLd5096Dd`D0dO?X00<0oooo0000003oool0;@3oool003T0
oooo0`0000000`3oool0ZKgX0:Vmj0040:Vmj0P0YkcY102Y/=d50;c:i@T0ZKcW202:/O090;o8h@P0
ZKgX2@1YQ]`80;79k0P0YYg=0`2AU=<70=7cj0030?oood000000000006@0oooo0`0000000`3oool0
ZKgX0:Vmj0040:Vmj0P0YkcY102Y/=d50;c:i@T0ZKcW202:/O090;o8h@P0ZKgX2@1YQ]`80;79k0P0
YYg=0`2AU=<70=7cj0030?oood000000000002d0oooo000g0?ooo`8000000P3oool00`2Y_NQ00000
0:Vmj0060:Vmj0L0YkcY0`2Y/=d60;c:i@L0ZKcW0`2[_nP808Zal0H0_lSQ0`2ne^`80:Vmj0L0JHKL
0P2nh_480;79k0P0YYg=00<0TICC0=7cj03AlnP01`3AlnP00`3oool000000?ooo`1Q0?ooo`800000
0P3oool00`2Y_NQ000000:Vmj0060:Vmj0L0YkcY0`2Y/=d60;c:i@L0ZKcW0`2[_nP808Zal0H0_lSQ
0`2ne^`80:Vmj0L0JHKL0P2nh_480;79k0P0YYg=00<0TICC0=7cj03AlnP01`3AlnP00`3oool00000
0?ooo`0/0?ooo`00=03oool300000080oooo302Y_NP70:Nlj@T0_<[U102Y_>L60:^oj0L0R[7`102o
b>460;kFk0L0ZKgX1@1YQ]`50;kRl@L0/LW/202VWLd:0=7cj080oooo00<000000?ooo`3oool0G03o
ool300000080oooo302Y_NP70:Nlj@T0_<[U102Y_>L60:^oj0L0R[7`102ob>460;kFk0L0ZKgX1@1Y
Q]`50;kRl@L0/LW/202VWLd:0=7cj080oooo00<000000?ooo`3oool0:P3oool00380oooo0P000000
0`3ooom000000:Vmj00?0:Vmj0L0TKG_2@2lb^D:0:^oj0L0R[7`2P2ne^`70:Vmj080JHKL1`2nh_47
0;79k0H0YYg=1@2Qk?T809>`jP80oooo00<000000?ooo`3oool0F@3oool2000000030?oood000000
ZKgX00l0ZKgX1`2A]Nl90;c:i@X0ZkoX1`2:/O0:0;kFk0L0ZKgX0P1YQ]`70;kRl@L0/LW/1P2VWLd5
0:7/n@P0Tk3Z0P3oool00`000000oooo0?ooo`0Y0?ooo`00;`3oool3000000030?ooo`2Y_NP0ZKgX
0180ZKgX1`2A]Nl60;c:i@<0/lW[2P2[_nP709BAc@X0_]K/1P2Y_NP:0;kRl@L0/LW/0`2VWLd50:7/
n@<0[<;Z202C/>X00`3oool000000?ooo`1G0?ooo`<0000000<0oooo0:Vmj02Y_NP04P2Y_NP7096e
k`H0_<[U0`2cbN/:0:^oj0L0U97=2P2ne^`60:Vmj0X0_^;a1`2abN`30:JMc@D0XNci0`2/`^X809>`
jP030?ooo`000000oooo02X0oooo000/0?ooo`<0000000=000000?ooo`2Y_NP05P2Y_NP7096ek`<0
_<[U1P2cbN/70:^oj080ZKKR202DTLd70;kFk0<0YZOF1`26YnX60;kRl@80ZKcW1`1nOLP60:7/n@D0
[<;Z202C/>X00`3ooom000000000001D0?ooo`<0000000=000000?ooo`2Y_NP05P2Y_NP7096ek`<0
_<[U1P2cbN/70:^oj080ZKKR202DTLd70;kFk0<0YZOF1`26YnX60;kRl@80ZKcW1`1nOLP60:7/n@D0
[<;Z202C/>X00`3ooom000000000000Z0?ooo`00:P3oool2000000<0oooo3P2Y_NP30:Vii0T0ZKgX
1`2A]Nl90;?9j`@0ZkoX1@2Y]^8809BAc@@0_]K/1@2VYmH908JWjPL0ZKcW2@1nOLP90:c2jPP0Tk3Z
00<0oooo0000003oool0D@3oool2000000<0oooo3P2Y_NP30:Vii0T0ZKgX1`2A]Nl90;?9j`@0ZkoX
1@2Y]^8809BAc@@0_]K/1@2VYmH908JWjPL0ZKcW2@1nOLP90:c2jPP0Tk3Z00<0oooo0000003oool0
:@3oool002L0oooo0`0000030?ooo`h0ZKgX1P2Y^N@90:Vmj0L0WZ_P2@2cbN/80:VfhPT0U97=2@2V
YmH608JWjP<0[ZoH1P2Y_>L807imb080eOo@202/`^X609>`jP<0Z;?Q00<0oooo0000003oool0C@3o
ool3000000<0oooo3P2Y_NP60:Vii0T0ZKgX1`2NZn090;?9j`P0ZKKR2@2DTLd90:JWePH0QZOZ0`2^
[mP60:Vli`P0OWg80P3Eom080:c2jPH0Tk3Z0`2X/n400`3oool000000?ooo`0X0?ooo`009@3oool2
00000080oooo00=000000:Vmj02Y_NP03@2Y_NP80:Vii0X0ZKgX202NZn050;?9j`<0ZKgX202Y]^87
09BAc@80fOKQ202VYmH408JWjPD0[ZoH1`2Y_>L607imb0@0eOo@202/`^X90:Rch@030?ooo`000000
oooo04X0oooo0P0000020?ooo`03@000002Y_NP0ZKgX00d0ZKgX202Y^N@:0:Vmj0P0WZ_P1@2cbN/3
0:Vmj0P0ZKKR1`2DTLd20=Wfh@P0YZOF1026YnX50:j_f0L0ZKcW1P1nOLP40=God0P0[<;Z2@2X/n40
0`3oool000000?ooo`0W0?ooo`008`3oool200000080oooo4`2Y_NP80:Vii0T0ZKgX2@2NZn080:Vm
j0L0ZKKR1@2DTLd40=Wfh@T0YZOF2@2^[mP60:Vli`D0OWg81P3Eom050:c2jP<0Xj?E202X/n400d00
000000000?ooo`030?ooo`E000000P3oool00d000000oooo0?ooo`0k0?ooo`8000000P3ooolC0:Vm
j0P0ZKWT2@2Y_NP909j[h0P0ZKgX1`2Y]^8509BAc@@0fOKQ2@2VYmH90:j_f0H0ZKcW1@1nOLP60=Go
d0D0[<;Z0`2SXmD80:Rch@03@00000000000oooo00<0oooo1D0000020?ooo`03@000003oool0oooo
01X0oooo000S0?oooaP0ZKgX202Y^N@90:Vmj0L0WZ_P0P2ld^X70:Vmj0L0ZKKR102DTLd60=Wfh@L0
YZOF0P2ohO080:j_f0L0ZKcW101nOLP70=God0L0Xj?E2@2X/n400`3oool000000?ooo`040?ooo`07
@000003oool0oooo0?oood000000oooo@000000l0?oooaP0ZKgX202Y^N@90:Vmj0L0WZ_P0P2ld^X7
0:Vmj0L0ZKKR102DTLd60=Wfh@L0YZOF0P2ohO080:j_f0L0ZKcW101nOLP70=God0L0Xj?E2@2X/n40
0`3oool000000?ooo`040?ooo`07@000003oool0oooo0?oood000000oooo@000000K0?ooo`007P3o
ool00d000000oooo0?ooo`020?ooo`030000002Y_NP0ZKgX01H0ZKgX1@2Y^N@30;35j@T0ZKgX102N
Zn050;cBjPL0ZKgX1`2Y]^8209BAc@P0fOKQ102VYmH40;oQl0T0[ZoH1P2Y_>L307imb0H0eOo@0`2P
R;X70:>Se@H0Z;?Q0`2bZm400`3oool000000?ooo`030?ooo`07@000003oool0oooo0?oood000000
oooo@000000g0?ooo`03@000003oool0oooo0080oooo00<000000:Vmj02Y_NP05P2Y_NP50:Vii0<0
/<GY2@2Y_NP409j[h0D0_=;Z1`2Y_NP70:VfhP80U97=203Im^440:JWeP@0_n7`2@2^[mP60:Vli`<0
OWg81P3Eom030:28^PL0Xj?E1P2X/n430;:[d@030?ooo`000000oooo00<0oooo00M000000?ooo`3o
ool0oooo@000003ooom0000001/0oooo000M0?ooo`03@000003ooom000000080oooo00<00000@000
003oool0602Y_NP80;35j@P0ZKgX0`2NZn070;cBjPL0ZKgX1P2Y]^8:0=Wfh@<0YZOF1P2ohO070:j_
f0030<?>h`1aL/D0LG;500D0ZKcW00<0OWg80=God03Eom000`3Eom050:28^PL0Xj?E102X/n460;:[
d@030000003oool0oooo0080oooo00M000000?ooo`3oool0oooo@000003ooom0000003H0oooo00=0
00000?oood0000000P3oool00`00001000000?ooo`0H0:Vmj0P0/<GY202Y_NP309j[h0L0_=;Z1`2Y
_NP60:VfhPX0fOKQ0`2VYmH60;oQl0L0[ZoH00<0`lkS075ba@1aL/D01@2Y_>L00`1nOLP0eOo@0=Go
d0030=God0D0X8Rj1`2SXmD40:Rch@H0/Z_A00<000000?ooo`3oool00P3oool01d000000oooo0?oo
o`3ooom000000?oood0000006`3oool001d0oooo00=000000?oood0000000P3oool010000000oooo
0?ooo`3ooolE0:Vmj0<0X[_[202`aNT80:Vmj0X0_=;Z1`2O^N/905VSmPL0fOKQ202ohO050:j_f0@0
`lkS1P1aL/D30=God0T0X8Rj1`2SXmD90;:[d@03@00000000000oooo0080oooo00M000000?ooo`3o
ool0oooo@000003ooom0000003H0oooo00=000000?oood0000000P3oool010000000oooo0?ooo`3o
oolE0:Vmj0<0X[_[202`aNT80:Vmj0X0_=;Z1`2O^N/905VSmPL0fOKQ202ohO050:j_f0@0`lkS1P1a
L/D30=God0T0X8Rj1`2SXmD90;:[d@03@00000000000oooo0080oooo00M000000?ooo`3oool0oooo
@000003ooom0000001/0oooo000M0?ooo`03@000003ooom000000080oooo00<00000@000003oool0
0P3oool@0:Vmj0P0X[_[202`aNT809JMf@L0_=;Z0`2NQkX809nij`D0FJ?f0`2Y^nL708B_l@P0_n7`
0P2^[mP60<?>h`P0LG;500<0dojo0:28^P2PR;X01`2PR;X50:>Se@<0^L_X2@2bZm400`3oool00000
0?ooo`02@00000@0oooo00=000000?ooo`3oool0=@3oool00d000000oooo@00000020?ooo`030000
04000000oooo0080oooo402Y_NP80::kj`P0/<GY202FWMT70;cBjP<0WXNj202O^N/505VSmP<0ZK_W
1`24[o480;oQl080[ZoH1P33c^<8075ba@030=?n_`2PR;X0X8Rj00L0X8Rj1@2SXmD30;W;j0T0/Z_A
00<0oooo0000003oool00T0000040?ooo`03@000003oool0oooo01X0oooo000M0?ooo`03@000003o
oom000000080oooo00<000000?ooo`3oool00`3oool=0:Vmj0<0YJ;B202R^n/50;35j@<0ZKgX2@2F
WMT30;cBjPH0WXNj202O^N/80:Vki`P0Q:oa1P2ohO080<?>h`L0LG;50`3Co[l90:28^P80Xj?E1@2i
bnP80;:[d@80cn7U00<000000?ooo`3oool0?@3oool00d000000oooo@00000020?ooo`030000003o
ool0oooo00<0oooo3@2Y_NP30:FRdPP0X[_[1@2`aNT30:Vmj0T0UYgI0`2ld^X609j7^PP0WkW[202Y
^nL808B_l@H0_n7`2033c^<7075ba@<0dojo2@2PR;X20:>Se@D0^L_X202bZm420<oQi@030000003o
ool0oooo0280oooo000N0?ooo`05@000003oool0oooo0?oood0000001P3oool80:Vmj0P0YJ;B202R
^n/70:Vmj0X0UYgI202NQkX609nij`<0XiO8202Y^nL508B_l@80YIc=1`2=T]<80<?>h`D0LG;5103C
o[l90:28^PP0^L_X1@2bZm450<oQi@030000003oool0oooo03d0oooo00E000000?ooo`3oool0oooo
@00000060?ooo`P0ZKgX202UX]880::kj`L0ZKgX2P2FWMT809j7^PH0WkW[0`2SUlP80:Vki`D0Q:oa
0P2UW<d708fBd`P0`lkS1@1aL/D40=?n_`T0X8Rj202ibnP50;:[d@D0cn7U00<000000?ooo`3oool0
8@3oool00280oooo00<000000?ooo`3oool0103oool90:Vmj0P0YJ;B1@2R^n/:0:Vmj0P0UYgI00<0
b=GT09j7^P2NQkX01`2NQkX309nij`D0XiO82@2Y^nL70:FLc@P0SI;C1P33c^<4075ba@D0dojo202P
R;X208KAO0L0^L_X102bZm460<oQi@03@00000000000oooo0440oooo00<000000?ooo`3oool0103o
ool90:Vmj0P0YJ;B1@2R^n/:0:Vmj0P0UYgI00<0b=GT09j7^P2NQkX01`2NQkX309nij`D0XiO82@2Y
^nL70:FLc@P0SI;C1P33c^<4075ba@D0dojo202PR;X208KAO0L0^L_X102bZm460<oQi@03@0000000
0000oooo0240oooo000Q0?ooo`03000004000000oooo00H0oooo202Y_NP90:FRdPl0ZKgX1@2FWMT4
0<SEi0T0WXNj202SUlP60:Vki`80ZkWS1`2UW<d908fBd`D0`lkS0`1aL/D70=?n_`H0X8Rj1026dG`7
0;W;j080/Z_A203?hND00`000000oooo0?ooo`0o0?ooo`03000004000000oooo00H0oooo202Y_NP9
0:FRdPl0ZKgX1@2FWMT40<SEi0T0WXNj202SUlP60:Vki`80ZkWS1`2UW<d908fBd`D0`lkS0`1aL/D7
0=?n_`H0X8Rj1026dG`70;W;j080/Z_A203?hND00`000000oooo0?ooo`0P0?ooo`004@3oool3@000
00<0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0oooo202Y_NP70:FRdP80cN;W3P2Y_NP309JMf@H0b=GT202NQkX00`3Oo;L0XiO80:>Gb0060:>G
b0@0ZK_W1@2[^N<70:FLc@L0SI;C0P30k?800`0XT>h0`lkS0<?>h`020<?>h`03075ba@3Co[l0dojo
00H0dojo1@2PR;X508KAO0L0^L_X2@3?hND00`2eZ/h0oooo0000000`0?ooo`=000000`3oool00d00
0000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool80:Vm
j0L0YJ;B0P3=h^L>0:Vmj0<0UYgI1P38eN@809j7^P030=ol]`2SUlP0XiO800H0XiO8102Y^nL50:^i
h`L0YIc=1`2=T]<20<3/lP0302R@kP33c^<0`lkS0080`lkS00<0LG;50=?n_`3Co[l01P3Co[l50:28
^PD0Q]5l1`2ibnP90<oQi@030;FZcP3oool000000240oooo000A0?ooo`03@000003oool0oooo0080
oooo00=000000?oood0000000P3oool00d000000oooo@00000030?ooo`03000004000000oooo00P0
oooo1`2Y_NP60:FRdP@0cN;W3P2Y_NP80<SEi0L0WXNj0`3Oo;L80:>Gb0P0ZkWS1`2UW<d508fBd`D0
`>cb1@0XT>h30:Rmj0D0dojo102PR;X708KAO0L0SkKa1P3?hND40;FZcP030?ooo`000000oooo02h0
oooo00=000000?ooo`3oool00P3oool00d000000oooo@00000020?ooo`03@000003ooom0000000<0
oooo00<00000@000003oool0203oool70:Vmj0H0YJ;B103=h^L>0:Vmj0P0b=GT1`2NQkX30=ol]`P0
XiO8202[^N<70:FLc@D0SI;C1@30k?8502R@kP<0Z;gX1@3Co[l40:28^PL0Q]5l1`2?]_460<oQi@@0
]J[>00<0oooo0000003oool07`3oool00180oooo00M000000?ooo`3oool0oooo@000003ooom00000
0080oooo00=000000?oood0000000`3oool00`000000oooo0?ooo`090?ooo`L0ZKgX0`2UX]870<gR
i`D0ZKgX0`2Y^ND608BGg@P0b=GT1@2NQkX40=ol]`L0XiO80P3In=l80:^ih`L0YIc=0P2=T]<80<3/
lPP0Z;gX00@005??0=?n_`3Co[l0dojo0`2PR;X00`26dG`0U8g909B=b@0609B=b@L0SkKa0`3?hND6
0;FZcP030?oood000000oooo02l0oooo00M000000?ooo`3oool0oooo@000003ooom000000080oooo
00=000000?oood0000000`3oool00`000000oooo0?ooo`090?ooo`L0ZKgX0`2UX]870<gRi`D0ZKgX
0`2Y^ND608BGg@P0b=GT1@2NQkX40=ol]`L0XiO80P3In=l80:^ih`L0YIc=0P2=T]<80<3/lPP0Z;gX
00@005??0=?n_`3Co[l0dojo0`2PR;X00`26dG`0U8g909B=b@0609B=b@L0SkKa0`3?hND60;FZcP03
0?oood000000oooo01l0oooo000B0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?oo
o`03@000003ooom0000000<0oooo00=000000?ooo`3oool02`3oool50:Vmj080YJ;B2@3=h^L70:Vi
i@P0Q9OM1P38eN@509j7^PD0gobg1@2SUlP40=Whg`L0ZkWS1`2UW<d80<3/lP<0[l;W1`2X_NP3001C
c`80dojo00<0X8Rj08KAO02WYM@0202DSLT808nfl@P0]J[>0P3oool00`000000oooo0?ooo`0]0?oo
o`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000003ooom0000000<0oooo00=0
00000?ooo`3oool02`3oool50:Vmj080YJ;B2@3=h^L70:Vii@P0Q9OM1P38eN@509j7^PD0gobg1@2S
UlP40=Whg`L0ZkWS1`2UW<d80<3/lP<0[l;W1`2X_NP3001Cc`80dojo00<0X8Rj08KAO02WYM@0202D
SLT808nfl@P0]J[>0P3oool00`000000oooo0?ooo`0M0?ooo`004@3oool00d000000oooo@0000002
0?ooo`03@000003ooom000000080oooo00=000000?oood0000000`3oool00`000000oooo0?ooo`0<
0?ooo`D0ZKgX203=h^L30:Vdh@L0ZKWU2024Umd50<SEi0@0WXNj1P3Oo;L30:>Gb0L0fOSO1`2[^N<4
0:FLc@H0Zl?[202_`^L70:Rmj0P0YjGD202DSLT508nfl@<0YZ_K202eZ/h20?ooo`030000003oool0
oooo02/0oooo00=000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom0
000000<0oooo00<000000?ooo`3oool0303oool50:Vmj0P0cN;W0`2Y]>470:Vii@P0Q9OM1@38eN@4
09j7^PH0gobg0`2SUlP70=Whg`L0ZkWS102UW<d60:_3j`P0[l;W1`2X_NP80:NUe0P0U8g91@2?]_43
0:J[f`P0]J[>0P3oool00`000000oooo0?ooo`0L0?ooo`004P3oool00d000000oooo0?ooo`020?oo
o`03@000003oool0oooo0080oooo00I000000?ooo`3oool0oooo00000400000?0?ooo`T0JjOd1`2Y
]>470:Vii@D0Q9OM0`2lgo801007F=80b=GT0<SEi038eN@309j7^PP0gobg00<0XiO80=Whg`3In=l0
1`3In=l60:^ih`T0Zl?[0P2n//h70:o2i`D0Z;gX0`2WYmH70:NUe0P0U8g9202VZm/80;FZcP80oooo
00<000000?ooo`3oool0;03oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo
00I000000?ooo`3oool0oooo00000400000?0?ooo`T0JjOd1`2Y]>470:Vii@D0Q9OM0`2lgo801007
F=80b=GT0<SEi038eN@309j7^PP0gobg00<0XiO80=Whg`3In=l01`3In=l60:^ih`T0Zl?[0P2n//h7
0:o2i`D0Z;gX0`2WYmH70:NUe0P0U8g9202VZm/80;FZcP80oooo00<000000?ooo`3oool0703oool0
0200oooo00<000000?ooo`3oool0403oool506^Wm0<0ZK_V1`2Y]>460:Vii@<0Q9OM1P2lgo8200MH
dP80b=GT00<0WXNj0=ol]`07F=800P38g^T504f;jPP0fOSO0`2PWM4606^/m`H0Zl?[1@2n//h70:o2
i`L0YjOF202WYM@609B=b@80`KC=202VZm/60;FZcP80ZoCa00<0oooo@00000000000>`3oool00`00
0000oooo0?ooo`0@0?ooo`D0JjOd0`2Y^nH70:Vdh@H0ZKWU0`24Umd60;cOlP801eSB0P38eN@00`2N
QkX0gobg00MHdP020<SNj@D0CH_Z203In=l30:2Md@H0Jjcg1P2[`n/50;jbcPL0[l;W1`2WYmH80:NU
e0H0U8g90P31]<d80:J[f`H0]J[>0P2[m?400`3ooom000000000000M0?ooo`00803oool00`000010
00000?ooo`0A0?ooo`P0ZK_V1`2Y]>460:Vii@P0_=ob1@07F=850<SNj@P0CH_Z202PWM4606^/m`@0
Zl?[1P2n//h50:o2i`<0[;;M1`2WYmH70:NUe0D0U8g90`31]<d80:J[f`@0]J[>1@2[m?400`3oool0
00000?ooo`0j0?ooo`03000004000000oooo0140oooo202Y^nH70:Vdh@H0ZKWU202lgo8500MHdPD0
b=kY201=RnX80:2Md@H0Jjcg102[`n/60;jbcPD0[l;W0`2//]d70:NWePL0YjGD1@2DSLT30<6dc@P0
YZ_K102eZ/h50:_dl@030?ooo`000000oooo01`0oooo000A0?ooo`=000000P3oool00d000000oooo
0?ooo`020?ooo`03@000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool70:VkiPH0ZKCQ
0P2_^n<708jGf0L0_=ob0`07F=870<SNj@D0CH_Z0`2`]mh80:2Md@D0Jjcg0`2[`n/80;jbcPL0[;;M
1`2WYmH70:NUe0<0U8g91P31]<d80:J[f`80]J[>1P2[m?420?ooo`030000003oool0oooo02T0oooo
0d0000020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0B0?ooo`L0ZK_V1P2Y]>420:nkh`L0SYOH1`2lgo8300MHdPL0b=kY1@1=RnX30;2ggPP0X9gA
1@1[[?L30:_3j`P0_[;>1`2//]d70:NWePL0YjGD0`2DSLT60<6dc@P0YZ_K0P2eZ/h60:_dl@80oooo
00<000000?ooo`3oool06P3oool00180oooo00I000000?ooo`3ooom000000?oood0000020?ooo`03
@000003ooom0000000<0oooo00=000000?ooo`3oool04`3oool70:VkiP<0ZKCQ102_^n<908jGf0H0
_=ob2P38g^T70;2ggPL0X9gA0P3AknP507>Nk0T0_[;>0P3If=H70:bbg@L0YjOF1`2WYM@00`2DSLT0
`KC=0<6dc@050<6dc@P0YZ_K2@2[m?420?ooo`040000003oool0oooo0?ooo`E000000P3oool00d00
0000oooo0?ooo`0N0?ooo`06@000003oool0oooo@000003ooom000000P3oool00d000000oooo@000
00030?ooo`03@000003oool0oooo01<0oooo1`2Y^nH30:Vdh@@0[k_S2@2>UmP60;cOlPX0b=kY1`2`
]mh70:2Md@80dNoX1@1cW^`90;jbcP80fMSF1`2//]d70:NWePL0YjGD00<0U8g90<6dc@31]<d01@31
]<d80:J[f`T0ZoCa0P3oool010000000oooo0?ooo`3oool5@0000080oooo00=000000?ooo`3oool0
3P3oool00100oooo14000000103ooom000000?oood0000020?ooo`03@000003ooom0000000<0oooo
00<000000?ooo`3oool0503oool70:VkiPL0[k_S1`2>UmP20=7Zi`L0QI_P1P38g^T30:>eiPL0/;ON
1@2PWM440=7_j0D0Lik/1`2n//h30=WHePL0[;;M1`2WYmH70:NUe0T0`KC=2@2;c?d808NhmP030?oo
od000000oooo00@0oooo00M000000?ooo`3oool0oooo@000003ooom0000001d0oooo14000000103o
oom000000?oood0000020?ooo`03@000003ooom0000000<0oooo00<000000?ooo`3oool0503oool7
0:VkiPL0[k_S1`2>UmP20=7Zi`L0QI_P1P38g^T30:>eiPL0/;ON1@2PWM440=7_j0D0Lik/1`2n//h3
0=WHePL0[;;M1`2WYmH70:NUe0T0`KC=2@2;c?d808NhmP030?oood000000oooo00@0oooo00M00000
0?ooo`3oool0oooo@000003ooom0000000l0oooo000@0?ooo`03@000003ooom000000080oooo00=0
00000?oood0000000P3oool00d000000oooo@00000020?ooo`03000004000000oooo01H0oooo1`2P
^n`60:nkh`H0SYOH103Aj^L808FKh0L0XkGV1`2`]mh30:2Md@H0dNoX1P1cW^`50;jbcPD0fMSF1`2/
/]d909gIo0D0Fkkl1`31]<d20=7hiPH0Rlcm0`2ado8808NhmP030?ooo`000000oooo00<0oooo00=0
00000?ooo`3oool00`3oool00d000000oooo0?ooo`0K0?ooo`03@000003ooom000000080oooo00=0
00000?oood0000000P3oool00d000000oooo@00000020?ooo`03000004000000oooo01H0oooo1`2P
^n`60:nkh`H0SYOH103Aj^L808FKh0L0XkGV1`2`]mh30:2Md@H0dNoX1P1cW^`50;jbcPD0fMSF1`2/
/]d909gIo0D0Fkkl1`31]<d20=7hiPH0Rlcm0`2ado8808NhmP030?ooo`000000oooo00<0oooo00=0
00000?ooo`3oool00`3oool00d000000oooo0?ooo`0=0?ooo`004@3oool2@0000080oooo00=00000
0?oood0000000P3oool00d000000oooo@00000020?ooo`030000003oool0oooo01L0oooo1`2P^n`6
0:nkh`<0SYOH1P3Aj^L608FKh0<0`=O[1`2S]NH70;2ggP030:2Md@3AknP0dNoX00H0dNoX1@1cW^`4
0;jbcPH0fMSF1@2//]d309jJc`H0WMWl0`2NP[@405^no0H0`KC=1@3An>H80;7ClPD0QkSf0`2X/Mh0
0`3oool000000?ooo`020?ooo`04@000003oool0oooo0?ooo`9000007`3oool2@0000080oooo00=0
00000?oood0000000P3oool00d000000oooo@00000020?ooo`030000003oool0oooo01L0oooo1`2P
^n`60:nkh`<0SYOH1P3Aj^L608FKh0<0`=O[1`2S]NH70;2ggP030:2Md@3AknP0dNoX00H0dNoX1@1c
W^`40;jbcPH0fMSF1@2//]d309jJc`H0WMWl0`2NP[@405^no0H0`KC=1@3An>H80;7ClPD0QkSf0`2X
/Mh00`3oool000000?ooo`020?ooo`04@000003oool0oooo0?ooo`900000403oool00180oooo00E0
00000?ooo`3oool0oooo@00000040?ooo`06@000003oool0oooo0?ooo`00001000006@3oool60:2k
k0H0[k_S0P2>UmP80=7Zi`<0QI_P1P30en/60:>eiPL0/;ON1`3AknP30:6Tf00303V>k`1cW^`0Lik/
0080Lik/0P2n//h80=WHePT0WY[?1`2NP[@202]_gP<0Fkkl0`31]<d60=7hiP80_O3c202ado880:Ra
gP050000003oool0oooo0?oood0000000`3oool00d000000oooo0?ooo`0O0?ooo`05@000003oool0
oooo0?oood000000103oool01T000000oooo0?ooo`3oool00000@00001T0oooo1P2P^n`60:nkh`80
SYOH203Aj^L308FKh0H0`=O[1P2S]NH70;2ggPL0dNoX0`2QY=P00`0iS^l0Lik/07>Nk00207>Nk080
_[;>203If=H909jJc`L0WX:d0P0[Kmh305^no0<0`KC=1P3An>H20;g`l`P0/M?b202X/Mh01@000000
oooo0?ooo`3ooom0000000<0oooo00=000000?ooo`3oool03`3oool001l0oooo00<000000?ooo`3o
ool06@3oool60:2kk0H0[k_S2P3Aj^L80<3Gj`L0XkGV2@2CQL480:6Tf0D0>Hk_203If=H20<3fk`L0
WY[?00<0gOKL09j2]02NP[@01P2NP[@302]_gP0305^no031]<d0`KC=00D0dOSV102ml?<60;7ClP<0
Zl3Y202X/Mh010000000oooo@000040000030?ooo`=00000;03oool00`000000oooo0?ooo`0I0?oo
o`H0X;_/1P2_^n<:0=7Zi`P0`=O[1`2S]NH909>5`@P0XJCH1@0iS^l80=WHeP80`?K_1`2NV/l00`3M
m]`0WX:d09j2]00609j2]0<0:foN00<0Fkkl0<6dc@31]<d01@3An>H40;g`l`H0/M?b0`2[`>T80:Ra
gP040000003ooom00000@00000<0oooo0d00000?0?ooo`007`3oool00`00001000000?ooo`0J0?oo
o`H0VY?;2@20/O@708JalPP0`=O[1P2O]NP809>5`@80d_NU202QY=P503V>k`D0fMSF1030m^l609jJ
c`<0gOKL1`2NP[@502]_gPD0dOSV1P2ml?<80:_0j@H0Z;7N0P2fdNh00`3oool000000?ooo`0c0?oo
o`03000004000000oooo01X0oooo1P2JTl/9082am0L0Q[7b2030en/609nej0P0ThG10P3BmjD80:6T
f0D0>Hk_1@3If=H40<3fk`H0WY[?0`3Mm]`709j2]0D0:foN1@3An>H60;g`l`P0Zl3Y1P2X/Mh20;KA
kP030?ooo`000000oooo01H0oooo000?0?ooo`900000103oool00d000000oooo0?ooo`020?ooo`03
@000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool809ZCb`D0P;7d0`2YUL4808JalPL0
X[o^1P2O]NP709>5`@<0d_NU202QY=P503V>k`<0fMSF1P30m^l409jJc`@0gOKL202NP[@702]_gPH0
_O3c0`2]aN/80:_0j@<0Z;7N1@2fdNh00`000000oooo0?ooo`0R0?ooo`900000103oool00d000000
oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool809ZCb`D0
P;7d0`2YUL4808JalPL0X[o^1P2O]NP709>5`@<0d_NU202QY=P503V>k`<0fMSF1P30m^l409jJc`@0
gOKL202NP[@702]_gPH0_O3c0`2]aN/80:_0j@<0Z;7N1@2fdNh00`000000oooo0?ooo`0E0?ooo`00
3`3oool00d000000oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oood000000
0P3oool00`00001000000?ooo`0L0?ooo`P0VY?;2@2YUL4408JalP<0YJgN1`2R_nh509nej0H0ThG1
103BmjD60:6Tf0<0`n3]1@1nRmH80<3fk`<0WY[?1@3Mm]`709j2]0800000201g/oP80:g5j`L0Zl3Y
202fdNh00`3ooom000000?ooo`0R0?ooo`03@000003ooom000000080oooo00=000000?oood000000
0P3oool00d000000oooo@00000020?ooo`03000004000000oooo01`0oooo202JTl/90:VE`@@0Q[7b
0`2U[Mh70::okPD0WkGX1P2CQL440=;gY@H0XJCH0`33h>d507j;ePP0`?K_0`2NV/l50=gfg0L0WX:d
0P00000807Ncn0P0[LG[1`2[`>T80;KAkP030?oood000000oooo01D0oooo000?0?ooo`03@000003o
oom000000080oooo00=000000?oood0000000P3oool00d000000oooo@00000020?ooo`030000003o
ool0oooo01`0oooo1`2JTl/20=;hi0T0ZIG11`2U[Mh70::okP@0WkGX1@2CQL460=;gY@<0XJCH1@33
h>d707j;eP80_Zc800<0@h_/0<3fk`30m^l00P30m^l00`2NV/l0gOKL0=gfg0040=gfg0L0WX:d0`00
000507Ncn0<0Y;7R202]aN/709^gk0P0]]7^903oool00d000000oooo@00000020?ooo`03@000003o
oom000000080oooo00=000000?oood0000000P3oool00`000000oooo0?ooo`0L0?ooo`L0VY?;0P3B
n>@90:VE`@L0YJgN1`2R_nh409nej0D0ThG11P3BmjD30:6Tf0D0`n3]1`1nRmH20;j/b00304>;k030
m^l0`?K_0080`?K_00<0WY[?0=gfg03Mm]`0103Mm]`709j2]0<000001@1g/oP30:BahPP0[LG[1`2K
]n`80;KAkQL0oooo000?0?ooo`9000000`3oool00d000000oooo@00000020?ooo`03@000003ooom0
00000080oooo00<00000@000003oool07@3oool509ZCb`<0d_ST202YUL420>;mb@L0YJgN1`2R_nh4
09nej0@0ThG11`3BmjD80<?Pk@D0OX_F102n[<P404>;k0P0gOKL1@2NP[@5000000P0Y;7R1@2]aN/3
0:Vmj0L0VkO/1`2fdNhT0?ooo`9000000`3oool00d000000oooo@00000020?ooo`03@000003ooom0
00000080oooo00<00000@000003oool07@3oool509ZCb`<0d_ST202YUL420>;mb@L0YJgN1`2R_nh4
09nej0@0ThG11`3BmjD80<?Pk@D0OX_F102n[<P404>;k0P0gOKL1@2NP[@5000000P0Y;7R1@2]aN/3
0:Vmj0L0VkO/1`2fdNhG0?ooo`003`3oool00d000000oooo0?ooo`020?ooo`03@000003ooom00000
0080oooo00=000000?oood0000000P3oool00`000000oooo0?ooo`0M0?ooo`<0VY?;1P3Bn>@60:VE
`@<0h_g9202U[Mh709VAbP<0WkGX0`2CQL400`3BmjD0Z9_90:RKb@0608bOh@L0`n3]0`1nRmH60;j/
b0L0@h_/1@3Mm]`409j2]0L0ZKgX202T/N870:Vmj0P0VkO/:P3oool00d000000oooo0?ooo`020?oo
o`03@000003ooom000000080oooo00=000000?oood0000000P3oool00`000000oooo0?ooo`0M0?oo
o`<0VY?;1P3Bn>@60:VE`@<0h_g9202U[Mh709VAbP<0WkGX0`2CQL400`3BmjD0Z9_90:RKb@0608bO
h@L0`n3]0`1nRmH60;j/b0L0@h_/1@3Mm]`409j2]0L0ZKgX202T/N870:Vmj0P0VkO/7@3oool00100
oooo0T0000030?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3oool0oooo@000000P0?oo
o`0309ZCb`3Bn>@0d_ST00D0d_ST1@2YUL450>;mb@D0YJgN0P2kd^/809VAbP80WkGX0P2CQL40103B
mjD0Z9_90:RKb@2XVlT808bOh@H0`n3]00<0OX_F0;j/b02n[<P01P2n[<P709Vhk@@0gOKL102NP[@0
0`2Z_^P0ZKgX0:Vmj0050:Vmj0D0Y;7R0`2cc>`70:Vmj0D0VkO/;@3oool2@00000<0oooo00=00000
0?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom000000200oooo00<0VY?;0=;hi03Bn>@01@3B
n>@50:VE`@D0h_g91@2U[Mh20;_Bj`P0VI7:0P2O]NP209>5`@040=;gY@2XVlT0Z9_90:RKb@P0S9oQ
1P33h>d00`1nRmH0_Zc80;j/b0060;j/b0L0VKS]103Mm]`409j2]0030:Znj02Y_NP0ZKgX00D0ZKgX
1@2T/N830;?<k0L0ZKgX1@2K]n`O0?ooo`007P3oool00`000000oooo0?ooo`0N0?ooo`T0d_ST102Y
UL450>;mb@<0YJgN1@2kd^/809VAbP030:RKb@2O]NP0ThG100D0Z9_91@2<Wn430;g>i`D0OI?M202n
[<P20:f2YPL0VKS]0`3Mm]`309j2]080Z[kX1`2Y_NP30:BahPD0/lc/1`2Y_NQ00?ooo`030000003o
ool0oooo01h0oooo2@3Bn>@40:VE`@D0h_g90`2U[Mh50;_Bj`P0VI7:00<0Z9_909nej02CQL401@2X
VlT508bOh@<0_LkW1@1mTmd80;j/b080[H:V1`2I^>d30=gfg0<0WX:d0P2Z_^P70:Vmj0<0Y;7R1@2c
c>`70:Vmj2@0oooo000N0?ooo`03@000003oool0oooo02<0oooo00@085[@0=;hi03Bn>@0d_ST0`2Y
UL470>;mb@L0^m;[1`2ITLX20<k8e0L0Z9_90`2<Wn450;g>i`H0OI?M1P2n[<P40:f2YPD0VKS]0`2X
[M/20=gfg00309j2]02Z_^P0Z[kX0080Z[kX1`2Y_NP80;?<k0@0ZKgX@P3oool00d000000oooo0?oo
o`0S0?ooo`04021Jd03Bn>@0d_ST0=;hi0<0ZIG11`3RoLT70;_Bj`L0VI7:0P3>b=@70:RKb@<0S9oQ
1@2mc^L607fCg@H0_Zc8102]PZH509Vhk@<0Z:gK0P3Mm]`00`2NP[@0Z[kX0:Znj0020:Znj0L0ZKgX
202cc>`40:Vmj2H0oooo000?0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3o
ool01D000000oooo0?ooo`3oool0000002H0oooo0`0PF]020=;hi0040:VE`@3RoLT085[@0<gVj@L0
V8c61P2kd^/509VAbP<0c/SD202XVlT80;g>i`D0OI?M1@2n[<P60:f2YPL0Z:gK00<0Z[kX0=gfg02N
P[@0102Z_^P809jij`L0/lc/=`3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080
oooo00E000000?ooo`3oool0oooo0000000V0?ooo`<085[@0P3Bn>@0102YUL40h_g9021Jd03=i^T7
09R<aPH0^m;[1@2ITLX30<k8e0P0Z9_9202mc^L507fCg@D0_Zc81P2]PZH70:R]f`030:Znj03Mm]`0
WX:d00@0Z[kX202N^N/70;?<k2X0oooo000>0?ooo`03@000003ooom000000080oooo00=000000?oo
od0000000P3oool00d000000oooo@00000020?ooo`030000003oool0oooo02D0oooo1P0PF]030<gV
j@P0V8c6102kd^/309VAbPH0c/SD1P2XVlT20;okj0L0_LkW1P1mTmd40;j/b0H0[H:V00<0000Y0:R]
f`2X[M/01@2X[M/40:Znj0<0ZKgX202N^N/l0?ooo`03@000003ooom000000080oooo00=000000?oo
od0000000P3oool00d000000oooo@00000020?ooo`030000003oool0oooo02D0oooo1P0PF]030<gV
j@P0V8c6102kd^/309VAbPH0c/SD1P2XVlT20;okj0L0_LkW1P1mTmd40;j/b0H0[H:V00<0000Y0:R]
f`2X[M/01@2X[M/40:Znj0<0ZKgX202N^N/`0?ooo`003P3oool00d000000oooo@00000020?ooo`03
@000003ooom000000080oooo00=000000?oood0000000P3oool00`00001000000?ooo`0V0?ooo`<0
85[@1@3=i^T709R<aP80g_cD00D0=HW/0;_Bj`2kd^/0^m;[09VAbP070<k8e0@0Z9_91@2onnP70;g>
i`D0OI?M0`2n[<P60:f2YP80000Y1`2X[M/80:Vmj0D0W[W[?P3oool00d000000oooo@00000020?oo
o`03@000003ooom000000080oooo00=000000?oood0000000P3oool00`00001000000?ooo`0V0?oo
o`<085[@1@3=i^T709R<aP80g_cD00D0=HW/0;_Bj`2kd^/0^m;[09VAbP070<k8e0@0Z9_91@2onnP7
0;g>i`D0OI?M0`2n[<P60:f2YP80000Y1`2X[M/80:Vmj0D0W[W[<P3oool000l0oooo00M000000?oo
o`3oool0oooo@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo0?oo
o`0V0?ooo`8085[@1`3=i^T509R<aP@0g_cD0`0eRN`90<k8e080Z9_91`2onnP708bnm`0300j@h@1m
Tmd0OI?M0080OI?M00<0_Zc80:f2YP2]PZH01@2]PZH30000:@D0Z:gK0P2lf>h80:Vmj4<0oooo00M0
00000?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000
oooo0?ooo`0V0?ooo`8085[@1`3=i^T509R<aP@0g_cD0`0eRN`90<k8e080Z9_91`2onnP708bnm`03
00j@h@1mTmd0OI?M0080OI?M00<0_Zc80:f2YP2]PZH01@2]PZH30000:@D0Z:gK0P2lf>h80:Vmj3H0
oooo000>0?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo
@000000/0?ooo`P0cNKY102HS<H60=kle0<0=HW/203>b=@40;okj0H0WkCW202<__L300j@h@P0[H:V
0`0002T30:R]f`D0_=S^1@2Y_NQ40?ooo`03@000003ooom000000080oooo00=000000?oood000000
0P3oool00d000000oooo@000000/0?ooo`P0cNKY102HS<H60=kle0<0=HW/203>b=@40;okj0H0WkCW
202<__L300j@h@P0[H:V0`0002T30:R]f`D0_=S^1@2Y_NPh0?ooo`003`3oool00d000000oooo0?oo
o`020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool0;`3oool40<gVj@<0V8c61@3N
o=@20:BGa`80NGg;0`0eRN`40<k8e0@0Im_U0`2Y_NP609ndi`D0S;kg0P2Y/]l300j@h@P0[H:V1000
02T80;cHkTT0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03@000003o
ool0oooo02l0oooo103=i^T309R<aPD0g_cD0P2TUlL207Umb`<0=HW/103>b=@406OKi@<0ZKgX1P2O
]>L508bnm`80ZK;O0`0>T>480:f2YP@0000Y202lf>hl0?ooo`00B`3oool2065_b`<0cNKY00@0V8c6
0=kle03No=@0g_cD1P2TUlL507Umb`<0Im_U202Y_NP609ndi`L0ZK;O0P0>T>470:f2YPH0T[G_1@2l
f>j70?ooo`80HFo;0`3=i^T0102HS<H0g_cD0=kle03No=@60:BGa`D0NGg;0`1WfnD80:Vmj0H0WkCW
1`2Y/]l200j@h@L0[H:V1P2B]Nl50;cHkSh0oooo001<0?ooo`L0HFo;00<0gO_I0:BGa`2TUlL0102T
UlL707Umb`80`jVo1`2Y_NP409ndi`<0[lGZ1P2Y/]l300j@h@H0[H:V00<0UfZL09:ek`2B]Nl0102B
]Nn<0?ooo`L0HFo;00<0gO_I0:BGa`2TUlL0102TUlL707Umb`80`jVo1`2Y_NP409ndi`<0[lGZ1P2Y
/]l300j@h@H0[H:V00<0UfZL09:ek`2B]Nl0102B]Nm20?ooo`00C03oool6065_b`<0gO_I1P2TUlL5
07Umb`@0`jVo1`2Y_NP70:o5jPD0ZK;O0`0>T>460:f2YP0309MZW02B]Nl0T[G_0080T[G_SP3oool6
065_b`<0gO_I1P2TUlL507Umb`@0`jVo1`2Y_NP70:o5jPD0ZK;O0`0>T>460:f2YP0309MZW02B]Nl0
T[G_0080T[G_A03oool004d0oooo101QKl/40=gkf@H0Y9O7101iOL/60<>Y_`L0Xk_[1P2_aNX30:Vb
g`<0]/k/0P0>T>450:f2YP<0UfZLTP3oool4065_b`@0gO_I1P2TUlL407Umb`H0`jVo1`2S^n/60:o5
jP<0ZK;O0`2fc^`200j@h@D0[H:V0`2GJYa70?ooo`00C@3oool3065_b`H0gO_I1@2TUlL307Umb`H0
`jVo0P3>lYX80:>kj`D0[lGZ1@2fc^`200j@h@D0[H:V0`2GJYbB0?ooo`<0HFo;1P3MnmT50:BGa`<0
NGg;1P33ZKl20<kbVPP0Xk_[1@2_aNX50;K>k0803Y3Q1@2]PZH309MZW4L0oooo001>0?ooo`03065_
b`3MnmT0gO_I00D0gO_I1P2TUlL00`1iOL/0`jVo0<>Y_`050<>Y_`<0c_:J1@2S^n/20:Vmj0H0WI?8
102fc^`200j@h@D0[H:V0`2GJYbC0?ooo`03065_b`3MnmT0gO_I00D0gO_I1P2TUlL00`1iOL/0`jVo
0<>Y_`050<>Y_`<0c_:J1@2S^n/20:Vmj0H0WI?8102fc^`200j@h@D0[H:V0`2GJYa70?ooo`00D`3o
ool0101/O]@0gO_I0=gkf@3MnmT50:BGa`L0`jVo1@3>lYX70:Vmj0L0WI?80`2fc^`00`0>T>40[H:V
0:f2YP030:f2YP<0UfZLV03oool0101/O]@0gO_I0=gkf@3MnmT50:BGa`L0`jVo1@3>lYX70:Vmj0L0
WI?80`2fc^`00`0>T>40[H:V0:f2YP030:f2YP<0UfZLA`3oool005<0oooo101/O]@609[An`D0`jVo
103>lYX30:^oj0H0ZKgX1P2MTlP0103oool0]/k/0;K>k02fc^`200j@h@<0[H:V0`2GJYbI0?ooo`@0
K7kD1P2JdO/50<>Y_`@0c_:J0`2[_nP60:Vmj0H0WI?800@0oooo0;K>k02fc^`0]/k/0P0>T>430:f2
YP<0UfZLB03oool005@0oooo101/O]@509[An`@0`jVo0P3>lYX70:^oj0H0ZKgX102MTlP20?ooo`@0
]/k/00@03Y3Q0:f2YP2]PZH0[H:V0`2GJYbJ0?ooo`@0K7kD1@2JdO/40<>Y_`80c_:J1`2[_nP60:Vm
j0@0WI?80P3oool40;K>k00400j@h@2]PZH0[H:V0:f2YP<0UfZLB03oool005@0oooo1P1/O]@409[A
n`<0`jVo00<0c_:J0:Rhi@2X^>D01`2[_nP50:Vmj0<0WI?8103oool30;K>k00400j@h@2]PZH0[H:V
0:f2YP<0UfZLVP3oool606ane0@0V]7k0`33ZKl00`3>lYX0Z;SU0:Rhi@070:^oj0D0ZKgX0`2MTlP4
0?ooo`<0]/k/00@03Y3Q0:f2YP2]PZH0[H:V0`2GJYa80?ooo`00E@3oool306ane0@0[j_C0P2JdO/2
0<>Y_`D0Z;SU102[_nP40?ooo`@0ZKgX00<0WI?80?ooo`3oool00`3oool30;K>k00300j@h@2]PZH0
[H:V00@0UfZLV`3oool306ane0@0[j_C0P2JdO/20<>Y_`D0Z;SU102[_nP40?ooo`@0ZKgX00<0WI?8
0?ooo`3oool00`3oool30;K>k00300j@h@2]PZH0[H:V00@0UfZLB03oool005D0oooo1`2_Zm<30=cn
cPL0Z;SU4@3oool30;K>k00309MZW02]PZH0[H:V00@0UfZLV`3oool70:n[d`<0g?k>1`2X^>DA0?oo
o`<0]/k/00<0UfZL0:f2YP2]PZH0102GJYa80?ooo`00EP3oool50:n[d`@0g?k>1@2X^>DC0?ooo`<0
]/k/00<0UfZL0:f2YP2]PZH0102GJYbL0?ooo`D0[j_C103Lo/h50:RhiA<0oooo0`2fc^`00`2GJY`0
[H:V0:f2YP0409MZW4P0oooo001F0?ooo`@0[j_C1P3Lo/hH0?ooo`80]/k/00<0UfZL00j@h@2]PZH0
0`2GJYbM0?ooo`@0[j_C1P3Lo/hH0?ooo`80]/k/00<0UfZL00j@h@2]PZH00`2GJYa90?ooo`00E`3o
ool20:n[d`80g?k>7@3oool20;K>k0H0UfZLWP3oool20:n[d`80g?k>7@3oool20;K>k0H0UfZLB@3o
ool005L0oooo0P2_Zm<00`3Lo/h0oooo0?ooo`0L0?ooo`<0]/k/1@2GJYbN0?ooo`80[j_C00<0g?k>
0?ooo`3oool0703oool30;K>k0D0UfZLB@3oool007P0oooo0`2fc^`509MZW;l0oooo0`2fc^`509MZ
W4T0oooo001i0?ooo`80]/k/1@2GJYc00?ooo`80]/k/1@2GJYa90?ooo`00N@3oool20;K>k0D0UfZL
`03oool20;K>k0D0UfZLB@3oool007T0oooo0P2fc^`509MZW<00oooo0P2fc^`509MZW4T0oooo001i
0?ooo`80]/k/102GJYc10?ooo`80]/k/102GJYa:0?ooo`00NP3oool00`2fc^`0UfZL09MZW00209MZ
W<80oooo00<0]/k/09MZW02GJY`00P2GJYa:0?ooo`00NP3oool00`2fc^`0UfZL09MZW00209MZW<80
oooo00<0]/k/09MZW02GJY`00P2GJYa:0?ooo`00NP3oool20;K>k0<0UfZL`P3oool20;K>k0<0UfZL
BP3oool007X0oooo0P2fc^`309MZW<80oooo0P2fc^`309MZW4X0oooo001j0?ooo`80]/k/0`2GJYc2
0?ooo`80]/k/0`2GJYa:0?ooo`00N`3oool0102fc^`0UfZL09MZW02GJYc30?ooo`040;K>k02GJY`0
UfZL09MZW4X0oooo001k0?ooo`030;K>k02GJY`0UfZL0<@0oooo00<0]/k/09MZW02GJY`0B`3oool0
07/0oooo00<0]/k/09MZW02GJY`0a03oool00`2fc^`0UfZL09MZW01;0?ooo`00N`3oool00`2fc^`0
UfZL09MZW0340?ooo`030;K>k02GJY`0UfZL04/0oooo001l0?ooo`80UfZLa@3oool209MZW4/0oooo
001l0?ooo`80UfZLa@3oool209MZW4/0oooo001l0?ooo`030;K>k02GJY`0oooo0<@0oooo00<0]/k/
09MZW03oool0BP3oool007`0oooo00<0]/k/0?ooo`3oool0a03oool00`2fc^`0oooo0?ooo`1:0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00I@3oool00d000000oooo0?ooo`060?ooo`03@000003o
ool0oooo0;/0oooo00=000000?ooo`3oool01P3oool00d000000oooo0?ooo`1H0?ooo`00I03oool0
0d000000oooo0?ooo`080?ooo`03@000003oool0oooo0;T0oooo00=000000?ooo`3oool0203oool0
0d000000oooo0?ooo`1G0?ooo`00H`3oool00d000000oooo0?ooo`020?ooo`A00000103oool00d00
0000oooo0?ooo`2g0?ooo`04@000003oool0oooo0?ooo`A000001@3oool00d000000oooo0?ooo`1F
0?ooo`00H`3oool00d000000oooo0?ooo`020?ooo`=000001@3oool00d000000oooo0?ooo`2g0?oo
o`03@000003oool0oooo0080oooo00A000000?ooo`3ooom00000103oool00d000000oooo0?ooo`1F
0?ooo`00H`3oool00d000000oooo0?ooo`040?ooo`03@000003oool0oooo00<0oooo00=000000?oo
o`3oool0]`3oool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo@00000@0oooo00=00000
0?ooo`3oool0EP3oool006<0oooo00=000000?ooo`3oool00`3oool2@00000D0oooo00=000000?oo
o`3oool0]`3oool00d000000oooo0?ooo`020?ooo`=000001@3oool00d000000oooo0?ooo`1F0?oo
o`00I03oool00d000000oooo0?ooo`080?ooo`03@000003oool0oooo0;T0oooo00E000000?ooo`3o
ool0oooo@00000060?ooo`03@000003oool0oooo05L0oooo001U0?ooo`03@000003oool0oooo00H0
oooo00=000000?ooo`3oool0^`3oool014000000oooo@000040000050?ooo`03@000003oool0oooo
05P0oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo002D0?ooo`900000:03oool2@00001H0oooo0d00
002g0?ooo`00UP3oool00d000000oooo0?ooo`0W0?ooo`03@000003oool0oooo01@0oooo00=00000
0?ooo`3oool0]P3oool008P0oooo0d0000030?ooo`=000000`3oool3@00000D0oooo00A000000?oo
o`3oool0oooo0T0000060?ooo`03@000003oool0oooo00L0oooo1D000000103ooom00000@0000400
00030?ooo`=000000P3oool2@00000030?oood00001000000080oooo00=000000?ooo`3oool02P3o
ool3@0000080oooo140000020?ooo`9000000`3oool2@00000<0oooo0T0000020?ooo`=0000000<0
oooo@000040000000P3oool014000000oooo@0000400002D0?ooo`00R@3oool00d000000oooo0?oo
o`030?ooo`05@000003oool0oooo0?oood0000000P3oool00d000000oooo0?ooo`070?ooo`03@000
003ooom000000100oooo00A000000?ooo`3ooom000000P3oool01D000000oooo0?ooo`3ooom00000
0080oooo00=000000?oood000000103oool014000000oooo0?oood00000<0?ooo`05@000003oool0
oooo@000003oool00d0000020?ooo`06@000003oool0oooo@000003ooom000000P3oool00d000000
oooo@00000050?ooo`05@000003oool0oooo0?oood0000000P3oool01D000000oooo0?ooo`3ooom0
000009<0oooo00290?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@0000002
0?ooo`03@000003oool0oooo00L0oooo00=000000?oood000000403oool00d000000oooo0?ooo`03
0?ooo`05@000003oool0oooo0?oood0000000P3oool00d000000oooo@0000002@0000080oooo00A0
00000?ooo`3ooom00000303oool014000000oooo0?oood0000030?ooo`04@000003oool0oooo@000
00@0oooo00=000000?ooo`3oool00P3oool3@00000<0oooo00E000000?ooo`3oool0oooo@0000002
0?ooo`04@000003oool0oooo@00009@0oooo00290?ooo`9000000`3oool2@00000@0oooo0d000009
0?ooo`9000004@3oool2@00000<0oooo0T0000040?ooo`=0000000D0oooo@0000400001000000?oo
o`04@00000`0oooo140000030?ooo`90000000<0oooo@000040000000T0000000`3ooom00000@000
0002@0000080oooo0d0000020?ooo`Q000000`3oool2@00009<0oooo00290?ooo`04@000003oool0
oooo@00001<0oooo00=000000?ooo`3oool0403oool014000000oooo0?oood00000Z0?ooo`03@000
003oool0oooo0080oooo00=000000?ooo`3oool0Y`3oool008P0oooo1D0000020?ooo`03@000003o
ool0oooo00l0oooo0T00000?0?ooo`E000000P3oool00d000000oooo0?ooo`3D0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.192686, 
  0.00526322, 0.00526322}, {{9.5, 190.438}, {362.375, 
  215.563}} -> {-0.182389, -0.210404, 0.00620182, 0.00620182}, {{208.5, 
  389.438}, {362.375, 215.563}} -> {-1.41655, -0.210404, 0.00620182, 
  0.00620182}, {{9.5, 190.438}, {200.938, 54.125}} -> {-0.182708, -1.21161, 
  0.00620182, 0.00620182}, {{208.5, 389.438}, {200.938, 
  54.125}} -> {-1.41687, -1.21161, 0.00620182, 0.00620182}}]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "Even though the sample images in Fig. 5 are the different angled and \
resolutions, their eigen patterns are similar ones. The sample images having \
the same resolution take the same eigen pattern even if they are angled. The \
lower resolution sample images take the eigen patterns having smaller maximum \
amplitude.\n\tThe correlation coefficient computations between them suggest \
that all of the sample images in Fig. 5 are the same ones.\n",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["\t",
    FormatType->InputForm],
  StyleBox[
  "Thus, the meaning of the eigen pattern may be understood by every one. \
Before to continue the next section, we remove the needless variables and \
check the memories used.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["Table[corRelation[eigen2D[[1]],eigen2D[[i]]],{i,2,4,1}]", "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \({0.999999999999999822`, 0.998162474072426597`, 0.99830925732309339`}
      \)], "Output",
  CellLabel->"Out[59]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Remove[\"monoSample\",\"monoSampleW\",\"mSamplewDG\",\"eigen2DG\"];
memoryUsed\
\>", "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    InterpretationBox[\(3414\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ 3414, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Inverse transform",
  FormatType->InputForm,
  FontFamily->"Times New Roman"]], "Subsubsection",
  FormatType->InputForm],

Cell[TextData[{
  "\t",
  StyleBox[
  "In this section, we generate or recover the monochrome images from the \
monochrome image eigen patterns in Fig.6. Similar to the one-dimensional \
image recovery, the recovered images are depended on the base image data. The \
base image data work as a guideline for which type image will be recovered \
from the same eigen pattern. We select the data representing a sample image \
of Fig. 5(a) as the base image data, after that we recover the monochrome \
images from the eigen patterns in Fig. 6(b)-(d). Figure 7 shows the recovered \
monochrome images formatted by the based image of Fig. 5(a). As you can see, \
we have just recovered the same images to the windowed one in Fig. 5(a). ",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
recover2D=Table[inverseEigenPattern[eigen2D[[i]],
\tFlatten[monoSampleWD[[1]]],resolution],{i,2,4,1}];\
\>", "Input",
  CellLabel->"In[62]:="],

Cell["\<\
recover2DG=Table[ListDensityPlot[
\tconvert2D[recover2D[[i]],dim[[2]],dim[[3]]],
\tPlotRange->All,Mesh->False,Frame->False,
\tPlotLabel->StringForm[\"`1`\",label[[i+1]]],
\tDisplayFunction->Identity],{i,3}];\
\>", "Input",
  CellLabel->"In[63]:=",
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[recover2DG],PlotLabel->\"Fig.7. Recovered images\",
\tImageSize->{450,150}];\
\>", "Input",
  CellLabel->"In[64]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
%%ImageSize: 450 150 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[.5 .325 -71 0 ]
[.5 .325 71 12.5625 ]
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .325 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.7) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Recovered) show
165.000000 12.812500 moveto
(images) show
201.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000C30000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000C8C8C8C8C8C8C8C3C8C3C3C3C8C8C8C8BEBEC3
C3C300000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00C8C8C8C8C3C3C8C8C3C3C3C3BEBFC3C8C8C8C3C3C3BFBE
BDBAC3C3C3BE000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000BDC3
C8C3C3C3C3C8C3C3C8C3C3C8C3C3BEBDC3C3BFC8C3BEBABE
BABABABABDBABAB5B5000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000B6B4BABAC2
BFC3C3C3C3C8C3C8C3C3C3C3BFC3C3BEBEBDBEC3C3BFBDBE
BABEB5AFB5BEB5B5BEB5BDBA000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000003220B4B4BFBDBF
BFC3C3C3C3C3C8C8C3C3C3C3C3C3C3BDBDC3BEBFBEC0BABA
BABAB5B5B5B5AFAAAFB5AFBFAAB100000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000004532273AB4B4BABFBF
C2BFC8C3C8C3C3C3C3C3BEC3C3BDC3BEBFBEBABAB5BABABA
BAB5B5AFADAAAAAAAFBFAFA4A2A4A5A50000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000765B553A3A484CB6BDBFC8
BFBFC8C3C3C3C3C3C3BFC3BFBAC0C3BDBEBEBDB5BDAFBABD
BAB5B5ADAD99A2B1BFB19599A299A2998685000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000007C725555454D5132B4BFC2C8
BFBFC3BEBDC3BEBDC3C3BDBEBDBEBEC3BABABABDAFBEAFB5
B1AFADA799A2A2BDBF9599A2A295827B6785760000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000007C74676751555B5B4520BFBAC2BF
C3BFC3BEBEC3BEBEBEBEBEBEBDBDBEBABDBABAAFAFAFB5AF
B1B1A7A29595AFB4958F8F918F82795E7485767676000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000008D827874554D5B5F553D3AC2BDC8C2
BAC3BFBFC3BEC0BDBEB5BEBEB5B5B5B5BEAFB5B1AFB5AAAD
AAA4A2919598A2998D8F8D8D82676D6D7293868576720000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000998D7C74725F5B725B3A3A32C2BDBFB4
BFC3C3B5B5BEBAB5B5B5AFB5B5AFAFB5ADB5ADADADADAAAA
A2A299938FA491827B867C82657C71727486938D7C868200
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000A2A28D7C747455675B4D323D32BFBFBFBF
BFBAC3BDB5BEB5AFB5AFADAFADAFADADADB1AFAAA7A4AAA4
A4A2998D9995827B7C74745F6D6D5B67789393939986867C
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000EFADA2918D676D5F5E675E483D483AC2B6BFBA
BFBAB5BDB5B5B5AFADADADA5A7AAA7A7ADAAAAA2A5A2A2A2
A295958D998D7C74717165746D5F5F677685938D938D8D7C
7C7800000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000EFD5AEA28D82747C5B67675F32323A3DBFB4BDB4
BABAB5B5B5ADAFAAA7AAA7A7A5999999A2A2A7A2A2999999
95958F8D7C7472677174746767676E76788593A8A2AF9172
727C91000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000EFEFC2AC968D7C676D5F72554D2A2A3A3ABFB4BABD
BAB5B5ADAAAAAAAAA5A4A2A5A2A299999999A2A29999998F
8F8D828D78675F74677474484855728585858D98A299AC8D
7C8D8D990000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000ECF5DDB8AC8D82746D5F5F6755453A3D3D45B4B4B1B1
B5B1ADB1ADADA4A5A5999999919595919999919999998F8D
8F8D7C9374556D6D675F4D48326E857285788698A8A4AF8D
8D988D999600000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00F2F5ECCAAE9F82826D71675F5F3D3D3A3D3D3DB4B1B4C2
B8B8B5B8B5B5B1ADADA4958D958A8D8D8D8D95958D8D8D82
827B7C8D674C67745548454C5B6C85857C857298A2AC9996
8D91918DACAC000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00F2F2E6C6AC96827C74677C5E5F27453D3D3A54B4C7CBCB
CBC8C8C0C0C0BAB8B8B1ADA48A8A868A8A8282828D8A8286
7C7474865556675E4D3A3D6E4D6786857C727C93A4AFB1AC
96968278ACAC000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
F2F5F5CFB8A29182795F675F674D3248453D3A87CBCDD8D1
D1CBCBD1CBCBC0C0BDB8B1ADA799867C8286868A7B828682
7C74657C5F677C4D453A49765167788676727C8D93AFB1AC
A2967C8DA2A2A20000000000000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000000000F2
EFF5F5CFAD968D797474675F67323D4C3D3D8ECDD3D8D3D8
D1D8D1D3D1CBC8CBC0C0B8B5ADAAA2997C7C7C7C867C827C
716D564D7C5F8D453A273272785B7893728D7C8DA2AFBDC2
AE788D8D9991A2AE00000000000000000000000000000000
0000000000000000
00000000000000000000000000000000000000000000F7F7
F2E9D5C79F96826D5F67675F50324C4C3DCAD3CED3D8D8D8
D8D8D1D1D1D3CBC8C8C8BFB4B1B5ADA4997B74747C747B74
71674D488D4D95673D49274D86517886768D8D8D98A2BFC2
AC91828D9696ACAEAC000000000000000000000000000000
0000000000000000
00000000000000000000000000000000000000000000F7F5
ECE9CCBE968D827465675F5F3D3A483D82D0D3CBD3D3D8D8
D8D8D8D8D1D1CBCBCBC2BDBFBAB5B4ADA491997171746D71
655E52458679827C3A274867868D86868D74918D96A2ACBF
BD8D7C8D8696B8BDB5000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000ECF7F2
ECDDCCAD968D7C6D565F555F2A3D455ECBCDD3D3D3D3D8D1
D8D1D1D8D1D1CBC8CBCBC8BDBDBAB4B1ADA4999167717162
67504C326DA4559965743A6E568D6E85868D879682AC98C2
D08D7C8D919FA2ACAEBD0000000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000F7F7F5E9
E9CFCC9F91797C655F5F543D3A505ACDCBCED3D3D3D1CECB
CBCBCBCBC8C0C0C2C8BFC3BDBDB1B5B4B1ADA29995675E67
56553D3D568D826D9F51825F71788672868D678D8DA2A2AD
B1BD8D788D9F96ACBDD8EC00000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000F5F7F7E9
D8CFB5968279655F5F5F323D3A3ACDCDD3CECBCBD1CBC3BD
B8B8B1B1B1ADB1B1B1B1BABABABDBAB1B1ADA7A4A2957B5F
5452453D4965998D7AA286824D728D8586728282A496A2AC
C2CA8D96A49691ADBFEFDD00000000000000000000000000
0000000000000000
00000000000000000000000000000000000000F7F7F5F5E9
D5CCAE967C7C71565F543A3D50CAD0D0D3CECBCBC8C2B8B5
ADA7A7A7A7A7A7ADA7ADB1ADBABABDB4B1ADA9A499998F5E
4E4C3D2A3D6399795FA9869882677493867C8D82A296ACA2
ACC7ACA29F9FA2AEC2E6E6EF000000000000000000000000
0000000000000000
00000000000000000000000000000000000000EFF7F5ECD8
CFCF9F8279677156503D3D454CCDCDCBCBCBCBC8C0958999
999E9E9E9E9E89898989A4B1B1BABABAB4B1ADA4A499918D
4C3D3A273A5679A48791AC98A296867C8D8D727C8DA28DAF
AEBDC29FAC96A2BDCCD8E9EC000000000000000000000000
0000000000000000
000000000000000000000000000000000000F7F7EFF7E9DD
D5AE967A6D675F4C56453D4CD2CDCBCBC8CECBA79E9E9ECD
C0A7A7B5C09E9E99918D89A4B1B4BABDB4B1B1A9A4999E8F
82492A2A27562AA9B167AE82AAAC8D8D986E8D828D9699A4
AEC2CA968796A2ADE6E6ECECE60000000000000000000000
0000000000000000
000000000000000000000000000000000000F7F7F2F7DACC
AD96877A565F565F323D3D82D0D0D0CBC8C8C8999E9E9995
95959E89897D8080A78D8D7DABB8BABABABAB1A9A4A49999
8D793D3D173A5E8796828DAC8DAFCE8D7C8D8D74829896A2
A2C2C29F969F96ADE6E9EFE9E90000000000000000000000
0000000000000000
0000000000000000000000000000000000F5F7F5F5F5D8C3
A2967965565F503A483A5FD2D2D0CBCBC8A79E795E687579
75757D6F5E575B684D665B4E629EBABABAB1B1B1A4A4A2A4
8F825E20173D495A8DA95FA982A4BFCE9999768D828D9182
ACBDC2BEA2AC9FB8DDECE6ECF5EC00000000000000000000
0000000000000000
0000000000000000000000000000000000F5F5EFF5E9D8BE
968265565E554C4C4C4ED2D2CDD0D3CBC8C0C8A78D898089
808999808080808080A2A9ABB1B1BABAB5B5B1B5ADA4A4A2
998F71361717365A71A4966DA282BFBFD0798D8D828D8D82
ACACC2C796ACA2D5E9E9E6E6F5F500000000000000000000
0000000000000000
00000000000000000000000000000000EFF7F5ECEFE6CFAE
876D6D5E5550454C4D54D0CBD0CECBCEC8CED3D3D8D8CDCB
D8CBC8D3D8CDCBC2BDC2BDBABABDBABDBAB8B1B1ADADA4A2
99998254280B5A495A718D678D748DBFBFA2998D7C7C8D99
A299C2C79F9F91DDE6E6E9E6F7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000F5EFF5F5E9C6BF9F
79655454523A4C4C48B8D0D0D0D1D3CBD3CBD3D3D8D3D8D3
D8C8CBCBCBBDBDBDBDBFBDBFC8BDBABFBDB8B8B1ADADA49E
99998262271F495482719F675F918DB4BFC8AC8D8D917C82
8299C2C7A2AE96E6E9DDE6EFF7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000F5F5EFF5F5CF9F82
676D50523D4C4C4C4CD0D0CDD0D3D1D1D3D0D3D3D3D3D3D3
D0CBC8C8C8BDBFC3BDC2BDC8BDC8BDBDB8B8BAB1ADA7ADA2
99998F6D453617505665677967827A99BDBD99A28D8D7C8D
7CA2ACC2AD96A4D8E6E6D5F7F5F7F7000000000000000000
0000000000000000
000000000000000000000000000000F7F7F5F5EFCFC3967C
6D505E3D4C3A4C503DD0CDCDD0D3D3D3D1D3D3D3D3D0D3D3
C8C8BDC8BDB5BABFBDC0C3C8C0C0CBC8BDBDB8B5ADADA4A2
9E918F7C49272A49636B71876D5E659691A8C8AC86916D96
8DA4A2C2AD8DCAD5E9E9E9F5F7F7F7F70000000000000000
0000000000000000
000000000000000000000000000000F5F5F7F7E9C6A7966D
67654E4C4C494C3D87CACDCDD3D3D3D3D8D3D0D3D3D3CBCB
BDB1ADB8B4ADB1B8BABDC3C2C8CBCBC0C0BDB8B1ADADA4A4
A2998A7B5E363D3D5A5671657C546756AEBDA2AA91967A82
8D9FA2BFB896DDC2F5E9F7F7F7F7F7F70000000000000000
0000000000000000
000000000000000000000000000000F7EFF7F5F5BF967965
56564C3D3D4C4C3ACACDCDD1D3D3D3D3D3D3CED3D3D3CBC0
BABAA7ADADA4A9B1B1BABDC3C0C8C8C8C0C8BEB8B1ADA4A4
A2918F8262360B2449546D567C67674CA98DA2CE96919182
8E8D96BFBEBECCD8D8D2F7F7F7F7F7F70000000000000000
0000000000000000
0000000000000000000000000000F7F7F7F7F7E9AE876554
563D4C454C4E3A32CDC7CBCBD3D1D8D8D3D3D3D1D8A799CB
CBC0B5757591A782A2B1BDC8C8CBCBCBC8C0BDB8B5ADADA4
A2998F7B714517243249565A6D6D546D5E8DAFA2AF8D8D67
8282A2BDBEE9ADE9B8F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000F7F7F7F7F5E096796567
4C4C3D484C3D3256CDCBD0D3D8D3D1D8D1D3CED3D8D0CDD1
D1CBBAB1B4B5BAAD95A4BDCBCBCBCBCBC0C8C8BEB5B1ADA4
99998F8A715E0B17243D505E5671545F2AAC9598BF828D6D
798D96ADC6C6ACB8F7F7F5F7F7F7F7F7F500000000000000
0000000000000000
0000000000000000000000000000F7EFF7F7F7D88D65623D
4952454C5232327CC7D1D1D1D8D8D8D8D8D3D3D1D8CDD8D8
D8D1C8BABABAB4B1ADADC0CBCBD1CBCBCBC0C0C0BAB5B1A7
9E9E8F8274650B1F17495665456D545F32968DACBF828D79
828796AEC6C6BECCF7F7F5F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000F7F5F5F7F5D2795E5F54
4C4C5056482A36CACDD3D3D8D8D8D8D8D8D8D1CBD8D8D8E3
D8D1CBC2B8B5B4B1ADB8C0CBCBCECBD1CBC8C8C0C0B8B5AD
A7999182745F2A001F452A67546D48545E7991AAAAA2828D
798282ADC7B8D2F5F7F7F7F7F7F7F7F5F500000000000000
0000000000000000
0000000000000000000000000000F5F7F7F7EF9665653D45
454C524C1F321FCBD1D2D1D8D8D8D8D8D8D8D8D3D3D1D8D8
D8D3CBB8ABADB1ABB4BDCBCDCDD0D3CBCBC8CBC8C0B8B5B1
ADA2918279714907173656565E654C5449718D99B1C27C82
718296BFC79FCCF7F5F7F5F5F5F7F7F7F500000000000000
0000000000000000
00000000000000000000000000F7F5F7F7F7F28965503D56
52524C172A2736CBD3D8D8D8D8D8D8D8D8D8D8D8D1D2D1D8
D1CDC0BDABB1B4B4BDCBCBCBCDD1D3CDD1CBC8CBC0C0B8B5
A9AD998F796D560B282A454954546754547A8D98B1CE827C
6D7A87ADC6CCF5F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F5F7F5F5F5F5895F4C4C56
494C522A1F2AADD0D0D8D8D8D8D8E1E1E1D8D8D8D8D3CDD8
D8CBC0B4B4B1BABDC2CBD0CDD1D1D8D2D1CDCBCBC0BDBDB4
ADA4A28F7B6D651F07322A565E4C5F6754719FA2AFCE7991
5E8779BDCFCCF7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F5F5F7CC715E455454
524C2A1F17C0D2D1D8E1D8D8E1D8D8D8D8D8D8D8D8D8D3D8
D8D1CBBDB4BABABDC2CDCDD8D8D1D8D1D8D2D2CDCBC7C0BA
B1A9A4A2826D6745323D49496554675E5671A9A2ACC28D7C
547A82B1D5ECF7F7F7F7F7F7F7F7F7F5F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7F7F7715F54325649
49522A3D36CBCDD8D8D8D8E1E1D8D8D8E1D8D8D8D8D8D2D8
D8D8D1BDB4BDBFC2C2C7D0D8D2D8D8D8D1D2D2D2CDCBC2BD
B4B1A4A28A7B62493D3D3D565467655E7089A4A2A2AC9172
507A96AEDDF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7F5F77967493D5E56
4C453D2A84D1D2D8D8D8E1E1D8D8D8D8D8D8E1E1D8D8D8D8
D8D1D1BDB4B4BFC2CBCBD2D2D2D8D8D1D1D8D3D0CDCBCBC2
B4B1A9A28F7B625632323D49526567655FA2A2A2A2A9AC74
747987AFECF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7F7F5717156494556
52324556CDD3D2D8D8D8D8D8D8D8D8D8D2D8D8D8D8D8D8CD
D8D8D8C2B8B4BDC2C2C7CDD2D2D2D8D2D8D2CDCDCBCDC7C2
C2B4A9A499826D56453A3D3D565F635650AEA296A49FB15F
797982ACEFF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F5F7AE5F63545E5456
3D3645C7D8CDD8D8D8D8D8E1D8D8D8D2CDCDD2D2D8D8D1D3
D8D8D8CBB8B1B4B6BFB6CACFCDD8D2D2D2CDCACDCBCBCBC2
C2B6B1A99E8F6D5F492A3D3D496D5E5E5E9F96A2A26DBD4D
6D8D96ADF7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F5F77F8E6D496D4956
32494CC7D1C7D8D8E1D8D8D8D8D2D2C0C7CBCBCDD2D8D0D3
D8D8D8CBB5B1ABB4B4C2CACDD2C7C7C2C7C7C7C7CBCDC7C7
B8BFB1A9A28F795F522A273D495E675E5E9F9999A252AF62
5E89A9C7F7F7F7F5F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F5F5F7F755935E6B5A5E49
2A67B5CBB8CDD8D8D8D8D8D2CFCDCDCBB6B4C2C7CDD2C7CD
D8D8D8C0B4A7AEABADB8C7CAC2C2B8BAB1B1ABB6B6C2C2C2
BFBFB4A999917B6D564517323D5E5E6D5696A4828D50BD6D
5696ACD5F7F7F7F7F7F7F7F7F5F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7FF6D7C565E566227
5452D199ADD0D8D8D8D8D2CAB6968EABAA96B6B6D2D2CDCD
D8D8D8CBB4A49FA4BFB6CABAB6A99E898E9F9F9FAABFC2B6
B6B6B1A99F91826256493D32325654635E898D82825FBD5F
569FA2D8FFF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7A07A714956496232
5FBEC0A7ABD0D2D8D8CDBA878DB6AE6268849F9E9ECDCDC7
D8D8D8C8BDA4A996A95E7D91ABCC7A557F7C7A7C89ABB4B4
B6B6ABAB99917B6D5E49562A2A56565E6D87967C825BBF67
71ACACE9F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7899E71633256623A
2AD1B5B5B4D2D8D2C7BA8991C0D86D6250747F9F96BAB4C8
D8D8D0CBBDAD9689919F66CCE96F70628559A0716789A9A9
B4B1ABA4A289796D5449320B1F565E456D89876D7A71B150
96AEAEF7F7F7F7F7F7F7F7F7F7F7F7F7F5F7000000000000
0000000000000000
00000000000000000000000000F7F7FFF582544C32565656
62D1ADA7B4CAD0CBB696703698B777B40D6E42708996BDCE
D8D8D3CBBFBA968E718E966DC350BD0D6850A028507C8E96
A9ABA996968F796256521F171F2A564979717A7A8271AC50
8DA4C6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F793C987705349565662
8DC0A7A4B1CDD0BDAA914961613D24365667617C96B8C3D3
D3D8D3CBC3BDAD969179708C8C362A3636493D55537C8789
99A4A4968982625E5E493D1F363D3D496D796D678279AC65
8DA2E6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F779A09A5E4963564956
8FB5A4A4B1CDCAC7C2B4967B63535353567091A9BDCBCBD3
D8D8D3CBCBC8BAADA496895F7C847B61463D49718D8E9199
A4A496998D7B625E5656452A3632324571827167828DAC6D
8DA9ECF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
0000000000000000000000000000F7E6896B494549493D6D
8F999F96ABCAD0D0D8D2CBCDC2BDBABDC2BDA4ADB8C8D8D3
D8D8D8D3CECBBAA2A796A9ABA996969699A4A9A9B1B5B4AB
A9A499918D826263563D3D2A3649453D6D8D6D678D96B471
96DEFFF7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000FFFF455E323D3D65325E
7B9E998EA9D0C2D3D8D8D8D8D8D8B5917C717BBDC8D8D8D8
E1D8D8D8D3D8C3B89171717B8EC2C7CBC7C2C2BDBDBDB4A9
9687998D82796D5E5456322A2A3627495E796D659196BF7A
9FE9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000E9FF3D4C323D49564967
75828D919FCBC6BFCDD8D8D8D1897C707BA9C8D3D3D8E1D8
E1D8D8D8D8D3D3C8B88D6256627BADBAC7CBCBC0C2B4AD96
7A998E89796D6D5E3D3D2A322A27505A6B7A715F8D8DAE96
9FF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000AEFF5445494932564C5F
62627C899FCAD2969FA9A49E7B79A4D3D8D8E1E1E1E1E1E1
D8D8D8D8D8D8D3D3D3CEBDA98E705E7171898E91877C7A89
96969E8D796D6D566D1F45453D2A245F6D796D658DA28974
CCF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000A77149495F5649494956
5F63717AA9CAD0D0CBA99E9EB6D8E1E1E1E1E1E1E1E1E1E3
D8D8E1E1E1D8D8D8D8D3D1CBCBCBC7C79F7C797C7C969F96
99A2998D797179563D493D3217171F63705E7A71969F6D8D
E9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000006D56497B675656495E
5E637979A4CBCDD0D0D8D8D8D8D8E1E1E1E1E1E1E1E3E1E1
D8E1E1E1D8D8D8D8D8D8D0D0D3CBCBCBC2C7C7BDB4B1ABA4
A9968E82797A796D493D271717171F8E635EA26D82AC6D9F
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000
0000000000000000
00000000000000000000000000000050505A876B565A565A
5A5E7A71A4C7D0D0D2D8D8D8E1E1D8D8E1E1E1D8E1E1E1E1
D8D8E1D8D8E1D8D8D8D8D8D1D3CDCBC7C2CBBDBDB4A9A9A4
A496968D7B79795E6D452A2A1F3227967A5E96796DAE6DBE
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000
0000000000000000
000000000000000000000000000000566763716367635A56
54546D7191BFCDD0D0D2D8D8D8E1E1D8E1E1E1E1E1E1E1E1
E1E1E1E1E1D8D8D8D3D3D3D3D3CBC8C7CBC2BFBAB4B1ABA9
A4A299827982716D49323D3217171F967C6DA27C63966DF5
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000
0000000000000000
000000000000000000000000000000005656565F63565A56
5A567A8296BDC2CED2D3D8D8D8D8E1E1E1E1E1D8D8E1E1E1
E1E1D8D8D8D8D8D1D3D3D3CECBCBCBC0C2BFC2BDB1B4ADA9
9699918D82796D564936451F17173271A287A4827165ADF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000675663676B635A5A
5663718D96B1C2D0D2D8D8D8D8E1E1D8D8E1E1D8E1E1D8E1
E1E1D8D8D8D8D8D8D8D3D3CECBCBCBC0BDBDBDBDB8B1ABA9
A4998E87877C6D5E3D49271F1F1724709671968D8265D2F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000505E6B6B5A635656
6B63718996ABC2CBD3D3D3D8D8D8E1E1D8D8E1E1D8D8E1D8
D8D8D8D8D8D8D8D3D8D3D3CBD3CBC8C8C2BFC2BAB4B1ABA9
96999187876D6D5E493D27170B0B53637A799F96AE96F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000007A5E635F5E5A67
45637C8D8EA9BFCBD0D3D8D8D8E1E1D8E1E1E1D8E1D8D8E1
D8D8D8D8D8D8D8D8D8D8CBD1CECBCBC0C8BDBDB4B4B1ABA9
96A28E89716B5A495632170B240B5F6B6D6596969FDDF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000000000
0000000000000000
000000000000000000000000000000000056565656545A56
63637A8E9FABBFCBD0D8D8D8D8E1E1D8E1D8E1D8D8D8E1D8
D8D8D8D8D8D8D8D8D8D1D3D3CBCBCBC0C8BDBDB4B1B1B1A9
9FA4897C71716D563D32171724176B6B7167969FABF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000000000
0000000000000000
000000000000000000000000000000000000564954504956
636D878EA4AEBFCBD3D1D8D8D8D8D8D8D8E1E1E1E1D8D8E1
D8D8D8D8D8D8D8D8D1D3D3D3CBD3CBC8C8C3BDB4B1ABB1A9
A99689897C635E3D321F1F0B1B17796B67659FB5CFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000000000
0000000000000000
000000000000000000000000000000000000565654565650
566D7C8E9FB6C2CBD3D3D8D8D8E1D8E1E1E1E1E1D8E1D8D8
E1D8D8D8D8D8D8D8D3D8D3D1CECBCBC8C8BDBDB6B1B1A9AB
99998D7C7A715E36321F24141F1F7C895E7996BFF7F7F5F7
F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000000000
0000000000000000
000000000000000000000000000000000000004950505656
506B8796A9B4C8CBCDD0D3D8D8D8D8D8E1D8E1D8D8D8D8D8
D8D8D8D8D8D8D8D8D3D3CED3D1CBCBCBC2C2BFBAB1B1ABA4
A48E8D7C7163563632241F2A2A176D876D8DA9D2F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
0000000000000000
00000000000000000000000000000000000000505A565056
5A6B7196AEC2C2CBD3D3D8D8D8D8D8E1E1D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D3D3D3CECECBC8C8CBC2BFBAB8B1B1ADAD
998E89796D5E4936362A1F2A170B6B716D8DB1ECF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
0000000000000000
00000000000000000000000000000000000000006B6B6B56
566B828EA4BDC8CBCBD3D0D3D8D8D8D8D8D8D8E1D8D8D8D8
D8D8D3D8D3D3D3D3D8D1D3C8C8C8C8C0C2BFBAB4BAA9A9A9
8E8E7C7A6356454932321F17073689717C99ADF7F5F7F7F7
F7F7F7F7F7F7F7F7F7F7F700000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000706B5A63
5F6379969FB4C8CBCBD3D3D8D8D3D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D3D3D3D8D3CBCBCBCBC8CBC3BDBDBDBAB1A4AB96
968D7962565A453636242A0D077A7C658291CFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F700000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000565F50
63637A8DA4B6C2C0CBCBD3CECED3D3D8D8D8D3D8D8D8D3D8
D0D3D2D3D3D3CECBCBCBCBC8CBC8C8C0BDBDBDB4B4ABA4A9
8E7C6D655E5A5A32322A170B89796D658DB8E9F7F5F5F7F7
F7F7F7F7F7F7F7F7F7F70000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000005A7A
567A7A8D9FB4BFC7CBC8CBD3D3D8D3D2D8D3D8D8D8D8D8D3
D3D8D3CBD3CBD3CBCBC8CBCBC8C8BFC3BABAB6B1AD96A499
897C716D5A49506B1F171B56567A6D7996C2F5F7F5FFF7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000005656
5F7C7A8DA4B4B6C2CBC8CBD1CBD8CED3D3D3D3D3D3D3D8D1
D1CBCBCBC0CBC8C8C8C8C8CBC8C8BABABDB4B4B1A9969689
7971655A5A565636493649457C71878DAEBEF7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000054
565E7187969FB8BDC2C8C0D1D1D0D0CDCBD1D3D3D8CDD0CB
CBC8C0BDBDBEC8C8C3C0C3BEBDBDB1B8B4ABABA496968E89
797A6D505049493D4532826B716DA496BFF7F7F7F5F7F7FF
F7F7F7F7F7F7F7F700000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
6D5671828EABB4B6BDC0C0C8CBC7CBD0CBCBCBCDCBC8CBCB
C3BDB5B8B8BABEB5B5B5B5ADB1B8A9B1A9A99FA296898787
7A715E5A56506756496789707C8DA9BFBEF5F7F7F7FFF7F7
F7F7F7F7F7F7F70000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
006B63717C96ABBFB6B8BDBDCBCBCBCBC7C2C2C2C2BDB6B1
B4B4A9A9A4A4A4A2A7A4A2A29699999999918E968E89826D
63706B556B6B49636D6D716D8D87B4BFEFF7F7F7F7F7F7F7
F7F7F7F7F7F7000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00636B7A897F8E96B4B8C2C8C7C2C2C2BFB4B4A9B4BFABAD
A9AB969F91998DA48D99828E82828D878789897C8E968287
7A7C6363707C5A3D568287828DADB8BEF7F7F7F7F7F7F7F5
F7F7F7F7F7F7000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000056717A638E9FBECACACAC2C2B8B6A9ADABABA9ABA9A9
96968E8E898E89798987716D89718771797C7A7C636B7079
70717071565A676D717A7A96B8B89FF7F7F7F7F5F7F7F7F7
F7F7F7F7F700000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000007687A7AA9EB6AAB6BEBEB6B4ABA9AB969FA99F969F
9691878971967C96877C8D7A6D967A897C7A82875F6B7A79
67707C656D656D657187ACB5ADAED2F7F7F7F7FFF7F7F7F7
F7F7F7F70000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000006B828E8E9EB6B8B4ADABAE9F9F9F8E968E968E96
89967A717F65827A8E717C7A7C96637171897A6B6B5A5649
506356565656657C96ACC79EAE87F7F7F7F7F7F7F7F7F7F7
F7F7F7000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000A09FA7B8B8B8B89F9F9F9F969F969689899687
7A7C65828263497C5A877A7C7C5E6D7A4549675E5A5E6765
6D656556676DAD96AEBE639E82D2FFF7F7F7F7F7F7F7F5F7
F7F700000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000082A9B5B6B8A796968E96968E82878E7C87
8763967A6396635A7C63636B5A5E54455656675656655E56
525E7187879F96BFB8827A9E82F7F7F7F7F7F5F7F7F5F7F7
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000093ACB5ABA77C89829696897689877C8E
7C875A7170637A5A63655A5F5A5056565649455656565454
637A7A7A7A9FB5797982A796E9F5F5F7F7F5F7F7F5F7F700
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000093B8B8AC7A8E7C7C877A708282707C
707C5A7A6D6B50497A50565A565449493D36454545546D5A
63829F96C2B59E876B9F6BE9FFFFF5F7F7F7F7F7F7F70000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000B5BEAC7A6B937C8E93876B827A63
7C7C63717A70673249567A56563D56453D32363232495E82
968996B5935F7787826DA9F7F7F7F7F7F7F5F7FFF7000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000B8826B7A8E70707C67637670
676B7C70637A71676349495F56565E546D54545F6D797C8D
9FC6939E7B4970829393F7F7F7F7F7F7FFF7F50000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000B863677987706B5A565663
636B7063637A827170567A5654706B63656D7A879F8E96B8
9E9A8787567687827FFFF7FFFFF7F5FFF5FF000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000676782826B82565A5A
6D6B71567F718E7C89936B5E5E717187878D8DA9A9A77C7B
7B5E45567C827996FFF7F7F7FFFFF7F70000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000826384707C6B56
534963567671968EC6CAB89FB6ABABABC7C7B4B58767796B
5A566387937C7FFFF7F7FFF7F7F700000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000084897F96A7
7B5367537093A79E89BEC0BEC6D5D2BE9F93938472706B50
567079967C93F7F7F7F5F7F7000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000C0A9
D2D8EFE6D8D2CFBECCC6C6C6CFB587A787797B7B6367557C
8782827CFFF7F7FFF5000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00C6CACFCAD8DED8CCD2B5A0BE9E9AA06C7A63677B849E9F
8E82A9F7F7F5000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000D8DED2CCC0C39A8CA0797B708761899E9F9A89
9FE000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000009A0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000C30000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000C8C8C8C8C8C8C8C3C8C3C3C3C8C8C8C8BEBEC3
C3C300000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00C8C8C8C8C3C3C8C8C3C3C3C3BEBFC3C8C8C8C3C3C3BFBE
BDBAC3C3C3BE000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000BDC3
C8C3C3C3C3C8C3C3C8C3C3C8C3C3BEBDC3C3BFC8C3BEBABE
BABABABABDBABAB5B5000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000B6B4BABAC2
BFC3C3C3C3C8C3C8C3C3C3C3BFC3C3BEBEBDBEC3C3BFBDBE
BABEB5AFB5BEB5B5BEB5BDBA000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000003220B4B4BFBDBF
BFC3C3C3C3C3C8C8C3C3C3C3C3C3C3BDBDC3BEBFBEC0BABA
BABAB5B5B5B5AFAAAFB5AFBFAAB100000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000004532273AB4B4BABFBF
C2BFC8C3C8C3C3C3C3C3BEC3C3BDC3BEBFBEBABAB5BABABA
BAB5B5AFADAAAAAAAFBFAFA4A2A4A5A50000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000765B553A3A484CB6BDBFC8
BFBFC8C3C3C3C3C3C3BFC3BFBAC0C3BDBEBEBDB5BDAFBABD
BAB5B5ADAD99A2B1BFB19599A299A2998685000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000007C725555454D5132B4BFC2C8
BFBFC3BEBDC3BEBDC3C3BDBEBDBEBEC3BABABABDAFBEAFB5
B1AFADA799A2A2BDBF9599A2A295827B6785760000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000007C74676751555B5B4520BFBAC2BF
C3BFC3BEBEC3BEBEBEBEBEBEBDBDBEBABDBABAAFAFAFB5AF
B1B1A7A29595AFB4958F8F918F82795E7485767676000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000008D827874554D5B5F553D3AC2BDC8C2
BAC3BFBFC3BEC0BDBEB5BEBEB5B5B5B5BEAFB5B1AFB5AAAD
AAA4A2919598A2998D8F8D8D82676D6D7293868576720000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000998D7C74725F5B725B3A3A32C2BDBFB4
BFC3C3B5B5BEBAB5B5B5AFB5B5AFAFB5ADB5ADADADADAAAA
A2A299938FA491827B867C82657C71727486938D7C868200
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000A2A28D7C747455675B4D323D32BFBFBFBF
BFBAC3BDB5BEB5AFB5AFADAFADAFADADADB1AFAAA7A4AAA4
A4A2998D9995827B7C74745F6D6D5B67789393939986867C
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000EFADA2918D676D5F5E675E483D483AC2B6BFBA
BFBAB5BDB5B5B5AFADADADA5A7AAA7A7ADAAAAA2A5A2A2A2
A295958D998D7C74717165746D5F5F677685938D938D8D7C
7C7800000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000EFD5AEA28D82747C5B67675F32323A3DBFB4BDB4
BABAB5B5B5ADAFAAA7AAA7A7A5999999A2A2A7A2A2999999
95958F8D7C7472677174746767676E76788593A8A2AF9172
727C91000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000EFEFC2AC968D7C676D5F72554D2A2A3A3ABFB4BABD
BAB5B5ADAAAAAAAAA5A4A2A5A2A299999999A2A29999998F
8F8D828D78675F74677474484855728585858D98A299AC8D
7C8D8D990000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000ECF5DDB8AC8D82746D5F5F6755453A3D3D45B4B4B1B1
B5B1ADB1ADADA4A5A5999999919595919999919999998F8D
8F8D7C9374556D6D675F4D48326E857285788698A8A4AF8D
8D988D999600000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00F2F5ECCAAE9F82826D71675F5F3D3D3A3D3D3DB4B1B4C2
B8B8B5B8B5B5B1ADADA4958D958A8D8D8D8D95958D8D8D82
827B7C8D674C67745548454C5B6C85857C857298A2AC9996
8D91918DACAC000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00F2F2E6C6AC96827C74677C5E5F27453D3D3A54B4C7CBCB
CBC8C8C0C0C0BAB8B8B1ADA48A8A868A8A8282828D8A8286
7C7474865556675E4D3A3D6E4D6786857C727C93A4AFB1AC
96968278ACAC000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
F2F5F5CFB8A29182795F675F674D3248453D3A87CBCDD8D1
D1CBCBD1CBCBC0C0BDB8B1ADA799867C8286868A7B828682
7C74657C5F677C4D453A49765167788676727C8D93AFB1AC
A2967C8DA2A2A20000000000000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000000000F2
EFF5F5CFAD968D797474675F67323D4C3D3D8ECDD3D8D3D8
D1D8D1D3D1CBC8CBC0C0B8B5ADAAA2997C7C7C7C867C827C
716D564D7C5F8D453A273272785B7893728D7C8DA2AFBDC2
AE788D8D9991A2AE00000000000000000000000000000000
0000000000000000
00000000000000000000000000000000000000000000F7F7
F2E9D5C79F96826D5F67675F50324C4C3DCAD3CED3D8D8D8
D8D8D1D1D1D3CBC8C8C8BFB4B1B5ADA4997B74747C747B74
71674D488D4D95673D49274D86517886768D8D8D98A2BFC2
AC91828D9696ACAEAC000000000000000000000000000000
0000000000000000
00000000000000000000000000000000000000000000F7F5
ECE9CCBE968D827465675F5F3D3A483D82D0D3CBD3D3D8D8
D8D8D8D8D1D1CBCBCBC2BDBFBAB5B4ADA491997171746D71
655E52458679827C3A274867868D86868D74918D96A2ACBF
BD8D7C8D8696B8BDB5000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000ECF7F2
ECDDCCAD968D7C6D565F555F2A3D455ECBCDD3D3D3D3D8D1
D8D1D1D8D1D1CBC8CBCBC8BDBDBAB4B1ADA4999167717162
67504C326DA4559965743A6E568D6E85868D879682AC98C2
D08D7C8D919FA2ACAEBD0000000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000F7F7F5E9
E9CFCC9F91797C655F5F543D3A505ACDCBCED3D3D3D1CECB
CBCBCBCBC8C0C0C2C8BFC3BDBDB1B5B4B1ADA29995675E67
56553D3D568D826D9F51825F71788672868D678D8DA2A2AD
B1BD8D788D9F96ACBDD8EC00000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000F5F7F7E9
D8CFB5968279655F5F5F323D3A3ACDCDD3CECBCBD1CBC3BD
B8B8B1B1B1ADB1B1B1B1BABABABDBAB1B1ADA7A4A2957B5F
5452453D4965998D7AA286824D728D8586728282A496A2AC
C2CA8D96A49691ADBFEFDD00000000000000000000000000
0000000000000000
00000000000000000000000000000000000000F7F7F5F5E9
D5CCAE967C7C71565F543A3D50CAD0D0D3CECBCBC8C2B8B5
ADA7A7A7A7A7A7ADA7ADB1ADBABABDB4B1ADA9A499998F5E
4E4C3D2A3D6399795FA9869882677493867C8D82A296ACA2
ACC7ACA29F9FA2AEC2E6E6EF000000000000000000000000
0000000000000000
00000000000000000000000000000000000000EFF7F5ECD8
CFCF9F8279677156503D3D454CCDCDCBCBCBCBC8C0958999
999E9E9E9E9E89898989A4B1B1BABABAB4B1ADA4A499918D
4C3D3A273A5679A48791AC98A296867C8D8D727C8DA28DAF
AEBDC29FAC96A2BDCCD8E9EC000000000000000000000000
0000000000000000
000000000000000000000000000000000000F7F7EFF7E9DD
D5AE967A6D675F4C56453D4CD2CDCBCBC8CECBA79E9E9ECD
C0A7A7B5C09E9E99918D89A4B1B4BABDB4B1B1A9A4999E8F
82492A2A27562AA9B167AE82AAAC8D8D986E8D828D9699A4
AEC2CA968796A2ADE6E6ECECE60000000000000000000000
0000000000000000
000000000000000000000000000000000000F7F7F2F7DACC
AD96877A565F565F323D3D82D0D0D0CBC8C8C8999E9E9995
95959E89897D8080A78D8D7DABB8BABABABAB1A9A4A49999
8D793D3D173A5E8796828DAC8DAFCE8D7C8D8D74829896A2
A2C2C29F969F96ADE6E9EFE9E90000000000000000000000
0000000000000000
0000000000000000000000000000000000F5F7F5F5F5D8C3
A2967965565F503A483A5FD2D2D0CBCBC8A79E795E687579
75757D6F5E575B684D665B4E629EBABABAB1B1B1A4A4A2A4
8F825E20173D495A8DA95FA982A4BFCE9999768D828D9182
ACBDC2BEA2AC9FB8DDECE6ECF5EC00000000000000000000
0000000000000000
0000000000000000000000000000000000F5F5EFF5E9D8BE
968265565E554C4C4C4ED2D2CDD0D3CBC8C0C8A78D898089
808999808080808080A2A9ABB1B1BABAB5B5B1B5ADA4A4A2
998F71361717365A71A4966DA282BFBFD0798D8D828D8D82
ACACC2C796ACA2D5E9E9E6E6F5F500000000000000000000
0000000000000000
00000000000000000000000000000000EFF7F5ECEFE6CFAE
876D6D5E5550454C4D54D0CBD0CECBCEC8CED3D3D8D8CDCB
D8CBC8D3D8CDCBC2BDC2BDBABABDBABDBAB8B1B1ADADA4A2
99998254280B5A495A718D678D748DBFBFA2998D7C7C8D99
A299C2C79F9F91DDE6E6E9E6F7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000F5EFF5F5E9C6BF9F
79655454523A4C4C48B8D0D0D0D1D3CBD3CBD3D3D8D3D8D3
D8C8CBCBCBBDBDBDBDBFBDBFC8BDBABFBDB8B8B1ADADA49E
99998262271F495482719F675F918DB4BFC8AC8D8D917C82
8299C2C7A2AE96E6E9DDE6EFF7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000F5F5EFF5F5CF9F82
676D50523D4C4C4C4CD0D0CDD0D3D1D1D3D0D3D3D3D3D3D3
D0CBC8C8C8BDBFC3BDC2BDC8BDC8BDBDB8B8BAB1ADA7ADA2
99998F6D453617505665677967827A99BDBD99A28D8D7C8D
7CA2ACC2AD96A4D8E6E6D5F7F5F7F7000000000000000000
0000000000000000
000000000000000000000000000000F7F7F5F5EFCFC3967C
6D505E3D4C3A4C503DD0CDCDD0D3D3D3D1D3D3D3D3D0D3D3
C8C8BDC8BDB5BABFBDC0C3C8C0C0CBC8BDBDB8B5ADADA4A2
9E918F7C49272A49636B71876D5E659691A8C8AC86916D96
8DA4A2C2AD8DCAD5E9E9E9F5F7F7F7F70000000000000000
0000000000000000
000000000000000000000000000000F5F5F7F7E9C6A7966D
67654E4C4C494C3D87CACDCDD3D3D3D3D8D3D0D3D3D3CBCB
BDB1ADB8B4ADB1B8BABDC3C2C8CBCBC0C0BDB8B1ADADA4A4
A2998A7B5E363D3D5A5671657C546756AEBDA2AA91967A82
8D9FA2BFB896DDC2F5E9F7F7F7F7F7F70000000000000000
0000000000000000
000000000000000000000000000000F7EFF7F5F5BF967965
56564C3D3D4C4C3ACACDCDD1D3D3D3D3D3D3CED3D3D3CBC0
BABAA7ADADA4A9B1B1BABDC3C0C8C8C8C0C8BEB8B1ADA4A4
A2918F8262360B2449546D567C67674CA98DA2CE96919182
8E8D96BFBEBECCD8D8D2F7F7F7F7F7F70000000000000000
0000000000000000
0000000000000000000000000000F7F7F7F7F7E9AE876554
563D4C454C4E3A32CDC7CBCBD3D1D8D8D3D3D3D1D8A799CB
CBC0B5757591A782A2B1BDC8C8CBCBCBC8C0BDB8B5ADADA4
A2998F7B714517243249565A6D6D546D5E8DAFA2AF8D8D67
8282A2BDBEE9ADE9B8F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000F7F7F7F7F5E096796567
4C4C3D484C3D3256CDCBD0D3D8D3D1D8D1D3CED3D8D0CDD1
D1CBBAB1B4B5BAAD95A4BDCBCBCBCBCBC0C8C8BEB5B1ADA4
99998F8A715E0B17243D505E5671545F2AAC9598BF828D6D
798D96ADC6C6ACB8F7F7F5F7F7F7F7F7F500000000000000
0000000000000000
0000000000000000000000000000F7EFF7F7F7D88D65623D
4952454C5232327CC7D1D1D1D8D8D8D8D8D3D3D1D8CDD8D8
D8D1C8BABABAB4B1ADADC0CBCBD1CBCBCBC0C0C0BAB5B1A7
9E9E8F8274650B1F17495665456D545F32968DACBF828D79
828796AEC6C6BECCF7F7F5F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000F7F5F5F7F5D2795E5F54
4C4C5056482A36CACDD3D3D8D8D8D8D8D8D8D1CBD8D8D8E3
D8D1CBC2B8B5B4B1ADB8C0CBCBCECBD1CBC8C8C0C0B8B5AD
A7999182745F2A001F452A67546D48545E7991AAAAA2828D
798282ADC7B8D2F5F7F7F7F7F7F7F7F5F500000000000000
0000000000000000
0000000000000000000000000000F5F7F7F7EF9665653D45
454C524C1F321FCBD1D2D1D8D8D8D8D8D8D8D8D3D3D1D8D8
D8D3CBB8ABADB1ABB4BDCBCDCDD0D3CBCBC8CBC8C0B8B5B1
ADA2918279714907173656565E654C5449718D99B1C27C82
718296BFC79FCCF7F5F7F5F5F5F7F7F7F500000000000000
0000000000000000
00000000000000000000000000F7F5F7F7F7F28965503D56
52524C172A2736CBD3D8D8D8D8D8D8D8D8D8D8D8D1D2D1D8
D1CDC0BDABB1B4B4BDCBCBCBCDD1D3CDD1CBC8CBC0C0B8B5
A9AD998F796D560B282A454954546754547A8D98B1CE827C
6D7A87ADC6CCF5F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F5F7F5F5F5F5895F4C4C56
494C522A1F2AADD0D0D8D8D8D8D8E1E1E1D8D8D8D8D3CDD8
D8CBC0B4B4B1BABDC2CBD0CDD1D1D8D2D1CDCBCBC0BDBDB4
ADA4A28F7B6D651F07322A565E4C5F6754719FA2AFCE7991
5E8779BDCFCCF7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F5F5F7CC715E455454
524C2A1F17C0D2D1D8E1D8D8E1D8D8D8D8D8D8D8D8D8D3D8
D8D1CBBDB4BABABDC2CDCDD8D8D1D8D1D8D2D2CDCBC7C0BA
B1A9A4A2826D6745323D49496554675E5671A9A2ACC28D7C
547A82B1D5ECF7F7F7F7F7F7F7F7F7F5F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7F7F7715F54325649
49522A3D36CBCDD8D8D8D8E1E1D8D8D8E1D8D8D8D8D8D2D8
D8D8D1BDB4BDBFC2C2C7D0D8D2D8D8D8D1D2D2D2CDCBC2BD
B4B1A4A28A7B62493D3D3D565467655E7089A4A2A2AC9172
507A96AEDDF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7F5F77967493D5E56
4C453D2A84D1D2D8D8D8E1E1D8D8D8D8D8D8E1E1D8D8D8D8
D8D1D1BDB4B4BFC2CBCBD2D2D2D8D8D1D1D8D3D0CDCBCBC2
B4B1A9A28F7B625632323D49526567655FA2A2A2A2A9AC74
747987AFECF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7F7F5717156494556
52324556CDD3D2D8D8D8D8D8D8D8D8D8D2D8D8D8D8D8D8CD
D8D8D8C2B8B4BDC2C2C7CDD2D2D2D8D2D8D2CDCDCBCDC7C2
C2B4A9A499826D56453A3D3D565F635650AEA296A49FB15F
797982ACEFF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F5F7AE5F63545E5456
3D3645C7D8CDD8D8D8D8D8E1D8D8D8D2CDCDD2D2D8D8D1D3
D8D8D8CBB8B1B4B6BFB6CACFCDD8D2D2D2CDCACDCBCBCBC2
C2B6B1A99E8F6D5F492A3D3D496D5E5E5E9F96A2A26DBD4D
6D8D96ADF7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F5F77F8E6D496D4956
32494CC7D1C7D8D8E1D8D8D8D8D2D2C0C7CBCBCDD2D8D0D3
D8D8D8CBB5B1ABB4B4C2CACDD2C7C7C2C7C7C7C7CBCDC7C7
B8BFB1A9A28F795F522A273D495E675E5E9F9999A252AF62
5E89A9C7F7F7F7F5F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F5F5F7F755935E6B5A5E49
2A67B5CBB8CDD8D8D8D8D8D2CFCDCDCBB6B4C2C7CDD2C7CD
D8D8D8C0B4A7AEABADB8C7CAC2C2B8BAB1B1ABB6B6C2C2C2
BFBFB4A999917B6D564517323D5E5E6D5696A4828D50BD6D
5696ACD5F7F7F7F7F7F7F7F7F5F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7FF6D7C565E566227
5452D199ADD0D8D8D8D8D2CAB6968EABAA96B6B6D2D2CDCD
D8D8D8CBB4A49FA4BFB6CABAB6A99E898E9F9F9FAABFC2B6
B6B6B1A99F91826256493D32325654635E898D82825FBD5F
569FA2D8FFF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7A07A714956496232
5FBEC0A7ABD0D2D8D8CDBA878DB6AE6268849F9E9ECDCDC7
D8D8D8C8BDA4A996A95E7D91ABCC7A557F7C7A7C89ABB4B4
B6B6ABAB99917B6D5E49562A2A56565E6D87967C825BBF67
71ACACE9F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7899E71633256623A
2AD1B5B5B4D2D8D2C7BA8991C0D86D6250747F9F96BAB4C8
D8D8D0CBBDAD9689919F66CCE96F70628559A0716789A9A9
B4B1ABA4A289796D5449320B1F565E456D89876D7A71B150
96AEAEF7F7F7F7F7F7F7F7F7F7F7F7F7F5F7000000000000
0000000000000000
00000000000000000000000000F7F7FFF582544C32565656
62D1ADA7B4CAD0CBB696703698B777B40D6E42708996BDCE
D8D8D3CBBFBA968E718E966DC350BD0D6850A028507C8E96
A9ABA996968F796256521F171F2A564979717A7A8271AC50
8DA4C6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F793C987705349565662
8DC0A7A4B1CDD0BDAA914961613D24365667617C96B8C3D3
D3D8D3CBC3BDAD969179708C8C362A3636493D55537C8789
99A4A4968982625E5E493D1F363D3D496D796D678279AC65
8DA2E6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F779A09A5E4963564956
8FB5A4A4B1CDCAC7C2B4967B63535353567091A9BDCBCBD3
D8D8D3CBCBC8BAADA496895F7C847B61463D49718D8E9199
A4A496998D7B625E5656452A3632324571827167828DAC6D
8DA9ECF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
0000000000000000000000000000F7E6896B494549493D6D
8F999F96ABCAD0D0D8D2CBCDC2BDBABDC2BDA4ADB8C8D8D3
D8D8D8D3CECBBAA2A796A9ABA996969699A4A9A9B1B5B4AB
A9A499918D826263563D3D2A3649453D6D8D6D678D96B471
96DEFFF7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000FFFF455E323D3D65325E
7B9E998EA9D0C2D3D8D8D8D8D8D8B5917C717BBDC8D8D8D8
E1D8D8D8D3D8C3B89171717B8EC2C7CBC7C2C2BDBDBDB4A9
9687998D82796D5E5456322A2A3627495E796D659196BF7A
9FE9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000E9FF3D4C323D49564967
75828D919FCBC6BFCDD8D8D8D1897C707BA9C8D3D3D8E1D8
E1D8D8D8D8D3D3C8B88D6256627BADBAC7CBCBC0C2B4AD96
7A998E89796D6D5E3D3D2A322A27505A6B7A715F8D8DAE96
9FF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000AEFF5445494932564C5F
62627C899FCAD2969FA9A49E7B79A4D3D8D8E1E1E1E1E1E1
D8D8D8D8D8D8D3D3D3CEBDA98E705E7171898E91877C7A89
96969E8D796D6D566D1F45453D2A245F6D796D658DA28974
CCF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000A77149495F5649494956
5F63717AA9CAD0D0CBA99E9EB6D8E1E1E1E1E1E1E1E1E1E3
D8D8E1E1E1D8D8D8D8D3D1CBCBCBC7C79F7C797C7C969F96
99A2998D797179563D493D3217171F63705E7A71969F6D8D
E9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000006D56497B675656495E
5E637979A4CBCDD0D0D8D8D8D8D8E1E1E1E1E1E1E1E3E1E1
D8E1E1E1D8D8D8D8D8D8D0D0D3CBCBCBC2C7C7BDB4B1ABA4
A9968E82797A796D493D271717171F8E635EA26D82AC6D9F
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000
0000000000000000
00000000000000000000000000000050505A876B565A565A
5A5E7A71A4C7D0D0D2D8D8D8E1E1D8D8E1E1E1D8E1E1E1E1
D8D8E1D8D8E1D8D8D8D8D8D1D3CDCBC7C2CBBDBDB4A9A9A4
A496968D7B79795E6D452A2A1F3227967A5E96796DAE6DBE
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000
0000000000000000
000000000000000000000000000000566763716367635A56
54546D7191BFCDD0D0D2D8D8D8E1E1D8E1E1E1E1E1E1E1E1
E1E1E1E1E1D8D8D8D3D3D3D3D3CBC8C7CBC2BFBAB4B1ABA9
A4A299827982716D49323D3217171F967C6DA27C63966DF5
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000
0000000000000000
000000000000000000000000000000005656565F63565A56
5A567A8296BDC2CED2D3D8D8D8D8E1E1E1E1E1D8D8E1E1E1
E1E1D8D8D8D8D8D1D3D3D3CECBCBCBC0C2BFC2BDB1B4ADA9
9699918D82796D564936451F17173271A287A4827165ADF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000675663676B635A5A
5663718D96B1C2D0D2D8D8D8D8E1E1D8D8E1E1D8E1E1D8E1
E1E1D8D8D8D8D8D8D8D3D3CECBCBCBC0BDBDBDBDB8B1ABA9
A4998E87877C6D5E3D49271F1F1724709671968D8265D2F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000505E6B6B5A635656
6B63718996ABC2CBD3D3D3D8D8D8E1E1D8D8E1E1D8D8E1D8
D8D8D8D8D8D8D8D3D8D3D3CBD3CBC8C8C2BFC2BAB4B1ABA9
96999187876D6D5E493D27170B0B53637A799F96AE96F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000007A5E635F5E5A67
45637C8D8EA9BFCBD0D3D8D8D8E1E1D8E1E1E1D8E1D8D8E1
D8D8D8D8D8D8D8D8D8D8CBD1CECBCBC0C8BDBDB4B4B1ABA9
96A28E89716B5A495632170B240B5F6B6D6596969FDDF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000000000
0000000000000000
000000000000000000000000000000000056565656545A56
63637A8E9FABBFCBD0D8D8D8D8E1E1D8E1D8E1D8D8D8E1D8
D8D8D8D8D8D8D8D8D8D1D3D3CBCBCBC0C8BDBDB4B1B1B1A9
9FA4897C71716D563D32171724176B6B7167969FABF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000000000
0000000000000000
000000000000000000000000000000000000564954504956
636D878EA4AEBFCBD3D1D8D8D8D8D8D8D8E1E1E1E1D8D8E1
D8D8D8D8D8D8D8D8D1D3D3D3CBD3CBC8C8C3BDB4B1ABB1A9
A99689897C635E3D321F1F0B1B17796B67659FB5CFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000000000
0000000000000000
000000000000000000000000000000000000565654565650
566D7C8E9FB6C2CBD3D3D8D8D8E1D8E1E1E1E1E1D8E1D8D8
E1D8D8D8D8D8D8D8D3D8D3D1CECBCBC8C8BDBDB6B1B1A9AB
99998D7C7A715E36321F24141F1F7C895E7996BFF7F7F5F7
F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000000000
0000000000000000
000000000000000000000000000000000000004950505656
506B8796A9B4C8CBCDD0D3D8D8D8D8D8E1D8E1D8D8D8D8D8
D8D8D8D8D8D8D8D8D3D3CED3D1CBCBCBC2C2BFBAB1B1ABA4
A48E8D7C7163563632241F2A2A176D876D8DA9D2F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
0000000000000000
00000000000000000000000000000000000000505A565056
5A6B7196AEC2C2CBD3D3D8D8D8D8D8E1E1D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D3D3D3CECECBC8C8CBC2BFBAB8B1B1ADAD
998E89796D5E4936362A1F2A170B6B716D8DB1ECF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
0000000000000000
00000000000000000000000000000000000000006B6B6B56
566B828EA4BDC8CBCBD3D0D3D8D8D8D8D8D8D8E1D8D8D8D8
D8D8D3D8D3D3D3D3D8D1D3C8C8C8C8C0C2BFBAB4BAA9A9A9
8E8E7C7A6356454932321F17073689717C99ADF7F5F7F7F7
F7F7F7F7F7F7F7F7F7F7F700000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000706B5A63
5F6379969FB4C8CBCBD3D3D8D8D3D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D3D3D3D8D3CBCBCBCBC8CBC3BDBDBDBAB1A4AB96
968D7962565A453636242A0D077A7C658291CFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F700000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000565F50
63637A8DA4B6C2C0CBCBD3CECED3D3D8D8D8D3D8D8D8D3D8
D0D3D2D3D3D3CECBCBCBCBC8CBC8C8C0BDBDBDB4B4ABA4A9
8E7C6D655E5A5A32322A170B89796D658DB8E9F7F5F5F7F7
F7F7F7F7F7F7F7F7F7F70000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000005A7A
567A7A8D9FB4BFC7CBC8CBD3D3D8D3D2D8D3D8D8D8D8D8D3
D3D8D3CBD3CBD3CBCBC8CBCBC8C8BFC3BABAB6B1AD96A499
897C716D5A49506B1F171B56567A6D7996C2F5F7F5FFF7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000005656
5F7C7A8DA4B4B6C2CBC8CBD1CBD8CED3D3D3D3D3D3D3D8D1
D1CBCBCBC0CBC8C8C8C8C8CBC8C8BABABDB4B4B1A9969689
7971655A5A565636493649457C71878DAEBEF7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000054
565E7187969FB8BDC2C8C0D1D1D0D0CDCBD1D3D3D8CDD0CB
CBC8C0BDBDBEC8C8C3C0C3BEBDBDB1B8B4ABABA496968E89
797A6D505049493D4532826B716DA496BFF7F7F7F5F7F7FF
F7F7F7F7F7F7F7F700000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
6D5671828EABB4B6BDC0C0C8CBC7CBD0CBCBCBCDCBC8CBCB
C3BDB5B8B8BABEB5B5B5B5ADB1B8A9B1A9A99FA296898787
7A715E5A56506756496789707C8DA9BFBEF5F7F7F7FFF7F7
F7F7F7F7F7F7F70000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
006B63717C96ABBFB6B8BDBDCBCBCBCBC7C2C2C2C2BDB6B1
B4B4A9A9A4A4A4A2A7A4A2A29699999999918E968E89826D
63706B556B6B49636D6D716D8D87B4BFEFF7F7F7F7F7F7F7
F7F7F7F7F7F7000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00636B7A897F8E96B4B8C2C8C7C2C2C2BFB4B4A9B4BFABAD
A9AB969F91998DA48D99828E82828D878789897C8E968287
7A7C6363707C5A3D568287828DADB8BEF7F7F7F7F7F7F7F5
F7F7F7F7F7F7000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000056717A638E9FBECACACAC2C2B8B6A9ADABABA9ABA9A9
96968E8E898E89798987716D89718771797C7A7C636B7079
70717071565A676D717A7A96B8B89FF7F7F7F7F5F7F7F7F7
F7F7F7F7F700000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000007687A7AA9EB6AAB6BEBEB6B4ABA9AB969FA99F969F
9691878971967C96877C8D7A6D967A897C7A82875F6B7A79
67707C656D656D657187ACB5ADAED2F7F7F7F7FFF7F7F7F7
F7F7F7F70000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000006B828E8E9EB6B8B4ADABAE9F9F9F8E968E968E96
89967A717F65827A8E717C7A7C96637171897A6B6B5A5649
506356565656657C96ACC79EAE87F7F7F7F7F7F7F7F7F7F7
F7F7F7000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000A09FA7B8B8B8B89F9F9F9F969F969689899687
7A7C65828263497C5A877A7C7C5E6D7A4549675E5A5E6765
6D656556676DAD96AEBE639E82D2FFF7F7F7F7F7F7F7F5F7
F7F700000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000082A9B5B6B8A796968E96968E82878E7C87
8763967A6396635A7C63636B5A5E54455656675656655E56
525E7187879F96BFB8827A9E82F7F7F7F7F7F5F7F7F5F7F7
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000093ACB5ABA77C89829696897689877C8E
7C875A7170637A5A63655A5F5A5056565649455656565454
637A7A7A7A9FB5797982A796E9F5F5F7F7F5F7F7F5F7F700
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000093B8B8AC7A8E7C7C877A708282707C
707C5A7A6D6B50497A50565A565449493D36454545546D5A
63829F96C2B59E876B9F6BE9FFFFF5F7F7F7F7F7F7F70000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000B5BEAC7A6B937C8E93876B827A63
7C7C63717A70673249567A56563D56453D32363232495E82
968996B5935F7787826DA9F7F7F7F7F7F7F5F7FFF7000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000B8826B7A8E70707C67637670
676B7C70637A71676349495F56565E546D54545F6D797C8D
9FC6939E7B4970829393F7F7F7F7F7F7FFF7F50000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000B863677987706B5A565663
636B7063637A827170567A5654706B63656D7A879F8E96B8
9E9A8787567687827FFFF7FFFFF7F5FFF5FF000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000676782826B82565A5A
6D6B71567F718E7C89936B5E5E717187878D8DA9A9A77C7B
7B5E45567C827996FFF7F7F7FFFFF7F70000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000826384707C6B56
534963567671968EC6CAB89FB6ABABABC7C7B4B58767796B
5A566387937C7FFFF7F7FFF7F7F700000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000084897F96A7
7B5367537093A79E89BEC0BEC6D5D2BE9F93938472706B50
567079967C93F7F7F7F5F7F7000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000C0A9
D2D8EFE6D8D2CFBECCC6C6C6CFB587A787797B7B6367557C
8782827CFFF7F7FFF5000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00C6CACFCAD8DED8CCD2B5A0BE9E9AA06C7A63677B849E9F
8E82A9F7F7F5000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000D8DED2CCC0C39A8CA0797B708761899E9F9A89
9FE000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000009A0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000C30000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000C8C8C8C8C8C8C8C3C8C3C3C3C8C8C8C8BEBEC3
C3C300000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00C8C8C8C8C3C3C8C8C3C3C3C3BEBFC3C8C8C8C3C3C3BFBE
BDBAC3C3C3BE000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000BDC3
C8C3C3C3C3C8C3C3C8C3C3C8C3C3BEBDC3C3BFC8C3BEBABE
BABABABABDBABAB5B5000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000B6B4BABAC2
BFC3C3C3C3C8C3C8C3C3C3C3BFC3C3BEBEBDBEC3C3BFBDBE
BABEB5AFB5BEB5B5BEB5BDBA000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000003220B4B4BFBDBF
BFC3C3C3C3C3C8C8C3C3C3C3C3C3C3BDBDC3BEBFBEC0BABA
BABAB5B5B5B5AFAAAFB5AFBFAAB100000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000004532273AB4B4BABFBF
C2BFC8C3C8C3C3C3C3C3BEC3C3BDC3BEBFBEBABAB5BABABA
BAB5B5AFADAAAAAAAFBFAFA4A2A4A5A50000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000765B553A3A484CB6BDBFC8
BFBFC8C3C3C3C3C3C3BFC3BFBAC0C3BDBEBEBDB5BDAFBABD
BAB5B5ADAD99A2B1BFB19599A299A2998685000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000007C725555454D5132B4BFC2C8
BFBFC3BEBDC3BEBDC3C3BDBEBDBEBEC3BABABABDAFBEAFB5
B1AFADA799A2A2BDBF9599A2A295827B6785760000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000007C74676751555B5B4520BFBAC2BF
C3BFC3BEBEC3BEBEBEBEBEBEBDBDBEBABDBABAAFAFAFB5AF
B1B1A7A29595AFB4958F8F918F82795E7485767676000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000008D827874554D5B5F553D3AC2BDC8C2
BAC3BFBFC3BEC0BDBEB5BEBEB5B5B5B5BEAFB5B1AFB5AAAD
AAA4A2919598A2998D8F8D8D82676D6D7293868576720000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000998D7C74725F5B725B3A3A32C2BDBFB4
BFC3C3B5B5BEBAB5B5B5AFB5B5AFAFB5ADB5ADADADADAAAA
A2A299938FA491827B867C82657C71727486938D7C868200
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000A2A28D7C747455675B4D323D32BFBFBFBF
BFBAC3BDB5BEB5AFB5AFADAFADAFADADADB1AFAAA7A4AAA4
A4A2998D9995827B7C74745F6D6D5B67789393939986867C
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000EFADA2918D676D5F5E675E483D483AC2B6BFBA
BFBAB5BDB5B5B5AFADADADA5A7AAA7A7ADAAAAA2A5A2A2A2
A295958D998D7C74717165746D5F5F677685938D938D8D7C
7C7800000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000EFD5AEA28D82747C5B67675F32323A3DBFB4BDB4
BABAB5B5B5ADAFAAA7AAA7A7A5999999A2A2A7A2A2999999
95958F8D7C7472677174746767676E76788593A8A2AF9172
727C91000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000EFEFC2AC968D7C676D5F72554D2A2A3A3ABFB4BABD
BAB5B5ADAAAAAAAAA5A4A2A5A2A299999999A2A29999998F
8F8D828D78675F74677474484855728585858D98A299AC8D
7C8D8D990000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000ECF5DDB8AC8D82746D5F5F6755453A3D3D45B4B4B1B1
B5B1ADB1ADADA4A5A5999999919595919999919999998F8D
8F8D7C9374556D6D675F4D48326E857285788698A8A4AF8D
8D988D999600000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00F2F5ECCAAE9F82826D71675F5F3D3D3A3D3D3DB4B1B4C2
B8B8B5B8B5B5B1ADADA4958D958A8D8D8D8D95958D8D8D82
827B7C8D674C67745548454C5B6C85857C857298A2AC9996
8D91918DACAC000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00F2F2E6C6AC96827C74677C5E5F27453D3D3A54B4C7CBCB
CBC8C8C0C0C0BAB8B8B1ADA48A8A868A8A8282828D8A8286
7C7474865556675E4D3A3D6E4D6786857C727C93A4AFB1AC
96968278ACAC000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
F2F5F5CFB8A29182795F675F674D3248453D3A87CBCDD8D1
D1CBCBD1CBCBC0C0BDB8B1ADA799867C8286868A7B828682
7C74657C5F677C4D453A49765167788676727C8D93AFB1AC
A2967C8DA2A2A20000000000000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000000000F2
EFF5F5CFAD968D797474675F67323D4C3D3D8ECDD3D8D3D8
D1D8D1D3D1CBC8CBC0C0B8B5ADAAA2997C7C7C7C867C827C
716D564D7C5F8D453A273272785B7893728D7C8DA2AFBDC2
AE788D8D9991A2AE00000000000000000000000000000000
0000000000000000
00000000000000000000000000000000000000000000F7F7
F2E9D5C79F96826D5F67675F50324C4C3DCAD3CED3D8D8D8
D8D8D1D1D1D3CBC8C8C8BFB4B1B5ADA4997B74747C747B74
71674D488D4D95673D49274D86517886768D8D8D98A2BFC2
AC91828D9696ACAEAC000000000000000000000000000000
0000000000000000
00000000000000000000000000000000000000000000F7F5
ECE9CCBE968D827465675F5F3D3A483D82D0D3CBD3D3D8D8
D8D8D8D8D1D1CBCBCBC2BDBFBAB5B4ADA491997171746D71
655E52458679827C3A274867868D86868D74918D96A2ACBF
BD8D7C8D8696B8BDB5000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000ECF7F2
ECDDCCAD968D7C6D565F555F2A3D455ECBCDD3D3D3D3D8D1
D8D1D1D8D1D1CBC8CBCBC8BDBDBAB4B1ADA4999167717162
67504C326DA4559965743A6E568D6E85868D879682AC98C2
D08D7C8D919FA2ACAEBD0000000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000F7F7F5E9
E9CFCC9F91797C655F5F543D3A505ACDCBCED3D3D3D1CECB
CBCBCBCBC8C0C0C2C8BFC3BDBDB1B5B4B1ADA29995675E67
56553D3D568D826D9F51825F71788672868D678D8DA2A2AD
B1BD8D788D9F96ACBDD8EC00000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000F5F7F7E9
D8CFB5968279655F5F5F323D3A3ACDCDD3CECBCBD1CBC3BD
B8B8B1B1B1ADB1B1B1B1BABABABDBAB1B1ADA7A4A2957B5F
5452453D4965998D7AA286824D728D8586728282A496A2AC
C2CA8D96A49691ADBFEFDD00000000000000000000000000
0000000000000000
00000000000000000000000000000000000000F7F7F5F5E9
D5CCAE967C7C71565F543A3D50CAD0D0D3CECBCBC8C2B8B5
ADA7A7A7A7A7A7ADA7ADB1ADBABABDB4B1ADA9A499998F5E
4E4C3D2A3D6399795FA9869882677493867C8D82A296ACA2
ACC7ACA29F9FA2AEC2E6E6EF000000000000000000000000
0000000000000000
00000000000000000000000000000000000000EFF7F5ECD8
CFCF9F8279677156503D3D454CCDCDCBCBCBCBC8C0958999
999E9E9E9E9E89898989A4B1B1BABABAB4B1ADA4A499918D
4C3D3A273A5679A48791AC98A296867C8D8D727C8DA28DAF
AEBDC29FAC96A2BDCCD8E9EC000000000000000000000000
0000000000000000
000000000000000000000000000000000000F7F7EFF7E9DD
D5AE967A6D675F4C56453D4CD2CDCBCBC8CECBA79E9E9ECD
C0A7A7B5C09E9E99918D89A4B1B4BABDB4B1B1A9A4999E8F
82492A2A27562AA9B167AE82AAAC8D8D986E8D828D9699A4
AEC2CA968796A2ADE6E6ECECE60000000000000000000000
0000000000000000
000000000000000000000000000000000000F7F7F2F7DACC
AD96877A565F565F323D3D82D0D0D0CBC8C8C8999E9E9995
95959E89897D8080A78D8D7DABB8BABABABAB1A9A4A49999
8D793D3D173A5E8796828DAC8DAFCE8D7C8D8D74829896A2
A2C2C29F969F96ADE6E9EFE9E90000000000000000000000
0000000000000000
0000000000000000000000000000000000F5F7F5F5F5D8C3
A2967965565F503A483A5FD2D2D0CBCBC8A79E795E687579
75757D6F5E575B684D665B4E629EBABABAB1B1B1A4A4A2A4
8F825E20173D495A8DA95FA982A4BFCE9999768D828D9182
ACBDC2BEA2AC9FB8DDECE6ECF5EC00000000000000000000
0000000000000000
0000000000000000000000000000000000F5F5EFF5E9D8BE
968265565E554C4C4C4ED2D2CDD0D3CBC8C0C8A78D898089
808999808080808080A2A9ABB1B1BABAB5B5B1B5ADA4A4A2
998F71361717365A71A4966DA282BFBFD0798D8D828D8D82
ACACC2C796ACA2D5E9E9E6E6F5F500000000000000000000
0000000000000000
00000000000000000000000000000000EFF7F5ECEFE6CFAE
876D6D5E5550454C4D54D0CBD0CECBCEC8CED3D3D8D8CDCB
D8CBC8D3D8CDCBC2BDC2BDBABABDBABDBAB8B1B1ADADA4A2
99998254280B5A495A718D678D748DBFBFA2998D7C7C8D99
A299C2C79F9F91DDE6E6E9E6F7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000F5EFF5F5E9C6BF9F
79655454523A4C4C48B8D0D0D0D1D3CBD3CBD3D3D8D3D8D3
D8C8CBCBCBBDBDBDBDBFBDBFC8BDBABFBDB8B8B1ADADA49E
99998262271F495482719F675F918DB4BFC8AC8D8D917C82
8299C2C7A2AE96E6E9DDE6EFF7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000F5F5EFF5F5CF9F82
676D50523D4C4C4C4CD0D0CDD0D3D1D1D3D0D3D3D3D3D3D3
D0CBC8C8C8BDBFC3BDC2BDC8BDC8BDBDB8B8BAB1ADA7ADA2
99998F6D453617505665677967827A99BDBD99A28D8D7C8D
7CA2ACC2AD96A4D8E6E6D5F7F5F7F7000000000000000000
0000000000000000
000000000000000000000000000000F7F7F5F5EFCFC3967C
6D505E3D4C3A4C503DD0CDCDD0D3D3D3D1D3D3D3D3D0D3D3
C8C8BDC8BDB5BABFBDC0C3C8C0C0CBC8BDBDB8B5ADADA4A2
9E918F7C49272A49636B71876D5E659691A8C8AC86916D96
8DA4A2C2AD8DCAD5E9E9E9F5F7F7F7F70000000000000000
0000000000000000
000000000000000000000000000000F5F5F7F7E9C6A7966D
67654E4C4C494C3D87CACDCDD3D3D3D3D8D3D0D3D3D3CBCB
BDB1ADB8B4ADB1B8BABDC3C2C8CBCBC0C0BDB8B1ADADA4A4
A2998A7B5E363D3D5A5671657C546756AEBDA2AA91967A82
8D9FA2BFB896DDC2F5E9F7F7F7F7F7F70000000000000000
0000000000000000
000000000000000000000000000000F7EFF7F5F5BF967965
56564C3D3D4C4C3ACACDCDD1D3D3D3D3D3D3CED3D3D3CBC0
BABAA7ADADA4A9B1B1BABDC3C0C8C8C8C0C8BEB8B1ADA4A4
A2918F8262360B2449546D567C67674CA98DA2CE96919182
8E8D96BFBEBECCD8D8D2F7F7F7F7F7F70000000000000000
0000000000000000
0000000000000000000000000000F7F7F7F7F7E9AE876554
563D4C454C4E3A32CDC7CBCBD3D1D8D8D3D3D3D1D8A799CB
CBC0B5757591A782A2B1BDC8C8CBCBCBC8C0BDB8B5ADADA4
A2998F7B714517243249565A6D6D546D5E8DAFA2AF8D8D67
8282A2BDBEE9ADE9B8F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000F7F7F7F7F5E096796567
4C4C3D484C3D3256CDCBD0D3D8D3D1D8D1D3CED3D8D0CDD1
D1CBBAB1B4B5BAAD95A4BDCBCBCBCBCBC0C8C8BEB5B1ADA4
99998F8A715E0B17243D505E5671545F2AAC9598BF828D6D
798D96ADC6C6ACB8F7F7F5F7F7F7F7F7F500000000000000
0000000000000000
0000000000000000000000000000F7EFF7F7F7D88D65623D
4952454C5232327CC7D1D1D1D8D8D8D8D8D3D3D1D8CDD8D8
D8D1C8BABABAB4B1ADADC0CBCBD1CBCBCBC0C0C0BAB5B1A7
9E9E8F8274650B1F17495665456D545F32968DACBF828D79
828796AEC6C6BECCF7F7F5F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000F7F5F5F7F5D2795E5F54
4C4C5056482A36CACDD3D3D8D8D8D8D8D8D8D1CBD8D8D8E3
D8D1CBC2B8B5B4B1ADB8C0CBCBCECBD1CBC8C8C0C0B8B5AD
A7999182745F2A001F452A67546D48545E7991AAAAA2828D
798282ADC7B8D2F5F7F7F7F7F7F7F7F5F500000000000000
0000000000000000
0000000000000000000000000000F5F7F7F7EF9665653D45
454C524C1F321FCBD1D2D1D8D8D8D8D8D8D8D8D3D3D1D8D8
D8D3CBB8ABADB1ABB4BDCBCDCDD0D3CBCBC8CBC8C0B8B5B1
ADA2918279714907173656565E654C5449718D99B1C27C82
718296BFC79FCCF7F5F7F5F5F5F7F7F7F500000000000000
0000000000000000
00000000000000000000000000F7F5F7F7F7F28965503D56
52524C172A2736CBD3D8D8D8D8D8D8D8D8D8D8D8D1D2D1D8
D1CDC0BDABB1B4B4BDCBCBCBCDD1D3CDD1CBC8CBC0C0B8B5
A9AD998F796D560B282A454954546754547A8D98B1CE827C
6D7A87ADC6CCF5F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F5F7F5F5F5F5895F4C4C56
494C522A1F2AADD0D0D8D8D8D8D8E1E1E1D8D8D8D8D3CDD8
D8CBC0B4B4B1BABDC2CBD0CDD1D1D8D2D1CDCBCBC0BDBDB4
ADA4A28F7B6D651F07322A565E4C5F6754719FA2AFCE7991
5E8779BDCFCCF7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F5F5F7CC715E455454
524C2A1F17C0D2D1D8E1D8D8E1D8D8D8D8D8D8D8D8D8D3D8
D8D1CBBDB4BABABDC2CDCDD8D8D1D8D1D8D2D2CDCBC7C0BA
B1A9A4A2826D6745323D49496554675E5671A9A2ACC28D7C
547A82B1D5ECF7F7F7F7F7F7F7F7F7F5F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7F7F7715F54325649
49522A3D36CBCDD8D8D8D8E1E1D8D8D8E1D8D8D8D8D8D2D8
D8D8D1BDB4BDBFC2C2C7D0D8D2D8D8D8D1D2D2D2CDCBC2BD
B4B1A4A28A7B62493D3D3D565467655E7089A4A2A2AC9172
507A96AEDDF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7F5F77967493D5E56
4C453D2A84D1D2D8D8D8E1E1D8D8D8D8D8D8E1E1D8D8D8D8
D8D1D1BDB4B4BFC2CBCBD2D2D2D8D8D1D1D8D3D0CDCBCBC2
B4B1A9A28F7B625632323D49526567655FA2A2A2A2A9AC74
747987AFECF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7F7F5717156494556
52324556CDD3D2D8D8D8D8D8D8D8D8D8D2D8D8D8D8D8D8CD
D8D8D8C2B8B4BDC2C2C7CDD2D2D2D8D2D8D2CDCDCBCDC7C2
C2B4A9A499826D56453A3D3D565F635650AEA296A49FB15F
797982ACEFF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F5F7AE5F63545E5456
3D3645C7D8CDD8D8D8D8D8E1D8D8D8D2CDCDD2D2D8D8D1D3
D8D8D8CBB8B1B4B6BFB6CACFCDD8D2D2D2CDCACDCBCBCBC2
C2B6B1A99E8F6D5F492A3D3D496D5E5E5E9F96A2A26DBD4D
6D8D96ADF7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F5F77F8E6D496D4956
32494CC7D1C7D8D8E1D8D8D8D8D2D2C0C7CBCBCDD2D8D0D3
D8D8D8CBB5B1ABB4B4C2CACDD2C7C7C2C7C7C7C7CBCDC7C7
B8BFB1A9A28F795F522A273D495E675E5E9F9999A252AF62
5E89A9C7F7F7F7F5F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F5F5F7F755935E6B5A5E49
2A67B5CBB8CDD8D8D8D8D8D2CFCDCDCBB6B4C2C7CDD2C7CD
D8D8D8C0B4A7AEABADB8C7CAC2C2B8BAB1B1ABB6B6C2C2C2
BFBFB4A999917B6D564517323D5E5E6D5696A4828D50BD6D
5696ACD5F7F7F7F7F7F7F7F7F5F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7FF6D7C565E566227
5452D199ADD0D8D8D8D8D2CAB6968EABAA96B6B6D2D2CDCD
D8D8D8CBB4A49FA4BFB6CABAB6A99E898E9F9F9FAABFC2B6
B6B6B1A99F91826256493D32325654635E898D82825FBD5F
569FA2D8FFF7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7A07A714956496232
5FBEC0A7ABD0D2D8D8CDBA878DB6AE6268849F9E9ECDCDC7
D8D8D8C8BDA4A996A95E7D91ABCC7A557F7C7A7C89ABB4B4
B6B6ABAB99917B6D5E49562A2A56565E6D87967C825BBF67
71ACACE9F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F7F7899E71633256623A
2AD1B5B5B4D2D8D2C7BA8991C0D86D6250747F9F96BAB4C8
D8D8D0CBBDAD9689919F66CCE96F70628559A0716789A9A9
B4B1ABA4A289796D5449320B1F565E456D89876D7A71B150
96AEAEF7F7F7F7F7F7F7F7F7F7F7F7F7F5F7000000000000
0000000000000000
00000000000000000000000000F7F7FFF582544C32565656
62D1ADA7B4CAD0CBB696703698B777B40D6E42708996BDCE
D8D8D3CBBFBA968E718E966DC350BD0D6850A028507C8E96
A9ABA996968F796256521F171F2A564979717A7A8271AC50
8DA4C6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F793C987705349565662
8DC0A7A4B1CDD0BDAA914961613D24365667617C96B8C3D3
D3D8D3CBC3BDAD969179708C8C362A3636493D55537C8789
99A4A4968982625E5E493D1F363D3D496D796D678279AC65
8DA2E6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
00000000000000000000000000F7F779A09A5E4963564956
8FB5A4A4B1CDCAC7C2B4967B63535353567091A9BDCBCBD3
D8D8D3CBCBC8BAADA496895F7C847B61463D49718D8E9199
A4A496998D7B625E5656452A3632324571827167828DAC6D
8DA9ECF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
0000000000000000
0000000000000000000000000000F7E6896B494549493D6D
8F999F96ABCAD0D0D8D2CBCDC2BDBABDC2BDA4ADB8C8D8D3
D8D8D8D3CECBBAA2A796A9ABA996969699A4A9A9B1B5B4AB
A9A499918D826263563D3D2A3649453D6D8D6D678D96B471
96DEFFF7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000FFFF455E323D3D65325E
7B9E998EA9D0C2D3D8D8D8D8D8D8B5917C717BBDC8D8D8D8
E1D8D8D8D3D8C3B89171717B8EC2C7CBC7C2C2BDBDBDB4A9
9687998D82796D5E5456322A2A3627495E796D659196BF7A
9FE9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000E9FF3D4C323D49564967
75828D919FCBC6BFCDD8D8D8D1897C707BA9C8D3D3D8E1D8
E1D8D8D8D8D3D3C8B88D6256627BADBAC7CBCBC0C2B4AD96
7A998E89796D6D5E3D3D2A322A27505A6B7A715F8D8DAE96
9FF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000AEFF5445494932564C5F
62627C899FCAD2969FA9A49E7B79A4D3D8D8E1E1E1E1E1E1
D8D8D8D8D8D8D3D3D3CEBDA98E705E7171898E91877C7A89
96969E8D796D6D566D1F45453D2A245F6D796D658DA28974
CCF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000A77149495F5649494956
5F63717AA9CAD0D0CBA99E9EB6D8E1E1E1E1E1E1E1E1E1E3
D8D8E1E1E1D8D8D8D8D3D1CBCBCBC7C79F7C797C7C969F96
99A2998D797179563D493D3217171F63705E7A71969F6D8D
E9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
0000000000000000000000000000006D56497B675656495E
5E637979A4CBCDD0D0D8D8D8D8D8E1E1E1E1E1E1E1E3E1E1
D8E1E1E1D8D8D8D8D8D8D0D0D3CBCBCBC2C7C7BDB4B1ABA4
A9968E82797A796D493D271717171F8E635EA26D82AC6D9F
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000
0000000000000000
00000000000000000000000000000050505A876B565A565A
5A5E7A71A4C7D0D0D2D8D8D8E1E1D8D8E1E1E1D8E1E1E1E1
D8D8E1D8D8E1D8D8D8D8D8D1D3CDCBC7C2CBBDBDB4A9A9A4
A496968D7B79795E6D452A2A1F3227967A5E96796DAE6DBE
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000
0000000000000000
000000000000000000000000000000566763716367635A56
54546D7191BFCDD0D0D2D8D8D8E1E1D8E1E1E1E1E1E1E1E1
E1E1E1E1E1D8D8D8D3D3D3D3D3CBC8C7CBC2BFBAB4B1ABA9
A4A299827982716D49323D3217171F967C6DA27C63966DF5
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000
0000000000000000
000000000000000000000000000000005656565F63565A56
5A567A8296BDC2CED2D3D8D8D8D8E1E1E1E1E1D8D8E1E1E1
E1E1D8D8D8D8D8D1D3D3D3CECBCBCBC0C2BFC2BDB1B4ADA9
9699918D82796D564936451F17173271A287A4827165ADF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000675663676B635A5A
5663718D96B1C2D0D2D8D8D8D8E1E1D8D8E1E1D8E1E1D8E1
E1E1D8D8D8D8D8D8D8D3D3CECBCBCBC0BDBDBDBDB8B1ABA9
A4998E87877C6D5E3D49271F1F1724709671968D8265D2F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000505E6B6B5A635656
6B63718996ABC2CBD3D3D3D8D8D8E1E1D8D8E1E1D8D8E1D8
D8D8D8D8D8D8D8D3D8D3D3CBD3CBC8C8C2BFC2BAB4B1ABA9
96999187876D6D5E493D27170B0B53637A799F96AE96F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000
0000000000000000
00000000000000000000000000000000007A5E635F5E5A67
45637C8D8EA9BFCBD0D3D8D8D8E1E1D8E1E1E1D8E1D8D8E1
D8D8D8D8D8D8D8D8D8D8CBD1CECBCBC0C8BDBDB4B4B1ABA9
96A28E89716B5A495632170B240B5F6B6D6596969FDDF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000000000
0000000000000000
000000000000000000000000000000000056565656545A56
63637A8E9FABBFCBD0D8D8D8D8E1E1D8E1D8E1D8D8D8E1D8
D8D8D8D8D8D8D8D8D8D1D3D3CBCBCBC0C8BDBDB4B1B1B1A9
9FA4897C71716D563D32171724176B6B7167969FABF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000000000
0000000000000000
000000000000000000000000000000000000564954504956
636D878EA4AEBFCBD3D1D8D8D8D8D8D8D8E1E1E1E1D8D8E1
D8D8D8D8D8D8D8D8D1D3D3D3CBD3CBC8C8C3BDB4B1ABB1A9
A99689897C635E3D321F1F0B1B17796B67659FB5CFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000000000
0000000000000000
000000000000000000000000000000000000565654565650
566D7C8E9FB6C2CBD3D3D8D8D8E1D8E1E1E1E1E1D8E1D8D8
E1D8D8D8D8D8D8D8D3D8D3D1CECBCBC8C8BDBDB6B1B1A9AB
99998D7C7A715E36321F24141F1F7C895E7996BFF7F7F5F7
F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000000000
0000000000000000
000000000000000000000000000000000000004950505656
506B8796A9B4C8CBCDD0D3D8D8D8D8D8E1D8E1D8D8D8D8D8
D8D8D8D8D8D8D8D8D3D3CED3D1CBCBCBC2C2BFBAB1B1ABA4
A48E8D7C7163563632241F2A2A176D876D8DA9D2F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
0000000000000000
00000000000000000000000000000000000000505A565056
5A6B7196AEC2C2CBD3D3D8D8D8D8D8E1E1D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D3D3D3CECECBC8C8CBC2BFBAB8B1B1ADAD
998E89796D5E4936362A1F2A170B6B716D8DB1ECF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
0000000000000000
00000000000000000000000000000000000000006B6B6B56
566B828EA4BDC8CBCBD3D0D3D8D8D8D8D8D8D8E1D8D8D8D8
D8D8D3D8D3D3D3D3D8D1D3C8C8C8C8C0C2BFBAB4BAA9A9A9
8E8E7C7A6356454932321F17073689717C99ADF7F5F7F7F7
F7F7F7F7F7F7F7F7F7F7F700000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000706B5A63
5F6379969FB4C8CBCBD3D3D8D8D3D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D3D3D3D8D3CBCBCBCBC8CBC3BDBDBDBAB1A4AB96
968D7962565A453636242A0D077A7C658291CFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F700000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000565F50
63637A8DA4B6C2C0CBCBD3CECED3D3D8D8D8D3D8D8D8D3D8
D0D3D2D3D3D3CECBCBCBCBC8CBC8C8C0BDBDBDB4B4ABA4A9
8E7C6D655E5A5A32322A170B89796D658DB8E9F7F5F5F7F7
F7F7F7F7F7F7F7F7F7F70000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000005A7A
567A7A8D9FB4BFC7CBC8CBD3D3D8D3D2D8D3D8D8D8D8D8D3
D3D8D3CBD3CBD3CBCBC8CBCBC8C8BFC3BABAB6B1AD96A499
897C716D5A49506B1F171B56567A6D7996C2F5F7F5FFF7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000005656
5F7C7A8DA4B4B6C2CBC8CBD1CBD8CED3D3D3D3D3D3D3D8D1
D1CBCBCBC0CBC8C8C8C8C8CBC8C8BABABDB4B4B1A9969689
7971655A5A565636493649457C71878DAEBEF7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000054
565E7187969FB8BDC2C8C0D1D1D0D0CDCBD1D3D3D8CDD0CB
CBC8C0BDBDBEC8C8C3C0C3BEBDBDB1B8B4ABABA496968E89
797A6D505049493D4532826B716DA496BFF7F7F7F5F7F7FF
F7F7F7F7F7F7F7F700000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
6D5671828EABB4B6BDC0C0C8CBC7CBD0CBCBCBCDCBC8CBCB
C3BDB5B8B8BABEB5B5B5B5ADB1B8A9B1A9A99FA296898787
7A715E5A56506756496789707C8DA9BFBEF5F7F7F7FFF7F7
F7F7F7F7F7F7F70000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
006B63717C96ABBFB6B8BDBDCBCBCBCBC7C2C2C2C2BDB6B1
B4B4A9A9A4A4A4A2A7A4A2A29699999999918E968E89826D
63706B556B6B49636D6D716D8D87B4BFEFF7F7F7F7F7F7F7
F7F7F7F7F7F7000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00636B7A897F8E96B4B8C2C8C7C2C2C2BFB4B4A9B4BFABAD
A9AB969F91998DA48D99828E82828D878789897C8E968287
7A7C6363707C5A3D568287828DADB8BEF7F7F7F7F7F7F7F5
F7F7F7F7F7F7000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000056717A638E9FBECACACAC2C2B8B6A9ADABABA9ABA9A9
96968E8E898E89798987716D89718771797C7A7C636B7079
70717071565A676D717A7A96B8B89FF7F7F7F7F5F7F7F7F7
F7F7F7F7F700000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000007687A7AA9EB6AAB6BEBEB6B4ABA9AB969FA99F969F
9691878971967C96877C8D7A6D967A897C7A82875F6B7A79
67707C656D656D657187ACB5ADAED2F7F7F7F7FFF7F7F7F7
F7F7F7F70000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000006B828E8E9EB6B8B4ADABAE9F9F9F8E968E968E96
89967A717F65827A8E717C7A7C96637171897A6B6B5A5649
506356565656657C96ACC79EAE87F7F7F7F7F7F7F7F7F7F7
F7F7F7000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000A09FA7B8B8B8B89F9F9F9F969F969689899687
7A7C65828263497C5A877A7C7C5E6D7A4549675E5A5E6765
6D656556676DAD96AEBE639E82D2FFF7F7F7F7F7F7F7F5F7
F7F700000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000082A9B5B6B8A796968E96968E82878E7C87
8763967A6396635A7C63636B5A5E54455656675656655E56
525E7187879F96BFB8827A9E82F7F7F7F7F7F5F7F7F5F7F7
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000093ACB5ABA77C89829696897689877C8E
7C875A7170637A5A63655A5F5A5056565649455656565454
637A7A7A7A9FB5797982A796E9F5F5F7F7F5F7F7F5F7F700
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000093B8B8AC7A8E7C7C877A708282707C
707C5A7A6D6B50497A50565A565449493D36454545546D5A
63829F96C2B59E876B9F6BE9FFFFF5F7F7F7F7F7F7F70000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000B5BEAC7A6B937C8E93876B827A63
7C7C63717A70673249567A56563D56453D32363232495E82
968996B5935F7787826DA9F7F7F7F7F7F7F5F7FFF7000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000B8826B7A8E70707C67637670
676B7C70637A71676349495F56565E546D54545F6D797C8D
9FC6939E7B4970829393F7F7F7F7F7F7FFF7F50000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000B863677987706B5A565663
636B7063637A827170567A5654706B63656D7A879F8E96B8
9E9A8787567687827FFFF7FFFFF7F5FFF5FF000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000676782826B82565A5A
6D6B71567F718E7C89936B5E5E717187878D8DA9A9A77C7B
7B5E45567C827996FFF7F7F7FFFFF7F70000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000826384707C6B56
534963567671968EC6CAB89FB6ABABABC7C7B4B58767796B
5A566387937C7FFFF7F7FFF7F7F700000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000084897F96A7
7B5367537093A79E89BEC0BEC6D5D2BE9F93938472706B50
567079967C93F7F7F7F5F7F7000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000C0A9
D2D8EFE6D8D2CFBECCC6C6C6CFB587A787797B7B6367557C
8782827CFFF7F7FFF5000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00C6CACFCAD8DED8CCD2B5A0BE9E9AA06C7A63677B849E9F
8E82A9F7F7F5000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000D8DED2CCC0C39A8CA0797B708761899E9F9A89
9FE000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000009A0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[64]:=",
  ImageSize->{450, 150},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000720000UR000`400?l00000o`00003oo`3oooo3
0?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo3
0?ooo`00o`3oooo30?ooo`008@3ooom[000001l0ooooJP00000O0?ooof/000008`3oool00240oooo
J`00000O0?ooofX000007`3ooom[000002<0oooo000Q0?ooof/000007`3ooomZ000001l0ooooJ`00
000S0?ooo`008@3ooom[000001l0ooooJP00000O0?ooof/000008`3oool00240ooooJ`00000O0?oo
ofX000007`3ooom[000002<0oooo000Q0?ooof/000007`3ooomZ000001l0ooooJ`00000S0?ooo`00
8@3ooom[000001l0ooooJP00000O0?ooof/000008`3oool00240ooooJ`00000O0?ooofX000007`3o
oom[000002<0oooo000Q0?ooof/000007`3ooomZ000001l0ooooJ`00000S0?ooo`008@3ooom[0000
01l0ooooJP00000O0?ooof/000008`3oool00240ooooJ`00000O0?ooofX000007`3ooom[000002<0
oooo000Q0?ooof/000007`3ooold000000030<?3``000000000003<000007`3ooom[000002<0oooo
000Q0?ooob`000001P38b<P01033`l<0b<S80<?3``33`l<40<S8b0040;jn_P33`l<0`l?30<?3`bd0
00007`3oool/000000L0b<S80`33`l<30<S8b080_[jn0P33`l<]000001l0oooo;00000060<S8b004
0<?3``38b<P0`l?30<?3``@0b<S800@0_[jn0<?3``33`l<0`l?3;@00000S0?ooo`008@3ooolV0000
00030;fm_@33`l<0b<S800<0`l?300H0b<S80<?3``33`l<0b<S80<?3``38b<P20<?3``080;jn_P33
`l<0`l?30;no_`38b<P0`l?30;Zj^P2n_[h30;Zj^P030;fm_@2j^[X0^[Zj0080]KFe9`00000O0?oo
obH0000000<0_Kfm0<?3``33`l<00`33`l<00`38b<P0`l?30<S8b0020<?3``040<S8b033`l<0_[jn
0;fm_@80`l?300D0b<S80<?3``2n_[h0^[Zj0;jn_P030;Zj^P040;fm_@2j^[X0]KFe0;Fe]BL00000
7`3ooolV000000030;fm_@33`l<0b<S800<0`l?300H0b<S80<?3``33`l<0b<S80<?3``38b<P20<?3
``080;jn_P33`l<0`l?30;no_`38b<P0`l?30;Zj^P2n_[h30;Zj^P030;fm_@2j^[X0^[Zj0080]KFe
9`00000S0?ooo`008@3ooolT000000050;Jf]P2d];@0^[Zj0<;2`P2o_kl00`33`l<00`38b<P0`l?3
0<S8b0030<?3``060;no_`33`l<0`l?30;jn_P2m_Kd0_[jn0P33`l<0102m_Kd0_[jn0;Zj^P2n_[h2
0;Fe]@060;jn_P2e]KD0]KFe0;jn_P2m_Kd0^[Zj9@00000O0?ooob@0000000@0];Bd0;Zj^P2j^[X0
`/;21033`l<20<S8b0H0`l?30P2n_[h01@2m_Kd0`l?30<?3``2o_kl0_Kfm0080_[jn00P0]KFe0:n_
[`2e]KD0_[jn0;Fe]@2n_[h0]KFe0;fm_BD000007`3ooolT000000050;Jf]P2d];@0^[Zj0<;2`P2o
_kl00`33`l<00`38b<P0`l?30<S8b0030<?3``060;no_`33`l<0`l?30;jn_P2m_Kd0_[jn0P33`l<0
102m_Kd0_[jn0;Zj^P2n_[h20;Fe]@060;jn_P2e]KD0]KFe0;jn_P2m_Kd0^[Zj9@00000S0?ooo`00
8@3ooolR00000005038b<P0P8200];Bd0;Bd]02m_Kd00P2o_kl40<?3``80b<S81P33`l<01@2m_Kd0
`l?30;jn_P2o_kl0_[jn00@0^[Zj0`2e]KD01`2_[jl0ZZZZ0:n_[`2_[jl0_kno0:ZZZP2a/K408`00
000O0?ooob80000000H0<S8b020P802d];@0_kno0;fm_@2o_kl50<?3``030<S8b033`l<0`l?300@0
`l?30P2m_Kd01033`l<0_kno0;jn_P30`<030;Zj^P@0]KFe00H0ZZZZ0:n_[`2e]KD0[jn_0:ZZZP2a
/K4S000001l0oooo8P0000001@0b<S80820P0;Bd]02d];@0_Kfm0080_kno1033`l<20<S8b0H0`l?3
00D0_Kfm0<?3``2n_[h0_kno0;jn_P040;Zj^P<0]KFe00L0[jn_0:ZZZP2_[jl0[jn_0;no_`2ZZZX0
/K6a02<000008`3oool00240oooo8@0000000`0b<S809bLW03Xj>P020;Bd]080_kno00@0`/;20;no
_`38b<P0b<S81033`l<01`2n_[h0`l?30<?3``2m_Kd0`l?30;no_`2n_[h00P2j^[X0102e]KD0^[Zj
0;Zj^P2j^[X20;Fe]@040:f][@2ZZZX0ZZZZ0:ZZZP80[jn_00@0Y:BT0::RXP2TY:@0YJFU8P00000O
0?ooob00000000H0ADE5038b<P0W9bL0>SXj0;Bd]02j^[X30;no_`030<S8b033`l<0b<S800@0`l?3
00T0_[jn0<?3``2m_Kd0`l?30;jn_P2o_kl0_[jn0;Zj^P2e]KD00`2j^[X20;Fe]@090:n_[`2][Jd0
ZZZZ0:ZZZP2_[jl0_kno0:n_[`2RXZ80Y:BT0080YJFU8@00000O0?ooob40000000<0<S8b02LW9`0j
>SX00P2d];@20;no_`040<;2`P2o_kl0b<S80<S8b0@0`l?300L0_[jn0<?3``33`l<0_Kfm0<?3``2o
_kl0_[jn0080^[Zj00@0]KFe0;Zj^P2j^[X0^[Zj0P2e]KD0102][Jd0ZZZZ0:ZZZP2ZZZX20:n_[`04
0:BTY02RXZ80Y:BT0:FUYB8000008`3oool00240oooo7`0000002@1fMWH0Fe]K03Xj>P0j>SX0B4Q8
04a<C02f][H0_kno0<S8b0020;no_`030<S8b033`l<0`l?300@0`l?300@0_kno0;Zj^P30`<00`l?3
0P2n_[h01P2m_Kd0]KFe0;fm_@2j^[X0_Kfm0;Zj^P80]KFe00`0[Jf]09VIV@2RXZ80/K6a0;no_`2E
UID0VIVI0::RXP2IVIT0XZ:R08J6QP25QHDP000001l0oooo7`0000002`1KFe/0EEEE03Xj>P0j>SX0
B4Q80;Jf]P2m_Kd0_kno0<S8b02o_kl0b<S800D0`l?300H0_kno0<?3``2o_kl0`<300<?3``2m_Kd2
0;jn_P050;Fe]@2m_Kd0[jn_0;Zj^P2m_Kd00P2e]KD20:f][@0:09VIV@2a/K40_kno0;6a/@2EUID0
XZ:R09VIV@2RXZ80VIVI08J6QR0000007`3ooolO0000000907IfMP1KFe/0>SXj03Xj>P18B4P0C4a<
0;Jf]P2o_kl0b<S80080_kno00<0b<S80<?3``33`l<01033`l<0102o_kl0^[Zj0<30`033`l<20;jn
_P060;fm_@2e]KD0_Kfm0;Zj^P2m_Kd0^[Zj0P2e]KD0302][Jd0VIVI0::RXP2a/K40_kno09FEU@2I
VIT0XZ:R09VIV@2RXZ80QXJ608F5QB0000008`3oool00240oooo700000001@1lO7`0M7Ad06MWI`1W
IfL0DE5A0080Fe]K00X0ADE5020P802o_kl0`/;20;no_`33`l<0_kno0<?3``2n_[h0`l?31@2n_[h2
0;fm_@040;jn_P2m_Kd0^[Zj0;Zj^P80[jn_00D0]KFe0:n_[`2a/K40/K6a0:NWY`0209FEU@0:0:n_
[`2d];@0UIFE08n?S`2ATI40Shn?08:2PP1iNGT0M7Ad08F5Q@<0MWIf7@00000O0?oooa`0000000D0
O7al07AdM01WIfL0DE5A05EEE@0205]KF`0404E5A@2o_kl0^[Zj0<;2`P80_kno00@0`l?30;jn_P2n
_[h0`l?31@2n_[h01@2m_Kd0_[jn0;Zj^P2m_Kd0^[Zj00<0[jn_00D0]KFe0:n_[`2a/K40YjNW0::R
XP0209FEU@030;Bd]02EUID0Shn?0080Shn?00@0PX:207UiN@1NGUh0M7Ad0`1fMWHM000001l0oooo
700000001@1lO7`0M7Ad06MWI`1WIfL0DE5A0080Fe]K00X0ADE5020P802o_kl0`/;20;no_`33`l<0
_kno0<?3``2n_[h0`l?31@2n_[h20;fm_@040;jn_P2m_Kd0^[Zj0;Zj^P80[jn_00D0]KFe0:n_[`2a
/K40/K6a0:NWY`0209FEU@0:0:n_[`2d];@0UIFE08n?S`2ATI40Shn?08:2PP1iNGT0M7Ad08F5Q@<0
MWIf7@00000S0?ooo`008@3ooolK0000000D08f=S@22PX80N7Qh07AdM01EEED0CDe=05mOG`1EEED0
?Cdm03Xj>P32`/80b<S80<;2`P2j^[X0`l?30;no_`33`l<0_[jn0<30`02m_Kd30;jn_P<0]KFe00h0
_[jn0:n_[`2e]KD0/K6a0:n_[`2ZZZX0[Jf]0:ZZZP2TY:@0XZ:R09FEU@2HV9P0XZ:R09VIV@<0SHf=
00P0PX:206MWI`1]KFd0LW9b09>CT`26QXH0QHF507IfMQd000007`3ooolK0000000>08f=S@22PX80
N7Qh07AdM01=CDd0Fe]K05mOG`1EEED0?Cdm0<;2`P2m_Kd0b<S80<;2`P33`l<20;no_`050<?3``2n
_[h0_Kfm0;jn_P2e]KD00P2n_[h30;Fe]@0B0;jn_P2_[jl0/K6a0:n_[`2e]KD0ZZZZ0:f][@2TY:@0
XZ:R096AT@2EUID0V9RH09VIV@2=SHd0Shn?08f=S@22PX80IfMW0P1]KFd01@1bLW80QXJ608F5Q@1f
MWH0LW9b01`000007`3ooolK0000000D08f=S@22PX80N7Qh07AdM01EEED0CDe=05mOG`1EEED0?Cdm
03Xj>P32`/80b<S80<;2`P2j^[X0`l?30;no_`33`l<0_[jn0<30`02m_Kd30;jn_P<0]KFe00h0_[jn
0:n_[`2e]KD0/K6a0:n_[`2ZZZX0[Jf]0:ZZZP2TY:@0XZ:R09FEU@2HV9P0XZ:R09VIV@<0SHf=00P0
PX:206MWI`1]KFd0LW9b09>CT`26QXH0QHF507IfMQd000008`3oool00240oooo6`0000001@2=SHd0
O7al07AdM01bLW80GemO0080Fe]K0P0j>SX01@0b<S80`/;20;no_`2d];@0_kno0080`l?300<0]KFe
0;jn_P2j^[X00P2e]KD00`2_[jl0]KFe0;Fe]@020:n_[`030:f][@2e]KD0[Jf]0080[Jf]0P2ZZZX2
0::RXP0A09VIV@2?Shl0Y:BT096AT@22PX80Ng]k07alO022PX80IFEU07alO01aLG40M7Ad08J6QP2C
Ti<0SHf=07alO022PX807000000O0?oooaX0000000P0VIVI08f=S@1lO7`0M7Ad079bLP1KFe/0LW9b
05]KF`80>SXj00@0`/;20;fm_@2o_kl0];Bd0P33`l<20;Fe]@060;jn_P2e]KD0]KFe0;Fe]@2_[jl0
]KFe0P2_[jl00`2e]KD0[Jf]0;Fe]@030:f][@80ZZZZ01<0XZ:R09VIV@2CTi<0Shn?0:BTY022PX80
Ng]k08J6QP1lO7`0IFEU07alO01aLG40LW9b07AdM02CTi<0SHf=07alO026QXH0PX:201/000007`3o
oolK0000000508f=S@1lO7`0M7Ad079bLP1OGel00P1KFe/203Xj>P05038b<P32`/80_kno0;Bd]02o
_kl00P33`l<00`2e]KD0_[jn0;Zj^P020;Fe]@030:n_[`2e]KD0]KFe0080[jn_00<0[Jf]0;Fe]@2]
[Jd00P2][Jd20:ZZZP80XZ:R0140VIVI08n?S`2TY:@0TI6A08:2PP1kNg/0O7al08:2PP1UIFD0O7al
075aL@1dM7@0QXJ609>CT`2=SHd0O7al08:2PP0L000002<0oooo000Q0?oooaX0000000<0XZ:R08f=
S@1lO7`00P1dM7@01P1EEED0IfMW04e=C@0b<S80?Cdm038b<P@0_kno00/0^[Zj0<?3``2e]KD0_[jn
0;Fe]@2_[jl0]KFe0:f][@2_[jl0[Jf]0:n_[`020:f][@050;6a/@2_[jl0ZZZZ0:NWY`2ZZZX00P2T
Y:@02@2RXZ80VIVI09VIV@2EUID0PX:207]kN`1lO7`0M7Ad05mOG`0206e]K@0305]KF`1hN7P0Ti>C
0080Ti>C00<0VIVI08J6QP1lO7`06`00000O0?oooaX0000000<0XZ:R08f=S@1lO7`00P1dM7@01@1W
IfL0Fe]K04e=C@0b<S80?Cdm00@0_kno00T0^[Zj0<?3``2m_Kd0]KFe0;jn_P2_[jl0]KFe0:n_[`2]
[Jd00P2_[jl30:f][@0=0;6a/@2ZZZX0YjNW0:BTY02ZZZX0Y:BT0::RXP2IVIT0SHf=09VIV@2EUID0
Ng]k07alO00207AdM080KFe]00<0Fe]K06MWI`1hN7P00P2CTi<00`2IVIT0QXJ608J6QP0K000001l0
oooo6P0000000`2RXZ80SHf=07alO00207AdM00605EEE@1WIfL0CDe=038b<P0m?Cd0<S8b102o_kl0
2`2j^[X0`l?30;Fe]@2n_[h0]KFe0:n_[`2e]KD0[Jf]0:n_[`2][Jd0[jn_0080[Jf]00D0/K6a0:n_
[`2ZZZX0YjNW0:ZZZP020:BTY0090::RXP2IVIT0VIVI09FEU@22PX80Ng]k07alO01dM7@0GemO0080
KFe]00<0Fe]K07QhN02CTi<00P2CTi<00`2IVIT0QXJ607alO00K000002<0oooo000Q0?oooaP00000
0180kno_0:f][@2RXZ80SHf=06MWI`1]KFd0GemO05iNGP1WIfL0B4Q803dm?@18B4P0>SXj0<;2`P2o
_kl0^[Zj0;no_`2j^[X40;Fe]@080:n_[`2][Jd0[Jf]0:FUY@2WYjL0ZZZZ0:NWY`2][Jd20:ZZZP03
0::RXP2UYJD0XZ:R0080XZ:R0P2EUID0202IVIT0SHf=07alO01dM7@0LG5a06EUI@1dM7@0KFe]0P1O
Gel01P1fMWH0QHF509>CT`2=SHd0Ti>C08f=S@80O7al00<0N7Qh0000000000005`00000O0?oooaP0
000000l0kno_0:f][@2ATI40SHf=06MWI`1]KFd0GemO06MWI`1NGUh0B4Q803dm?@18B4P0`/;20;Jf
]P2o_kl00P2j^[X01@2e]KD0_Kfm0;Fe]@2e]KD0[jn_00<0[Jf]00P0YJFU0:ZZZP2WYjL0YjNW0:f]
[@2ZZZX0XZ:R0:FUY@<0XZ:R0P2EUID0102=SHd0VIVI08f=S@1dM7@2075aL@0906EUI@1]KFd0GemO
05mOG`1WIfL0MWIf09>CT`2=SHd0Ti>C0080SHf=00<0O7al07QhN00000006000000O0?oooaP00000
0180kno_0:f][@2RXZ80SHf=06MWI`1]KFd0GemO05iNGP1WIfL0B4Q803dm?@18B4P0>SXj0<;2`P2o
_kl0^[Zj0;no_`2j^[X40;Fe]@080:n_[`2][Jd0[Jf]0:FUY@2WYjL0ZZZZ0:NWY`2][Jd20:ZZZP03
0::RXP2UYJD0XZ:R0080XZ:R0P2EUID0202IVIT0SHf=07alO01dM7@0LG5a06EUI@1dM7@0KFe]0P1O
Gel01P1fMWH0QHF509>CT`2=SHd0Ti>C08f=S@80O7al00<0N7Qh0000000000005`00000S0?ooo`00
8@3ooolF00000080kno_00T0`/;20:b/[02FUYH0O7al06MWI`1]KFd0GemO079bLP1EEED00P0Z:RX2
03Xj>P040;no_`2j^[X0_Kfm0;Zj^P80]KFe102ZZZX00`2UYJD0XZ:R0:FUY@020::RXP<0VIVI0P2R
XZ8209VIV@80Shn?00P0SHf=08:2PP1hN7P0IfMW05mOG`1dM7@0IfMW07AdM080B4Q800X0EEEE079b
LP25QHD0QHF508f=S@2HV9P0XZ:R0:b/[02=SHd0O7al0P2=SHd00`2IVIT000000000000E000001l0
oooo5P0000020>o_k`090<;2`P2/[:`0SHf=07alO01WIfL0KFe]05mOG`1EEED0CDe=0080:RXZ00D0
>SXj0;no_`2d];@0^[Zj0;fm_@020;Fe]@090:f][@2ZZZX0ZZZZ0:ZZZP2UYJD0Y:BT0::RXP2UYJD0
XZ:R00@0VIVI00`0XZ:R09VIV@2IVIT0VIVI08n?S`2=SHd0PX:208f=S@1hN7P0IfMW07AdM01WIfL2
07AdM00304Q8B01EEED0LW9b0080QHF500H0SHf=09RHV02RXZ80VIVI0:b/[01lO7`208f=S@0309VI
V@000000000001D000007`3ooolF00000080kno_00T0`/;20:b/[02FUYH0O7al06MWI`1]KFd0GemO
079bLP1EEED00P0Z:RX203Xj>P040;no_`2j^[X0_Kfm0;Zj^P80]KFe102ZZZX00`2UYJD0XZ:R0:FU
Y@020::RXP<0VIVI0P2RXZ8209VIV@80Shn?00P0SHf=08:2PP1hN7P0IfMW05mOG`1dM7@0IfMW07Ad
M080B4Q800X0EEEE079bLP25QHD0QHF508f=S@2HV9P0XZ:R0:b/[02=SHd0O7al0P2=SHd00`2IVIT0
00000000000E000002<0oooo000Q0?oooaH0000000L0mOGe0=gMg@2h^;P0[:b/08f=S@1dM7@0KFe]
0080GemO00<0IfMW05EEE@0j>SX00P0m?Cd01P15ADD0];Bd0;6a/@2a/K40]KFe0;6a/@<0[Jf]00<0
Y:BT0:FUY@2UYJD00P2IVIT00`2ATI40UIFE09FEU@0209VIV@0:096AT@2IVIT0VIVI08n?S`2=SHd0
Shn?08f=S@1lO7`0M7Ad05EEE@80KFe]00D0IfMW04e=C@18B4P0<S8b06i^KP0208F5Q@0507QhN026
QXH0V9RH0:RXZ02_[jl00P2=SHd00`2HV9P0SHf=09VIV@0G000001l0oooo5@000000203/k>`0mOGe
0=gMg@2h^;P0[:b/08:2PP1dM7@0KFe]0P1OGel00`1EEED0ADE503Xj>P0203dm?@80];Bd0`2a/K40
102][Jd0/K6a0:f][@2][Jd20:FUY@<0VIVI0P2EUID00`2ATI40VIVI09VIV@0309VIV@0J08n?S`2=
SHd0SHf=07alO02CTi<0M7Ad05EEE@1]KFd0IfMW05mOG`1=CDd0<S8b06i^KP25QHD0LW9b08F5Q@26
QXH0V9RH0:RXZ02TY:@0[jn_08f=S@2HV9P0SHf=09VIV@2FUYHF000001l0oooo5P0000001`3emOD0
gMgM0;Rh^02/[:`0SHf=07AdM01]KFd00P1OGel00`1WIfL0EEEE03Xj>P0203dm?@0604E5A@2d];@0
/K6a0;6a/@2e]KD0/K6a0`2][Jd00`2TY:@0YJFU0:FUY@0209VIV@03096AT@2EUID0UIFE0080VIVI
00X0TI6A09VIV@2IVIT0Shn?08f=S@2?Shl0SHf=07alO01dM7@0EEEE0P1]KFd01@1WIfL0CDe=04Q8
B00b<S80KVi^0080QHF500D0N7Qh08J6QP2HV9P0Z:RX0:n_[`0208f=S@0309RHV02=SHd0VIVI01L0
00008`3oool00240oooo5@0000002@3bl_80k>c/0<[:bP2^[Zh0WinO08:2PP1]KFd0LG5a06MWI`02
05mOG`0303dm?@0j>SX0?Cdm0080?Cdm0P2d];@00`32`/80^;Rh0;Rh^0030;Fe]@070;6a/@2][Jd0
[Jf]09FEU@2=SHd0UIFE08Z:RP0308f=S@80UIFE0P2=SHd208:2PP0D07]kN`1lO7`0IfMW04a<C01W
IfL0M7Ad05EEE@15ADD0C4a<05]KF`1/K6`0QHF507alO025QHD0LW9b09RHV02RXZ80VIVI09JFUP2=
SHd2096AT@0308f=S@2/[:`0000001D000007`3ooolE0000000:0?Gem@3/k>`0b/[:0:j^[P2OWil0
PX:206e]K@1aLG40IfMW05mOG`80?Cdm00X0>SXj03dm?@0m?Cd0];Bd0;6a/@2d];@0`/;20;Rh^02e
]KD0^;Rh0P2e]KD20:f][@040:BTY02EUID0SHf=08Z:RP@0SHf=0100UIFE08f=S@2=SHd0SHf=08:2
PP1kNg/0O7al08f=S@1WIfL0C4a<07AdM01EEED0B4Q804E5A@1KFe/0K6a/0P25QHD01`1lO7`0LW9b
09RHV02RXZ80[:b/09VIV@2=SHd00P2ATI400`2=SHd0[:b/0000000E000001l0oooo5@0000002@3b
l_80k>c/0<[:bP2^[Zh0WinO08:2PP1]KFd0LG5a06MWI`0205mOG`0303dm?@0j>SX0?Cdm0080?Cdm
0P2d];@00`32`/80^;Rh0;Rh^0030;Fe]@070;6a/@2][Jd0[Jf]09FEU@2=SHd0UIFE08Z:RP0308f=
S@80UIFE0P2=SHd208:2PP0D07]kN`1lO7`0IfMW04a<C01WIfL0M7Ad05EEE@15ADD0C4a<05]KF`1/
K6`0QHF507alO025QHD0LW9b09RHV02RXZ80VIVI09JFUP2=SHd2096AT@0308f=S@2/[:`0000001D0
00008`3oool00240oooo5@000000303bl_80i^KV0<K6aP2/[:`0UYJF08:2PP1dM7@0IfMW07alO01N
GUh0GemO02LW9`80?Cdm00<0>SXj05ADE02d];@00`3;bl/20<S8b080`<3000D0^[Zj0;Rh^02h^;P0
[Jf]0:BTY00208Z:RP0308J6QP2:RXX0PX:20080PX:200@0SHf=08:2PP26QXH0O7al0P1dM7@04@1E
EED0EUIF06MWI`1NGUh0CDe=03dm?@1^KVh0CDe=06MWI`26QXH0O7al079bLP1lO7`0Ti>C0:BTY02a
/K40[:b/0080UYJF00<0PX:207QhN02/[:`05P00000O0?oooaD0000000`0l_;b0>KViP36a/H0[:b/
09JFUP1lO7`0M7Ad06MWI`1lO7`0GUiN02LW9`15ADD203dm?@0303Xj>P2d];@0alO70080bl_;0P38
b<P30<30`080^;Rh00D0/K6a0:f][@2TY:@0RXZ:08J6QP0208Z:RP80PX:200@0SHf=08Z:RP22PX80
QXJ60P1dM7@02`26QXH0EEEE05IFEP1NGUh0CDe=03Xj>P0m?Cd0CDe=06MWI`26QXH0QHF50080O7al
00@0Ti>C0:BTY02_[jl0/K6a0P2FUYH00`22PX80N7Qh0:b/[00F000001l0oooo5@000000303bl_80
i^KV0<K6aP2/[:`0UYJF08:2PP1dM7@0IfMW07alO01NGUh0GemO02LW9`80?Cdm00<0>SXj05ADE02d
];@00`3;bl/20<S8b080`<3000D0^[Zj0;Rh^02h^;P0[Jf]0:BTY00208Z:RP0308J6QP2:RXX0PX:2
0080PX:200@0SHf=08:2PP26QXH0O7al0P1dM7@04@1EEED0EUIF06MWI`1NGUh0CDe=03dm?@1^KVh0
CDe=06MWI`26QXH0O7al079bLP1lO7`0Ti>C0:BTY02a/K40[:b/0080UYJF00<0PX:207QhN02/[:`0
5P00000S0?ooo`008@3ooolD0000000C0?;blP3emOD0clo?0;Rh^02RXZ80TI6A08:2PP1OGel0IfMW
05mOG`1WIfL0CDe=038b<P15ADD0?Cdm03Xj>P27QhL0bl_;0=SHf0020=7Ad@@0bl_;0P30`<001`2m
_Kd0/K6a0:f][@2WYjL0VIVI08J6QP22PX800P26QXH0702:RXX0Ng]k08J6QP22PX80O7al07AdM01U
IFD0GemO06MWI`1lO7`0CDe=04E5A@19BDT0MWIf055AD@1WIfL0N7Qh07IfMP1bLW80O7al08f=S@2C
Ti<0/K6a0:b/[02RXZ80UYJF07alO02=SHd20::RXQD000007`3ooolD0000000D0?;blP3emOD0clo?
0;Rh^02RXZ80TI6A07UiN@1OGel0IfMW05mOG`1WIfL0<S8b04Q8B015ADD0?Cdm03Xj>P3;bl/0cLg=
0=SHf03AdM420<_;b`0Y0=7Ad@3;bl/0bl_;0<30`02m_Kd0^;Rh0;6a/@2][Jd0VIVI08J6QP1lO7`0
PX:208J6QP2:RXX0Ng]k08:2PP26QXH0PX:207AdM01UIFD0O7al05mOG`1WIfL0CDe=04E5A@0j>SX0
BDU9055AD@1WIfL0N7Qh08J6QP1fMWH0O7al08f=S@2CTi<0[jn_0;6a/@2RXZ80UYJF07alO02=SHd0
0P2RXZ8E000001l0oooo500000004`3bl_80mOGe0<o?c`2h^;P0XZ:R096AT@22PX80GemO06MWI`1O
Gel0IfMW04e=C@0b<S80ADE503dm?@0j>SX0QhN70<_;b`3Hf=P00P3AdM440<_;b`80`<3000L0_Kfm
0;6a/@2][Jd0YjNW09VIV@26QXH0PX:20080QXJ601`0RXZ:07]kN`26QXH0PX:207alO01dM7@0IFEU
05mOG`1WIfL0O7al04e=C@15ADD0BDU907IfMP1ADE40IfMW07QhN01fMWH0LW9b07alO02=SHd0Ti>C
0;6a/@2/[:`0XZ:R09JFUP1lO7`0SHf=0P2RXZ8E000002<0oooo000Q0?oooa<0000000d0l_;b0>o_
k`3emOD0clo?0:f][@2FUYH0SHf=07UiN@1dM7@0IfMW05mOG`1WIfL0<S8b00<0?Cdm00L0SXj>0<g=
c@3Cdm<0dm?C0=SHf03AdM40f=SH0080dM7A00T0bl_;0<S8b03;bl/0`<300;Rh^02e]KD0[Jf]0:ZZ
ZP2RXZ80101lO7`06@26QXH0PX:207alO01aLG40KFe]05IFEP1lO7`0GemO08f=S@15ADD0>SXj038b
<P1bLW80N7Qh05]KF`1hN7P0LW9b08f=S@1lO7`0SHf=0::RXP2m_Kd0`/;20:j^[P1hN7P00P2=SHd0
0`2ATI40XZ:R0:j^[P0D000001l0oooo4`0000001`3bl_80kno_0?Gem@3?cll0[Jf]09JFUP2=SHd0
0P1dM7@01@1WIfL0GemO06MWI`0m?Cd0C4a<0080?Cdm00@0SXj>0=?Cd`3Hf=P0dm?C0P3Hf=P00`3A
dM40dm?C0=7Ad@020<_;b`80`<3000D0^;Rh0;Fe]@2ZZZX0XZ:R09VIV@0307alO00I08J6QP1lO7`0
PX:207alO01]KFd0EUIF04e=C@1lO7`0GemO04E5A@0j>SX09bLW038b<P1hN7P0Fe]K07QhN02CTi<0
LW9b07alO02=SHd0XZ:R0:n_[`2m_Kd0[Zj^07QhN00208f=S@0309VIV@2RXZ80[Zj^01@000007`3o
oolC0000000=0?;blP3_knl0mOGe0<o?c`2][Jd0UYJF08f=S@1iNGT0M7Ad06MWI`1OGel0IfMW038b
<P0303dm?@0708j>SP3=cLd0dm?C0=?Cd`3Hf=P0dM7A0=SHf0020=7Ad@090<_;b`38b<P0bl_;0<30
`02h^;P0]KFe0:f][@2ZZZX0XZ:R00@0O7al01T0QXJ608:2PP1lO7`0LG5a06e]K@1FEUH0O7al05mO
G`2=SHd0ADE503Xj>P0b<S80LW9b07QhN01KFe/0N7Qh079bLP2=SHd0O7al08f=S@2RXZ80_Kfm0<;2
`P2^[Zh0N7Qh0080SHf=00<0TI6A0::RXP2^[Zh05000000S0?ooo`008@3ooolB0000000:0?Ogm`3e
mOD0k>c/0>WYj@2n_[h0UYJF08f=S@22PX80M7Ad06MWI`80GemO00P0?Cdm03Xj>P18B4P0PX:20=3@
d03Cdm<0bl_;0=?Cd`D0f=SH0P3AdM430<_;b`080;fm_@2o_kl0^[Zj0;Fe]@2d];@0Y:BT096AT@2I
VIT2075aL@0N06e]K@1aLG40IFEU05iNGP1BDU80QXJ607UiN@22PX80O7al03Xj>P18B4P0IfMW08J6
QP2=SHd0QXJ608f=S@1dM7@0TI6A08f=S@2FUYH0[:b/0;no_`2m_Kd0SHf=07alO02=SHd0UYJF0;Rh
^02m_Kd0]KFe4`00000O0?oooa80000000X0moOg0?Gem@3/k>`0c<c<0;jn_P2FUYH0SHf=08:2PP1U
IFD0IfMW0P1OGel01@0m?Cd0B4Q803dm?@22PX80d=3@00<0dm?C1@3Hf=P20=7Ad@80bl_;00P0`/;2
0;fm_@2o_kl0]KFe0;Bd]02][Jd0Y:BT096AT@80LG5a00h0M7Ad06e]K@1aLG40GUiN059BDP15ADD0
QXJ607UiN@1lO7`0>SXj02LW9`18B4P0QXJ608f=S@80QXJ600h0SHf=096AT@2=SHd0UYJF0::RXP2/
[:`0_Kfm08f=S@1lO7`0SHf=08J6QP2h^;P0_Kfm0;Fe]A<000007`3ooolB0000000:0?Ogm`3emOD0
k>c/0>WYj@2n_[h0UYJF08f=S@22PX80M7Ad06MWI`80GemO00P0?Cdm03Xj>P18B4P0PX:20=3@d03C
dm<0bl_;0=?Cd`D0f=SH0P3AdM430<_;b`080;fm_@2o_kl0^[Zj0;Fe]@2d];@0Y:BT096AT@2IVIT2
075aL@0N06e]K@1aLG40IFEU05iNGP1BDU80QXJ607UiN@22PX80O7al03Xj>P18B4P0IfMW08J6QP2=
SHd0QXJ608f=S@1dM7@0TI6A08f=S@2FUYH0[:b/0;no_`2m_Kd0SHf=07alO02=SHd0UYJF0;Rh^02m
_Kd0]KFe4`00000S0?ooo`008@3ooolA0000000B0>c/k03gmoL0l_;b0>c/k03MgMd0[Jf]09JFUP2=
SHd0O7al06e]K@1OGel0EEEE05mOG`0Z:RX0?Cdm04E5A@3;bl/0cLg=0`3Cdm<00`3Hf=P0dM7A0=SH
f0040=7Ad@040<_;b`38b<P0bl_;0<S8b080_Kfm02H0^[Zj0;Bd]02][Jd0Y:BT09VIV@2ATI40IfMW
075aL@1RHV80IfMW051@D01<C4`0KFe]0:BTY01EEED0VIVI06EUI@0j>SX0KVi^05IFEP2=SHd0KVi^
08J6QP2=SHd0QhN709JFUP22PX80V9RH0<;2`P3@d=00SHf=07alO02=SHd0WinO0::RXP2/[:`0[Zj^
0;fm_A8000007`3ooolA0000000B0>c/k03gmoL0l_;b0>c/k03<c<`0[Jf]09JFUP2=SHd0O7al05IF
EP1OGel0EEEE05mOG`0Z:RX0ADE505iNGP3;bl/0cLg=0`3Cdm<01@3Hf=P0dM7A0=7Ad@3AdM40f=SH
0080dM7A00`0b<S80<_;b`3;bl/0b<S80;fm_@2j^[X0];Bd0;6a/@2][Jd0Y:BT096AT@1WIfL2075a
L@0M069RHP1@D500C4a<038b<P1]KFd0Y:BT09VIV@1UIFD0M7Ad03Xj>P1FEUH0SHf=06i^KP25QHD0
QXJ608N7Q`2FUYH0PX:20:b/[02HV9P0d=3@08f=S@1lO7`0SHf=096AT@2RXZ80[:b/0:j^[P2m_Kd0
4P00000O0?oooa4000000180k>c/0?Ogm`3bl_80k>c/0=gMg@2][Jd0UYJF08f=S@1lO7`0KFe]05mO
G`1EEED0GemO02XZ:P0m?Cd0ADE50<_;b`3=cLd30=?Cd`030=SHf03AdM40f=SH00@0dM7A00@0bl_;
0<S8b03;bl/0b<S80P2m_Kd09P2j^[X0];Bd0:f][@2TY:@0VIVI096AT@1WIfL0LG5a069RHP1WIfL0
D51@04a<C01]KFd0Y:BT05EEE@2IVIT0IFEU03Xj>P1^KVh0EUIF08f=S@1^KVh0QXJ608f=S@27QhL0
UYJF08:2PP2HV9P0`/;20=3@d02=SHd0O7al08f=S@2OWil0XZ:R0:b/[02^[Zh0_Kfm4P00000S0?oo
o`008@3ooolA0000000B0?Ogm`3emOD0jNWY0>WYj@3?cll0WinO096AT@1iNGT0O7al06EUI@1OGel0
E5AD03dm?@0j>SX0D51@05YJFP3;bl/0c/k>0`3Cdm<00`3>c/h0bl_;0<_;b`020<_;b`060<S8b030
`<00`<300<;2`P38b<P0`l?30P2m_Kd05@2a/K40]KFe0;6a/@2][Jd0XZ:R09VIV@2EUID0GUiN06MW
I`1FEUH0EEEE03dm?@1FEUH0SHf=08:2PP1]KFd0WinO08:2PP1OGel0LG5a07QhN00208J6QP0?08f=
S@1WIfL0SHf=08f=S@2RXZ80[Jf]0;6a/@2m_Kd0SHf=07QhN02OWil0UYJF0:b/[02m_Kd0f=SH0180
00007`3oool@00000080moOg00P0mOGe0>WYj@3YjNT0c<c<09nOW`2ATI40NGUi07alO080GemO00L0
E5AD03dm?@0j>SX0FUYJ0<g=c@3;bl/0c/k>0080dm?C00<0dM7A0<k>cP3;bl/00`3;bl/04P38b<P0
`<300<;2`P38b<P0_kno0<?3``2m_Kd0/K6a0;Fe]@2d];@0/K6a0:f][@2IVIT0UIFE06MWI`1NGUh0
IfMW05EEE@80?Cdm00`0EUIF08f=S@1]KFd0WinO055AD@22PX80LG5a07QhN026QXH0LW9b08J6QP1W
IfL208f=S@80XZ:R00X0/K6a0;fm_@2=SHd0N7Qh08f=S@2FUYH0[:b/0;fm_@3Hf=P0k>c/4@00000O
0?oooa4000000180moOg0?Gem@3YjNT0jNWY0<o?c`2OWil0TI6A07UiN@1lO7`0IFEU05mOG`1DE5@0
?Cdm03Xj>P1@D500FUYJ0<_;b`3>c/h30=?Cd`030<k>cP3;bl/0bl_;0080bl_;00H0b<S80<30`030
`<00`/;20<S8b033`l<20;fm_@0E0;6a/@2e]KD0/K6a0:f][@2RXZ80VIVI09FEU@1NGUh0IfMW05IF
EP1EEED0?Cdm05IFEP2=SHd0PX:206e]K@2OWil0PX:205mOG`1aLG40N7Qh0080QXJ600l0SHf=06MW
I`2=SHd0SHf=0::RXP2][Jd0/K6a0;fm_@2=SHd0N7Qh09nOW`2FUYH0[:b/0;fm_@3Hf=P04P00000S
0?ooo`008@3ooolA00000080moOg00L0jNWY0=SHf03?cll0UYJF08:2PP1iNGT0IFEU0080GemO00L0
<S8b03dm?@0j>SX0>SXj0<g=c@3Cdm<0c/k>0080bl_;00<0dM7A0<?3``2m_Kd00P2h^;P20;6a/@04
0:f][@2a/K40/K6a0;6a/@<0^[Zj01P0_Kfm0;Zj^P2a/K40[Jf]0:NWY`2TY:@0XZ:R07]kN`1OGel0
E5AD059BDP15ADD0BDU906EUI@2IVIT0SHf=07YjNP26QXH0PX:204e=C@1bLW80SHf=08J6QP1bLW82
08:2PP060:BTY02RXZ80[:b/0<;2`P3:b/X0SHf=0P2FUYH0102ATI40[Jf]0;no_`3_knlB000001l0
oooo400000002P3emOD0moOg0?Ogm`3YjNT0f=SH0;Fe]@2FUYH0PX:207UiN@1UIFD205mOG`03038b
<P0m?Cd0>SXj0080cLg=00P0dm?C0<k>cP3;bl/0dM7A0<_;b`33`l<0_Kfm0;Rh^0<0/K6a00@0[Jf]
0;6a/@2a/K40/K6a0P2j^[X0602m_Kd0^[Zj0;6a/@2a/K40[Jf]0:BTY02RXZ80UIFE07]kN`1OGel0
DU9B04E5A@0m?Cd0BDU906EUI@2=SHd0NWYj0::RXP26QXH0CDe=079bLP2=SHd0QHF508J6QP80PX:2
00d0Y:BT09JFUP2RXZ80`/;20<[:bP2=SHd0UYJF0:BTY02ATI40[Jf]0;no_`3_knl0gMgM01400000
7`3ooolA00000080moOg00L0jNWY0=SHf03?cll0UYJF08:2PP1iNGT0IFEU0080GemO00L0<S8b03dm
?@0j>SX0>SXj0<g=c@3Cdm<0c/k>0080bl_;00<0dM7A0<?3``2m_Kd00P2h^;P20;6a/@040:f][@2a
/K40/K6a0;6a/@<0^[Zj01P0_Kfm0;Zj^P2a/K40[Jf]0:NWY`2TY:@0XZ:R07]kN`1OGel0E5AD059B
DP15ADD0BDU906EUI@2IVIT0SHf=07YjNP26QXH0PX:204e=C@1bLW80SHf=08J6QP1bLW8208:2PP06
0:BTY02RXZ80[:b/0<;2`P3:b/X0SHf=0P2FUYH0102ATI40[Jf]0;no_`3_knlB000002<0oooo000Q
0?oooa00000000L0moOg0?Gem@3emOD0jNWY0=GEe@3<c<`0UYJF0080O7al00X0LG5a05IFEP1DE5@0
>SXj03dm?@1@D500b/[:0=3@d03Cdm<0c/k>0P3;bl/01038b<P0^;Rh0;Fe]@2][Jd50:NWY`040:f]
[@2WYjL0/K6a0:f][@80^[Zj00X0_Kfm0;6a/@2][Jd0ZJVY0:BTY02IVIT0Shn?05iNGP1>CTh0C4a<
0P0m?Cd06P1SHf<0VIVI07UiN@1OGel0QXJ609RHV022PX80IfMW07AdM026QXH0O7al08f=S@22PX80
XZ:R0:b/[02RXZ80[:b/0<O7a`2/[:`0XZ:R09nOW`2RXZ80[Zj^0<;2`P3Vi^H0kno_4@00000O0?oo
oa00000000L0moOg0?Gem@3emOD0jNWY0=GEe@2^[Zh0UYJF0080O7al00H0LG5a05mOG`1DE5@0>SXj
03dm?@1@D5020=3@d0070=?Cd`3>c/h0bl_;0<S8b032`/80^;Rh0;Fe]@050:NWY`0;0:f][@2WYjL0
[Jf]0;6a/@2][Jd0^[Zj0;fm_@2d];@0/K6a0:f][@2TY:@00P2IVIT0502?Shl0GUiN04a<C00m?Cd0
:RXZ03dm?@1SHf<0NGUi05mOG`2YZJT0QXJ608:2PP1WIfL0M7Ad09>CT`26QXH0SHf=08:2PP2RXZ80
UYJF0P2/[:`01`37alL0[:b/0::RXP2OWil0XZ:R0:j^[P32`/800P3Vi^HA000001l0oooo40000000
1`3gmoL0mOGe0?Gem@3YjNT0eMGE0<c<c02FUYH00P1lO7`02P1aLG40EUIF05ADE00j>SX0?Cdm051@
D03:b/X0d=3@0=?Cd`3>c/h20<_;b`040<S8b02h^;P0]KFe0:f][@D0YjNW00@0[Jf]0:NWY`2a/K40
[Jf]0P2j^[X02P2m_Kd0/K6a0:f][@2YZJT0Y:BT09VIV@2?Shl0GUiN04i>CP1<C4`203dm?@0J06=S
H`2IVIT0NGUi05mOG`26QXH0V9RH08:2PP1WIfL0M7Ad08J6QP1lO7`0SHf=08:2PP2RXZ80[:b/0::R
XP2/[:`0alO70:b/[02RXZ80WinO0::RXP2^[Zh0`/;20>KViP3_knlA000002<0oooo000Q0?ooo`l0
00000`3gmoL04`3YjNT0gMgM0=GEe@2^[Zh0NWYj06e]K@1WIfL0GemO04a<C015ADD0?Cdm04a<C03B
d]80cLg=0<_;b`38b<P0c/k>0<_;b`2WYjL00P2NWYh01@3=cLd0`<300:NWY`2WYjL0`<300080WYjN
00P0VIVI096AT@29RHT0Y:BT0;6a/@2d];@0^[Zj0;Bd]080/K6a01/0ZJVY0:BTY02NWYh0Shn?08:2
PP19BDT0:RXZ02LW9`1FEUH0:RXZ0:VYZ@2a/K40[Zj^08:2PP2ZZZX0[:b/08f=S@2HV9P0KVi^08f=
S@22PX80SHf=09VIV@2TY:@0[Zj^0<;2`P3:b/X00P2FUYH01P2RXZ80[Jf]0>KViP3Vi^H0k>c/0>KV
iQ0000007`3oool?0000000@0?Ogm`3_knl0moOg0>WYj@3MgMd0eMGE09JFUP1jNWX0KFe]06MWI`1O
Gel0EUIF04E5A@0m?Cd0C4a<0=;BdP80bl_;00<0b<S80<k>cP3;bl/00`2NWYh05P3=cLd0YjNW0:NW
Y`2e]KD0`<3009jNWP2IVIT0TI6A08f=S@29RHT0Y:BT0;Bd]02j^[X0_Kfm0;Bd]02a/K40ZJVY0:BT
Y02IVIT0WYjN08n?S`19BDT202XZ:P0802LW9`1FEUH0ZJVY0;6a/@1WIfL0[Zj^0:ZZZP2/[:`208f=
S@0=09RHV02=SHd0PX:208f=S@2FUYH0VIVI0:j^[P32`/80b/[:09JFUP27QhL0XZ:R0:f][@020>KV
iP030>c/k03Vi^H0000000l000007`3oool?000000<0moOg01<0jNWY0=gMg@3EeMD0[Zj^07YjNP1]
KFd0IfMW05mOG`1<C4`0ADE503dm?@1<C4`0d];B0<g=c@3;bl/0b<S80<k>cP3;bl/0YjNW0080WYjN
00D0cLg=0<30`02WYjL0YjNW0<30`00209jNWP0809VIV@2ATI40RHV90:BTY02a/K40];Bd0;Zj^P2d
];@20;6a/@0K0:VYZ@2TY:@0WYjN08n?S`22PX80BDU902XZ:P0W9bL0EUIF02XZ:P2YZJT0/K6a0:j^
[P22PX80ZZZZ0:b/[02=SHd0V9RH06i^KP2=SHd0PX:208f=S@2IVIT0Y:BT0:j^[P32`/80b/[:0080
UYJF00H0XZ:R0:f][@3Vi^H0i^KV0>c/k03Vi^H@000002<0oooo000Q0?ooo`l000000`3gmoL02@3J
f]X0c<c<0:f][@2FUYH0NWYj05IFEP1OGel0EUIF05mOG`0203dm?@0408:2PP3@d=00d=3@0=3@d0<0
b<S800<0VIVI09jNWP2IVIT00`2EUID00`2NWYh0RHV907emO@020820P0050:NWY`2=SHd0OGem0:^[
Z`2h^;P00`2j^[X00`2a/K40ZJVY0:BTY00209VIV@0>08f=S@1iNGT0?Cdm01LG5`0j>SX0GUiN08N7
Q`2FUYH0SHf=0:b/[02=SHd0[jn_0<k>cP1lO7`208f=S@0307AdM022PX80UYJF0080XZ:R0P32`/82
09nOW`0309JFUP2][Jd0i^KV00<0jNWY4000000O0?ooo`l0000000`0moOg0?;blP3gmoL0f][J0<c<
c02][Jd0QhN707YjNP1FEUH0GemO05IFEP0b<S8203dm?@0408:2PP3@d=00d=3@0<_;b`<0b<S80P2N
WYh0102IVIT0UIFE09FEU@2NWYh208V9R@0307emO@20P800YjNW0080SHf=00<0OGem0;Rh^02j^[X0
0`2j^[X00`2YZJT0Y:BT0:BTY00209VIV@0807UiN@0m?Cd0?Cdm01LG5`0j>SX0QhN709JFUP22PX82
08f=S@0:0:n_[`3>c/h0SHf=07alO02=SHd0M7Ad08:2PP2HV9P0UYJF0::RXP80`/;200P0WinO09JF
UP2FUYH0[Jf]0>KViP3YjNT0kno_0>WYjA0000007`3oool?000000<0moOg00T0f][J0<c<c02][Jd0
UYJF07YjNP1FEUH0GemO05IFEP1OGel00P0m?Cd01022PX80d=3@0=3@d03@d=030<S8b00309VIV@2N
WYh0VIVI00<0UIFE00<0WYjN08V9R@1mOGd00P20P8001@2WYjL0SHf=07emO@2[Zj/0^;Rh00<0^[Zj
00<0/K6a0:VYZ@2TY:@00P2IVIT03P2=SHd0NGUi03dm?@0G5aL0>SXj05iNGP27QhL0UYJF08f=S@2/
[:`0SHf=0:n_[`3>c/h0O7al0P2=SHd00`1dM7@0PX:209JFUP020::RXP80`/;20P2OWil00`2FUYH0
[Jf]0>KViP030>WYjA0000008`3oool00240oooo3P000000303emOD0moOg0?Gem@3emOD0f=SH0<?3
``2RXZ80UYJF06EUI@1FEUH0GemO051@D080>SXj00`0GemO0=;BdP3Bd]80d=3@0<_;b`38b<P0YjNW
09jNWP1iNGT0GUiN07EeM@1iNGT207EeM@0:07emO@1NGUh0EeMG05]KF`1XJ6P0CDe=05]KF`1>CTh0
HV9R09jNWP80^[Zj0`2a/K40402TY:@0XZ:R0:BTY02?Shl0PX:205iNGP0G5aL0?Cdm04U9B@1JFUX0
SHf=05mOG`2YZJT0PX:20:BTY02o_kl209VIV@0=07IfMP2=SHd0PX:2096AT@22PX80[:b/0;fm_@32
`/80_[jn0:b/[02OWil0^;Rh0=gMg@020>c/k0030?Gem@3/k>`0000000h000007`3oool>0000000?
0?Gem@3gmoL0mOGe0?Gem@3Hf=P0`l?30::RXP1iNGT0IFEU05IFEP1OGel0D51@04Q8B00j>SX0GemO
0080d];B0P3;bl/04P38b<P0YjNW09jNWP1NGUh0J6QX07EeM@1iNGT0MGEe07emO@1_Kfl0GUiN05MG
E`1XJ6P0CDe=06IVIP1KFe/0CTi>09jNWP<0^[Zj0P2a/K420:BTY00Q0::RXP2TY:@0PX:205iNGP0P
82005aLG03dm?@1JFUX0SHf=0:VYZ@1OGel0PX:20:BTY02o_kl0c/k>09VIV@1fMWH0SHf=08:2PP2=
SHd0TI6A0:b/[02m_Kd0`/;20;jn_P2RXZ80WinO0;Rh^03MgMd0k>c/0>KViP3emOD0k>c/00l00000
7`3oool>0000000<0?Gem@3gmoL0mOGe0?Gem@3Hf=P0`l?30::RXP2FUYH0IFEU05IFEP1OGel0D51@
0P0j>SX0301OGel0d];B0=;BdP3@d=00bl_;0<S8b02WYjL0WYjN07UiN@1NGUh0MGEe07UiN@80MGEe
00X0OGem05iNGP1GEeL0Fe]K06QXJ01=CDd0Fe]K04i>CP1RHV80WYjN0P2j^[X30;6a/@0@0:BTY02R
XZ80Y:BT08n?S`22PX80GUiN01LG5`0m?Cd0BDU905YJFP2=SHd0GemO0:VYZ@22PX80Y:BT0;no_`80
VIVI00d0MWIf08f=S@22PX80TI6A08:2PP2/[:`0_Kfm0<;2`P2n_[h0[:b/09nOW`2h^;P0gMgM0080
k>c/00<0mOGe0>c/k00000003P00000S0?ooo`008@3oool>00000080mOGe00T0kno_0>WYj@3Hf=P0
_[jn09JFUP22PX80EUIF05iNGP1EEED00P1<C4`0401>CTh0d];B0=;BdP3=cLd0d=3@0=?Cd`38b<P0
`<300<S8b02WYjL0SHf=0820P029RHT0P82008V9R@2IVIT50820P0050:VYZ@2[Zj/0/K6a0;6a/@2j
^[X00P2e]KD0202a/K40]KFe0:f][@2TY:@0XZ:R09VIV@2?Shl0LG5a0P0G5aL02P0f=SH0FUYJ075a
L@2FUYH0KFe]0::RXP22PX80_kno0=3@d01iNGT208f=S@0308:2PP2=SHd0PX:20080[:b/00D0`/;2
0<O7a`2/[:`0XZ:R0=GEe@020>WYj@030>KViP3emOD0mOGe00l000007`3oool>000000<0mOGe00P0
jNWY0=SHf02n_[h0UYJF06EUI@1FEUH0GUiN05EEE@80C4a<00`0CTi>0=;BdP3Bd]80cLg=0=?Cd`3;
bl/0b<S80<30`038b<P0SHf=08V9R@20P80208V9R@0309VIV@20P800P82000<0P82000@0XZ:R0:VY
Z@2[Zj/0/K6a0P2j^[X30;Fe]@070:f][@2TY:@0Y:BT0::RXP2?Shl0LG5a03Hf=P0201LG5`0605YJ
FP1aLG40Y:BT09JFUP2RXZ80PX:20P2o_kl0103@d=00SHf=08f=S@22PX8208f=S@80[:b/00D0`/;2
0<O7a`2FUYH0XZ:R0=GEe@020>WYj@030>KViP3emOD0mOGe00l000007`3oool>00000080mOGe00T0
kno_0>WYj@3Hf=P0_[jn09JFUP22PX80EUIF05iNGP1EEED00P1<C4`0401>CTh0d];B0=;BdP3=cLd0
d=3@0=?Cd`38b<P0`<300<S8b02WYjL0SHf=0820P029RHT0P82008V9R@2IVIT50820P0050:VYZ@2[
Zj/0/K6a0;6a/@2j^[X00P2e]KD0202a/K40]KFe0:f][@2TY:@0XZ:R09VIV@2?Shl0LG5a0P0G5aL0
2P0f=SH0FUYJ075aL@2FUYH0KFe]0::RXP22PX80_kno0=3@d01iNGT208f=S@0308:2PP2=SHd0PX:2
0080[:b/00D0`/;20<O7a`2/[:`0XZ:R0=GEe@020>WYj@030>KViP3emOD0mOGe00l000008`3oool0
0240oooo3@0000005P3_knl0moOg0?Gem@3/k>`0i^KV0<o?c`2^[Zh0QhN706e]K@1NGUh0EEEE051@
D015ADD0C4a<05ADE03@d=00bl_;0=3@d03>c/h0bl_;0<S8b03>c/h20=?Cd`0:0=SHf03=cLd0bl_;
0=SHf03;bl/0b<S80=SHf03=cLd0bl_;0<;2`P80_Kfm0P2j^[X0102m_Kd0^[Zj0;Zj^P2h^;P20;6a
/@030:f][@2TY:@0XZ:R0080VIVI01T0PX:202PX:00;2`/0FUYJ04U9B@1JFUX0SHf=06MWI`2=SHd0
M7Ad08f=S@2o_kl0XZ:R09VIV@2=SHd0O7al08f=S@2IVIT0XZ:R09VIV@32`/80alO709nOW`2ATI40
gMgM00<0i^KV0`3gmoL>000001l0oooo3@0000005`3_knl0moOg0?Gem@3_knl0i^KV0<o?c`2^[Zh0
QhN706e]K@1NGUh0EEEE051@D015ADD0CDe=05ADE03@d=00bl_;0=3@d03;bl/0c/k>0<S8b03>c/h0
dm?C0080f=SH0180cLg=0<_;b`3;bl/0b<S80=?Cd`3Hf=P0cLg=0<;2`P2m_Kd0`/;20;fm_@2j^[X0
_Kfm0;Zj^P2m_Kd0^[Zj0;Rh^02a/K420:f][@0:0:BTY02RXZ80VIVI08:2PP1DE5@0:2PX00/;2`19
BDT0FUYJ075aL@80SHf=00H0M7Ad08f=S@2o_kl0_kno09VIV@2=SHd207alO00808f=S@2RXZ80VIVI
0<;2`P37alL0WinO096AT@3MgMd20>KViP040>WYj@3gmoL0moOg0?Ogm`h000007`3oool=0000000F
0>o_k`3gmoL0mOGe0>c/k03Vi^H0clo?0:j^[P27QhL0KFe]05iNGP1EEED0D51@04E5A@1<C4`0E5AD
0=3@d03;bl/0d=3@0<k>cP3;bl/0b<S80<k>cP80dm?C00X0f=SH0<g=c@3;bl/0f=SH0<_;b`38b<P0
f=SH0<g=c@3;bl/0`/;20P2m_Kd20;Zj^P040;fm_@2j^[X0^[Zj0;Rh^080/K6a00<0[Jf]0:BTY02R
XZ800P2IVIT06@22PX80:2PX00/;2`1JFUX0BDU905YJFP2=SHd0IfMW08f=S@1dM7@0SHf=0;no_`2R
XZ80VIVI08f=S@1lO7`0SHf=09VIV@2RXZ80VIVI0<;2`P37alL0WinO096AT@3MgMd00`3Vi^H30?Og
m`h000008`3oool00240oooo3@0000020?Gem@090>o_k`3emOD0clo?09nOW`22PX80IfMW06e]K@1B
DU80?Cdm00<0C4a<0P3@d=001P3=cLd0d=3@0=?Cd`3AdM40dm?C0=3@d0D0dm?C00L0d=3@0<_;b`38
b<P0b<S80;fm_@2o_kl0`l?30080_Kfm00@0b<S80;fm_@38b<P0_Kfm0P2h^;P01@2j^[X0/K6a0:f]
[@2][Jd0XZ:R0080VIVI00/0Shn?04E5A@0f=SH05aLG051@D01FEUH0IfMW07UiN@1WIfL0PX:207Yj
NP020;fm_@0<09VIV@2RXZ80SHf=07alO02=SHd0O7al0::RXP2/[:`0`/;209JFUP2TY:@0f=SH0P3V
i^H0103gmoL0mOGe0?Ogm`3gmoL>000001l0oooo3@0000020?Gem@090>o_k`3emOD0clo?09nOW`22
PX80IfMW051@D01BDU80?Cdm00<0C4a<0P3@d=001P3=cLd0d=3@0=7Ad@3AdM40dm?C0=3@d0D0dm?C
00T0bl_;0<S8b038b<P0b<S80;fm_@33`l<0_Kfm0<;2`P2m_Kd00P38b<P20;fm_@80^;Rh00d0/K6a
0:f][@2WYjL0[Jf]0::RXP2IVIT0Shn?06e]K@15ADD0=SHf051@D01FEUH0IFEU0080IfMW00H0PX:2
07YjNP2IVIT0_Kfm09VIV@2RXZ8208f=S@80O7al00H0XZ:R0:b/[032`/80[Jf]0:BTY03Hf=P20>KV
iP040=GEe@3emOD0moOg0?Ogm`h000007`3oool=00000080mOGe00T0kno_0?Gem@3?cll0WinO08:2
PP1WIfL0KFe]059BDP0m?Cd00`1<C4`20=3@d0060<g=c@3@d=00dm?C0=7Ad@3Cdm<0d=3@1@3Cdm<0
1`3@d=00bl_;0<S8b038b<P0_Kfm0;no_`33`l<00P2m_Kd01038b<P0_Kfm0<S8b02m_Kd20;Rh^005
0;Zj^P2a/K40[Jf]0:f][@2RXZ800P2IVIT02`2?Shl0ADE503Hf=P0G5aL0D51@05IFEP1WIfL0NGUi
06MWI`22PX80NWYj0080_Kfm00`0VIVI0::RXP2=SHd0O7al08f=S@1lO7`0XZ:R0:b/[032`/80UYJF
0:BTY03Hf=P20>KViP040?Ogm`3emOD0moOg0?Ogm`h000008`3oool00240oooo300000020?Ogm`80
mOGe00`0kno_0<?3``2FUYH0O7al06e]K@1@D500?Cdm04a<C00j>SX0C4a<051@D03@d=020<g=c@04
0=3@d03Cdm<0dm?C0=7Ad@H0dm?C0P38b<P20;fm_@060;Fe]@2j^[X0_kno0;fm_@33`l<0b<S80P30
`<008`3;bl/0_Kfm0;fm_@2h^;P0]KFe0:f][@2TY:@0XZ:R09jNWP2ATI40Shn?04U9B@0W9bL0:RXZ
04U9B@1SHf<0LG5a08N7Q`1]KFd0GUiN06EUI@2ATI40Z:RX0<S8b02/[:`0QXJ606e]K@2FUYH0SHf=
0:BTY02RXZ80`/;208f=S@3:b/X0eMGE0080jNWY00<0mOGe0?Ogm`3gmoL00P3gmoL=000001l0oooo
300000020?Ogm`80mOGe00`0clo?0<?3``2FUYH0O7al06e]K@1NGUh0?Cdm04a<C00j>SX0C4a<03dm
?@3@d=020<g=c@040=3@d03Cdm<0dm?C0=7Ad@<0dm?C0100d=3@0=?Cd`3Cdm<0b<S80;fm_@38b<P0
_Kfm0;Fe]@2o_kl0_Kfm0<30`033`l<0b<S80<30`03;bl/0b<S80P2m_Kd07`2e]KD0[Jf]0:f][@2T
Y:@0XZ:R096AT@2?Shl0O7al04U9B@0W9bL0BDU906=SH`1[Jf/0LG5a06e]K@1NGUh0IFEU09JFUP2A
TI40b<S80:b/[026QXH0TI6A06e]K@2=SHd0Y:BT0::RXP32`/80[Jf]0<[:bP3EeMD00`3YjNT40?Og
m`d000007`3oool<00000080moOg0P3emOD0303_knl0`l?309JFUP1lO7`0KFe]051@D00m?Cd0C4a<
03Xj>P1<C4`0D51@0=3@d080cLg=00@0d=3@0=?Cd`3Cdm<0dM7A1P3Cdm<20<S8b080_Kfm00H0]KFe
0;Zj^P2o_kl0_Kfm0<?3``38b<P20<30`00S0<_;b`2m_Kd0_Kfm0;Rh^02e]KD0[Jf]0:BTY02RXZ80
WYjN096AT@2?Shl0BDU902LW9`0Z:RX0BDU906=SH`1aLG40QhN706e]K@1NGUh0IFEU096AT@2XZ:P0
b<S80:b/[026QXH0KFe]09JFUP2=SHd0Y:BT0::RXP32`/80SHf=0<[:bP3EeMD00P3YjNT00`3emOD0
moOg0?Ogm`020?Ogm`d000008`3oool00240oooo300000020?Gem@80moOg00H0jNWY0:NWY`2FUYH0
KFe]06MWI`1UIFD204a<C00404U9B@1<C4`0?Cdm0<[:bP80cLg=0`3Cdm<00`3Hf=P0dm?C0=3@d002
0=?Cd`80bl_;00/0_Kfm0;6a/@2][Jd0];Bd0:f][@2a/K40^;Rh0;Zj^P33`l<0`/;20<S8b0020<_;
b`050<30`02m_Kd0^;Rh0;6a/@2][Jd00P2TY:@01@2RXZ80VIVI08Z:RP1NGUh0=SHf0080?Cdm01H0
FUYJ075aL@1UIFD0O7al05ADE01WIfL0[Zj^0;fm_@2RXZ80ZZZZ096AT@1jNWX0PX:208f=S@2OWil0
XZ:R0;no_`2FUYH0gMgM0<;2`P3emOD0jNWY1@3gmoL=000001l0oooo300000020?Gem@80moOg00H0
a/K60:NWY`2FUYH0KFe]06MWI`1>CTh204a<C00404U9B@1<C4`0QhN70<[:bP80cLg=0`3Cdm<00`3H
f=P0dm?C0=3@d0020=?Cd`80bl_;00X0/K6a0:f][@2h^;P0];Bd0:f][@2h^;P0^[Zj0;fm_@33`l<0
`/;20P3;bl/20<30`0040;fm_@2a/K40[Jf]0:f][@80Y:BT01`0VIVI08Z:RP1kNg/0GUiN03Hf=P0m
?Cd0FUYJ05IFEP1aLG40O7al05ADE01WIfL0EUIF0:j^[P2RXZ80ZZZZ096AT@2FUYH0NWYj08f=S@2O
Wil0XZ:R0;no_`2h^;P0gMgM0<;2`P3emOD0jNWY1@3gmoL=000001l0oooo300000020?Gem@80moOg
00H0jNWY0:NWY`2FUYH0KFe]06MWI`1UIFD204a<C00404U9B@1<C4`0?Cdm0<[:bP80cLg=0`3Cdm<0
0`3Hf=P0dm?C0=3@d0020=?Cd`80bl_;00/0_Kfm0;6a/@2][Jd0];Bd0:f][@2a/K40^;Rh0;Zj^P33
`l<0`/;20<S8b0020<_;b`050<30`02m_Kd0^;Rh0;6a/@2][Jd00P2TY:@01@2RXZ80VIVI08Z:RP1N
GUh0=SHf0080?Cdm01H0FUYJ075aL@1UIFD0O7al05ADE01WIfL0[Zj^0;fm_@2RXZ80ZZZZ096AT@1j
NWX0PX:208f=S@2OWil0XZ:R0;no_`2FUYH0gMgM0<;2`P3emOD0jNWY1@3gmoL=000002<0oooo000Q
0?ooo``0000000<0moOg0>o_k`3gmoL00P3emOD00`2FUYH0NGUi06EUI@0205IFEP80?Cdm0P1<C4`0
100j>SX0cLg=0<g=c@3AdM450=?Cd`050<k>cP3Cdm<0dm?C0<_;b`30`<000P2j^[X0102WYjL0[Jf]
0:BTY02YZJT20;6a/@030;fm_@33`l<0`<300080b<S800D0`<300<S8b02n_[h0^;Rh0;6a/@020:BT
Y00;0::RXP2ATI40Shn?069RHP0f=SH02`/;02@T9019BDT0KFe]05IFEP1lO7`00P1WIfL03@2YZJT0
SHf=0::RXP3>c/h0UYJF096AT@22PX80SXj>08f=S@2FUYH0_kno0;jn_P3<c<`00P3Hf=P00`3Bd]80
moOg0?Ogm`030?Ogm`d000007`3oool<0000000:0?Ogm`3_knl0moOg0?Gem@2o_kl0UYJF07UiN@1U
IFD0EUIF04a<C080?Cdm0P1<C4`0103:b/X0cLg=0<g=c@3AdM450=?Cd`070<k>cP3Cdm<0dm?C0<_;
b`30`<00^[Zj0:NWY`020:f][@060:BTY02a/K40/K6a0;Zj^P2m_Kd0`l?30`38b<P01@30`<00b<S8
0;Rh^02a/K40[Jf]0080Y:BT00X0TI6A08n?S`22PX80HV9R03Hf=P0T92@0BDU905ADE01]KFd0O7al
0P1WIfL01@1<C4`0ZJVY0::RXP3>c/h0UYJF0080TI6A00H0SXj>08f=S@2FUYH0_kno0;jn_P3<c<`2
0=SHf0030=;BdP3gmoL0moOg00<0moOg3@00000O0?ooo``0000000<0moOg0>o_k`3gmoL00P3emOD0
0`2FUYH0NGUi06EUI@0205IFEP80?Cdm0P1<C4`0100j>SX0cLg=0<g=c@3AdM450=?Cd`050<k>cP3C
dm<0dm?C0<_;b`30`<000P2j^[X0102WYjL0[Jf]0:BTY02YZJT20;6a/@030;fm_@33`l<0`<300080
b<S800D0`<300<S8b02n_[h0^;Rh0;6a/@020:BTY00;0::RXP2ATI40Shn?069RHP0f=SH02`/;02@T
9019BDT0KFe]05IFEP1lO7`00P1WIfL03@2YZJT0SHf=0::RXP3>c/h0UYJF096AT@22PX80SXj>08f=
S@2FUYH0_kno0;jn_P3<c<`00P3Hf=P00`3Bd]80moOg0?Ogm`030?Ogm`d000008`3oool00240oooo
300000040?Ogm`0<0>WYj@27QhL0IFEU05ADE01FEUH0?Cdm04E5A@1<C4`0CTi>03Xj>P0b<S80alO7
0P3;bl/00`3Cdm<0dM7A0=SHf0030=?Cd`030=7Ad@3Hf=P0VIVI0080bl_;00P0`<300;Fe]@1eMGD0
TI6A0:NWY`22PX80XZ:R0;fm_@80b<S80P3;bl/04@38b<P0`<300;fm_@2h^;P0]KFe0:f][@2TY:@0
XZ:R09VIV@2?Shl0LG5a04E5A@0G5aL092@T038b<P1FEUH0FUYJ0080KFe]00P0E5AD05iNGP2=SHd0
[jn_0::RXP2_[jl0SHf=06MWI`80PX:200H0XZ:R0;fm_@3YjNT0[Jf]0>WYj@2h^;P60?Ogm`d00000
7`3oool<000000@0moOg00`0[Zj^08N7Q`1UIFD0E5AD05IFEP1<C4`0ADE504a<C01>CTh0>SXj0<g=
c@37alL20<_;b`030=?Cd`3Hf=P0f=SH00<0dm?C00H0f=SH0:NWY`2IVIT0bl_;0<30`02e]KD207Ee
M@06096AT@22PX80XZ:R0;6a/@2m_Kd0b<S80`3;bl/01038b<P0`<300;Rh^02e]KD20:f][@0:0:BT
Y02IVIT0Shn?07]kN`1aLG40ADE502@T900b<S80BDU905IFEP80KFe]00H0E5AD06e]K@1NGUh0[jn_
0::RXP2_[jl208f=S@80PX:200H0XZ:R0;fm_@2n_[h0[Jf]0>WYj@2h^;P60?Ogm`d000007`3oool<
000000@0moOg00`0jNWY08N7Q`1UIFD0E5AD05IFEP0m?Cd0ADE504a<C01>CTh0>SXj038b<P37alL2
0<_;b`030=?Cd`3AdM40f=SH00<0dm?C00<0dM7A0=SHf02IVIT00P3;bl/02030`<00]KFe07EeM@2A
TI40YjNW08:2PP2RXZ80_Kfm0P38b<P20<_;b`0A0<S8b030`<00_Kfm0;Rh^02e]KD0[Jf]0:BTY02R
XZ80VIVI08n?S`1aLG40ADE501LG5`0T92@0<S8b05IFEP1JFUX00P1]KFd0201DE5@0GUiN08f=S@2_
[jl0XZ:R0:n_[`2=SHd0IfMW0P22PX801P2RXZ80_Kfm0>WYj@2][Jd0jNWY0;Rh^0H0moOg3@00000S
0?ooo`008@3oool<0000000<0>o_k`3gmoL0moOg0?Ogm`3Hf=P0IFEU069RHP0m?Cd0BDU9059BDP1<
C4`0DU9B0P0b<S80101lO7`0dM7A0=7Ad@3AdM440=SHf080dm?C00<0dM7A0=SHf03Hf=P00P3Hf=P0
203AdM40b<S80;Zj^P2j^[X0];Bd0;6a/@2][Jd0`<300P3;bl/00`3AdM40bl_;0<_;b`030<30`003
0;Zj^P2a/K40YjNW0080WYjN01T0Shn?07AdM01UIFD02`/;01lO7`0G5aL0EUIF06EUI@15ADD0KFe]
05ADE00b<S80UYJF08f=S@2/[:`0_kno08f=S@1iNGT0PX:208N7Q`2FUYH0[Zj^0<K6aP2n_[h0c<c<
00L0moOg3@00000O0?ooo``0000000`0kno_0?Ogm`3gmoL0moOg08f=S@1UIFD0HV9R03dm?@19BDT0
ADE504a<C01BDU82038b<P040<O7a`3AdM40dM7A0=7Ad@@0f=SH0P3Cdm<01P3Hf=P0cLg=0=SHf03H
f=P0dM7A0<S8b0<0^[Zj00H0/K6a0:f][@2][Jd0`<300<_;b`3AdM430<_;b`80`<3001h0^[Zj0;Fe
]@2a/K40YjNW09jNWP2?Shl0PX:207AdM01UIFD07alO01LG5`19BDT0EUIF04E5A@1]KFd0E5AD05mO
G`0b<S80SHf=0:b/[02o_kl0PX:208f=S@22PX80QhN709JFUP2^[Zh0a/K60;jn_P3<c<`20?Ogm`03
0?Gem@3gmoL0moOg0080moOg3@00000O0?ooo``0000000`0kno_0?Ogm`3gmoL0moOg0=SHf01UIFD0
HV9R03dm?@19BDT0DU9B04a<C01BDU82038b<P0407alO03AdM40dM7A0=7Ad@@0f=SH0P3Cdm<00`3A
dM40f=SH0=SHf0020=SHf0080=7Ad@38b<P0^[Zj0;Zj^P2d];@0/K6a0:f][@30`<020<_;b`030=7A
d@3;bl/0bl_;00<0`<3000<0^[Zj0;6a/@2WYjL00P2NWYh06@2?Shl0M7Ad06EUI@0;2`/07alO01LG
5`1FEUH0IFEU04E5A@1]KFd0E5AD038b<P2FUYH0SHf=0:b/[02o_kl0SHf=07UiN@22PX80QhN709JF
UP2^[Zh0a/K60;jn_P3<c<`01`3gmoL=000002<0oooo000Q0?ooo``000000P3emOD01P3gmoL0mOGe
0=;BdP1NGUh0GemO05ADE080C4a<00D0EUIF04Q8B00Z:RX0=SHf0<[:bP020=?Cd`H0f=SH00h0dM7A
0<_;b`3Hf=P0f=SH0>?Sh`3Hf=P0dM7A0<_;b`2h^;P0]KFe0;Bd]02a/K40[Jf]0<30`080bl_;00<0
c/k>0<_;b`3;bl/00P38b<P20<30`00B0;Fe]@2][Jd0YjNW09VIV@2ATI40M7Ad05mOG`0Z:RX00000
01lO7`0Z:RX0IfMW05ADE01]KFd0B4Q805iNGP1iNGT0TI6A0P2ZZZX00`22PX80SHf=07UiN@0208:2
PP040:f][@2h^;P0d];B0?Gem@H0moOg00<0mOGe0000000000002`00000O0?ooo``000000P3emOD0
3@3gmoL0mOGe07UiN@1NGUh0GemO05ADE01<C4`0D51@05IFEP18B4P0:RXZ03Hf=P3=cLd00P3Cdm<6
0=SHf00D0=7Ad@3Hf=P0f=SH0=SHf03Shn<0dM7A0<_;b`32`/80^;Rh0;Fe]@2a/K40[Jf]0;Rh^030
`<00bl_;0<k>cP3;bl/0dM7A0<_;b`38b<P20<30`00B0;Rh^02e]KD0[Jf]09VIV@2ATI40PX:207Ad
M01OGel0000001lO7`15ADD0:RXZ05ADE01]KFd0B4Q805ADE01NGUh0TI6A0P2ZZZX00`2RXZ80PX:2
07UiN@0208:2PP040:f][@37alL0d];B0?Gem@H0moOg00<0mOGe0000000000002`00000O0?ooo``0
00000P3emOD01P3gmoL0mOGe0=;BdP1NGUh0GemO05ADE080C4a<00D0EUIF04Q8B00Z:RX0=SHf0<[:
bP020=?Cd`H0f=SH00h0dM7A0<_;b`3Hf=P0f=SH0>?Sh`3Hf=P0dM7A0<_;b`2h^;P0]KFe0;Bd]02a
/K40[Jf]0<30`080bl_;00<0c/k>0<_;b`3;bl/00P38b<P20<30`00B0;Fe]@2][Jd0YjNW09VIV@2A
TI40M7Ad05mOG`0Z:RX0000001lO7`0Z:RX0IfMW05ADE01]KFd0B4Q805iNGP1iNGT0TI6A0P2ZZZX0
0`22PX80SHf=07UiN@0208:2PP040:f][@2h^;P0d];B0?Gem@H0moOg00<0mOGe0000000000002`00
000S0?ooo`008@3oool<000000<0moOg00@0kno_09JFUP1UIFD0?Cdm0P15ADD204a<C00601lO7`0b
<S807alO0<_;b`3Bd]80dM7A1`3Hf=P20=?Cd`<0f=SH00P0dm?C0<_;b`2[Zj/0[Jf]0;6a/@2[Zj/0
];Bd0<_;b`80cLg=0140d=3@0=?Cd`3;bl/0b<S80<_;b`38b<P0`<300;Fe]@2a/K40[Jf]0::RXP2A
TI40NGUi075aL@19BDT01`L701LG5`0205IFEP0C05iNGP1UIFD0C4a<04U9B@1aLG40SHf=09VIV@2a
/K40O7al08:2PP1aLG40PX:209JFUP2o_kl0WinO0<c<c03gmoL0mOGe0?Ogm`020?Gem@<0moOg3@00
000O0?ooo``000000`3gmoL0103_knl0IFEU06EUI@0m?Cd204E5A@08059BDP1<C4`07alO038b<P0O
7al0dM7A0=;BdP3AdM470=SHf00@0=?Cd`3AdM40f=SH0=SHf03Cdm<0bl_;0;Rh^02[Zj/0[Jf]0:^[
Z`2d];@0_Kfm0<_;b`3=cLd0d=3@0=?Cd`80bl_;0P38b<P08030`<00^;Rh0;Fe]@2a/K40XZ:R096A
T@22PX80NGUi075aL@071`L05aLG03Hf=P1FEUH0GUiN06EUI@1<C4`0E5AD04U9B@2=SHd0VIVI0;6a
/@32`/80O7al075aL@22PX80UYJF0;no_`37alL0c<c<0?Ogm`3emOD0moOg0P3emOD30?Ogm`d00000
7`3oool<000000<0moOg00@0kno_09JFUP1UIFD0?Cdm0P15ADD204a<C00601lO7`0b<S807alO0<_;
b`3Bd]80dM7A1`3Hf=P20=?Cd`<0f=SH00P0dm?C0<_;b`2[Zj/0[Jf]0;6a/@2[Zj/0];Bd0<_;b`80
cLg=0140d=3@0=?Cd`3;bl/0b<S80<_;b`38b<P0`<300;Fe]@2a/K40[Jf]0::RXP2ATI40NGUi075a
L@19BDT01`L701LG5`0205IFEP0C05iNGP1UIFD0C4a<04U9B@1aLG40SHf=09VIV@2a/K40O7al08:2
PP1aLG40PX:209JFUP2o_kl0WinO0<c<c03gmoL0mOGe0?Ogm`020?Gem@<0moOg3@00000S0?ooo`00
8@3oool;000000@0moOg00D0l_;b08V9R@1@D500?Cdm05IFEP02059BDP0501LG5`0Z:RX09bLW03Hf
=P3;bl/02P3Hf=P20=7Ad@060=SHf03AdM40cLg=0<30`02[Zj/0/K6a0P2d];@05`2m_Kd0bl_;0<_;
b`3=cLd0dM7A0=?Cd`3AdM40bl_;0<S8b03;bl/0`<300;Rh^02e]KD0ZJVY0:f][@2IVIT0NGUi06e]
K@1FEUH02`/;02PX:015ADD0BDU90080E5AD00h0IfMW05ADE01jNWX0SHf=09RHV02a/K40PX:207al
O01]KFd0NWYj08N7Q`2][Jd0c<c<0?Gem@T0moOg3000000O0?ooo`/00000103gmoL0303bl_80IFEU
051@D00m?Cd0EUIF059BDP1<C4`05aLG02XZ:P0W9bL0=SHf0=?Cd`T0f=SH00/0dM7A0=;BdP3AdM40
f=SH0<g=c@30`<00_Kfm0:^[Z`2a/K40];Bd0;fm_@030<_;b`040=7Ad@3Cdm<0cLg=0=7Ad@80bl_;
0P30`<002`2h^;P0]KFe0:f][@2IVIT0Shn?07UiN@1]KFd02`/;02PX:00Z:RX0ADE50080E5AD00h0
IfMW05ADE01DE5@0SHf=09RHV02a/K40c/k>08:2PP1]KFd0NWYj08N7Q`2][Jd0a/K60?Gem@T0moOg
3000000O0?ooo`/00000103gmoL01@3bl_80RHV9051@D00m?Cd0EUIF0080DU9B00D05aLG02XZ:P0W
9bL0=SHf0<_;b`0:0=SHf080dM7A00H0f=SH0=7Ad@3=cLd0`<300:^[Z`2a/K420;Bd]00G0;fm_@3;
bl/0bl_;0<g=c@3AdM40dm?C0=7Ad@3;bl/0b<S80<_;b`30`<00^;Rh0;Fe]@2YZJT0[Jf]09VIV@1i
NGT0KFe]05IFEP0;2`/0:2PX04E5A@19BDT00P1DE5@03P1WIfL0E5AD07YjNP2=SHd0V9RH0;6a/@22
PX80O7al06e]K@1jNWX0QhN70:f][@3<c<`0mOGe2@3gmoL<000002<0oooo000Q0?ooo`/000001@3e
mOD02`29RHT0C4a<04a<C01FEUH0BDU904a<C00Z:RX07alO02XZ:P2][Jd0d=3@00D0f=SH0P3QhN44
0=SHf00<0<g=c@3Hf=P0f=SH0<_;b`30`<00];Bd0;6a/@2j^[X0_Kfm0<;2`P3@d=00cLg=0P3AdM40
0`3Hf=P0dM7A0<g=c@020<_;b`0L0<30`02m_Kd0];Bd0:f][@2TY:@0XZ:R07]kN`1]KFd0IFEU01lO
7`071`L0:RXZ05IFEP1NGUh0C4a<05mOG`1DE5@0LG5a09nOW`2RXZ80[jn_07UiN@2ATI40GUiN08N7
Q`1iNGT0_Kfm0<c<c0X0moOg3000000O0?ooo`/000001@3emOD02`1OGel0C4a<04a<C01FEUH0BDU9
059BDP0Z:RX07alO02XZ:P2][Jd0d=3@00@0f=SH0`3QhN430=SHf0050=?Cd`3=cLd0f=SH0<_;b`30
`<000P2d];@03@2a/K40_Kfm0<;2`P3;bl/0d=3@0<g=c@3AdM40f=SH0=;BdP3AdM40cLg=0<_;b`30
`<000P2m_Kd06@2d];@0Y:BT0::RXP2?Shl0Ng]k06e]K@0O7al01`L7038b<P0Z:RX0GUiN04a<C01O
Gel0IfMW05ADE02OWil0XZ:R0:n_[`3>c/h0NGUi05iNGP27QhL0NGUi0;fm_@3?cll02P3gmoL<0000
01l0oooo2`0000050?Gem@0;08V9R@1<C4`0C4a<05IFEP19BDT0C4a<02XZ:P0O7al0:RXZ0:f][@3@
d=001@3Hf=P20>7Qh@@0f=SH00`0cLg=0=SHf03Hf=P0bl_;0<30`02d];@0/K6a0;Zj^P2m_Kd0`/;2
0=3@d03=cLd20=7Ad@030=SHf03AdM40cLg=0080bl_;01`0`<300;fm_@2d];@0[Jf]0:BTY02RXZ80
Ng]k06e]K@1UIFD07alO00L71`0Z:RX0EUIF05iNGP1<C4`0GemO05ADE01aLG40WinO0::RXP2_[jl0
NGUi096AT@1NGUh0QhN707UiN@2m_Kd0c<c<2P3gmoL<000002<0oooo000Q0?ooo`/00000103gmoL0
101aLG40GemO038b<P1FEUH204U9B@05059BDP0m?Cd0=SHf0<_;b`3=cLd00`3Hf=P20>7Qh@80f=SH
00<0hN7Q0=SHf03Hf=P00P3Hf=P0203Bd]80f=SH0=SHf03Hf=P0dM7A0;Bd]02m_Kd0_kno0P32`/80
0`3@d=00f=SH0=;BdP020=SHf00>0=7Ad@3Bd]80d];B0=;BdP3=cLd0`/;20;fm_@2d];@0/K6a0:BT
Y02:RXX0Ng]k069RHP19BDT203dm?@0705IFEP1DE5@0IfMW06EUI@1`L700RHV90:BTY0020::RXP06
096AT@1bLW80D51@07YjNP2FUYH0[Zj^2`3gmoL<000001l0oooo2`0000040?Ogm`04075aL@1DE5@0
<S8b05IFEP80BDU900D0:RXZ03dm?@0f=SH0bl_;0<g=c@030=SHf080hN7Q0P3Hf=P00`3QhN40f=SH
0=SHf0020=SHf0070=;BdP3Hf=P0f=SH0=7Ad@2m_Kd0];Bd0;fm_@020<;2`P030<O7a`3@d=00f=SH
00<0f=SH00d0dM7A0=;BdP3Bd]80cLg=0<_;b`32`/80_Kfm0;6a/@2TY:@0XZ:R08Z:RP1kNg/0BDU9
00<0?Cdm00H0E5AD06MWI`1UIFD0GUiN071`L02TY:@20::RXP070:b/[02ATI40D51@07YjNP2FUYH0
[Zj^0=gMg@0:0?Ogm``000007`3oool;000000@0moOg00@0LG5a05mOG`0b<S80EUIF0P19BDT01@1B
DU80?Cdm03Hf=P3;bl/0cLg=00<0f=SH0P3QhN420=SHf0030>7Qh@3Hf=P0f=SH0080f=SH00P0d];B
0=SHf03Hf=P0f=SH0=7Ad@2d];@0_Kfm0;no_`80`/;200<0d=3@0=SHf03Bd]800P3Hf=P03P3AdM40
d];B0=;BdP3Bd]80cLg=0<;2`P2m_Kd0];Bd0;6a/@2TY:@0RXZ:07]kN`1RHV80BDU90P0m?Cd01`1F
EUH0E5AD06MWI`1UIFD0L71`08V9R@2TY:@00P2RXZ801P2ATI40LW9b051@D01jNWX0UYJF0:j^[P/0
moOg3000000S0?ooo`008@3oool;00000080moOg00d0mOGe0?Ogm`1iNGT0IfMW03dm?@1NGUh0EUIF
04a<C015ADD0:RXZ08B4Q03AdM40d];B0080f=SH0P3QhN450=SHf080hN7Q103Hf=P20=7Ad@80];Bd
00<0_kno0<;2`P3;bl/00`3Bd]820=SHf00E0=7Ad@3Hf=P0dm?C0=3@d03=cLd0bl_;0<;2`P2d];@0
/K6a0:VYZ@2?Shl0Ng]k069RHP1FEUH0<S8b03dm?@19BDT0DU9B06EUI@1WIfL0GemO00@0XZ:R00H0
[:b/07AdM01dM7@0NGUi08N7Q`2_[jl;0?Ogm``000007`3oool;00000080moOg00d0mOGe0?Ogm`1i
NGT0BDU903dm?@1NGUh0EUIF04a<C00m?Cd0:RXZ08B4Q03AdM40d];B0080f=SH0P3QhN450=SHf003
0>7Qh@3Hf=P0f=SH0080f=SH0P3AdM40102m_Kd0];Bd0;Bd]032`/820<_;b`80d];B0P3Hf=P20=7A
d@030=SHf03@d=00cLg=0080bl_;00L0`/;20;6a/@2YZJT0XZ:R08n?S`1kNg/0EUIF0080<S8b00H0
?Cdm059BDP1UIFD0IfMW06EUI@1OGel30::RXP070:VYZ@2/[:`0M7Ad07UiN@27QhL0[jn_0>c/k00:
0?Ogm``000007`3oool;00000080moOg00d0mOGe0?Ogm`1iNGT0IfMW03dm?@1NGUh0EUIF04a<C015
ADD0:RXZ08B4Q03AdM40d];B0080f=SH0P3QhN450=SHf080hN7Q103Hf=P20=7Ad@80];Bd00<0_kno
0<;2`P3;bl/00`3Bd]820=SHf00E0=7Ad@3Hf=P0dm?C0=3@d03=cLd0bl_;0<;2`P2d];@0/K6a0:VY
Z@2?Shl0Ng]k069RHP1FEUH0<S8b03dm?@19BDT0DU9B06EUI@1WIfL0GemO00@0XZ:R00H0[:b/07Ad
M01dM7@0NGUi08N7Q`2_[jl;0?Ogm``000008`3oool00240oooo2`0000030?Ogm`0<0?Gem@1aLG40
LG5a04U9B@15ADD0EUIF059BDP0b<S80EUIF0<g=c@3Cdm<0d];B1`3Hf=P00`3Bd]80f=SH0=SHf003
0=SHf0070<g=c@3Hf=P0f=SH0=SHf02h^;P0];Bd0;fm_@020<;2`P040<g=c@3Bd]80d];B0=;BdP80
f=SH00D0d];B0<g=c@3=cLd0bl_;0<O7a`020<;2`P070;Bd]02YZJT0VIVI08:2PP1]KFd0EUIF04E5
A@0203dm?@0:05IFEP1OGel0Hf=S051@D02^[Zh0XZ:R09JFUP2TY:@0/K6a05mOG`80NGUi00<0PX:2
0:b/[03gmoL02P3gmoL<000001l0oooo2`0000030?Ogm`0<0?Gem@1aLG40EUIF04U9B@15ADD0EUIF
059BDP15ADD0EUIF0<g=c@3Cdm<0d];B1`3Hf=P00`3Bd]80f=SH0=SHf0030=SHf0060<g=c@3Hf=P0
f=SH0<;2`P2h^;P0];Bd0P32`/808037alL0cLg=0=;BdP3Bd]80f=SH0=;BdP3Hf=P0d];B0<g=c@3;
bl/0cLg=0<O7a`32`/80];Bd0:VYZ@2TY:@0VIVI08:2PP1FEUH0ADE503Xj>P0m?Cd0EUIF05mOG`1S
Hf<0EUIF051@D02RXZ80UYJF0:BTY02OWil0/K6a0P1iNGT00`22PX80[:b/0>o_k`0:0?Ogm``00000
7`3oool;000000<0moOg00`0mOGe075aL@1aLG40BDU904E5A@1FEUH0DU9B038b<P1FEUH0cLg=0=?C
d`3Bd]870=SHf0030=;BdP3Hf=P0f=SH00<0f=SH00L0cLg=0=SHf03Hf=P0f=SH0;Rh^02d];@0_Kfm
0080`/;200@0cLg=0=;BdP3Bd]80d];B0P3Hf=P01@3Bd]80cLg=0<g=c@3;bl/0alO70080`/;200L0
];Bd0:VYZ@2IVIT0PX:206e]K@1FEUH0ADE50080?Cdm00X0EUIF05mOG`1SHf<0D51@0:j^[P2RXZ80
UYJF0:BTY02a/K40GemO0P1iNGT00`22PX80[:b/0?Ogm`0:0?Ogm``000008`3oool00240oooo2`00
00003P3gmoL0mOGe0?Ogm`2^[Zh0GemO06=SH`1NGUh0E5AD05IFEP0m?Cd0=SHf0<O7a`3Hf=P0cLg=
103Hf=P0103QhN40f=SH0=SHf03Hf=P20<g=c@80d];B00<0f=SH0=7Ad@3Cdm<00`3Hf=P02@2h^;P0
/K6a0;Bd]02f][H0_kno0<[:bP3?cll0cLg=0=SHf0020=;BdP030<g=c@3:b/X0cLg=0080bl_;0P32
`/801`2f][H0/K6a09jNWP2?Shl0KFe]05mOG`19BDT00P0m?Cd01P19BDT0KFe]05iNGP1NGUh0WinO
09JFUP80XZ:R00H0_Kfm04e=C@1]KFd0SHf=09JFUP2][Jd;0?Ogm``000007`3oool;0000000>0?Og
m`3emOD0moOg0:j^[P1OGel0E5AD05iNGP1DE5@0EUIF03dm?@15ADD0alO70=SHf03=cLd40=SHf004
0>7Qh@3Hf=P0f=SH0=;BdP80cLg=00D0d];B0=SHf03Hf=P0dM7A0=?Cd`020=SHf0090<_;b`2h^;P0
/K6a0;Jf]P2o_kl0][Jf0<[:bP3?cll0f=SH00<0d];B0P3=cLd30<_;b`0<0<;2`P2f][H0/K6a0:VY
Z@2NWYh0Shn?05mOG`19BDT0:RXZ03dm?@19BDT0KFe]0`1NGUh02@2FUYH0XZ:R0::RXP1]KFd0_Kfm
06e]K@2=SHd0UYJF0:f][@0;0?Ogm``000007`3oool;0000000>0?Ogm`3emOD0moOg0:j^[P1OGel0
Hf=S05iNGP1DE5@0EUIF03dm?@0f=SH0alO70=SHf03=cLd40=SHf0040>7Qh@3Hf=P0f=SH0=SHf080
cLg=0P3Bd]800`3Hf=P0dM7A0=?Cd`030=SHf0090;Rh^02a/K40];Bd0;Jf]P2o_kl0b/[:0<o?c`3=
cLd0f=SH0080d];B00<0cLg=0<[:bP3=cLd00P3;bl/20<;2`P070;Jf]P2a/K40WYjN08n?S`1]KFd0
GemO04U9B@0203dm?@0604U9B@1]KFd0GUiN05iNGP2OWil0UYJF0P2RXZ801P2m_Kd0CDe=06e]K@2=
SHd0UYJF0:f][@/0moOg3000000S0?ooo`008@3oool;000000050?Ogm`3emOD0moOg07moO`2>SXh0
0P1]KFd01`19BDT0EUIF038b<P19BDT0alO70=7Ad@37alL01P3Hf=P20=;BdP070<O7a`3;bl/0bl_;
0<g=c@3Bd]80d=3@0=?Cd`030=SHf0030;Fe]@2a/K40Zj^[0080];Bd00<0b/[:0<g=c@3Bd]801P37
alL04P3;bl/0alO70<O7a`2h^;P0_kno0;6a/@2RXZ80Shn?07UiN@1OGel0DU9B02LW9`0m?Cd0BDU9
05iNGP1WIfL0GUiN09nOW`80VIVI00L0XZ:R0:n_[`1RHV80GUiN08V9R@2YZJT0alO70080moOg00<0
mOGe0?Ogm`3gmoL01P3gmoL<000001l0oooo2`000000403gmoL0mOGe0?Ogm`1oOgl0SXj>04U9B@1]
KFd0BDU905IFEP0b<S80C4a<0<O7a`3AdM40alO70=SHf03QhN440=SHf0030=;BdP30`<00alO70080
bl_;00@0d];B0=SHf03@d=00dm?C0P3Hf=P00`3;bl/0]KFe0;6a/@020;Bd]0030<;2`P3:b/X0cLg=
0080alO700H0`/;20<O7a`37alL0alO70<_;b`3=cLd20<O7a`0<0;no_`2a/K40ZJVY0::RXP2?Shl0
GemO059BDP0Z:RX09bLW04U9B@1NGUh0IfMW0P1NGUh209VIV@070::RXP1BDU80[jn_05iNGP29RHT0
ZJVY0<O7a`020?Ogm`030?Gem@3gmoL0moOg00H0moOg3000000O0?ooo`/0000000D0moOg0?Gem@3g
moL0Ogmo08j>SP0206e]K@0704U9B@1FEUH0<S8b04U9B@37alL0dM7A0<O7a`060=SHf080d];B00L0
alO70<_;b`3;bl/0cLg=0=;BdP3@d=00dm?C00<0f=SH00<0]KFe0;6a/@2[Zj/00P2d];@00`3:b/X0
cLg=0=;BdP060<O7a`0B0<_;b`37alL0alO70;Rh^02o_kl0/K6a0::RXP2?Shl0NGUi05mOG`1BDU80
9bLW03dm?@19BDT0GUiN06MWI`1NGUh0WinO0P2IVIT01`2RXZ80[jn_069RHP1NGUh0RHV90:VYZ@37
alL00P3gmoL00`3emOD0moOg0?Ogm`060?Ogm``000008`3oool00240oooo2`0000020?Ogm`030?oo
o`1]KFd0O7al0080EUIF00L0HV9R02LW9`1DE5@0DU9B09VIV@2][Jd0d=3@00<0f=SH00L0d];B0<[:
bP2f][H0UYJF08j>SP2ZZZX0UYJF0080][Jf00<0d];B0<g=c@3=cLd00`3Hf=P02`2d];@0Y:BT09nO
W`2TY:@0_kno0<[:bP2j^[X0][Jf0:VYZ@2NWYh0SXj>00<0WinO00<0ZZZZ0<;2`P2f][H00P2f][H0
1`2a/K40WinO096AT@22PX80HV9R05IFEP0m?Cd00P0b<S801@1FEUH0E5AD05iNGP29RHT0SHf=0080
PX:200H0_Kfm05mOG`1FEUH0WinO0::RXP3Hf=P;0?Ogm``000007`3oool;00000080moOg00`0oooo
06e]K@1lO7`0GUiN05IFEP1RHV809bLW05ADE03AdM40VIVI0:f][@3@d=030=SHf0080=;BdP3:b/X0
][Jf08j>SP2[Zj/0ZZZZ09JFUP2f][H20=;BdP80cLg=0P3Hf=P0303;bl/0];Bd0:BTY02TY:@0_kno
0;Jf]P3:b/X0^[Zj0:VYZ@2NWYh0RHV908j>SP80WinO00<0ZZZZ0;no_`32`/800P2f][H03P2a/K40
ZJVY09nOW`2ATI40HV9R05IFEP19BDT0?Cdm038b<P1FEUH0E5AD06=SH`1NGUh0SHf=0P22PX801`1O
Gel0_Kfm05IFEP2OWil0XZ:R0=SHf03oool02P3gmoL<000001l0oooo2`0000020?Ogm`030?ooo`1]
KFd0O7al0080EUIF00L0HV9R02LW9`1DE5@0DU9B09VIV@2][Jd0d=3@00<0f=SH00L0d];B0<[:bP2f
][H0UYJF08j>SP2ZZZX0UYJF0080][Jf00<0d];B0<g=c@3=cLd00`3Hf=P02`2d];@0Y:BT09nOW`2T
Y:@0_kno0<[:bP2j^[X0][Jf0:VYZ@2NWYh0SXj>00<0WinO00<0ZZZZ0<;2`P2f][H00P2f][H01`2a
/K40WinO096AT@22PX80HV9R05IFEP0m?Cd00P0b<S801@1FEUH0E5AD05iNGP29RHT0SHf=0080PX:2
00H0_Kfm05mOG`1FEUH0WinO0::RXP3Hf=P;0?Ogm``000008`3oool00240oooo2`0000020?Ogm`03
0:2PX01jNWX0LG5a0080BDU90180HV9R038b<P1OGel0_[jn0:NWY`2[Zj/0d=3@0=;BdP3Hf=P0cLg=
0;Zj^P27QhL0SHf=0;Jf]P2^[Zh0J6QX08B4Q02OWil209jNWP030<g=c@37alL0f=SH0080f=SH00l0
_Kfm0:BTY02YZJT0UYJF0:VYZ@1mOGd0TI6A0:^[Z`3<c<`0NWYj07moO`1lO7`0NWYj07alO029RHT0
0P2d];@20;Jf]P070:^[Z`2IVIT0TI6A07]kN`1]KFd0GUiN05IFEP0202XZ:P80EUIF00P0KFe]08N7
Q`2FUYH0O7al08:2PP2o_kl0IfMW075aL@80[:b/00<0jNWY0?Ogm`3gmoL02@3gmoL<000001l0oooo
2`0000020?Ogm`0H0:2PX01jNWX0LG5a05IFEP19BDT0HV9R038b<P1OGel0`<300:NWY`2[Zj/0d=3@
0=;BdP3Hf=P0cLg=0;Zj^P27QhL0SHf=0:j^[P1RHV80J6QX08B4Q02OWil0WYjN0P3=cLd03`37alL0
f=SH0=SHf038b<P0_Kfm0:BTY02FUYH0ZJVY05iNGP1mOGd0TI6A0<c<c01jNWX0EEEE07moO`0207al
O00508V9R@2[Zj/0];Bd0;Bd]02f][H00P2[Zj/01`2IVIT0TI6A06e]K@1NGUh0BDU905IFEP0Z:RX0
0P1FEUH0201NGUh0KFe]09JFUP1lO7`0PX:205]KF`2o_kl0LG5a0P2/[:`00`3YjNT0moOg0?Ogm`09
0?Ogm``000007`3oool;00000080moOg00<0X:2P07YjNP1aLG400P19BDT04P1RHV80<S8b05mOG`2n
_[h0YjNW0:^[Z`3@d=00d];B0=SHf03=cLd0^[Zj08N7Q`2=SHd0][Jf0:j^[P1XJ6P0Q8B409nOW`80
WYjN00<0cLg=0<O7a`3Hf=P00P3Hf=P03`2m_Kd0Y:BT0:VYZ@2FUYH0ZJVY07emO@2ATI40Zj^[0<c<
c01jNWX0Ogmo07alO01jNWX0O7al08V9R@020;Bd]080][Jf00L0Zj^[09VIV@2ATI40Ng]k06e]K@1N
GUh0EUIF0080:RXZ0P1FEUH0201]KFd0QhN709JFUP1lO7`0PX:20;no_`1WIfL0LG5a0P2/[:`00`3Y
jNT0moOg0?Ogm`090?Ogm``000008`3oool00240oooo2`0000020?Ogm`0K08V9R@2NWYh0LG5a06=S
H`1FEUH0HV9R03Xj>P0Z:RX0dM7A0;Fe]@2d];@0d];B0=SHf03Bd]80^[Zj08V9R@2ATI40`<300=SH
f01]KFd0D51@07AdM01oOgl0WinO09JFUP2d];@0b<S80080f=SH0100d=3@0;fm_@2][Jd0UYJF08V9
R@2ATI40IVIV0<c<c03YjNT0Kfm_071`L025QHD0FEUI0:2PX01aLG40IfMW0P2YZJT05@2d];@0/K6a
0:^[Z`2RXZ80RHV907UiN@1]KFd0E5AD038b<P0;2`/07alO05IFEP1NGUh0KFe]08V9R@27QhL0KFe]
07YjNP2a/K40D51@09JFUP020:j^[P`0moOg3000000O0?ooo`/000000P3gmoL02029RHT0WYjN075a
L@0b<S80EUIF069RHP0j>SX0:RXZ0P2e]KD08`2d];@0d];B0=SHf037alL0^[Zj08V9R@2ATI40`<30
06e]K@1RHV80D51@07AdM01oOgl0UYJF0;Zj^P2d];@0b<S80=SHf03@d=00bl_;0;fm_@2][Jd0RHV9
096AT@2OWil0IVIV0<c<c01_Kfl0L71`069RHP25QHD0FEUI075aL@1WIfL0RHV90080ZJVY01@0/K6a
0:^[Z`2TY:@0XZ:R08V9R@1]KFd0E5AD04U9B@0b<S807alO05IFEP1NGUh0ADE506e]K@27QhL0KFe]
07YjNP1aLG40/K6a09JFUP80[Zj^303gmoL<000001l0oooo2`0000020?Ogm`0K08V9R@2NWYh0LG5a
06=SH`1FEUH0HV9R03Xj>P0Z:RX0dM7A0;Fe]@2d];@0d];B0=SHf03Bd]80^[Zj08V9R@2ATI40`<30
0=SHf01]KFd0D51@07AdM01oOgl0WinO09JFUP2d];@0b<S80080f=SH0100d=3@0;fm_@2][Jd0UYJF
08V9R@2ATI40IVIV0<c<c03YjNT0Kfm_071`L025QHD0FEUI0:2PX01aLG40IfMW0P2YZJT05@2d];@0
/K6a0:^[Z`2RXZ80RHV907UiN@1]KFd0E5AD038b<P0;2`/07alO05IFEP1NGUh0KFe]08V9R@27QhL0
KFe]07YjNP2a/K40D51@09JFUP020:j^[P`0moOg3000000S0?ooo`008@3oool;000000060?Ogm`3o
ool0mOGe08:2PP1DE5@0C4a<0`1FEUH0501RHV80dM7A0:NWY`2d];@0b/[:0=3@d03;bl/0UYJF071`
L00f=SH0V9RH0;Ng]`1gMgL03@d=06i^KP12@T80L71`08V9R@2m_Kd0c/k>0P3Hf=P08@3Cdm<0_kno
0;Zj^P2FUYH0SXj>075aL@2FUYH0KFe]0<?3``1@D500_Kfm06QXJ01@D500X:2P02PX:01@D500SXj>
09JFUP2YZJT0Zj^[0:VYZ@2FUYH0Shn?07UiN@1RHV80EUIF01lO7`0G5aL07alO02XZ:P1FEUH0NGUi
075aL@0207YjNP0608:2PP2/[:`0D51@08f=S@2TY:@0a/K6303gmoL<000001l0oooo2`0000001P3g
moL0oooo0?Gem@22PX80E5AD038b<P<0EUIF02X0HV9R0:f][@2WYjL0];Bd0<[:bP3@d=00][Jf09JF
UP1`L700=SHf09RHV01gMgL0];Bd00d=3@1^KVh0@T9208V9R@2FUYH0_Kfm0<k>cP3Hf=P0dm?C0<_;
b`2o_kl0^[Zj08j>SP1aLG40SXj>09JFUP1]KFd0D51@0;fm_@0=3@d0J6QX051@D00X:2P0D51@07al
O02>SXh0UYJF0:^[Z`2YZJT209JFUP0408n?S`1RHV80EUIF059BDP807alO00@0:RXZ05IFEP19BDT0
NGUi0P1jNWX01P22PX80LG5a0:b/[02=SHd0Y:BT0<K6aP`0moOg3000000O0?ooo`/0000000H0moOg
0?ooo`3emOD0PX:205ADE01<C4`305IFEP0D069RHP3AdM40YjNW0;Bd]03:b/X0d=3@0<_;b`2FUYH0
L71`03Hf=P2HV9P0]kNg07MgM`0=3@d0KVi^0492@P1`L700RHV90;fm_@3>c/h20=SHf00Q0=?Cd`2o
_kl0^[Zj09JFUP2>SXh0LG5a09JFUP1]KFd0`l?3051@D02m_Kd0J6QX051@D02PX:00:2PX051@D02>
SXh0UYJF0:VYZ@2[Zj/0ZJVY09JFUP2?Shl0NGUi069RHP1FEUH07alO01LG5`0O7al0:RXZ05IFEP1i
NGT0LG5a0080NWYj00H0PX:20:b/[01@D500SHf=0:BTY036a/H<0?Ogm``000008`3oool00240oooo
2`0000001P3gmoL0Ti>C0<W9b@27QhL0L71`05=CD`80EUIF00X0HV9R08f=S@30`<00Y:BT0;6a/@3=
cLd0d=3@0;fm_@2ATI40BDU90P1QHF40200m?Cd092@T05IFEP1WIfL0HF5Q07alO02FUYH0`l?30P3C
dm<0203Hf=P0dm?C0<?3``2m_Kd0[Jf]09JFUP2ATI40L71`0P2<S8`02P0f=SH0:RXZ03Hf=P19BDT0
?Cdm05EEE@1CDe<0QhN708V9R@2IVIT20:BTY00308V9R@22PX80HV9R0080GUiN00<0?Cdm01lO7`0f
=SH00P0m?Cd02P1]KFd0NGUi06e]K@1WIfL0PX:20:b/[01UIFD0SHf=0::RXP3Vi^H<0?Ogm``00000
7`3oool;000000060?Ogm`2CTi<0bLW908N7Q`1`L700BDU90P1FEUH02P1RHV80SHf=0:NWY`2TY:@0
/K6a0<g=c@3@d=00ZZZZ096AT@19BDT2065QH@0E02@T900f=SH0EUIF06MWI`1QHF40UYJF0;Rh^033
`l<0dm?C0=SHf03Cdm<0bl_;0<?3``2m_Kd0UYJF096AT@1iNGT0L71`08b<S00f=SH0:RXZ0080=SHf
00H0BDU905EEE@1CDe<0O7al08N7Q`29RHT20:BTY00309JFUP29RHT0PX:20080GUiN00<0BDU903dm
?@0f=SH00P0m?Cd02P19BDT0KFe]06e]K@1WIfL0PX:207UiN@2/[:`0SHf=0::RXP3Vi^H<0?Ogm``0
00007`3oool;000000060?Ogm`2CTi<0bLW908N7Q`1`L700De=C0P1FEUH02P1RHV80SHf=0<30`02T
Y:@0/K6a0<g=c@3@d=00_Kfm096AT@19BDT2065QH@0803dm?@0T92@0EUIF06MWI`1QHF40O7al09JF
UP33`l<20=?Cd`080=SHf03Cdm<0`l?30;fm_@2][Jd0UYJF096AT@1`L70208b<S00:03Hf=P0Z:RX0
=SHf04U9B@0m?Cd0EEEE05=CD`27QhL0RHV909VIV@80Y:BT00<0RHV908:2PP1RHV800P1NGUh00`0m
?Cd07alO03Hf=P0203dm?@0:06e]K@1iNGT0KFe]06MWI`22PX80[:b/06EUI@2=SHd0XZ:R0>KViP`0
moOg3000000S0?ooo`008@3oool<0000000=0>KViP29RHT0Jf][04U9B@15ADD0BDU903dm?@1]KFd0
Shn?09VIV@2FUYH0Zj^[0<[:bP020=3@d00=0=;BdP3;bl/0cLg=0<;2`P2m_Kd0^[Zj0<;2`P2m_Kd0
Y:BT0:f][@2h^;P0f=SH0=?Cd`030=SHf0080<k>cP3;bl/0^[Zj0::RXP2WYjL0ZJVY0:^[Z`2YZJT2
09JFUP0N09VIV@2TY:@0ZJVY0:VYZ@2a/K40];Bd0:^[Z`2YZJT0Y:BT09VIV@2=SHd0PX:2069RHP1S
Hf<0EUIF03dm?@0Z:RX0=SHf04U9B@15ADD0KFe]08f=S@1]KFd0IfMW08f=S@2d];@0LG5a09JFUP3N
g]h0oooo2`3gmoL=000001l0oooo300000000`3Vi^H0RHV906][J`0304U9B@0F03dm?@1]KFd0Shn?
09nOW`2FUYH0Zj^[0<[:bP3@d=00f=SH0=;BdP3;bl/0cLg=0<;2`P2j^[X0_Kfm0<;2`P2m_Kd0Y:BT
0;Rh^038b<P0f=SH0=?Cd`80f=SH00P0dm?C0<k>cP3;bl/0XZ:R0:NWY`2FUYH0ZJVY0:^[Z`<0UYJF
00h0VIVI0:BTY02YZJT0/K6a0;Fe]@2d];@0Zj^[0:BTY02IVIT0TI6A08f=S@22PX80Hf=S05IFEP80
?Cdm00@0=SHf04U9B@15ADD0?Cdm0P1]KFd01`1WIfL0SHf=09JFUP2d];@0UYJF0=kNgP3oool02`3g
moL=000001l0oooo300000003@3Vi^H0RHV906][J`19BDT0ADE504U9B@0m?Cd0KFe]08n?S`2IVIT0
UYJF0:^[Z`3:b/X00P3@d=003@3Bd]80bl_;0<g=c@32`/80_Kfm0;Zj^P32`/80_Kfm0:BTY02][Jd0
^;Rh0=SHf03Cdm<00`3Hf=P0203>c/h0bl_;0;Zj^P2RXZ80YjNW0:VYZ@2[Zj/0ZJVY0P2FUYH07P2I
VIT0Y:BT0:VYZ@2YZJT0/K6a0;Bd]02[Zj/0ZJVY0:BTY02IVIT0SHf=08:2PP1RHV80Hf=S05IFEP0m
?Cd0:RXZ03Hf=P19BDT0ADE506e]K@2=SHd0KFe]06MWI`2=SHd0];Bd075aL@2FUYH0g]kN0?ooo`/0
moOg3@00000S0?ooo`008@3oool<0000000?0?ooo`15ADD0GUiN038b<P0m?Cd0IFEU038b<P1NGUh0
Ng]k09jNWP2>SXh0ZJVY0=3@d032`/80dm?C00D0f=SH00H0]KFe07alO01aLG40Ng]k0;fm_@38b<P2
0=SHf00<0>7Qh@3Hf=P0f=SH0=?Cd`3Hf=P0`l?30;Rh^02ATI40LG5a07]kN`2>SXh0`/;20P37alL2
0<;2`P80_Kfm00/0];Bd0:VYZ@2FUYH0QhN709VIV@22PX80NGUi06e]K@1NGUh0E5AD038b<P0202XZ
:P0;03Hf=P0W9bL0GUiN07UiN@1]KFd0IFEU096AT@2o_kl0NWYj09nOW`3YjNT0303gmoL=000001l0
oooo300000003P3oool0ADE505iNGP0b<S80?Cdm06EUI@0b<S80GUiN07]kN`2IVIT0SXj>0:VYZ@3@
d=00`/;21@3Hf=P01P2e]KD0TI6A07alO01aLG40Ng]k0<S8b0H0f=SH00@0dm?C0=SHf02h^;P0TI6A
0P1aLG401P1kNg/0`/;20<O7a`3;bl/0alO70<;2`P<0_Kfm01L0];Bd0:VYZ@27QhL0VIVI08f=S@22
PX80NGUi05iNGP1DE5@0EUIF038b<P0Z:RX0=SHf02LW9`19BDT0GUiN06e]K@1UIFD0TI6A09JFUP2o
_kl0WinO0>WYj@0<0?Ogm`d000007`3oool<0000000?0?ooo`15ADD0GUiN038b<P0m?Cd0IFEU038b
<P1NGUh0Ng]k09jNWP2>SXh0ZJVY0=3@d032`/80dm?C00D0f=SH00H0]KFe07alO01aLG40Ng]k0;fm
_@38b<P20=SHf00<0>7Qh@3Hf=P0f=SH0=?Cd`3Hf=P0`l?30;Rh^02ATI40LG5a07]kN`2>SXh0`/;2
0P37alL20<;2`P80_Kfm00/0];Bd0:VYZ@2FUYH0QhN709VIV@22PX80NGUi06e]K@1NGUh0E5AD038b
<P0202XZ:P0;03Hf=P0W9bL0GUiN07UiN@1]KFd0IFEU096AT@2o_kl0NWYj09nOW`3YjNT0303gmoL=
000002<0oooo000Q0?ooo``0000000l0oooo03dm?@1<C4`0<S8b03dm?@1FEUH0BDU906MWI`1eMGD0
PX:2096AT@2OWil0bl_;0<K6aP2o_kl00`3Hf=P01P3AdM40RHV907alO01kNg/0ZJVY0<S8b080dm?C
00<0hN7Q0=SHf03QhN400`3Hf=P20=?Cd`080<S8b02h^;P0HV9R05IFEP1RHV80Ng]k0:f][@37alL2
0<_;b`080<30`032`/80[Jf]09JFUP1jNWX0VIVI08j>SP1iNGT206e]K@0?05iNGP0m?Cd0:RXZ038b
<P0Z:RX09bLW051@D01[Jf/0NWYj075aL@1OGel0SHf=0:j^[P2FUYH0WinO00d0moOg3@00000O0?oo
o``0000000l0oooo03dm?@1<C4`0<S8b04U9B@1FEUH0BDU906MWI`1eMGD0SHf=096AT@2OWil0bl_;
0<K6aP3=cLd00`3Hf=P02@3AdM40O7al071`L01kNg/0ZJVY0<S8b03Cdm<0f=SH0>7Qh@050=SHf00F
0=?Cd`38b<P0^;Rh08f=S@1RHV80EUIF07]kN`2][Jd0^[Zj0<O7a`3;bl/0`<300<;2`P2d];@0[Jf]
09JFUP2IVIT0SXj>08V9R@1iNGT0KFe]05iNGP80?Cdm0P0Z:RX01P0W9bL0D51@05YJFP1[Jf/0LG5a
05mOG`80SHf=00<0[Zj^09nOW`3gmoL0303gmoL=000001l0oooo300000003`3oool0?Cdm04a<C00b
<S80?Cdm05IFEP19BDT0IfMW07EeM@22PX80TI6A09nOW`3;bl/0a/K60;no_`030=SHf0060=7Ad@29
RHT0O7al07]kN`2YZJT0b<S80P3Cdm<00`3QhN40f=SH0>7Qh@030=SHf080dm?C00P0b<S80;Rh^01R
HV80EUIF069RHP1kNg/0[Jf]0<O7a`80bl_;00P0`<300<;2`P2][Jd0UYJF07YjNP2IVIT0SXj>07Ui
N@80KFe]00l0GUiN03dm?@0Z:RX0<S8b02XZ:P0W9bL0D51@06][J`1jNWX0LG5a05mOG`2=SHd0[Zj^
09JFUP2OWil03@3gmoL=000002<0oooo000Q0?ooo``0000000<0oooo05ADE015ADD00P19BDT00`1F
EUH0C4a<05mOG`02069RHP0;08V9R@2OWil0b/[:0=;BdP2FUYH0ZJVY0:BTY02NWYh0Ng]k07UiN@2T
Y:@00P3Hf=P50>7Qh@D0f=SH0`3Cdm<0302m_Kd0ZJVY08j>SP1`L700GUiN075aL@29RHT0SXj>096A
T@27QhL0NWYj08V9R@80UYJF00H0WYjN07UiN@1]KFd0KFe]05IFEP1]KFd204E5A@0;03dm?@0Z:RX0
92@T06e]K@1iNGT0KFe]06EUI@2=SHd0RHV907AdM03<c<`03@3gmoL=000001l0oooo300000005@3o
ool0E5AD04E5A@19BDT0<S8b05IFEP1<C4`0GemO069RHP1lO7`0RHV909nOW`3:b/X0d];B09nOW`2Y
ZJT0Y:BT09jNWP1kNg/0Y:BT0=?Cd`020=SHf0D0hN7Q1@3Hf=P20=?Cd`050<k>cP2m_Kd0ZJVY071`
L01NGUh00P1aLG404`29RHT0TI6A08N7Q`1lO7`0NWYj08V9R@2FUYH0WYjN08f=S@1iNGT0KFe]05IF
EP1]KFd07alO04E5A@0m?Cd0:RXZ02@T901OGel00P1]KFd01@1UIFD0SHf=0::RXP29RHT0c<c<00d0
moOg3@00000O0?ooo``0000000<0oooo05ADE015ADD00P19BDT00`1FEUH0C4a<05mOG`02069RHP0;
08V9R@2OWil0b/[:0=;BdP2FUYH0ZJVY0:BTY02NWYh0Ng]k07UiN@2TY:@00P3Hf=P50>7Qh@D0f=SH
0`3Cdm<0302m_Kd0ZJVY08j>SP1`L700GUiN075aL@29RHT0SXj>096AT@27QhL0NWYj08V9R@80UYJF
00H0WYjN07UiN@1]KFd0KFe]05IFEP1]KFd204E5A@0;03dm?@0Z:RX092@T06e]K@1iNGT0KFe]06EU
I@2=SHd0RHV907AdM03<c<`03@3gmoL=000002<0oooo000Q0?ooo``0000000D0LG5a04U9B@19BDT0
GemO05IFEP0204U9B@0605IFEP1OGel0Hf=S07YjNP2YZJT0b/[:0P3@d=001@2YZJT0WYjN09jNWP2f
][H0f=SH00L0hN7Q00<0hn?S0=SHf03Hf=P00P3QhN440=SHf0080=7Ad@3;bl/0bl_;0<_;b`37alL0
WinO07alO01iNGT207alO00909nOW`2FUYH0VIVI0::RXP2IVIT0NGUi075aL@1iNGT0EUIF0080?Cdm
00`0<S8b01LG5`0G5aL07alO071`L01NGUh0NWYj075aL@2FUYH0KFe]08f=S@3YjNT=0?Ogm`d00000
7`3oool<00000004075aL@19BDT0BDU905mOG`<0BDU900T0EUIF05mOG`1aLG40NWYj0:VYZ@3:b/X0
d=3@0<_;b`2YZJT00P2NWYh00`2f][H0hN7Q0>7Qh@060>7Qh@030>?Sh`3Hf=P0hN7Q0080hN7Q0`3H
f=P0103Cdm<0dM7A0<_;b`3;bl/20<O7a`0@09nOW`1lO7`0O7al07alO02FUYH0WinO09JFUP2RXZ80
VIVI08f=S@1iNGT0LG5a05IFEP0m?Cd0BDU903dm?@805aLG00T07alO06=SH`1`L700NWYj075aL@2F
UYH0WinO06e]K@3YjNT03@3gmoL=000001l0oooo300000001@1aLG40BDU904U9B@1OGel0EUIF0080
BDU900H0EUIF05mOG`1SHf<0NWYj0:VYZ@3:b/X20=3@d0050:VYZ@2NWYh0WYjN0;Jf]P3Hf=P01`3Q
hN400`3Shn<0f=SH0=SHf0020>7Qh@@0f=SH00P0dM7A0<_;b`3;bl/0bl_;0<O7a`2OWil0O7al07Ui
N@80O7al00T0WinO09JFUP2IVIT0XZ:R09VIV@1iNGT0LG5a07UiN@1FEUH00P0m?Cd0300b<S805aLG
01LG5`0O7al0L71`05iNGP1jNWX0LG5a09JFUP1]KFd0SHf=0>WYj@d0moOg3@00000S0?ooo`008@3o
ool<00000080D51@00D0FUYJ08N7Q`1[Jf/0FUYJ05IFEP0205YJFP0405iNGP1aLG40Y:BT0<O7a`80
d=3@0`3Hf=P20>7Qh@050=SHf03QhN40hN7Q0>7Qh@3Hf=P00`3QhN420=SHf0030>7Qh@3Hf=P0hN7Q
00@0f=SH00H0dM7A0=?Cd`3=cLd0bl_;0<;2`P3;bl/20;fm_@040;Bd]02YZJT0Y:BT0:BTY080UYJF
00D0Ng]k07UiN@1iNGT0GUiN06e]K@0202XZ:P0701lO7`0b<S809bLW07YjNP1NGUh0UYJF07UiN@02
06e]K@030;jn_P3oool0moOg00`0moOg3@00000O0?ooo``000000P1@D5001@1JFUX0QhN705IFEP1J
FUX0EUIF0080FUYJ00H0NWYj075aL@2TY:@0alO70=3@d03Bd]830=SHf0030>7Qh@3Hf=P0f=SH00L0
hN7Q00D0f=SH0>7Qh@3Hf=P0f=SH0>7Qh@040=SHf0080=7Ad@3=cLd0bl_;0<O7a`32`/80bl_;0;fm
_@2d];@20:VYZ@0E0:BTY02FUYH0UYJF08f=S@1kNg/0NGUi05iNGP1]KFd0ADE502XZ:P0O7al0<S8b
02LW9`2FUYH0NWYj09JFUP1iNGT0KFe]0:j^[P1]KFd0oooo00d0moOg3@00000O0?ooo``000000P1@
D5001@1JFUX0QhN706][J`1JFUX0EUIF0080FUYJ00@0GUiN075aL@2TY:@0alO70P3@d=030=SHf080
hN7Q00D0f=SH0>7Qh@3QhN40hN7Q0=SHf0030>7Qh@80f=SH00<0hN7Q0=SHf03QhN40103Hf=P01P3A
dM40dm?C0<g=c@3;bl/0`/;20<_;b`80_Kfm00@0];Bd0:VYZ@2TY:@0Y:BT0P2FUYH01@1kNg/0NGUi
07UiN@1NGUh0KFe]0080:RXZ00L07alO038b<P0W9bL0NWYj05iNGP2FUYH0NGUi0080KFe]00<0_[jn
0?ooo`3gmoL0303gmoL=000002<0oooo000Q0?ooo``0000000@0EUIF06MWI`1SHf<0LG5a0P1SHf<0
2P1JFUX0EUIF05ADE01DE5@0LG5a096AT@2o_kl0cLg=0=3@d03Bd]830=SHf0d0hN7Q0`3Hf=P40=?C
d`0C0<_;b`38b<P0bl_;0<;2`P2o_kl0^[Zj0;Bd]02[Zj/0ZJVY0:BTY02RXZ80VIVI07UiN@22PX80
LG5a06e]K@19BDT0?Cdm038b<P0201LG5`0801lO7`1lO7`0KFe]0::RXP1lO7`0Hf=S06e]K@3emOD>
0?Ogm`d000007`3oool<0000000@05IFEP1WIfL0Hf=S075aL@1WIfL0Hf=S05YJFP1FEUH0E5AD06e]
K@1aLG40TI6A0;no_`3=cLd0d=3@0=;BdP<0f=SH00<0hN7Q0=SHf03QhN402P3QhN420=SHf0@0dm?C
01<0bl_;0<S8b037alL0bl_;0<;2`P2j^[X0];Bd0;6a/@2[Zj/0ZJVY0::RXP2IVIT0PX:207UiN@22
PX80KFe]04U9B@0b<S80?Cdm00805aLG00P07alO09JFUP1lO7`0XZ:R07alO01SHf<0UYJF06e]K@h0
moOg3@00000O0?ooo``0000000@0EUIF06MWI`1SHf<0LG5a0P1SHf<02P1JFUX0EUIF05ADE01DE5@0
LG5a096AT@2o_kl0cLg=0=3@d03Bd]830=SHf0d0hN7Q0`3Hf=P40=?Cd`0C0<_;b`38b<P0bl_;0<;2
`P2o_kl0^[Zj0;Bd]02[Zj/0ZJVY0:BTY02RXZ80VIVI07UiN@22PX80LG5a06e]K@19BDT0?Cdm038b
<P0201LG5`0801lO7`1lO7`0KFe]0::RXP1lO7`0Hf=S06e]K@3emOD>0?Ogm`d000008`3oool00240
oooo3@00000305IFEP0<05mOG`1FEUH0FUYJ05IFEP1JFUX0EUIF08:2PP2FUYH0_Kfm0<;2`P3>c/h0
dm?C103Hf=P40>7Qh@80f=SH103QhN440=SHf0040=7Ad@3Cdm<0dm?C0<k>cP<0bl_;0140`/;20;no
_`32`/80_Kfm0;6a/@2][Jd0ZJVY09JFUP2IVIT0TI6A08:2PP1iNGT0KFe]05IFEP19BDT0ADE501lO
7`0201LG5`07038b<P2RXZ80QhN70:BTY022PX80LG5a0:f][@0>0?Ogm`h000007`3oool=000000<0
EUIF00`0Hf=S05IFEP1JFUX0EUIF05YJFP1jNWX0PX:209JFUP2m_Kd0`/;20=;BdP3Cdm<30=SHf0D0
hN7Q00<0f=SH0>7Qh@3QhN400P3QhN440=SHf0050=7Ad@3Cdm<0dm?C0=?Cd`3>c/h00P3;bl/04@30
`<00`/;20;no_`2m_Kd0/K6a0;Bd]02][Jd0ZJVY09VIV@2ATI40SHf=08:2PP1iNGT0EUIF04U9B@0f
=SH0ADE500805aLG00P0<S8b075aL@2RXZ80Y:BT08:2PP1aLG40IFEU0:f][@d0moOg3P00000O0?oo
o`d000000`1FEUH0301OGel0EUIF05YJFP1FEUH0FUYJ05IFEP22PX80UYJF0;fm_@32`/80c/k>0=?C
d`@0f=SH103QhN420=SHf0@0hN7Q103Hf=P0103AdM40dm?C0=?Cd`3>c/h30<_;b`0A0<;2`P2o_kl0
`/;20;fm_@2a/K40[Jf]0:VYZ@2FUYH0VIVI096AT@22PX80NGUi06e]K@1FEUH0BDU904E5A@0O7al0
0P0G5aL01`0b<S80XZ:R08N7Q`2TY:@0PX:2075aL@2][Jd03P3gmoL>000002<0oooo000Q0?ooo`d0
000000D0IfMW05IFEP1SHf<0IfMW06=SH`0205YJFP0705IFEP1SHf<0SHf=09JFUP2a/K40`/;20=3@
d0040=SHf080hN7Q00H0f=SH0>7Qh@3QhN40f=SH0>7Qh@3Hf=P30>7Qh@H0f=SH00<0dm?C0<k>cP3;
bl/00P3;bl/40;fm_@0<0;Rh^02[Zj/0ZJVY0:BTY02IVIT0SXj>08N7Q`1lO7`0KFe]05iNGP0m?Cd0
9bLW0P0O7al0200G5aL092@T09JFUP1aLG40UYJF08f=S@22PX80d];B3P3gmoL>000001l0oooo3@00
00001@1WIfL0EUIF06=SH`1[Jf/0Hf=S0080FUYJ00L0EUIF075aL@2=SHd0UYJF0;6a/@32`/80d];B
00@0f=SH00<0hN7Q0=SHf03Hf=P0103QhN400`3Hf=P0hN7Q0>7Qh@060=SHf080dm?C00@0c/k>0<_;
b`3;bl/0`<300`2m_Kd01P2h^;P0/K6a0:^[Z`2YZJT0VIVI08j>SP80QhN700T0O7al05iNGP0m?Cd0
BDU902LW9`0O7al05aLG02@T901`L7000P2FUYH0102=SHd0PX:206EUI@3Bd]8=0?Ogm`h000007`3o
ool=0000000506MWI`1FEUH0Hf=S06MWI`1SHf<00P1JFUX01`1FEUH0Hf=S08f=S@2FUYH0/K6a0<;2
`P3@d=00103Hf=P20>7Qh@060=SHf03QhN40hN7Q0=SHf03QhN40f=SH0`3QhN460=SHf0030=?Cd`3>
c/h0bl_;0080bl_;102m_Kd0302h^;P0Zj^[0:VYZ@2TY:@0VIVI08j>SP27QhL0O7al06e]K@1NGUh0
?Cdm02LW9`807alO00P05aLG02@T902FUYH0LG5a09JFUP2=SHd0PX:20=;BdPh0moOg3P00000S0?oo
o`008@3oool=00000005051@D01NGUh0Jf][06][J`1SHf<00P1FEUH01`1[Jf/0Hf=S08V9R@2FUYH0
Zj^[0<;2`P3;bl/00P3Cdm<30=SHf0030>7Qh@3Hf=P0f=SH0080hN7Q00<0f=SH0>7Qh@3Hf=P01P3H
f=P04P3Cdm<0f=SH0=?Cd`3;bl/0dm?C0<_;b`38b<P0`/;20;no_`32`/80^[Zj0;Bd]02[Zj/0ZJVY
09JFUP2IVIT0TI6A08N7Q`80KFe]00@0GUiN04U9B@0W9bL05aLG0P0;2`/01P1CDe<0NWYj07UiN@2O
Wil0UYJF0:j^[Pl0moOg3P00000O0?ooo`d0000000D0D51@05iNGP1[Jf/0FUYJ06=SH`0205IFEP06
06][J`1aLG40RHV909JFUP2[Zj/0`/;20`3Cdm<20=SHf080hN7Q0P3Hf=P0103QhN40f=SH0=SHf03Q
hN460=SHf0040=?Cd`3Hf=P0dm?C0=?Cd`80bl_;0P38b<P02@32`/80_kno0;Zj^P2d];@0/K6a0:^[
Z`2YZJT0VIVI096AT@0208N7Q`0506e]K@1NGUh0BDU903dm?@0W9bL00P0;2`/01`1CDe<0Hf=S07Yj
NP2OWil0UYJF0:j^[P2FUYH03P3gmoL>000001l0oooo3@0000001@1@D500GUiN06][J`1[Jf/0Hf=S
0080EUIF00L0Jf][06=SH`29RHT0UYJF0:^[Z`32`/80bl_;0080dm?C0`3Hf=P00`3QhN40f=SH0=SH
f0020>7Qh@030=SHf03QhN40f=SH00H0f=SH0180dm?C0=SHf03Cdm<0bl_;0=?Cd`3;bl/0b<S80<;2
`P2o_kl0`/;20;Zj^P2d];@0Zj^[0:VYZ@2FUYH0VIVI096AT@27QhL206e]K@0405iNGP19BDT09bLW
01LG5`802`/;00H0De=C07YjNP1iNGT0WinO09JFUP2^[Zh?0?Ogm`h000008`3oool00240oooo3P00
000305IFEP0305ADE01JFUX0EUIF0080Hf=S00D0SXj>09nOW`2[Zj/0_kno0<_;b`040=SHf0<0hN7Q
00D0f=SH0>7Qh@3Hf=P0f=SH0>7Qh@090=SHf080dm?C0`3;bl/01038b<P0_Kfm0;fm_@2d];@20;6a
/@040:VYZ@2OWil0Y:BT08V9R@80LG5a00<0KFe]05IFEP0m?Cd00P0G5aL0200T92@05aLG06][J`1a
LG40IfMW09JFUP2OWil0Zj^[3P3gmoL?000001l0oooo3P00000305IFEP0:05ADE01JFUX0EUIF06=S
H`1jNWX0SXj>09nOW`2[Zj/0_kno0=3@d0@0f=SH00D0hN7Q0=SHf03QhN40f=SH0>7Qh@020=SHf003
0>7Qh@3Hf=P0f=SH00H0f=SH00<0dM7A0=?Cd`3Cdm<00P3;bl/01030`<00b<S80;fm_@2d];@30;6a
/@040:VYZ@2TY:@0RHV907alO080LG5a00H0EUIF03dm?@0b<S805aLG02@T900G5aL206][J`04075a
L@2FUYH0WinO0:^[Z`h0moOg3`00000O0?ooo`h000000`1FEUH00`1DE5@0FUYJ05IFEP0206=SH`05
08j>SP2OWil0Zj^[0;no_`3;bl/0103Hf=P30>7Qh@050=SHf03QhN40f=SH0=SHf03QhN402@3Hf=P2
0=?Cd`<0bl_;00@0b<S80;fm_@2m_Kd0];Bd0P2a/K40102YZJT0WinO0:BTY029RHT2075aL@0306e]
K@1FEUH0?Cdm00805aLG00P092@T01LG5`1[Jf/0LG5a06MWI`2FUYH0WinO0:^[Z`h0moOg3`00000S
0?ooo`008@3oool?0000000=05IFEP19BDT0D51@04U9B@1FEUH0Hf=S06e]K@2>SXh0Y:BT0:j^[P2o
_kl0bl_;0=7Ad@060=SHf0@0hN7Q00<0f=SH0>7Qh@3Hf=P01P3Hf=P02P3AdM40dm?C0=?Cd`3;bl/0
dm?C0<_;b`38b<P0`l?30;fm_@2d];@20;6a/@80ZJVY0140UYJF08V9R@1lO7`0Hf=S05iNGP0m?Cd0
<S8b01lO7`0;2`/06a/K01LG5`1iNGT0IfMW06EUI@2OWil0]KFe0<o?c`0=0?Ogma0000007`3oool?
0000000=05IFEP1DE5@0D51@04U9B@1FEUH0Hf=S08N7Q`2>SXh0Y:BT0:j^[P2o_kl0dm?C0=7Ad@06
0=SHf0<0hN7Q0P3Hf=P00`3QhN40f=SH0=SHf0040=SHf0030=7Ad@3Cdm<0dm?C0080dm?C00X0bl_;
0<S8b038b<P0`l?30;Bd]02a/K40Zj^[0;6a/@2YZJT0UYJF0P29RHT0101lO7`0Hf=S03dm?@0b<S82
01lO7`0801/K6`0G5aL0NGUi06][J`1WIfL0WinO0;Fe]@3?cll=0?Ogma0000007`3oool?0000000=
05IFEP19BDT0D51@04U9B@1FEUH0Hf=S06e]K@2>SXh0Y:BT0:j^[P2o_kl0bl_;0=7Ad@060=SHf0@0
hN7Q00<0f=SH0>7Qh@3Hf=P01P3Hf=P02P3AdM40dm?C0=?Cd`3;bl/0dm?C0<_;b`38b<P0`l?30;fm
_@2d];@20;6a/@80ZJVY0140UYJF08V9R@1lO7`0Hf=S05iNGP0m?Cd0<S8b01lO7`0;2`/06a/K01LG
5`1iNGT0IfMW06EUI@2OWil0]KFe0<o?c`0=0?Ogma0000008`3oool00240oooo3`00000405IFEP09
051@D01FEUH0KFe]08j>SP2OWil0][Jf0<;2`P3;bl/0dm?C00<0f=SH00<0hN7Q0=SHf03QhN400`3Q
hN430=SHf0030>7Qh@3Hf=P0f=SH00@0f=SH0P3Cdm<01@3AdM40c/k>0<_;b`3;bl/0b<S80080_Kfm
00@0][Jf0;6a/@2YZJT0Zj^[0P2IVIT0202=SHd0NWYj075aL@1NGUh0=SHf038b<P0T92@051@D0P0O
7al01`1lO7`0GUiN07UiN@2FUYH0_kno0?Ogm`3emOD0303gmoL@000001l0oooo3`0000002`1FEUH0
E5AD05IFEP1FEUH0D51@05IFEP1lO7`0SXj>09nOW`2f][H0`/;20080dm?C103Hf=P40>7Qh@030=SH
f03QhN40f=SH00L0f=SH00@0dm?C0=SHf03Cdm<0dM7A0P3;bl/20<S8b00?0;fm_@2f][H0/K6a0;6a
/@2YZJT0Zj^[09VIV@2=SHd0O7al07YjNP1aLG40=SHf038b<P0O7al092@T00807alO00D0O7al08V9
R@1NGUh0UYJF0;no_`020?Ogm`030?Gem@3gmoL0moOg00T0moOg4000000O0?ooo`l00000101FEUH0
2@1@D500EUIF06e]K@2>SXh0WinO0;Jf]P32`/80bl_;0=?Cd`030=SHf0030>7Qh@3Hf=P0hN7Q00<0
hN7Q0`3Hf=P00`3QhN40f=SH0=SHf0040=SHf080dm?C00D0dM7A0<k>cP3;bl/0bl_;0<S8b0020;fm
_@040;Jf]P2a/K40ZJVY0:^[Z`80VIVI00P0SHf=07YjNP1aLG40GUiN03Hf=P0b<S8092@T01@D5080
7alO00L0O7al05iNGP1iNGT0UYJF0;no_`3gmoL0mOGe00`0moOg4000000S0?ooo`008@3oool@0000
000=04U9B@1@D500EUIF05IFEP1@D500Jf][09JFUP2YZJT0];Bd0<S8b03;bl/0d=3@0=?Cd`040=SH
f0030>7Qh@3Hf=P0hN7Q00/0f=SH00@0dm?C0<k>cP3Cdm<0dM7A0P3;bl/20<;2`P040;no_`2j^[X0
/K6a0:^[Z`80Y:BT00P0SXj>08f=S@1aLG40Hf=S05IFEP0f=SH0<S8b01lO7`80:RXZ00H05aLG06e]
K@1]KFd0SHf=0:VYZ@3Bd]8=0?Ogma4000007`3oool@00000080D51@0P1FEUH02@1@D500QhN709JF
UP2YZJT0];Bd0<S8b03=cLd0d=3@0=?Cd`040=SHf0030>7Qh@3Hf=P0hN7Q00X0f=SH0P3Cdm<00`3>
c/h0dm?C0<_;b`020<_;b`80`/;201D0^[Zj0;6a/@2a/K40Zj^[0:BTY02>SXh0SHf=07alO01aLG40
Hf=S03Hf=P0b<S8092@T01lO7`0Z:RX05aLG06e]K@27QhL0KFe]0:VYZ@3Bd]803@3gmoLA000001l0
oooo400000003@19BDT0D51@05IFEP1FEUH0D51@06][J`2FUYH0ZJVY0;Bd]038b<P0bl_;0=3@d03C
dm<0103Hf=P00`3QhN40f=SH0>7Qh@0;0=SHf0040=?Cd`3>c/h0dm?C0=7Ad@80bl_;0P32`/80102o
_kl0^[Zj0;6a/@2[Zj/20:BTY00808j>SP2=SHd0LG5a06=SH`1FEUH0=SHf038b<P0O7al202XZ:P06
01LG5`1]KFd0KFe]08f=S@2YZJT0d];B3@3gmoLA000002<0oooo000Q0?oooa00000000P0D51@05IF
EP1@D500EUIF05YJFP1[Jf/0UYJF0:j^[P80`/;200<0bl_;0=?Cd`3Hf=P0103Hf=P00`3QhN40f=SH
0=SHf00:0=SHf080dm?C0P3>c/h0203;bl/0b<S80<S8b032`/80_kno0;Zj^P2h^;P0/K6a0P2][Jd0
1P2IVIT0SXj>08V9R@1]KFd0GUiN04U9B@80=SHf00T07alO02XZ:P0G5aL02`/;06][J`1]KFd0SHf=
0;6a/@3/k>`03@3gmoLA000001l0oooo40000000201JFUX0EUIF051@D01FEUH0FUYJ075aL@2FUYH0
[Zj^0P32`/820=?Cd`@0f=SH0P3QhN4;0=SHf0<0dm?C0P3>c/h20<S8b0040<_;b`32`/80_kno0;Rh
^080/K6a0P2][Jd01@2>SXh0RHV907UiN@1]KFd0GUiN0080=SHf00T0:RXZ01lO7`0G5aL02`/;06][
J`1aLG40KFe]0;6a/@3/k>`03@3gmoLA000001l0oooo40000000201@D500EUIF051@D01FEUH0FUYJ
06][J`2FUYH0[Zj^0P32`/800`3;bl/0dm?C0=SHf0040=SHf0030>7Qh@3Hf=P0f=SH00X0f=SH0P3C
dm<20<k>cP080<_;b`38b<P0b<S80<;2`P2o_kl0^[Zj0;Rh^02a/K420:f][@0609VIV@2>SXh0RHV9
06e]K@1NGUh0BDU90P0f=SH02@0O7al0:RXZ01LG5`0;2`/0Jf][06e]K@2=SHd0/K6a0>c/k00=0?Og
ma4000008`3oool00240oooo4@0000002P1[Jf/0FUYJ06=SH`1OGel0Hf=S09JFUP2OWil0];Bd0<S8
b03;bl/20=?Cd`80f=SH00<0dm?C0=SHf03Hf=P02@3Hf=P30=?Cd`030=SHf03Cdm<0bl_;0080bl_;
00<0b<S80<_;b`2m_Kd00P2m_Kd00`2j^[X0/K6a0:^[Z`0209JFUP0508f=S@1iNGT0EUIF05YJFP15
ADD00P0f=SH0200Z:RX03@d=00L71`1jNWX0O7al08:2PP2ATI40clo?3@3gmoLB000001l0oooo4000
00002`1`L700Jf][05YJFP1SHf<0GemO07UiN@2FUYH0WinO0;Bd]038b<P0bl_;0080dm?C3P3Hf=P2
0=?Cd`030=SHf03Cdm<0bl_;0080bl_;00<0b<S80<_;b`33`l<00P2m_Kd02P2j^[X0/K6a0:BTY02[
Zj/0UYJF08f=S@1iNGT0HV9R05IFEP1JFUX203Hf=P0802@T900Z:RX01`L707YjNP1lO7`0IFEU08:2
PP3?cll>0?Ogma4000007`3ooolA0000000:06][J`1JFUX0Hf=S05mOG`1SHf<0UYJF09nOW`2d];@0
b<S80<_;b`80dm?C0P3Hf=P00`3Cdm<0f=SH0=SHf0090=SHf0<0dm?C00<0f=SH0=?Cd`3;bl/00P3;
bl/00`38b<P0bl_;0;fm_@020;fm_@030;Zj^P2a/K40Zj^[0080UYJF00D0SHf=07UiN@1FEUH0FUYJ
04E5A@0203Hf=P0802XZ:P0=3@d01`L707YjNP1lO7`0PX:2096AT@3?cll=0?Ogma8000008`3oool0
0240oooo4@0000000`1FEUH0GemO051@D00206=SH`0708f=S@2TY:@0][Jf0<;2`P30`<00bl_;0=?C
d`020<k>cP80dm?C0P3Hf=P0203Cdm<0f=SH0=SHf03Cdm<0f=SH0=3@d03Cdm<0d];B0P3Cdm<01P3>
c/h0bl_;0<_;b`3;bl/0b<S80<_;b`80b<S80`2m_Kd20;Bd]0060:BTY02YZJT0SXj>07alO01]KFd0
GUiN0P1JFUX2038b<P0:01LG5`0;2`/0RHV907UiN@1]KFd0SHf=0;Rh^03YjNT0moOg0?Gem@/0moOg
4P00000O0?oooa40000000T0EUIF05mOG`1@D500Hf=S07YjNP2=SHd0Y:BT0;Jf]P32`/800P3;bl/0
103Cdm<0c/k>0<k>cP3Cdm<30=SHf0070=?Cd`3Hf=P0f=SH0=?Cd`3Hf=P0dm?C0=;BdP030=?Cd`@0
bl_;0`38b<P00`30`<00_Kfm0;fm_@020;Bd]0080:^[Z`2TY:@0ZJVY07alO01]KFd0IFEU05iNGP1J
FUX2038b<P0902XZ:P0G5aL0RHV907UiN@1]KFd0IFEU08f=S@3YjNT0moOg0080mOGe2P3gmoLB0000
01l0oooo4@0000000`1FEUH0GemO051@D00206=SH`0708f=S@2TY:@0][Jf0<;2`P30`<00bl_;0=?C
d`020<k>cP80dm?C0P3Hf=P0203Cdm<0f=SH0=SHf03Cdm<0f=SH0=3@d03Cdm<0d];B0P3Cdm<01P3>
c/h0bl_;0<_;b`3;bl/0b<S80<_;b`80b<S80`2m_Kd20;Bd]0060:BTY02YZJT0SXj>07alO01]KFd0
GUiN0P1JFUX2038b<P0:01LG5`0;2`/0RHV907UiN@1]KFd0SHf=0;Rh^03YjNT0moOg0?Gem@/0moOg
4P00000S0?ooo`008@3ooolB0000000;05YJFP1jNWX0EUIF07YjNP2=SHd0WinO0;Bd]02o_kl0alO7
0<S8b03;bl/00P3Cdm<0103Hf=P0dm?C0=SHf03Cdm<40=SHf080dm?C00D0f=SH0=?Cd`3Cdm<0bl_;
0=?Cd`040<_;b`80b<S80140_kno0;Zj^P2j^[X0][Jf0;6a/@2][Jd0Y:BT09VIV@29RHT0O7al075a
L@1JFUX0BDU9051@D01[Jf/07alO01/K6`0205IFEP0707YjNP1]KFd0UYJF0<;2`P3emOD0moOg0?Ge
m@0:0?Ogma<000007`3ooolB0000000;05YJFP1jNWX0EUIF07YjNP2=SHd0WinO0;Bd]02o_kl0bl_;
0<S8b03;bl/00`3Cdm<00`3Bd]80f=SH0=?Cd`040=SHf0050=?Cd`3Hf=P0dm?C0<_;b`3Cdm<00`3;
bl/01P38b<P0bl_;0<_;b`38b<P0_kno0<?3``80^[Zj01L0/K6a0:f][@2FUYH0Y:BT09VIV@1lO7`0
LG5a06e]K@1JFUX0BDU906][J`0O7al05aLG01/K6`1FEUH0NWYj06e]K@1iNGT0UYJF0?Gem@3gmoL0
mOGe0?ooo`090?Ogma<000007`3ooolB0000000;05YJFP1jNWX0EUIF07YjNP2=SHd0WinO0;Bd]02o
_kl0alO70<S8b03;bl/00P3Cdm<0103Hf=P0dm?C0=SHf03Cdm<40=SHf080dm?C00D0f=SH0=?Cd`3C
dm<0bl_;0=?Cd`040<_;b`80b<S80140_kno0;Zj^P2j^[X0][Jf0;6a/@2][Jd0Y:BT09VIV@29RHT0
O7al075aL@1JFUX0BDU9051@D01[Jf/07alO01/K6`0205IFEP0707YjNP1]KFd0UYJF0<;2`P3emOD0
moOg0?Gem@0:0?Ogma<000008`3oool00240oooo4P00000205IFEP0=05mOG`1lO7`0SHf=0:BTY02d
];@0][Jf0<;2`P38b<P0bl_;0=7Ad@3;bl/0f=SH0<k>cP050=?Cd`030=SHf03AdM40dM7A0080bl_;
00<0`<300<_;b`38b<P00`38b<P01@3;bl/0b<S80<S8b02j^[X0_Kfm0080];Bd00P0/K6a0:VYZ@2F
UYH0RHV907UiN@1aLG40IFEU05YJFP80EUIF00/0=SHf04U9B@19BDT0ADE507alO01aLG40QhN70:j^
[P2n_[h0moOg0?ooo`0;0?Ogma<000007`3ooolB00000080EUIF00`0GemO07YjNP2=SHd0Y:BT0;Bd
]02f][H0bl_;0<S8b03;bl/0dM7A0<_;b`3>c/h60=?Cd`030=SHf03AdM40bl_;0080bl_;00<0`<30
0<_;b`38b<P00`38b<P0203;bl/0b<S80;Zj^P2j^[X0_Kfm0;Bd]02a/K40ZJVY0P2FUYH00`29RHT0
LG5a06EUI@0205YJFP0<05IFEP0f=SH0BDU903Hf=P19BDT0O7al075aL@27QhL0SHf=0:j^[P3gmoL0
oooo2`3gmoLC000001l0oooo4P00000205IFEP0=05mOG`1lO7`0SHf=0:BTY02d];@0][Jf0<;2`P38
b<P0bl_;0=7Ad@3;bl/0f=SH0<k>cP050=?Cd`030=SHf03AdM40dM7A0080bl_;00<0`<300<_;b`38
b<P00`38b<P01@3;bl/0b<S80<S8b02j^[X0_Kfm0080];Bd00P0/K6a0:VYZ@2FUYH0RHV907UiN@1a
LG40IFEU05YJFP80EUIF00/0=SHf04U9B@19BDT0ADE507alO01aLG40QhN70:j^[P2n_[h0moOg0?oo
o`0;0?Ogma<000008`3oool00240oooo4`0000002P1DE5@0EUIF05iNGP27QhL0UYJF09nOW`2h^;P0
_Kfm0<S8b030`<020=7Ad@80d=3@00H0bl_;0=7Ad@3Cdm<0dm?C0=SHf03@d=020<_;b`040<S8b030
`<00_Kfm0;jn_P80b<S80P33`l<01@2n_[h0_Kfm0;fm_@2a/K40];Bd0080Zj^[00P0Y:BT09JFUP2>
SXh0RHV907UiN@1jNWX0KFe]051@D080BDU900P0?Cdm04E5A@22PX80Jf][075aL@1]KFd0Y:BT0;no
_`<0moOg00<0mOGe0?Ogm`3oool01`3gmoLD000001l0oooo4`0000002P1DE5@0EUIF075aL@27QhL0
UYJF09nOW`2h^;P0`/;20<S8b030`<020=7Ad@0;0=3@d03=cLd0bl_;0=7Ad@3Cdm<0f=SH0<g=c@3@
d=00bl_;0<S8b030`<000P2m_Kd0302n_[h0b<S80<?3``30`<00`l?30;jn_P2m_Kd0/K6a0;Rh^02d
];@0Zj^[0:BTY080UYJF00@0SXj>08V9R@1jNWX0KFe]0P1@D5002P19BDT0?Cdm04E5A@0b<S80PX:2
075aL@1]KFd0Y:BT09JFUP2o_kl20?Ogm`030?Gem@3gmoL0moOg00L0moOg5000000O0?oooa<00000
00X0E5AD05IFEP1NGUh0QhN709JFUP2OWil0^;Rh0;fm_@38b<P0`<300P3AdM420=3@d0060<_;b`3A
dM40dm?C0=?Cd`3Hf=P0d=3@0P3;bl/01038b<P0`<300;fm_@2n_[h20<S8b080`l?300D0_[jn0;fm
_@2m_Kd0/K6a0;Bd]0020:^[Z`080:BTY02FUYH0SXj>08V9R@1iNGT0NWYj06e]K@1@D50204U9B@08
03dm?@15ADD0PX:206][J`1aLG40KFe]0:BTY02o_kl30?Ogm`030?Gem@3gmoL0oooo00L0moOg5000
000S0?ooo`008@3ooolE0000000706][J`1aLG40O7al09JFUP2[Zj/0_kno0;Rh^0020;fm_@<0bl_;
00<0alO70<;2`P32`/800P32`/801@2f][H0/K6a0;Bd]02d];@0ZJVY00<0Y:BT00D0XZ:R0:NWY`2R
XZ80XZ:R09JFUP0309VIV@08096AT@2>SXh0UYJF08j>SP22PX80KFe]06=SH`1`L70306][J`0904U9
B@1SHf<0KFe]075aL@1]KFd0SHf=08N7Q`2d];@0kno_00/0moOg5P00000O0?oooaD0000000L0Hf=S
075aL@1lO7`0UYJF0:^[Z`2f][H0^;Rh0080_Kfm0`3;bl/02037alL0`/;20<;2`P32`/80_Kfm0;Jf
]P2a/K40];Bd0P2YZJT20:BTY0030::RXP2WYjL0Y:BT0080XZ:R102IVIT02@2ATI40UYJF08j>SP29
RHT0PX:206e]K@1`L700Jf][05EEE@0206][J`0906=SH`1]KFd0KFe]075aL@2=SHd0QhN70;Bd]02o
_kl0kno_00X0moOg5P00000O0?oooaD0000000L0Jf][075aL@1lO7`0UYJF0:^[Z`2o_kl0^;Rh0080
_Kfm0`3;bl/00`37alL0`/;20<;2`P020<;2`P050;Jf]P2a/K40];Bd0;Bd]02YZJT00`2TY:@01@2R
XZ80YjNW0::RXP2RXZ80UYJF00<0VIVI00P0TI6A08j>SP2FUYH0SXj>08:2PP1]KFd0Hf=S071`L0<0
Jf][00T0BDU906=SH`1]KFd0LG5a06e]K@2=SHd0QhN70;Bd]03_knl02`3gmoLF000002<0oooo000Q
0?oooaD0000000X0Hf=S07YjNP29RHT0Ogmo08j>SP2FUYH0^;Rh0<;2`P38b<P0alO70P32`/804@2o
_kl0];Bd0;Bd]02YZJT0];Bd0:^[Z`2][Jd0ZJVY0:^[Z`2FUYH0TI6A09VIV@2=SHd0Y:BT08f=S@22
PX80SXj>0080PX:201D0SHf=08N7Q`29RHT0RHV907alO02>SXh0PX:208N7Q`1jNWX0O7al06=SH`1`
L700O7al05YJFP0m?Cd0EUIF08N7Q`22PX80SHf=0:f][@2h^;P01P3gmoL00`3emOD0moOg0?Ogm`03
0?OgmaH000007`3ooolE0000000:06][J`1jNWX0RHV907moO`2>SXh0];Bd0;Rh^032`/80b<S80<O7
a`80`/;201<0_kno0;Bd]02d];@0];Bd0;no_`2[Zj/0[Jf]0:^[Z`2FUYH0WinO096AT@2IVIT0Y:BT
08f=S@2IVIT0PX:208j>SP22PX80SHf=0080QhN700L0RHV907alO02>SXh0UYJF08:2PP27QhL0O7al
0080Hf=S00X0L71`07alO00m?Cd0EUIF08:2PP27QhL0SHf=0:f][@2h^;P0_[jn2`3gmoLF000001l0
oooo5@0000002P1SHf<0NWYj08V9R@1oOgl0SXj>09JFUP2h^;P0`/;20<S8b037alL20<;2`P0A0;no
_`2d];@0];Bd0:VYZ@2d];@0Zj^[0:f][@2YZJT0Zj^[09JFUP2ATI40VIVI08f=S@2TY:@0SHf=08:2
PP2>SXh00P22PX805@2=SHd0QhN708V9R@29RHT0O7al08j>SP22PX80QhN707YjNP1lO7`0Hf=S071`
L01lO7`0FUYJ03dm?@1FEUH0QhN708:2PP2=SHd0[Jf]0;Rh^0060?Ogm`030?Gem@3gmoL0moOg00<0
moOg5P00000S0?ooo`008@3ooolF00000005075aL@1jNWX0Hf=S08j>SP2OWil00`3:b/X20<;2`P03
0;Rh^02YZJT0[Jf]0080Zj^[0`2YZJT209JFUP0L08j>SP29RHT0SXj>08V9R@1iNGT0RHV9075aL@1]
KFd0RHV9075aL@27QhL0NGUi07alO01jNWX0O7al06=SH`1`L700NGUi071`L01aLG40L71`05IFEP1J
FUX0IfMW06e]K@1aLG40NWYj09JFUP80^;Rh00D0WinO0?Ogm`3gmoL0moOg0?Gem@070?OgmaL00000
7`3ooolE0000000605IFEP1aLG40NWYj06=SH`2>SXh0_[jn0`3:b/X02032`/80^;Rh0;Jf]P2YZJT0
[Jf]0:^[Z`2YZJT0Zj^[0P2YZJT03P2FUYH0SXj>08j>SP29RHT0SXj>07UiN@29RHT0QhN7075aL@1]
KFd0LG5a08N7Q`1aLG40NGUi0P1lO7`02`1SHf<0Jf][071`L01iNGT0LG5a071`L01aLG40EUIF05YJ
FP1]KFd0LG5a0080NWYj0P2h^;P01@2OWil0moOg0?Ogm`3gmoL0mOGe00P0moOg5P00000O0?oooaH0
000000D0LG5a07YjNP1SHf<0SXj>09nOW`030<[:bP80`/;200<0^;Rh0:VYZ@2][Jd00P2[Zj/30:VY
Z@80UYJF01`0SXj>08V9R@2>SXh0RHV907UiN@29RHT0LG5a06e]K@29RHT0LG5a08N7Q`1iNGT0O7al
07YjNP1lO7`0Hf=S071`L01iNGT0L71`075aL@1`L700EUIF05YJFP1WIfL0KFe]075aL@1jNWX0UYJF
0P2h^;P01@2OWil0moOg0?Ogm`3gmoL0mOGe00L0moOg5`00000S0?ooo`008@3ooolF0000000707If
MP27QhL0YjNW0:ZZZP2NWYh0ZZZZ0;Jf]P020;jn_P0Z0;Jf]P2d];@0ZJVY0:^[Z`2FUYH0WinO0:VY
Z@2FUYH0WinO09JFUP2ATI40QhN7075aL@2FUYH0O7al09JFUP27QhL0SHf=07YjNP1]KFd0UYJF07Yj
NP1lO7`0NWYj08:2PP27QhL0GemO07YjNP1iNGT0IfMW071`L01lO7`0KFe]06EUI@1]KFd0IFEU075a
L@2/[:`0]KFe0:f][@2^[Zh0d];B0`3gmoL00`3oool0moOg0?Ogm`050?OgmaL000007`3ooolF0000
000707IfMP27QhL0YjNW0:ZZZP2f][H0ZZZZ0;Jf]P020;jn_P0=0;Bd]02[Zj/0ZJVY0:^[Z`2FUYH0
ZJVY09nOW`2FUYH0WinO096AT@27QhL0RHV9075aL@0209JFUP0B08N7Q`1lO7`0SHf=07YjNP2FUYH0
NWYj08V9R@1lO7`0NWYj08N7Q`1OGel0Jf][07YjNP1iNGT0L71`07alO01UIFD0KFe]0P1UIFD01P1a
LG40QhN70:b/[02][Jd0[Zj^0=;BdP<0moOg00<0oooo0?Ogm`3gmoL01@3gmoLG000001l0oooo5P00
00001`1fMWH0QhN70:NWY`2ZZZX0WYjN0:ZZZP2f][H00P2n_[h0:P2f][H0];Bd0:VYZ@2[Zj/0UYJF
09nOW`2YZJT0UYJF09nOW`2FUYH0TI6A08N7Q`1aLG40UYJF07alO02FUYH0QhN708f=S@1jNWX0KFe]
09JFUP1jNWX0O7al07YjNP22PX80QhN705mOG`1jNWX0NGUi06MWI`1`L700O7al06e]K@1UIFD0KFe]
06EUI@1aLG40[:b/0;Fe]@2][Jd0[Zj^0=;BdP<0moOg00<0oooo0?Ogm`3gmoL01@3gmoLG000002<0
oooo000Q0?oooaL0000000X0Jf][08:2PP2>SXh0SXj>0;Jf]P2h^;P0];Bd0:f][@2[Zj/0[Zj^0P2O
Wil05@2>SXh0UYJF08j>SP2>SXh0UYJF08V9R@2FUYH0NWYj07moO`1UIFD0PX:207YjNP2>SXh0O7al
07YjNP1lO7`0UYJF06=SH`1aLG40RHV907YjNP0206][J`0405IFEP19BDT0D51@06=SH`<0EUIF00L0
IFEU07alO02FUYH0alO709jNWP2^[Zh0QhN700/0moOg6000000O0?oooaL0000000T0Jf][08:2PP2>
SXh0WYjN0;Jf]P2h^;P0];Bd0:f][@2^[Zh00`2OWil208j>SP0?09JFUP2>SXh0UYJF09JFUP1jNWX0
LG5a07moO`1UIFD0NWYj08j>SP1aLG40O7al07YjNP2FUYH0Hf=S0080LG5a00L0RHV906][J`1[Jf/0
FUYJ05IFEP19BDT0Hf=S00@0EUIF00H0O7al09JFUP2/[:`0alO70:j^[P27QhL;0?OgmaP000007`3o
oolG0000000:06][J`22PX80SXj>08j>SP2f][H0^;Rh0;Bd]02][Jd0Zj^[0:j^[P80WinO01D0SXj>
09JFUP2>SXh0SXj>09JFUP29RHT0UYJF07YjNP1oOgl0IFEU08:2PP1jNWX0SXj>07alO01jNWX0O7al
09JFUP1SHf<0LG5a08V9R@1jNWX00P1[Jf/0101FEUH0BDU9051@D01SHf<305IFEP0706EUI@1lO7`0
UYJF0<O7a`2NWYh0[Zj^08N7Q`0;0?OgmaP000008`3oool00240oooo600000000`2PX:00WinO0:NW
Y`030;Rh^0<0WinO0100UYJF09nOW`2FUYH0UYJF08V9R@2FUYH0QhN707YjNP1lO7`0IFEU08:2PP1S
Hf<0BDU907alO01JFUX0NWYj0P1lO7`02P1NGUh0KFe]04E5A@19BDT0IfMW05iNGP1JFUX0IfMW06EU
I@1]KFd206EUI@0:06MWI`1]KFd0[Jf]09JFUP2^[Zh0Hf=S09jNWP22PX80d];B0?ooo`D0moOg00@0
mOGe0?Ogm`3gmoL0moOg6@00000O0?oooaP0000000<0X:2P09nOW`2h^;P00`2h^;P309nOW`0309JF
UP2OWil0UYJF0080RHV900@0UYJF08N7Q`1lO7`0IFEU0P22PX803`1SHf<0O7al05YJFP27QhL0NWYj
07alO01NGUh0KFe]07YjNP15ADD0BDU905iNGP1JFUX0GUiN06MWI`0306EUI@0:05IFEP1WIfL0KFe]
09JFUP2^[Zh0_[jn06=SH`22PX80d];B0?ooo`H0moOg00<0mOGe0?Ogm`3gmoL06@00000O0?oooaP0
000000<0X:2P09nOW`2WYjL00`2h^;P309nOW`0@09JFUP2OWil0UYJF09JFUP29RHT0UYJF08N7Q`1j
NWX0O7al06EUI@22PX80Hf=S04U9B@1lO7`0FUYJ07YjNP80O7al00X0GUiN06e]K@15ADD0BDU906MW
I`1NGUh0FUYJ06MWI`1UIFD0KFe]0P1UIFD02P1WIfL0KFe]0:f][@2FUYH0[Zj^06=SH`2NWYh0PX:2
0=;BdP3oool50?Ogm`040?Gem@3gmoL0moOg0?OgmaT000008`3oool00240oooo6`0000001P2/[:`0
]KFe0:^[Z`2WYjL0O7al08V9R@80UYJF0140RHV907IfMP29RHT0O7al08j>SP1lO7`0QhN705YJFP1`
L700Hf=S07YjNP1JFUX0Hf=S05YJFP1OGel0FUYJ051@D00205IFEP0404U9B@15ADD0EUIF05IFEP80
E5AD00H0Hf=S07YjNP1jNWX0NWYj09nOW`2e]KD207UiN@030:NWY`2FUYH0jNWY0080mOGe00H0moOg
0?Gem@3gmoL0moOg0?Gem@3gmoLL000001l0oooo6P0000001`2CTi<0[:b/0;Fe]@2[Zj/0YjNW08V9
R@22PX800P2FUYH208V9R@0>08N7Q`1lO7`0SXj>08N7Q`1JFUX0LG5a071`L01SHf<0FUYJ06=SH`1U
IFD0FUYJ05mOG`1@D50305IFEP0404U9B@1FEUH0EUIF05IFEP80E5AD101jNWX01P2OWil0NGUi07Ui
N@22PX80YjNW0>WYj@80mOGe103gmoL00`3emOD0moOg0?Ogm`0K000001l0oooo6`0000001P2/[:`0
]KFe0:^[Z`2WYjL0O7al08V9R@80UYJF0140RHV907IfMP29RHT0O7al08j>SP1lO7`0QhN705YJFP1`
L700Hf=S07YjNP1JFUX0Hf=S05YJFP1OGel0FUYJ051@D00205IFEP0404U9B@15ADD0EUIF05IFEP80
E5AD00H0Hf=S07YjNP1jNWX0NWYj09nOW`2e]KD207UiN@030:NWY`2FUYH0jNWY0080mOGe00H0moOg
0?Gem@3gmoL0moOg0?Gem@3gmoLL000002<0oooo000Q0?oooa/0000001`0Ti>C0;Rh^02h^;P0[:b/
07YjNP2>SXh0O7al08N7Q`1jNWX0L71`08:2PP1`L700O7al071`L01lO7`0FUYJ06e]K@1[Jf/0D51@
04U9B@1jNWX0EUIF05YJFP1FEUH0E5AD04U9B@0m?Cd0=SHf0`15ADD02@1]KFd0FUYJ06=SH`22PX80
WinO0<;2`P2e]KD0WYjN08N7Q`0206][J`040>WYj@3oool0oooo0?Gem@D0moOg7@00000O0?oooa/0
000000D0Ti>C0;Rh^02h^;P0[:b/08j>SP0207alO00508N7Q`1jNWX0PX:208:2PP1`L7000P1lO7`0
2P1JFUX0NWYj06e]K@1[Jf/0BDU907YjNP1@D500EUIF05YJFP1DE5@204U9B@0@03dm?@0f=SH0ADE5
04E5A@1DE5@0KFe]05YJFP22PX80WinO09JFUP32`/80]KFe08N7Q`1[Jf/0WinO06][J`80oooo00<0
mOGe0?Ogm`3gmoL0103gmoLL000001l0oooo6`000000702CTi<0^;Rh0;Rh^02/[:`0NWYj08j>SP1l
O7`0QhN707YjNP1`L700PX:2071`L01lO7`0L71`07alO01JFUX0KFe]06][J`1@D500BDU907YjNP1F
EUH0FUYJ05IFEP1DE5@0BDU903dm?@0f=SH304E5A@0906e]K@1JFUX0Hf=S08:2PP2OWil0`/;20;Fe
]@2NWYh0QhN70080Jf][00@0jNWY0?ooo`3oool0mOGe1@3gmoLM000002<0oooo000Q0?oooa`00000
00`0]KFe0;jn_P2/[:`0NWYj06][J`1lO7`0SXj>09>CT`27QhL0Jf][07YjNP1SHf<207alO00706=S
H`1jNWX0L71`06MWI`0b<S80BDU907YjNP0205IFEP0503dm?@1FEUH0?Cdm038b<P0f=SH00P0b<S80
2`1NGUh0PX:209JFUP29RHT0UYJF09>CT`1OGel0MgMg08N7Q`22PX80ZJVY00D0moOg00@0mOGe0?Og
m`3oool0moOg7@00000O0?oooa`0000001X0]KFe0;jn_P2/[:`0Jf][09>CT`1lO7`0SXj>09>CT`1[
Jf/0PX:207YjNP1SHf<0O7al06=SH`1aLG40NWYj071`L00b<S80BDU905IFEP1jNWX0EUIF03dm?@1F
EUH0ADE503dm?@<0<S8b00`0BDU905iNGP22PX80RHV909JFUP2e]KD0Ti>C05mOG`27QhL0PX:206e]
K@2YZJT60?Ogm`030?ooo`3gmoL0000001`000007`3ooolL0000000<0;Fe]@2n_[h0[:b/07YjNP1[
Jf/0O7al08j>SP2CTi<0QhN706][J`1jNWX0Hf=S0P1lO7`01`1SHf<0NWYj071`L01WIfL0<S8b04U9
B@1jNWX00P1FEUH01@0m?Cd0EUIF03dm?@0b<S80=SHf0080<S8b00/0GUiN08:2PP2FUYH0RHV909JF
UP2CTi<0GemO07MgM`27QhL0PX:20:VYZ@050?Ogm`040?Gem@3gmoL0oooo0?Ogmad000008`3oool0
0240oooo7P000000102h^;P0PX:206][J`2>SXh2071`L00>07alO01WIfL0MWIf071`L01WIfL0Jf][
07alO01SHf<0NWYj075aL@1WIfL0Hf=S04U9B@1OGel205IFEP0@05iNGP1]KFd0E5AD05ADE01OGel0
KFe]07alO02=SHd0WinO0<K6aP2CTi<0Ng]k04U9B@1`L700PX:209>CT`D0moOg00<0oooo0?Ogm`3e
mOD07`00000O0?oooah0000000@0^;Rh06][J`1jNWX0SXj>0P1`L7002`1WIfL0Hf=S07IfMP1`L700
Jf][07alO01`L700Hf=S07YjNP1WIfL0Hf=S0080BDU90140GemO05IFEP1NGUh0E5AD06e]K@1DE5@0
GemO06e]K@1iNGT0O7al08f=S@36a/H0Ti>C09jNWP1kNg/0BDU908:2PP0209>CT`D0moOg00<0oooo
0?Gem@0000007P00000O0?oooah0000000@0^;Rh08:2PP1[Jf/0SXj>0P1`L7003P1lO7`0IfMW07If
MP1`L700IfMW06][J`1lO7`0Hf=S07YjNP1aLG40IfMW06=SH`19BDT0GemO0P1FEUH0401NGUh0KFe]
05ADE01DE5@0GemO06e]K@1lO7`0SHf=09nOW`36a/H0Ti>C07]kN`19BDT0L71`08:2PP2CTi<50?Og
m`030?ooo`3gmoL0mOGe01l000008`3oool00240oooo7`000000202h^;P0Hf=S07UiN@27QhL0L71`
06][J`1JFUX0EUIF0P1SHf<0701[Jf/0L71`06=SH`1jNWX0PX:2075aL@1`L700NWYj05IFEP1DE5@0
L71`06][J`1UIFD0KFe]07YjNP27QhL0WinO09JFUP2h^;P0WYjN09ZJVP27QhL0EUIF07IfMP27QhL0
PX:207moO`3gmoL20?ooo`040?Ogm`3emOD0mOGe0?ooob0000007`3ooolO0000000606=SH`1WIfL0
NGUi08N7Q`1`L700FUYJ0P1FEUH00`1SHf<0Jf][071`L00206=SH`0A07YjNP1aLG40L71`05IFEP1j
NWX0EUIF071`L01[Jf/0Hf=S06EUI@1]KFd0QhN709nOW`2>SXh0UYJF0;Rh^02JVYX00P27QhL02`1F
EUH0MWIf08:2PP1oOgl0oooo0?Ogm`3oool0moOg0?Gem@3oool0mOGe020000007`3ooolO00000008
0;Rh^01SHf<0NGUi08N7Q`1`L700Jf][05YJFP1FEUH206=SH`0L06][J`1`L700Hf=S07YjNP22PX80
LG5a071`L01jNWX0EUIF05ADE01`L700Jf][06EUI@1]KFd0NWYj08N7Q`2OWil0UYJF0;Rh^02NWYh0
VYZJ08N7Q`1FEUH0MWIf08N7Q`22PX80Ogmo0?Ogm`80oooo00@0moOg0?Gem@3emOD0oooo8000000S
0?ooo`008@3ooolR0000000A08:2PP1SHf<0Q8B4071`L01[Jf/0EUIF05=CD`19BDT0Hf=S07IfMP1a
LG40UYJF08j>SP36a/H0^;Rh09nOW`2f][H00P2[Zj/20<O7a`0>0;Bd]02e]KD0QhN707UiN@1[Jf/0
FUYJ05IFEP1SHf<0Ti>C07alO01oOgl0oooo0?Ogm`3oool30?Ogmb<000007`3ooolR0000000@08:2
PP1SHf<0L71`07alO01[Jf/0EUIF04U9B@1SHf<0EUIF07IfMP1aLG40SXj>0<K6aP3:b/X0^;Rh09nO
W`<0Zj^[0P37alL02`2e]KD0QhN706MWI`1iNGT0Jf][05IFEP1SHf<0QhN709>CT`1lO7`0oooo0080
moOg00<0oooo0?Ogm`3gmoL08`00000O0?ooob8000000140PX:206=SH`24Q8@0L71`06][J`1FEUH0
De=C04U9B@1SHf<0MWIf075aL@2FUYH0SXj>0<K6aP2h^;P0WinO0;Jf]P020:^[Z`80alO700h0];Bd
0;Fe]@27QhL0NGUi06][J`1JFUX0EUIF06=SH`2CTi<0O7al07moO`3oool0moOg0?ooo`<0moOg8`00
000S0?ooo`008@3ooolT0000000B08B4Q029RHT0UYJF0:NWY`1kNg/0De=C06MWI`1`L700Ti>C0:NW
Y`2NWYh0RHV90<30`02n_[h0a/K60=GEe@3Bd]80WinO0P2CTi<02@24Q8@0LW9b06][J`1@D500EUIF
071`L01iNGT0O7al09>CT`050?OgmbD000007`3ooolT0000000M08V9R@1oOgl0UYJF0:NWY`1CDe<0
IfMW05=CD`1`L700Ti>C09jNWP29RHT0_[jn0<30`02n_[h0eMGE0=;BdP2n_[h0WinO09>CT`24Q8@0
LW9b071`L01[Jf/0D51@071`L01iNGT0UYJF07alO02CTi<00P3gmoL00`3emOD0moOg0000000T0000
01l0oooo900000004P24Q8@0RHV909JFUP2WYjL0Ng]k05=CD`1WIfL0L71`09>CT`2WYjL0WYjN08V9
R@30`<00_[jn0<K6aP3EeMD0d];B09nOW`80Ti>C00T0Q8B4079bLP1[Jf/0D51@05IFEP1`L700NGUi
07alO02CTi<01@3gmoLU000002<0oooo000Q0?ooobH0000000X0`<300:VYZ@3Bd]80f=SH0>o_k`3H
f=P0d];B0<o?c`2n_[h0c<c<0P36a/H01@3?cll0]KFe08N7Q`27QhL0NGUi0080Ng]k00@0Hf=S05EE
E@1lO7`0QhN70P22PX801@3oool0moOg0?Ogm`3oool0mOGe02L000007`3ooolV000000090<30`02Y
ZJT0f=SH0>o_k`3Vi^H0f=SH0=;BdP2n_[h0c<c<00<0a/K600X0]KFe08N7Q`2WYjL0QhN707UiN@1k
Ng/0Hf=S06MWI`1EEED0O7al0P22PX801@1lO7`0oooo0?Ogm`3oool0mOGe02L000007`3ooolV0000
000:0<30`02YZJT0d];B0=SHf03_knl0f=SH0=;BdP3?cll0_[jn0<c<c080a/K600D0clo?0;Fe]@27
QhL0QhN707UiN@0207]kN`0406=SH`1EEED0O7al08N7Q`80PX:200D0oooo0?Ogm`3gmoL0oooo0?Ge
m@0W000002<0oooo000Q0?ooobT0000001P0a/K60<[:bP3:b/X0f=SH0=kNgP3Hf=P0c<c<0;Fe]@2P
X:00_[jn09jNWP2JVYX0K6a/07YjNP1SHf<0IfMW07]kN`2NWYh0WinO08j>SP22PX80ZJVY0?Ogm`3e
mODZ000001l0oooo:00000001036a/H0b/[:0<o?c`3:b/X20=SHf00@0<c<c03Bd]80]KFe0:2PX02N
WYh0VYZJ0:2PX01/K6`0NWYj06MWI`1kNg/0Q8B409jNWP2OWil0PX:20:VYZ@80moOg00<0mOGe0000
000000009`00000O0?ooobT0000001P0a/K60<[:bP3:b/X0f=SH0=kNgP3Hf=P0c<c<0;Fe]@2PX:00
_[jn09jNWP2JVYX0K6a/07YjNP1SHf<0IfMW07]kN`2NWYh0WinO08j>SP22PX80ZJVY0?Ogm`3emODZ
000002<0oooo000Q0?ooob`000000180f=SH0=kNgP3Bd]80c<c<0<?3``2JVYX0S8b<0:2PX01iNGT0
L71`08N7Q`1QHF40RHV909jNWP2JVYX0RHV909nOW`3Ph>0]000001l0oooo;00000004@3Hf=P0d];B
0<c<c030`<00`l?309ZJVP2PX:00NGUi07]kN`1`L700QhN708V9R@2NWYh0WinO09ZJVP29RHT0h>3P
02d000007`3oool/0000000B0=SHf03Ng]h0d];B0<c<c033`l<0VYZJ08b<S02PX:00NGUi071`L027
QhL0HF5Q08V9R@2NWYh0VYZJ08V9R@2OWil0h>3P;@00000S0?ooo`008@3ooom[000001l0ooooJP00
000O0?ooof/000008`3oool00240ooooJ`00000O0?ooofX000007`3ooom[000002<0oooo000Q0?oo
of/000007`3ooomZ000001l0ooooJ`00000S0?ooo`008@3ooom[000001l0ooooJP00000O0?ooof/0
00008`3oool00240ooooJ`00000O0?ooofX000007`3ooom[000002<0oooo000Q0?ooof/000007`3o
oomZ000001l0ooooJ`00000S0?ooo`008@3ooom[000001l0ooooJP00000O0?ooof/000008`3oool0
0240ooooJ`00000O0?ooofX000007`3ooom[000002<0oooo000Q0?ooof/000007`3ooomZ000001l0
ooooJ`00000S0?ooo`008@3ooom[000001l0ooooJP00000O0?ooof/000008`3oool00240ooooJ`00
000O0?ooofX000007`3ooom[000002<0oooo000Q0?ooof/000007`3ooomZ000001l0ooooJ`00000S
0?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo3
0?ooo`00DP3oool00d000000oooo0?ooo`060?ooo`03@000003oool0oooo07d0oooo00=000000?oo
o`3oool01P3oool00d000000oooo0?ooo`1m0?ooo`03@000003oool0oooo00H0oooo00=000000?oo
o`3oool0DP3oool00540oooo00=000000?ooo`3oool0203oool00d000000oooo0?ooo`1k0?ooo`03
@000003oool0oooo00P0oooo00=000000?ooo`3oool0N`3oool00d000000oooo0?ooo`080?ooo`03
@000003oool0oooo0540oooo001@0?ooo`04@000003oool0oooo0?ooo`A000001@3oool00d000000
oooo0?ooo`1i0?ooo`03@000003oool0oooo0080oooo0d0000050?ooo`03@000003oool0oooo07T0
oooo00=000000?ooo`3oool00`3oool3@00000@0oooo00=000000?ooo`3oool0D03oool00500oooo
00=000000?ooo`3oool00P3oool014000000oooo0?oood0000040?ooo`03@000003oool0oooo07T0
oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`050?ooo`03@000003oool0oooo07T0
oooo00=000000?ooo`3oool00P3oool014000000oooo0?oood0000040?ooo`03@000003oool0oooo
0500oooo001@0?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3ooom00000103oool00d00
0000oooo0?ooo`1i0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool01@3oool00d00
0000oooo0?ooo`1i0?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3ooom00000103oool0
0d000000oooo0?ooo`1@0?ooo`00D03oool00d000000oooo0?ooo`020?ooo`=000001@3oool00d00
0000oooo0?ooo`1i0?ooo`03@000003oool0oooo0080oooo0d0000050?ooo`03@000003oool0oooo
07T0oooo00=000000?ooo`3oool00`3oool3@00000@0oooo00=000000?ooo`3oool0D03oool00540
oooo00E000000?ooo`3oool0oooo@00000060?ooo`03@000003oool0oooo07/0oooo00=000000?oo
o`3oool0203oool00d000000oooo0?ooo`1k0?ooo`03@000003oool0oooo00@0oooo00E000000?oo
o`3oool0oooo@000001C0?ooo`00DP3oool014000000oooo@000040000050?ooo`03@000003oool0
oooo07d0oooo00=000000?ooo`3oool01P3oool00d000000oooo0?ooo`1m0?ooo`03@000003oool0
oooo0080oooo0T0000020?ooo`03@000003oool0oooo0580oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo002W0?ooo`900000J@3oool2@0000:h0oooo002Y0?ooo`03@000003oool0
oooo06P0oooo00=000000?ooo`3oool0Z`3oool009/0oooo0d0000030?ooo`=000000`3oool3@000
00D0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`040?ooo`03@000003oool0oooo
00L0oooo0d000000103ooom000000?ooo`3oool2@0000080oooo0d0000030?ooo`9000000`3oool2
@00000<0oooo0T0000020?ooo`=000000`3oool2@00000<0oooo0d00000@0?ooo`=0000000L0oooo
@000003ooom000000?oood000000oooo00A000000P3oool3@0000080oooo0T0000020?ooo`900000
Y@3oool009`0oooo00=000000?ooo`3oool00`3oool01D000000oooo0?ooo`3ooom000000080oooo
00=000000?ooo`3oool0203oool00d000000oooo0?ooo`0?0?ooo`06@000003oool0oooo@000003o
oom00000103oool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo@0000080oooo0T000002
0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@00000040?ooo`04@000003o
ool0oooo@0000140oooo00U000000?ooo`3ooom000000?oood000000oooo@000003oool00d000002
0?ooo`06@000003oool0oooo@000003ooom000001P3oool00d000000oooo0?ooo`2R0?ooo`00W03o
ool00d000000oooo0?ooo`030?ooo`05@000003oool0oooo0?oood0000000P3oool00d000000oooo
0?ooo`080?ooo`03@000003oool0oooo00l0oooo0d0000020?ooo`=000000P3oool00d000000oooo
0?ooo`020?ooo`06@000003oool0oooo@000003ooom000000P3oool00d000000oooo@0000002@000
00<0oooo00A000000?ooo`3oool0oooo0d0000020?ooo`04@000003oool0oooo@0000140oooo00Q0
00000?ooo`3ooom000000?oood000000oooo@00000<0oooo00A000000?ooo`3ooom000000P3oool0
0d000000oooo@0000002@00000<0oooo00=000000?ooo`3oool0X`3oool009`0oooo0T0000030?oo
o`900000103oool3@00000/0oooo00=000000?ooo`3oool03P3oool01D000000oooo0?oood000000
oooo00=000000P3oool3@00000<0oooo0T0000000`3ooom00000@00000020?ooo`03@000003ooom0
0000009000000P3oool4@00000040?oood0000100000@00000<0oooo0d00000@0?ooo`9000000P3o
ool2@00000030?oood000000oooo0080oooo0T0000030?ooo`=0000000@0oooo@000040000100000
0`3oool2@0000:@0oooo002L0?ooo`04@000003oool0oooo@00001<0oooo00=000000?oood000000
403oool014000000oooo0?oood00000W0?ooo`03@000003oool0oooo0<h0oooo002K0?ooo`E00000
0P3oool00d000000oooo0?ooo`0>0?ooo`=000003`3oool4@00002L0oooo0T00000A0?ooo`03@000
003oool0oooo0;`0oooo003o0?oool<0oooo003o0?oool<0oooo0000\
\>"],
  ImageRangeCache->{{{0, 449}, {149, 0}} -> {-0.184538, -0.0234427, 
  0.00750352, 0.00750352}, {{24.5625, 149.5}, {145.875, 
  20.875}} -> {-40.3294, -6.3068, 1.19876, 1.19876}, {{162, 286.938}, {
  145.875, 20.875}} -> {-205.084, -6.3068, 1.19876, 1.19876}, {{299.438, 
  424.375}, {145.875, 20.875}} -> {-369.838, -6.3068, 1.19876, 1.19876}}]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "Similar to that of the one-dimensional images, the correlation coefficient \
computations between the images in Fig. 5(a) and in Fig. 7 suggest that all \
of the sample images in Fig. 5 are the same ones. Finally, we remove the \
needless variables and check the used memories.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
Table[corRelation[Flatten[monoSampleWD[[1]]],recover2D[[i]]],{i,3}]\
\>", "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \({0.999997177768191924`, 0.999997177768188905`, 0.99999717776819299`}
      \)], "Output",
  CellLabel->"Out[65]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Remove[\"monoSampleWD\",\"recover2D\",\"recover2DG\",\"eigen2D\"];
memoryUsed\
\>", "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    InterpretationBox[\(2238\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ 2238, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.3.3 Eigen pattern of a color image",
  FontSize->12]], "Subsection",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Sample images",
  FormatType->InputForm,
  FontFamily->"Times New Roman"]], "Subsubsection",
  FormatType->InputForm],

Cell[TextData[{
  "\t",
  StyleBox["The sample data read in the ",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " front-end are converted into the color image data format. After that, we \
have a color sample image as shown in Fig. 8.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
Show[convertRGB[sample],AspectRatio->dim[[2]]/dim[[3]],
\tPlotLabel->\"Fig.8. Original color sample\"];\
\>", "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times New Roman"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -86 0 ]
[.5 1.0125 86 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -147 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.8) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Original) show
159.000000 12.812500 moveto
(color) show
195.000000 12.812500 moveto
(sample) show
231.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
EFEFF7F7EFE7F7F7F7F7F7F7EFEFF7F7EFE7EFEFE7EFEFE7F7F7F7EFEFE7F7EFE7EFCEB5EFCEB5\
EFCEB5EFCEBDEFD6C6EFCEBDEFCEBDEFCEBDEFCEBDEFCEBDF7EFE7F7E7DEC6846B
E7C6ADEFCEBDE7C6ADE7C6ADE7BDA5EFC6A5EFC6A5E7BD9CEFC6A5EFC6ADEFC6A5EFC6ADE7BDA5\
E7BDA5EFC6A5EFC6A5EFCEADEFCEADEFC6ADEFC6ADEFC6A5EFC6A5EFC6A5EFC6AD
EFB59CEFC6ADEFC6ADEFC6ADF7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5EFCEADF7CEB5\
EFC6ADEFC6ADF7C6B5F7CEB5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFC6A5
EFC6A5EFC6A5EFC6ADEFC6ADE7C6ADEFC6ADEFC6ADEFC6A5EFC6ADEFC6ADEFC6A5F7DECEF7EFE7\
F7DECECE946BE7BDA5E7BDA5EFC6A5EFC6A5E7BDA5E7BDA5E7BDA5E7C6ADE7C6AD
E7C6ADE7C6ADE7C6ADE7C6ADEFCEB5EFCEADEFC6B5EFCEADF7D6BDF7CEB5F7D6BDF7D6BDF7D6BD\
EFCEBDF7D6BDEFCEB5E7C6B5E7C6ADD6BDADD6BDADE7BDA5E7BDA5E7BD9CD6BDAD
EFDECEE7DEDEDEAD8CE7CEBDEFE7E7F7EFF7F7F7F7EFEFF7
EFEFF7F7EFF7F7EFF7EFEFE7F7EFE7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7EFE7EFEFE7EFCEBD\
EFCEBDEFCEBDEFCEBDEFCEBDEFCEBDEFCEBDEFCEB5EFCEB5EFCEB5F7E7DED6A58C
EFC6ADEFCEB5E7C6B5E7C6ADE7C6ADE7BDA5E7BDA5E7BDA5EFBD9CEFC6A5EFC6ADEFC6A5EFC6AD\
EFC6A5EFBD9CEFC6ADEFCEB5EFC6ADEFC6ADEFC6A5EFC6A5EFB59CEFBD9CEFC6A5
EFC6A5E7BDA5EFC6A5EFC6ADEFC6A5EFC6ADEFCEADF7C6B5EFC6ADEFC6ADF7CEB5EFC6ADEFC6AD\
F7CEB5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADF7C6B5EFC6ADEFC6ADEFC6A5EFC6A5
EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADE7C6ADE7BDA5EFC6ADEFC6ADEFC6A5EFC6ADEFC6A5F7DECE\
F7EFE7D6AD84DE8473EFC6A5EFC6A5EFC6A5E7BDA5E7BDA5E7BDA5E7BDA5E7BDA5
EFC6A5EFC6ADEFC6ADEFC6ADEFCEADEFC6ADEFCEB5EFC6ADEFCEB5EFCEB5EFCEBDEFCEBDEFCEBD\
F7D6BDEFCEBDEFCEBDE7C6ADE7C6B5E7C6ADE7C6ADE7BDA5E7BDA5E7C6ADEFE7DE
EFE7E7E7BD9CE7BD94E7BDA5EFE7E7F7EFF7EFEFF7F7EFE7
EFEFE7EFEFE7EFEFE7F7EFE7EFEFF7EFEFF7EFEFF7F7EFE7EFEFF7EFEFF7F7F7F7F7F7F7F7EFF7\
EFCEBDEFCEB5EFCEB5EFCEB5F7C6B5EFCEB5EFCEB5EFC6B5EFCEB5F7DED6F7E7DE
C67B4AE7C6ADEFC6B5E7C6B5E7BDA5E7B59CE7BDA5EFC6A5EFC6A5EFC6A5EFC6ADEFC6A5EFC6AD\
EFC6A5E7BDA5EFB59CEFCEADEFCEADEFC6ADEFC6A5EFBD9CEFBD9CE7BD9CE7BD9C
E7B59CE7B59CE7B59CEFBD9CEFC6A5EFC6ADEFC6ADEFCEADEFC6ADEFC6ADEFC6ADEFC6ADEFC6A5\
EFC6ADEFC6ADEFCEB5F7CEB5F7CEB5EFCEADF7C6B5F7CEB5EFC6ADEFC6ADEFC6AD
EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6A5\
EFCEBDF7EFE7F7DECEC68463E7BDA5E7BDA5E7BDA5EFC6A5E7C6ADE7BDA5E7BDA5
EFC6A5E7BDA5E7BDA5EFC6ADEFCEB5EFCEADEFCEB5EFCEADEFCEB5EFCEB5EFCEBDEFD6C6F7D6BD\
EFD6C6EFCEBDE7CEBDEFC6B5E7C6ADEFC6ADE7C6ADE7C6ADE7CEBDE7D6CEE7D6C6
EFE7DEE7D6C6E7BD9CE7BDA5E7DED6EFEFE7F7F7F7F7EFE7
F7EFE7EFEFF7F7EFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEFE7F7F7F7F7F7F7F7EFE7EFEFF7F7EFE7\
EFEFE7EFEFE7F7D6BDEFC6B5EFCEB5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADF7E7DE
EFD6C6DEAD9CE7C6ADE7C6B5E7C6B5E7BDA5E7BDA5E7BDA5E7BDA5E7BDA5EFC6A5EFC6ADEFC6AD\
EFC6A5E7BDA5E7BDA5EFC6A5EFC6ADEFC6ADEFC6ADEFBD9CEFC6A5E7BD9CE7B59C
E7BD9CE7BD9CE7B59CE7B594E7BDA5EFC6A5EFC6A5EFC6ADEFC6ADEFC6A5EFC6ADEFC6A5EFC6A5\
EFC6A5EFCEADF7D6BDF7CEB5F7CEB5F7CEB5F7D6BDF7CEB5F7CEB5EFCEADF7CEB5
F7CEB5EFC6ADEFC6ADEFC6B5EFC6B5EFC6B5EFC6ADEFC6B5EFC6B5EFC6ADEFC6ADEFC6ADEFC6AD\
EFC6ADEFCEBDF7EFE7F7DECEDE8473EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFCEAD
EFC6ADEFC6ADEFC6B5EFC6ADEFCEADEFC6ADEFCEB5EFC6B5EFCEB5EFCEBDF7D6BDEFD6C6EFD6C6\
EFCEBDEFD6C6EFC6B5EFC6B5E7C6B5EFCEB5E7C6B5EFE7E7E7D6CEE7D6C6EFE7DE
E7BD9CE7DED6E7C6ADE7BD9CEFE7E7EFE7E7EFE7E7F7EFE7
EFEFF7F7EFF7EFEFF7F7EFF7F7F7F7F7EFF7F7EFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7\
F7F7F7EFEFF7F7EFE7F7D6BDEFCEB5F7CEB5EFC6ADEFCEADEFC6ADF7CEB5F7E7DE
F7E7DEDEAD9CEFC6ADEFC6B5E7CEBDE7BDA5E7BDA5E7BDA5EFC6A5E7BDA5E7BDA5EFC6A5EFC6A5\
EFC6ADEFC6A5EFC6A5EFC6ADEFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFC6A5EFC6A5
EFC6A5EFC6A5EFBD9CE7B59CE7BD9CE7BDA5EFC6A5EFB59CEFB59CEFB59CEFC6A5EFC6ADEFC6AD\
EFC6ADEFC6ADEFC6ADF7CEB5EFC6ADEFC6ADF7D6BDF7D6BDEFC6B5F7CEB5F7C6B5
F7CEB5F7C6B5EFC6ADEFCEB5EFCEB5EFC6B5EFC6B5EFCEB5EFCEB5EFCEB5EFC6ADEFCEB5EFC6AD\
EFC6ADEFC6ADEFCEBDF7EFE7DEAD8CE7AD9CEFC6ADEFCEADEFCEADEFCEADEFC6AD
EFC6ADEFC6ADEFCEADEFCEB5EFCEADEFCEB5F7CEB5EFCEB5EFCEB5F7CEB5F7D6BDEFD6C6EFD6C6\
EFD6C6EFCEBDEFCEBDEFCEBDE7C6B5EFD6C6EFEFE7EFE7E7EFE7DEEFE7DEEFEFE7
E7CEBDF7DED6E7BD9CE7BD9CEFE7E7F7F7F7F7EFE7EFEFE7
EFEFF7F7EFF7EFEFE7F7EFF7EFEFF7F7EFE7F7EFF7F7F7F7EFEFE7F7EFF7F7EFF7EFEFE7F7F7F7\
F7F7F7F7EFF7F7F7F7F7EFF7EFDECEEFCEB5F7CEB5EFCEB5EFCEB5EFCEB5EFCEBD
F7E7DEEFE7DEEFC6ADEFCEB5EFCEB5E7C6B5E7C6ADE7BDA5E7BDA5EFC6A5E7C6ADEFC6ADEFC6AD\
E7BDA5E7BDA5EFC6A5E7BDA5E7B59CEFBD9CEFBD9CE7BD9CEFC6A5EFC6A5EFC6A5
EFC6ADEFC6A5EFC6ADEFC6ADEFB59CE7B59CE7B59CEFBD9CE7B59CEFC6A5E7BDA5EFC6A5EFC6AD\
EFC6ADEFC6ADEFC6ADEFC6ADF7C6B5F7CEB5F7CEB5EFC6ADEFCEBDEFCEB5EFCEB5
EFCEB5F7CEB5EFCEB5F7CEB5EFCEB5EFCEBDEFCEB5EFC6B5EFCEB5EFC6B5EFC6B5EFC6B5EFC6AD\
EFCEADEFC6ADEFC6ADEFCEBDF7EFE7E7BDA5E7AD9CEFC6ADEFCEB5EFCEB5EFCEAD
EFC6B5EFCEADEFCEADF7CEB5F7CEB5F7CEB5F7CEB5EFCEB5F7CEB5EFCEBDEFCEBDEFD6C6EFD6C6\
EFD6C6EFCEBDE7C6B5DEC6B5E7BD9CE7D6CEEFE7DEF7EFE7E7C6ADE7D6CEE7C6AD
EFCEBDEFE7E7E7BDA5E7D6CEF7EFF7F7EFF7F7EFF7EFEFE7
EFEFF7F7F7F7F7F7F7F7F7F7EFEFE7F7F7F7EFEFE7F7EFF7F7EFF7F7F7F7EFEFE7F7F7F7F7F7F7\
EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7EFD6C6EFD6C6F7D6BDEFD6C6F7D6BD
F7D6BDF7EFE7E7D6D6EFC6B5EFCEBDEFCEBDE7CEBDE7C6B5E7C6ADE7BDA5E7BDA5E7BD9CE7BD9C\
E7BDA5E7B594DEAD94E7B594E7B594E7B594E7BD9CE7B594EFC6A5EFC6ADEFCEAD
EFCEADEFCEADEFCEADF7CEB5EFC6A5EFC6A5E7B59CEFBD9CE7BD9CEFBD9CE7B59CE7BD9CE7BDA5\
EFB59CEFC6A5EFC6A5EFC6ADEFC6ADEFCEADEFC6ADEFC6ADEFC6ADEFC6ADEFC6AD
EFC6B5EFC6ADEFC6ADEFCEB5EFCEB5EFC6B5EFC6B5EFC6B5EFC6ADEFC6ADEFC6ADEFC6ADEFC6AD\
E7C6ADEFC6ADEFC6ADE7C6ADEFD6C6F7EFE7F7DECEE7C6ADEFC6ADEFC6ADEFC6AD
EFC6A5EFCEADF7C6B5F7CEB5F7CEB5EFCEB5F7CEB5EFCEB5F7D6BDEFCEBDEFD6C6EFD6C6EFD6C6\
E7C6B5E7C6ADDEAD9CCEAD94E7BDA5EFE7E7E7DED6EFEFE7E7C6B5E7CEBDEFCEB5
E7CEBDE7CEBDE7BD94EFE7E7F7EFF7F7EFE7F7F7F7EFEFF7
EFEFF7F7EFE7F7EFF7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7EFEFF7EFEFF7EFEFE7EFEFF7EFEFF7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7EFEFF7F7DED6F7DECEF7DECEF7DECE
EFDECEEFDECEF7EFE7EFD6C6BD947BEFCEBDEFC6B5EFC6ADE7BDA5E7BDA5E7BDA5E7BDA5E7BD9C\
DEAD94DEAD94E7B594E7B594E7B594E7B594E7B594E7B594E7BDA5EFC6A5EFC6AD
EFCEADEFCEADEFCEADF7CEB5EFC6ADEFC6ADEFB59CE7B59CE7B594E7B594E7B59CE7BDA5E7B59C\
E7B594E7B594E7B59CE7BDA5E7BDA5E7BDA5EFC6A5E7BDA5E7BDA5EFBD9CE7BDA5
EFC6A5E7BDA5EFC6A5E7C6ADE7BDA5E7C6ADEFC6A5EFC6A5E7BDA5E7BDA5E7BDA5E7BDA5E7BDA5\
E7BDA5E7BDA5EFC6A5E7BDA5E7BDA5E7D6D6F7E7DEE7C6B5E7C6ADEFC6A5EFC6AD
EFC6ADEFC6ADEFC6ADEFCEB5F7CEB5EFCEB5EFCEB5F7D6BDF7D6BDEFCEBDEFCEBDEFCEBDE7C6AD\
E7BDA5D69C7BD6AD84CEAD94E7C6ADE7D6CEE7C6ADDEAD8CE7BDA5EFC6A5E7BD94
E7D6CEE7C6B5E7BD9CEFE7DEF7EFF7EFEFE7F7EFE7EFEFF7
EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7EFE7F7EFF7F7EFF7F7F7F7F7EFF7EFEFF7\
EFEFE7F7F7F7F7EFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7EFF7F7EFF7
F7F7F7F7F7F7F7EFF7F7EFF7F7EFE7D6BDADE7C6ADEFC6ADE7C6ADE7BDA5E7BDA5E7BDA5E7B59C\
E7BD9CD6B5A5E7BD9CE7BD9CEFBD9CEFC6A5EFC6A5EFBD9CE7B594EFBD9CEFC6A5
EFCEADEFCEADEFCEADEFCEADF7CEB5EFCEADEFC6A5EFB594EFBD9CEFC6A5EFB59CEFBD9CEFBD9C\
E7BDA5E7BDA5E7B594E7B594DEAD8CDEAD94DEAD8CDEA584DEAD94DEAD8CDEAD8C
DEAD8CDEA584DEAD8CDEAD8CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94E7BD9CE7B59C\
E7BD9CE7BD9CE7BD9CE7B59CE7B594E7BD9CDEAD94E7CEC6E7CEC6D6AD8CDE8473
DEAD94E7BDA5E7BDA5EFC6ADEFC6ADEFC6ADEFCEB5EFCEBDEFCEBDEFD6C6EFCEBDE7C6B5CE9463\
D69C73DEAD8CCEB5A5DEAD8CDEAD8CE7C6B5E7C6ADE7BDA5E7BD94E7BD9CE7DED6
E7CEBDE7BD9CE7D6D6EFE7DEEFEFF7F7EFF7EFEFE7EFEFE7
F7F7F7F7EFF7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7EFEFE7F7EFE7EFEFF7EFEFF7\
F7EFE7F7F7F7EFEFF7EFEFE7F7F7F7EFEFF7F7F7F7F7EFF7F7F7F7F7EFF7EFEFF7
F7F7F7F7EFF7F7EFF7F7EFE7F7F7F7EFEFF7E7BD9CD69C7BE7D6C6E7BDA5DEAD9CE7BDA5E7BDA5\
E7BD9CD6B5A5D6B5A5DEAD94E7B594E7BD9CEFBD9CEFBD9CE7B594E7BD9CEFC6A5
EFC6A5F7CEB5EFCEADF7CEB5EFCEADEFC6ADEFC6ADEFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFBD9C\
EFC6A5EFC6A5EFC6A5EFBD9CEFC6A5EFBD9CEFBD9CE7BD9CE7B59CE7BD9CE7B59C
E7B59CE7B59CE7BD9CE7B59CE7B59CEFBD9CE7BD9CEFBD9CE7BDA5E7BDA5EFC6A5EFC6A5E7B59C\
EFC6A5EFC6A5EFC6A5E7BDA5EFC6A5E7BDA5E7BDA5EFBD9CEFC6B5E7CEBDE7CEC6
E7BDA5945A31E7B59CDEAD9CE7BDA5E7C6ADE7C6ADE7C6B5D6AD8CC6845AC67B4AC67B4ACE8C5A\
DEAD8CE7BD94E7BDA5DEAD8CE7BD94E7BD9CE7BDA5E7CEBDE7C6ADDEAD8CEFD6C6
E7D6C6DEAD8CEFDECEE7DED6F7EFE7F7EFF7F7F7F7EFEFF7
EFEFE7EFEFF7F7F7F7EFEFF7F7EFF7EFEFE7EFEFF7F7EFF7F7EFF7F7F7F7EFEFE7F7EFF7F7F7F7\
F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7EFEFF7F7EFF7
F7EFF7EFEFF7F7F7F7EFEFF7F7EFF7F7EFF7E7BD9CD69C73DEAD94CEAD94DEAD9CE7BD9CE7BD9C\
E7BD9CE7BD9CE7BDA5D6B5A5E7B594E7BD9CEFBD9CEFBD9CE7B594E7BD94EFC6A5
EFC6ADEFC6A5EFC6ADEFCEADEFCEADEFCEADEFCEADEFC6A5EFBD9CEFBD9CEFC6A5EFC6A5EFC6A5\
EFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFB59CEFC6A5EFC6A5EFC6A5EFC6A5E7BDA5
E7BD9CEFBD9CEFBD9CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CE7BDA5EFC6A5EFC6A5EFC6A5EFC6A5\
EFC6A5EFBD9CEFC6A5EFBD9CEFC6A5EFC6A5EFC6ADEFC6A5E7BDA5EFC6ADEFC6A5
E7CEBDDECEBDE7D6D6D6AD8CBD947BBD947BD6A584BD8C63C67B4ACE8C5AC67B4AC6845AD69C73\
D69C73E7BD94DEAD94D6AD84EFE7DEE7BD94E7BD94DEC6B5DEA57BEFCEBDEFDECE
E7BD9CE7DED6E7C6B5EFEFE7EFE7E7EFEFE7EFEFE7F7F7F7
F7F7F7EFEFF7F7EFE7F7F7F7EFEFF7F7F7F7F7F7F7EFEFE7F7EFE7F7EFE7F7F7F7F7EFF7F7F7F7\
EFEFF7F7F7F7EFEFF7F7EFF7F7EFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7
EFEFF7EFEFF7EFEFE7EFEFE7F7EFF7EFEFE7E7C6B5E7C6ADCE9463D6AD84D6AD84CE946BE7BD9C\
E7BDA5E7B59CE7BD9CDEAD9CE7BD94E7BD9CE7B594EFBD9CE7BD94E7BD94EFC6A5
EFC6A5EFC6A5EFC6ADEFC6ADEFCEADEFC6A5EFCEADEFC6A5EFC6A5EFBD9CEFBD9CEFC6A5EFC6A5\
EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFB59CEFBD9CEFBD9CEFC6A5EFC6A5
EFC6A5E7BD9CEFBD9CE7BDA5EFB59CEFBD9CEFC6A5EFC6A5EFB59CEFC6A5EFC6A5EFC6A5EFC6A5\
EFBD9CEFBD9CEFC6A5E7BDA5EFC6A5E7BD9CEFC6A5EFC6A5EFC6A5EFC6A5E7BDA5
E7BDA5E7BDA5E7CEBDE7CEC6E7CEC6D6BDADAD6331AD6B39C6845AC67B4AC6845ACE9463CE9463\
CE946BCE9463CEAD94D6B5A5E7DED6D69C73DEAD84E7C6ADDEA57BE7C6B5E7D6C6
E7BD94EFEFE7EFE7DEEFEFE7EFEFE7EFEFF7EFEFF7F7F7F7
EFEFF7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7\
F7EFF7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7F7EFF7F7F7F7F7F7F7F7EFF7
EFEFF7EFEFF7F7EFF7EFEFF7EFEFF7EFEFF7E7CEC6E7C6B5D6AD8CCE9463D6AD84C67B42AD6B39\
DEAD9CE7BD9CE7B59CE7B59CE7BD9CE7B59CE7BD9CEFB594E7B594E7BD9CEFC6A5
EFC6A5EFC6A5EFC6A5EFC6A5EFCEADEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5\
EFC6A5EFC6ADEFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFBD9C
EFBD9CEFC6A5E7BD9CEFB59CEFBD9CEFBD9CEFBD9CE7BD9CE7BDA5EFC6A5EFC6ADEFC6A5EFC6A5\
EFB59CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFC6A5E7BDA5E7BDA5E7BDA5
E7BD9CDEAD94D6A584D69C7BC67B4AB56B42C67B4AC67B42B57B5AC67B42CE9463CE8C5ACE9463\
CE946BDEAD84DEAD84DEAD8CE7C6ADDEA57BDEAD84E7BD94DEAD84E7D6C6E7C6AD
E7CEBDEFE7DEEFEFE7F7EFF7EFE7DEF7F7F7F7F7F7F7EFF7
F7F7F7F7EFF7EFEFF7F7EFF7F7EFE7F7F7F7EFEFF7F7F7F7EFEFE7F7F7F7EFEFF7F7F7F7F7EFE7\
F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7EFF7F7F7F7F7F7F7EFEFF7F7F7F7
F7EFE7EFEFE7EFEFF7F7F7F7F7EFE7EFEFF7EFDECEEFE7DEE7D6C6CE8C5ACE9463C67B42B56B39\
945229E7B59CDEAD9CE7BD9CDEAD94DEAD9CE7B59CE7BD9CE7BD94E7BD9CEFC6A5
EFC6A5EFC6A5EFC6A5EFC6A5EFC6ADEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9C\
EFBD9CEFC6A5EFBD9CEFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9C
E7BD9CE7BD9CE7BD9CEFBD9CEFBD9CEFBD9CEFBD9CE7BD9CEFBD9CEFBD9CEFC6A5E7BD9CEFBD9C\
EFBD9CEFC6A5EFC6A5EFBD9CE7BD9CEFBD9CEFBD9CEFBD9CE7B594E7BD9CDEAD94
DEAD8CD69C7BCE9463B5734AB56B42C67B4ACE8C5ACE8C5AC6946BC6845AC67B42CE9463CE9463\
DEA573DEAD8CDEAD84E7BD9CDEAD8CD69C73DEAD84DEAD84E7C6ADE7C6ADE7C6AD
E7D6C6F7EFF7EFEFE7F7EFE7F7EFE7F7EFF7F7EFF7EFEFE7
EFEFF7F7EFF7F7F7F7F7EFF7EFEFE7F7F7F7F7F7F7F7F7F7F7EFE7F7F7F7F7EFF7EFEFF7F7F7F7\
EFEFF7F7F7F7F7F7F7F7EFE7EFEFF7F7EFF7EFEFF7F7F7F7EFEFE7F7F7F7F7EFF7
F7EFE7F7F7F7F7EFF7F7EFF7EFEFE7F7EFE7E7D6CEF7EFE7E7C6ADCE8C5AC67B4AC67B42B56331\
9452297B3918DEA584DEAD8CDEAD94E7BD9CE7B59CE7BD9CE7B594E7BD94E7BDA5
EFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFBD9C\
EFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFC6A5EFC6A5EFC6A5EFB594EFB594EFBD9C
EFBD9CEFBD9CEFBD9CEFB59CEFBD9CE7BD9CEFB594E7BD94E7BD9CEFB59CEFC6A5EFBD9CEFC6A5\
EFBD9CE7BD9CEFC6A5EFC6A5EFBD9CEFBD9CE7BD9CE7B594E7B594DEAD8CDEAD84
D69C73D69C73C67B4AAD6B39C6845ACE8C5AC67B4ACE8C5AD69C7BCE8C5AC6845ACE8C5ADEA573\
CE9463D6AD84D69C73CEAD94DEA57BE7BD94E7BD94E7BD94EFDECEDEAD8CE7C6B5
EFEFE7EFEFE7F7EFF7F7E7DEEFEFF7EFEFE7F7F7F7F7EFF7
F7EFE7EFEFF7EFEFF7F7EFE7EFEFF7F7F7F7EFEFE7F7EFE7EFEFE7F7F7F7F7F7F7F7F7F7F7EFE7\
F7F7F7F7EFE7F7EFE7F7F7F7EFEFF7F7F7F7F7EFF7EFEFF7F7F7F7EFEFF7F7EFE7
F7F7F7F7EFE7F7F7F7F7EFF7F7EFE7EFEFE7EFDECEEFE7DEE7C6B5D6BDADC67B42C6845AB56B39\
9452297B39187B3918DEAD94DEAD94E7B594DEAD94E7BD9CE7BD94E7B594EFC6A5
EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFBD9C\
EFB594E7BD9CEFBD9CEFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9CE7BD9CEFB594
E7BD94E7B594EFBD9CEFBD9CEFBD9CEFB594E7BD9CE7AD8CE7BD9CE7BD94EFBD9CEFBD9CEFBD9C\
EFBD9CEFBD9CEFBD9CE7BD94DEAD84DEAD84DEA57BD69C73D69C73D69C73D69C73
C6845A9C6339945229C67B4AD69C73CE9463AD6B42CE8C5ACE946BD6AD84DEA573DEA573CE8C5A\
CE8C5ACE9463D69C73DEAD8CDEA57BE7BD94E7BD94EFE7DEE7BD9CE7C6ADEFD6C6
EFE7E7EFE7DEEFE7E7F7EFE7F7EFE7EFEFF7F7F7F7F7EFF7
EFEFE7F7F7F7F7EFF7EFEFF7F7F7F7EFEFF7EFEFF7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7\
F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFE7F7EFE7F7F7F7F7EFF7
EFEFF7EFEFE7F7EFF7F7EFE7F7EFF7EFEFE7F7EFE7E7DED6E7DED6D6AD84C6845AC67B4AAD6331\
9452298C42217B39186B3118DEAD8CE7B59CCEAD94E7BD94E7B594E7BD94EFBD9C
EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFBD9CEFBD9CEFC6A5EFBD9CEFBD9CEFC6A5EFBD9C\
EFBD9CEFB594E7BD94EFBD9CEFBD9CE7BD9CEFC6A5EFBD9CEFB594E7B594EFB594
E7B594E7B594E7B594E7B594E7BD94E7B594E7B594E7AD8CE7AD8CE7AD8CEFB594EFBD9CE7AD8C\
EFBD9CDEAD84E7BD94E7B594E7AD8CDEA57BDEA57BD69C73CE946BC6845AB5734A
945229AD5A31AD6331C6845ACE9463CE9463C68C63D69C73D69C73DEA573D69C73D69C73DEA573\
CE8C5ACE9463DEA57BDEA57BDEAD84E7BD94E7BDA5E7BD9CE7C6ADE7D6C6EFE7DE
EFE7E7E7DED6EFE7E7F7EFF7F7EFF7EFEFF7F7F7F7F7F7F7
F7EFE7EFEFE7F7F7F7F7F7F7F7F7F7EFEFE7F7F7F7F7F7F7F7F7F7F7EFE7EFEFF7F7F7F7F7EFE7\
F7EFF7EFEFE7F7EFF7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7
EFEFF7EFEFF7F7EFE7F7EFF7F7EFE7EFE7E7EFE7DEE7CEBDEFDECECE8C5AC6845AC67B42AD5A31\
9452299452298C42216B31184A1808D6A584DEAD9CDEAD94E7B594E7B594E7BDA5
E7BD9CEFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFBD9CEFC6A5EFBD9CEFBD9CEFBD9CEFBD9CE7BD9C\
EFBD9CEFBD9CEFB594EFB594E7BD94EFB594EFBD9CEFBD9CE7BD9CE7BD94EFB594
E7B594EFB594E7AD8CDEAD84E7AD8CEFB594E7AD8CE7AD8CEFB594E7AD8CE7BD94E7B594E7AD8C\
DEAD84E7B594DEAD8CDEAD8CDEAD84DEA57BD69C7BCE8C63B5734AAD6B39AD6331
9C6339AD6B42BD8C63CE946BCE8C5AC68C63CE9463D69C73CE9463C6845AC6845ACE9463CE8C5A\
DEA573DEA57BDEA57BDEA573E7BD94E7BDA5E7BDA5E7C6ADEFE7DEEFE7DEEFDECE
EFE7E7F7EFF7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFEFE7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFE7F7EFF7F7F7F7F7F7F7F7EFF7EFEFF7EFEFE7\
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7EFEFF7F7EFF7F7EFF7F7EFF7F7F7F7
F7EFF7F7EFF7F7EFF7EFEFF7F7EFE7F7EFF7EFE7E7E7D6C6E7DED6CE9463C6845AC67B4AAD6331\
9452299452298C42216329106329104A1808DEAD94DEAD94E7BD9CE7B59CE7BD9C
E7BD9CEFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9C\
EFBD9CEFBD9CE7BD94E7BD94EFBD9CEFB594E7BD9CEFB594EFB59CE7B594E7B594
E7B594E7B594E7AD8CE7AD8CE7AD8CE7AD8CDEAD84DEA57BDEAD84E7AD8CDEAD84E7BD9CDEA57B\
DEAD8CDEAD84DEAD84D69C7BDEA584D69C73C67B4AAD5A31AD6B39844221AD6B42
B5734AC67B4ACE9463CE8C5AC68C63C6946BC68C63DEA573D69C73D69C73D69C73DEA573DEA573\
DEA57BDEAD84D6AD84E7BD94E7BD9CE7BDA5E7BDA5EFCEBDEFD6C6EFDECEEFE7DE
EFEFE7F7EFE7F7F7F7F7EFF7F7F7F7F7EFF7EFEFF7F7F7F7
F7F7F7F7F7F7EFEFE7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7EFEFE7F7EFF7F7F7F7\
EFEFF7EFEFE7F7EFF7F7EFF7F7F7F7F7F7F7F7EFE7F7EFF7F7F7F7EFEFF7EFEFF7
F7EFF7F7F7F7F7EFF7EFEFF7F7EFE7EFEFE7EFE7DEE7DED6E7CEC6CE9463C6845AB56B42AD6331\
9C63399452297B39186329105221106B3118DEAD94DEAD94E7B594E7BD9CE7BD9C
E7BDA5E7BD9CEFC6A5EFBD9CEFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFB594EFBD9CEFBD9C\
E7BD94EFBD9CEFB594E7BD9CEFB594E7B594E7B594E7AD8CE7B594E7B594E7B594
E7B594E7AD8CE7AD8CDEAD84DEA584DEA57BDEA57BDEA57BDEAD84E7BD9CDEAD84D69C7BD69C73\
D69C7BDE9C73DE9C73CE8C63CE8C63C67B42C67B4A8C4A31AD5A319C6339AD6B39
9C6339C67B4ACE8C5AC6845AC6845AC68C63D69C73D69C73D6AD84DEAD8CD69C73DEA573E7BD94\
D6AD84DEAD84E7BD94E7BD94E7BDA5E7BD9CEFCEBDEFD6C6EFD6C6F7EFE7F7EFE7
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7EFEFF7F7F7F7F7F7F7
F7F7F7F7EFF7F7EFE7F7EFE7F7EFF7EFEFF7F7F7F7F7EFE7F7F7F7F7EFE7EFEFF7F7F7F7F7F7F7\
F7EFF7F7F7F7F7EFE7F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7EFEFF7EFEFF7F7F7F7
F7F7F7F7EFF7F7F7F7F7EFE7F7EFF7EFEFE7F7E7DEE7D6C6D6AD84CE9463C6845AB5734AAD5A31\
B56B399452298C4A296B31186B31187B42217B4A29DEAD9CE7BD94E7BD9CEFC6A5
E7BD9CE7BD9CEFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFBD9CE7BD9CEFBD9CE7BD9CE7B594\
EFB59CEFBD9CE7BD94EFB594EFB594E7BD94E7AD8CE7BD94DEAD84E7B594E7BD94
E7B594E7AD8CE7AD8CDEA584DEA584CE946BD69C73DEAD8CE7BD9CDEAD8CCE8C63CE946BD69C73\
CE946BD69C73CE946BC67B4AC67B42B56331AD6331C67B4AAD6B42C67B4AC67B4A
BD8C63CE9463CE946BC68C63CE8C5AC68C63D69C73CE8C5ACE946BD69C73D69C73DEA57BD69C73\
D69C73E7BD94E7BD94E7BD94E7BD9CE7CEBDEFD6C6EFE7DEEFE7DEF7EFF7F7F7F7
EFEFF7EFEFE7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7
F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7EFF7F7EFF7F7F7F7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7\
F7F7F7EFEFF7F7EFF7F7F7F7EFEFF7F7EFF7EFEFE7EFEFF7F7F7F7EFEFF7F7EFF7
F7F7F7F7EFE7F7EFF7F7EFE7EFEFE7EFE7DEEFE7E7DECEBDD6AD84C6845AC6845AB56B42B5734A\
AD6B398C4A298C4A297B39188442218C4221632910DEAD94E7BD9CE7BDA5EFC6A5
E7BD9CE7BD9CEFBD9CEFB594E7BD94EFBD9CEFB594E7BD94EFBD9CEFBD9CE7BD94EFB594E7BD94\
EFB594EFB594EFBD9CE7B594E7B594E7B594E7BD94DEAD84EFB594DEAD84E7AD8C
DEAD8CDEAD84DEA584DE9C7BCE946BD69C73D69C73E7BD94E7BD9CCE8C63CE946BD69C73D69C73\
CE8C63B57B5AB56B529C6339C67B42B56B39AD6331AD6B39C67B42C67B4AB56B42
C6845ACE9463CE9463CE8C5AC6845AB5734AD6AD84CE9463D6AD84CE946BE7BD94D69C73DEA57B\
E7BD94E7BD94E7BD94E7BD94E7C6ADE7C6B5EFE7DEEFE7E7EFE7E7F7EFF7F7F7F7
EFEFE7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7
F7F7F7EFEFF7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF7F7EFE7F7F7F7F7F7F7F7EFF7F7EFF7EFEFE7F7F7F7F7EFF7F7F7F7
EFEFF7EFEFF7F7F7F7F7F7F7F7EFE7EFE7DEEFE7DEDEAD94D6AD84C6845AB5734AAD6B429C6339\
9C63398C42218C4A299452299452297B39184A1808E7BD9CE7B594E7BDA5E7BD9C
EFBD9CE7BD9CEFBD9CEFB594EFB594EFBD9CEFB594EFB594EFB594EFB594EFB594EFB594E7BD94\
E7BD94EFB594E7B594E7BD94E7B594E7B594DEAD84DEAD84DEAD84E7AD8CDEAD84
DEAD8CDEAD8CDE9C7BD69C73CE8C63CE8C63DEAD84DEAD94CE8C63C68463C68463C68C63C68463\
B57B5AAD73528C5A42AD6B42C67B42B56B39B56B39B56B39B56B42AD6B42B56B42
C6845ACE9463CE946BBD8C63BD8C63CE9463D69C7BCE946BD69C73CE946BCE946BDEA573DEA573\
DEA57BE7BD9CE7BD9CE7BDA5EFD6C6F7EFE7EFE7DEEFE7E7EFEFE7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7EFEFF7F7EFF7EFEFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7
EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7EFE7DEE7D6CED6AD84D69C73BD8C63B57B5AB56B42AD6B42\
8C4A29844221945229945A318C4A296B39216B3118E7BDA5E7B59CEFC6A5E7BDA5
E7B594EFBD9CE7BD9CE7BD9CEFBD9CEFB594EFB59CE7BD94EFB594E7AD8CEFB594EFB594E7AD8C\
E7AD8CE7AD8CE7AD8CEFB594DEAD84E7AD8CDEAD8CDEAD84E7AD8CDEA57BDEA584
DEA57BD69C7BD69C73C6846BCE8C63CE9463D69C73CE946BC6845AC68463C6845AC6845AB57B5A\
9C63399C6B4A9C6B4AAD6B39CE8C5AC67B4AC67B42B56B39AD6B39BD8C63C67B4A
C6845ABD8C63CE8C5AC6946BD6AD84D69C73D69C73C6946BCE946BCE946BCE946BD69C73E7BD94\
E7BDA5EFC6A5E7BDA5EFD6C6EFDECEEFE7DEEFEFE7EFE7DEEFEFE7F7EFE7EFEFE7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7
F7EFF7F7EFF7F7EFF7F7EFE7EFEFF7EFE7DEE7D6C6D6AD8CCE946BC6845AB5734AAD6B42AD6B39\
945A31945229AD6B399452296B31186B3118632910E7BDA5E7B59CE7BD9CDEAD94
E7BD9CEFBD9CEFBD9CE7AD8CE7AD8CEFB594E7B594E7AD8CE7AD8CE7AD8CDEAD84E7AD8CE7AD8C\
DEAD84DEAD84E7AD8CDEA584E7AD8CDEA584DEA584DEA584DEA584DEA57BDEA57B
D69C73D69C73CE946BCE8C5AC68463D69C7BC68C63B57B5AB56B52C67B4AB5734AB57B5A946342\
B5734A9C7352AD6B39AD6B42C67B4ACE8C5AC6845AB5734AC67B4AB57B5AC67B4A
BD8C63B5734AC68C63C6946BD6AD84D6AD84D6AD84CE9463CE946BD6AD84CE9463D69C73E7BD94\
E7BD9CE7C6ADEFD6C6EFE7DEF7EFE7EFE7DEEFEFE7EFE7DEF7EFE7F7EFE7F7F7F7
F7F7F7F7F7F7F7EFF7EFEFF7F7EFF7EFEFF7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7
F7F7F7F7EFE7EFEFF7F7F7F7F7F7F7EFE7DEE7BDA5D69C73D69C73BD8C63B5734AAD6B42AD6B42\
8C4A299C63399452298442216329106B3921632910E7BD9CE7BD9CE7BD9CE7BD9C
E7BD9CE7B594EFBD9CE7BD94E7AD8CEFB594E7AD8CDEAD84E7AD8CDEAD84DEA584DEAD84DEA584\
DEAD84DEA584DEA584DEA584DEAD8CDEAD84DEA57BDE9C7BD69C7BDEA57BD69C7B
D69C7BD69C73CE946BC6845ACE946BCE8C63B57B5AB56B52B5734AAD6B42AD6B42945A319C6B4A\
9C6B4A9452299C6339B56B42CE8C5ACE8C5ACE8C5ACE946BC67B4AC67B4AB5734A
B5734ABD8C63C6946BC6845AD6A584D6AD84D69C7BC6946BD6AD84DEAD8CD69C73DEAD84E7BD94\
E7BD94EFD6C6F7DECEEFE7DEE7DED6EFE7DEEFEFE7F7EFF7F7EFF7F7EFF7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7EFEFE7
F7EFF7EFEFE7F7F7F7F7EFF7F7EFE7F7EFE7CEAD94D69C73C68C63C6845A9C63399C6B4A945A31\
9C4A319C63399C4A317B42216B39217B42216B3118E7BDA5DEAD9CE7BD9CE7B594
E7BD9CE7B594E7AD8CE7BD94E7AD8CE7AD8CE7AD8CDEAD84DEA584DEA584DEA584DE9C73DE9C7B\
DEA57BDE9C7BDE9C7BDEA584DEA57BDEA57BD69C73DE9C73D69C73D69C73D69C73
D69C73CE8C63CE8C63C6845ACE946BC6845AB5734AAD6B42AD6342AD6342946342AD6B429C6B4A\
945A31945A319C6339B56B39C67B42CE8C5AC6845ACE8C5AC6845ABD8C63B5734A
B5734AB56B42C6845AD69C73D69C7BD69C73D6AD8CD6AD8CD6AD84CE946BD69C73DEAD84E7BD9C\
E7C6B5EFDECEE7DED6EFE7DEF7EFE7EFEFE7EFE7DEF7EFF7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7
F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7EFEFF7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7EFE7EFEFF7F7F7F7F7EFF7F7EFF7F7F7F7
F7F7F7F7EFF7F7F7F7EFEFE7F7EFE7E7D6C6D6AD8CD69C73C6845AB57B5AAD6B42B5734A945229\
9C63399C6339945A315A31216329106B31186B3921E7BD9CDEAD94E7B59CDEAD94
E7B594E7B594E7AD8CE7AD8CE7AD8CDEA584DEAD84DEA57BDE9C7BDEA57BDE9C7BDE9C7BDE9C73\
CE946BCE946BCE946BD69C73D69C73DE9C7BD69C73D69C73CE946BCE946BCE946B
CE8C63CE8C63C68463BD8C63B5734AAD6B42AD6B399C6339AD6342AD6B42AD6B429C63399C6339\
9C6339AD6331B56B39B56B42C67B42CE8C5ADEA573D69C73DEAD84C68C63AD6B39
AD6B39B5734AC68C63C6845AD69C73D6AD84D6AD84D6AD84CE9463CE9463CE9463E7BD94E7C6AD\
E7C6B5E7DED6EFE7DEEFDECEEFEFE7EFE7DEF7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7EFF7
F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7EFE7EFEFF7EFEFF7F7EFF7F7F7F7F7F7F7F7F7F7EFEFF7\
F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7EFEFF7F7EFF7F7EFE7F7EFE7E7BDA5D6AD84C6946BBD8C63B5734A9C63399C6B4A945A31\
AD6B398C4A298442215229185229186B31186B3118E7BD9CDEAD94E7B594E7B59C
E7B594E7AD8CE7AD8CDEA584DEA57BDEA57BDEA57BDEA57BDE9C73D69C7BD69C73DE9C73D69C73\
D69C73CE946BCE946BCE946BCE946BD69C73D69C73CE946BCE946BCE946BC68463
C68463C6845AB57B5AC6845AB56B429C6339945A31AD6B429C6339AD6B42AD6B427B42217B4221\
8C4A29B56331C67B42C67B42C67B42C6845ACE9463D69C73CE946BD6AD84BD8C63
B5734AC6845AC6845ACE946BC6845AD6AD8CD6AD8CCE946BCE9463CE946BCE9463E7BD94E7C6AD\
EFE7DEE7DED6EFE7DEEFE7DEEFE7E7EFEFF7F7F7F7EFEFE7F7EFE7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFE7F7EFF7F7F7F7F7EFE7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7EFE7
F7EFF7F7F7F7EFEFE7F7EFF7E7DED6D6B5A5D6AD84BD8C63B57B5AAD6B429C6B4A945A31945A31\
9C63398C4A297B39186B31186B39216B39217B3918DEAD94DEAD94DEAD8CDEAD8C
E7AD8CDEAD8CDEA584DEAD8CDEA584DEA584D69C7BDE9C73DE9C73CE946BCE946BCE946BC6846B\
CE8C63CE8C63C6846BCE946BCE946BC6846BCE946BCE946BCE946BC68463C6845A
C68463C6845AB5734ACE8C5AAD6B428C4A299C6B4A9C6B4A9C6339945A318442217B4221632910\
AD6331C67B42B56331C67B42B56B42C67B4ACE9463DEA573D69C7BDEAD84BD8C63
BD8C63CE9463BD8C63CE946BC6946BD6AD84CE946BCE946BC6845ACE8C5ADEAD84E7C6ADEFD6C6\
EFDECEEFDECEE7DED6EFEFE7F7EFE7F7EFE7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7
F7F7F7EFEFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7EFEFF7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7EFEFF7F7EFE7F7EFF7EFEFF7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7EFEFF7F7EFF7EFEFE7E7C6B5D6AD8CC69C84B57B5AB57B5A9C6B4AAD63429C6339945A31\
945A316B39216B39216B31186B39216B39216B3921DEAD94DEAD8CDEAD94E7BDA5
E7AD94E7AD94E7A594E7AD94E7A594E7A594DEAD8CDEA584DEA584D69C7BCE8C63C6845ACE8C63\
C67B5AC6845AC6845AC6845AC6845ACE8C63CE8C63C6845AC6845AC6845AB57B5A
B57B5AB56B52B5734AC6845A9C63397B4A299C6339AD6B428C4A297B42217B39187B4A29945229\
AD5A31C67B42C67B42B5734AC67B42AD6B39CE9463D69C73D6AD84CE946BC6946B
C6845AC68C63C68C63BD8C63D6AD84D6AD84CE9463D69C73CE9463D6AD84D6AD84DEC6B5F7EFE7\
EFD6C6E7DED6EFEFE7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7
F7EFF7F7F7F7F7F7F7EFEFE7EFEFE7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7\
EFEFF7F7F7F7F7EFF7F7F7F7F7EFE7F7EFF7F7EFE7F7F7F7F7F7F7F7EFF7F7EFF7
EFEFF7EFEFF7EFEFF7EFE7DEDEC6B5D6AD84C6946BB57B5AB5734AAD6B429C6339B5734A9C4A31\
945A315221107342296B39216B39216B3118845231DEAD94E7C6ADEFC6ADEFC6AD
EFC6ADEFC6A5EFC6A5EFB59CEFB59CEFB59CE7AD9CE7AD94E7AD94DEAD8CDEA584D69C7BC67B5A\
C67B5AC67B4AC67B5AC67B5AB57B5AB57B5AB57B5AC6845AC67B5AB57B5AC67B4A
B5734AAD6B42AD6B42C67B4A8C4A298C4A319C63398C5A428442216B31186B3921AD6331844221\
9C6339C67B4AC67B42B5734AAD6B39B5734ACE8C5AD69C7BDEAD84DEAD8CD6AD84
C6946BC6946BB57B5AB56B42D6AD84D6AD84C6946BCE946BD6AD84D6AD84E7BD9CEFEFE7EFE7DE\
EFE7DEEFE7DEEFEFE7F7EFE7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7EFEFF7
F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7EFEFE7F7F7F7F7EFF7F7F7F7F7EFE7
EFEFF7F7EFF7F7EFF7E7CEBDD6B5A5D69C73C68C63B57B5AAD7352945A319C6339945A319C6339\
8442216329107B42217342296B39216B3118B58463EFC6ADEFC6B5F7D6BDF7C6B5
F7C6B5EFC6ADEFC6ADF7C6B5EFC6ADEFC6ADEFB59CEFB59CE7B59CE7AD94DEAD8CDEA584DE9C7B\
CE946BC67B4AB5734AB57B5AC67B4AC67B4AC67B5AB56B52B57B5AC67B4AB57B5A
B5734AAD6B42946342B5734A945A319C6339B5734A8442217B39186B3118734A31B56B398C4221\
9C6339B56B42C67B4AB56B39AD6B39B5734AC6845ACE8C5ADEAD84DEAD8CD6AD84
D69C73C6946BB5734ABD8C63D69C73D69C73D69C73D69C73E7BD94D69C73E7BD9CEFEFE7EFDECE\
E7D6C6F7E7DEEFE7E7F7F7F7F7EFF7F7F7F7EFEFF7F7EFF7EFEFF7F7EFF7F7EFF7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7EFE7F7F7F7F7EFF7F7EFE7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7EFE7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7EFEFF7EFEFF7
F7EFE7F7EFF7F7EFF7E7CEBDCEAD94C6946BBD8C63AD7352AD6B42AD6B429C6339945A319C6339\
6329106B39217B4A296B39216B3921B58C73EFC6B5F7CEB5F7D6BDF7CEB5F7D6BD
F7C6B5F7D6BDF7C6B5F7CEB5F7C6B5EFC6ADEFC6A5EFC6ADEFB59CEFB59CE7AD94E7AD8CDEA584\
DEA57BD69C73CE946BB5734AB5734AB5734AB5734AC67B4AB5734AB57B5AB5734A
AD63429C6B4A845239844221B5734A945A31C6845A7B39186B3118522110632910AD6B39B56B42\
945229B56B42CE8C5AAD6B39BD8C63B5734AC6845AD69C73DEAD84E7BD94E7BDA5
D6AD8CB56B42BD8C63BD8C63CE946BC68C63D69C73D6AD8CD6AD84DEA57BEFE7E7EFDECEEFCEBD\
EFE7DEF7EFE7F7EFF7F7F7F7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7EFF7F7EFE7F7F7F7F7F7F7F7F7F7\
F7EFE7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
EFEFF7EFE7E7E7D6C6E7C6ADC69C84C6946BB57B5A9C6B4A945A319C63399C6339945A31844A29\
6329107B4A297B4A296B3921E7C6B5F7CEB5EFCEADF7CEB5F7D6BDF7D6BDEFD6C6
F7D6BDEFD6C6F7C6B5F7C6B5F7C6B5F7CEB5EFC6ADEFC6A5EFC6A5EFC6A5E7BD9CDEAD94DEAD8C\
E7AD8CDEA584D69C7BCE946BB56B52AD6B42AD6B42B5734AAD6B42B56B52AD6B42
AD63429C63398442217B4221C6845A844221CE8C639C63396B3921734A31522110844221C67B4A\
8C4221B56B42C67B4AB56B39C6845AC6845AC6845ACE9463D69C73E7BD9CE7BDA5
D6AD84C68C63B57B5ABD8C63C6946BC6946BD6AD84D6AD8CD6AD84E7BD94E7DED6E7D6CEE7DED6\
EFEFE7EFEFE7F7F7F7F7EFE7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7
F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7\
F7EFF7F7EFE7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
EFEFE7EFE7E7DECEBDD6BDADBD947BBD8C63B57B5AAD6B429463429C6339945A31945A316B3921\
6B31187B42216B3921A5846BEFCEB5F7CEB5EFC6ADF7CEB5F7CEB5F7D6BDF7D6BD
F7D6BDF7D6BDEFD6C6F7D6BDF7C6B5F7C6B5EFC6ADEFC6ADEFC6ADE7BDA5E7B59CE7BD9CE7B594\
E7AD8CDEAD94DEA584D69C7BC6846BCE946BAD6342AD6342AD6B429C6B4AAD6342
9463429C4A31844A31734229C67B4AAD7352B57B5AB5734A6B31185221107B42219C6339C67B4A\
C6845AC67B4AC67B4AC6845AAD6B42C68C63BD8C63C6946BD69C73D6AD84E7BD9C
E7BD94BD8C63B5734ABD8C63C67B4AC6946BD6B5A5E7BD94CEB5A5D6AD8CE7C6ADEFE7DEF7EFE7\
F7EFE7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
EFEFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFE7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7\
F7EFF7F7EFE7F7F7F7F7EFF7F7EFF7F7EFE7F7F7F7F7F7F7EFEFE7F7F7F7EFEFF7
EFEFE7E7DED6DECEBDCEAD94BD947BBD8C63B5734A9C6B4A845239945A318C4A29945A31522918\
6B39217342298C5A42EFC6ADEFC6B5F7CEB5F7CEB5F7CEB5F7CEB5F7D6BDF7C6B5
F7D6BDF7C6B5F7C6B5F7D6BDF7C6B5F7C6B5EFC6ADEFC6A5EFC6ADEFC6ADEFC6A5E7B59CE7B59C\
E7B594DEAD94DEAD8CDEA584D69C7BCE946BC6846B9C6339AD6342AD6342945A42
9C6339844A297B4A296329109C6B4AD69C7B8C4A29CE946B946342AD6B426B3118AD63318C4A31\
BD8C63AD6331C67B42C67B4ABD8C63B58463C6946BB57B5AD6AD84CE9463E7BDA5
EFCEB5BD8C63B5734ABD8C63C68C63C69C84D69C73D6AD84D6AD8CE7BD94E7DED6EFE7DEEFE7E7\
F7EFE7EFEFE7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7
F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7
F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7EFE7E7
EFE7E7E7CEBDDECEBDC69C84C68C63AD7352B5734A946342945A31945A318452316B39216B3118\
844A29845A42EFC6B5EFC6ADEFCEADF7CEB5F7CEB5F7CEB5F7C6B5EFCEADEFC6AD
EFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFB59CEFB59CE7BDA5EFC6A5E7BD9CEFBD9CE7B59CE7B59C\
DEAD8CE7AD8CDEAD94DEAD8CDEA584D69C73CE946BCE8C639C63399C4A319C6339
8C4A318C4A296B39216B3921845239BD8C63B57B5A9C6B4AC69C848C4221B57B5A945A31AD6342\
B56B42C67B4AAD6B39C67B4ABD8C639C6339BD8C63BD8C63D69C73D69C73CEAD94
DEAD8CE7BD94BD8C63B56B42BD8C63C69C84C6946BD6AD84E7BD94E7D6CEEFEFE7E7DED6EFEFE7\
F7EFE7EFEFE7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7F7F7F7\
F7F7F7F7EFF7F7F7F7F7EFF7F7EFE7EFEFF7F7EFF7F7EFF7F7F7F7F7F7F7EFE7E7
E7D6CEE7CEBDCEB5A5BD947BB57B5AAD7352946342945A31945A31945A315A31216B39216B3118\
6B3118EFC6B5EFC6B5F7CEB5EFCEADEFC6ADEFC6ADF7C6B5EFC6ADEFBD9CE7B59C
E7AD94E7AD94DEAD8CDEAD8CDEAD8CDEA584DEAD8CDEAD8CDEAD8CDEAD8CE7B594E7B594E7B594\
E7B59CE7B594DEAD8CDEAD8CDEA584DE9C7BD69C7BD69C73CE8C63B56B52945A31
845231844A317342296B3921734A31946342CE946BBD8C63A57B5AD69C73C67B4AB57B5A844221\
AD6B39C6845AC67B42C67B4AAD6B39B57B5AB57B5AD69C7BC6946BD69C73D6AD84
E7BDA5E7C6B5BD8C63C6946BD69C7BC6946BC68C63CEAD94E7BD9CF7EFE7E7DED6F7EFF7EFEFE7\
F7EFE7EFEFE7F7F7F7F7F7F7F7EFF7F7F7F7EFEFF7F7EFF7F7F7F7F7EFF7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7EFE7E7
E7D6C6DECEBDD6AD8CC6946BB5734AB5734AAD63428C4A31945A318452316B31186B3921844A29\
E7C6B5EFCEB5EFCEB5F7CEB5EFCEADEFC6ADEFC6ADEFC6A5E7BDA5E7AD94E7AD8C
DEA584DE9C7BE78C7BE78C7BE78C7BE78C7BE78C7BDEA584DE9C7BDEA584DEAD8CDEA584E7B594\
E7B594E7B59CDEAD94DEAD8CDEA584D6A584D69C7BCE946BCE946BC684638C5A42
8442297B4A296B39215229186B39218C634ACE946BAD7352945A31D6A584C67B4ACE9463B57B5A\
9C6339AD6B42CE8C5AC67B4AB5734ABD8C63B57B5AD69C73C6946BD6AD84D69C73
D6AD84E7C6ADD6AD84D69C73C69C84C69C84D69C73D6AD8CE7BDA5EFE7DEEFE7DEF7EFE7EFEFE7\
F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFE7F7EFE7F7F7F7F7EFF7EFEFE7E7D6CE
E7CEBDDECEC6C69C84B57B5AAD73529C6339AD6342845239844A296B39216B39217B39187B4A29\
EFC6B5EFC6B5EFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFB59CDE7363CE6B5ADE7B6B
DE7B6BDE8473DE8473DE8473DE8473DE8473CE6B5ACE6B5ACE6B5ACE6B5AD69C7BDEAD8CDEAD8C\
E7B594E7B594E7B594DEAD94DEAD8CDEA584D69C7BD69C7BCE946BC6846BC6845A
7B4A296B39216B31185221106B3118845239AD7352D69C7BB58463C6846BD6AD84CE9463D69C73\
C6946BC67B4AB5734AC6845ABD8C63AD6B39B5734ABD8C63D69C73BD8C63DEAD84
D6AD8CE7BD94E7BDA5C69C84D6AD84C6946BD69C73E7BD94DECEBDE7D6CEEFE7E7EFEFE7EFE7E7\
EFEFE7F7EFE7F7F7F7EFEFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7EFF7F7EFE7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFE7F7F7F7EFE7E7E7DED6
E7D6C6D6AD8CC6946BA57B5A9C6B4A9C6339945A317B4A298452397342296B39217B4A29EFCEBD\
EFC6B5EFC6ADEFC6ADEFC6A5EFCEADEFC6ADE78C7BDE8473DE8473DE8473EFC6B5
EFB59CE78C7BE78C7BE7A594EFB59CDE8473DE8473DE7B6BC6846BCE7363CE6B5AD69C7BDEAD8C\
DEAD94E7B594E7B59CDEAD94DEAD8CDEAD8CD6A584D69C7BCE946BDE8473C68463
B57B5A734A31522918522918522110845239522918D6A584DEAD8C9C6339D6AD8CB57B5ADEA57B\
D6AD84BD8C63C6845ACE9463AD6331C6845AB57B5ABD8C63C6946BCE946BD69C7B
D6AD8CE7BDA5E7C6B5BD947BB58463C6946BD69C73CEAD94EFE7DEEFE7DEEFEFE7EFEFE7EFE7DE\
F7F7F7F7F7F7EFEFF7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7
F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7\
F7EFF7F7EFF7F7EFF7F7EFF7F7EFE7F7F7F7F7F7F7EFEFF7F7F7F7E7D6D6DECEBD
CEAD94C6946BB58463A57B5A845239945A318C4A31945A316329106B39216B3921A5846BEFCEB5\
EFCEB5EFCEB5EFC6ADEFC6A5EFC6A5EFC6A5DE7B6BDE8473DE8473DE7B6BDE7363
DE7363DE7363DE8473CE6B5ACE6B5AC65A4AC6634AC6634AE78C7BCE7363CE7363C65A4AD6A58C\
E7AD94E7B594E7B594E7B594E7B594DEAD8CD6A584D69C7BD69C7BCE946BCE946B
C6845AAD73526B39216B39213918106B31188C5A42B58463C6946BB57B5ABD8C63D6AD84C6845A\
DEAD84EFCEADBD8C63B5734AC6845AC6845AAD6B42B57B5ACE9463C6946BD69C73
D69C73E7BDA5E7BDA5C69C84C6946BC69C84BD947BCEAD94EFE7DEEFE7E7F7EFE7EFE7E7EFE7E7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7\
F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7E7D6CED6C6B5
D69C73C6946BAD73529463428C4A31945A31844A296B31187B42216B3118945A31EFCEBDEFCEBD\
EFCEB5EFC6ADEFC6ADEFC6A5E78C7BDE8473AD73529C4A31AD4A31BD5242AD7352
BD5242BD5242C65A4AB552399C4A319C31219C4229AD4A318C3121AD42319C4229844229945A42\
DE8473E7B594E7B594E7B594DEAD8CDEAD8CDEAD8CD69C7BD69C7BD69C73D69C7B
C68463B57B5A8C5A424A18083918106B3921734A31845A42BD8C63D6A584945A31D6A584B57B5A\
D69C7BE7BD9CEFCEADCE946BCE946BB56B39C6845AB57B5ABD8C63C68C63B57B5A
D6AD84E7BD94E7BDA5D6BDADD69C73D6AD84C69C84D6B5A5E7DED6EFEFE7EFE7DEEFEFE7F7EFF7\
EFEFE7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7
F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7\
F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7F7EFF7F7EFE7F7EFF7EFE7E7E7D6CED6BDAD
BD947BB57B5A9463428C4A318C5A428C4A297B4A297B4A297B4A29844229EFCEBDEFCEBDEFC6B5\
EFCEB5F7CEB5EFC6ADEFC6A5EFB59CEFC6A5E78C7BCE7363CE6B5AC6634ACE6B5A
C6634ACE6B5ADE7B6BC6634AC6634AC6634AC6634AC6634AC6634AD69C73D6A584D6A58CDEAD8C\
DEAD8CE7B594E7B594E7AD8CE7AD8CDEAD8CE7AD8CDEA584D69C7BD69C7BD69C73
CE946BC684639C73525A39293918103918105A3929845A429C7352D69C7BC6946B9C6B4AD69C73\
B57B5AE7BD9CE7BD9CEFCEB5AD7352C6845AC6845AB57B5ABD8C63BD8C63B57B5A
D6AD84D6AD84E7BDA5E7C6ADC6946BD6AD84D69C73E7D6C6EFE7E7EFE7E7EFE7DEEFE7DEF7EFF7\
F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFE7F7F7F7F7EFF7EFEFE7F7EFE7EFE7DEDECEC6D6AD8C
B584639C6B4A9C6B4A8C5A428C4A29844A297342297B4A29844221845231EFCEB5EFC6ADEFCEB5\
EFCEADEFC6ADEFCEADEFC6A5EFCEADF7CEB5F7CEB5F7D6BDEFD6C6EFC6B5EFC6AD
F7D6BDEFC6ADEFC6A5F7CEB5F7D6BDEFC6B5EFC6ADE7BDA5E7B59CE7BDA5E7B59CE7B594E7B594\
E7B59CE7B594E7B59CE7B594E7AD94DEAD8CDEAD8CDEA584DEA584D69C7BD69C73
CE946BCE946BB57B5A845231423129291008845A42734A31845A429C7352BD8C639C6339C6845A\
AD6B42C6845AE7BD9CE7BD9CD69C73CE946BBD8C63B5734AB5734ABD8C63CE946B
D69C73CE946BE7BDA5E7C6ADC69C84C69C84C68C63E7DED6EFE7DEEFE7DEEFE7E7EFE7DEF7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7\
F7EFF7F7F7F7F7F7F7F7EFF7F7EFE7F7EFF7F7EFF7EFE7E7DEC6B5E7BD9CC69C84
AD7352946342845231845231844A316B31187B4A297B4A297B4221D6B5A5EFCEB5EFCEB5EFCEB5\
F7C6B5F7CEB5EFC6ADF7CEB5EFC6ADF7CEB5F7CEB5F7D6BDF7CEB5F7D6BDF7CEB5
F7D6BDEFC6A5EFC6ADEFC6ADEFC6ADE7B59CE7B59CE7B59CE7B59CE7BD9CE7B59CE7BD9CEFC6A5\
E7B59CE7B594E7BD9CE7B59CE7AD94E7AD94DEAD8CDEA584DEA584D69C7BDE8473
CE946BCE946BB57B5A945A42522110422118734A31845231A5846B9C7352C69C849C6339945A31\
C68C63BD8C63DEAD94E7BD9CEFC6A5D6AD84C6845AC6845AC68C63B5734AB57B5A
B57B5ACE946BE7BDA5E7C6ADD69C73D6AD8CC6946BEFE7DEEFE7E7E7DED6EFE7DEF7EFE7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7EFE7F7EFF7F7EFF7DECEC6C69C84B57B5A
9C63399C6B4A844A29844A316B39217B4A297B4A297B4A297B4A29EFCEB5EFCEB5EFC6B5EFCEB5\
F7CEB5F7C6B5F7C6B5F7CEB5EFCEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5
EFCEB5EFC6ADEFC6A5EFC6A5EFC6A5E7B59CE7BD9CEFBD9CE7B59CE7BDA5E7B59CEFC6A5E7B59C\
EFC6A5E7B59CE7B59CE7AD94E7AD94E7B594DEAD8CDEA584DE9C7BDEA584D69C73
CE946BCE946BC684639C6B4A7342295A39293918107352428452399463429C6339AD73529C6339\
B57B5AA57B5ACE946BE7BD94E7BD94CE946BD69C73C6845ABD8C63B5734ABD8C63
B5734AD69C73D6AD84E7BDA5CEAD94C6946BD69C7BE7D6CEEFE7DEEFE7DEE7D6C6F7F7F7F7EFF7\
F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7EFE7DECEC6D6C6B5BD947BB5734A
9C6B4A844A298C5A426B39217B4A296B31187B4A29844A296B3921EFCEB5EFC6B5EFC6B5EFCEB5\
F7CEB5F7CEB5F7CEB5F7C6B5F7CEB5F7CEB5F7CEB5F7CEB5EFCEB5F7CEB5F7CEB5
EFC6A5EFC6A5E7B59CEFC6A5E7B59CE7AD8CE7B594E7BD9CE7B59CEFB59CEFBD9CEFC6A5EFB59C\
EFB59CEFC6ADEFC6A5E7B59CE7B59CE7AD94E7AD8CDEA584DEA584D69C7BD69C73
DE8473C6846BC68463B5734A734A31522110522918734A318C634A946B529C7352B584639C6B4A\
8C5A42946342BD947BC68C63DEA573EFC6A5D6AD84C67B4AC68C639C6B4AC6946B
BD8C63D69C7BD69C73E7BDA5CEAD94BD8C63E7C6B5E7D6C6EFE7E7EFE7E7EFE7E7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7EFE7E7DEC6B5C6A594BD947B9C6B4A
9C63399463428442297B4A297B4A29734A317B4A296B3921B58463E7C6B5EFC6B5EFC6B5F7CEB5\
F7CEB5F7CEB5F7CEB5F7D6BDF7CEB5EFCEB5F7CEB5F7CEB5F7CEB5EFC6ADEFC6AD
E7B59CDEAD8CDEA584E7AD94DEAD94DEA584DEAD8CE7AD94E7B594E7B59CEFBD9CE7BDA5EFC6A5\
EFC6ADEFC6ADEFB59CEFB59CE7B59CE7AD94DEAD8CDEA584DEA584D69C7BD69C7B
D69C73CE946BC67B5AB56B528C5A425A39296B39215A4239845A428452399C7352946342B5734A\
8452319C6339845239D6AD8CE7BD94D69C73DEA57BC68C63C6946BA57B5AB57B5A
BD8C63C69C84D69C73E7BD9CD6B5A5C6946BE7DED6E7BDA5F7EFF7EFE7E7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7EFE7F7F7F7F7EFF7F7EFF7E7BD9CBD947BAD7352946342
8C4A318C4A317B4A296B39216B39217B4A297B4A296B3118E7C6B5EFC6B5EFC6B5F7C6B5F7CEB5\
F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5EFCEADF7CEB5F7CEB5F7CEB5EFC6ADEFB59C
E7AD9CE7B594DE9C7BDEA584DEA584D69C7BD6A584DEAD8CDEAD8CE7B594E7B59CEFBD9CEFB59C\
EFC6A5EFC6A5EFC6A5EFB59CEFC6A5EFB594E7AD94DEAD8CDEA584D69C7BD69C7B
D69C73C6846BC68463B57B5A945A425A3929291008422921734A318452319C6B4A845239B5734A\
9C63399C63397B4A29D6A584C6845AD69C73EFCEADC6946BC68C63C68C63B57B5A
B58C73C6845AC6946BE7BD9CD6BDADD6BDADDECEBDE7D6CEE7D6CEE7CEC6F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7D6AD8CB58463946342845231
8C4A316B39217B4A297342297B4A298442296B31185A3121EFC6B5E7C6ADEFC6ADEFC6ADF7CEB5\
F7C6B5F7D6BDF7D6BDF7CEB5F7CEB5F7CEB5F7C6B5EFD6C6DE9C7BDE7B6BEFC6AD
EFC6ADEFB59CE7A594B56342B56342C6846BDE9C7BB57B5AD69C73DEAD8CE7B59CEFC6A5EFC6A5\
EFC6ADEFC6ADEFC6ADEFC6A5EFB59CE7B59CE7AD94E7AD8CDEA584DEA584D69C7B
D69C73CE946BC68463B56B52AD63427342293918104229215A3121734A31845239845A429C6B4A\
9C6B4A8452319C6B4A8C5A42BD8C63DEAD84D69C73DEAD84C6845ABD8C639C6339
B57B5AB57B5AD69C73E7BD94D6BDADEFE7E7CEAD94EFE7E7D6B5A5F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7E7DEDEC6946BAD73529463429C6339
7B4A297B4A296B39217B42217B4A296B39215A3121845239EFC6B5EFC6ADEFCEB5F7CEB5F7D6BD\
F7CEB5F7C6B5F7D6BDF7C6B5F7CEB5EFCEADF7CEB5F7D6BDEFCEB5EFC6B5F7C6B5
F7C6B5EFC6ADE7B594DEAD8CDEAD94E7AD8CE7B594DEA584CE8C63D69C7BE7B59CEFC6ADEFC6AD\
EFC6ADEFC6ADEFC6ADEFB59CEFC6A5EFC6A5EFB594E7AD8CDEAD8CDEA584D69C7B
CE946BCE946BC68463C67B5A9C73528C5A422910083918104229215A42397352428C5A42845239\
9C7352845231945A31522918D6AD84CE8C63CE9463E7BD9CB57B5ABD8C639C6B4A
AD7352BD8C63C6946BCEAD94DEC6B5DEC6B5C6AD9CD6B5A5F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7E7D6CEBD8C63946342945A426B3921
734A31844A317342297B4A29844A31632910632910A57B63E7C6ADF7C6B5F7C6B5F7C6B5EFD6C6\
F7D6BDF7D6BDF7D6BDEFD6C6F7CEB5F7CEB5F7C6B5F7D6BDEFC6B5EFD6C6EFD6C6
EFD6C6F7C6B5EFC6A5E7B594E7AD9CE7AD9CDEAD94DEAD8CDEA584DEA584EFB59CEFC6ADEFC6AD\
F7C6B5EFC6ADEFC6ADEFC6ADEFB59CEFB59CEFB59CE7B594E7AD8CDEAD8CDE9C7B
DE8473DE8473C68463B57B5AAD6B42946342291008422118391810734A31845239946342734229\
9C6B4A845231945A315A3121C6946BBD8C63D6AD84E7BD9CB57B5ABD8C63AD7352
B57B5AB58463BD947BD6AD8CDEC6B5DEC6B5D6BDADDECEBDF7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7\
F7EFE7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7E7CEC6AD73528C5A42945A31845231
7B4A297B4A29844A298C4A317B42215229185A3929E7C6B5EFC6B5F7CEB5F7CEB5F7D6BDF7D6BD\
F7D6BDEFD6C6F7D6BDEFD6C6F7D6BDF7C6B5EFC6ADF7D6BDF7D6BDEFD6C6F7DED6
EFD6C6F7C6B5EFC6ADE7BDA5E7AD94E7A594DEAD94DEAD8CDEA584E7AD94EFB59CEFC6ADEFC6AD\
EFCEADEFC6ADF7C6B5EFC6ADEFC6A5EFC6A5EFB59CEFB59CE7AD94E7AD8CDEA584
DE9C7BCE946BC6846BB57B5AAD6B42945A315229181808084221187342295229189C6339845231\
9C6B4A7B42218452318C5A42AD7352C68C63DEA57BDEA57BD69C73B57B5ABD8C63
AD7352B57B5AB57B5ACEAD94E7C6ADD6B5A5E7CEC6F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFE7C6946B9463429463426B3921734229
7342297B4A29844A317B4A29422118632910422118EFC6ADF7C6B5EFCEBDF7C6B5F7D6BDF7D6BD\
EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7C6B5EFD6C6EFD6C6
EFD6C6F7CEB5EFC6ADE7AD94D6A58CDEA584DEAD8CD6A58CDEAD94E7B59CEFC6ADEFC6B5EFC6B5\
EFCEB5F7CEB5EFC6ADEFC6ADEFC6A5EFC6ADEFC6A5EFB59CE7AD94E7AD8CDEAD8C
DEA584D69C73C6846BB57B5AAD7352AD6342734A312110083918105A39297B5A428452398C5A42\
9463427B4A29845231734A319C7352C6845ACE946BDEAD8CE7BDA5B5734AB57B5A
9C7352B57B5AC6946BE7BD9CE7C6ADC69C84DECEBDF7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7EFEFF7B5846B946342844A296B3921845239
844A31844A317B4A293918105229185221105A3929EFC6ADF7CEB5F7D6BDEFD6C6EFD6C6EFD6C6\
EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDF7D6BDF7C6B5EFCEBDF7C6B5F7D6BD
F7C6B5EFC6B5EFB59CE7B59CD6A58CDEAD8CDEAD94DEAD94E7B59CEFC6ADEFC6ADEFC6ADEFC6B5\
F7C6B5F7CEB5EFC6B5F7C6B5EFC6ADEFC6A5EFC6ADEFB59CEFB59CE7AD94E7AD8C
D6A584DEA584CE946BC68463AD73529C6B4A8C4A31291008423129522918734229734A31845231\
8452319C6339845231845231A57B5ABD8C63CE9463DEAD8CEFCEADB57B5AB5734A
9C6B4AA57B5AB58463CEAD94DEC6B5DECEBDF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7B5846B945A317B4A297B4A29845239
734A317B4A29844A31522918422118522918CEAD94EFCEB5EFCEB5F7D6BDEFD6C6EFD6C6EFD6C6\
EFD6C6F7DECEF7DECEF7DECEEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5EFC6B5F7D6BD
F7D6BDEFC6ADEFB59CDEAD94DEAD94DEAD8CE7B594E7B59CE7BDA5EFC6ADEFCEB5EFC6B5F7C6B5\
F7C6B5F7D6BDEFCEBDF7C6B5EFC6B5EFC6ADEFC6ADEFB59CE7B59CE7B59CDEAD94
DEA584D69C7BD69C73C68463B56B529C6B4A9463424221182110085A31215229188452398C5A42\
7B4A29945A319C63398452319C7352C69C84D69C73DEAD84EFCEADAD7352C68C63
8C5A42B58463AD7352E7BD94E7CEBDDECEBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7\
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7DEC6C69C73528C5A42734229845231845231
844A317B4A29522918422118391810EFB59CEFCEBDF7C6B5F7D6BDF7DECEEFD6C6EFD6C6F7DECE\
EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDF7CEB5F7D6BD
F7D6BDF7C6B5EFC6ADE7B59CDEAD94E7B594E7B594E7B59CE7BDA5EFC6B5EFC6B5EFD6C6F7D6BD\
F7C6B5EFD6C6F7C6B5F7D6BDEFCEBDEFCEBDEFC6B5EFC6ADE7C6ADEFB59CE7B594
DEAD8CD6A584D69C7BD69C73B57B5A9C6B4A9C63397342296329106B3921734A31734A31946342\
8452319C63398C5A428C4A319C7352D6A584D69C73D6AD84E7BDA5BD8C63B5734A
845231A57B5AB57B5ADEAD8CE7D6C6EFEFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79C7352945A318452315A31217B5A42734A31
734A31844A315229186B39215A3929EFC6ADEFC6B5EFD6C6F7D6BDEFD6C6EFD6C6F7DECEF7DECE\
EFD6C6EFD6C6F7D6BDF7DECEEFD6C6EFD6C6EFD6C6EFD6C6F7D6BDEFCEBDF7D6BD
F7D6BDF7D6BDF7C6B5E7B59CDEAD94E7B59CE7BD9CE7BDA5E7BDA5E7C6ADEFCEB5F7D6BDEFCEBD\
F7D6BDEFD6C6F7D6BDF7C6B5EFCEBDEFCEBDEFCEBDEFC6B5EFC6ADE7BDA5E7B59C
DEAD94DEAD8CD69C7BD69C73C67B5AB56B52945A42734A316B39216B39216B3921845239845231\
9C63399463428C5A4294735AB5846BD69C7BD69C73D69C73D6AD84C68C63AD6B39
844A29A57B5ABD947BD6AD8CE7DED6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7AD73529C6339734A316B39218C5A42845239
7B4A297342296B3921522918A58473F7C6B5EFCEBDEFD6C6EFD6C6EFD6C6F7DECEF7DECEEFD6C6\
F7D6BDEFD6C6F7D6BDF7D6BDEFD6C6F7DECEF7DECEEFD6C6EFD6C6F7D6BDF7D6BD
EFD6C6F7C6B5F7C6B5E7B59CDEAD94DEAD94E7BD9CE7BDA5EFC6ADEFC6ADEFCEBDEFCEBDEFCEBD\
EFD6C6EFD6C6F7C6B5F7C6B5F7D6BDF7CEB5EFCEB5EFC6B5EFC6ADEFC6ADE7BDA5
DEAD94DEAD8CD6A584D69C73C68463B56B52945A428C4A315A31215A31216B3921734A31844A31\
9463429C6339946342945A31D69C73D69C73D69C73D69C73D6A584D6AD84AD6B42
AD6B42AD7352B58463DEAD84EFEFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF79C73529C7352845239734A31734229845239
844A315A3121734229845239EFC6B5F7CEB5EFCEBDEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6\
EFD6C6F7D6BDEFD6C6EFCEBDEFD6C6EFD6C6EFD6C6EFD6C6F7D6BDF7D6BDEFC6B5
EFD6C6EFD6C6F7D6BDE7BDA5E7AD94DEAD94E7B59CE7BDA5E7BDA5E7C6ADEFC6B5EFCEBDEFCEBD\
EFCEBDEFD6C6EFCEBDF7D6BDEFCEBDEFC6B5EFC6B5EFC6ADEFC6B5E7C6ADE7BDA5
E7BDA5DEAD94D6A584D69C7BCE946BB57B5A9C6B4A8452397342296B31186B39216B3921845239\
945A318C634A845239844A29D6AD8CD69C73C6946BD69C7BC69C84DEAD8C945A31
AD7352AD7352A5846BD6AD84F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7BDADAD945A318C634A8452318C5A428452318C4A31
6B39215A3929734229E7C6ADF7D6BDEFC6B5F7D6BDEFD6C6EFD6C6EFD6C6EFD6C6F7DECEEFD6C6\
EFD6C6F7D6BDEFCEBDEFC6B5EFC6B5EFCEBDEFCEBDF7D6BDF7D6BDF7C6B5F7CEB5
EFD6C6EFD6C6F7D6BDEFC6ADE7AD94DEAD8CDEAD94DEAD9CE7BD9CDEAD9CE7C6B5E7CEBDEFC6B5\
EFD6C6EFCEBDEFCEBDEFCEBDEFC6B5E7C6B5EFC6B5EFC6ADEFC6ADEFC6ADE7BDA5
E7BDA5DEAD9CDEAD8CD6A584DE8473C684639C6B4A945A31734A315229186B39216B3921734A31\
9C6B4A8C5A428C5A428C5A42C69C84C6946BD69C73D69C739C6B4AE7BD94844221
9C6B4ABD8C63C6946BCEAD94F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7A57B6BB58C739C6B4A734A319C6B4A734A318C4A31
5A3121734A317B4A29E7C6ADF7C6B5E7C6ADEFD6C6EFD6C6F7DECEEFD6C6EFD6C6F7D6BDEFD6C6\
EFCEBDEFCEBDEFB59CE7C6ADEFC6ADEFC6ADEFC6B5EFCEBDF7D6BDEFCEB5F7CEB5
F7D6BDEFD6C6F7D6BDEFC6ADE7A594DEAD8CD6A58CDEAD94DEAD94E7BDA5E7C6B5EFC6B5EFCEBD\
E7C6ADE7C6ADE7BDA5E7C6ADE7C6ADE7C6ADE7C6ADEFC6ADEFC6B5E7C6ADE7C6AD
D6B5A5E7BD9CDEAD8CD6A584D69C73C68463AD7352945A31844A315229185221106B3921734A31\
8C5A429C63398C5A428C5A42C69C84CE946BCE946BD69C73844A31DEAD84945A42
8C5A42B5846BD6A584E7C6ADF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7\
F7EFF7F7EFF7F7F7F7F7F7F78C4A29B5947B8C5A42946B52845A428C5A42734A31
5229189C6339E7AD8CEFC6ADE7AD94EFC6B5F7D6BDEFD6C6EFD6C6EFD6C6EFD6C6EFCEBDE7CEBD\
EFC6B5EFC6B5EFC6ADDEAD9CDEAD94E7BDA5E7C6ADEFC6B5EFCEBDE7C6ADEFC6B5
EFD6C6EFD6C6F7D6BDEFB59CDEAD94DE9C7BD6AD8CD6A58CCEAD94D6B5A5E7C6ADE7C6B5E7BDA5\
E7BDA5D6B5A5E7AD9CDEAD8CDEAD8CD6A58CDEAD9CDEAD9CE7BDA5E7BDA5E7BDA5
E7BD9CE7BD9CDEAD94D6A584CE946BC6846BB56B529C6B4A8452397342293918106329106B3921\
8C5A428C5A429C6B4A845239BD947BD69C7BB57B5ABD8C63844A29E7BD949C6B4A
8C4A31C6946BD6AD84E7D6C6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFF9C6B4AA57B638452398C5A42845239945A42522110
845231844A31F7C6B5CE946BDEA584EFCEB5F7D6BDEFD6C6EFD6C6EFD6C6EFCEBDE7C6B5DEAD9C\
BD947BB58C73D6A58CCEA594BD947BDEAD9CDEAD9CEFCEBDEFCEBDEFC6B5EFC6B5
F7D6BDF7D6BDF7D6BDEFC6ADDEAD94D69C7BC69C84D69C7BE7BD9CDEAD9CE7C6B5E7AD9CDEAD9C\
C6A59CBD9C8CB5846BB58C73C69C84C69C84C69C84CEA594E7BD9CE7BDA5DEAD9C
DEAD9CDEAD9CDEAD8CD6A584C69C84C6846BB57B5A945A42845239734A316B39215A31215A3121\
8452398452318C634A8C5A42B5846BBD8C63B57B5AB57B5A945A31E7BD94945A31
8C4A31C69C84D69C73E7D6CEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7BD9C94A57B5A9C7352734A31845239734A31945A425A3121
945A31EFB594EFB59CE78C7BD6A58CEFCEB5EFCEBDEFD6C6EFD6C6EFC6B5E7AD9CB58463BD8C63\
DEAD9CBDADAD736B6373736BA58473C69C84DE8473DE8473EFC6B5EFC6B5E7C6AD
F7D6BDF7D6BDF7D6BDEFC6A5E7B59CD69C7BD6A584BD947BD6A5849C4A31C65A4AC6846BD6A58C\
DEC6C6947B73735A4AA57B6BA57B63A57B5AA57B63B5846BD6A58CDEAD94DEAD94
DEAD9CDEAD9CD6A58CD6A58CCE946BC6846BB56B529C6B4A8C5A42734A31845239522918522918\
8452398452398C5A429C6B4AB58463BD947BB5734AB57B5A945229E7BD9C9C6339
9C7352D6AD84D6AD84EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7B5846BBD9C8C9C73528C634A5A3121845239945A426B3118
522918F7C6B5E7AD8CE7A594DEAD94EFCEBDF7D6BDEFCEBDE7C6ADE7AD9CB5846BC6846BD6BDB5\
E7D6CE7B7373736B63635A52847B73A57B6BC69C84BD947BE7AD9CDEAD94EFC6A5
F7D6BDF7D6BDEFCEB5EFC6ADE7B59CDEA584BD947BB5846BC6846BC69C84AD4231DEC6C6EFE7E7\
8C736394735A7B6B5A948C846B635ABD9C949C73528C6B52B5846BD6A584D6A584
DEAD94DEAD8CD6A58CD69C7BD69C73B5846BAD73529C6B4A845231734A315A3121291008422118\
8452398C5A427342299C6B4AB5846BB584639C6B4AA57B5AAD6342DEAD8C844A29
BD947BD6AD8CD6AD8CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFFF7EFF7A5846B8452317B4A295A3121845239845239845239
945A42F7C6B5DEA584E78C7BDEAD94E7C6B5EFCEB5EFC6ADDEAD9CBD947B94735A5A3929B5948C\
C6B5B5947B6BB5B5BD21181884736B5A4A4294735AB5846BBD947BE7B59CEFCEAD
F7D6BDF7D6BDF7CEB5EFC6ADE7BD9CE7B594BD947BB58C739C7352B58C73BD947B9C6B4ACEC6BD\
635A52B5BDCE21181873736B635A52BD9C94423129735242A57B63B58C73BD947B
D6A584D6A58CD6A584BD947BC6946BC68463AD7352945A42845239844A31422118391810422118\
522918845239734A31AD73529C7352A57B5AA57B5AB57B5AAD6342D6AD84844A29
BD8C63D69C7BDEC6B5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7B5947BD6C6C6A58C7394735A7B5242734A31845239845239945A42
CE7363EFB59CE78C7BD69C7BDEAD8CEFC6B5EFCEB5E7B59CCEA594C6846B734A31846352846352\
5A42394229215A39298452398C6B52846352A57B63BD947BE7AD94EFBD9CF7CEB5
F7CEB5F7D6BDF7CEB5EFC6ADEFBD9CE7B59CDEA584BD947BC6846BAD735294735AA58C84A58C84\
5A39295229185A39295A3929734A315A4239735A4A7B5242A57B63B58463B5846B
CE946BD69C7BD69C7BBD947BB5846BB57B5A945A428C5A428C5A42734A316B39214221185A3929\
6B39216B3921734A319C6B4AAD73529C6B4A9C6339B57B5AAD7352D6AD84946342
BD8C63D69C73EFE7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7AD7352BD9C94B59C8C8C5A42734A318C634A845239734A318C4A31
C68463E7A594D69C7BD69C7BDEAD8CEFC6B5E7C6B5E7C6ADE7BDA5DEAD94BD947BB56B528C634A\
7B52427B52427B524284523994735AC6846BD6A584E7B59CEFC6ADEFC6ADF7CEB5
F7D6BDF7D6BDF7CEB5EFC6ADEFC6ADEFC6A5E7B594DEA584D69C7BBD947BB5846B84634AA57B63\
A584739C7B6B846352634A425A4239734A319C7352BD8C63B58C73C6846BCE946B
D69C7BD69C7BBD947BCE946BBD8C63B56B52945A428C5A428452398452397342295229185A3929\
5A31215A31217342299C7352B57B5A9C73529C6339B57B5ABD8C63D6AD849C6B4A
BD8C63D6A584EFEFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7EFE7DEA58C7B946B52734A31734229734A31734A316B39219C6B4A
C68463CE946BC69C84BD947BD6A58CE7C6B5EFCEB5EFCEB5F7D6BDEFCEBDEFC6ADEFC6B5E7BDA5\
E7B59CE7AD9CE7B59CE7BDA5E7B59CD69C7BDEA584E7AD94EFC6A5F7D6BDF7CEB5
EFD6C6EFD6C6F7D6BDF7CEB5EFCEADEFC6ADE7B594D69C73DE9C7BBD947BD6A584D6A58CD6A584\
BD947BBD947BBD947BCE946BD69C7BD6A584D6A584DEAD8CE7AD8CDEAD94D6A58C
D6A584D69C7BCE946BC6846BBD8C63B57B5A945A428C634A8452396B39216B39215229185A3929\
734A317342296B39219C6B4ABD8C639C6B4A9C6339C6845ABD947BDEAD949C7352
BD947BEFDECEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7FFFFFFFFFFFF7342298C5A425A31216B39216B39219463425A31219C4A31
B56B52DE8473CE946BB58C73D6A584EFCEB5E7BDA5F7CEB5F7D6BDF7D6BDEFD6C6F7D6BDF7D6BD\
EFD6C6E7A594C6846BA57B639C7352B56B52E7B59CEFC6A5F7D6BDF7D6BDF7D6BD
F7DECEEFD6C6F7D6BDEFD6C6F7CEB5F7D6BDEFBD9CE7AD94C6846BAD63429C7352B56B52B58C73\
E7BDA5E7C6ADEFC6ADE7C6ADE7BDA5E7BDA5E7B59CE7B59CE7B59CDEAD94D6A584
C6946BB58463CE946BBD8C63B57B5AAD73529C6B4A8C5A42845231845239632910522918522918\
5A3929522110734A318C5A42AD73529C6B4A946342C68C63C6946BE7BD9CA57B5A
C69C84EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7EFE7E7FFFFFF6B39217B4A295A31216B3921734A31845239734A319C6339
B56342B57B5ABD8C63C6846BC69C84EFC6ADDEC6B5E7BD9CEFC6B5F7D6BDEFD6C6EFD6C6F7C6B5\
B5846BA57B6394735AB56B52D6A584EFC6A5F7CEB5F7CEB5F7D6BDF7DECEF7D6BD
F7DECEEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5F7CEB5EFC6A5E7AD94BD8C63945A42845239945A42\
B56B52DEA584E7AD9CE7C6ADEFC6ADEFC6ADEFB59CE7BDA5DEAD94DEA584BD947B
A57B5ACE946BB58C73B5846BAD73529C6B4A9C6B4A8C5A426B39216B39215229185A3121522918\
522110735242845A42946B52A57B5A9C7352945A31BD8C63BD8C63D6AD8CBD947B
C69C84F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
FFFFFFBDADADFFFFFF845231734229734A31734A315A31218452397B4A29945A31
945A42945A42A57B63B5846BC69C84E7C6B5EFCEBDBD947BC69C84D6A584D69C7BDE8473B56B52\
AD7352D69C7BF7CEB5F7D6BDF7D6BDF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDEFD6C6F7CEB5F7CEB5F7CEB5EFCEADE7B59CD6A584B58C73\
94735A8C5A429C7352AD6342CE6B5AB58C73C6846BB58463A57B63A57B5AB5846B
BD947BBD947BDE8473BD8C63AD73529C6B4A9C6B4A8452399C6B4A4221187342297342296B3921\
52291842292184634A9C6B4AAD73529C6B4A946342BD8C63D69C73B5846BAD6B42
DECEBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7C6A5949C7352734A31734A3184634A845239734A31734A31734A31845239
945A318C634A9C7352A57B5AD6A584E7C6B5EFCEB5EFCEB5EFC6ADD6A584BD9C8CDE8473DEAD9C\
EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DED6
EFD6C6EFD6C6F7DECEF7DECEF7DECEF7D6BDF7D6BDEFD6C6F7D6BDF7CEB5F7C6B5EFC6ADEFC6AD\
EFC6ADE7C6ADE7C6ADC69C84A57B63AD7352A57B63A57B63BD947BC69C84BD947B
CE946BD69C73CE946BBD8C63AD73529C7352AD73528452396B3921734A316B39215A3121391810\
3918104221188C634A94735A8C5A42A57B5AAD6342C6946BC69C849C6B4ABD8C63
EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7D6C6C69C6B4A7B5A42734A319C7B6B8C6B527B5A42845239734A318C5A42
8C5A428C634AAD7352AD7352D69C7BEFC6ADEFC6B5EFCEB5EFCEB5F7D6BDF7D6BDEFD6C6EFD6C6\
EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DED6F7DECEF7DECE
EFD6C6F7DECEF7DECEF7DECEEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDEFCEB5EFCEB5F7CEB5\
EFC6ADEFC6ADEFC6ADE7BDA5E7C6ADE7C6ADE7B59CDEAD94DEAD8CD6A58CD69C7B
D6A584BD947BB58C73B57B5AAD7352A57B5AAD73529C6B4A734A316B3921522110391810391810\
391810422118B58C738C634A8C5A42D69C739C6B4AB57B5AD6AD849C6B4AC69C84
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7CEB5A5844A29735242845A42A58C73946B52845239845A427B5A42845A42
845A428C5A42A57B5A9C7352D69C7BE7C6ADEFCEB5EFCEB5EFCEBDF7D6BDF7D6BDEFD6C6F7DECE\
F7DECEEFD6C6F7D6BDF7DECEF7DECEF7DECEF7D6BDF7DECEF7DECEF7DECEF7DECE
F7D6BDEFD6C6F7DECEEFD6C6EFD6C6F7DECEEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7C6B5F7CEB5\
EFC6B5EFC6ADE7C6ADE7BDA5EFC6ADE7B59CE7B59CDEAD94D6A584D6A584D69C7B
D69C7BBD947BC6946BBD8C63B56B52AD7352AD73528C5A429C6B4A734229522918522918422118\
5A3121522110BD947BA57B5A8C5A42BD947BAD73529C6B4AD6AD8C9C6B4AD6BDAD
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7DECEC68452398C6B528C634A9C73528C634A8C6B528C634A845A42845239
8452318452319C6B4A9C7352C6846BE7BD9CEFC6B5EFCEB5EFCEB5EFCEBDF7D6BDF7D6BDEFD6C6\
F7DECEF7DECEF7D6BDF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
F7DECEF7DECEF7DECEF7DECEF7DECEEFD6C6EFD6C6EFD6C6F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5\
EFC6ADEFC6A5E7C6ADEFC6ADE7BDA5E7BD9CE7B594DEAD94DEAD8CD6A58CD6A584
D69C7BD69C73CE946BB57B5AAD7352B57B5A9C73529C6B4A734A315A31216B39215A3121391810\
391810422118C6946BA57B639C6B4AD69C73B5734A8C634ABD947B9C6B4AF7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF78C634A84523984523984523984634A8C634A845239845A42845239
845A42845239A57B5AB57B5AC6946BE7B59CE7BDA5EFCEADEFCEBDF7CEB5F7D6BDF7D6BDEFD6C6\
EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6BDF7D6BDF7DECEF7DECEF7DECE
F7DECEF7DECEEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7C6B5F7CEB5F7CEB5F7CEB5EFCEADEFC6AD\
EFC6ADEFC6ADEFB59CE7BDA5E7BD9CE7BDA5E7B59CDEAD8CDEAD94DEA584D6A584
BD947BCE946BC6846BBD8C63B57B5AAD73529C6B4A845239734A315A3929734229422118391810\
3918105A31219C7352D69C73B58463D69C7BB57B5A9C7352946342CEAD94F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFF7B52428C6B528452398C634A8C6B52946B528C634A845A42845A42
8452398C634A9C7352BD8C63BD947BDEAD8CE7BDA5EFCEB5EFCEBDF7D6BDF7D6BDF7D6BDF7D6BD\
F7DECEF7DECEF7D6BDF7D6BDF7DECEF7DECEF7D6BDF7DECEF7DECEEFD6C6F7DECE
F7DECEF7DECEEFD6C6EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5EFCEADEFC6AD\
EFC6ADEFC6ADEFB59CE7B59CE7B59CE7B59CE7B59CE7AD94DEAD8CD6A58CD6A584
D69C7BCE946BB58C73B58463B58463A57B639C6B4A8C5A426B3921734A31522110422118422118\
39181042292194735ABD947B9C7352C6946BBD8C63A5846B946342E7CEC6F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFF9C7B6B7352428C5A42946B52946B52845A428C634A8452397B5A42
946B528C634A9C7352B5846BC6946BD6A58CE7BDA5EFC6ADF7CEB5F7CEB5F7CEB5F7D6BDF7D6BD\
F7D6BDF7DECEF7DECEEFD6C6F7D6BDF7DECEF7DECEEFD6C6F7D6BDF7DECEF7D6BD
EFD6C6EFD6C6F7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5F7D6BDF7CEB5F7CEB5EFC6ADF7CEB5\
EFC6ADEFC6A5EFC6A5E7BDA5E7BD9CE7BDA5E7B594DEAD94DEAD8CD6A58CD6A584
BD947BCE946BC6846BB58463B584639C6B4A9C6B4A8C5A42734A316B3921522110391810291008\
2910087B52428C634AA57B5AAD7352C69C84C6946BD6AD8CC6946BF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFF845239A57B63A57B5A8C5A428C634A84634A8C5A42845A429C6339
7342298C634AA57B63BD8C63B58C73D6A584E7BD9CEFC6ADEFCEB5F7CEB5F7D6BDF7D6BDF7D6BD\
F7DECEF7DECEEFD6C6F7DECEF7DECEF7DECEF7D6BDF7DECEF7D6BDEFD6C6F7DECE
F7D6BDEFD6C6EFD6C6F7D6BDEFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDEFC6ADF7C6B5EFCEAD\
EFC6ADEFC6ADEFB59CEFC6A5E7B59CE7B59CDEAD94DEAD94DEAD8CD6A58CD6A584
BD947BD69C73B58C73B5846B9C7352946B52845A42734A318452395A3121391810291008422921\
29100884634A946B529C6B4A946342C6946BC6946BC69C84E7DED6F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7E7DEDEA57B637B5A427B5A42845239845239845231845A42845239
8C634A8C634AA57B5AB58C73C69C84D6A58CE7BD9CEFC6ADEFCEB5F7D6BDF7D6BDEFD6C6F7D6BD\
F7DECEF7DECEF7D6BDF7DECEF7D6BDF7DECEF7D6BDEFD6C6F7D6BDF7DECEF7D6BD
EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7C6B5F7CEB5F7CEB5EFC6AD\
EFC6ADEFC6ADEFB59CEFC6A5E7B59CE7B59CDEAD94DEAD8CDEAD8CDEAD8CD6A584
C69C84D69C7BB5846BA57B639C73529C73529C6B4A7B5A426B39215A3121391810391810422921\
391810946B52946B529C73529C6339C6946BC69C84D6A58CF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFF8C634A7B5A42845239734A31845231735242734A317B5A42
8C634A9C6B4AB58463B58C73D69C7BD6AD8CE7BD9CEFC6ADF7CEB5F7C6B5F7D6BDEFD6C6F7D6BD\
F7D6BDF7D6BDF7D6BDEFD6C6F7DECEF7DECEF7DECEF7DECEEFD6C6EFD6C6F7DECE
F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7C6B5F7CEB5F7CEB5F7CEB5EFC6AD\
F7CEB5EFC6ADEFC6A5EFC6A5EFBD9CE7B59CDEAD94DEAD8CD6A58CDEAD8CD6A584
D6A584BD947BB5846BB5846BA57B638C634A8C5A426B39215A3121422118422118291008392118\
3918109C7B63946B529C6339946342C69C84CEB5A5DECEC6F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7CEB5B584634A845239845239845231845239845239735242
8452399C6B4AA57B63B58C73C69C84DEAD9CE7BDA5EFC6ADF7CEB5F7CEB5F7D6BDEFD6C6EFD6C6\
F7DECEEFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEEFD6C6F7DECEF7D6BDEFD6C6
F7DECEEFD6C6F7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7D6BDF7CEB5F7C6B5EFCEAD\
EFC6ADEFC6ADEFC6A5EFC6A5E7B59CE7B59CDEAD9CDEAD8CDEAD8CD6A584D6A58C
CE946BCE946BBD8C63A57B63A57B5A9C73528C5A425A39295A3121422118422921311818422118\
422118A57B63B5846B8C5A42AD7352C6946BE7BD9CF7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF78C6B52734A31734A317352427352428452397B5A42
735242946B52B58463BD947BD6A584DEAD94EFC6A5EFC6ADEFC6B5EFCEB5F7CEB5F7D6BDF7D6BD\
F7D6BDF7D6BDF7D6BDF7DECEF7D6BDF7DECEEFD6C6F7D6BDF7D6BDEFD6C6F7D6BD
EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7CEB5F7CEB5EFCEADF7CEB5F7C6B5\
EFC6ADEFC6ADEFC6ADE7BDA5E7BDA5E7BD9CE7B594DEAD8CDEAD8CD6A58CD69C7B
D69C7BB58C73BD8C63A57B639C73528C634A8452395A39295A3121422921422118522918522918\
3918109C6B4AB584639C6B4AC6845AD6A584DECECEF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7A57B638C6B52735242845A427B5A427352427B5A42
845A42946B529C7352C6946BD6AD8CE7BDA5E7BDA5EFC6ADF7CEB5F7CEB5F7D6BDF7D6BDF7D6BD\
EFD6C6EFD6C6F7DECEF7DECEEFD6C6F7D6BDF7D6BDEFD6C6EFD6C6EFD6C6EFD6C6
F7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7CEB5EFCEADEFCEADEFC6AD\
EFC6A5EFC6A5EFC6ADE7BDA5E7BD9CE7B594E7AD94DEAD8CDEAD8CDEA584DEA584
CE946BB58C73B5846BAD73529C6B4A8C5A42734A315A39295A3929522918422118522918391810\
291008946B529C73529C6B4ABD8C63DEAD8CEFEFE7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFCEB5B5A57B63946B52946B52946B527B5A42
7B5A42946B52A5846BB58C73D69C7BE7B59CEFC6A5EFC6ADEFC6ADF7CEB5EFCEB5F7CEB5EFD6C6\
EFD6C6EFD6C6EFD6C6F7D6BDF7D6BDEFD6C6F7DECEF7D6BDEFD6C6F7D6BDF7D6BD
F7D6BDF7D6BDF7CEB5F7D6BDF7CEB5F7CEB5F7CEB5F7CEB5F7D6BDF7C6B5F7CEB5EFC6A5EFC6A5\
EFC6A5EFC6A5EFB59CE7BDA5E7BD9CE7B594DEAD94E7B594D6A584D6A584D6A584
B58C73B58C73A57B63A57B5A8C634A845239734229734A315A31215A3121422118391810211008\
5A3929B5846B9C7352B5734ACE946BCEAD94F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFEFE7E794735A946B52845A428C634A
84634A8C634AAD7352BD947BC69C84DEAD94EFC6A5EFC6ADEFC6ADF7CEB5F7CEB5F7D6BDF7D6BD\
F7CEB5EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFD6C6F7D6BD
F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7CEB5F7D6BDF7CEB5EFC6ADEFC6ADEFC6ADEFC6AD\
EFC6A5EFC6ADEFBD9CE7B59CE7B59CE7B59CE7B594DEAD8CD69C7BD6A58CBD947B
BD947BBD8C63AD7352945A42845239845A427342295A39295A3929422921522918211818211008\
A57B5AA57B63946342B57B5AC68C63E7CEBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFBD9C9484523984634A735242
8C634A8C634AA57B5ABD8C63D69C7BDEAD9CE7BDA5EFB59CEFC6ADEFC6ADF7CEB5EFCEADEFCEAD\
F7CEB5F7CEB5F7D6BDF7D6BDF7D6BDF7CEB5F7D6BDF7D6BDF7D6BDF7CEB5F7D6BD
EFCEB5F7CEB5EFCEBDF7CEB5F7CEB5F7CEB5EFCEADEFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFC6AD\
EFC6A5EFC6A5EFB59CE7B59CE7B59CE7B59CDEAD94DEAD94D6A58CD69C7BD6A584
B58C73A57B639C6B4A9463428C5A42845A42845A425A31215A3121522918391810291008B5846B\
9C7B639C6B4A946342BD8C63D6B5A5EFE7E7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFDECEBD6B3921845A42A57B5A
7B5A42A57B5AA57B5ABD8C63C69C84DEAD94E7BD9CE7C6ADEFC6ADEFC6A5EFC6ADF7CEB5F7CEB5\
F7D6BDF7CEB5EFCEBDF7D6BDF7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5
F7CEB5F7D6BDF7CEB5EFC6ADF7CEB5EFC6ADF7CEB5EFC6ADEFC6ADEFC6A5EFC6ADEFC6ADEFC6A5\
EFC6A5E7BD9CEFBD9CE7B594E7B594DEAD9CDEAD8CCEAD94BD947BD69C7BCE946B
B5846BA57B639C73529C6B4A845A42734A31735242946B524221183918103921187B5A42845239\
A57B5A9C6B4AAD7352C6946BE7BDA5F7EFF7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFCEB5A59C7352845239845239
84634AA57B63A57B5ABD8C63D69C7BDEAD94DEAD9CE7BDA5EFC6ADEFC6A5EFC6ADF7C6B5EFC6AD\
F7D6BDEFCEADF7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7D6BDF7C6B5
F7C6B5EFC6ADEFC6ADEFC6ADEFB59CEFC6ADEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6ADEFC6A5\
EFC6A5E7B594E7B594E7B59CDEAD94DEAD94DEAD8CD6A584BD947BBD947BB5846B
AD73529C7352946342845A42845A428452398452395A3929734A315A3929734A31734229A57B63\
9C7352B58463BD8C63D6AD8CD6BDADF7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFC6A594C69C84734229845231
7B5A428C5A429C7352B58463BD947BC69C84D6B5A5E7B59CE7BDA5EFC6A5EFB59CF7C6B5F7C6B5\
EFCEB5EFCEB5EFC6B5EFC6ADF7C6B5F7CEB5F7CEB5F7D6BDEFC6B5EFCEB5EFC6AD
EFC6ADEFC6A5EFB59CE7B59CE7B59CEFB594EFC6A5EFC6A5EFBD9CEFB59CEFBD9CEFB594E7B59C\
E7B59CDEAD8CE7AD94DEAD94D6A58CD6A58CD69C7BBD947BBD947BB58C73B5846B
AD7352A57B5A9C6B4A735242735242734A31734A315A42397342295A3121A5846B946B529C7352\
9C6B4AD69C7BC6946BE7BD9CF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEDEDEC6C65A3121734229
9C6B4A8452399C7352A5846BB58C73D6A58CDEAD94DEAD9CE7B59CEFB59CEFB59CEFC6A5EFC6AD\
E7C6ADEFC6ADEFCEB5EFC6ADEFC6ADEFC6ADEFC6B5EFC6ADEFC6A5EFC6ADEFC6AD
EFBD9CE7B59CE7AD8CE7AD94E7AD94E7B594EFB594E7AD8CE7AD8CE7AD8CE7AD8CDEA584DEAD8C\
E7AD94D6A584DEAD8CD6A584D6A584C69C84D69C73BD947BB5846BB58463B58463
A57B5A9C73528C5A42845A427B5A427352428C6B527B5A42734A318C6B52B5846B94735AA57B63\
BD8C63D6A584E7BD9CD6BDADF7EFF7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6A5949C7B6B7B5A42
845A42946B528C634A9C7352A57B63BD947BD6A58CE7BD9CDEAD9CD6B5A5E7B59CE7B59CEFC6AD\
EFC6ADEFC6ADEFC6ADE7C6ADE7BDA5E7BDA5E7BDA5E7BDA5E7B59CDEAD9CDEAD8C
DEAD94DEAD94D6A584D6A584D69C7BD69C7BD69C7BD69C73DE9C7BD69C7BD69C73D69C73BD947B\
CE946BCE946BCE946BCE946BC6846BB58C73BD947BB58C73B5846BB57B5A9C6B4A
8C634A94735A946B52735A4A946B52946B52734A318C634A9C6B4A9C6B4A9C73529C6B4ABD8C63\
B58463DEAD94E7BD9CF7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BDADAD94735A
845A428C634A946B52A57B5AB5846BA57B6BB58C73BD947BDEAD94D6B5A5E7BDA5EFC6A5E7C6AD\
E7BDA5E7BDA5E7BDA5E7BD9CDEAD94DEAD94D6A584DEAD94E7BD9CD6A58CDEA584
D6A584D6A58CBD947BC69C84C6846BCE946BBD8C63D69C7BCE7363CE946BB57B5AB58C73B57B5A\
B57B5ABD8C63B58463B58463B5846BB5846BA57B63B58C73BD947BA5846BA58C73
A57B5AA57B638C634A8C634A94735AA57B63845A426B3921845239B57B5AB58463B57B5ABD8C63\
CEAD94D6B5A5D6BDADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7
A58C7B94735A7B5A429C7352A57B5A8C634AB58C73C69C84D6BDADE7C6B5E7C6B5E7C6B5E7BDA5\
E7BDA5D6B5A5DEAD9CD6A584CEAD94D6A58CD6A58CD6A584D6A58CD6A584D6A584
C6946BC6946BB58C73B58C73B5846BB58C73B5846BAD7352B5846BB584639C73529C6B4AB5846B\
9C7352B584639C7352AD7352A57B63A57B5AA57B638C634A946B5294735AAD7352
94735A9C735294735A9C7352845239845A428C6B529C6B4A9C7352A57B5AA57B5AC6946BD6B5A5\
D6B5A5C69C84F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
A58C7BA57B6BA57B639C7363A58C73C6A594CEA594BD9C8CDEAD9CCEA594DEAD9CD6BDADD6BDAD\
DEAD9CDEAD94D6A58CD6A584D6A58CBD947BC69C84D6A584C69C84C6946BC69C84
BD947BC6846BB58463B5846B9C7352BD947BA57B63BD947BB58463A57B63BD8C63A57B5A9C6B4A\
BD947BA57B5AB5846BA57B63A57B5AA5846BA58C7384634A946B52A57B5A9C7B63
8C6B5294735AA57B639463429C6B4A9463429C6B4A9463429C7352B58463D6AD84CEB5A5CEAD94\
D6AD8CE7CEC6F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFF94735AA584739C7363946B52A5846BB58C73B58C73BD9C8CDEAD9CD6B5A5DEAD94CEAD94\
D6A58CD6AD8CC69C84C69C84C69C84B58C73BD947BB58C73BD947BB58C73BD947B
B5846BBD947BA57B5A9C7352A57B6B946342A5846BA57B5AB58C739C7352A57B63A57B5AA57B63\
C6946B8C634A9C73529C7352B5846BA57B5A946B52946B52845A427B5A42734A31
7352428C634A8452398452397B5A427B5A42946342B5734AC6946BD6AD84E7C6ADBD9C8CD6AD8C\
B58463F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7FFFFFFB5947BA57B6BA57B63BD9C94C69C84C6A594D6B5A5D6B5A5D6B5A5D6B5A5C69C84\
C69C84C69C84C69C84BD947BC69C84BD947BBD947BB5846BB5846BBD947BB58463
A57B5AA57B63946342A5846BA5846B8C634A734A31A57B63845A42B58463A57B5AA57B63A57B63\
8C5A429C6B4AA57B5A734229734A319C63398C5A42845A428C5A429C6339946342
9C6B4A9463429463428452399C63399C6B4ACEAD94BD947BD6AD8CD6BDAD8C634ABD9C8CA5846B\
DECECEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7C6A59CA5847384634A9C73639C6B4AA5846BC6A59CCEB5A5DEAD9CD6B5A5C6A594\
BD947BBD947BB58C73BD947BBD947BB58C73A5846BA58C73B58C73A57B63B58463
B584638C634AC6946BA57B5A8C634ABD947B8C634A845A42A57B638C634A8C634A946B52845A42\
8C5A428452317342298452398452399C63398452397B5A429463428C5A42845239
844A318C5A429C7352B58463B58463C69C84BD947BE7BD9CD6B5A5A5846BA57B5ABD9C8CA5846B\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFF735A4A9C7B6BBD9C8CA57B6BA5846BB5947BC6AD9CCEB5A5D6A58CC6A594\
A57B63B5846BA5846BBD947BBD947BB5846B9C7363B5846BB58463A57B63B58C73
A57B63B58463845A429C735294735A8C634AA57B5A845A428C634A946342845A4284634A845A42\
735242845239845239845239734A317342298452397B5A42845239845231845231
8C634AA57B5AA57B5AA57B5AA57B5AC69C84CEB5A59C7B639C7B63A5846BC6A594BD947BEFE7E7\
F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F79C7B6B734A31B5947BB59C8CBD9C8CB5947BD6B5A5D6B5A5C6AD9C\
A57B5AB58C73A57B63A57B63B58463A57B5A94735AA5846BA5846B94735AA57B63
94735AA57B63845A42A57B5A9C6B4A946B52735242734A31A57B5A7352427B5A42845A427B5A42\
845231734A31734A316B39215A39297342297342297342298452319C6B4A845A42
8C634AA5846BC69C84BD947BE7BDA5CEB5A5BD9C8CA58C73946B52C69C84946B52EFE7E7FFFFFF\
FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFA57B6B734229947363A58473B5947BCEB5A5D6BDADC6AD9C\
A57B5A946B52B5947BA57B63B58C73B5947BB58463946B52A5846BA57B5A8C634A
A57B63A57B638C634A9C7352A57B5A94735A8C6B525A3121734A317B5A42A57B5A845239845239\
6B39218452397342296B39215A31215A39295A31215A3121734A318C5A42A5846B
BD947BB5846BBD947BCEB5A5B5947B84634A947B6BB58463A5846B9C6B4AC6A59CF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECECE7B6B5A7B5A4284634AA58C73BD9C8CC6AD9CD6B5A5\
A5846B946B52A57B5AB58C7394735A94735AA57B638C6B528C634A9C736394735A
8C6B52946B52A57B6394735A8C634AA57B5A9C73528C6B528C634A734A31734A3184634A845239\
8452398C5A428452319C6B4A845231845231945A319C6B4AAD7352A57B63BD8C63
C69C84DEC6B5B5947BBD9C8C9C7B6B734A3194735AA5846BB5947BB5947BF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDB5947B6B8C735A84635284634AA58473A58C84\
D6B5A58C634A8C6B529C7B63B5846394735A946B52845A427B5A427B5A428C634A
8C634A946B5294735A8C634A8C634AA57B5AA5846B9C735294735A7B5A42A57B5A845239845231\
94735A946B528C634A9463429C6B4AA57B5AB58463C69C84B58C73BD947BD6B5A5
BD9C8CB59C8CA58C73A58C737B5A429C7363A58C73A5846BA57B6BFFFFFFF7F7F7FFFFFFFFFFFF\
F7F7F7F7EFF7FFFFFFF7EFF7FFFFFFF7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7BDADAD94735A9473639C7363A5846BA58C7B\
C69C84C6A5948C6B528C6B52A5846BA5846B946B52A5846B845239845A42845A42
9C6B4A946B529C7352845239A57B6B9C7352B58C73A57B63B5846BB5947B946B528C5A428C5A42\
9C73529C7352B58463B58463BD8C63BD8C63D6A584D6A584C6A594A57B639C7B6B
9C7B6B8C5A42734229845239A57B63A5846B9C7B63BD947BFFFFFFF7F7F7F7F7F7F7F7F7FFFFFF\
FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7CEB5B5846352947363A58C73B5947B\
BD9C8CC6A594C6AD9C94735AA5846B8C634AA5847394735AA57B63946B52845239
7B5242734A318C634A7B5A429C73639C7352BD947BB58C73DEC6B5E7C6B5D6B5A5C69C84DEAD9C\
D6A58CD6A58CD6A58CE7C6ADE7C6ADDEAD94CEB5A5A58C738C6B529C7B63946B52
845A427B5A428C634AB58463B5947BA57B63A57B6BFFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7EFEFF79C847B947363736352\
A58C73CEB5A5CEB5A5CEAD94A58473B58C73A58473A58C7BA57B6BBD947BC6A594
9C7B6B7B52428C6B527B524294735AB5947BC6A594BD9C8CA58C7BD6BDADD6BDB5D6BDADDEC6B5\
E7D6C6E7CEC6D6BDADC69C84B5947BB5947BA5847394736394735A946B52735242
84523994735A9C7B63BD947BA57B63B5947BF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7\
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFF9C7B6B846352\
9C8473A58C7BC6AD9CDEC6C6C6AD9CC6AD9CD6BDB5BDADADDECEBDD6BDB5C6A59C
E7CEC6EFD6C6F7EFE7EFE7DEEFD6C6E7CEC6E7CEBDD6BDADDECEBDDEC6B5DEC6B5DEC6B5E7CEBD\
CEB5A5A58C73C6A594A58C739C7B639C7B6B9C7B6B8C634A8C6B52735A4AA57B63
A58C73A5846BA5846BA57B63FFFFFFF7F7F7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEDE\
8463528C7363B5947BBDA59CD6BDB5DECEBDE7D6CEDECEC6DECEBDDECEBDDECEBD
E7D6CEDEC6B5E7C6B5E7CEBDE7C6B5EFD6C6EFDECEE7D6CEDECEBDE7CEC6CEB5A5BD9C94D6BDAD\
BD9C8CB59C8CBD9C948C735AA57B5A8C634A8C6B529C7B6BA58473BD9C8CC69C84
B58C73A5846BC6A59CF7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFFFFFFFF7F7F7FFFFFFF7F7F7F7F7F7FFFFFF\
EFE7E7A584739C8473A58C84CEB5A5CEB5A5D6BDB5D6C6B5DECEBDE7D6CEE7D6CE
E7D6CEE7D6CEEFE7DEE7DED6E7D6D6E7D6CEEFDECEE7CEC6DECEBDD6BDB5CEC6BDB59C8CA58C84\
BD9C949C7B639C7B6B94735AA58C73846352A58C7BBD9C8CC69C84B59C8CA58C7B
C69C84E7DEDEF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7\
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
FFFFFFF7F7F7F7F7F7B5948C9C7B6BA58473CEB5B5DEC6C6E7D6CEE7D6CEE7D6C6
E7CEC6DEC6C6E7D6D6DECEC6DEC6C6D6BDB5C6AD9CBD9C8CB5947BC6A594C6AD9CB59C8CA58C7B\
846B52A57B6BB59C8CA58C7BC6AD9CC6AD9CCEB5A5C6AD9CA58C84C6AD9CF7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7\
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BD9C94B5948CC6B5B5CEB5B5D6BDB5
E7D6D6E7D6D6E7D6CEE7D6D6E7D6D6E7D6CED6BDB5D6BDB5C6A59CBDA59CB5948CCEB5A5DECEBD\
BD9C94D6BDB5DEC6C6D6BDB5BD9C94B5947BD6BDADEFE7E7FFFFFFFFFFFFFFFFFF
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF\
F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7BDADADBDA59CD6BDB5
C6A59CD6BDADDECEC6DECEC6E7DED6E7D6D6EFE7DEF7EFE7EFE7DEE7D6CEDECEBDE7D6CEDECEC6\
DECEBDC6A59CBD9C8CCEB5A5DECEBDEFE7E7F7F7F7F7F7F7FFFFFFFFFFFFF7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7FFFFFFF7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7
F7EFF7EFE7E7EFE7E7E7DEDEF7EFE7EFE7DEDECEBDD6BDB5D6BDB5DECEBDDECEC6DEC6C6DEC6C6\
DECECEEFE7E7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7
FFFFFFFFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7FFFFFFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFF\
F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7
F7F7F7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFF7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFFFFFFF
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7\
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFF\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7EFF7
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7FFFFFFFFFFFFF7F7F7F7F7F7\
F7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7\
FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7FFFFFFF7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7EFF7FFFFFFF7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFFFFFFFF7F7F7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7F7EFF7F7F7F7F7F7F7FFFFFFF7EFF7F7F7F7
FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7\
F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7
FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7EFF7F7EFF7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7FFFFFF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7EFF7FFFFFF
F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF\
F7EFF7FFFFFFF7F7F7F7EFF7F7F7F7F7EFF7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF\
F7F7F7FFFFFFF7F7F7F7EFF7FFFFFFFFFFFFF7F7F7F7EFF7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7FFFFFF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7\
F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7F7EFF7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFFF7EFF7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7
F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
FFFFFFF7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFF
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003P3oool20>o_m`80mnoW103gmoL20>o_m`80mnoW
103_knL20?Ogm`80knoW0P3gknL60>o>]@80kljm0P3_e/H:0>o>_@80mnoW0P3gimh20<J4J`80ilJ]
0P3_c[d40>O6[@80ikfU103_aZD30>NmW080klJU0P3_aZd20>o6Y@80klJ]103W_JD40>o6Y@@0klj]
103_aZd60>o6Y@80klJ]0P3_]I`60>o6[@h0mlje0P3_cZd20?O>]@@0klJ]0P3ga[D20?O>]@X0klJ]
203_aZD40>o6[@80ilJ]103_aZd20>o6Y@@0klJ]0P3_aZD20?ONcP80mnoW0P3gg/h20<jDJ`@0ikfU
103_aZD60>NmY@d0ilJ]0P3_c[D20>o>[@80klJe0P3_cZd20?OF_@80mlje1P3ge[d20>o>_@80mmJm
0P3_c[D20>O6]@80ilJ]103F_Jd40>NmY@80ikfL0P3F_Jd20>oNcP80imkN0P3N[H`20>O>_@80knOW
0P3gkoL20?Ogm`80knog403oool000h0oooo0P3_koL20?O_i`@0moOg0P3_koL20?O_i`@0knoW0P3g
moL20>o_i`80mnoW1P3_c[D20>o>_@80kmK62P3_c[d20?O_i`80mnON0P36Q6/20>O6[@80kljm103W
aZd20>NmY@@0klJU0`3W_I`20>o6Y@80klJ]0P3_aZD20>o6[@@0ikfU103_aZD40>o>[@@0klJ]1P3_
aZD20>o6[@80kkFL1P3_aZd>0?O>]@80klj]0P3gc[D40>o6[@80mlJe0P3gc[D:0>o6[@P0klJU103_
aZd20>O6[@@0klJ]0P3_aZD40>o6[@80klJU0P3gg/h20?O_i`80mmk>0P3>U6/40>NmY@@0klJU1P3W
_JD=0>O6[@80klje0P3_cZd20>o6]@80klj]0P3ge[d20?O>]@H0mmJm0P3_c[d20?OF_@80klje0P3W
a[D20>O6[@@0e[f]103W_JD20>NmW080e[f]0P3_g/h20>ONgP80gZf<0P3Wc[d20>oWi`80mnog0P3g
moL20>o_ma00oooo000>0?ooo`80knog103gkoL20>o_i`80mnoW103gmoL40>o_m`80moOg0P3gknL2
0>o_i`h0kljm1P3_c[D20?OWgP80eZF<0P3_aZd20>o>]@80ilJe103WaZd70>NmY@80kkfL0P3_aZD2
0>o6[@80klJU0P3_aZd20>o6Y@80kkfL0P3_aZd20>o>]@@0klJ]103_aZD20>neW080kkfL103_aZD2
0>NmY@80klJU0P3_aZd20>o6Y@80klJ]0P3_cZd20?O6]@@0klJ]0P3gc[D40>o6[@80mlje2P3_aZd2
0?O6]@@0klJ]103_aZD:0>o6[@80ilJ]0P3W_JD40>o6[@80klJU0P3_aZd20>o6Y@80mmk>0P3gknL2
0=J]Q080gXAc1P3_aZD;0>NmY@80klJU1P3_aZd20>o>[@80klJ]0P3_c[D20>o6[@@0klje1P3_c[d2
0?OF_@@0kljm0P3WaZd20>O6]@@0ilJ]103W_JD20>O6[@80knON0P3_inL20>NmW080ikfD0P3W_JD2
0>oWi`80mnog0P3_koL20?O_ia00oooo000>0?ooo`80knog103gkoL20>o_i`80mnoW103gmoL40>o_
m`80moOg0P3gknL20>o_i`h0kljm1P3_c[D20?OWgP80eZF<0P3_aZd20>o>]@80ilJe103WaZd70>Nm
Y@80kkfL0P3_aZD20>o6[@80klJU0P3_aZd20>o6Y@80kkfL0P3_aZd20>o>]@@0klJ]103_aZD20>ne
W080kkfL103_aZD20>NmY@80klJU0P3_aZd20>o6Y@80klJ]0P3_cZd20?O6]@@0klJ]0P3gc[D40>o6
[@80mlje2P3_aZd20?O6]@@0klJ]103_aZD:0>o6[@80ilJ]0P3W_JD40>o6[@80klJU0P3_aZd20>o6
Y@80mmk>0P3gknL20=J]Q080gXAc1P3_aZD;0>NmY@80klJU1P3_aZd20>o>[@80klJ]0P3_c[D20>o6
[@@0klje1P3_c[d20?OF_@@0kljm0P3WaZd20>O6]@@0ilJ]103W_JD20>O6[@80knON0P3_inL20>Nm
W080ikfD0P3W_JD20>oWi`80mnog0P3_koL20?O_ia00oooo000>0?ooo`H0knoW0P3gknL60>o_m`80
mnoW103_koL40?Ogm`80mnog0P3_c[d60>o>]@80mlJe103_c[D20>o6]@80klje0P3gg]H20?OWgP80
aW]:0P3WaZd20>o6]@80ilJe0P3W_JD20>NeW080ikfU1`3_aZD20>o6[@80klJU0P3_aZd20>o6Y@80
ikfU0P3_]I`40>o>[@80klJ]0P3_aZD40>nmW0@0ikfL1P3W]I`20>nmW080klJU103_aZd20>o>[@P0
klJ]0P3_aZD40>o6[@80klje103gc[D20>o>[@80mlJe0P3gc[D@0>o6[@80klJU303_aZd20>o6Y@80
kljm0P3gknL20?ONcP80aXAS1P3W_JD20>o6Y@80ilJ]1@3W_JD20>o6Y@@0ikfU0P3_aZd20>o>]@80
klj]0P3_c[D20>o>[@@0klje0P3_c[d20>oFaP80mmJm0P3_e/H20>o>_@80iljm0P3_a[D20>O6[@80
klJ]103WaZd20>O>_@80imK>0P3We/H20>oWgP80imK60P3W_I`20>NmY@80imkF0P3_knL20?Ogm`80
mnoW403oool000h0oooo1P3_knL20?O_i`H0knog0P3gknL40>o_m`@0moOg0P3gkoL20>o>_@H0klje
0P3ga[D40>o>]@80klJe0P3_c[D20?ONeP80mnON0P36NdX20>O6[@80klJe0P3Wa[D20>NmY@80ikFL
0P3W_JD70>o6Y@80klJ]0P3_aZD20>o6[@80klJU0P3W_JD20>neW0@0klj]0P3_aZd20>o6Y@@0kkfL
103W_I`60>NeW080kkfL0P3_aZD40>o6[@80klj]203_aZd20>o6Y@@0klJ]0P3_c[D40?O>]@80klj]
0P3ga[D20?O>]A00klJ]0P3_aZD<0>o6[@80klJU0P3_c[d20?O_i`80mmk>0P36Q6<60>NmY@80klJU
0P3WaZd50>NmY@80klJU103W_JD20>o6[@80klje0P3_cZd20>o>]@80klj]103_c[D20>o>_@80kmK6
0P3ge[d20>oFaP80kljm0P3Wc[d20>o6]@80ilJ]0P3_aZd40>O6[@80iljm0P3We/h20>OFaP80knON
0P3We/H20>NmW080ikfU0P3Wg]H20>o_i`80moOg0P3gknL@0?ooo`003P3oool20?O_i`80knog0P3g
koL20?Ogm`80knog103gmoL20>o_i`@0moOg0P3gknL20>o_m`80mnoW103_knL20?OF_@80klJe0P3_
c[D:0>o6[@80mnON0P3_e/H20=j]W080ilJ]103Wa[D;0>NmY@80klJU103_aZd20>o6Y@@0ikfU0P3_
aZD60>o6[@80kkfL0P3_aZD20>NmW080ikFL103W_I`20>NeW080ikFD0P3W_JD40>o6Y@@0klJ]0P3_
aZD20>o6[@H0klJU0P3_cZd20?OF_@H0mlje0P3ge[d40?O>]@80klj]103gc[D40>o6[@H0klJe0P3_
aZd40>o6]@X0klJ]0P3_c[d20?O_i`80mmk>0P3NQ7<:0>o6[@<0klj]103_aZd20>o6]@80klJ]0P3_
cZd20>o6[@80klje0P3_a[D20>o>]@80kljm0P3ge[d40>oFaP80kljm0P3_e/H40>o6]@80ilJe0P3_
c[D20>O6]@80knOW0P3We/h20>OFaP80knON0P3W_I`20>ONeP80ilJ]0P3W_I`60>oWi`80mnoW403o
ool000h0oooo0P3gknL20>o_m`80mnog0P3gmoL20>o_m`@0moOg0P3_knL40?Ogm`80mnoW0P3_koL2
0?O_i`@0knoW0P3ge[d20>o6]@80klje2P3_aZd20?OWgP80kmK60P3N[I`20>O6[@@0ilJe2`3W_JD2
0>o6Y@@0klJ]0P3_aZD40>NmY@80klJU1P3_aZd20>nmW080klJU0P3W_I`20>NeW0@0ikfL0P3W]I`2
0>NeU080ikfU103_aZD40>o6[@80klJU0P3_aZd60>o6Y@80klj]0P3ge[d60?O>]@80mmJm103gc[D2
0>o>[@@0mlje103_aZd60>o6]@80klJ]103_a[D:0>o6[@80kljm0P3gknL20?ONcP80gXAc2P3_aZd3
0>o>[@@0klJ]0P3_a[D20>o6[@80klj]0P3_aZd20>o>]@80klJe0P3_c[D20>o>_@80mmJm103_e/H2
0>o>_@80kmK6103_a[D20>O6]@80klje0P3Wa[D20>oWi`80imK>0P3We/H20>oWgP80ikfL0P3Wg]H2
0>O6[@80ikfL1P3_inL20?O_ia00oooo000>0?ooo`80knog0P3gkoL20>o_m`80mnog0P3gmoL40?O_
m`80knog203gmoL20?O_i`80moOg0P3_koL20?O_i`80mmJm0P3_c[D20?O>]@80klJ]0P3_cZd20>o6
[@80mlje103gimh20=j]W080klJ]0P3_a[D20>O>_@L0ikfU0P3_aZD40>NmY@@0klJU0P3_aZd40>o6
Y@80klJ]0P3_aZD60>nmW0X0klJU0P3__I`20>NeW080ikfL0P3W_JD20>o6Y@H0kkFL0P3_aZD:0>o6
[@80mlje103_aZd40?OF_@80klJe0P3gc[D20?O6]@80mlje0P3ga[D20>o6[@@0klje103_a[D60>o>
]@80klJ]0P3_c[D60>o6[@80kljm0P3gknL20=j]S080ijfL0P3_aZd60>o>[@L0klJ]0P3_cZd20>o>
]@80klj]0P3_c[D20?O>]@@0klje0P3gc[D20?OF_@H0kmK61P3_c[d20>O6]@80kmK60P3_knL20>oW
i`@0knON0P3_knL20>O>_@80mmkF103W_I`20>oWi`80moOg0P3gknL20>o_ia00oooo000>0?ooo`80
knog0P3gkoL20>o_m`80mnog0P3gmoL40?O_m`80knog203gmoL20?O_i`80moOg0P3_koL20?O_i`80
mmJm0P3_c[D20?O>]@80klJ]0P3_cZd20>o6[@80mlje103gimh20=j]W080klJ]0P3_a[D20>O>_@L0
ikfU0P3_aZD40>NmY@@0klJU0P3_aZd40>o6Y@80klJ]0P3_aZD60>nmW0X0klJU0P3__I`20>NeW080
ikfL0P3W_JD20>o6Y@H0kkFL0P3_aZD:0>o6[@80mlje103_aZd40?OF_@80klJe0P3gc[D20?O6]@80
mlje0P3ga[D20>o6[@@0klje103_a[D60>o>]@80klJ]0P3_c[D60>o6[@80kljm0P3gknL20=j]S080
ijfL0P3_aZd60>o>[@L0klJ]0P3_cZd20>o>]@80klj]0P3_c[D20?O>]@@0klje0P3gc[D20?OF_@H0
kmK61P3_c[d20>O6]@80kmK60P3_knL20>oWi`@0knON0P3_knL20>O>_@80mmkF103W_I`20>oWi`80
moOg0P3gknL20>o_ia00oooo000>0?ooo`80knog0P3gkoL20>o_i`80mnog0P3_koL20?O_i`80mnog
0P3gmoL20>o_i`@0mnog0P3_knL40?Ogm`80mnog0P3gmoL20?O_m`80kmk>0P3_c[D20?O>]@H0klje
0P3_c[d20?OWgP80knON0P3_aZd40>o>]@80ilJe0P3WaZd50>NmY@80klJU0P3WaZd40>o6[@@0ikfU
0P3_aZD20>NmY@80ikFL103__I`20>NmW0H0klJU0P3_aZd20>o6Y@@0klJ]0P3_]I`40>NeW080kkfL
0P3W]I`20>o6Y@80ikfU0P3_aZD:0>o6[@80mlJe103gc[D20>o6[@80kljm1P3_c[D20?O>]@80klje
0P3gc[D20>o>]@80kljm0P3_c[D20>o6]@80klje1P3_a[D20>o6[@80klj]103_aZd20>o>_@80mnoW
0P3W_JD20>N]W080klJ]103_c[D30>o>[@80klJe103_cZd80?O>]@80klje0P3gc[D40>o>_@H0kmK6
0P3_c[d20>O6]@80g/Je0P3W_I`20>OFcP80knON0P3gknL20>O6[@80imK>0P3WaZd20>o>_@80knOW
0P3W_JD20>OFcPH0mnog0P3_knL@0?ooo`003P3oool20>o_m`80mnog0P3_knL20?O_m`80knog0P3g
knL20?O_m`80moOg0P3_knL40?O_m`80knoW103gmoL20?O_m`80moOg0P3gkoL20>oNcP80klje0P3g
c[D60>o>]@80kljm0P3gimh20>oWgP80klJ]103_c[D20>O6]@80ilJ]1@3W_JD20>o6Y@80ilJ]103_
aZd40>NmY@80klJU0P3W_JD20>NeW0@0kkfL0P3W_I`60>o6Y@80klJ]0P3_aZD40>o6[@80kkFL103W
]I`20>nmW080ikFL0P3_aZD20>NmY@80klJU2P3_aZd20?O6]@@0mlje0P3_aZd20>o>_@H0klje0P3g
c[D20>o>]@80mlje0P3_c[D20>o>_@80klje0P3_a[D20>o>]@H0klJe0P3_aZd20>o>[@@0klJ]0P3_
c[d20?O_i`80ikfU0P3W[I`20>o6[@@0klje0`3_cZd20>o6]@@0klj]203gc[D20>o>]@80mlje103_
c[d60>oFaP80kljm0P3Wa[D20=k6]@80ikfL0P3We/h20>oWgP80mnoW0P3WaZd20>OFcP80ilJ]0P3_
c[d20>oWi`80ikfU0P3We/h60?O_m`80knoW403oool000h0oooo0P3_koL60?Ogm`80knoW0P3gmoL2
0>o_i`@0mnog0P3gmoL20>o_i`@0moOg0P3_koL80?Ogm`80mnoW103_e/H20?OF_@80kmK6103ge[d2
0?O_i`80imKF0P3_a[D40>o>_@80iljm0`3Wa[D20>O6[@@0ikfU103W_I`20>NmY@80ikFD0P3N[I@6
0>NeU080ikfL0P3W]I@20>o6Y@80klJ]203_cZd20?O>]@@0klJU0P3W]I`20>nmW080ikfL0P3__I`2
0>NeW080ikfL0P3W_JD20>neW0@0klJU103_aZd20>o>[@X0klJ]0P3_a[D40>o6[@@0klje1P3_a[D:
0>o6[@80ilJ]103_aZd20>O6[@80kmK60P3gknL20?ONcP80ilJ]1`3_aZd20>o6Y@80klj]0P3ga[D4
0?O>]@80klje0P3gc[D20>o>]@80mmJm0P3_c[d60>oFaP80ilJe0P3WaZd20=j]W080cZfD0P3W_JD2
0>oWi`80imkF0P3_knL20>O6]@80iljm0P3_c[D40>O>_@80ikfD0P3_inL20?O_m`80mnoW0P3gmoL2
0>o_ma00oooo000>0?ooo`80knog1P3gmoL20>o_i`80moOg0P3_knL40?O_m`80moOg0P3_knL40?Og
m`80knog203gmoL20?O_i`@0kmK60P3ge[d20>oFaP@0mmJm0P3gknL20>OFeP80klJe103_c[d20>O>
_@<0ilJe0P3WaZd40>NmY@@0ikfL0P3W_JD20>NeU080gZfD1P3W]I@20>NmW080ikFD0P3_aZD20>o6
[@P0klj]0P3gc[D40>o6Y@80ikFL0P3__I`20>NmW080kkfL0P3W]I`20>NmW080ikfU0P3_]I`40>o6
Y@@0klJ]0P3_cZd:0>o6[@80klJe103_aZd40>o>]@H0klJe2P3_aZd20>O6[@@0klJ]0P3WaZd20>oF
aP80mnoW0P3gg/h20>O6[@L0klJ]0P3_aZD20>o>[@80mlJe103gc[D20>o>]@80mlje0P3_c[D20?OF
_@80kljm1P3_e/H20>O6]@80ilJ]0P3N[I`20<j]U080ikfU0P3_inL20>ONeP80knoW0P3Wa[D20>O>
_@80klje103Wc[d20>NmU080knOW0P3gkoL20?O_i`80moOg0P3_koL@0?ooo`003P3oool20>o_m`80
mnoW1P3gkoL20?Ogm`80mnog0P3gmoL40>o_m`80knoW103_koL20?Ogm`80mnog1P3gmoL20?O_m`80
knog0P3gg]H60?ONcP@0kmk>0P3gknL20>oFaP80_IAk0P3_c[d20>o6]@<0klJ]203W_JD20>NmW0@0
gZfD303W]I@20>NmY@80klJU0P3_aZd60>o>[@80mlje103_aZd20>neW080ikFL103W]I@20>NeW080
ikfU0P3W]I`40>NeU080ikFL1P3W_JD20>o6Y@@0ikfU0P3__I`20>NmY@80klJU0P3W_JD20>o6Y@80
ilJ]0P3W_JD20>O6[@@0klJU3P3W_JD20>o6Y@@0ikfU0P3We]H20?OWgP80ilJe0P3WaZd20>o6Y@T0
klJ]0P3_c[D20?O>]@@0klje103ge[d60>o>_@80ilJ]0P3W_JD20=JLN`80eZf40P3>[I@20>O6[@80
imK>0P3WaZd20=j]S080ikfU0P3_aZD20>NmU080imK>0P3Wa[D20>NmW080knON0P3gkoL20>o_i`80
mnoW0P3_koL@0?ooo`003P3oool20>o_m`80mnoW1P3gkoL20?Ogm`80mnog0P3gmoL40>o_m`80knoW
103_koL20?Ogm`80mnog1P3gmoL20?O_m`80knog0P3gg]H60?ONcP@0kmk>0P3gknL20>oFaP80_IAk
0P3_c[d20>o6]@<0klJ]203W_JD20>NmW0@0gZfD303W]I@20>NmY@80klJU0P3_aZd60>o>[@80mlje
103_aZd20>neW080ikFL103W]I@20>NeW080ikfU0P3W]I`40>NeU080ikFL1P3W_JD20>o6Y@@0ikfU
0P3__I`20>NmY@80klJU0P3W_JD20>o6Y@80ilJ]0P3W_JD20>O6[@@0klJU3P3W_JD20>o6Y@@0ikfU
0P3We]H20?OWgP80ilJe0P3WaZd20>o6Y@T0klJ]0P3_c[D20?O>]@@0klje103ge[d60>o>_@80ilJ]
0P3W_JD20=JLN`80eZf40P3>[I@20>O6[@80imK>0P3WaZd20=j]S080ikfU0P3_aZD20>NmU080imK>
0P3Wa[D20>NmW080knON0P3gkoL20>o_i`80mnoW0P3_koL@0?ooo`003P3oool20>o_m`80moOg0P3_
koL60?Ogm`80knog0P3gknL40?O_m`80moOg0P3gkoL20>o_m`80knoW0P3gmoL20?O_m`@0moOg0P3_
koL20?Ogm`80knog0P3gmoL40?O_m`@0moOg103gkoL20?O_i`80e[f]0P3WaZd30>o6[@80ilJ]1P3W
_JD20>NeW080ikfL0P3F]JD40>NmW080kkfL103_aZD20>nmW080ikFD0P3__I`20>o6Y@P0klj]0P3g
c[D20>o>[@80klJU0P3_]I@20>nmW080klJU0P3_]I`40>nmW0@0ikfU103W]I@20=j]S080gZfD0P3N
[H`20=jUQ080gZfD1P3N[H`20=jUQ0@0gZf<3P3N[I@20>NmW080ikFL1P3W_I`20>NeW080ikFD0P3W
_I`20=j]U0@0ilk60P3F[H`30=j4L`80gZfD103W_JD60>o6[@80klje103_c[d20>oFaP80kljm0P3W
a[D20<jDH`80eYac0P3N[H`20<jeY@@0gZf<0P3Wa[D20>O6[@80ikfU0P3W_I@20>NmW080imkF0P3W
c[d20>NmW080imKF0P3_imh20>o_m`80mnog103_knL@0?ooo`003P3oool20>o_m`80moOg0P3_koL6
0?Ogm`80knog0P3gknL40?O_m`80moOg0P3gkoL20>o_m`80knoW0P3gmoL20?O_m`@0moOg0P3_koL2
0?Ogm`80knog0P3gmoL40?O_m`@0moOg103gkoL20?O_i`80e[f]0P3WaZd30>o6[@80ilJ]1P3W_JD2
0>NeW080ikfL0P3F]JD40>NmW080kkfL103_aZD20>nmW080ikFD0P3__I`20>o6Y@P0klj]0P3gc[D2
0>o>[@80klJU0P3_]I@20>nmW080klJU0P3_]I`40>nmW0@0ikfU103W]I@20=j]S080gZfD0P3N[H`2
0=jUQ080gZfD1P3N[H`20=jUQ0@0gZf<3P3N[I@20>NmW080ikFL1P3W_I`20>NeW080ikFD0P3W_I`2
0=j]U0@0ilk60P3F[H`30=j4L`80gZfD103W_JD60>o6[@80klje103_c[d20>oFaP80kljm0P3Wa[D2
0<jDH`80eYac0P3N[H`20<jeY@@0gZf<0P3Wa[D20>O6[@80ikfU0P3W_I@20>NmW080imkF0P3Wc[d2
0>NmW080imKF0P3_imh20>o_m`80mnog103_knL@0?ooo`003P3oool20?Ogm`80mnog0P3gmoL20?O_
i`H0moOg103gkoL20>o_i`80mnoW103_koL20?O_i`80moOg0P3_koL20>o_i`80moOg0P3_koL20?Og
m`80mnog0P3gmoL20?O_m`80knog0P3gmoL40?O_m`80mnoW0P3gmoL20>o_m`80ikfL0`3FW7/20>OF
aP80ikfU0P3N[I`40>NmY@80ikfL103F]JD20=j]U080ikFD0P3W_I`40>nmW080ikFD0P3W_I`40>o6
Y@80mlje0P3_cZd20?O>]@80klj]103_aZd80>nmW080klJU0P3__I`60>o6Y@80kkfL0P3_aZD40>nm
W080ikfL0P3W]I`20>NmW0H0ikFL0P3W_I`40>NeW080kkfL0P3W_I`20>nmW0@0ikfU103_aZD20>Ne
W0H0klJU0P3W_JD20>o6Y@@0ikfU0P3__I`20>o6]@80iljm0`3Wc/H20>NmY@80U5Xa0P3W]I`20=j]
W080ikfU103WaZd20>O6]@80eZf<0P36Q5X40<IkBP80cXaJ0P3N[H`20>NmU080ikfU0P3N[H`20>Nm
U080ikfL0P3W_JD20>O>_@80ilJ]0P3N[H`20>oFaP80imK60P3N[H`20>oNcP80imkF0P3gknL20?O_
m`80moOg0P3_koL@0?ooo`003P3oool20?Ogm`80mnog0P3gmoL20?O_i`H0moOg103gkoL20>o_i`80
mnoW103_koL20?O_i`80moOg0P3_koL20>o_i`80moOg0P3_koL20?Ogm`80mnog0P3gmoL20?O_m`80
knog0P3gmoL40?O_m`80mnoW0P3gmoL20>o_m`80ikfL0`3FW7/20>OFaP80ikfU0P3N[I`40>NmY@80
ikfL103F]JD20=j]U080ikFD0P3W_I`40>nmW080ikFD0P3W_I`40>o6Y@80mlje0P3_cZd20?O>]@80
klj]103_aZd80>nmW080klJU0P3__I`60>o6Y@80kkfL0P3_aZD40>nmW080ikfL0P3W]I`20>NmW0H0
ikFL0P3W_I`40>NeW080kkfL0P3W_I`20>nmW0@0ikfU103_aZD20>NeW0H0klJU0P3W_JD20>o6Y@@0
ikfU0P3__I`20>o6]@80iljm0`3Wc/H20>NmY@80U5Xa0P3W]I`20=j]W080ikfU103WaZd20>O6]@80
eZf<0P36Q5X40<IkBP80cXaJ0P3N[H`20>NmU080ikfU0P3N[H`20>NmU080ikfL0P3W_JD20>O>_@80
ilJ]0P3N[H`20>oFaP80imK60P3N[H`20>oNcP80imkF0P3gknL20?O_m`80moOg0P3_koL@0?ooo`00
3P3oool20>o_i`80knog0P3gmoL20>o_m`80mnog0P3_knL20>o_m`@0mnog0P3gmoL20>o_i`80mnog
103gmoL60?O_m`80moOg0P3gkoL20?Ogm`80mnog0P3gmoL20>o_m`@0mnog0P3_koL20?Ogm`80knog
103gkoL20>NmW0<0eYac0P3N[I@20<j]U080gZfL203W_I`20>NmY@80e[FU0P3W]I@20>NmW0@0kkfL
0P3W]I@20>NmU080klJU0P3_aZd20>o6Y@80klJ]203_cZd20>o6Y@@0kkfL3P3_aZD20>nmW080kkFL
203_aZD20>NmY@80ikfL103__I`40>o6Y@H0kkfL0P3W_JD:0>o6Y@80kkfL0P3_aZD20>nmW0@0klJU
0P3_aZd20>o6Y@80ikfU0P3_aZd30>o6Y@80iljm0P3Nc[d20>OFeP80eZf<102mU7/20=JUQ080_HaS
0P36NdX20<j<FP80aW]:0P36Q5X40=JLL`80ikfD0P3N[I@20=J]Q080knON103W_I@20=k6]@80gZEk
0P3_c[d20>oNcP80ikfL0P3Wg]H20>O6]@80knoW0P3_inL40>o_i`80moOg403oool000h0oooo0P3_
knL20>o_m`80moOg0P3_koL20?O_m`80knoW0P3_koL40?O_m`80moOg0P3_knL20?O_m`@0moOg1P3g
koL20?Ogm`80mnog0P3gmoL20?O_m`80moOg0P3_koL40?O_m`80knog0P3gmoL20>o_m`@0mnog0P3W
_I`30=JLL`80gZfD0P3>[I@20=j]W0P0ikfL0P3W_JD20=JeY@80ikFD0P3W_I`40>nmW080ikFD0P3W
_I@20>o6Y@80klJ]0P3_aZD20>o6[@P0klj]0P3_aZD40>nmW0h0klJU0P3__I`20>neW0P0klJU0P3W
_JD20>NmW0@0kkfL103_aZD60>nmW080ikfU2P3_aZD20>nmW080klJU0P3__I`40>o6Y@80klJ]0P3_
aZD20>NmY@80klJ]0`3_aZD20>O>_@80g/jm0P3We]H20=J]S0@0_IAk0P3FYH@20;f<H`80aW]:0P3>
S5X20<IkBP80aXAJ103FW7<20>NmU080gZfD0P3F[H@20>oWgP@0ikfD0P3Na[D20=jUN`80kljm0P3_
g/h20>NmW080imkF0P3Wa[D20>o_i`80knOW103_knL20?Ogma00oooo000>0?ooo`80moOg0P3_koL2
0?O_i`80moOg0P3_koL40?Ogm`80knoW103gknL20?Ogm`80mnog0P3gmoL20>o_m`80moOg0P3_koL4
0?O_m`80moOg0P3_koL80?Ogm`@0knog103_knL20?O_m`80knoW0P3Wa[D30>O6[@80cYAS103F[H@2
0<jDJ`80ikfL0P3W_JD20>NeW080ikfL0P3N[I`20>NmU080ikfL0P3W]I@20>nmW0@0ikfD1P3_aZD4
0>o6[@80klj]0P3_aZD20>o>[@@0klJU103__I`@0>o6Y@80kkFL103__I`60>o6Y@80ikfL0P3__I`2
0>NmY@80kkFL0P3__I`40>o6Y@80kkFL203_aZD40>nmW080klJU0P3W_JD20>o6Y@80ikfL203_aZD7
0>NmY@80iljm103Wc/H20=Jm[@80[F<a0P2]JcT20<J4FP80aW]:0P36Q5X40<jDH`80cYA[0P3>U6<2
0<j]U080e[FU0P3Wg]H20=JLL`80gZf40P3WaZd20=jUN`80ilJe0P3We/H20>NmU080knoW0P3_imh4
0>o_i`@0knog0P3gmoL@0?ooo`003P3oool20?Ogm`80knog0P3gknL20?Ogm`80knog103gmoL20>o_
i`@0mnoW0P3gmoL20?O_m`80moOg0P3_koL20?Ogm`80knog103gkoL20?Ogm`80knog203gmoL40>o_
m`@0knoW0P3gkoL20>o_i`80ilJe0`3WaZd20<jDH`@0eZf40P3>U6/20>NmW080ikfU0P3W]I`20>Nm
W080gZfL0P3W_I@20>NmW080ikFD0P3__I`40>NmU0H0klJU103_aZd20>o>[@80klJU0P3_cZd40>o6
Y@@0kkfL403_aZD20>neW0@0kkfL1P3_aZD20>NmW080kkfL0P3W_JD20>neW080kkfL103_aZD20>ne
W0P0klJU103__I`20>o6Y@80ikfU0P3_aZD20>NmW0P0klJU1`3W_JD20>O>_@@0ilk60P3F_Jd20:eS
<@80[F/i0P36Q5X20<IkBP80aXAJ103>U6<20<jDJ`80cYAS0P3>[I@20=JeY@80imkF0P3FW7<20=j]
Q080ilJ]0P3NYG/20>O6]@80imK60P3W_I@20>o_i`80knON103_knL40>o_m`80moOg403oool000h0
oooo0P3_koL40?Ogm`@0knog0P3gmoL20?O_i`H0moOg0P3_koL40?Ogm`80mnog0P3gknL80?Ogm`80
mnoW0P3gkoL40?Ogm`80mnog103_koL20?O_m`H0knog0P3Wc/H30>O6]@80eZf<0P3>U6<20=J]Q080
aW]20P2]JcT20=j]W080ikfL103W]I`20>NmW080ikFL0P3W_I`20>neU080ikFD0P3W_I`:0>o6Y@80
klj]4P3_aZD20>o6[@P0klJU1P3__I`20>o6Y@@0kkfL0P3_aZD20>NmW080kkFL1P3__I`20>NmW080
ikfU0P3_aZD20>o6[@@0klJU0P3_]I`40>o6Y@H0kkfL103_aZD70>NmY@80ikfL0P3N[I@20=JUQ080
eYak0P36NdX20;E[@P80aW]:0P36Nd820;EkFP80aW]20P3>U6<20<j<FP80cYAS0P3>U6/40=j]Q080
gZf<0P3WaZd20=jUN`80gZf40P3W_I@20=j]Q080imK60P3WaZd20>O>_@80knON0P3_knL20?O_m`80
knON103gmoL20?O_ma00oooo000>0?ooo`80knog103gmoL40>o_m`80moOg0P3gknL60?Ogm`80knog
103gmoL20?O_m`80mnoW203gmoL20?O_i`80mnog103gmoL20?O_m`@0knog0P3gkoL60>o_m`80ilk6
0`3Wa[D20=J]S080cYAS0P3F[H@20<Ik@P80[F/i0P3N[I`20>NmW0@0ikFL0P3W_I`20>NeW080ikfL
0P3_]I@20>NeU080ikfL2P3_aZD20>o>[A80klJU0P3_aZd80>o6Y@H0kkfL0P3_aZD40>nmW080klJU
0P3W_I`20>neW0H0kkfL0P3W_I`20>NmY@80klJU0P3_aZd40>o6Y@80kkFL103_aZD60>nmW0@0klJU
1`3W_JD20>NmW080gZfD0P3FYH@20=JLN`80aW]:0P2eJd820<IkBP80aW]20P2eNeX20<Ik@P80cYAS
0P3>S5X20<jDH`80cYA[103N[H@20=j]S080ilJ]0P3NYG/20=j]Q080ikfD0P3N[H@20>OFaP80ilJ]
0P3Wc[d20>oWgP80knoW0P3gkoL20>oWgP@0moOg0P3gkoL@0?ooo`003P3oool20?Ogm`80mnog0P3_
koL20?O_m`80mnoW0P3gmoL20>o_m`80moOg0P3_knL20?Ogm`80knog0P3gmoL20?O_i`80moOg0P3_
koL60?Ogm`80knog0P3gkoL40?Ogm`80knog0P3gmoL20?O_i`80knoW0P3_koL20?Ogm`80mnoW0P3_
koL20>oNcP<0knON0P3We/H20<j<FP80cYAS0P36Nd820;E[>@80U58Y0P3W]I`20=j]W080ikfL0P3N
[I@20=j]W080ikFL0P3W_I`20>NmU080ikfL2P3_aZD20>o6[@X0klJU203__I`20>o6Y@80kkfL1P3_
aZD:0>nmW0H0ikfL203__I`20>NmW0@0kkfL0P3_aZD20>NmW0@0kkfL103_aZD20>nmW080ikfL1P3_
_I`20>NeU080ikfL0`3N[I@20=j]S080eYak0P3>U6<20;EcBP80]F]20P36NdX40<j<FP80aYA[0P36
Q5X20<Ik@P@0cYAS0P3NYG<20=j]S080gZf40P3W_I`20=j]S080eYac103N[H@60>O6[@80imK60P3g
koL20>o_i`@0mnoW103gkoL20>o_ia00oooo000>0?ooo`80moOg0P3gkoL20>o_m`80mnog0P3gknL2
0?Ogm`80knog0P3gmoL20>o_i`80moOg0P3_koL20?Ogm`80mnoW0P3gmoL20>o_m`H0moOg0P3_koL2
0?O_m`@0moOg0P3_koL20?Ogm`80mnoW0P3_knL20>o_m`80moOg0P3gknL20>o_m`80kmk>0`3_imh2
0>OFaP80cXaJ0P3>U6<20<Ik@P80]F/i0P2DDRT20>NeW080gZfL0P3W_I`20=j]U080gZfL0P3W]I`2
0>NmW080ikfD0P3W_I`:0>o6Y@80klJ]2P3_aZD80>nmW080klJU0P3__I`60>o6Y@X0kkfL1P3W_I`8
0>nmW080ikfL103__I`20>o6Y@80ikfL103__I`40>o6Y@80kkfL0P3W_I`60>nmW080ikFD0P3W_I`3
0=j]U080gZf<0P3FW7/20<jDH`80]G=:0P2eJd820<IkBP@0cXaJ0P36U6/20<J4FP80aW]2103>U6<2
0=jUL`80gZf<0P3N[H@20>NmW080gZf<0P3FW7<40=j]Q0H0ilJ]0P3We/H20?O_m`80knoW103gknL4
0?O_m`80knoW403oool000h0oooo0P3_koL20?O_m`80moOg0P3gkoL20>o_i`H0moOg0P3gknL20?Og
m`80mnog0P3_koL20?Ogm`80knog103gmoL20?O_i`80knog0P3gkoL20>o_m`80moOg0P3_knL20?Og
m`80mnog0P3gknL20?Ogm`@0mnog0P3_knL20?O_i`80imK>0`3gknL20>O6[@80cXaJ0P36NdX20<Ik
@P80]F<a0P2DDRT207/i6080gZF40P3N[H`20=j]U080ikfL0P3W]I`20>NmW080ikFD0P3W_I@20>Nm
Y@P0klJU0P3__I`>0>o6Y@80kkfL0P3_aZD60>nmW0P0klJU103_]I@80>nmW080kkFL0P3__I`20>Nm
W080kkFD0P3W_I@20>NmW080kkFL0P3_aZD20>nmW080klJU0P3__I`20>NmW0@0klJU103__I`20>Nm
W0@0ikFD0P3N[H`30=j]Q0@0eYac0P36NdX20:e[>@80aXAJ0P3>S5X20<IkBP80cXaJ0P3FW7/20<j<
FP80aXAJ0P3>S5X20=jUL`80cYAS0P3F[H@20=JLL`80cZfD0P3NYG/60>NmU080kmk>0P3N[H`20>O6
]@@0knoW0P3gkoL20?OWgP80knog0P3_knL20?Ogm`80mnog403oool000h0oooo0P3_koL20?O_m`80
moOg0P3gkoL20>o_i`H0moOg0P3gknL20?Ogm`80mnog0P3_koL20?Ogm`80knog103gmoL20?O_i`80
knog0P3gkoL20>o_m`80moOg0P3_knL20?Ogm`80mnog0P3gknL20?Ogm`@0mnog0P3_knL20?O_i`80
imK>0`3gknL20>O6[@80cXaJ0P36NdX20<Ik@P80]F<a0P2DDRT207/i6080gZF40P3N[H`20=j]U080
ikfL0P3W]I`20>NmW080ikFD0P3W_I@20>NmY@P0klJU0P3__I`>0>o6Y@80kkfL0P3_aZD60>nmW0P0
klJU103_]I@80>nmW080kkFL0P3__I`20>NmW080kkFD0P3W_I@20>NmW080kkFL0P3_aZD20>nmW080
klJU0P3__I`20>NmW0@0klJU103__I`20>NmW0@0ikFD0P3N[H`30=j]Q0@0eYac0P36NdX20:e[>@80
aXAJ0P3>S5X20<IkBP80cXaJ0P3FW7/20<j<FP80aXAJ0P3>S5X20=jUL`80cYAS0P3F[H@20=JLL`80
cZfD0P3NYG/60>NmU080kmk>0P3N[H`20>O6]@@0knoW0P3gkoL20?OWgP80knog0P3_knL20?Ogm`80
mnog403oool000h0oooo0P3gknL40>o_m`80mnoW0P3_koL20?Ogm`80knoW0P3gknL20>o_i`H0moOg
0P3gknL20?Ogm`@0mnoW0P3gmoL20>o_m`80moOg0P3gkoL20>o_m`80moOg0P3_koL20?O_i`80moOg
0P3gknL20?Ogm`80mnog0P3gknL20>o_i`80kmk>0`3_imh20>O6]@80e[f]0P36Nd820<J4FP80]F/i
0P2DDRT407/i60@0gZfD0P3W]I@20=j]U080ikfL0P3W_I@20>NeU0`0klJU103__I`40>o6Y@P0kkfL
0P3_]I@20>NmW080kkfL1P3_aZD60>nmW080ikfL0P3_]I@20>NmU080ikFD1P3__I`20>neU080ikfL
0P3W[H`20>NmW080ikfD303__I`20>NmU0@0gZf40P3NYG/90=JLL`80aXAJ0P2LHcT209AB:@80aW]:
0P3FW7<20<jDH`80[F]20P3>S5X20<jDJ`80eZf4103NYG<40<j<FP80cYAS0P3FW7<20=j]S080gZEk
103W_I@20>oWgP80ikfL0P3WaZd20>oFaP80knOW0P3_imh20>oWi`@0mnoW0P3_koL20?Ogm`80mnog
403oool000h0oooo0P3gknL40>o_m`80mnoW0P3_koL20?Ogm`80knoW0P3gknL20>o_i`H0moOg0P3g
knL20?Ogm`@0mnoW0P3gmoL20>o_m`80moOg0P3gkoL20>o_m`80moOg0P3_koL20?O_i`80moOg0P3g
knL20?Ogm`80mnog0P3gknL20>o_i`80kmk>0`3_imh20>O6]@80e[f]0P36Nd820<J4FP80]F/i0P2D
DRT407/i60@0gZfD0P3W]I@20=j]U080ikfL0P3W_I@20>NeU0`0klJU103__I`40>o6Y@P0kkfL0P3_
]I@20>NmW080kkfL1P3_aZD60>nmW080ikfL0P3_]I@20>NmU080ikFD1P3__I`20>neU080ikfL0P3W
[H`20>NmW080ikfD303__I`20>NmU0@0gZf40P3NYG/90=JLL`80aXAJ0P2LHcT209AB:@80aW]:0P3F
W7<20<jDH`80[F]20P3>S5X20<jDJ`80eZf4103NYG<40<j<FP80cYAS0P3FW7<20=j]S080gZEk103W
_I@20>oWgP80ikfL0P3WaZd20>oFaP80knOW0P3_imh20>oWi`@0mnoW0P3_koL20?Ogm`80mnog403o
ool000h0oooo0P3_knL20?Ogm`80mnog0P3_koL20?Ogm`@0knog0P3gkoL20?Ogm`@0mnog0P3gmoL2
0?O_m`80moOg0P3gkoL40?Ogm`80mnog0P3gmoL20?O_m`@0mnoW0P3gmoL20?O_m`80knog0P3_knL2
0?O_m`80mnoW0P3gkoL20>o_i`80mnoW1@3Wg]H20=J]Q080aXAJ0P36NdX20:eS<@80U58Y0P2<@R42
07/i6080Jc4H0P3N[H`20>NeW080cZfD0P3W_I@20>NeU080ikfD0P3__I`20>o6Y@P0kkfL0P3_aZD4
0>nmW080klJU103__I`20>o6Y@@0kkfL0P3_]I@20>NmU0@0kkfL0P3W_I`20>o6Y@80kkfL0P3_]I@2
0>NeU080kkFD203W]I@20>NmU0@0ikFD1P3W[H`20>neU080kkfL0P3W[H`20>nmW080gZf40P3W_I@2
0>NeU080ijf<103NYG/20=JLL`80cYA[0P36Q5X30;EcBP80U58Y0P2]FS420:eS<@80aXAJ103>U6<2
0<J<H`@0eYac0P3NYG<40=JLL`80gZEc0P3>S5X20<jDH`@0gZEk0P3N[H@20>NmU080ikfU0P3W_I`2
0>O6[@80imK60P3_imh20>oWi`80imkF0P3_inL40?O_m`80knog103gmoL@0?ooo`003P3oool20>o_
i`80moOg0P3gkoL20>o_m`80moOg103_koL20?O_m`80moOg103gkoL20?Ogm`80mnog0P3gmoL20?O_
m`@0moOg0P3gkoL20?Ogm`80mnog103gknL20?Ogm`80mnog0P3_koL20>o_i`80mnog0P3gknL20?O_
m`80knoW0P3gknL50>ONeP80eZf40P36Q5X20<IkBP80[F<a0P2DDRT208a28@80NcTH0P1[<AP20=j]
S080ikFL0P3>[I@20>NmU080ikFD0P3W_I@20>nmW080klJU203__I`20>o6Y@@0kkfL0P3_aZD40>nm
W080klJU103__I`20>neU080ikfD103__I`20>NmW080klJU0P3__I`20>neU080ikFD0P3_]I@80>Ne
U080ikfD103W]I@60>N]S080kkFD0P3__I`20>N]S080kkfL0P3N[H@20>NmU080ikFD0P3W[H`40=jU
N`80eYac0P3>U6/20<J4FP<0]G=:0P2DDRT20:eJ<@80[F<a0P36Q5X40<jDH`80aXaS103FW7<20=jU
L`@0eYac0P3NYG<20<j<FP80cYAS103NYG/20=j]Q080ikfD0P3W_JD20>NmW080ilJ]0P3We/H20>oW
gP80knOW0P3Wg]H20>oWi`@0mnog0P3_koL40?Ogma00oooo000>0?ooo`80mnoW0P3_knL60?Ogm`80
knoW1P3gmoL20?O_i`80knog0P3gmoL20?O_i`80mnog0P3_knL20?O_m`@0knog1P3gmoL40?O_m`80
moOg103_koL20?O_i`80mnog0P3gknL20>oWi`80knON0`3Wc[d20>oNcP80cXaJ0P36Q5X20<Ik@P80
[EXa102DDRT208a28@80Jc4H0P1:60P20=JUQ080gZfL0P3N[I@40>NeU080ikfU0P3W_I`80>nmW080
klJU0P3__I`20>o6Y@P0kkfL0P3W_I`40>nmW0@0kkFD0P3W_I@20>neU0@0kkfL0P3W_I`20>NmU080
kkFD0P3W]I@20>neU080ijf<0P3N[H@20>N]S080kkFD103W[H`20>neU080ijf<0P3W_I@20>NeU080
ijf<0P3N[H@20>NeU0@0gZf<0P3N[H@20=jUN`80eYak0P3>S6<20;EcBP80[F/i0`2]Hc4209aS>@80
[F]20P2mS6<20<jDJ`80cXaJ0P36S6<20<jDH`80eYac0P3>U6<40<J4FP80cYAS0P3>S5X20=jUL`@0
gZEk0P3NYG<20>NmU0@0ikfU0P3WaZd40>oWgP80kmk>0P3_inL20?O_m`80mnoW2P3gmoL@0?ooo`00
3P3oool20?O_i`80knoW1P3gmoL20>o_i`H0moOg0P3gknL20>o_m`80moOg0P3gknL20?O_m`80knoW
0P3gkoL40>o_m`H0moOg103gkoL20?Ogm`@0knog0P3gknL20?O_m`80mnoW0P3_inL20>oWgP<0iljm
0P3_g/h20<j<FP80aXAJ0P36Nd820:eJ<@@0U58Y0P2<@R4206/a6080BQP80P3FYH@20=j]W080gZfD
103W]I@20>NmY@80ikfL203__I`20>o6Y@80kkfL0P3_aZD80>nmW080ikfL103__I`40>neU080ikfD
0P3_]I@40>nmW080ikfL0P3W_I@20>neU080ikFD0P3_]I@20>N]S080gZf40P3W[H`20>neU0@0ijf<
0P3_]I@20>N]S080ikfD0P3W]I@20>N]S080gZf40P3W]I@40=j]S080gZf40P3NYG/20=JLN`80cXaS
0P2eLdX20:e[>@<0[F<a0P2LHcT20:e[@P80_HaS0P3>U6/20<j<FP80aXaS0P3>U6<20=JLL`80cYAS
1036Q5X20<jDH`80cXaJ0P3NYG<40=jUN`80gZEc0P3W_I@40>NmY@80ilJ]103_imh20>oNcP80knOW
0P3gkoL20?O_i`X0moOg403oool000h0oooo0P3_knL20?Ogm`80mnog1P3gmoL20?O_i`80mnog103g
moL20?O_m`80knog0P3_knL20?O_m`P0moOg0P3gkoL20>o_m`H0mnog0P3gmoL60?O_m`80knog0P3g
knL20?O_m`80knOW0`3We/H20>ONeP80cYAS0P36Q5X20<IkBP80[F<a102DDRT208a28@@0HbT@0P1:
60P40=j]U080ikfL0P3W]I`40>NmW0X0kkfL103_aZD>0>nmW0@0ikfD0P3__I`20>neU080ikfL0P3_
]I@20>neW0P0ikFD203W[H`20=j]Q080gZEk0P3N[H@20>N]S080gZf40P3W_I`20=jUN`80gZf<103N
[H@20=JLN`80gZF40P3FW7<20<IkBP80[EXa0P2]JcT208A28@<0[F]20P2eLdX20<IkBP80cYAS0P3>
S5X20<J<H`80aYA[0P36S6<20=jUL`H0eYac103NYG<20=jUN`80gZf40P3F[H@20>NmU080ikfL103W
_JD20>o>_@80kmK60P3_g/h20>oWgP80knoW0P3gknL20?Ogm`80mnog0P3gmoL20?O_m`80knog0P3g
moL@0?ooo`003P3oool20>o_i`80moOg0P3gkoL60?Ogm`80mnoW0P3gkoL40?Ogm`80mnog0P3_koL2
0>o_i`80mnog203gmoL20?O_m`80knog1P3gkoL20?Ogm`H0mnog0P3_koL20?O_i`80mnog0P3_inL3
0>OFaP80imkF0P3>U6<20<J4FP80aW]:0P2]Hc4409AB:@80S48Q101S:A0204XH20@0gZfD0P3W_I`2
0>NeW0@0ikfL2P3__I`40>o6Y@h0kkfL103W_I@20>nmW080kkFD0P3W_I`20>neU080kkFL203W]I@8
0>N]S080gZf40P3NYG/20=j]Q080ijf<0P3N[H@20>NmW080gZEk0P3N[H`40=j]Q080eYak0P3NYH@2
0=JLL`80aW]:0P2]FS420:e[>@80Q48Q0`2]Jd820;EcBP80aW]:0P3>U6<20<j<FP80aXaS0P36U6/2
0<J<H`80gZEc1P3FW7<40=jUL`80gZEk0P3N[H@20=J]Q080ikfD0P3W_I`40>NmY@80kljm0P3_e/H2
0>oNcP80knON0P3_knL20?O_i`80moOg0P3gkoL20?Ogm`80mnog0P3_koL20?Ogma00oooo000>0?oo
o`@0moOg0P3_knL20?Ogm`80mnog1P3gmoL40?O_m`80knoW0P3gkoL20?Ogm`80knog0P3_knL40?O_
m`@0moOg0P3gknL20?O_m`80moOg103_koL20?O_m`80moOg0P3gkoL20>o_m`80mnoW0P3_knL20>oW
gP<0imkF0P3Wc/H20<jDH`80aXAJ0P2eJd820:eS<@80W6<i0P2DDRT207/i6080HbT@0P1B8A0206/a
60@0gZfD0P3W]I@40>NmW080ikfU0P3W_I`20>o6Y@80kkfL0P3_aZD:0>nmW080kkFD103__I`20>Nm
U080kkfL0P3_]I@20>NmW080kkFD103W]I@20>N]S0P0ikFD103W[H`20=j]Q080gZF41P3NYG/20=j]
Q080ikfL0P3N[H@20=JLN`80eYac0P3FW7/40=jLL`@0cXaS0P36Nd820<IkBP80S4Xa0P2]FS4209aS
>@<0[F/i0P2LHcT20<IkBP80cXaJ1036Q5X20<J<H`@0eYac0P3F[H@20=j]S080eYac0P3NYG<20>Nm
U080eZf40P3N[H@40>NmU080ikfU0P3W_I`20>o>_@@0kmK6103gknL40?Ogm`@0mnog0P3gmoL20>o_
m`@0moOg403oool000h0oooo103gmoL20>o_i`80moOg0P3gkoL60?Ogm`@0mnog0P3_knL20?O_m`80
moOg0P3_koL20>o_i`@0mnog103gmoL20?O_i`80mnog0P3gmoL40>o_m`80mnog0P3gmoL20?O_m`80
knog0P3gknL20>o_i`80knON0`3Wg]H20>O>aP80cYAS0P36Q5X20;E[@P80[F<a0P2LHcT209AB:@80
NcTH0P1S:A02058Q4080Jc4H103N[I@20>NeU0@0ikfL0P3W_JD20>NmW080klJU0P3__I`20>o6Y@X0
kkfL0P3_]I@40>nmW080ikfD0P3__I`20>neU080ikfL0P3_]I@40>NeU080ijf<203W]I@40>N]S080
gZf40P3NYH@60=jUN`80gZf40P3W_I`20=j]Q080eYak0P3FW7<20=JLN`@0gYac103>S6<20<Ik@P80
aW]:0P2<BS420:eJ<@80W6<i0`2]JcT209aS>@80aW]:0P3>S5X40<J4FP80aXaS103FW7<20=J]Q080
gZf<0P3FW7<20=jUL`80ikfD0P3F[H@20=j]Q0@0ikfD0P3W_JD20>NmW080kljm103_e/H40?O_i`@0
moOg103gkoL20?Ogm`80knog103gmoL@0?ooo`003P3oool20?Ogm`80mnog103gknL20?O_m`80knog
0P3gmoL20?O_i`80moOg0P3gknL20>o_m`@0moOg0P3gkoL20?Ogm`80mnoW0P3gmoL60?O_m`80moOg
103_koL40?Ogm`80mnog0P3gmoL20?O_i`80mnog0P3_knL20?OWgP<0imK60P3F[H@20<jDH`80aXAJ
0P2eLdX20:eJ<@80]F/i0P2DDRT208a::@@0Jc4H0P1k@R4207]::@80gZfL0P3W_I@20>NmW080klJU
103W_I`20>o6Y@`0kkfL0P3W_I`20>nmW080ikfL0P3W]I@20>neW080kkfL0P3W_I@40>neU080ikfD
0P3W[H`20>NmU080gZf40P3W]I@20>NmU080ikFD103W[H`40=jUQ080cYA[0P3FW7<20=j]S080ikfL
0P3N[H`20<j<H`80cYA[0P3FW7<20<jDJ`80eYac0P3>U6/20<IkBP80aW]20P2eHc420:eS<@80aW]:
0P2]Jd850<IkBP80_HaS0P3>U6<20<jDJ`80aXaS0P3>S5X20<J<H`80eYac0P3>S5X20<jDJ`@0eYac
0P3NYG/40=JLL`H0ikfD0P3W_I`20>O>_@80kmK6103_imh20?O_m`80moOg0P3_koL20>o_i`@0moOg
103gkoL20?Ogm`80mnog403oool000h0oooo0P3gmoL20?O_m`@0mnoW0P3gkoL20>o_m`80moOg0P3g
knL20?Ogm`80mnoW0P3_koL40?Ogm`80mnog0P3gmoL20?O_i`80moOg1P3gkoL20?Ogm`@0knog103g
moL20?O_m`80moOg0P3gknL20?O_m`80knoW0P3gimh30>OFaP80eZf40P3>U6<20<J4FP80]G=:0P2]
FS420;E[>@80U58Y0P2<BRT406/a6080Nd8Q0P1kBRT20=j]W080ikfD0P3W_I`20>o6Y@@0ikfL0P3_
aZD<0>nmW080ikfL0P3__I`20>NmW080ikFD0P3_]I`20>nmW080ikfD103_]I@20>NmU080ijf<0P3W
_I@20=j]Q080ikFD0P3W_I@20>NeU0@0ijf<103NYH@20<jDJ`80eYac0P3N[H`20>NmW080gZf<0P3>
S6<20<jDJ`80eYac0P3>U6/20=JLL`80cYA[0P36NdX20<Ik@P80]F<a0P2]Hc420<IkBP80[F]21@36
NdX20;f<H`80cYAS0P3>U6/20<J<H`80cXaJ0P36S6<20=JLL`80cXaJ0P3>U6/40=JLL`80gZEk103F
W7<60>NmU080ikfL0P3Wc[d20>oFaP@0knON0P3gkoL20?Ogm`80knog0P3_knL40?Ogm`@0mnog0P3g
moL20?O_ma00oooo000>0?ooo`@0moOg0P3_koL20?Ogm`80knog103gkoL40?Ogm`80mnoW203gmoL2
0>o_m`80mnog0P3gmoL20>o_m`80mnog0P3_knL20>o_m`80moOg0P3_koL20?O_m`80moOg0P3gknL2
0?O_m`80mnoW0P3_knL20>oWgP80knOW0`3Nc[d20=J]Q0@0aXAJ0P2eJd820;EcBP80[F/i102<BRT2
07/i6080Q48Q0P2<@R4206<Y4080gZfD0P3W_I`20>NmY@80klJU103W_I`20>nmW080kkFD0P3W_I@2
0>nmW080kkFD0P3W_I@40>nmW080ikfD0P3_]I@20>NmU0@0kkFD0P3__I`60>NeU080ikfD0P3N[H@2
0>neU080gZf40P3W[H`20=j]S080gZf40P3NYH@20=jLN`80cYA[103FW7<20>NmU080ikfL0P3>S6<2
0<jDJ`@0eYac0P3>S6<20;EkFP80]F]B0P2LHcT20<Ik@P80]F/i0P2]Hc420:e[>@80aW]20P36NdX3
0;E[@P80aXAJ103>U6<20<j<FP80aXAJ0P2eLdX20=J]Q080cYAS0P3F[H@20<jDJ`80ikfD0P3FW7<2
0=jUN`P0ikfD0P3WaZd20>O6]@80knON103_inL20?O_m`80moOg0P3_knL60?Ogm`80knog1P3gmoL@
0?ooo`003P3oool40?Ogm`80knog0P3gmoL20>o_m`@0mnog103gmoL20?O_i`P0moOg0P3_koL20?O_
m`80moOg0P3_koL20?O_m`80knoW0P3_koL20?Ogm`80knog0P3gkoL20?Ogm`80mnoW0P3gkoL20?O_
i`80knoW0P3_imh20>oWi`<0g/jm0P3F[H@40<J4FP80]F]20P2eLdX20:e[>@@0S4XY0P1k>AP208A2
8@80S48Q0P1S:A020=j]U080ikfL0P3W_JD20>o6Y@@0ikfL0P3__I`20>neU080ikfD0P3__I`20>ne
U080ikfD103__I`20>NmU080kkFD0P3W_I@40>neU080kkfL1P3W]I@20>NmU080gZf40P3_]I@20=j]
Q080ijf<0P3N[H`20=j]Q080gZF40P3NW7/20<jDJ`@0eYac0P3W_I@20>NmW080cXaS0P3>U6/40=JL
L`80cXaS0P2eNeX20;E[DP80W6<i0P36Nd820;E[>@80[F<a0P2]JcT20<Ik@P80aW]:0`2eJd820<J4
FP@0cYAS0P3>S5X20<J4FP80]G=:0P3F[H@20<jDH`80eZf40P3>U6/20>NmU080eYac0P3NYG/80>Nm
U080ilJ]0P3Wa[D20>oWgP@0knOW0P3gkoL20?Ogm`80knoW1P3gmoL20>o_m`H0moOg403oool000h0
oooo0P3gmoL20>o_m`80moOg0P3gknL:0?Ogm`80mnog203gmoL20?O_m`80mnoW103gmoL40?O_m`80
knoW0P3gmoL20?O_m`80moOg103_koL40?Ogm`80mnoW103_imh30=j]U080eZf40P36Q5X20;EcBP80
[F]2102LHcT208a28@80S4XY102DDRT207/i6080BQP80P3W_I`20>NeU080ikfU0P3W_I`20>nmW080
ikfL0P3__I`40>neU080kkfL303_]I@40>NmU080kkFD0P3W]I@20>NmU0@0ikFD1P3N[H@20>N]S080
gZf4103N[H`20=jLN`80eYac103>S6<20=j]Q080gZfD0P3>S6<40<J4H`80aXaS0P36Q6<20;EkFP80
[G=B0P2<FT820:e[@P80aW]21P2eJcT20;E[@P80[F]20`2eJd820<J4FP80cYAS0P3>U6/40;f<H`80
cYAS0P3FW7/20<jDJ`80eYac103>U6/40=jUL`80gZEk103W_I`20>NmY@80kmK60P3gknL20>oWgP80
knOW0P3_knL40?Ogm`80mnog103gmoL20>o_m`80mnog0P3_koL40?Ogma00oooo000>0?ooo`80moOg
0P3_koL20?Ogm`80mnoW2P3gmoL20?O_m`P0moOg0P3gkoL20?O_i`@0moOg103gkoL20>o_i`80moOg
0P3gkoL20?Ogm`@0knog103gmoL20?O_i`@0knON0`3N[I@20=J]Q080aXAJ0P2eLdX20:e[@P@0W6<i
0P2<@R4208a::@@0U58Y0P1k>AP204XH2080ikfL0P3W]I@20>NmY@80ikfL0P3__I`20>NmW080kkfL
103_]I@20>nmW0`0kkFD103W_I@20>neU080ikFD0P3W_I@40>NeU0H0gZf40P3W[H`20=j]Q0@0gZf<
0P3NW7/20=JLL`@0cXaS0P3N[H@20=j]U080cXaS1036Q6<20<J<H`80aXAS0P2eNeX20:ecDP80S5Y2
0P2]Jd820<Ik@PH0]F/i0P2eJd820:e[@P<0]F]20P36Q5X20<jDH`80cYA[102mS6<20<jDH`80eYak
0P3>U6/20=JLL`@0cYA[103NYG<20=jUN`@0ikfL0P3W_JD20>oFaP80mnoW0P3_imh20>oWi`80knoW
103gmoL20?O_m`@0moOg0P3_koL20?O_m`80knog103gmoL@0?ooo`003P3oool60?Ogm`80knog103g
moL20?O_m`80moOg0P3gkoL20?Ogm`80mnog203gmoL:0?O_m`@0moOg0P3gkoL20?Ogm`80knog1P3g
moL20>o_m`80knON0P3We/h30=J]Q080eYac0P2mS6<20;EkFP80]F]20P2]Jd8208a::@80Q48Q0P2D
DRT209AJ<@80S4XY0P1[>B4206/a6080ikfU0P3W]I`20>o6Y@80ikfU0P3W]I@20>nmW0@0ikfL0P3_
_I`20>neU080kkFL0P3W_I@20>neU080ijf<103_]I@80>N]S080kkFD0P3N[H@20>N]S080gZf<0P3N
[H@20>N]S080gZEk0P3NYH@20=jUN`80eYak0P3FW7<20<J4J`80cXaS0P3>U6<20=JLL`80cYA[0P36
Q5X20<J4H`@0aXAJ0P2eNeX209aS>@@0W6]:0P2]JcT20<j<FP80aW]:0P36Nd820;E[>@80[F/i0P2m
S6<30<IkBP80aXAJ0P2mS6<20<j<FP80aYA[0P3F[H@40=JLL`80aYA[1P3>U6/20=JLL`80ikfD0P3W
_JD20>o6Y@80ikfU0P3_e/H20>oNcP80knON0P3_knL20>oWgP80knoW0P3gknL20>o_i`@0moOg0P3g
koL:0?Ogma00oooo000>0?ooo`H0moOg0P3_koL40?Ogm`80mnog0P3gmoL20?O_m`80moOg0P3gkoL8
0?Ogm`X0mnog103gmoL20?O_m`80moOg0P3_koL60?Ogm`80knog0P3_imh20>OFcP<0eZf40P3FW7<2
0;f<H`80]G]J0P2eJd820:e[@P80S4XY0P24@R4209AB:@80U5Xa0P2<BRT206/i8@80Jc4H0P3W_JD2
0>NeW080klJU0P3W_JD20>NeU080kkfL103W_I`20>nmW080kkFD0P3_]I`20>NmU080kkFD0P3W[H`4
0>neU0P0ijf<0P3_]I@20=j]Q080ijf<0P3N[H`20=j]Q080ijf<0P3NYG/20=jUQ080gZEk0P3FW7/2
0=JLL`80aXA[0P3>S6<20<jDH`80eYac0P3>U6/20<J4FP80aXAS1036Q5X20;EkFP80W6<i102LJdX2
0:e[>@80cXaJ0P36NdX20<Ik@P80]F/i0P2]JcT20;f<H`<0aW]:0P36Q5X20;f<H`80cXaJ0P36U6/2
0=J]Q0@0eYac0P36U6/60<jDJ`80eYac0P3W_I@20>NmY@80klJU0P3W_JD20>oFaP80kmk>0P3_imh2
0>o_i`80knON0P3_knL20?O_i`80knoW103gmoL20?O_m`X0moOg403oool000h0oooo0P3gmoL20?O_
m`H0moOg103gkoL40?Ogm`80mnog203gmoL20?O_m`80moOg103gkoL40?Ogm`80mnog0P3gmoL:0?O_
m`80mnoW0P3_koL20>oWgP80imK60`3F[H`20<jDJ`80aXAJ0P2eLdX20:e[@P80[F/i0P2DFS4209AB
:@80[F/i0P2DDRT406/a6080HbT@0P3W_JD20>NeW080ikfL0P3N[I@20>NmW0@0kkfL103W[H`20>ne
U080ikFD1P3W[H`20=j]Q0@0ijf<103N[H@20>N]S080gZF40P3W[H`80=jUQ0@0gZEk103FW7<20<jD
J`80cXaJ0P36Q6<20=JLN`80aXaS0P2eNeX20;E[DP80aW]:0P2eLdX20;EkFP80U6=20P2eLdX209ac
DP80[F/i0P2]Jd820<IkBP80cXaJ0P36Q5X20;EcBP80aW]:0P2eNeX30<IkBP80_HaS0P2eLdX20<J<
H`80aYA[1P3F[H@20<jDH`80cYA[0P3F[H@20<jDH`80eYac0P3W_I@20>NmW080ilJ]0P3_e/H20>oW
gP80mnoW0P3_imh20>o_i`80knON103gknL60?Ogm`80mnog0P3_koL20?O_m`80knog0P3gkoL20?Og
ma00oooo000>0?ooo`80moOg0P3gkoL60?Ogm`@0mnog103gmoL20?O_m`P0moOg0P3gkoL20?Ogm`@0
mnog103gmoL20?O_m`80moOg2P3gkoL20?O_i`80knog0P3_imh20>OFaP<0eZf<0P3>U6/20<J4FP80
]G=:0P2]Jd820:e[>@80U5Xa0P2DDRT20:e[>@80U58Y101[<AP206<Y4080ikfU0P3W]I`20>NmW080
gZfD0P3W_I`40>nmW0@0ijf<0P3_]I@20>NeU0H0ijf<0P3N[H@40>N]S0@0gZf40P3W[H`20=jUQ080
ijf<203NYH@40=jUN`@0eYac0P3>U6/20<j<FP80aXAS0P3FW7/20<J<H`80]G]J0P2eJe820<IkBP80
]G=:0P2eNeX209AS@P80]G=:0P2LLe820:e[>@80[F]20P36NdX20<j<FP80aXAJ0P2eLdX20<IkBP80
]G]J0`36NdX20;f<H`80]G=:0P36S6<20<JDJ`H0eZf40P3>U6<20<jDJ`80eZf40P3>U6<20=JLL`80
ikfD0P3W_I`20>O6[@80kmK60P3_imh20?O_i`80knON0P3_knL20>oWgP@0mnoW1P3gmoL20?O_m`80
knog0P3gkoL20>o_m`80mnog0P3gmoL@0?ooo`003P3oool60?Ogm`80mnog103gmoL20?O_m`H0moOg
0P3gkoLB0?Ogm`80mnog0P3gmoL40?O_m`80moOg0P3gknL20>o_m`@0moOg0P3_imh20>NmY@D0eYac
0P2mS6<20;EcBP@0[F]20P2<BRT209aS>@80U58Y0P24@R4206<Y4080JcTQ0P1S:A0:0>NmW080ikFD
0P3__I`20>NmU080ijf<0P3_]I@20>N]S080gZf40P3W[H`20=j]Q080gZF40P3N[H@20=jUQ080gZf4
1P3NYH@20=j]S080gZf40P3NYG/20=jLN`80eYak0P3NYG/40=JLN`80eYac0P3>U6/20<J4FP80cYA[
0P3>S6<20;EkFP80]F]B0P2eLdX40:e[@P80U5Xa102LJdX209AB:@80W6<i0P2eJd860<j<FP80cYA[
1036NdX50;EcBP80_HaS0P36U6/20<J4FP80eZF40P3F[H@20=JLN`80aYA[0P3F[H@20=j]S080eYac
0P3N[H@40>NmU080kmK60P3gg/h20>oWgP80imkF0P3_imh20>o_i`H0mnog0P3gmoL20?O_m`H0moOg
103gkoL20?Ogm`80mnog403oool000h0oooo1P3gmoL20?O_m`@0moOg0P3gkoL60?Ogm`80mnog4P3g
moL20?O_m`80moOg103gkoL20?Ogm`80mnoW0P3_koL40?Ogm`80knON0P3W_JD50=JLL`80_HaS0P2e
LdX40:e[@P80S4XY0P2LHcT209AB:@80Q48Q0P1S:A0206/i8@80HbT@2P3W_I`20>NeU080kkfL0P3W
_I@20>N]S080kkFD0P3W[H`20=j]Q080ijf<0P3N[H@20=jUQ080gZf40P3NYH@20=j]Q0H0gZF40P3N
[H`20=j]Q080gZEk0P3NW7/20=JLN`80gZEk103FW7/20=JLL`80cYA[0P36Q5X20<jDJ`80cXaS0P2e
NeX20;E[DP80]G=:102]Jd8209AJ<@@0W6]:0P2DDRT209aS>@80]F]21P3>S5X20<jDJ`@0aW]:1@2e
LdX20;f<H`80aYA[0P36Q5X20=JUQ080eZf40P3FW7/20<JDJ`80eZf40P3N[H`20=JLL`80gZf4103W
_I@20>oFaP80mmk>0P3_imh20>ONeP80knON0P3_knL60?O_m`80moOg0P3gkoL60?Ogm`@0mnog0P3g
moL20?O_ma00oooo000>0?ooo`P0moOg103gkoL20?Ogm`80mnog0P3_koL80?Ogm`80mnog2P3gmoL2
0?O_m`@0moOg0P3gkoL20>o_i`80mnog0P3_knL20?Ogm`80mnog103gknL20<j]U0<0eYac0P36S6<2
0<J4FP80W6<i0P2LJdX209AJ<@80W4Xa0P2LHcT209a:<@80Nd8Q0P1[>B4207]28@80Jc4H0P3W_JD2
0=j]W080ikfL0P3W]I@20>NmW080ikFD0P3W[H`20>NmU0H0ijf<0P3N[H@60=jUQ080gYac0P3NW7/2
0=jUN`@0gYak0P3NYH@40=jUN`80eYac0P3NW7<80=JLL`@0cXaS0P36Q5X20<jDJ`80aXAJ0P2eLdX2
0:e[@P@0[F=20P2DHd820:e[@P80W6]:102DFS4209aS>@80]F/i0P36Nd820<j<FP80aXAJ0P3>S5X2
0<J4FP80_HaS1@2eLdX20;E[@P80aXAJ0P3FW7<20=JLN`80eYac103F[H`20=J]Q080cYA[0P3FW7<2
0=j]Q080ikfL0P3Wa[D20>oNcP80imkF0P3_imh20?O_i`80knoW0P3_imh20?O_m`80moOg0P3gkoL:
0?Ogm`80mnog103gmoL20?O_ma00oooo000>0?ooo`P0moOg103gkoL20?Ogm`80mnog0P3_koL80?Og
m`80mnog2P3gmoL20?O_m`@0moOg0P3gkoL20>o_i`80mnog0P3_knL20?Ogm`80mnog103gknL20<j]
U0<0eYac0P36S6<20<J4FP80W6<i0P2LJdX209AJ<@80W4Xa0P2LHcT209a:<@80Nd8Q0P1[>B4207]2
8@80Jc4H0P3W_JD20=j]W080ikfL0P3W]I@20>NmW080ikFD0P3W[H`20>NmU0H0ijf<0P3N[H@60=jU
Q080gYac0P3NW7/20=jUN`@0gYak0P3NYH@40=jUN`80eYac0P3NW7<80=JLL`@0cXaS0P36Q5X20<jD
J`80aXAJ0P2eLdX20:e[@P@0[F=20P2DHd820:e[@P80W6]:102DFS4209aS>@80]F/i0P36Nd820<j<
FP80aXAJ0P3>S5X20<J4FP80_HaS1@2eLdX20;E[@P80aXAJ0P3FW7<20=JLN`80eYac103F[H`20=J]
Q080cYA[0P3FW7<20=j]Q080ikfL0P3Wa[D20>oNcP80imkF0P3_imh20?O_i`80knoW0P3_imh20?O_
m`80moOg0P3gkoL:0?Ogm`80mnog103gmoL20?O_ma00oooo000>0?ooo`80moOg103gkoL20?Ogm`@0
mnog1P3gmoL20?O_m`80knog103gmoL20?O_m`@0moOg103gkoL20?O_i`80knog0P3gmoL40?O_m`@0
moOg0P3gkoL20?Ogm`80knoW0P3gknL20>OFaP80eZf<0`3FW7<20<J4FP80]G]J0P2]Jd820;EcBP80
U58Y102LHcT209AJ<@80FS4Q0P1S:A0206/a6080JcTQ0P3W_I`20=j]U080ikFL0P3N[I@40>NeU0H0
ijf<0P3NYH@20=j]Q080gZEk0P3NW7/20=jUN`@0gYak0P3NW7<60<jDJ`@0eYac0P3NW7/40=JLL`H0
cYA[103>S6<20<J4H`80_HaS0P2eLdX20:e[@P80[F/i0P2LHcT20:eS@P@0[F]21P2LHcT20:eS<@80
]F/i0P2eJd820<Ik@P80cXaJ0P3NYG<20=JLL`80gZf40P36S6<50:e[>@80]G=:0P36S6<20<J4FP80
eYac1P3F[H@60<jDH`80ikfD0P3WaZd20>O6]@80imkF0P3_imh20>oNcP80knoW0P3_imh20?Ogm`80
mnog203gmoL20?O_m`H0moOg0P3_koL20?Ogm`80mnog403oool000h0oooo0P3gmoL40?O_m`80moOg
103gkoL60?Ogm`80mnog0P3_koL40?Ogm`80mnog103gmoL40?O_m`80mnoW0P3_koL20?Ogm`@0mnog
103gmoL20?O_m`80moOg0P3_knL20?O_i`80imK60P3F[H`30=JLL`80aXAJ0P2eNeX20:e[@P80]G=:
0P2DDRT409aS>@80U5Xa0P1J<B4206<Y4080Jc4H0P1[>B420>NmW080gZfD0P3W]I`20=j]U0@0ikFD
1P3W[H`20=jUQ080gZf40P3NYG/20=jLN`80gZEk103NW7/20=jLL`H0cYA[103FW7<20=jLN`@0eYac
1P3>U6/40<j<H`80aXAS0P2mS6<20;EcBP80[F]20P2]JcT209aS>@80[F=2102]Jd8609aS>@80[F<a
0P2eJcT20;E[@P80aW]20P3>S5X20=jUL`80eYac0P3N[H@20<J<H`D0[F/i0P2eLdX20<J<H`80aXAJ
0P3FW7<60=J]Q0H0cYAS0P3W_I@20>O6[@80ilJe0P3Wg]H20>oWgP80kmk>0P3_knL20>oWgP80moOg
0P3gkoL80?Ogm`80mnog1P3gmoL20>o_m`80moOg0P3gkoL@0?ooo`003P3oool20?O_m`@0moOg103g
koL20?O_i`@0knog0P3gkoL60?Ogm`80knog0P3gmoL20?O_m`80moOg0P3gkoL20?Ogm`80mnoW2P3g
moL20?O_m`80knog0P3gkoL40?O_i`80ikfU0P3F[H@30<JDJ`80_HaS0P2eLdX209aS>@80W6]:0P2D
FS420:e[>@80S4XY0P24@R44058Y60@0Jc4H0P3W_I`20=j]U080ikFD0P3W]I`20>NeU0@0ijf<0P3N
YH@80=jUN`80gYac0P3FW7/20=JLL`80gYac103FW7<80<jDJ`@0eYac1P3>U6/40<J4H`80aXAJ0P2e
NeX20<J4FP80]F]20P2LHcT209AJ<@80[F]20P2LHcT40:e[@P@0Nd8Q0P2<BRT20;ES<@H0aW]20P36
Q5X20<jDH`80eYac0P3>U6/20=J]Q0<0_HaS0P2eLdX40<J4FP80cYA[0P36Q5X40=J]S080cYA[0P3>
U6<20<jDJ`80cYAS0P3W_I@20>O6[@80knON0P3Wg]H40>oWgP80knOW0P3_koL20?Ogm`80knoW0P3g
knL40?Ogm`80mnog1P3gmoL20?O_m`H0moOg403oool000h0oooo0P3gkoL40?Ogm`@0mnog0P3gknL4
0>o_m`80mnog1P3gmoL20>o_m`80moOg0P3gkoL20?Ogm`80mnog0P3gmoL20?O_i`X0moOg0P3gkoL2
0>o_m`80mnog103gknL20>NmY@80eZf40`36U6/20;f<H`80]G=:0P2LHcT209a[BP80U5Xa0P2]JcT2
08a::@80Q48Q101B:AP406/a6080ikfL0P3N[I@20>NeU080ikFL0P3W]I@40>N]S080gZF4203NYG/2
0=jLL`80eYak0P3FW7<20=jLL`@0eYac203>U6/40=JLL`H0cYA[1036Q6<20<J4FP80]G]J0P36Q5X2
0;E[@P80W6<i0P2DFS420:e[@P80W6<i102]Jd8407]28@80S4XY0P2eHc460<Ik@P80aXAJ0P3>U6<2
0=JLL`80cYA[0P3F[H@30;f<H`80]G=:1036Q5X20<jDJ`80aXAJ103F[H`20<jDJ`80cYAS0P3>U6/2
0<jDH`80ikfD0P3WaZd20>oWgP80imkF103_imh20>oWi`80knog0P3gmoL20>o_i`80mnoW103gmoL2
0?O_m`H0moOg0P3gkoL60?Ogma00oooo000>0?ooo`P0moOg0P3gkoL@0?Ogm`80mnoW0P3gkoL20?Og
m`80mnoW0P3gmoL20?O_m`80moOg0P3gkoL20?Ogm`80mnog0P3gknL20?O_m`80moOg0P3_knL20?O_
m`80imkF0P3F]JD20=J]Q0<0_HaS0P2eNeX20:e[@P80W6]:102DFS4209aS>@80S4XY0P1k>AP206/a
60@0JcTQ0P1k>AP40=j]U0@0gZf<0P3W[H`20=j]S080gZF40P3N[H`40=jUQ080eYak103NW7<60<jD
J`80aXA[103>S6<20<J4J`@0cYA[0P36Q6/60<jDJ`80aXAS0P36Q5X20<J4H`80aXAJ0P2eLdX20<j<
FP80[F]20P2<BRT409a[BP80W6<i0P2DFS4208A28@80Nd8Q0P1S:A020:eS<@80aW]20P2eHc420<Ik
@P80]F]20P36NdX20<jDH`80gZEc0P3FW7/20=j]Q0D0_HaS0P3>U6<20;f<H`80cYA[0P36U6/20=J]
Q0@0cYA[0P36Q5X20<j<FP80gZf40P3WaZd20>oFaP@0kmk>0P3Wg]H20>o_i`@0mnoW0P3gmoL40?O_
m`H0moOg0P3_koL20?Ogm`80mnog0P3gmoL20?O_m`@0moOg403oool000h0oooo203gmoL20?O_ma00
moOg0P3gknL20?O_m`80moOg0P3gknL20?Ogm`80mnog0P3gmoL20?O_m`80moOg0P3gkoL20?O_i`80
mnog0P3gmoL20>o_i`80mnog0P3Wg]H20=JeY@80eZf40`2mS6<20;EkFP80[F]20P2LJdX409AJ<@80
W6<i0P2<BRT207/i6080Jc4H101[>B4207/i60@0gZfD103N[H`20>N]S080gZf<0P3NYH@20=j]S0@0
gZF40P3FW7/40=jLL`H0cYA[0P36Q6/40<j<H`80aXA[103>U6/20<J4J`H0cYA[0P36Q6<20<J4FP80
aXAS0P36Q5X20;EcBP80cXaJ0P2]Jd8208a::@@0W6]:0P2LHcT209AJ<@80Q48Q0P1k@R4206<Y4080
[F<a0P36Nd820;ES<@80aW]20P2eJd820<IkBP80cYAS0P3NYG<20=JLN`80gZf41@2mS6<20<jDH`80
_HaS0P3>U6/20<JDJ`80eZf4103>U6/20<J4FP80cXaJ0P3N[H@20>O6[@80kmK6103_g/h20>ONeP80
knoW103gknL20?Ogm`@0mnog1P3gmoL20>o_m`80moOg0P3gkoL20?Ogm`80mnog103gmoL@0?ooo`00
3P3oool40?Ogm`80mnog0P3gmoL40?O_m`80knog103gkoL20?Ogm`80mnog2P3gmoL20>o_m`80mnoW
0P3gkoL20>o_m`@0moOg0P3gkoL40?Ogm`80knog0P3gkoL20>o_i`80ilJe0P3F[H`20<JLQ0D0]G]J
0P2LJdX20:eS@P80W6<i102DFS4406/i8@80Jc4H1P1[>B420=j]U080gZf<0P3N[I@20>NmY@@0ijfD
0P3WYI@20>N]U0@0ijFD0P3N[H`40=jUQ080eYak0P3>S6<20<J4FP80cXaS0P36NeX80<J4FP@0cXaS
1P36Q5X40;EkFP80]F]B0P2eLdX20<J4FP80W6<i0P1kBRT209aS>@80[F]20P2<BRT207]28@80NcTH
0P1kBRT209AB:@80[EXa1036Nd820;EcBP80aW]20P2]JcT20<jDH`80eYac0P3F[H@20<jDJ`<0aYA[
0P36Q5X40<J<H`80_HaS103F[H@20<jDH`80eYac0P3>U6<40=J]Q080g/Je0P3gknL20>oFaP80imkF
0P3_knL20>oWi`P0moOg0P3gkoL>0?Ogm`80mnog0P3gmoL20?O_ma00oooo000>0?ooo`@0moOg0P3g
koL20?Ogm`@0mnog0P3_koL40?O_m`80moOg0P3gkoL:0?Ogm`80knog0P3gknL20?O_m`80knog103g
moL20?O_m`@0moOg0P3_koL20?O_m`80knoW0P3Wa[D20=J]S080aYb41@2eNeX209a[BP80[F=20P2L
HcT409AJ<@@0JcTQ0P1[<AP606/i8@80gZfD0P3N[H`20=j]U080ikfU103W[I@20>NUU080ijfD103W
YI@20=j]S0@0gZF40P3FW7/20<j<H`80aXAJ0P3>S6<20<IkFPP0aXAJ103>S6<60<J4FP@0]G]J0P2e
Je820;EcBP80aXAJ0P2LHcT207]::@80W6<i0P2]Jd8208a::@80Nd8Q0P1k>AP207]::@80U58Y0P2]
FS440<Ik@P80]G=:0P36Nd820:e[>@80cYAS0P3FW7<20=J]Q080cYA[0`36U6/20<J4FP@0aXaS0P2m
S6<40=J]Q080cYAS0P3FW7<20<jDH`@0eZf40P3Na[D20?O_i`80kmK60P3Wg]H20>o_i`80knOW203g
moL20?O_m`h0moOg0P3gkoL20?Ogm`80mnog403oool000h0oooo0P3gkoL40?Ogm`@0knoW0P3gmoL2
0?O_m`@0moOg103gkoL40?Ogm`80knog0P3gmoL20?O_m`80moOg0P3gknL20?O_m`80mnoW103gmoL4
0?O_m`H0knog0P3_imh20=k6]@80eZf40P36U6/30;EkFP80]G=:0P2]Jd8209aS>@80]G=:0P2LBS42
09AJ<@80DR4@0P1c@RT406/i8@80Jc4H0P24DS420=j]U080ilJ]1P3_aZd40>o6Y@H0kkFL0P3W[I`4
0>N]U080gZf<0P3NYH@20=JLN`@0aW]J0P36NdX40<IkFPH0]G]J0P36Q5X20<IkFP80]G]J0P36NdX2
0;EcBP@0[F]20P36NdX208a::@80S4Xa0P2LHcT208aJ@P80Q48Q0P1[<AP206/i8@80[F<a0P24@R42
09aS>@80aW]:0P36Nd820;EcBP80[F/i0P2eLdX20<j<FP80eYak0P3N[H@20=j]S0<0eZf41036U6/2
0;EkFP80]F]2103F[H@20<JDJ`80cYA[103F[H@20>NmW080knoW1P3_imh20>o_i`80mnoW0P3gkoL2
0?Ogm`80mnog203gmoL20?O_m`X0moOg0P3gkoL20>o_ma00oooo000>0?ooo`80mnog103gmoL40>o_
i`80moOg0P3gkoL40?Ogm`@0mnog103gmoL20>o_m`80moOg0P3gkoL20?Ogm`80mnoW0P3gkoL20?O_
i`@0moOg103gkoL60>o_m`80knON0P3Na[D20=J]Q080aYA[0`2eNeX20;EcBP80[F]20P2LHcT20;Ec
BP80W4Xa0P2DFS42058Q4080Ld8Y101[>B4206/a6080Q58a0P3N[I@20>O6[@H0klJ]103_aZD60>ne
W080ijfL103W[I@20=j]S080gZF40P3FW7/40<IkFP80aW]:1036NeX60;EkFP80aXAJ0P36NeX20;Ek
FP80aW]:0P2eLdX40:e[@P80aW]:0P2<BRT208a:<@80W6<i0P2<FT8208A28@80Jc4H0P1[>B420:eS
<@80Q48Q0P2LHcT20<IkBP80aW]20P2eLdX20:e[>@80]G=:0P3>S5X20=JLN`80gZf40P3N[H`30=J]
Q0@0aYA[0P2eNeX20;E[@P@0eZf40P36U6/20<jDJ`@0eZf40P3W_I`20>o_i`H0knON0P3_knL20?O_
i`80mnog0P3gmoL20?O_m`P0moOg0P3gkoL:0?Ogm`80mnog0P3_koL@0?ooo`003P3oool20?O_m`@0
moOg103_knL20?Ogm`80mnog103gmoL40?O_m`@0moOg0P3_koL20?Ogm`80mnog0P3gmoL20?O_i`80
mnog0P3gknL40?Ogm`@0mnog1P3_koL20>oWgP80g/Je0P3F[H@20<JDJ`<0]G]J0P2eLdX20:e[@P80
W6<i0P2eLdX209a:<@80U5Xa0P1B8A0207=2:@@0JcTQ0P1[<AP208AB<@80gZfD0P3WaZd60>o6[@@0
klJU1P3_]I`20>N]W0@0ijfD0P3N[H`20=jUQ080eYak1036NeX20<IkBP@0aW]J1P2eNeX20<J4FP80
aW]J0P2eNeX20<IkBP80]G=:102]Jd820<IkBP80S4XY0P2<BS4209aS>@80S5Y20P24@R4206/a6080
JcTQ0P2]Hc4208A28@80W6<i0P36NdX20<Ik@P80]G=:0P2]JcT20;EcBP80cXaJ0P3FW7/20=j]Q080
gZf<0`3F[H@40<JDJ`80]G]J0P2eJd840=J]Q080aYA[0P3>U6/40=J]Q080ikfL0P3_knL60>oWgP80
knoW0P3gknL20?O_m`80moOg0P3gkoL80?Ogm`80mnog2P3gmoL20?O_m`80knog403oool000h0oooo
0P3gmoL40?O_m`H0moOg0P3gkoL<0?Ogm`80mnog103gmoL20?O_m`@0moOg0P3_knL20?Ogm`80mnog
0P3gmoL20?O_i`80knog103gkoL20>O>_@80e[FU0P3FW7<20<J<H`<0]G]J0P2]Le8209AJ<@80W6<i
0P2DFS4209aS>@80Q48Q0P1S:A0207]28@80Ld8Y0P1[>B4206/a6080]HAS0P3_aZd20>o6]@80mmJm
103ga[D40>o6[@80mlJe103_aZd40>neW080ikFL0P3W[I@20=j]S080gZF40P3NW7/20<jDJ`80aW]:
0P2eLdX20;EkFP@0aW]:0P36NeX20;E[DP80]G]J0P36NdX20;EkFP80]G=:0P2]Jd8209AS@P80]G=:
0P2DFS4209aS>@80]G=:0P24@R4207/i6080Jc4H0P1cBS420;E[>@80S48Q0P2LHcT20;E[@P80aW]:
0P2eJcT20:e[>@80]G=:0P36Q5X20<j<FP80gZf40P3N[H`30=J]Q080eYac0P36U6/20;EcBP80_HaS
203FW7<20>NmU080eYac0P3W_I`20>o_i`80kmk>0P3We/H20?OWgP80knOW0P3gmoL20?O_m`80moOg
0P3_koL20?O_m`80knog103gkoL40?Ogm`80mnog2P3gmoL@0?ooo`003P3oool20?Ogm`@0mnog1P3g
moL20?O_m``0moOg0P3gkoL40?Ogm`80mnog103gmoL20>o_i`80moOg0P3gkoL20?Ogm`80mnoW0P3_
koL40?O_m`80iljm0P3F]JD20=JLL`80aXaS0`2eNeX20:ecDP80U5Xa0P2LHcT209AJ<@80W6<i0P24
@R4206<Y4080Nd8Q0P1c@RT206/i8@80Jc4H0P2eQ6<20>o6[@80klJe0P3ge[d40?O6]@@0klJ]0P3g
a[D40>o6[@@0kkFL0P3W]I`20>N]U080gZf<0P3NYH@20=jLN`80cYA[0P36NdX20;EcBP80]G]J1036
NdX20<IkFP80]F]B0P2eNeX20<IkBP80]G]J0P2eLdX20:e[@P80U6=20P2eLdX209AJ<@80W6<i0P2e
LdX208A28@80NcTH0P1[<AP207=:<@80]F/i0P2<@R4209aS>@80]F]20P36NdX20;E[>@80[F/i0P2e
LdX20<J4FP80cXaJ0P3N[H@20=j]S0<0eZf40P3FW7<20<JDJ`80]G=:0P2mS6<80=JLL`80ikfD0P3F
W7<20>NmW080knoW0P3_g/h20>OFaP80mnON0P3_inL20?Ogm`80mnog0P3gmoL20>o_m`80mnog0P3_
koL40?O_m`@0moOg0P3gkoL:0?Ogma00oooo000>0?ooo`80mnog0P3gmoL20?O_i`80moOg0P3gkoL2
0?O_i`80moOg0P3_koL80?Ogm`80mnog0P3gknL20?Ogm`@0mnog0P3gmoL40?O_m`80moOg0P3gkoL4
0>o_m`80mnoW103gkoL20>O>_@80cZfD0P36U6/20;f<H`<0[G=B102]Jd8209aS>@80U5Xa0P2LHcT2
06<Y4080JcTQ0P1kBRT406/i8@80]Hac0P3_a[D20?O>]@80mmJm0P3gc[D20?OF_@80mlJe0P3ge[d2
0?O6]@80mlje0P3ga[D20>o6[@80klJU0P3_aZd40>neW080ijfD0P3W[H`20=jUQ080gZEk0P3FW7<2
0<jDJ`P0]G=:0P36NdX20;EcBP80]G]J0P2eLdX20:eS@P80W6]:0P24DST208A28@80]G=:0P2DFS42
0<J4FP80NcTH0P1[<AP2058Q4080HbT@0P2]JcT20;E[@P80U58Y0P2eJd820<j<FP80[F/i0P2mS6<2
0;EcBP80aXAJ0P3FW7<20=j]Q080ikfD0`3W_JD20=J]S080]F]2102mS6<20<jDJ`80aXaS0P3FW7<2
0=J]S080eZf40P3NYG/20>oWi`80kmk>0P3_c[d20>oWgP80mnoW0P3gkoL40?Ogm`80mnoW203gmoL4
0?O_m`P0moOg0P3gkoL40?Ogma00oooo000>0?ooo`80mnog0P3gmoL20?O_i`80moOg0P3gkoL20?O_
i`80moOg0P3_koL80?Ogm`80mnog0P3gknL20?Ogm`@0mnog0P3gmoL40?O_m`80moOg0P3gkoL40>o_
m`80mnoW103gkoL20>O>_@80cZfD0P36U6/20;f<H`<0[G=B102]Jd8209aS>@80U5Xa0P2LHcT206<Y
4080JcTQ0P1kBRT406/i8@80]Hac0P3_a[D20?O>]@80mmJm0P3gc[D20?OF_@80mlJe0P3ge[d20?O6
]@80mlje0P3ga[D20>o6[@80klJU0P3_aZd40>neW080ijfD0P3W[H`20=jUQ080gZEk0P3FW7<20<jD
J`P0]G=:0P36NdX20;EcBP80]G]J0P2eLdX20:eS@P80W6]:0P24DST208A28@80]G=:0P2DFS420<J4
FP80NcTH0P1[<AP2058Q4080HbT@0P2]JcT20;E[@P80U58Y0P2eJd820<j<FP80[F/i0P2mS6<20;Ec
BP80aXAJ0P3FW7<20=j]Q080ikfD0`3W_JD20=J]S080]F]2102mS6<20<jDJ`80aXaS0P3FW7<20=J]
S080eZf40P3NYG/20>oWi`80kmk>0P3_c[d20>oWgP80mnoW0P3gkoL40?Ogm`80mnoW203gmoL40?O_
m`P0moOg0P3gkoL40?Ogma00oooo000>0?ooo`80moOg0P3gkoL:0?Ogm`80knog0P3gkoL20?O_i`H0
moOg0P3gknL20?O_m`80moOg203gkoL80?Ogm`80knog0P3_inL20>OFaP80ilJ]0P36W8@20<JDJ`80
]G]J0`2LJdX209AJ<@@0W6<i0P2DFS4208A::@80HbT@101kBRT206/i8@80ilJe0P3gc[D20>o>[@80
mlje103ge[d20>oFaP80mmJm0P3_e/H60?O6]@80mlje0P3_aZd60>o6Y@80ikfL0P3N[I@20=j]S080
ijf<0P3NYH@20=JLN`80cYA[0P2eJe840:e[@P80]G=:0P2]Jd820;E[DP80[F]20P2]Hd8209aS>@80
Q48Q0P1k@R420<J4FP80Q48Q0P3>S6<209aS>@80JcTQ0P1cBS42058Q4080Q48Q0P36NdX208a28@80
]F]20P36NdX20;E[>@H0aXAJ0P3>U6<20=JLL`80ikfL0`3W_JD20=J]Q080aXaS0P2eNeX20;f<H`@0
aYA[0P3F[H@20=J]S080eZf40P3W_I@20>ONeP80imK>0P3Wg]H40>o_i`80moOg0P3gknL20?Ogm`80
mnog103gmoL40?O_m`80moOg103gkoL<0?Ogma00oooo000>0?ooo`80moOg0P3gkoL:0?Ogm`80knog
0P3gkoL20?O_i`H0moOg0P3gknL20?O_m`80moOg203gkoL80?Ogm`80knog0P3_inL20>OFaP80ilJ]
0P36W8@20<JDJ`80]G]J0`2LJdX209AJ<@@0W6<i0P2DFS4208A::@80HbT@101kBRT206/i8@80ilJe
0P3gc[D20>o>[@80mlje103ge[d20>oFaP80mmJm0P3_e/H60?O6]@80mlje0P3_aZd60>o6Y@80ikfL
0P3N[I@20=j]S080ijf<0P3NYH@20=JLN`80cYA[0P2eJe840:e[@P80]G=:0P2]Jd820;E[DP80[F]2
0P2]Hd8209aS>@80Q48Q0P1k@R420<J4FP80Q48Q0P3>S6<209aS>@80JcTQ0P1cBS42058Q4080Q48Q
0P36NdX208a28@80]F]20P36NdX20;E[>@H0aXAJ0P3>U6<20=JLL`80ikfL0`3W_JD20=J]Q080aXaS
0P2eNeX20;f<H`@0aYA[0P3F[H@20=J]S080eZf40P3W_I@20>ONeP80imK>0P3Wg]H40>o_i`80moOg
0P3gknL20?Ogm`80mnog103gmoL40?O_m`80moOg103gkoL<0?Ogma00oooo000>0?ooo`P0moOg0P3_
koL>0?Ogm`80knog0P3gkoL20?O_i`@0moOg0P3gkoL:0?Ogm`80mnog0P3_knL20>oWi`80g/jm0P3F
_Jd20;fDN`80_HaS0P2eNeX30:e[@P80U6=20P2LHcT409AJ<@80JcTQ0P1[<AP207]28@80JcTQ0P2U
Q6/20>o>]@80mlje0P3_aZd40?O>]@P0mmJm0P3_e/H20?OF_@@0mlJe1P3_aZd20>NmY@80ikFL0P3W
_I`20>NeU080ijf<0P3N[I@20=jUQ080eYak0P36Q6/20<jDJ`@0[F=20P2]Jd8209a[BP80[F=20P2D
Hd8209a:<@80Q4Xa0P1c@RT20<IkBP80[G=B0P2eNeX20;EcBP80Jc4H0P1B8A0207]28@80W6<i0P36
NdX20<J4FP@0aW]:0P36Q5X20:e[@P80aXaS0P2mS6<20<JDJ`80eYac0P3F[H@30>NmW080ikfD0P2m
S6<20;EcBP80_HaS0P36NdX20<JDJ`80e[FU0P3W_I@20<jeY@80eZf<0P3WaZd20>oWgP@0mnoW0P3g
koL20?Ogm`80mnog0P3gmoL20?O_m`80moOg103gkoL80?Ogm`80mnog1P3gmoL20?O_m`80moOg403o
ool000h0oooo203gmoL20>o_m`h0moOg0P3_koL20?O_m`80mnoW103gmoL20?O_m`X0moOg0P3gkoL2
0>o_i`80knOW0P3Nc[d20=Jm[@80_IAk0P2mS6<20;EkFP<0[F]20P2DHd8209aS>@@0U5Xa0P1[>B42
06/a6080Nd8Q0P1[>B420:F4J`80klje0P3gc[D20>o6[@@0mlje203ge[d20>oFaP80mmJm103ga[D6
0>o6[@80ikfU0P3W]I`20>NmW080ikFD0P3W[H`20=j]U080gZF40P3FW7/20<J4J`80cYA[102]Hd82
0:e[@P80W6]:0P2]Hd8209AS@P80W4Xa0P24BS4207=2:@80aW]:0P2]Le820;EkFP80]G=:0P1[<AP2
058Q4080Nd8Q0P2LHcT20<IkBP80aXAJ1036NdX20<J4FP80[F]20P36S6<20;f<H`80aYA[0P3FW7<2
0=J]Q0<0ikfL0P3W_I@20;f<H`80]G=:0P2mS6<20<IkBP80aYA[0P3F]JD20>NmU080c[FU0P3F[H`2
0>O6[@80knON103gknL20?O_m`80moOg0P3gkoL20?Ogm`80mnog0P3gmoL40?O_m`P0moOg0P3gkoL6
0?Ogm`80mnog0P3gmoL@0?ooo`003P3oool20>o_m`80moOg0P3gkoL60?Ogm`80mnoW0P3gmoL40?O_
m`80moOg1P3gkoL20?O_i`80moOg103gkoL20?O_i`@0moOg0P3_knL20?Ogm`80knog0P3_knL20>ON
eP80g/jm0P3>[I@20;fDN`80_HaS0P2eLdX309a[BP80Q58i0P2DFS4208a::@80U5Xa0P1B:AP206/i
8@80Ld8Y0P2<FT820>o6[@80klJe203gc[D20?OF_@80mlJe0P3ge[d40?O6]@80mmJm103ga[D20>o6
[@80klJU103_aZd20>o6Y@@0ikFL0P3W]I@20=j]U080gZf<0P3NYH@20=JLN`80cYA[0P36Q6/209aS
>@@0[F=20P2DFT8209aS>@80Q4XY0P1kBRT206<Y4080W6]:0P3FW7/208a::@80cYA[0P2DHd820:e[
@P80Jc4H0P2]Hc4208a:<@80_HaS0P2]Hc420<Ik@P80aW]:0P2mS6<20;F4H`80aYA[0P2eNeX20=J]
Q080cYAS0`3W_JD20>o>]@80_HaS0P2eLdX20;f<H`80aXaS0P36W8@20=JLL`80eZf40P3F[H`20>Nm
U080imkF0P3_imh20>oWi`80mnoW0P3_knL20?O_m`80moOg0P3gkoL40?Ogm`@0mnog0P3gmoL40?O_
m`80moOg103gkoL20?Ogm`80mnog103gmoL@0?ooo`003P3oool20>o_m`80moOg0P3gkoL60?Ogm`80
mnoW0P3gmoL40?O_m`80moOg1P3gkoL20?O_i`80moOg103gkoL20?O_i`@0moOg0P3_knL20?Ogm`80
knog0P3_knL20>ONeP80g/jm0P3>[I@20;fDN`80_HaS0P2eLdX309a[BP80Q58i0P2DFS4208a::@80
U5Xa0P1B:AP206/i8@80Ld8Y0P2<FT820>o6[@80klJe203gc[D20?OF_@80mlJe0P3ge[d40?O6]@80
mmJm103ga[D20>o6[@80klJU103_aZd20>o6Y@@0ikFL0P3W]I@20=j]U080gZf<0P3NYH@20=JLN`80
cYA[0P36Q6/209aS>@@0[F=20P2DFT8209aS>@80Q4XY0P1kBRT206<Y4080W6]:0P3FW7/208a::@80
cYA[0P2DHd820:e[@P80Jc4H0P2]Hc4208a:<@80_HaS0P2]Hc420<Ik@P80aW]:0P2mS6<20;F4H`80
aYA[0P2eNeX20=J]Q080cYAS0`3W_JD20>o>]@80_HaS0P2eLdX20;f<H`80aXaS0P36W8@20=JLL`80
eZf40P3F[H`20>NmU080imkF0P3_imh20>oWi`80mnoW0P3_knL20?O_m`80moOg0P3gkoL40?Ogm`@0
mnog0P3gmoL40?O_m`80moOg103gkoL20?Ogm`80mnog103gmoL@0?ooo`003P3oool20?O_m`80moOg
0P3gkoL60?Ogm`@0mnog203gmoL40?O_m`80moOg0P3gkoL<0?Ogm`80mnog103_inL20>O>_@80g/jm
0P36W8@20<J<H`80[G=B0P2eLdX309AS@P@0U5Xa0P24DS4206/i8@80Jc4H0P24BRT208AJ@P80klJe
0P3_aZd20>o>[@H0mlje0P3ga[D20>o>[@X0klJ]0P3_aZD40>neW080ikfU0P3_aZD20>NmW080kkfL
103W]I`20=j]S080ijf<0P3N[I@20=j]S080gZF40P3FW7<20<jDJ`80cXaS0P2LHcT209a:<@80W6<i
0P2<BS4208a::@@0JcTQ0P24DST20;f<H`80]G]J0P2LJdX20<JLQ080S48Q0P2eNeX209AJ<@80[F=2
0P2eJd820<IkBP80[F/i0P36NdX20;f<H`80W6<i102mS6<40=JLL`<0cZfD0P3N[H`20>NmU080_HaS
0P2eJd820;f<H`80aYb40P36U6/20=J]Q080ikfD0P3We/h20>o_i`80imkF0P3_knL20?O_i`80knoW
0P3gmoL40?O_m`80moOg0P3gkoL40?Ogm`80mnog0P3gmoL20?O_m`H0moOg0P3gkoL60?Ogma00oooo
000>0?ooo`80mnog0P3gmoL20?O_m`H0moOg103gkoL80?Ogm`@0mnog0P3gmoL20?O_m``0moOg0P3g
koL40>oWi`80iljm0P3Nc[d20<JLQ080aXaS0P2]Le820;EcBP<0U6=2102DFS4208AB<@80JcTQ0P1[
<AP208A::@80Q5Y20P3_a[D20>o6[@80klj]1P3gc[D20?O6]@80klj]2P3_aZd20>o6Y@@0kkFL0P3W
_JD20>o6Y@80ikfL0P3__I`40>NeW080gZf<0P3W[H`20=j]U080gZf<0P3NYH@20=JLL`80cYA[0P3>
S6<209aS>@80W4Xa0P2LHcT208a:<@80S4XY101[>B4208AB>@80_HaS0P2eNeX209a[BP80aYb40P2<
@R420;EkFP80U5Xa0P2]Hd820;E[@P80aW]:0P2]JcT20<IkBP80_HaS0P2LHcT40;f<H`@0eYac0`3>
[I@20=j]S080ikfD0P2mS6<20;E[@P80_HaS0P36W8@20<JDJ`80eZf40P3W_I@20>OFcP80knoW0P3W
g]H20>o_i`80mnoW0P3_knL20?Ogm`@0mnog0P3gmoL20?O_m`@0moOg0P3gkoL20?Ogm`80mnog1P3g
moL20?O_m`H0moOg403oool000h0oooo103gmoL20?O_m`H0moOg0P3gkoL20?Ogm`P0mnog103gmoL2
0?O_m`80moOg0P3gkoL20?O_i`80knog103gkoL40?Ogm`80knOW0P3We/h20>O>_@80c[FU0P2mU7/2
0;EkFP80[G=B0P2DHd8709AJ<@80FS4Q0P1[>B4406/a60@0klJe0P3gc[D20>o>[@@0klJ]0P3ga[D2
0>o6[@80kkfL0P3W]I`40>N]U0H0gZf<0P3NYH@80=j]S0H0ikFD0P3W]I`20>NeU0@0gZf<0P3NYH@2
0=jLN`80eYak0P3FW7<20<j<H`80]F]B0P2DFS4208AB<@80Q4Xa0P1c@RT206/i8@80LdXa0P2DHd82
0<jDJ`80_HaS0P2UNeX20=JLL`80aW]:0P2eNeX208A28@80[F/i0P36Q5X20<Ik@P80aW]:0P2]JcT4
0;EkFP80eYak0P36U6/20=JLL`<0eZf40P3W_JD20>O6]@80_HaS0P36U6/20=JLN`80aYA[0P36S6<2
0<j]U080ikfL0P3gknL20>ONeP80mnog0P3_knL20?O_i`80knoW103gmoL20?O_m`80moOg0P3_koL2
0?O_m`80moOg103gkoL>0?Ogm`80mnog403oool000h0oooo103gmoL20?O_m`H0moOg0P3gkoL20?Og
m`P0mnog103gmoL20?O_m`80moOg0P3gkoL20?O_i`80knog103gkoL40?Ogm`80knOW0P3We/h20>O>
_@80c[FU0P2mU7/20;EkFP80[G=B0P2DHd8709AJ<@80FS4Q0P1[>B4406/a60@0klJe0P3gc[D20>o>
[@@0klJ]0P3ga[D20>o6[@80kkfL0P3W]I`40>N]U0H0gZf<0P3NYH@80=j]S0H0ikFD0P3W]I`20>Ne
U0@0gZf<0P3NYH@20=jLN`80eYak0P3FW7<20<j<H`80]F]B0P2DFS4208AB<@80Q4Xa0P1c@RT206/i
8@80LdXa0P2DHd820<jDJ`80_HaS0P2UNeX20=JLL`80aW]:0P2eNeX208A28@80[F/i0P36Q5X20<Ik
@P80aW]:0P2]JcT40;EkFP80eYak0P36U6/20=JLL`<0eZf40P3W_JD20>O6]@80_HaS0P36U6/20=JL
N`80aYA[0P36S6<20<j]U080ikfL0P3gknL20>ONeP80mnog0P3_knL20?O_i`80knoW103gmoL20?O_
m`80moOg0P3_koL20?O_m`80moOg103gkoL>0?Ogm`80mnog403oool000h0oooo0P3gmoL20?O_m`H0
moOg0P3gkoL80?Ogm`80mnog2P3gmoL60?O_m`@0moOg103gkoL20>oWi`80imK60P3Nc[d20=J]S080
aYA[102eLdX20:eS@P<0S4Xa0P2DFS4208AB<@80Jc4H0P1[>B4208A::@80ilJe103_c[D20?O>]@80
klj]103_aZd20>o6Y@80ikfU0P3W[I@20>N]S080gZF40P3NW7/:0>N<N`80gZF40P3NW7/20=jUQ080
gZf<0P3NYH@40>NeU080ikFL0P3N[I@20=j]S080gZF40P3FYH@20=JLN`@0cYA[0P36Q6<208aJ@P80
Q48Y0P1kBRT206/i8@80DRTH0P1[>B4208aSBP80cYA[0P2]Le8209AJ<@80eZF40P36NdX20<jDH`80
]G]J0P2LHcT20:e[@P80cXaJ0P36NdX20;EcBP80_HaS0P2eNeX20=JLL`80aYA[0P3F[H@30=JLL`80
eZf40P3WaZd20=J]Q080eYac1036W8@20=JLL`80eZf<0P3W_JD40>oWgP80mnoW0P3_knL20?O_m`80
moOg0P3gkoL40?Ogm`80knog1P3gmoL20?O_m`@0moOg0P3gkoL<0?Ogma00oooo000>0?ooo`80moOg
0P3gkoL60?Ogm`80mnog203gmoL20?O_m`X0moOg1P3gkoL40?Ogm`@0mnog0P3_inL20>OFaP80g/jm
0P3F[H`20<JDJ`@0]G=:0P2]Hd8308a:<@80U5Xa0P24DS4206/a6080JcTQ0P24BRT20>O6]@@0klje
0P3gc[D20>o>[@@0klJ]0P3_aZD20>NmY@80ijfD0P3W[H`20=jUQ080gYak2P3WS7/20=jUQ080gYak
0P3NYH@20=j]S080gZF4103W]I@20>NeW080gZfD0P3N[H`20=jUQ080eZF40P3FW7/40<jDJ`80aXAS
0P2<FT8208A2:@80NdXY0P1[>B42058Y6080JcTQ0P2<HdX20<jDJ`80[G=B0P2DFS420=JUQ080aW]:
0P3>U6<20;EkFP80W6<i0P2]Jd820<j<FP80aW]:0P2eLdX20;f<H`80]G]J0P3FW7<20<JDJ`80eZf4
0`3FW7<20=J]Q080ilJ]0P3F[H@20=JLL`@0aYb40P3FW7<20=J]S080ikfU103_imh20?O_i`80knoW
0P3gkoL20?Ogm`80mnog103gmoL20>o_m`H0moOg0P3gkoL40?Ogm`80mnog303gmoL@0?ooo`003P3o
ool20?Ogm`80mnog103gmoL20?O_m`X0moOg0P3gkoL<0?Ogm`80mnog103gknL20?Ogm`80mnog0P3_
knL20>OFcP80iljm0P3Nc/H20<JLQ080]G]J0P2]Le8209aS>@80[F=20`24DST208A::@@0JcTQ0P1k
>AP207]::@@0klJe203_aZd20>o6Y@80kkFL0P3NLf<20<i[FP@0gW][2P3NQ7<80<i[FP80eYak103N
[H`60>NeU080gZfD0P3N[H`20=jUQ0@0eYak0P3>U6/20<J4J`80aXAJ0P1kBRT206/i8@80Jc4H0P1B
8A0206/a6080Q58i0P2]Le820=JLN`80]HAS0P36Q6/20=J]Q080cYAS0P3FW7<20<JDJ`80aW]:0P2e
LdX20<J4FP80_HaS0P2]JcT20;EcBP80_HaS0P3FW7<20;f<H`<0gZf40P3F[H`20>NmU080ikfU0P36
W8@20=J]Q080aYA[0P3FW7<20>NmU080g/jm0P3We/h20>oWi`80knoW0P3_inL20>o_i`80mnoW0P3g
moL20>o_m`80mnog0P3gmoL20?O_m`H0moOg0P3gkoL40?Ogm`80mnog103gmoL20?O_m`@0moOg403o
ool000h0oooo0P3gmoL20?O_m`@0moOg0P3gkoL:0?Ogm`80mnog303gmoL20?O_m`@0mnoW0P3gmoL2
0?O_m`80knoW0P3We/h20>O>_@80g/k60P36W8@20;EkFP80[G=B0P2LHcT20:eS@P<0Q58i0P24BRT4
06/i8@80NcTH0P1kBRT40>o6]@P0klJ]0P3_aZD20>neW080gW=S0P3>JeX40=ikJ`X0gXAc203>JeX2
0=JLN`@0gZf<1P3W]I@20=j]U080gZf<0P3NYH@40=JLN`80cYA[0P36Q6/20<J4FP80NdXY0P1[>B42
06/a6080DR4@0P1[<AP208AB>@80[G=B0P3FW7/20;F4H`80aXA[0P3F[H@20<jDH`80eYac0P36U6/2
0<IkBP80]G=:0P36Q5X20;f<H`80[F/i0P2eLdX20;f<H`80eYac0P2mS6<30=j]Q080eZf<0P3W_I@2
0>NmY@80aYb40P3F[H@20<JDJ`80eYac0P3W_I@20=k>_@80imK>0P3_inL20>o_i`80knOW0P3_knL2
0?O_i`80moOg0P3_koL20?O_m`80moOg0P3gkoL60?Ogm`80mnog103gmoL20?O_m`@0moOg0P3gkoL4
0?Ogma00oooo000>0?ooo`80moOg0P3gkoL20?Ogm`80mnog0P3gmoL20?O_m`P0moOg0P3gkoL40?Og
m`80mnog0P3gknL40?Ogm`80mnog103gmoL20?O_i`80moOg0P3_inL20>ONeP80imK60P3F[H`20<JD
J`80YG]J0P2LJdX209aS>@80U5Xa0`1kBRT208AB>@80Ld8Y0P1[>B4207]::@80kljm0P3_a[D40>o6
[@80klJU0P3_cZd20>o6[@80ihak1P3NQ7<20>o6]@80kkFL103WS7/20>NUU080kkFL103NQ7<20=ik
J`80aXA[0P3>Lf<20<i[FP80eYak0P3N[H`20=j]U080ikFD0P3W]I`20=j]U0@0gZf<0P3FYH@20=JL
N`80cYA[0P3NQ7<20<J4H`80]G]J0P1cBS44058Y6080DR4@0P24DST2058Y6080eZF40P3N[H`209aS
>@80eZf<0P2eNeX20=jUN`80eZf40P2mS6<20<J4FP80cYAS0P2]Hc420<J4FP80]G]J0P2mS6<20<JD
J`80cYA[0`3FW7/20=J]S080ikfU0P3Wa[D20;fDN`80]HAS0P36U6/20=JLL`80cZfD103_imh40>o_
i`80knON103gmoL20>o_m`@0mnog0P3gmoL20?O_m`80moOg103gkoL40?Ogm`80mnog103gmoL40?O_
m`80moOg0P3gkoL@0?ooo`003P3oool20?Ogm`80mnog0P3gmoL20?O_m`80moOg0P3gkoL80?Ogm`80
mnog103gmoL20?O_m`80mnoW103gmoL20?O_m`@0moOg0P3gknL20?Ogm`80knOW0P3Wg]H20>OFaP80
eZf<0P36U6/20:EkFP80W6]:0P2LHcT209AJ<@<0NdXY0P24DST207=2:@80JcTQ0P1kBRT20>o>_@80
klJe103_aZd20>o6Y@80klj]0P3_aZd20>N<N`H0gXAc0P3_a[D20>neW0@0ihak0P3WYI@20>neW0@0
gXAc0P3NNf/20<J4J`80cW=S0P3>JeX20=JLN`80gZf<0P3N[I@20>NeU080ikFL0P3N[I@40=j]S080
eZF40P3FW7/20<jDJ`80gXAc0P36Q6<20;EkFP80LdXa101B:AP2058Q4080Q58i0P1B:AP20=JUQ080
gZf<0P2LHcT20=J]S080]G]J0P3NYG/20=J]Q080_HaS0P36Q5X20<jDH`80[F<a0P36Q5X20;EkFP80
_HaS0P36U6/20<jDJ`<0eYak0P3F[H`20>NmY@80ilJe0P2mU7/20;F4H`80aYA[0P3FW7<20<j]U0@0
knON103_knL20>oWgP@0moOg0P3_koL40?O_m`80moOg0P3gkoL20?Ogm`@0mnog103gmoL20?O_m`@0
moOg103gkoL20?Ogm`80mnog403oool000h0oooo0P3gkoL20?Ogm`80mnog0P3gmoL20?O_m`80moOg
0P3gkoL20?Ogm`@0mnog0P3gmoL<0?O_m`80mnoW103gmoL20>o_m`80moOg0P3We]H20=k>_@80cZfD
0P36U6/20;F4H`80YG]J0P24DST209AJ<@80S4Xa0`2DFS4206<Y40@0JcTQ0P2UQ6/60>o>]@80klJ]
1P3_aZD20=ikJ`@0gXAc0P3NNf/60=icH`80gXAc103>JeX20<IJBP@0aV=:0P3WS7/40<icH`80aUY:
0P3FYH`20>N]U0P0ikFD0P3N[H`20=JUQ0@0eYak103>U6/20<J4FP80[G=B101[>B4203TH4080Jc4H
0P2<FT820;F4H`80aYA[0P2eNeX20;f<H`80eZf40P36Q5X20=j]Q080klj]0P2mS6<20;EcBP@0aXAJ
0P2]Jd820;EkFP80cYAS0P36U6/50=JLL`@0ikfU0P36W8@20<JDJ`80aYb40P2mU7/20<j]U080knON
0P3_inL20?O_i`@0knOW3P3gmoL20?O_maH0moOg403oool000h0oooo0P3gkoL20?Ogm`80mnog0P3g
moL20?O_m`80moOg0P3gkoL20?Ogm`@0mnog0P3gmoL<0?O_m`80mnoW103gmoL20>o_m`80moOg0P3W
e]H20=k>_@80cZfD0P36U6/20;F4H`80YG]J0P24DST209AJ<@80S4Xa0`2DFS4206<Y40@0JcTQ0P2U
Q6/60>o>]@80klJ]1P3_aZD20=ikJ`@0gXAc0P3NNf/60=icH`80gXAc103>JeX20<IJBP@0aV=:0P3W
S7/40<icH`80aUY:0P3FYH`20>N]U0P0ikFD0P3N[H`20=JUQ0@0eYak103>U6/20<J4FP80[G=B101[
>B4203TH4080Jc4H0P2<FT820;F4H`80aYA[0P2eNeX20;f<H`80eZf40P36Q5X20=j]Q080klj]0P2m
S6<20;EcBP@0aXAJ0P2]Jd820;EkFP80cYAS0P36U6/50=JLL`@0ikfU0P36W8@20<JDJ`80aYb40P2m
U7/20<j]U080knON0P3_inL20?O_i`@0knOW3P3gmoL20?O_maH0moOg403oool000h0oooo203gmoL4
0?O_m`80moOg1P3gkoL20?Ogm`H0mnog103gmoL40?O_m`80moOg1P3gkoL20>OFcP80e/Je0P3FW7<2
0<JDJ`80[G=B0P2DHd8208a:<@80U5Xa0P24BRT306/a6080Nd8Q0P1[<AP209AJ<@@0kljm0P3_c[D4
0>o6[@80klJU0P3WS7/20=j4L`80[G=B0P2LBS420:e:<@80_E920P2]Le840;eB@P80aUY:0P2eDST2
09a:<@80W34Q0P2L@RT20:e:<@80S34Q0P2]@S4209a2:@80Q48Y0P2DFT820=j4L`H0ikFD1P3N[H`4
0=JLN`80eYac0P3FW7/20<J4H`80]G]J0P2<FT8204XH2080>AP@0P1[>B4207=:<@80Q5Y20P2mS6<2
0=JUQ080U5Xa0P3FYH@20;EkFP80eYak0P3W_I`20>o>[@@0cYA[0P2eJcT20<J4FP80]G]J0P2mS6<2
0<J<H`<0]G]J0P3F[H@20>NmU080ikfU0P3F_Jd20=JLL`80eZf40P36W8@20=JeY@80imkF0P3_knL2
0>oWgP80knoW0P3gkoL20>o_i`@0moOg0P3gkoL20?Ogm`80mnog403gmoL20?O_m`80moOg0P3gkoL4
0?Ogma00oooo000>0?ooo`P0moOg103gkoL20?Ogm`H0mnog0P3gmoL60?O_m`@0moOg103gkoL20?Og
m`H0mnog0P3We/h20=K6]@80eYac0P36U6/20:ecDP80U6=20P2<BS4209AJ<@80Q4XY0`1[<AP207]2
8@80Jc4H0P2DFS440>o>_@80klje103_aZd20>o6Y@80ihak0P3NQ7<20:ecDP80W4Xa0P2]BS420;eB
@P80[G=B102mDT820<IJBP80]E8i0P2LBS4209`a8@80W48Y0P2]BS4208`a8@80[D8a0P2L@RT208A2
:@80U5Y20P3NQ7<60>NeU0H0gZf<103FW7/20=JLL`80eYak0P36Q6<20;EkFP80S5Y20P1:60P203TH
4080JcTQ0P1cBS4208AJ@P80_HaS0P3FYH@209AJ<@80eZF40P2eNeX20=JLN`80ikfL0P3_cZd40<jD
J`80]F/i0P36Q5X20;EkFP80_HaS0P36S6<30;EkFP80eZf40P3W_I@20>NmY@80e[f]0P3FW7<20=J]
Q080aYb40P3F]JD20>ONeP80knoW0P3_imh20>o_i`80mnog0P3_knL40?Ogm`80mnog0P3gmoL20?O_
ma00moOg0P3gkoL20?Ogm`80mnog103gmoL@0?ooo`003P3oool60?O_m`@0moOg103gkoL20?Ogm`80
mnog0P3gmoL20?O_m`80moOg0P3gkoL20?Ogm`X0mnog0P3gknL20?O_m`80knOW0P3We/h20=Jm[@80
_IAk0P2eNeX209AS@P80S4Xa0P2<FT8208a::@L0NdXY0P24@RT40>o>_@80klJe0P3_c[D20?O>]@80
klJ]0P3_aZD20>neW080klJU0P3WS7/20<icH`80cV]J0P36HdX20<i[FP80aV=:0P3>JeX20=ikJ``0
aV=:0P3FW7<20=JUQ080eZF<103N[H`40>NeU0@0ijf<0P3N[H`20>N]S080gZF4103FW7/20=JLL`80
cYA[0P36Q6<209acDP80FSTY100i610205Xi:@80Q5Y20P2LLe820=JLN`80aYA[0P2LJdX20=JLL`80
]G]J103W_I`20>o>]@80[G=B1036Q5X20;EkFP@0_HaS0`2eNeX40=J]Q080ikfU0P3WaZd20<JDJ`80
eZf40P3FW7<20>OFaP@0knOW103_imh80?O_m`P0moOg0P3gkoL40?Ogm`80mnog103gmoL20?O_m`@0
moOg0P3gkoL40?Ogma00oooo000>0?ooo`H0mnog103gmoL40?O_m`80moOg0P3gkoL20?Ogm`80mnog
0P3gmoL20?O_m`80moOg2P3gkoL20?O_i`80mnog0P3_inL20>OFcP80e[f]0P2mU7/20;EkFP80U6=2
0P2<BS4208aJ@P80S4XY1`1kBRT208A2:@@0kljm0P3_a[D20>o>]@80mlje0P3_aZd20>o6Y@80kkFL
0P3_aZD20>N<N`80cW=S0P3>JeX20<ISBP80cV]J0P36HdX20<i[FP80gW][3036HdX20=JLL`80eZF4
0P3FYH`40=j]S0@0ikFD103W[H`20=j]S080ijf<0P3NYH@40=JLN`80eYac0P3>U6/20<J4H`80W7=B
0P1J>BT403TH4080FSTY0P24FT8209acDP80eYak0P36U6/209a[BP80eYac0P2eNeX40>NmW080klje
0P2]Le840<J4FP80]G]J102mS6<30;EkFP@0eZf40P3W_JD20>O6[@80aYA[0P3F[H@20=JLL`80imK6
103_inL40>oWgPP0mnog203gmoL20?O_m`@0moOg0P3gkoL40?Ogm`80mnog103gmoL20?O_m`@0moOg
403oool000h0oooo0P3gmoL40?O_m`80moOg0P3gkoL60?Ogm`80mnog0P3gmoL20?O_m`X0moOg0P3g
knL20?Ogm`80mnog0P3_knL20?O_i`80knON0P3Nc/H20=J]S080]HAS102LJdX208aJ@P80S4XY0P24
BRT207=2:@<0NdXY0P24@R4208AB<@80klje0P3_aZd20>o>]@80klj]0P3_aZd20>o>[@80klJU0P3_
cZd40?O>]@80mmJm0P3_e/H20>o6]@80klJ]0P3ge[d20>o6[@80klJU0P3gc[D20?OF_@80klJe0P3_
aZd20>NmY@80ikFL0P3W_JD20>NeW0@0ikFD0P3W]I`20>NeU080ikFL0P3W]I@20>N]U0@0gZf<103N
YH@20=JLN`80eYac103>U6/20;EkFP80Q58a0P12<BT202T@2080Q5Y20P1cBS4208AJ@P80W7=B0P2m
S6<209aS>@80aXAJ0P2]Jd820<J4FP@0ikfL0P3FW7<20<jDJ`80_HaS102eLdX20;f<H`<0cYA[0P3F
W7<20<jDJ`80ikfU0P3WaZd40<JLQ080aXaS0P3Wg]H40>oWgP80knOW0P3_imh60?Ogm`80mnog303g
moL20?O_m`80moOg0P3gkoL60?Ogm`80mnog1P3gmoL@0?ooo`003P3oool20?Ogm`@0mnog0P3gmoL2
0?O_m`H0moOg0P3gkoL20?Ogm`80mnog2P3gmoL20?O_i`80moOg0P3gkoL20>o_i`80mnoW0P3_imh2
0=k>aP80eZf<0P2eQ6<409a[BP80S5Y20P2<BRT208A::@80Ld8Y0`1kBRT208A28@80Q58a0P3_c[D2
0>o6[@80klje0P3_cZd20>o6[@80klj]0P3_aZD20>o>[@@0mlje0P3ge[d20>oFaP80klJe0P3_aZd2
0?OF_@80klJ]0P3_aZD20?O>]@80mmJm0P3_a[D20>o6[@80ikfU0P3W]I`20>NmY@80ikFL103W]I@2
0>NeW080ikFD0P3W]I`20>NeU080ijfD103N[H`40=jUQ080eYak0P3FW7<40<jDJ`80]G]J0P24DS42
048a:@80:A080P24FT8207=:<@80Q5Y20P2LLe820;f<H`80W6<i0P36Q5X20:e[@P80aXAJ103W_I`2
0=JLL`80cYA[0P2mS6<40;EcBP80_HaS0`3>U6/20=JLL`80cYA[0P3W_JD20>O6[@@0aYb40P36S6<2
0>ONeP@0knON0P3_inL20>oWgPH0moOg0P3gkoL<0?Ogm`80mnog0P3gmoL20?O_m`H0moOg0P3gkoL6
0?Ogma00oooo000>0?ooo`80mnog2P3gmoL20?O_m`H0moOg0P3gkoL20?Ogm`@0mnog103gmoL20?O_
m`80mnoW103gkoL20>oWi`80g/Je0P3W_I`20<JLQ080[G=B0P2DHd8408AB<@80Q4Xa0P1[<AP507]:
:@80Nd8Q0P3F]JD60>o>]@80mlJe0P3gc[D20>o6[@80mlje0P3_aZd40?O>]@80mmJm0P3gc[D20?OF
_@80mlje0P3ge[d20>o6Y@H0klJ]203W]I`20>NmW080ikFL0P3W_I`20>o6Y@80ikFL0P3W]I@20>Nm
W080ikFL103W[I@20=j]S0@0gZF40P3FW7/20=j4L`@0cYA[0P2eNeX209AJ@P80DR4@0P128AP207=:
<@80Q58a0P2UQ6/209acDP80aYb40P2LHcT209AJ<@80aXaS0P2mS6<20=j]U080ikfL0P3_aZD20=J]
Q0@0aXAJ0P36S6<20;EcBPD0]G]J0P3>U6/20>NmY@80ilJ]0P3FW7<20=J]S080aYA[0P3_imh20>oW
i`80imkF0P3_imh20?O_i`H0moOg0P3gkoL40?Ogm`H0mnog503gmoL20?O_ma00oooo000>0?ooo`80
mnog2P3gmoL20?O_m`H0moOg0P3gkoL20?Ogm`@0mnog103gmoL20?O_m`80mnoW103gkoL20>oWi`80
g/Je0P3W_I`20<JLQ080[G=B0P2DHd8408AB<@80Q4Xa0P1[<AP507]::@80Nd8Q0P3F]JD60>o>]@80
mlJe0P3gc[D20>o6[@80mlje0P3_aZd40?O>]@80mmJm0P3gc[D20?OF_@80mlje0P3ge[d20>o6Y@H0
klJ]203W]I`20>NmW080ikFL0P3W_I`20>o6Y@80ikFL0P3W]I@20>NmW080ikFL103W[I@20=j]S0@0
gZF40P3FW7/20=j4L`@0cYA[0P2eNeX209AJ@P80DR4@0P128AP207=:<@80Q58a0P2UQ6/209acDP80
aYb40P2LHcT209AJ<@80aXaS0P2mS6<20=j]U080ikfL0P3_aZD20=J]Q0@0aXAJ0P36S6<20;EcBPD0
]G]J0P3>U6/20>NmY@80ilJ]0P3FW7<20=J]S080aYA[0P3_imh20>oWi`80imkF0P3_imh20?O_i`H0
moOg0P3gkoL40?Ogm`H0mnog503gmoL20?O_ma00oooo000>0?ooo`80mnog0P3gmoL80?O_m`80moOg
0P3gknL80?Ogm`80mnog0P3gmoL20?O_m`80moOg103gkoL20?O_i`@0mnog0P3Nc/H20<JLQ080]G]J
0P2LHcT209a[BP80Q4XY0P24BS4206/i8@T0NdXY103_c[D20>o6]@80klje0P3gc[D40?O6]@80mlje
0P3_c[D<0?O>]@80klje0P3_aZd60>o6Y@80ikFL0P3W_I`20>nmW080ikFL0P3W_JD20>NeW080klJU
0P3W]I`20>o6Y@@0ikFL103W[I@20>NeU080gZf<0P3NYH@20=jLN`80gZF40P3FW7<40<jDJ`80aXAS
0P2LJdX207=2:@80FSTY0P0i610207=B@P80Q58i0P2DHd8209aS>@80[G=B0P2LHcT20;EkFP80YG]J
0P3>U6/40>NmU080cYA[0P3FW7<20<J4FP80_HaS0P2eLdX30;f<H`80]G=:0P3FW7<20=J]Q080ikfU
0P3>[I@20<JDJ`80eYak0P3We/h40>oWgP80imK60P3gmoL20?O_m`@0moOg0P3gkoL20?Ogm`80mnog
203gmoL20?O_m`H0moOg103gkoL80?Ogma00oooo000>0?ooo`80mnog0P3gmoL80?O_m`80moOg0P3g
knL80?Ogm`80mnog0P3gmoL20?O_m`80moOg103gkoL20?O_i`@0mnog0P3Nc/H20<JLQ080]G]J0P2L
HcT209a[BP80Q4XY0P24BS4206/i8@T0NdXY103_c[D20>o6]@80klje0P3gc[D40?O6]@80mlje0P3_
c[D<0?O>]@80klje0P3_aZd60>o6Y@80ikFL0P3W_I`20>nmW080ikFL0P3W_JD20>NeW080klJU0P3W
]I`20>o6Y@@0ikFL103W[I@20>NeU080gZf<0P3NYH@20=jLN`80gZF40P3FW7<40<jDJ`80aXAS0P2L
JdX207=2:@80FSTY0P0i610207=B@P80Q58i0P2DHd8209aS>@80[G=B0P2LHcT20;EkFP80YG]J0P3>
U6/40>NmU080cYA[0P3FW7<20<J4FP80_HaS0P2eLdX30;f<H`80]G=:0P3FW7<20=J]Q080ikfU0P3>
[I@20<JDJ`80eYak0P3We/h40>oWgP80imK60P3gmoL20?O_m`@0moOg0P3gkoL20?Ogm`80mnog203g
moL20?O_m`H0moOg103gkoL80?Ogma00oooo000>0?ooo`80moOg0P3gkoL20?Ogm`@0mnog1P3gmoL2
0?O_ma00moOg103gkoL20?O_i`80g/k60P3Fa[D20;fDN`80]G=:0P2LJdX208A::@80S5Y20P1[>B42
07]::@80Jc4H0P1kBRT308A::@80JcTQ0P3_c[D40>o6]@80klje1P3gc[D20?O6]@P0mlje0P3_c[D4
0?O>]@@0klJU0P3W]I`20>o6Y@80ikFL0P3W[H`20>NeU080ikfL0P3W]I`20>neW080kkfL0P3_aZD4
0>neW080klJ]0P3_aZD40>NeW080ijfD0P3W[H`40=jUQ080eYak0P3FW7<20=j4L`80aXA[0P36Q6<2
0;EcBP80LdXa0P1B8A02058Y6080LdXa0P2<HdX209A[DP80W7=B0P2eQ6<209a[BP80S5Y20P2DHd82
0;fDN`80aXaS0P3NYG<20>o6Y@80eZf40P36NdX20<J<H`80W6]:0`36U6/20;f<H`80eYak0P3FW7<2
0>NmY@80cZfD0P2mS6<20>O6]@80imK61P3_inL20?O_m``0moOg0P3gkoL60?Ogm`80mnog0P3gmoL2
0?O_m`h0moOg403oool000h0oooo0P3gmoL20?O_m`80moOg103gkoL60?Ogm`80mnog403gmoL40?O_
m`80mnoW0P3Nc/H20=K6]@80_IAk0P2eLdX209a[BP80Q4XY0P2<FT8206/i8@80NdXY0P1[<AP207]:
:@<0Q4XY0P1[>B420>o>]@@0klJe0P3_c[D60?O>]@80mlJe203gc[D20>o>]@@0mlje103_aZD20>Ne
W080klJU0P3W]I`20>N]S080ikFD0P3W_I`20>NeW080kkFL0P3__I`20>o6Y@@0kkFL0P3_aZd20>o6
Y@@0ikFL0P3W[I@20>N]S0@0gZF40P3FW7/20=JLL`80gXAc0P36Q6/20<J4H`80]G=:0P1cBS42058Q
4080DRTH0P1cBS4208aSBP80U6]B0P2LLe820;F4H`80W6]:0P2<FT8209AS@P80_IAk0P36S6<20=jU
L`80klJU0P3F[H@20<IkBP80aXaS0P2LJdX30<JDJ`80_HaS0P3FW7/20=JLL`80ikfU0P3>[I@20;f<
H`80ilJe0P3We/H60>oWi`80mnog303gmoL20?O_m`H0moOg0P3gkoL20?Ogm`80mnog3P3gmoL@0?oo
o`003P3ooolB0?Ogm`80mnog203gmoL60?O_m`@0moOg0P3_inL20=k6]@80aZFD0P2mU7/209a[BP80
W6<i0P2DHd8208A2:@@0NdXY0P1cBS4207]::@<0JcTQ0P2eQ6<20>O6]@@0klJe203gc[D20?OF_@80
mlje0P3_c[D60?O>]@@0klJ]0P3W]I`20=j]S080gZF40P3W[I@20=j]U080gZF40P3N[H`20>N]U080
ikFD0P3W]I`20>nmW080ikfU0P3_aZD40>o6[@@0kkFL0P3W]I`20>N]U080gZf<103NYH@40=JLN`80
eYac0P3>U6/20<IkFP80]F]B0P2<FT8205Xi:@80JcTQ0P1J@ST208AJ@P80Q58i0P2LLe8209AS@P80
]G=:0P24DS4209aS>@80Q58i0P3F[H`20>NmU080eYac0P3NYG/20<J<H`80aYA[0P2UNeX30;EkFP80
_HaS0P36W8@20=JLL`80ikfL0P3F]JD20<JDJ`80imkF0P3W_JD20?O_m`80knOW303gmoL20?O_m``0
moOg103gkoL40?Ogm`80mnog203gmoL@0?ooo`003P3ooolB0?Ogm`80mnog203gmoL60?O_m`@0moOg
0P3_inL20=k6]@80aZFD0P2mU7/209a[BP80W6<i0P2DHd8208A2:@@0NdXY0P1cBS4207]::@<0JcTQ
0P2eQ6<20>O6]@@0klJe203gc[D20?OF_@80mlje0P3_c[D60?O>]@@0klJ]0P3W]I`20=j]S080gZF4
0P3W[I@20=j]U080gZF40P3N[H`20>N]U080ikFD0P3W]I`20>nmW080ikfU0P3_aZD40>o6[@@0kkFL
0P3W]I`20>N]U080gZf<103NYH@40=JLN`80eYac0P3>U6/20<IkFP80]F]B0P2<FT8205Xi:@80JcTQ
0P1J@ST208AJ@P80Q58i0P2LLe8209AS@P80]G=:0P24DS4209aS>@80Q58i0P3F[H`20>NmU080eYac
0P3NYG/20<J<H`80aYA[0P2UNeX30;EkFP80_HaS0P36W8@20=JLL`80ikfL0P3F]JD20<JDJ`80imkF
0P3W_JD20?O_m`80knOW303gmoL20?O_m``0moOg103gkoL40?Ogm`80mnog203gmoL@0?ooo`003P3o
ool20?O_m`X0moOg0P3gkoL20?Ogm`@0mnog103gmoL20?O_m`H0moOg0P3gknL20?Ogm`@0mnog0P3W
_I`20;fDN`80[G=B0P2DHd8408a:<@80NdXY101[>B4407]::@<0Jc4H0P3Wa[D40>o6]@80mlJe303g
c[D20>o>[@H0mlje0P3_aZd20>neW080ijfL0P3W]I@20=jLN`@0gZF40P3FW7/20=JUQ0@0gZf<0P3W
]I@20>NeW080kkfL0P3_]I`60>o6Y@80kkFL0P3_aZD20>neU080ijfD0P3N[H`20=jUQ0@0eYak0P3F
W7<20<J4J`80aXAS0P2eNeX209AJ@P80FSTY0P0Y40P2048Y8@80LdXa0P24DS4209a[BP80Q58i0P2e
LdX409aS>@80NdXY0P3FYH@20<J4FP80eYac0P3_cZd20<JDJ`@0aXaS0`2eNeX20;F<L`80aXAJ0P36
U6/20>NmW0@0e[f]0P3Nc[d40>OFcP80ilk6303gmoL20?O_ma@0moOg0P3gkoL80?Ogma00oooo000>
0?ooo`80mnog2P3gmoL20?O_m`80moOg103gkoL40?Ogm`80mnog1P3gmoL20?O_i`80moOg103gkoL2
0>NmW080_IAk0P2]Le8209AS@P@0S4Xa0P1kBRT406/i8@@0NdXY0`1[<AP20>O6]@@0klJe0P3ga[D<
0?O>]@80klj]1P3gc[D20>o6[@80kkFL0P3W[I`20>NeU080gYak103NYH@20=JLN`80eZF4103N[H`2
0>NeU080ikFL0P3__I`20>neW0H0klJU0P3_]I`20>o6Y@80kkFD0P3W[I@20=j]S080gZF4103FW7/2
0=JLL`80aXA[0P36Q6<20;EkFP80U5Y20P1J>BT202T@2080@RTQ0P1cBS4208AB<@80W6]:0P24DST2
0;EcBP@0W6<i0P1kBRT20=JUQ080aXAJ0P3FW7<20>o>[@80aYA[1036S6<30;EkFP80]Hac0P36Q5X2
0<JDJ`80ikfL103F_Jd20=k>_@@0imK>0P3Wc/H<0?Ogm`80mnog503gmoL20?O_m`P0moOg403oool0
00h0oooo3P3gmoL20?O_m`H0moOg0P3gkoL>0?Ogm`80knOW0P3F[H`20;F4H`80U6=20P24DS4208a:
<@80JcTQ0P1kBRT207=2:@80NdXY0P24@RT206/a60<0FS4Q0P3_a[D20>O6[@@0klJ]0P3gc[D20?O6
]@@0mmJm1P3gc[D20?O6]@80kmK60P3NW7/20=ikJ`@0klJ]0P3_]I`20>NUU0@0]F=20P36Q6/20=jL
N`80]G]J0P3FW7<20=j]S080ikFL103_aZD60>o6[@80klJU0P3_]I`20>NeW080ijfD0P3W[H`40=jU
Q080eYak0P3FW7<20<jDJ`80aXAS0P2eJe820:eS@P80Ld8Y0P0i6102048Y8@80FS4Q0P1cBS4208AB
>@80Q5Y2102LJdX208AB<@80W6]:0P2<FT820;f<H`80gZf40P3FW7<20=j]Q080aXAJ0P2mS6<309aS
>@@0]G]J0P3FW7<20>NmU080e[f]0P3_inL20<j]U080knOW0P3F]JDZ0?Ogm`80mnog0P3gmoL@0?oo
o`003P3oool>0?Ogm`80mnog1P3gmoL20?O_m`h0moOg0P3_inL20=J]S080]HAS0P2DHd8208AB<@80
S4Xa0P1[>B4207]::@80Ld8Y0P1kBRT208A2:@80Jc4H0`1J<B420>o6]@80ilJ]103_aZd20?O>]@80
mlJe103ge[d60?O>]@80mlJe0P3_e/H20=jLN`80gW][103_aZd20>neW080ijFD102eHd820<J4J`80
gYak0P2eNeX20=JLL`80gZf<0P3W]I`40>o6Y@H0klJ]0P3_aZD20>neW080ikFL0P3W[I@20>N]S0@0
gZF40P3FW7/20=JLL`80cYA[0P36Q6<20;E[DP80[F=20P1c@RT203TH4080@RTQ0P1J<B4207=:<@80
Q58i0P24FT8409a[BP80Q58a0P2LJdX208aJ@P80_HaS0P3N[H@20=JLL`80gZf40P36Q5X20;f<H`<0
W6<i102eNeX20=JLL`80ikfD0P3F_Jd20>oWi`80cZfD0P3_inL20=JeYBX0moOg0P3gkoL20?Ogma00
oooo000>0?ooo`@0mnog0P3gmoL40?O_m`P0moOg103gkoL20?Ogm`80mnog2P3gmoL20?O_m`80imkN
0P36U6/20:ecDP80U6=20P2LHcT407]::@80JcTQ0P1k@R4207]::@80JcTQ0P1J<B4308AB>@80klJe
0P3_aZd20>o>]@80mlje0P3ge[d20?O>]@80mlJe0P3ge[d20?O6]@80mlje0P3_cZd20?O>]@80mmJm
0P3_c[D20>o6]@@0mlJe0P3_aZd20>NeU080gZf<0P3N[I@20>N]S080ikFD0P3NYH@20<j<H`80eYak
0P3W]I`:0>o6[@80kkFL103_aZD20>neU080ijf<0P3N[H`20=jUQ080eYak103>U6/20<J4H`80aW]J
0P2LLe8208aJ@P80:A080P0i6102048Y8@80FT8i0P1cDT8208aJ@P80Q58i0P2LLe8208AB<@80U5Xa
0P1B:AP20=J]Q080cXaS0P3>U6<20>NmW080]G]J0P2mS6<309a[BP80[G=B0P2mS6<20<JDJ`80cZfD
103Na[D20<J]W080e[FU103gmoL20?O_m`X0moOg0P3gkoL80?Ogm`80mnog2P3gmoL40?O_m`H0moOg
403oool000h0oooo103gkoL20?Ogm`@0mnog203gmoL40?O_m`80moOg0P3gkoL:0?Ogm`80mnog0P3W
g]h20<JDJ`80[G=B0P2DHd8209aS>@@0NdXY0P1[>B4207]28@80NdXY0P1[>B4205Xa8@<0Q58i0P3_
a[D20>o6[@80klje0P3gc[D20?OF_@80mlje0P3ga[D20?OF_@80mlJe0P3gc[D20>o>[@80mlje0P3g
e[d20>o>]@80klJe103ga[D20>o6[@80ikFD0P3N[H`20=j]U080ijf<0P3W]I@20=jUQ080cXaS0P3F
W7/20>NeW0X0klJ]0P3_]I`40>o6Y@80kkFD0P3W[H`20=j]S080gZF40P3FW7/40<jDJ`80aXAS0P36
NeX209acDP80S5Y20P0Y40P203TH4080@RTQ0P1J@ST207=B@P80S5Y20P24DST209acDP80Q58a0P2D
FS42058Y6080eZf40P3>S6<20<jDH`80ikfL0P2eNeX20;f<H`<0W6]:0P2]Le820;f<H`80aYA[0P3>
[I@40=k6]@80aZfL0P3F]JD40?Ogm`80mnog2P3gmoL20?O_m`P0moOg0P3gkoL:0?Ogm`@0mnog1P3g
moL@0?ooo`003P3oool<0?Ogm`80mnog103gmoL40?O_m`P0moOg0P3gknL60?Ogm`80imK>0P2mS6<2
09AS@P80U5Y20P1[>B4207=:<@80Q4Xa0P1c@RT207]::@80Q4Xa101S:A030:EkH`80ilJ]1P3ga[D2
0>oFaPH0mmJm0P3_e/H40?O>]@80mlJe0P3ge[d20>o6]@H0kmK60P3ga[D20>o6Y@80ikFD103W[I`2
0=j]U080gZf<103NYH@20>neW0@0klJ]0P3ga[D60>o6[@H0kkFL0P3W]I@20>N]S080gZf<0P3NW7/4
0=j4L`80aXAS0P2eNeX20:e[@P80U6=20P0Y40P2048Q6080>AP@0P1cBS4208AB>@80U6=20P1c@RT2
09a[BP80Q58a0P2DFS4205Xa8@80aYA[0P2mS6<20=J]Q080ikfL0P2eNeX20;f<H`<0[G=B0P2eNeX2
0;F4H`80_IAk0P3F[H`40=k6]@80e[f]0P3Nc[d40?Ogm`80mnog3P3gmoL20?O_ma80moOg0P3gkoL6
0?Ogma00oooo000>0?ooo``0moOg0P3gkoL40?Ogm`@0mnog203gmoL20?O_i`H0moOg0P3We/h20;f<
H`80U6=20P2DFT8206/i8@80LdXa0P24BS4207=2:@80NdXY0P24BS4406<Y40<0YG]S0P3WaZd60?O6
]@80kmK61P3ge[d20>oFaP@0mlje0P3ga[D20?OF_@80klJe1P3_e/H20?O6]@80klJU0P3W]I@40>N]
W080gZfD0P3N[H`40=jUQ080kkFL103_aZd20?O6]@H0klJ]1P3_]I`20>NeU080ijf<0P3N[H`20=jL
N`@0gXAc0P36Q6<20;EkFP80[F]20P2DHd8202T@2080@R4H0P0i610207=:<@80Q58i0P2DHd8207=2
:@80W6]:0P24DS4209AJ<@80FS4Q0P36U6/20;f<H`80eZf40P3W_I`20;EkFP80_HaS0`2]Le820;Ek
FP80]HAS0P2mU7/20=J]S0@0g/Je0P3F_Jd20=k>_@@0moOg0P3gkoL>0?Ogm`80mnog4P3gmoL20?O_
m`H0moOg403oool000h0oooo1P3gmoL20?O_m`80moOg0P3gkoL40?Ogm`80mnog0P3gmoL20?O_m`@0
moOg0P3gknL20?Ogm`@0mnog0P3gmoL20?O_m`80ilk60P2]Le8208aJ@P80U5Xa0P24DS4407]::@80
Q4XY0P2<BS4207]28@80DRTH0P1J>BT30>O6]@80klJe103gc[D60?OF_@80kmK60P3ge[d20>oFaP80
mmJm0P3ga[D20>o6[@@0mmJm0P3_e/H20?ONeP80kmK60P3ga[D20>o6[@80ikfU0P3W[I@20>NUU080
gZfD0P3N[H`20=jUQ080ijfD0P3_]I`40>o6[@80klj]0P3_aZd20?O6]@80klJ]103_aZD40>neW080
ijfD0P3W[H`20=jUQ080gYak0P3>U6/20<J4J`80]G]J0P2]Jd8209AJ<@80DRTH0P0H20P2048Q6080
Ld8Y0P1B:AP209aS>@80Q58a0P2LJdX207]28@80Q58a0P2<FT820:ecDP80aXaS103NYG/20=JLL`80
]G]J0`2mS6<20:ecDP@0]G]J0P3>[I@20>O6[@80e[FU0P3Wc/H20?O_m`h0moOg103gkoLN0?Ogma00
oooo000>0?ooo`H0moOg0P3gkoL20?Ogm`80mnog103gmoL20?O_m`80moOg0P3gkoL40?Ogm`80mnoW
0P3gmoL40?O_m`80moOg0P3gkoL20>O>aP80[G=B0P2<FT8209AJ<@80Q58a101kBRT208A::@80S4Xa
0P1k@R42058Y6080FSTY0`3Wa[D20>o6]@@0mlje1P3ge[d20>oFaP80mmJm0P3_e/H20?OF_@80mlJe
0P3_aZd40?OF_@80kmK60P3gg]H20>oFaP80mlJe0P3_aZd20>NmY@80ijfD0P3WYI@20=j]U080gZf<
0P3NYH@20>N]U080kkFL103_aZd20>o>[@80klJ]0P3ga[D20>o6[@@0klJU103_]I`20>N]U080ijf<
0P3NYH@20=jLN`80cYA[0P36Q6/20;EkFP80[F]20P2DFS42058Y608060P80P128AP207=2:@80DRTH
0P2LHcT208AB<@80W6]:0P1k@R4208AB<@80S5Y20P2]Le820<J<H`@0gZEk0P3FW7<20;EkFP<0_HaS
0P2]Le840;EkFP80cZfD0P3WaZd20=JeY@80ilk60P3gkoL>0?Ogm`@0mnog7P3gmoL@0?ooo`003P3o
ool>0?Ogm`@0mnog0P3gmoL40?O_m`@0moOg0P3gkoL60?Ogm`80mnoW0P36U6/409AS@P80JcTQ101c
@RT207]::@80Q4Xa0P1kBRT2048Q6080HbT@0P128AP30>o6[@80mlJe0P3_c[d20?O6]@@0mmJm0P3_
e/H:0?OF_@@0mlje0P3ga[D60>oFaP80mlje0P3_aZd20>N]U080eZF<0P3NYH@20=j]S080eZF<0P3N
[I@20>NeW080klJ]103_a[D20>o>]@80mlje103_aZd20>o6Y@80klJ]0P3_aZD20>neW080ijfD0P3W
[H`20=j]S080gZF40P3FW7<20<J4J`80]G]J0P2]Le820:eS@P80LdXa0P0Q40P203TH4080FSTY0P1k
FT8208AB>@80S5Y20P2DHd8207]::@80Q58a0P1cBS4209acDP80aXAJ0P3>U6/20=j]S080ikfU0P2e
LdX30;EkFP80W7=B0P2eNeX20<JDJ`80ikfL0P3WaZd20<JLQ080g/jm0P3gmoL20?O_m`80moOg1P3g
koL60?Ogm`80mnog4P3gmoL20?O_m`X0moOg403oool000h0oooo3P3gmoL40?O_m`80moOg103gkoL4
0?Ogm`80mnog1P3gmoL20?O_i`80aYA[102DHd8206/i8@@0Ld8Y0P1kBRT208A:<@80NdXY0P128AP2
06<Y4080@R4H0`3_aZd20?O6]@80kljm0P3ga[D40?OF_@80kmK62P3ge[d40?O>]@80mlJe1P3_e/H2
0?O>]@80klJ]0P3W[I@20=JUS080gZF40P3N[H`20=JUS080gZfD0P3W]I`20>o6[@@0klJe0P3_c[D2
0?O>]@@0klJ]0P3_aZD20>o6[@80klJU0P3_]I`20>N]U080ijf<0P3N[H`20=jUQ080eYac0P36Q6/2
0;EkFP80[G=B0P2]Hd8207=:<@808A080P0i610205Xi:@80NeY20P24DST208aJ@P80U6=20P1kBRT2
08AB<@80LdXa0P2LLe820<J4FP80cYA[0P3N[H`20>NmY@80]G=:0`2eNeX209acDP80]G]J0P36U6/2
0>NmW080ilJ]0P36W8@20=k>_@80moOg0P3gkoL20?Ogm`H0mnog1P3gmoL20?O_ma80moOg0P3gkoL:
0?Ogma00oooo000>0?ooo`@0mnog1P3gmoL20?O_m``0moOg0P3gkoL20?Ogm`80mnog1P3gmoL20>o_
m`80]HA[0P2DHd8208A::@80JcTQ0P24DST408A:<@80NdXY0P0i6102058Y6080DR4@0P1J>BT30>o6
[@80mlje0P3ge[d@0>oFaP@0mmJm0P3ga[D20>o>_@80mlJe0P3ge[d20?O6]@80klJe0P3_]I`20>Ne
W080eZF<0P3N[H`40=j]U080ikFL1P3_aZd20>o6]@80mlJe0P3gc[D20>o6]@80mlJe0P3_aZd20>o6
Y@80klJ]103_]I`20>N]U080ijf<0P3FYH@20=jUQ080cYA[0P36Q6<20:ecDP80W6]:0P2<BS4202T@
2080@S4Y0P1B:AP207=2:@80LdXa1024DS4209aS>@@0Q58a0P2UNeX20;f<H`80cYAS0P3N[H`20>o>
[@80]G]J0`2eLdX209a[BP80YG]J0P2eQ6<20<j]U080g/Je0P3Nc[d20?O_ma`0moOg0P3gkoL80?Og
m`@0mnog203gmoL@0?ooo`003P3oool40?O_m`H0moOg0P3gkoL<0?Ogm`80mnog0P3gmoL20?O_m`H0
moOg0P3_koL20;F4J`80U6=20P24BRT206/i8@80Q58i1024BS4207]::@80>AP@0P1B:AP2058Q4080
FSTY0`3_aZd20?O>]@80mmJm403_e/H40?OF_@80mlJe0P3_c[d20?O6]@80mmJm0P3ga[D20>o6]@80
kkFL0P3W]I`20=JUS080gZf<103N[I@20>NeW0H0klJ]0P3_a[D20?O6]@80mlje0P3_a[D20?O6]@80
klJ]0P3_aZD20>o6[@@0kkFL0P3W[I@20>N]S080eZF40P3NYH@20<jDJ`80aXAS0P2]Le8209a[BP80
S4Xa0P0Y40P2048a:@80DRTH0P1c@RT207=:<@@0Q58a0P2LHcT408AB<@80YG]J0P2mS6<20<jDH`80
gZf<0P3_cZd20;EkFP<0]G=:0P2LJdX20:EkFP80]HAS0P3>[I@20=k6]@80g/jm0P3gkoLL0?Ogm`80
mnog203gmoL40?O_m`P0moOg403oool000h0oooo203gmoL20?O_m``0moOg0P3gkoL20?Ogm`80mnog
0P3gmoL80?O_m`80]HA[0P2DFS4407]::@80Q58i0P1cBS4207]::@80Q4Xa0P1B:AP2048Q6080DRTH
0P3>[I@50>o>]@80mmJm203_e/H60?ONcP80kmK61P3ge[d20?O>]@80klJe103ge[d20>o6[@80kkFL
103N[I@20=j]S080ikFD0P3W]I`20>NmY@80klJ]0P3_c[D20>o6]@@0mlJe0P3ge[d20>o>_@80mlJe
0P3_a[D40>o6[@80kkFL103W]I`20=j]U080gZF40P3FW7/20=JLL`80aXAS0P2eJe8209a[BP80U6=2
0P128AP2024@2080FS4Q0P1B:AP208AB>@80S5Y20P1kBRT209AJ<@80W6<i0P24DS4209acDP80aYb4
0P3FW7<20=j]Q080klj]0P2]Le830<J<H`80S5Y20P2eQ6<20:ecDP80ikfD0P3Wc[d20=k>_C00moOg
0P3gkoL20?Ogma00oooo000>0?ooo`P0moOg0P3gkoL<0?Ogm`80mnog0P3gmoL20?O_m`80moOg203g
koL20;F4J`80U5Xa101kBRT208AB>@80LdXa0P1kBRT208A:<@80DRTH0P128AP2058Y6080cZfD1@3_
c[D20?OF_@P0kmK61P3gg/h20>oFaPH0mmJm0P3gc[D20>o6]@@0mmJm0P3_aZd20>neW0@0gZfD0P3N
[H`20>NeU080ikFL0P3W_JD20>o6[@80klje0P3_a[D40?O6]@80mmJm0P3_c[d20?O6]@80klJe103_
aZd20>neW0@0ikFL0P3N[I@20=jUQ080eYak0P3FW7<20<J4H`80]F]B0P2LJdX209AS@P80@R4H0P0Q
40P205Xa8@80DRTH0P24DST208aJ@P80NdXY0P2DFS4209aS>@80Q58a0P2LLe820<JLQ080eYac0P3N
[H@20>o>[@80[G=B0`36S6<208aJ@P80]HAS0P2]Le820>NmU080iljm0P3Nc[d`0?Ogm`80mnog0P3g
moL@0?ooo`003P3oool60?O_m`h0moOg1P3gkoL40?Ogm`@0mnog0P3gmoL20=k6aP80W7=B0P2<FT82
07=2:@@0Q58a0P24BS4207]::@80DRTH0P128AP203TH4080kkFL0P3_c[d30?O6]@80mmJm0P3gg/h4
0>oFaP80mmk>403_e/H20?OF_@80mlje103ge[d20?O6]@80klJ]0P3W]I`20=j]U0@0ikFD0P3W]I`2
0>NmY@@0klJe0P3_e/H20?OF_@80mlJe0P3_e/H20?O6]@80mmJm103_c[d20>o6]@80klJ]0P3WaZd2
0>neW080ikFD0P3N[H`20=JUQ080eYak0P3FW7<20;EkFP80W6]:0P2LHcT207=2:@80HbT@0P1[>B44
07=:<@80U6=20P24DS4209aS>@80S5Y20P2<BS4209acDP80eZF40P3FW7<20=J]Q080ikfU0P2mS6<3
0;EcBP80Q58a0P2UNeX20;EkFP80gZf<0P3We/H20>o_ia80moOg0P3gkoL40?Ogm`@0mnog103gmoL2
0?O_m`80moOg0P3gkoL>0?Ogma00oooo000>0?ooo`H0mnog3P3gmoL60?O_m`@0moOg103gkoL20?Og
m`80g/K60P2LLe8208aJ@P80Ld8Y1024DS4208A:<@80NdXY0P1B:AP2048Q6080>AP@0P3_]I`20>o>
_@<0mlJe0P3ge[d20?ONcP@0kmK60P3gg/h@0>oFaP80mmJm0P3gc[D40?OF_@80mlJe0P3_aZd20>Ne
W080gZfD103W]I@20>NeW080ikfU103_a[D20>oFaP80mmJm0P3ga[D20>oFaP80mlJe0P3ge[d40>o>
_@80klJe0P3_aZd20>O6[@80kkFL0P3W]I@20=j]S080eZF40P3FW7/20=JLL`80]G]J0P2LJdX209aS
>@80Ld8Y0P1S:A0206/i8@@0LdXa0P2DHd8208AB<@80W6<i0P2<FT8208a:<@80W7=B0P3FYH@20=JL
L`80eZf40P3W_JD20;f<H`<0]G=:0P24DS420:EkFP80]G]J0P3N[H`20>OFaP80knoW4P3gmoL20?O_
m`@0moOg103gkoL40?Ogm`80mnog0P3gmoL20?O_m`h0moOg403oool000h0oooo0P3gkoL20?Ogm`80
mnog303gmoL20?O_m`@0moOg0P3gkoL:0?Ogm`80W7=B0P2DFS4208AB<@80FS4Q0P1kFT8407=:<@80
Q4Xa0P1B:AP206/i8@80FSTY0P3_aZd20>o6]@<0kmK60P3ge[d40>oFaP@0mmk>103_e/H20?OF_@80
mmk>203_e/H20?OF_@80kljm1P3ge[d20?O6]@80ikFL0P3N[I@20>NeW080ikfL103W_JD20>O6[@80
klje0P3ge[d20>o>_@80mmJm0P3_e/H20?OF_@80mlJe1P3_c[d20>o6]@80klJ]0P3W_JD20>NeW080
gZfD0P3N[H`20=JLN`80eYac0P36NeX20;E[DP80U5Y20P1cBS4606/i8@80Q58i0P24DS4209aS>@80
U6=20P2<FT8209AcFP80]HA[0P3FW7/40=JLL`80eZf40P36S6<30:e[>@80Q4XY0P2UNeX20;fDN`80
eZf<0P3Wg]HT0?Ogm`80mnog1P3gmoL20?O_m`P0moOg403oool000h0oooo0P3gkoL20?Ogm`80mnog
303gmoL20?O_m`@0moOg0P3gkoL:0?Ogm`80W7=B0P2DFS4208AB<@80FS4Q0P1kFT8407=:<@80Q4Xa
0P1B:AP206/i8@80FSTY0P3_aZd20>o6]@<0kmK60P3ge[d40>oFaP@0mmk>103_e/H20?OF_@80mmk>
203_e/H20?OF_@80kljm1P3ge[d20?O6]@80ikFL0P3N[I@20>NeW080ikfL103W_JD20>O6[@80klje
0P3ge[d20>o>_@80mmJm0P3_e/H20?OF_@80mlJe1P3_c[d20>o6]@80klJ]0P3W_JD20>NeW080gZfD
0P3N[H`20=JLN`80eYac0P36NeX20;E[DP80U5Y20P1cBS4606/i8@80Q58i0P24DS4209aS>@80U6=2
0P2<FT8209AcFP80]HA[0P3FW7/40=JLL`80eZf40P36S6<30:e[>@80Q4XY0P2UNeX20;fDN`80eZf<
0P3Wg]HT0?Ogm`80mnog1P3gmoL20?O_m`P0moOg403oool000h0oooo0P3gkoLF0?Ogm`80mnog1P3g
moL20?O_m`80moOg0P2]Le8209aS>@80LdXa0P1[>B4208aJ@P80Q58i0P1kBRT207=2:@80JcTQ0P1B
:AP20:F4L`80mlJe0P3_c[d70>oFaP@0mmk>0P3_e/H20?OF_@80kmK6103ge[d20>oFaP@0mmk>103_
e/H40?OF_@80kmK6103ga[D20>NeW0@0gZfD0P3W_I`20>NmY@@0klJ]1P3_c[d40>oFaP@0mlJe0P3g
e[d20?O>]@80klje0P3_a[D40>o6[@80ikfU0P3N[I@20=j]S080eZF40P3FW7<20<J4H`80]F]B0P2D
FT8208a:<@@0FS4Q0P1[>B4207=:<@80Q4Xa0P2DHd8209aS>@80U6=20P2DFS480=JLL`80eZF40P3F
[H@50:e[@P80[G=B0P2eQ6<20=j]Q080knoW6P3gmoL20?O_m`80moOg0P3gkoLF0?Ogma00oooo000>
0?ooo`80mnog5P3gmoL20?O_m`H0moOg0P3gkoL20?Ogm`80[G=B0P2LHcT207=:<@80JcTQ0P2<FT82
08AB>@80NdXY0P1c@RT206/i8@80DRTH0P2UQ7<20?O6]@80kljm1`3_e/H40?ONcP80kmK60P3ge[d2
0>oFaP@0mmJm0P3_e/H40?ONcP@0kmK6103ge[d20>oFaP@0mlJe0P3W]I`40=j]U080ikfL0P3W_JD4
0>o6[@H0kljm103_e/H40?O6]@80mmJm0P3gc[D20>o>]@80klJe103_aZd20>NmY@80gZfD0P3N[H`2
0=JUQ080eYac0P36Q6<20;E[DP80U5Y20P2<BS4405Xa8@80JcTQ0P1cBS4208A:<@80U6=20P2LHcT2
09AS@P80U5Xa203FW7<20=JUQ080eZf41@2]Jd820:ecDP80]HAS0P3N[H@20>o_iaX0moOg0P3gkoL2
0?Ogm`80mnog5P3gmoL@0?ooo`003P3oool40?Ogm`80mnog0P3gmoL20?O_m`H0moOg0P3gkoL@0?Og
m`80mnog102LLe8208AB>@80LdXa0P1c@RT208AB>@80Q4Xa0P1J<B4207=2:@80Q58i0P3_a[D20?O>
]@80kljm3`3_e/H20?OF_@80kmK60P3_c[d80>oFaP@0mmJm0P3_a[D40>oFaP80mmJm0P3W_JD20>N]
U080gZfD0P3W]I`40>NmY@80ilJ]0P3_a[D60>o>_@80kmK60P3_c[d20?OF_@80kljm103_a[D20>o6
[@80klJe0P3WaZd40>NmY@80gZfD0P3FYH@20=JLN`80cYA[0P2eNeX209a[BP80Q58i0P1c@RT206/a
60@0JcTQ0P24DST209AJ<@80S6=:0P24DST208A::@80eZf<0P3FW7<20<JDJ`80eYak0P36W8@20=j]
S0<0U5Xa102]Le820:F4J`80eZf40P3gknLR0?Ogm`80mnog4P3gmoL@0?ooo`003P3oool40?Ogm`80
mnog0P3gmoL20?O_m`H0moOg0P3gkoL@0?Ogm`80mnog102LLe8208AB>@80LdXa0P1c@RT208AB>@80
Q4Xa0P1J<B4207=2:@80Q58i0P3_a[D20?O>]@80kljm3`3_e/H20?OF_@80kmK60P3_c[d80>oFaP@0
mmJm0P3_a[D40>oFaP80mmJm0P3W_JD20>N]U080gZfD0P3W]I`40>NmY@80ilJ]0P3_a[D60>o>_@80
kmK60P3_c[d20?OF_@80kljm103_a[D20>o6[@80klJe0P3WaZd40>NmY@80gZfD0P3FYH@20=JLN`80
cYA[0P2eNeX209a[BP80Q58i0P1c@RT206/a60@0JcTQ0P24DST209AJ<@80S6=:0P24DST208A::@80
eZf<0P3FW7<20<JDJ`80eYak0P36W8@20=j]S0<0U5Xa102]Le820:F4J`80eZf40P3gknLR0?Ogm`80
mnog4P3gmoL@0?ooo`003P3oool20?O_m`H0moOg0P3gkoL20?Ogm`80mnog0P3gmoL20?O_m``0moOg
0P3gkoL20?Ogm`80_Jf]0P2DFS4208aSBP80Q58a0P2<FT8208AB<@80S4Xa0P1[>B4205Xi:@80Ld8Y
0P3WaZd20?OF_@80klJe0P3ge[d90>oFaP80mmk>103_e/H20?OF_@80kljm103_a[D40>o>_@@0mmJm
0P3ga[D20?O>]@@0kmK60P3ge[d20>o6[@80ijfD0P3N[H`20=j]U080gZfL0P3W_I`20=j]W080ilJe
0P3Wc[d20>o6]@80kmK61P3_c[d20>o6]@80ilJe0P3_a[D60>o6[@@0ikfU0P3N[I`20=j]S080eZF4
0P3NQ7<20<J4H`80W6]:0P2DFS4207=:<@80DRTH101[>B4207=:<@80W6]:1P2<FT820<JLQ080aYA[
103FW7<209a[BP80ikfD0`24@R4209a[BP80_HaS0P36U6/20<j]U200moOg0P3gkoLF0?Ogma00oooo
000>0?ooo`80mnog1P3gmoL20?O_m`80moOg0P3gkoL20?Ogm`80mnog303gmoL20?O_m`80moOg0P2m
[Jd209AJ<@80S6=:0P24DS4208aJ@P80Q58a0P2<BS4206/i8@80FSTY0P1c@RT20>O6[@80mmJm0P3_
a[D20?OF_@T0kmK60P3gg/h40>oFaP80mmJm0P3_c[d40>o6]@@0kljm103ge[d20?O6]@80mlje103_
e/H20?OF_@80klJ]0P3W[I@20=j]S080gZfD0P3N[I`20>NmW080gZfL0P3Wa[D20>O>_@80klJe0P3_
e/H60>o>_@80klJe0P3Wa[D20>o6]@H0klJ]103W_JD20=j]W080gZf<0P3FYH@20=j4L`80aXAS0P2L
JdX209AJ<@80LdXa0P1B:AP406/i8@80LdXa0P2LJdX608aJ@P80aYb40P36U6/40=JLL`80W6]:0P3W
_I@308A28@80W6]:0P2mS6<20<JDJ`80cZfD803gmoL20?O_maH0moOg403oool000h0oooo1P3gmoL2
0?O_m`@0moOg0P3gkoL@0?Ogm`80mnog0P3gmoL20:EkJ`80]Hac0P2LJdX207=:<@80W6]:0P1cBS42
08a:<@80FS4Q0P1cBS4207]::@80ilJ]0P3ga[D20>O6[@D0kmK60P3gg/h40>oFaP80mmJm0P3_e/H4
0>o>_@80kkFL0P3WaZd40>o6[@80klJe0P3_c[d20?OF_@80klje0P3gc[D20?OF_@80kmK60P3ge[d2
0>o6[@80ijFD0P3N[H`20=JUS0@0gZfD0P3W_JD20>O6]@80klJe0P3_c[d40>O6[@80ikfU203WaZd2
0>o6[@80klJe103WaZd20=JeY@80ikfL0P3N[H`20=JUQ080eYac0P36Q6<20:ecDP80U5Xa0P24BS42
058Y6080DR4@0P1[>B4207=:<@80S5Y20P2LHcT408aJ@P80aYb4103>U6/20=JLL`80Q4Xa0P3N[H@3
09AJ@P80S5Y20P2eQ6/20=JUQ080ilJ]1P3gmoL20?O_maP0moOg0P3gkoLF0?Ogma00oooo000>0?oo
o`H0moOg0P3gkoL40?Ogm`80mnog403gmoL20?O_m`80moOg0P2UNf/20;F<L`80W6]:0P1cBS4209a[
BP80LdXa0P2<BS4205Xa8@80LdXa0P1kBRT20>O6[@80mlJe0P3WaZd50>oFaP80mmk>103_e/H20?OF
_@80kmK6103_c[d20>neW080ilJ]103_aZd20>o6]@80kljm0P3ge[d20>o>]@80mlje0P3ge[d20>oF
aP80mmJm0P3_aZd20>NUU080gZf<0P3FYH`40=j]U080ikfU0P3Wa[D20>o6]@80kljm103WaZd20>Nm
Y@P0ilJ]0P3_aZd20>o6]@@0ilJ]0P3F]JD20>NmW080gZf<0P3FYH@20=JLL`80aXAS0P2]Le8209AJ
<@80Q4Xa0P1B:AP2058Q4080JcTQ0P1cBS4208aJ@P80W6<i102<FT820<JLQ0@0cYA[0P3FW7<208A:
<@80gZf40`2DFT8208aJ@P80]HA[0P3FYH@20>O6[@H0moOg0P3gkoLH0?Ogm`80mnog5P3gmoL@0?oo
o`003P3oool60?Ogm`80mnog1P3gmoL20?O_m`H0moOg203gkoL40?Ogm`80S4XY0P2eU7/208aJ@P80
U6]B0P24FT8208aJ@P80LdXa0P1B:AP209aS>@80ijf<0P3_aZd20>N]U080klJe0P3ge[d90>oFaP80
kljm0P3Wc[d40>o6]@80klJ]0P3N[I`20=j]U080ikfU0P3WaZd20>o6]@80kljm0P3WaZd20>o6]@@0
kmK60P3ge[d20>neW080gZfD0P3NW7/20=J]S080eZF<0P3>[I@20=JeY@80ilJ]0P3Wa[D40>NmY@80
e[FU0P3W[I`40=j]S080eZF<103N[I`60>NmY@@0ikfL0P3N[I@20=JUQ080cYA[0P36Q6/20;E[DP80
W6]:0P24DST207=2:@80>AP@0P1S:A0206/i8@@0S5Y20P2LJdX208AB>@80_IAk0P3FW7/20;EkFP80
_HaS0P24BRT20>NmU0<0W6]:0P2<BS420<JDJ`80eZf40P3We/H@0?Ogm`80mnog5P3gmoL20?O_m`h0
moOg403oool000h0oooo1P3gmoL20?O_m`H0moOg0P3gkoL60?Ogm`P0mnog103gmoL208a::@80]IAk
0P2<FT8209A[DP80Q5Y20P2<FT8207=:<@80DRTH0P2LHcT20>N]S080klJ]0P3W[I@20>o6]@80mmJm
2@3_e/H20>o>_@80iljm103_a[D20>o6[@80gZfL0P3N[I@20>NmY@80ilJ]0P3_a[D20>o>_@80ilJ]
0P3_a[D40>oFaP80mmJm0P3_]I`20=j]U080gYak0P3F[H`20=JUS080cZfD0P3F]JD20>O6[@80ilJe
103W_JD20=JeY@80ijfL103N[H`20=JUS0@0gZfL1P3W_JD40>NmW080gZfD0P3FYH@20<jDJ`80aXA[
0P2eJe8209a[BP80Q58i0P1c@RT203TH4080HbT@0P1[>B4408aJ@P80W6]:0P24DST20;fDN`80eYak
0P2eNeX20;f<H`80Q4XY0P3W_I@309a[BP80S4Xa0P36U6/20=J]Q080imK6403gmoL20?O_maH0moOg
0P3gkoL>0?Ogma00oooo000>0?oooa80moOg0P3gkoL20?Ogm`80mnog203gmoL20?ooo`80W6]:0P2U
Nf<208AB>@80S5Y20P24DST209AJ@P80DR4@0P24DS4208A:<@80mlJe0P3>U6/20=jUQ080klje0P3g
e[d70>oFaP80kljm0P3Wa[D20=j]W080_IAk0P2eS7<20=JUS080cZFD0P2mU7/40=j]W0@0kljm103_
a[D60?OF_@80klJ]0P3N[I@20=JLN`80aYb40P3FW7/20>NmW080gZfL0P3Wa[D20>N]W080gZfL0P36
YI`20;fLS080]HA[0P2eS7<60<JLQ080cZFD0P3W_I`20>NmY@H0gZfL0P3N[H`20=JUQ080aYb40P36
Q6/20;EkFP80U5Y20P24DST207=:<@80JcTQ101J<B4208AB>@80Q58a0P2<HdX208aJ@P80]HA[0P2m
S6<40;EkFP80U5Xa0P3W_I@309AJ<@80S4Xa0P36W8@20=JLL`80imK>0P3ooolf0?Ogma00oooo000>
0?oooa80moOg0P3gkoL20?Ogm`80mnog203gmoL20?ooo`80W6]:0P2UNf<208AB>@80S5Y20P24DST2
09AJ@P80DR4@0P24DS4208A:<@80mlJe0P3>U6/20=jUQ080klje0P3ge[d70>oFaP80kljm0P3Wa[D2
0=j]W080_IAk0P2eS7<20=JUS080cZFD0P2mU7/40=j]W0@0kljm103_a[D60?OF_@80klJ]0P3N[I@2
0=JLN`80aYb40P3FW7/20>NmW080gZfL0P3Wa[D20>N]W080gZfL0P36YI`20;fLS080]HA[0P2eS7<6
0<JLQ080cZFD0P3W_I`20>NmY@H0gZfL0P3N[H`20=JUQ080aYb40P36Q6/20;EkFP80U5Y20P24DST2
07=:<@80JcTQ101J<B4208AB>@80Q58a0P2<HdX208aJ@P80]HA[0P2mS6<40;EkFP80U5Xa0P3W_I@3
09AJ<@80S4Xa0P36W8@20=JLL`80imK>0P3ooolf0?Ogma00oooo000>0?ooo`80mnog203gmoL20?O_
m`80moOg0P3gkoL@0?Ogm`80_IbD0P2UNeX209acDP80LdXa0P24DST207=:<@80U5Y20P1J<B4209AJ
<@80kkFD0P3_]I`20>N<N`80eZF<0P3_c[D20>o>_@D0kmK60P3_a[D20>N]W080]HAS0P2mS6<20=j]
W080_Jf]0P1cJf<207=cJ`80YHAc0P36W8@40=j4L`@0klJe0P3WaZd60?OF_@80klJU0P3W]I`20=JL
N`80eZF40P2mU7/20=JUQ080W4Xa0P36FTX20<J4J`80eZF<0P3Na/H209AkL`80LeY:0P2UNf/20:Ek
H`80YG]J0P2UNf<20;F4J`80eZF<103N[I@40=j]W0@0eZF<0P3>U6/20<J4J`80]F]B0P2LJdX208aJ
@P80LdXa0P24DST4058Y60@0Q58i0P2<FT8209a[BP80]HAS0P2mU7/20;EcBP80]G]J0P2DDRT20>Nm
W0<0W6<i0P2LLe840=J]Q080knOW7P3gmoL20?O_maP0moOg403oool000h0oooo0P3gkoL80?Ogm`80
mnog0P3gmoL20?O_ma00moOg0P2mW9@20:EkFP80W7=B0P1cBS4208AB>@80LdXa0P2DFT8205Xa8@80
U5Xa0P3_]I@20>neW080ihak0P3FYH`20>o>]@80kljm1@3_e/H20>o6]@80ijfL0P2eQ6<20;f<H`80
gZfL0P2m[Jd207=[H`80Lg=[0P2UQ7<20<JLQ0@0gXAc103_a[D20>O6[@H0mmJm0P3_aZD20>NeW080
eYak0P3FYH@20;fDN`80eZF40P2LBS420<IJBP80aXA[0P3FYH`20=k6aP80U7]c0P1cFTX20:EkJ`80
YG]S0P2UNeX20:EkH`80]HA[0P3FYH`40=j]U0@0gZfL103FYH`20<jDJ`80aXA[0P2eJe8209a[BP80
S5Y20P1cBS4208AB>@@0DRTH1024DST208aJ@P80W6]:0P2eQ6<20;fDN`80]G=:0P2eNeX209AB:@80
ikfL0`2LHcT209acDP@0eZf40P3_inLN0?Ogm`80mnog603gmoL@0?ooo`003P3ooolF0?Ogm`80mnog
203gmoL20;F4J`80_Ib<0P2LLe8208aSBP80FS4Q0P24DST209AJ@P80Jc4H0P1B:AP20?O6]@80ijf<
0P3WYI@20=j]U080kljm0P3ge[d30>o>_@80ilJ]0P3W[I`20;F4J`80aXA[0P3F_KD20>OFcP80Ng=c
0P1cJf<206=JDP80Q7]c0P2UNf/20<JLQ080_IAk0P3W[I`20=j]U080klJU103ge[d20>o>]@80klJ]
0P3W]I`20=jUQ080_IAk0P2eQ6/20<J4J`80aYb40P2]@S420=k6aP80knOW0P2<Lf<209AcFP80Nf]J
0P2DS8@206]SFP80_IbD0P2LLe8208a[DP80]HA[103FYH@20=j]U080gZf<0P3FYH`20=JLN`80eYac
0P2eQ6/20:ecDP80W6]:0P24DS4207=:<@80FS4Q0P0Y40P2048Q6080Q58i0P2<FT8207=2:@80W6]:
0P2eQ6/20;F4H`80W6]:0P2UNeX20:eS@P80gZf<0`24BRT20;fDN`@0eZf<6P3gmoL20?O_m`H0moOg
0P3gkoLF0?Ogma00oooo000>0?oooaH0moOg0P3gkoL80?Ogm`80]HA[0P2mW8`209acDP80S6=:0P1J
<B4208AB>@80U5Y20P1[<AP2058Y6080mlJe0P3W[H`20>NUU080gZfD0P3_c[d20?OF_@<0kljm0P3W
aZd20>N]W080]HA[0P36Q6/20=Jm]@80imK>0P1kLg<207=[H`80HeYB0P24Ng<20:EkJ`80aYb40P2m
U7/20>N]W080gZfD0P3_aZD40?OF_@80klje0P3_aZd20>NeW080gZF40P2mU7/20;F4J`80aXA[0P36
W8@20:e2<@80g/K60P3_inL208acH`80U7=J0P1kJeX209B<Q080Jf=J0P2mW9@209acDP80S6]B0P2e
Q6/40=JUQ080gZfD0P3N[H`20=JUS080eYak0P3FW7<20;F4J`80[G=B0P2LJdX208AB<@80LdXa0P1J
<B4202T@2080@R4H0P24DST208aJ@P80Ld8Y0P2LJdX20;F4J`80]HAS0P2LJdX20:EkFP80[F=20P3N
[H`308A::@80_IAk103F[H`J0?Ogm`80mnog1P3gmoL20?O_maH0moOg403oool000h0oooo403gmoL2
0?O_m``0moOg0P3oool20?O_m`80YHA[0P24DS4207]::@80FS4Q1P24DST209AJ@P80mlJe0P3NYH@2
0>N<N`80gZfD0P3Wa[D20>o>]@<0klJ]0P3N[I`20;fDN`80U7=J0P1J>BT20;FDS080a[Fe0P2DNf/2
0;Fe_@808APH0P24Lf/205Y:@P80U7=J0P2eQ6/20;fDN`80ikFL0P3_cZd40?OF_@80mlje0P3_aZd2
0>NmW080ikFD0P2mU7/20;F<L`80W7=B0P2eS7<20;fDN`80W6]:0P3>a[d206=JDP80]Kg>0P0Q61P2
07=cJ`80HeYB0P2mW9@2048a:@80Le920P2UNf<20;F<L`80_IAk0P3FYH@20=JUS080eZF40P2mU7/2
0<JDJ`80aXAS0P2]Le8209AJ@P80Q58i0P24BS42048Q6080>AP@0P128AP2058Y6080Q58i0P1cBS42
0:ecDP80W7=B102UNeX20;EkFP80[F=20P3F[H@308A::@80_HaS0P3FW7/20=k6]CX0moOg403oool0
00h0oooo403gmoL20?O_m``0moOg0P3oool20?O_m`80YHA[0P24DS4207]::@80FS4Q1P24DST209AJ
@P80mlJe0P3NYH@20>N<N`80gZfD0P3Wa[D20>o>]@<0klJ]0P3N[I`20;fDN`80U7=J0P1J>BT20;FD
S080a[Fe0P2DNf/20;Fe_@808APH0P24Lf/205Y:@P80U7=J0P2eQ6/20;fDN`80ikFL0P3_cZd40?OF
_@80mlje0P3_aZd20>NmW080ikFD0P2mU7/20;F<L`80W7=B0P2eS7<20;fDN`80W6]:0P3>a[d206=J
DP80]Kg>0P0Q61P207=cJ`80HeYB0P2mW9@2048a:@80Le920P2UNf<20;F<L`80_IAk0P3FYH@20=JU
S080eZF40P2mU7/20<JDJ`80aXAS0P2]Le8209AJ@P80Q58i0P24BS42048Q6080>AP@0P128AP2058Y
6080Q58i0P1cBS420:ecDP80W7=B102UNeX20;EkFP80[F=20P3F[H@308A::@80_HaS0P3FW7/20=k6
]CX0moOg403oool000h0oooo7P3gmoL20;FDN`80e/K60P2US7<209AcFP80Ne920P1cBS4408AB>@80
U5Y20P3>Lf<20>neW080ihak0P3FW7/20=j]S080klJe0P3_c[D30>NeW080cZFD0P36Q6/207=:<@@0
Q6=B0P1J@ST2048Y8@80FSTY0P24DST208a[DP80Q6=B0P2UNf<20;fDN`80ijfD0P3__I`40?O>]@80
mmJm0P3gc[D20>o6[@80kkfL0P3W]I`20=jUQ080_IAk0P36Q6/20:ecDP80U7=J102US8@205Xi:@80
DRTH101J>BT207=:<@80FT8i0P1cFTX207]B@P80YG]S0P2eQ6<20;F4J`80cYA[103FW7/20;fDN`80
]HA[0P2eNeX209AJ@P@0S5Y20P1cBS4206/i8@80@R4H0P1J>BT406/i8@80LdXa0P2LJdX20:ecDP80
W6]:0P2LHcT20;EkFP80[G=B0P3F[H@309AS@P80_HaS0P3FW7<20>oWgRX0moOg0P3gkoL>0?Ogma00
oooo000>0?oooah0moOg0P2eU7/20=K6aP80YHac0P2DLeX207]B@P80LdXa1024DST209AJ@P80cW=S
0P3_]I`20>N<N`80eYak0P3N[H`20>o6]@80klje0`3W]I`20<jUU080aXA[0P1cBS4408ASDP80FT8i
0P12:B4205Xi:@80Q58i0P2<Je8208ASDP80YG]S0P2mU7/20>N]U080kkfL103gc[D20?OF_@80mlje
0P3_aZd20>nmW080ikFL0P3NYH@20;fDN`80aXA[0P2]Le8209AcFP@0YHb40P1J>BT2058Y60@0FSTY
0P1cBS4205Y2>@80LeY:0P1kDT820:EkH`80]HAS0P2eQ6/20<jDJ`@0eYak0P2mU7/20;F4J`80]G]J
0P2DFT8408aJ@P80LdXa0P1[>B42048Q6080FSTY101[>B4207=:<@80W6]:0P2]Le8209a[BP80W6<i
0P2eNeX20:ecDP80eZf40`2DHd820;f<H`80eYac0P3_imhZ0?Ogm`80mnog3P3gmoL@0?ooo`003P3o
ool80?Ogm`80mnog1P3gmoL20?O_m``0moOg0P2]Le820;fLU080]Ib<0P2<FT8207=:<@80S6=:0P24
DST207=:<@80S4Xa0P36Q6<20>NUU0@0eYak0P3N[H`20>o6]@80ilJe0`3WaZd20>NmY@80gZfD0P2m
U7/20;E[DP80S6=:1P1kDT8208AB>@80U7=J0P36Q6/20=JUQ080ikFL103_aZd20?O>]@@0mmJm0P3g
c[D40>o6[@80klJU0P3W]I@20=jUQ080eYak0P2mU7/20;F4J`80Q6=:0P2UNf<20:F4L`80W7][0P24
He8206=:@P80FT8i0P1cBS4209acDP80_HaS0P2eS7<20<J4J`80cYA[103FW7/20;fDN`80cYA[0P2m
S6<20;E[DP80U5Y20P2<FT8408AB>@80Ld8Y0P1B:AP205Xi:@@0FS4Q0P1c@RT209acDP80]G]J0P2L
Le8209aS>@80]G]J0P2mS6<20=J]Q0<0W6]:0P2mS6<20=JUQ080knoW>P3gmoL@0?ooo`003P3oool8
0?Ogm`80mnog1P3gmoL20?O_m``0moOg0P2]Le820;fLU080]Ib<0P2<FT8207=:<@80S6=:0P24DST2
07=:<@80S4Xa0P36Q6<20>NUU0@0eYak0P3N[H`20>o6]@80ilJe0`3WaZd20>NmY@80gZfD0P2mU7/2
0;E[DP80S6=:1P1kDT8208AB>@80U7=J0P36Q6/20=JUQ080ikFL103_aZd20?O>]@@0mmJm0P3gc[D4
0>o6[@80klJU0P3W]I@20=jUQ080eYak0P2mU7/20;F4J`80Q6=:0P2UNf<20:F4L`80W7][0P24He82
06=:@P80FT8i0P1cBS4209acDP80_HaS0P2eS7<20<J4J`80cYA[103FW7/20;fDN`80cYA[0P2mS6<2
0;E[DP80U5Y20P2<FT8408AB>@80Ld8Y0P1B:AP205Xi:@@0FS4Q0P1c@RT209acDP80]G]J0P2LLe82
09aS>@80]G]J0P2mS6<20=J]Q0<0W6]:0P2mS6<20=JUQ080knoW>P3gmoL@0?ooo`003P3ooolH0?Og
m`80mnog103gmoL20>oWgP80YHak0P2DJe8207=:<@80Ld8Y101cBS4206/i8@80W6]:0P36Q6<20<jD
J`80aYb40P2mU7/20=JUS080ilJe1@3_c[D20?OF_@80kljm0P3_aZd20>o6]@80ikfU0P3W]I`20>N]
W080ikFL0P3W_JD20>NeW080eYak0P3NYH@20>N]U080klJU0P3ge[d20?O>]@@0kmK60P3ge[d20?O>
]@80klj]0P3_aZd20>NeU080eYac0P3NW7/20;fDN`80eZF40P3FYH`20=JUQ0H0_IAk0P3>U6/20=JL
N`@0eZF40P3N[H`20>N]S080gZfD0P3FYH`20=JUQ080eYak0P3>U6/20<J4J`80_HaS0P2eNeX209AJ
@P80S6=:0P24DST406/i8@80DRTH0P1J>BT207=:<@80Ld8Y0P1[>B4209a[BP80_HaS0P2LJdX209aS
>@80aXAJ0P2mU7/20=j]U0<0W7=B0P2mU7/20>oNcP80oooo=P3gmoL20?O_m`80moOg403oool000h0
oooo603gmoL20?O_m`@0moOg0P3_imh20:F<N`80U6]B0P1cBS4207=2:@@0LdXa0P1[>B4209a[BP80
aXAS0P3>U6/20<JLQ080_IAk0P3FYH`20>O6]@D0klje0P3ge[d20>o>_@80klJ]0P3_a[D20>NmY@80
ikFL0P3W[I`20>NeW080ikfU0P3W]I`20=JLN`80gZF40P3W[I@20>o6Y@80mmJm0P3gc[D40>oFaP80
mmJm0P3gc[D20>o>[@80klJ]0P3W]I@20=JLL`80gYak0P2mU7/20=JUQ080eZF<0P3FYH@60;fDN`80
cYA[0P3FW7/40=JUQ080gZf<0P3W[H`20=j]U080eZF<0P3FYH@20=JLN`80cYA[0P36Q6/20;f<H`80
]G]J0P2DFT8208aSBP80Q58i101[>B42058Y6080FSTY0P1cBS4207=2:@80JcTQ0P2LJdX20;f<H`80
W6]:0P2LHcT20<J4FP80_IAk0P3N[I@309acDP80_IAk0P3_g/h20?ooocH0moOg0P3gkoL20?Ogma00
oooo000>0?ooo`@0moOg0P3gkoL40?Ogm`80mnog2P3gmoL20?O_m`@0moOg103oool207=2:@80S5Y2
0P1J<B4406/i8@80U6=20P1J<B4209a:<@80]F]B0P3NQ7<20<jDJ`80]Hac0P3FYH@20>o>]@80ikfU
0`3gc[D40?OF_@80kmK6103ge[d20>oFaP80ijFD0P36Q6/20:EkH`80W7=B0P2eJe820>NeW080klJU
1P3ge[d20?ONcP80kmK60P3ge[d20>oFaP80mlje0P3ge[d20>nmW080ijfD0P36Q6/20:eS@P80W7=B
0P2eJe820;F<L`80ikfU0P3WaZd20>o6[@80ilJ]103W_JD60>NeW080gZfD0P3FYH@20<JDJ`80]HAS
0P3>U6/20;f<H`80]G]J0P2]Le8209a[BP80S5Y20P24DS4208AB>@80HbT@101B:AP205Xi:@80DR4@
0P1cBS4208aJ@P80[G=B0P2LJdX209AS@P80aXaS0P36U6/20>NmW0<0YG]J0P36W8@20>oWic`0moOg
403oool000h0oooo103gmoL20?O_m`@0moOg0P3gkoL:0?Ogm`80mnog103gmoL40?ooo`80Ld8Y0P2<
FT8205Xa8@@0JcTQ0P2DHd8205Xa8@80W4Xa0P2eJe820=j4L`80cYA[0P2eS7<20=JUQ080klje0P3W
_JD30?O>]@@0mmJm0P3_e/H40?OF_@80kmK60P3WYI@20<J4J`80YG]S0P2LLe820;E[DP80ikFL0P3_
aZD60?OF_@80mmk>0P3_e/H20?OF_@80kmK60P3gc[D20?OF_@80kkfL0P3W[I@20<J4J`80[F=20P2L
Le820;E[DP80]Hac0P3W_JD20>O6[@80klJ]0P3WaZd40>NmY@H0ikFL0P3N[I@20=JUQ080aYA[0P2e
Q6<20<jDJ`80_HaS0P2eNeX20:ecDP80W6]:0P2<FT8208AB<@80Q58i0P1S:A04058Y6080FSTY0P1B
8A0207=:<@80S5Y20P2]Le8209a[BP80U6=20P36S6<20<JDJ`80ikfL0`2UNeX20<JLQ080knOW?03g
moL@0?ooo`003P3ooolL0?Ogm`80knOW0P3oool206/i8@80NdXY0P1J<B4206/i8@80LdXa0P24DST2
07=:<@80W6<i0P2eHd820;EkFP80_HaS0P36Q6/20<JLQ080klJ]0P3Na[D30>NmW080klJe0P3ge[d4
0>oFaP80mlJe0P2eQ6/20:EkH`80U7=J0P2eJe820=JUQ080klJU103gc[D20?OF_@80mmk>0P3ge[d2
0?ONcP80kmK61P3ge[d40?O>]@80klJU0P3W[I@20;f<H`80U5Y20P24DST209AJ@P80]F]B0P3NYH@2
0>N]W080ilJ]103_aZd20>neW080ikfU0P3N[I@20=jUQ080_IAk0P2UNeX20<jDJ`80]Hac0P2eQ6/2
0:ecDP@0W6]:0P2<FT8406/i8@80DRTH0P1J<B42058Y6080DR4@0P1cDT8208AJ@P80U6]B0P2UNeX2
09acDP80U5Xa102mS6<20=J]S0<0_IAk0P36W8@n0?Ogma00oooo000>0?oooa`0moOg0P3_inL20?oo
o`80JcTQ0P1kBRT205Xa8@80JcTQ0P1cBS4208AB>@80LdXa0P2LHcT20;ES@P80]G]J0P2mS6<20<J4
J`80aYb40P3_aZd20=k6]@<0ikfL0P3_a[D20?OF_@@0kmK60P3ga[D20;F4J`80YG]S0P2DLeX20;E[
DP80eZF40P3_aZD40?O>]@80mmJm0P3gg/h20?OF_@80mmk>0P3_e/H60?OF_@@0mlje0P3_aZD20>N]
U080_HaS0P2DFT8208AB>@80U5Y20P2eJe820=jUQ080ijfL0P3WaZd40>o6[@80kkFL0P3W_JD20=j]
U080gZF40P2mU7/20:EkFP80cYA[0P2eS7<20;F4J`80[G=B102LJdX208aJ@P@0JcTQ0P1B:AP205Xa
8@80DRTH0P1B8A0207=B@P80Q5Y20P2DJe820:EkFP80W7=B0P2DFS440;f<H`80eZf<0`2mU7/20<JL
Q3h0moOg403oool000h0oooo5P3gmoL20?O_m`80moOg0P3oool20;f][@80oooo0P24DS4207=2:@@0
LdXa0P1J<B4208AB>@80NdXY0P2DFS4409AJ@P80YG]S0P2eQ6/20<JLQ080ilJe0P3_c[d30;fDN`80
aYb40P3FYH@20=JLN`80gXAc0P2eJe820:ecDP80eYak0P3gc[D40?OF_@`0mmk>203_e/H20?OF_@80
kmK61P3gc[D20>o>[@80ikFL0P3FYH@20;F<L`80U7=J0P2<FT8209acDP80[F=20P3>JeX20;F<L`80
aXA[0P2eQ6<20:EkH`80YG]J0P2eQ6/40;fDN`80gXAc0P2mS6<20:ecDP@0W6]:0P24DST209a[BP80
@R4H101c@RT206/i8@80DRTH0P12:B4208ASBP80W6]:0P2]Le8209a[BP80U6=20P2mS6<20=JLL`80
]HA[0`2]Jd820=k>_B80moOg0P3gkoLJ0?Ogma00oooo000>0?oooaH0moOg0P3gkoL20?Ogm`80oooo
0P2m[Jd20?ooo`80Q58a0P1c@RT407=:<@80FS4Q0P24DST207]::@80U5Xa102DFT820:EkH`80]HA[
0P36W8@20>O6]@80kljm0`2mU7/20<JLQ080eZF40P3FW7/20=j4L`80]F]B0P2]Le820=JLN`80mlje
103ge[d<0?ONcPP0kmK60P3ge[d20>oFaPH0mlje0P3_cZd20>NeW080eZF40P2eS7<209AcFP80S5Y2
0P2LLe820:eS@P80cV]J0P2eS7<20<J4J`80]HAS0P2UNf<20:EkFP80]HA[102mU7/20=j4L`80_HaS
0P2]Le8409a[BP80Q58i0P2LJdX2048Q60@0Ld8Y0P1[>B42058Y6080@RTQ0P24HdX209a[BP80[G=B
0P2LJdX209AS@P80_HaS0P3FW7<20;F4J`<0[F]20P3Nc[dR0?Ogm`80mnog6P3gmoL@0?ooo`003P3o
oolF0?Ogm`80mnog103gmoL20<JUU080W7=B101cBS4208ASBP80Q58i1P1cBS4208AB>@80U5Xa0P2<
HdX209acDP80YG]J0P3FYH@20>O6]@D0klje0P3_aZd20=JUQ080_Ib<0P3NQ7<20=j]W080kmK64P3g
g/h20?ONeP@0kmK61P3gg/h40?OF_@80kmK60P3ge[d20?O>]@80mlJe1P3_aZd40>O6[@80aYb40P2U
Nf<20:ecDP@0YG]S0P2mU7/20<JLQ080_IAk0P3>U6/20=JLL`80cYA[0P2mS6<20:ecDP80W7=B0P2]
Le8208AB>@80JcTQ0P1cBS4206/i8@80FS4Q100i6102048Q6080S6=:0P2DLeX208aJ@P80YG]J0P2]
Hd820<JDJ`80aYb40P2LJdX30;f<H`80knOW9P3gmoL20?O_maH0moOg403oool000h0oooo5P3gmoL2
0?O_m`@0moOg0P36YI@209acDP@0LdXa0P24HdX208AB>@H0LdXa0P24DST209AJ<@80S6=:0P2LLe82
0:EkFP80eZF40P3Wa[D50>o>]@80klJ]0P3FYH@20;fLS080gXAc0P3N[I`20>oFaQ80mmk>0P3gg]H4
0>oFaPH0mmk>103ge[d20>oFaP80mmJm0P3gc[D20?O6]@H0klJ]103WaZd20<JLQ080YG]S0P2]Le84
0:EkH`80_IAk0P36W8@20;fDN`80cYA[0P3FW7<20<jDJ`80_HaS0P2]Le8209acDP80[G=B0P24DST2
06/i8@80LdXa0P1[>B4205Xa8@@0>AP@0P128AP208aSBP80U7=J0P2<FT820:EkFP80[F=20P36U6/2
0<JLQ080W6]:0`2mS6<20>oWibH0moOg0P3gkoLF0?Ogma00oooo000>0?ooo`P0moOg0P3gkoL60?Og
m`80mnog2P3gmoL20=K6aP80W6]:0P1kFT8207=:<@80W7][0P2<Je8207]J@P80Q58i0P1cBS4408aJ
@P80S6=:102]Le820=JLN`80klJ]0P3_a[D50>o>]@@0mmJm1P3_e/H>0?ONcP80mmkF103gg/h20>oF
aPH0mmk>2P3_e/H20?OF_@@0klje0P3gc[D60>o6[@80ikfU103WaZd20>NeW080gZfD0P3N[H`20=JU
S080eYak0P3FYH@20;fDN`80]Hac0P2eNeX20:ecDP80YG]J0P2]Le8209a[BP80LdXa0P1[>B42058Q
40H0>AP@0P128AP20;F<L`80S6=:0P2<FT820=JLL`80W6]:0P2eNeX20=J]Q080W6]:0`36W8A00?Og
ma00oooo000>0?ooo`P0moOg0P3gkoL60?Ogm`80mnog2P3gmoL20=K6aP80W6]:0P1kFT8207=:<@80
W7][0P2<Je8207]J@P80Q58i0P1cBS4408aJ@P80S6=:102]Le820=JLN`80klJ]0P3_a[D50>o>]@@0
mmJm1P3_e/H>0?ONcP80mmkF103gg/h20>oFaPH0mmk>2P3_e/H20?OF_@@0klje0P3gc[D60>o6[@80
ikfU103WaZd20>NeW080gZfD0P3N[H`20=JUS080eYak0P3FYH@20;fDN`80]Hac0P2eNeX20:ecDP80
YG]J0P2]Le8209a[BP80LdXa0P1[>B42058Q40H0>AP@0P128AP20;F<L`80S6=:0P2<FT820=JLL`80
W6]:0P2eNeX20=J]Q080W6]:0`36W8A00?Ogma00oooo000>0?ooo`@0moOg0P3gkoL80?Ogm`80mnog
303gmoL20<jeY@80Q4XY0P1cDT8208AJ@P80YHac0P2DJe8208AB>@80Q5Y20P1kFT8408AJ@P80S5Y2
0P2UNeX209acDP80eYak0P3WaZd50>o>]@80kljm103ge[d20>oFaP@0mmk>0P3_e/H20?OF_@H0mmk>
0P3ge[d80?ONcP80mmJm0P3_e/H20?ONcP@0kmK60P3gg/h20>oFaPP0mmJm0P3ga[D20?O>]@80klJe
0P3_aZd20>O6[@80ikfU0P3_aZd40>NeW080gZfD103FYH@40=JLN`80_IAk0P36U6/20;f<H`80]F]B
102]Le8208aJ@P80W6]:0P1c@RT4058Y6080@R4H0P1J<B42058Q4080_IAk0P2UNeX208aJ@P80_IAk
0P2]Le8209a[BP80eZf<0P2LJdX30=Jm[@80oooo?P3gmoL@0?ooo`003P3oool40?Ogm`80mnog203g
moL20?O_m``0moOg0P3>]JD208A::@80Le920P24FT820:F<L`80U6]B0P24DST208AJ@P80NeY21024
FT8208aJ@P80YG]J0P2LLe820=JLN`80ilJ]1@3_c[D20>o>_@@0mmJm0P3_e/H40?ONcP80kmK60P3g
e[d60?ONcP80mmJm203gg/h20?OF_@80kmK60P3gg/h40>oFaP80mmk>0P3_e/H80?OF_@80mlJe0P3g
c[D20>o6]@80klJ]0P3WaZd20>NmY@80klJ]103W]I`20=j]U0@0eZF4103FW7/20;fDN`80aYA[0P2m
S6<20;E[DP@0[G=B0P2<FT8209a[BP80Ld8Y101B:AP2048Q6080FS4Q0P1B8A020;fDN`80YG]J0P2<
FT820;fDN`80[G=B0P2LJdX20=J]S080W6]:0`3F_Jd20?oooch0moOg403oool000h0oooo703gmoL2
0=k>aP80Q58i0P2<Je8208aSBP80W7=B0P2<HdX208a[DP80S6=:0P24FT8208AB>@@0Q58a0P2LJdX2
09acDP80aXA[0P3W_I`20>o6]@D0klje0P3_c[d40?OF_@80kmK6103gg/h20?OF_AX0mmk>1P3_e/H:
0?O>]@80klJ]0P3_aZD20>O6[@80klJ]0P3W_JD20>NmW080ikFD0P3N[I@20=j]S080eZF<0P3FYH@2
0=JLN`80eYac0P3>U6/20;EkFP80[G=B0P2eNeX209acDP80W6]:0P1cBS4205Xa8@80JcTQ0P1J<B44
03TH4080@R4H0P36U6/20:EkH`80W6]:0P3FW7<20;EcBP80S6=:0P2mU7/209a[BP<0mnog@03gmoL@
0?ooo`003P3ooolL0?Ogm`80g/k60P24DST208a[DP80S6=:0P2LLe8208aSBP80S6]B0P2<HdX208AJ
@P80Q58i1024DS4209a[BP80W7=B0P36Q6/20>NmW080klJe1@3_c[D20>o>_@@0mmJm0P3_e/H40?ON
cP80mmJm6P3gg/h60>oFaPX0mlje0P3_aZd20>o6Y@80ilJ]0P3_aZd20>NmY@80ikfL0P3W]I@20=j]
U080gZf<0P3FYH`20=JUQ080eYak0P3FW7<20<jDJ`80]G]J0P2]Le820;EkFP80W7=B0P2LJdX207=:
<@80FS4Q0P1[>B4205Xa8@@0>AP@0P128AP20<JDJ`80YG]S0P2LJdX20=JLL`80]G=:0P2<HdX20;fD
N`80W6]:0`3gkoM00?Ogma00oooo000>0?ooo`X0moOg0P3gkoL@0?Ogm`80mnog0P2<HdX608AB>@80
Q6=:0P2<HdX208AB>@80Q5Y20P24DST208AJ@P80Q58i0P2UNeX20;EkFP80aYA[0P3W]I`20>NmY@<0
klj]0P3_c[d20?O>]@@0mmJm103_e/H:0?ONcP@0mmJm2P3gg/h:0>oFaP80mlJe1P3gc[D20>o>[@H0
klJ]0P3_]I`20>NmY@80ikfL0P3W_JD20>NeW080gZf<0P3N[I@20=jUQ080eZF40P2mU7/20<jDJ`80
aXA[0P2mS6<20;EkFP80[G=B0P2LJdX208AB>@80LdXa0P1J>BT207=2:@80@R4H100i610205Xa8@80
W7=B0P3FW7<20;F4H`80eYak0P2eNeX209acDP80U6=20P3>[I@Y0?Ogm`80mnog603gmoL@0?ooo`00
3P3oool:0?Ogm`80mnog403gmoL20?O_m`80S6=:1P24DST208ASBP80S6=:0P24DST208AJ@P80Q58i
0P24FT8208AB>@80YG]J0P2eNeX20<JDJ`80ikFL0P3W_JD30>o>[@80kljm0P3gc[D40?OF_@@0kmK6
2P3gg/h40?OF_@X0mmk>2P3_e/H20?O6]@H0mlje0P3_cZd60>o6[@80kkFL0P3W_JD20>NmW080ikfU
0P3W]I`20=j]S080gZfD0P3NYH@20=JUQ080_IAk0P3>U6/20<J4J`80_HaS0P2eNeX20:ecDP80W6]:
0P24DST207=:<@80FSTY0P1c@RT2048Q60@0>AP@0P1J<B4209acDP80eYac0P2eQ6<20=JLN`80]G]J
0P2LLe8209AS@P80cZfD:@3gmoL20?O_maP0moOg403oool000h0oooo703gmoL20?ooo`80Ne920P2<
Je8208AB>@80S6=:0P2<Je8209A[DP80S6=:1024FT8208AB>@80S6=:0P2LLe820;f<H`80_IAk0P3N
[H`20>NmY@<0klje0P3_c[d80?OF_@@0mmk>103ge[d40?ONcP80mmJm103gg/h20>oFaPH0mmk>1P3_
e/H80?OF_@@0mlje0P3_cZd60>o6[@80kkFL203W]I`20>N]U080gZf<0P3FYH`20=JUQ080eYak0P3>
U6/20;F<L`@0]HAS0P2UNf<209a[BP80S5Y20P1[>B4207=:<@80DR4@10128AP203TH4080@RTQ0P2D
LeX20;fDN`80W7=B0P36U6/20;f<H`80YHA[0P2DHd820>O>aT<0moOg403oool000h0oooo703gmoL2
0?ooo`80Ne920P2<Je8208AB>@80S6=:0P2<Je8209A[DP80S6=:1024FT8208AB>@80S6=:0P2LLe82
0;f<H`80_IAk0P3N[H`20>NmY@<0klje0P3_c[d80?OF_@@0mmk>103ge[d40?ONcP80mmJm103gg/h2
0>oFaPH0mmk>1P3_e/H80?OF_@@0mlje0P3_cZd60>o6[@80kkFL203W]I`20>N]U080gZf<0P3FYH`2
0=JUQ080eYak0P3>U6/20;F<L`@0]HAS0P2UNf<209a[BP80S5Y20P1[>B4207=:<@80DR4@10128AP2
03TH4080@RTQ0P2DLeX20;fDN`80W7=B0P36U6/20;f<H`80YHA[0P2DHd820>O>aT<0moOg403oool0
00h0oooo703gmoL20?ooo`80W7][0P1cDT8208aJ@P@0U6]B0P24FT8208aSBP80Q58i0P1kFT8209A[
DP80S6=:0P2LLe820;F4J`80aYA[0P3FYH`20>NmY@<0klJ]1P3gc[D60?OF_@@0mmk>0P3_e/H20?OF
_@@0mmk>0P3_e/H20?OF_@80mmk>0P3ge[d40>oFaP80mmJm0P3_e/H60?OF_@80mlje0P3ge[d40?O>
]@80klJ]0P3gc[D20>o6[@@0klJU0P3W_JD20>NmW080ikfU0P3W]I@20=j]U080gZf<0P3FYH`20=JU
Q080_IAk0P3>U6/20<J4J`@0]HAS102LJdX208aJ@P80LdXa0P1[>B42058Q4080>AP@100Y40P207]B
@P80S6=:0P2UNeX20:ecDP80aYb40P36U6/20=J]S080aYA[A@3gmoL@0?ooo`003P3ooolL0?Ogm`80
oooo0P2LNf/207=B@P80S5Y2102DJe8208AJ@P80S6=:0P24DST207]J@P80U6]B0P2<HdX209acDP80
]HA[0P36U6/20=JUS080ikfU0`3_aZd60?O>]@H0mmJm103gg/h20>oFaP80mmJm103gg/h20>oFaP80
mmJm0P3gg/h20?OF_@@0kmK60P3ge[d20>oFaPH0mmJm0P3gc[D20?OF_@@0mlje0P3_aZd20?O>]@80
klJ]103_aZD20>NmY@80ikfL0P3W_JD20>NeU080gZfD0P3N[H`20=JUS080eZF40P2mU7/20<jDJ`80
aXA[102eQ6<409a[BP80S5Y20P1cBS4206/i8@80DR4@0P0i610402T@2080Ne920P2<HdX20:EkFP80
[G=B0P36W8@20<JDJ`80eZf<0P36U6]50?Ogma00oooo000>0?oooa`0moOg0P3oool208AB>@80YG]S
0P2UNeX208aJ@P80S6=:0P24HdX208aJ@P80Q5Y20P2LHcT207=2:@80S6=:0P2UNf<20;f<H`80]Hac
0P3FYH@20>NmW0<0klJ]0P3_c[D20?O>]@H0mmJm103gg/h20>oFaPH0mmk>0P3ge[d20?ONcP80mmJm
0P3_e/H20?ONcP80mmJm103_e/H20?OF_@@0kmK6203ge[d20>o6[@80mlJe0P3_cZd40>o6[@80kkFL
0P3_aZD40>NeW0@0gZfD0P3N[H`20=JUS080eZF40P2mU7/20=JLL`80]Hac0P2eQ6/209acDP80U6]B
0P24FT8207=:<@80Q58i0P1J<B4203TH4080:A080P12:B4202T@2080Q6=:0P2DJe8209a[BP80U6=2
1036U6/20<JLQ080imkFA@3gmoL@0?ooo`003P3ooolL0?Ogm`80oooo0P24DST20:EkH`80YG]J0P2<
FT8208aSBP80Q6=:0P2<FT8208AJ@P80W6<i0P1c@RT208aSBP80YG]S0P2mS6<20;F<L`80eZF40P3W
_I`30>o6[@80klje0P3gc[D60?OF_@@0mmk>0P3_e/H60?ONcP80mmJm0P3gg/h20?OF_@80kmK60P3g
g/h20?OF_@@0kmK60P3ge[d40>oFaPP0mmJm0P3_aZd20?O6]@80klj]103_aZd20>neW080klJU103W
]I`40=j]U080gZf<0P3FYH`20=JUQ080_IAk0P3FW7<20;F<L`80]HA[0P2LLe8209A[DP80Q5Y20P1c
BS4208AB>@80FS4Q0P0i610202T@2080@RTQ0P0Y40P208ASBP80U6]B0P2LJdX209AS@P@0aYA[0P36
W8@20>ONeTD0moOg403oool000h0oooo103gmoL20?O_m`80moOg0P3gkoLD0?Ogm`80imkN0P2UNf<4
07]J@P@0Q58i0P24DS4208AJ@P80Q58i102<HdX20:EkFP80]Hac0P36W8@20=JUS080ikfL0`3_aZd2
0>o>]@@0mmJm0P3_e/H20?OF_@@0mmk>0P3ge[d20?ONcP80mmJm0P3gg/h20?OF_@80kmK60P3ge[d2
0?ONcP80mmJm103_e/H80?OF_@80kmK6103ge[d20?O6]@@0mlje1P3_aZd20>neW080klJU103W]I`2
0=j]U0H0gZf<0P3FYH@20<JLQ080eYak0P2eQ6/20:EkH`@0W7=B0P2LJdX207]J@P80JcTQ0P1J<B44
03TH4080@RTQ0P0i610409A[DP80W7=B0P2LHcT20<JDJ`80aYb40P3FYHa70?Ogma00oooo000>0?oo
o`@0moOg0P3gkoL20?Ogm`80mnog503gmoL20>ONgP80YG]S101kFT8408AB>@80Q58a0P24FT8208AB
>@@0S6=:0P2UNeX20;F<L`80aYb40P3FYH`20>NmW0<0klJ]0P3_c[D40?OF_@80kmK60P3ge[d40?ON
cP80mmJm0P3gg/h20?OF_@80mmk>0P3ge[d20>oFaP80mmJm0P3gg/h20?OF_@@0kmK6203ge[d20>oF
aP@0mmJm0P3ga[D40?O>]@H0klJ]0P3_]I`20>o6Y@@0ikFL0P3N[I@60=j]S080eZF40P36W8@20=JL
N`80]HA[0P2UNf<409acDP80W6]:0P1kFT8206/i8@80FS4Q100i6102048Y8@80>AP@102DJe8209ac
DP80W6<i0P36U6/20<JLQ080eZF<A`3gmoL@0?ooo`003P3ooolN0?Ogm`80oooo0P2<HdX207]J@P80
Q58i0P1cBS4208AB<@80Le920P1cBS4207]J@P80S6=:0P2LJdX20;F4H`80]Hac0P3FW7/20=J]S080
ikfL0`3_aZd20?O>]@80mlJe0P3ge[d20>oFaPP0mmJm0P3_e/H80?ONcP@0kmK60P3gg/h@0?OF_@80
mlJe1P3gc[D20>o6[@80mlje0P3_aZd40>o6Y@80kkfL0P3W]I`20=j]U080gZf<0P3FYH`20=j]S0@0
eZF40P2mU7/40;F4J`80YG]S0P2<HdX208aJ@P80JcTQ0P1J<B44048Q6080:A080P0i8AP203TH4080
W7]S0P2DJe8209aS>@80U6=20P36W8@20<jeY@80g/k6A`3gmoL@0?ooo`003P3ooolN0?Ogm`80oooo
0P2<HdX207]J@P80Q58i0P1cBS4208AB<@80Le920P1cBS4207]J@P80S6=:0P2LJdX20;F4H`80]Hac
0P3FW7/20=J]S080ikfL0`3_aZd20?O>]@80mlJe0P3ge[d20>oFaPP0mmJm0P3_e/H80?ONcP@0kmK6
0P3gg/h@0?OF_@80mlJe1P3gc[D20>o6[@80mlje0P3_aZd40>o6Y@80kkfL0P3W]I`20=j]U080gZf<
0P3FYH`20=j]S0@0eZF40P2mU7/40;F4J`80YG]S0P2<HdX208aJ@P80JcTQ0P1J<B44048Q6080:A08
0P0i8AP203TH4080W7]S0P2DJe8209aS>@80U6=20P36W8@20<jeY@80g/k6A`3gmoL@0?ooo`003P3o
oolP0?Ogm`80c[Fe0P24HdX408AB>@80Q58a1024DST207=B@P80Q58i0P2LJdX20:EkH`80]Hac0P36
W8@20=j]W080ikfU0`3_aZd40?O>]@80mmJm103_e/H20?ONcP80kmK62P3gg/h20>oFaP80mmk>0P3g
e[d20>oFaP80mmk>0P3_e/H20?OF_@80kmK6203ge[d20?O>]@80mmJm0P3gc[D20?O6]@80klj]103_
aZd40>o6Y@@0ikFL0P3N[I`40=j]S080eZF40P3FYH`40<jDJ`80_HaS0P2UNf<20:EkFP80W7=B0P2<
FT8205Xi:@80FS4Q0P128AP2048Y8@80<APH10128AP20:EkH`80]HA[0P2<FT820:ecDP80aYA[0P3W
_I`40?Ogm`80mnog@`3gmoL@0?ooo`003P3ooolP0?Ogm`80c[Fe0P24HdX408AB>@80Q58a1024DST2
07=B@P80Q58i0P2LJdX20:EkH`80]Hac0P36W8@20=j]W080ikfU0`3_aZd40?O>]@80mmJm103_e/H2
0?ONcP80kmK62P3gg/h20>oFaP80mmk>0P3ge[d20>oFaP80mmk>0P3_e/H20?OF_@80kmK6203ge[d2
0?O>]@80mmJm0P3gc[D20?O6]@80klj]103_aZd40>o6Y@@0ikFL0P3N[I`40=j]S080eZF40P3FYH`4
0<jDJ`80_HaS0P2UNf<20:EkFP80W7=B0P2<FT8205Xi:@80FS4Q0P128AP2048Y8@80<APH10128AP2
0:EkH`80]HA[0P2<FT820:ecDP80aYA[0P3W_I`40?Ogm`80mnog@`3gmoL@0?ooo`003P3oool20?Og
m`80mnog703gmoL20?O_m`80S6]B101cBS4407=B@P80Q58i0P1kFT8207=B@P80U6]B0P2eQ6<20;fD
N`80eZF40P3N[I@20>o6Y@<0klJ]0P3_a[D20>o>]@80mlje2P3ge[d20?ONcP80mmJm0P3gg/h20>oF
aP@0mmJm0P3_e/H20?OF_@@0kmK61P3ge[d20>oFaP@0mmJm103gc[D20>o>[@80mlje0P3ga[D60>o6
[@@0ikfU0P3W_I`20>NeU0@0gZf<0P3FYH`40=JLN`80]Hac0P2mS6<20:EkH`80W7=B0P2<HdX208AB
>@80FSTY0P1J<B42048Y8@80@R4H101B:AP203TH4080W6]:0P2eQ6<209a[BP80aXAJ0P3FYH@20=k>
cTT0moOg403oool000h0oooo0P3gmoL20?O_ma`0moOg0P3gkoL208a[DP@0LdXa101cDT8208AB>@80
NeY20P1cDT8209A[DP80]HAS0P2mU7/20=JUQ080gZfD0P3_aZD30>o6[@80klJe0P3_c[D20?O>]@X0
mmJm0P3gg/h20?OF_@80mmk>0P3_e/H40?OF_@80kmK60P3ge[d40>oFaPH0mmJm0P3_e/H40?OF_@@0
mlje0P3_cZd20?O>]@80mlJe1P3_aZd40>NmY@80ikfL0P3W]I@40=j]S080eZF<103FW7/20;F<L`80
_HaS0P2UNf<209acDP80S6=:0P24DST205Xi:@80FS4Q0P12:B42048Q60@0DRTH0P0i610209a[BP80
]HAS0P2LJdX20<J4FP80eZF40P3Nc/i90?Ogma00oooo000>0?ooob80moOg0P2UNf<208a[DP80Le92
0P24FT8207]J@P80Le920P1kFT8208AJ@P80U6]B0P2LLe820<JDJ`80eZf<103W_JD30>o6[@@0mlje
1P3ge[d40>oFaP@0mmk>0P3_e/H40?OF_@P0kmK6103ge[d20>oFaPP0mmJm1P3gc[D40>o>[@80klJ]
103_aZD20>o6[@80ikfU0P3W_I`20>NeU080ijfD103N[H`40=jUQ080cYA[0P2eS7<20;F4J`80[G=B
0P2LJdX208aJ@P80LdXa101J>BT2058Y6080@R4H0P1B:AP203TH4080:A080P2DJe8209acDP80W6]:
0P2mS6<20=j]S080knoWB@3gmoL@0?ooo`003P3ooolR0?Ogm`80YG]S0P2<Je8207=B@P80Q5Y20P1k
FT8207=B@P80NeY20P24FT8209A[DP80W7=B0P36U6/20=J]S0@0ikfU0`3_aZd40?O>]@H0mmJm103_
e/H40?ONcP80kmK6103ge[d80>oFaP@0mmJm0P3_e/H80?OF_@H0mlje103_cZd20>o6[@@0klJU0P3_
aZd20>NmY@80ikfL0P3W]I@20>N]U0@0gZf<103NYH@20<jDJ`80]Hac0P2eQ6/20:ecDP80W6]:0P2<
FT8207=:<@@0FSTY0P1B:AP2048Q6080DRTH0P0i610202T@2080U6]B0P2LLe8209a[BP80_HaS0P3N
[H`20>o_idT0moOg403oool000h0oooo8P3gmoL20?ooo`80c[Fe0P2UNf<609A[DP@0NeY20P2DJe82
0:F4J`80]Hac0P3FW7/20>NeW080klJU1@3_aZd20?O>]@80klje0P3gc[D80>oFaP@0mmJm0P3_e/H2
0?ONcP80mmJm0P3_e/H80?OF_@80mlje0P3ge[d80?O>]@80mmJm0P3ga[D20?O>]@P0klJU0P3_]I`2
0>NmY@80ikfL0P3W]I@20=j]U080ikFD1P3FYH@40;F<L`80YG]S0P2UNeX208aSBP80Q58i0P1c@RT2
07=:<@@0FS4Q0P128AP203TH40808A080P1J>BT20;F4J`80W7=B0P2eLdX20<jDJ`80cZfD0P3gmoL2
0?O_mdL0moOg403oool000h0oooo8P3gmoL20?ooo`80c[Fe0P2UNf<609A[DP@0NeY20P2DJe820:F4
J`80]Hac0P3FW7/20>NeW080klJU1@3_aZd20?O>]@80klje0P3gc[D80>oFaP@0mmJm0P3_e/H20?ON
cP80mmJm0P3_e/H80?OF_@80mlje0P3ge[d80?O>]@80mmJm0P3ga[D20?O>]@P0klJU0P3_]I`20>Nm
Y@80ikfL0P3W]I@20=j]U080ikFD1P3FYH@40;F<L`80YG]S0P2UNeX208aSBP80Q58i0P1c@RT207=:
<@@0FS4Q0P128AP203TH40808A080P1J>BT20;F4J`80W7=B0P2eLdX20<jDJ`80cZfD0P3gmoL20?O_
mdL0moOg403oool000h0oooo0P3gmoL20?O_ma80moOg0P3gkoL:0?Ogm`@0oooo0P3_inL209AcFP80
U6]B0P24FT8208aSBP80Q6=:0P2<HdX20:ecDP80_IAk0P36W8@20=j]U080klJU1@3_aZd40?O>]@@0
mmJm0P3gc[D40>oFaP`0mmJm0P3_e/H:0?OF_@H0mlje0P3ge[d20?O>]@P0klJ]0P3_aZD20>o6[@80
kkfL1P3W]I`20>NeU080gZf<0P3FW7/20=JUS0@0_IAk0P2mS6<20:ecDP80U5Y20P24DST208AJ@P80
Ld8Y101J>BT2048Y8@80DRTH0P0Q61P2024@2080YG]J0P2UNf<209AS@P80]G]J0P36S6<20>O>_D/0
moOg403oool000h0oooo0P3gmoL20?O_ma80moOg0P3gkoL:0?Ogm`@0oooo0P3_inL209AcFP80U6]B
0P24FT8208aSBP80Q6=:0P2<HdX20:ecDP80_IAk0P36W8@20=j]U080klJU1@3_aZd40?O>]@@0mmJm
0P3gc[D40>oFaP`0mmJm0P3_e/H:0?OF_@H0mlje0P3ge[d20?O>]@P0klJ]0P3_aZD20>o6[@80kkfL
1P3W]I`20>NeU080gZf<0P3FW7/20=JUS0@0_IAk0P2mS6<20:ecDP80U5Y20P24DST208AJ@P80Ld8Y
101J>BT2048Y8@80DRTH0P0Q61P2024@2080YG]J0P2UNf<209AS@P80]G]J0P36S6<20>O>_D/0moOg
403oool000h0oooo9P3gmoL20?ooo`80_IbD0P24DST208ASBP80Le92102<HdX20:EkFP80_HaS0P3F
W7/20=j]W080ikfU0`3_]I`40>o6[@80mlje103_cZd40?O>]@H0mmJm0P3gc[D60?OF_@80mlje0P3g
e[d20>o>]@80mlje0P3_c[d60?O>]@80klj]203_aZd20>o6Y@80klJ]103_aZD20>neW0H0ikFL103N
[I@20=JUS080eYak0P3FYH@20;F<L`80YG]S0P2LJdX209AS@P80S5Y21024FT8405Xa8@80DRTH0P0i
610202T@2080]HA[0P2LNf<209a[BP80U6=20P2mS6<20=JeY@80knOW0P3gmoL40?O_mdD0moOg403o
ool000h0oooo9P3gmoL20?ooo`80_IbD0P24DST208ASBP80Le92102<HdX20:EkFP80_HaS0P3FW7/2
0=j]W080ikfU0`3_]I`40>o6[@80mlje103_cZd40?O>]@H0mmJm0P3gc[D60?OF_@80mlje0P3ge[d2
0>o>]@80mlje0P3_c[d60?O>]@80klj]203_aZd20>o6Y@80klJ]103_aZD20>neW0H0ikFL103N[I@2
0=JUS080eYak0P3FYH@20;F<L`80YG]S0P2LJdX209AS@P80S5Y21024FT8405Xa8@80DRTH0P0i6102
02T@2080]HA[0P2LNf<209a[BP80U6=20P2mS6<20=JeY@80knOW0P3gmoL40?O_mdD0moOg403oool0
00h0oooo9P3gmoL20?ooo`80g/jm0P1[>B4208AJ@P80YG]J0P1kFT840:EkFP80_HaS0P36W8@20=j]
U080ikfL0`3WaZd20>o6[@80klJU0P3_aZd40?O>]@80mmJm0P3gc[D20>o>_@80mmJm0P3gc[D:0?OF
_@@0mlje0P3ge[d20?O>]@80klJ]0P3gc[D20>o6[@80mlje103_aZd20>o6Y@@0klJ]103_aZD20>Nm
W080kkfL103W]I@20=j]W080gZf<0P3>[I@20;fDN`80eYak0P3>U6/20;F4J`80YG]S0P2LLe8209a[
BP80Q5Y20P1cBS4207=B@P80U6]B0P128AP203TH4080>B4H0P1kFT8208AB>@80YG]J0P2LJdX20:ec
DP80aYA[0P3W_JD20?O_m`80moOg0P3gkoL20?ooodD0moOg403oool000h0oooo9P3gmoL20?ooo`80
g/jm0P1[>B4208AJ@P80YG]J0P1kFT840:EkFP80_HaS0P36W8@20=j]U080ikfL0`3WaZd20>o6[@80
klJU0P3_aZd40?O>]@80mmJm0P3gc[D20>o>_@80mmJm0P3gc[D:0?OF_@@0mlje0P3ge[d20?O>]@80
klJ]0P3gc[D20>o6[@80mlje103_aZd20>o6Y@@0klJ]103_aZD20>NmW080kkfL103W]I@20=j]W080
gZf<0P3>[I@20;fDN`80eYak0P3>U6/20;F4J`80YG]S0P2LLe8209a[BP80Q5Y20P1cBS4207=B@P80
U6]B0P128AP203TH4080>B4H0P1kFT8208AB>@80YG]J0P2LJdX20:ecDP80aYA[0P3W_JD20?O_m`80
moOg0P3gkoL20?ooodD0moOg403oool000h0oooo9P3gmoL20?ooo`80c[FU0P2LLe8408AB>@80Q6=:
0P2UNf<20:EkFP80_HaS0P3FW7/20=j]U080gZfL0`3W_JD20>o6[@80klJU0P3_aZd20?O6]@80klJ]
0P3ge[d20>o>[@h0mlje0P3ge[d40?O6]@H0klJ]0P3_]I`20>o6[@X0klJU0P3_aZd40>o6Y@@0ikFD
0P3W]I`40=j]U080gZf<0P3FYH@40;fDN`80]HA[0P2]Le8209acDP80U6=21024FT8408AB>@80FSTY
0P1cBS4205Xi:@80LdXa0P1c@RT20:EkH`80W7=B0P2eQ6<20;f<H`80eZf<0P3F_Jd20?Ogm`80oooo
B@3gmoL@0?ooo`003P3ooolV0?Ogm`80oooo0P3>]JD209acDP@0Q58i0P24HdX20:EkH`80YG]J0P2m
S6<20=JLN`80gZfD0P3N[I`30>NmY@80klJ]0P3_aZD20>o6[@80mlJe0P3_aZd20?OF_@80klj]3P3g
c[D20?OF_@@0mlJe1P3_aZd20>neW080klJ]2P3_aZD20>o6[@@0klJU103W]I@20>NeW0@0gZfD0P3N
[H`20=JUQ0@0_IAk0P2eQ6/20:ecDP80W7=B0P2DHd8408AJ@P@0Q58i0P1J>BT207=:<@80FSTY0P1c
BS4207=2:@80YG]S0P2LLe820;F4H`80_HaS0P3F[H`20=Jm[@80moOg0P3ooom90?Ogma00oooo000>
0?ooobH0moOg0P3oool20<JUU080aYb40P1c@RT208AB<@80NeY20P2<FT8209acDP80]HAS0P2mU7/2
0<JLQ080e[FU0`3W]I`20>NmY@80klJU0P3_]I`40?O6]@@0klje0P3_a[D20>o6[@80mlJe103gc[D2
0?OF_@80klJe0P3_c[D40>o6[@80klJU0P3_]I`40>NeW080kkFD103_aZD20>nmW080kkFL0P3__I`2
0>neU0@0ikFL0P3N[H`20>N]U080gZfD103FYH`20=JLN`@0_IAk0P2eS7<20;F4J`80[G=B0P2UNeX2
09a[BP@0Le92101cBS4205Y2>@80Ld8Y0P1J<B420:F4J`80U6]B0P2LLe8209a[BP80eYak0P36U6/2
0>NmW0H0moOg0P3gkoL40?Ogm`<0oooo8P3gmoL20?oooa`0moOg403oool000h0oooo9P3gmoL20?oo
o`80aZFD0P36W8@207=2:@80Q58a0P1kFT8208aJ@P80W7=B0P2eQ6<20;fDN`80aYb40P3F]JD30>Ne
W080ikfU0P3_aZD20>neW0@0mlJe103_c[D20>o6]@80klJ]0P3ga[D40?O>]@80mmJm0P3_a[D20>o>
]@@0klJ]0P3_aZD20>neW0@0ikFL0P3_]I@40>o6Y@80kkfL0P3_]I`20>nmW080kkFD103W]I`20=j]
S080ijfD0P3N[I@40=JUS080eYak102mU7/20;F<L`80]HA[0P2]Le820:EkFP80W6]:101cDT8407=:
<@80FT8i0P1c@RT205Xa8@80YHA[0P2DJe8209acDP80W6]:0P3FW7/20<JDJ`80ikfL1P3gmoL20?O_
m`@0moOg0`3ooolR0?Ogm`80oooo703gmoL@0?ooo`003P3ooolX0?Ogm`80imkN0P3Na/H205Xa8@80
Ld8Y0P2LJdX208AB>@80W7=B0P2UQ6/20;F<L`80eZF<0P3N[I@30=j]W080ikFL103_]I`20>o6Y@80
klJ]0P3WaZd20>o6[@80klje1P3_aZd20>o6]@80klJ]0P3_aZD40>o6[@80kkfL0P3W]I`20>N]S0@0
ijfD0P3W]I@20>neU0P0ijf<0P3NYH@20=j]S080ijfD0P3FYH@20=j]S0@0eZF40P36W8@20=JLL`80
_IAk0P2eQ6/40;F4H`80YG]J0P2LLe8208aJ@P80Q5Y20P1kFT8207=B@P80S6]B0P1kFT8207=:<@80
S6]B0P2eQ6/209AcFP80YG]S0P2mS6<20=JUQ080ikfL0P3F_Jd20?O_m`H0moOg0P3ooolK0?Ogm`80
mnog:03gmoL@0?ooo`003P3ooolX0?Ogm`80imkN0P3Na/H205Xa8@80Ld8Y0P2LJdX208AB>@80W7=B
0P2UQ6/20;F<L`80eZF<0P3N[I@30=j]W080ikFL103_]I`20>o6Y@80klJ]0P3WaZd20>o6[@80klje
1P3_aZd20>o6]@80klJ]0P3_aZD40>o6[@80kkfL0P3W]I`20>N]S0@0ijfD0P3W]I@20>neU0P0ijf<
0P3NYH@20=j]S080ijfD0P3FYH@20=j]S0@0eZF40P36W8@20=JLL`80_IAk0P2eQ6/40;F4H`80YG]J
0P2LLe8208aJ@P80Q5Y20P1kFT8207=B@P80S6]B0P1kFT8207=:<@80S6]B0P2eQ6/209AcFP80YG]S
0P2mS6<20=JUQ080ikfL0P3F_Jd20?O_m`H0moOg0P3ooolK0?Ogm`80mnog:03gmoL@0?ooo`003P3o
oolZ0?Ogm`80aZFD0P2LNf/207]J@P80Q5Y20P2DJe8208aSBP80W7=B0P2UNf<20;fDN`80eZF<0`3W
_I`20=j]W080e[FU103W]I`80>o6[@80ilJ]203W_JD20>NeW080gZfL0P3N[H`40=j]U0@0eZF41P3F
W7/20=JLL`80gYak0P3FW7/40=JLL`80_IAk203>U6/20<J4J`80]Hac0P2mU7/20;F<L`80]HA[0P2e
NeX209a[BP80S6=:0P2DLeX209A[DP80LeY:102DJe8207=:<@80S6=:102LJdX209acDP80W6]:0P2m
S6<20;F4H`80gZfD0P3W_I`20?O_idl0moOg403oool000h0oooo:P3gmoL20<JUU080W7][0P1kFT82
08AJ@P80U6]B0P2<HdX209acDP80YG]S0P2mU7/20=JUS0<0ikfL0P3N[I`20=JeY@@0ikFL203_aZd2
0>O6[@P0ikfU0P3W]I`20=j]W080gZf<103N[I@40=JUQ0H0eYak0P3FW7<20=jLN`80eYak103FW7<2
0;fDN`P0cYA[0P36Q6/20;F<L`80_IAk0P2eS7<20;F4J`80]G]J0P2LJdX208aSBP80U7=J0P2DJe82
07=JBP@0U6]B0P1cBS4208aSBP@0W6]:0P2LLe8209a[BP80_HaS0P2eQ6<20=j]U080ikfL0P3gknM?
0?Ogma00oooo000>0?ooobX0moOg0P36YI@209akJ`80NeY20P24FT8209A[DP80S6=:0P2LLe820:Ek
H`80_IAk0P3FYH`30>NmW080gZfL0P3F]JD40>NeW0P0klJ]0P3WaZd80>NmY@80ikFL0P3N[I`20=j]
S0@0gZfD103FYH@60=JLN`80eYac0P3NW7/20=JLN`@0eYac0P2mU7/80<jDJ`80aXA[0P2eS7<20;fD
N`80]Hac0P2eQ6/20;EkFP80W6]:0P2<HdX209AcFP80U6]B0P1cFTX409A[DP80LdXa0P2<HdX409a[
BP80W7=B0P2LJdX20;f<H`80]HAS0P3N[I@20>NmW080mnoWC`3gmoL@0?ooo`003P3oool/0?Ogm`80
_Jf]0P2DLeX208AJ@P80S6=:0P2DJe820:EkFP80]HA[0P2UNf/20;F<L`<0_IAk0P3N[I@20=JeY@80
ikfU0P3_aZD20>O6[@H0ikfU0P3W_I`40=j]U080eZF40P3N[I@20>NmW080eZF<0P3NYH@20=JUQ080
eZF<0P2mU7/20<JLQ080aXA[0P3>U6/20;f<H`80eYak0P3>Lf<20<jDJ`80]G]J0P2eS7<40;EkFP80
_HaS102eQ6<40;F4J`80YG]S0P2eS7<20;fDN`80YHA[0P2US7<20:EkFP80YG]S102<HdX209AcFP80
YG]S0P24FT8206/i8@80Q58i0P2eNeX20;F4H`80]G]J0P2mS6<20<j]U080e[FU0P3F_Jd>0?Ogm`<0
mnog8P3gmoL20?oooa`0moOg403oool000h0oooo;03gmoL20;f][@80U7=J0P24FT8208aSBP80U6]B
0P2UNeX20;F4J`80YG][0P2eS7<30;fDN`80gZfD0P3F]JD20>NmY@80klJU0P3WaZd60>NmY@80ikfL
103N[I@20=JUQ080gZfD0P3W_I`20=JUS080gZF40P3FYH@20=JUS080_IAk0P36W8@20<J4J`80cYA[
0P2mS6<20=JLN`80cW=S0P3>U6/20;EkFP80]Hac102eNeX20;f<H`@0]HAS102eQ6/20:EkH`80]Hac
0P2mU7/20:F4J`80YHac0P2UNeX20:EkH`@0S6=:0P2DLeX20:EkH`80Q5Y20P1[>B4208AB>@80]G]J
0P2eQ6<20;EkFP80_HaS0P3>[I@20=JeY@80e[f]3P3gmoL30?O_mb80moOg0P3ooolL0?Ogma00oooo
000>0?ooobh0moOg0P3_inL20:F<N`80U7=J0P1kFT8209acDP80YG]J0P2<HdX20;F<L`<0aYb40P3F
_Jd60>O6]@@0ikfU0P3F]JD20=j]W080eZF40P3>[I@40=JUS080eZF40P3FYH`40=JUQ0@0aYA[102e
S7<20;F4J`80]Hac0P2eQ6/20:ecDP80]HA[0P2eQ6<209acDP80W6]:0P2eQ6/209acDP80]HAS0P2L
Le820:ecDP80YG]S0P2UNeX20:EkH`80S6=:0P2DJe8209AcFP80[G=B0P2DLeX209acDP80U7=J0P2L
Le8208AB>@80Q5Y20P2<Je8209a[BP80W7=B102UNeX20<JDJ`@0e[FU0P36W8@80?Ogm`80mnog8`3g
moL20?O_mb@0moOg403oool000h0oooo;P3gmoL20>oWi`80YHak0P2DLeX207]J@P80W7=B0P2UNeX2
08aSBP80]Hac0`36W8@20=Jm[@H0ilJe103W_JD20=JeY@80gZfL0P3FYH@20<j]U0@0eZF<0P3FYH@2
0=JUS0@0eZF41036U6/40;F<L`80]HA[0P2eS7<20;F4J`80[G=B0P2eQ6/20;F4H`80W7=B0P2LJdX2
0;F4J`80W7=B0P2eQ6<209acDP80[G=B0P2UNf<20:EkFP80YG]S0P2<HdX209A[DP80U7=J0P2]Le82
09AcFP80W7=B0P2DLeX209acDP80Q58i0P24FT8208a[DP80W6]:0P2LLe840:EkFP80aYA[103F]JD2
0<JLQ0P0moOg0P3gkoLS0?Ogm`80mnog903gmoL@0?ooo`003P3oool>0?Ogm`80mnog0P3gmoL20?O_
ma`0moOg0P2US7/20:EkJ`80YG]S0P2LLf<20:F<L`80aZFD0P3>YI@30;fLS080gZfL0P3>YI@20=j]
W0@0e[f]0P3N[I`20=j]U080eZF<0P3FYH@20=JUS080_IAk0P36W8@20=JUQ080aYb40P36U6/20<JL
Q080_IAk0P36Q6/20;F4H`80]HA[0P2LLe820;fDN`80YG]S0P2mU7/20;F4H`80YG]S0P2mS6<20:Ek
FP80W6]:0P2mU7/20:EkFP80]HA[0P2UNf<20:EkFP80YHA[0P2US7<208ASBP80U6]B0P2UNeX209ak
H`80S6]B0P2DLeX20:EkH`80U6=20P2LJdX209AS@P80W6]:0P2DHd8209acDP80]HAS0P3F[H@20<je
Y@80cZfD0P3F[H`20>O>aPP0moOg0P3ooom90?Ogma00oooo000>0?ooo`h0moOg0P3gkoL20?Ogm`80
mnog703gmoL20:F<N`80YG][0P2UNf<209acH`80YHac0P36YI@20<jUU0<0_Ib<0P3N[I`20<jUU080
gZfL103F_Jd20=j]W080gZfD0P3FYH`20=JUQ080eZF<0P2mU7/20<JLQ080eZF40P36W8@20<JDJ`80
aYb40P2mU7/20<J4J`80]HAS0P2eQ6/209acDP80_IAk0P2UNf<20;fDN`80]HAS0P2UNf<20;f<H`80
YG]J0P2LJdX20;fDN`80YG]J0P2eQ6/20:EkH`80YG]J0P2UQ6/20:F<L`80Q6=:0P2DJe820:EkFP80
W7]S0P2<Je8209AcFP80YG]S0P2DHd8209a[BP80U6=20P2LJdX209AS@P80W7=B0P2eQ6<20=J]Q080
c[FU0P3>[I@20=J]S080ilk6203gmoL20?ooodT0moOg403oool000h0oooo103gmoL20?O_mbX0moOg
0P3oool209AcFP80YHAc0P2LLf<209A[DP80YHA[1@2eS7<20;fLS080gZfL0P3F]JD20=j]U080cZfD
0P3FYH`20=J]S0H0aYb40P2eS7<20;fDN`80]Hac0P2mU7/20;F<L`80_IAk0P2eQ6/20;fDN`80YG]J
0P2LLe820:EkJ`80U6=20P2UQ6/20:EkFP80]Hac0P2LLe820:EkH`80YG]J0P2UNf<20<JDJ`80S6=:
102LLe820;F4J`80YG]J102DJe8208AJ@P80NeY20P1cBS4207=B@P80S6=:1024DST407]J@P80U6=2
0P2eLdX20<JDJ`80eZf40P3WaZd20;fLS080eZf<0P2eQ6=E0?Ogma00oooo000>0?ooo`@0moOg0P3g
koLZ0?Ogm`80oooo0P2DLeX20:F4L`80W7=S0P2DJe820:F4J`D0]Hac0P2mW8`20=j]W080e[FU0P3N
[I@20<j]U080eZF<0P3F[H`60<JLQ080]Hac0P2mU7/20;F<L`80_IAk0P2eS7<20;fDN`80]HA[0P2m
U7/20:EkFP80W7=B0P2UNf/209AS@P80YHA[0P2UNeX20;F<L`80W7=B0P2UNf<20:EkFP80YG]S0P36
U6/208aSBP@0W7=B0P2eQ6/20:EkFP@0U6]B0P24FT8207]J@P80LdXa0P1cDT8208aSBP@0Q58i101k
FT8209AS@P80]G=:0P36U6/20=J]Q080ilJ]0P2mW8`20=J]S080]HASE@3gmoL@0?ooo`003P3ooolb
0?Ogm`80oooo0P2eU7/20:EkJ`80YG]S0P2mW9@20<JLQ0<0aZFD203F]JD80<JLQ080_IAk0P36W8@4
0;fDN`@0]HA[0P2mU7/20;F4H`80YG]J0P2UNf<209AS@P@0YHA[0P2<HdX207=:<@80YG]S0P24FT82
0;F4H`80YG]J102UNf<208aJ@P80W6]:0P2UNeX207=2:@80LdXa0P2LHcT208aJ@P80Q5Y20P2<FT82
09aS>@80U6=20P2LJdX409AS@P80Q58i0P2LHcT209a[BP80cZfD0P2mU7/20=J]S080e[f]0P2<HdX2
0;fLS080YHA[0P3Nc/h20?ooo`h0moOg0P3gkoM30?Ogma00oooo000>0?oooc80moOg0P3oool20;FD
N`80YG][0P2UNf<20;fLU080aYb40`36YI@80=JeY@P0aYb40P2mU7/20<JLQ0@0_IAk102eQ6/20;fD
N`80]HAS0P2UNeX20:EkH`80U6=2102UQ6/208aSBP80LdXa0P2UNf<208AJ@P80]HAS0P2UNeX40:Ek
H`80S5Y20P2LJdX20:EkFP80Ld8Y0P1cBS4209aS>@80S5Y20P24FT8208aJ@P80W6<i0P2DHd8209a[
BP@0U6=20P24DST209aS>@80W6]:0P3>[I@20;fDN`80eZf<0P3F_Jd208aSBP80_Ib<0P2UQ6/20=k>
cP80oooo3P3gmoL20?O_md<0moOg403oool000h0oooo=03gmoL20<JUW080YHAc0P24HdX209acH`80
W6]:0`2UQ6/20<JUW080c[FU0P3N[I`20=JeY@80aZFD102mU7/20;F<L`@0_IAk0P2eS7<20:F4J`80
YHac0P2eS7<20:EkH`@0]HAS0P2<HdX20<JDJ`80YG]J0P2<HdX20;fDN`80S6=:0P24FT820:EkH`@0
S6=:0P2DJe8208AJ@P80S5Y20P24DS4207=2:@@0Q58i0P2LHcT208AB>@80NeY20P2DHd8208aJ@P80
Q58i0P24BS4208aJ@P80W7=B102eQ6<20<JLQ080_IAk0P3W_I`20=JeY@80YHA[0P2UNeX20;fLS080
YHA[2P3gmoL20?O_m`@0moOg0P3gkoLM0?Ogm`80mnog103gmoL20?ooob00moOg403oool000h0oooo
=03gmoL20<JUW080YHAc0P24HdX209acH`80W6]:0`2UQ6/20<JUW080c[FU0P3N[I`20=JeY@80aZFD
102mU7/20;F<L`@0_IAk0P2eS7<20:F4J`80YHac0P2eS7<20:EkH`@0]HAS0P2<HdX20<JDJ`80YG]J
0P2<HdX20;fDN`80S6=:0P24FT820:EkH`@0S6=:0P2DJe8208AJ@P80S5Y20P24DS4207=2:@@0Q58i
0P2LHcT208AB>@80NeY20P2DHd8208aJ@P80Q58i0P24BS4208aJ@P80W7=B102eQ6<20<JLQ080_IAk
0P3W_I`20=JeY@80YHA[0P2UNeX20;fLS080YHA[2P3gmoL20?O_m`@0moOg0P3gkoLM0?Ogm`80mnog
103gmoL20?ooob00moOg403oool000h0oooo=03gmoL20?ooo`80LeY:0P2LNf/20;fLS080YG][0`2U
Q6/20;FDN`80aZfL0P3>]JD20=JUS080aZFD0P2UNf<20;F4J`80YHA[102mU7/20;F4J`80W7=S0P2e
Q6/20;F4H`80YG]S0P2eS7<20:EkH`80]HAS0P24FT8209acDP80U7=J0P2<HdX20:EkFP80Q5Y20P2<
HdX209AS@P80Q5Y20P24HdX208AJ@P80Le921P24DST207=:<@80Ld8Y0P24DST207]J@P80Q58i1024
DS4208aSBPP0YG]J0P36W8@20<jeY@@0W7]S0P2UQ6/20<JUU080_IAk0P3_inL40?O_m`@0moOg0P3g
koL40?Ogm`80mnog103gmoL30?ooo`P0moOg0P3ooolf0?Ogma00oooo000>0?oooc@0moOg0P3oool2
07=JBP80W7][0P2mW8`20:EkJ`<0YHA[0P2eU7/20<J]W080c[FU0P3FYH`20<JUU080YG]S0P2eQ6/2
0:F4J`@0_IAk0P2eQ6/209acH`80]HA[0P2eQ6<20:EkH`80]Hac0P2UNf<20;F4H`80Q5Y20P2LLe82
09AcFP80S6=:0P2UNeX208AJ@P80S6=:0P2DHd8208AJ@P80Q6=:0P24FT8207=B@PH0Q58i0P1cBS42
07=2:@80Q58i0P1kFT8208AB>@@0Q58a0P2<HdX80:EkFP80aYb40P3>]JD409akH`80YHA[0P36YI@2
0;fDN`80knOW103gkoL40?Ogm`80mnog103gmoL20?O_m`@0moOg0`3oool80?Ogm`80oooo=P3gmoL@
0?ooo`003P3ooolh0?Ogm`80W7][0P1cBS420;FDN`<0]Ib<0P2mW8`20;FDN`@0e[FU0P36[I`20:Ek
FP80]Hac102UNf<20;F4H`80YG]J0P2DLeX40:F4J`80U7=J0P2UNf<209AcFP80YG]S0P24FT820:Ek
FP80W6]:0P2DJe8207=B@P80LdXa0P2UNeX207=B@P80NeY20P24FT8207]J@P80Q58a101cBS4206/i
8@80FSTY1P1c@RT208AB<@80W6]:0P24FT8208aSBP80YHA[0P36W8@20;fDN`80ikfU0P3>]JD20;fL
S080YHac0P2DJe820<JLQ080U6]B0P3_inL40?ooo`80mnogD`3gmoL@0?ooo`003P3ooolh0?Ogm`80
W7][0P1cBS420;FDN`<0]Ib<0P2mW8`20;FDN`@0e[FU0P36[I`20:EkFP80]Hac102UNf<20;F4H`80
YG]J0P2DLeX40:F4J`80U7=J0P2UNf<209AcFP80YG]S0P24FT820:EkFP80W6]:0P2DJe8207=B@P80
LdXa0P2UNeX207=B@P80NeY20P24FT8207]J@P80Q58a101cBS4206/i8@80FSTY1P1c@RT208AB<@80
W6]:0P24FT8208aSBP80YHA[0P36W8@20;fDN`80ikfU0P3>]JD20;fLS080YHac0P2DJe820<JLQ080
U6]B0P3_inL40?ooo`80mnogD`3gmoL@0?ooo`003P3ooold0?Ogm`80mnog0P3gmoL20?ooo`80YG][
0P1c@RT309AcH`80YHAc0P2eU7/20<jeY@80e[f]0P36[I`20:EkFP80U6]B0P2eU7/20:EkH`80]Hac
0P2eU7/20;F4H`80U6]B0P2UQ6/20:EkFP80S6=:102UNf<208aSBP80W7=B0P2UNeX209AcFP80S6]B
0P1J<B4207=:<@80NeY20P2UNeX408AB>@80JcTQ0P24DST207=2:@80JcTQ0P1J<B4205Xi:@@0FS4Q
0P1cBS4208aJ@P80YHA[0P2mU7/20;F4J`80_IAk0P3>]JD20;FDN`80Q6=:0P2DNf/20;F4H`80YHA[
0P2LJdX20<JUW0`0moOg0P3gkoL20?Ogm`80oooo5`3gmoL20?O_ma80moOg0P3ooolL0?Ogma00oooo
000>0?oooc@0moOg0P3gkoL20?Ogm`80oooo0P2UNf/207=2:@<0U7=S0P2UQ7<20;FDN`80c[FU0P3F
_Jd20<J]W080YG]J0P2DJe820;FDN`80YG]S0P2eS7<20;FDN`80]HAS0P2DJe820:F4J`80YG]J0P2<
HdX40:EkH`80S6=:0P2LLe820:EkFP80U7=J0P2<Je8205Xa8@80LdXa0P1kFT820:EkFP@0Q58i0P1[
>B4208AB>@80Ld8Y0P1[>B4205Xa8@80FSTY101J<B4207=:<@80S5Y20P2UQ6/20;fDN`80]HA[0P2m
U7/20<jeY@80]IAk0P24HdX209AkJ`80]HAS0P2UQ6/209a[BP80aZFL303gmoL20?O_m`80moOg0P3o
oolG0?Ogm`80mnog4P3gmoL20?oooa`0moOg403oool000h0oooo2P3gmoL20?O_mbh0moOg0P3Nc/h2
07][FP<0NeY20P24HdX20:F<L`80_Ib<0P36[I`20=JeY@80YHA[0P2DJe820:EkFP80]Hac102DLeX2
0:EkH`80S6]B0P2<HdX209acH`80U7=J0P2<Je8209A[DP80YG]S0P2DLeX208aSBP80YG]J0P2LLe82
08a[DP80S6=:101cBS4208ASBP@0Q58i0P2<FT8208AB<@80W6]:1024DS4209AJ<@80W6]:0P2]Le82
0:EkH`80_HaS0P36W8@20=k6]@80]IAk0P2mW8`209akJ`80LdXa0P2DLeX20:F4J`@0]IAk303gmoL2
0?ooo`80moOg0P3gkoL;0?Ogm`80oooo403gmoL20?ooob`0moOg403oool000h0oooo2P3gmoL20?O_
mbh0moOg0P3Nc/h207][FP<0NeY20P24HdX20:F<L`80_Ib<0P36[I`20=JeY@80YHA[0P2DJe820:Ek
FP80]Hac102DLeX20:EkH`80S6]B0P2<HdX209acH`80U7=J0P2<Je8209A[DP80YG]S0P2DLeX208aS
BP80YG]J0P2LLe8208a[DP80S6=:101cBS4208ASBP@0Q58i0P2<FT8208AB<@80W6]:1024DS4209AJ
<@80W6]:0P2]Le820:EkH`80_HaS0P36W8@20=k6]@80]IAk0P2mW8`209akJ`80LdXa0P2DLeX20:F4
J`@0]IAk303gmoL20?ooo`80moOg0P3gkoL;0?Ogm`80oooo403gmoL20?ooob`0moOg403oool000h0
oooo?03gmoL20=Jm]@<0U7][0P2<LeX208ASDP80Q6=:0P2UQ7<20:F<Q080e[FU0P2<HdX208a[DP80
W7]S0P2eQ6<209AcFP80U6]B0P24FT8407]J@P@0S6=:0P2DJe8209AcFP@0S6=:0P2UNeX20:F4J`80
W7=B0P2DLeX207]J@P80YG]J0P24DST208AB<@80U7=J0P2DJe8208aSBP80U6=20P2LJdX20:EkFP80
]HAS0P36W8@20;F<L`80_IAk0P3F]JD20;fLS080]Ib<102US7<207]J@P80W7=S0P2US7<20:F4J`80
YG][0P3oool20?Ogm`@0oooo0P3gmoL20?O_m`80oooo0P3gkoL20?ooo`80moOg0P3gkoL20?Ogm`80
oooo8@3gmoL20?ooob80moOg403oool000h0oooo?03gmoL20=Jm]@<0U7][0P2<LeX208ASDP80Q6=:
0P2UQ7<20:F<Q080e[FU0P2<HdX208a[DP80W7]S0P2eQ6<209AcFP80U6]B0P24FT8407]J@P@0S6=:
0P2DJe8209AcFP@0S6=:0P2UNeX20:F4J`80W7=B0P2DLeX207]J@P80YG]J0P24DST208AB<@80U7=J
0P2DJe8208aSBP80U6=20P2LJdX20:EkFP80]HAS0P36W8@20;F<L`80_IAk0P3F]JD20;fLS080]Ib<
102US7<207]J@P80W7=S0P2US7<20:F4J`80YG][0P3oool20?Ogm`@0oooo0P3gmoL20?O_m`80oooo
0P3gkoL20?ooo`80moOg0P3gkoL20?Ogm`80oooo8@3gmoL20?ooob80moOg403oool000h0oooo=03g
moL20?ooo`P0moOg0`2m[Jd209AcFP80U7=S0P2LLf<20:F4J`80YHak0P36W8@20<JUU0@0S6]B102U
Q6/209A[DP80YHA[0P24DST408AJ@P80W6]:0P2DJe8209acDP80Q58i0P2UNf/209acDP80]Hac0P2U
Nf<20;F4J`80]IAk0P2DJe8408aJ@P@0W7=B102eQ6<40;f<H`@0eZF40P36YI@20:EkH`@0W7][0P2<
FT8207=2:@80Q58i0P2UNf<20:F4J`80W7]S0P2mU7/20?ooo`H0moOg103oool40?Ogm`80ooooC`3g
moL@0?ooo`003P3ooold0?Ogm`80oooo203gmoL30;f][@80U7=J0P2DLf<209acH`80YHA[0P2US7/2
0<JLQ080aZFD102<Je840:F4J`80U6]B0P2UQ6/208AB>@@0Q5Y20P2LJdX209A[DP80W7=B0P24DST2
0:EkJ`80W7=B0P2eS7<20:EkH`80]HA[0P2eU7/209A[DP@0S5Y2102LLe840;F4H`@0_HaS103FYH@2
0<JUU080YG]S102LNf/208aJ@P80Ld8Y0P24DST20:EkH`80YHA[0P2LNf<20;fDN`80oooo1P3gmoL4
0?ooo`@0moOg0P3ooom?0?Ogma00oooo000>0?oooc@0moOg0P3gkoL40?Ogm`80mnog1@3gmoL20<je
]@80Q6=B0P2DLf<20:F<L`80]IAk0P2mW8`20<JUU080aZfL0P2DLeX20:F4J`80S6=:0P2UQ7<209Ac
FP80YG]S0P2DJe8208AB>@80Ne920P1cBS4208aSBP80NeY20P2LLf<209acDP80_IAk0P2eS7<20=k6
]@80ilJe0P3F]JD20<JLQ080gZfL1P3FYH`40>O6[@80gZfD0P3>]JD20:F<L`80S6]B0P2LNf<209A[
DP80Q5Y20P1kFT8208aSBP80]HAS0P2eU7/20:EkH`80YG][0P3oool40?Ogm`80oooo3P3gmoL20?O_
m`@0moOg103ooom30?Ogma00oooo000>0?oooc@0moOg0P3gkoL40?Ogm`80mnog1@3gmoL20<je]@80
Q6=B0P2DLf<20:F<L`80]IAk0P2mW8`20<JUU080aZfL0P2DLeX20:F4J`80S6=:0P2UQ7<209AcFP80
YG]S0P2DJe8208AB>@80Ne920P1cBS4208aSBP80NeY20P2LLf<209acDP80_IAk0P2eS7<20=k6]@80
ilJe0P3F]JD20<JLQ080gZfL1P3FYH`40>O6[@80gZfD0P3>]JD20:F<L`80S6]B0P2LNf<209A[DP80
Q5Y20P1kFT8208aSBP80]HAS0P2eU7/20:EkH`80YG][0P3oool40?Ogm`80oooo3P3gmoL20?O_m`@0
moOg103ooom30?Ogma00oooo000>0?oooc`0moOg0P3oool50?Ogm`80knog0P2LQ7/209AcH`80Lf=B
0P2US7<40<jeY@80cZfD0P2UQ7<20;F<L`80YHAc0P2US7/20:EkJ`80_IAk0P36YI@209akJ`80Ne92
0P2<Je8207]B@P80U7=J0P2eU7/20<JUU080_Ib<0P2US7/20=Jm[@80e[fe0P3F_Jd20=k6]@80imK6
0P3Wc/H20=Jm[@80aYb4102eU7/20:F4L`80U7=S0P2DLeX209A[DP80Le920P24DST209AcFP80W7]S
0P2mU7/20:EkH`80]IAk1P3gmoL20?O_m`@0moOg103gkoL60?Ogm`80mnog3@3gmoL20?O_mch0moOg
403oool000h0oooo?03gmoL20?ooo`D0moOg0P3_koL209b4N`80U7=S0P1cHe820:F<L`@0c[FU0P3>
[I@20:F4L`80]Hac0P2UQ7<20:F<N`80YG][0P2mU7/20<JUU080W7][0P1kDT8208a[DP80Ne920P2D
LeX20;FDN`80aZFD0P2mW8`20:F<N`80e[f]0P3F_KD20=Jm[@80g/Je0P3We/H20>O>aP80e[f]0P36
W8@40;FDN`80YHAc0P2DLf<209AcFP80U6]B0P1cDT8208AB>@80U7=J0P2LNf<20;fDN`80YG]S0P2e
U7/60?Ogm`80mnog103gmoL40?O_m`H0moOg0P3gkoL=0?Ogm`80mnog?P3gmoL@0?ooo`003P3oooll
0?Ogm`80oooo1`3gmoL20?ooo`80W7][0P24He8209b4L`80YHak0P36[I`20=k6aP@0aZfL0P3F_KD2
0;f][@80g/jm0P3F_KD20<JUW080ilk60P3_e/H20?O_i`80knON0P3_e/H20>O>aP80iljm0P3F_Jd2
0=k>_@H0g/Je0P3Wc[d20<jeY@80YHac0P36YI@20:F<L`80W7]S102LNf/208aSBP80S6]B0P1cFTX2
0:EkH`80YHac102UQ6/20:EkH`80oooo103gmoL20?ooo`80mnog203gmoL20?O_m`P0moOg0P3gkoL4
0?Ogm`80oooo1@3gmoL20?O_m`@0moOg0P3gkoL20?Ogm`80oooo=03gmoL@0?ooo`003P3oooll0?Og
m`80oooo1`3gmoL20?ooo`80W7][0P24He8209b4L`80YHak0P36[I`20=k6aP@0aZfL0P3F_KD20;f]
[@80g/jm0P3F_KD20<JUW080ilk60P3_e/H20?O_i`80knON0P3_e/H20>O>aP80iljm0P3F_Jd20=k>
_@H0g/Je0P3Wc[d20<jeY@80YHac0P36YI@20:F<L`80W7]S102LNf/208aSBP80S6]B0P1cFTX20:Ek
H`80YHac102UQ6/20:EkH`80oooo103gmoL20?ooo`80mnog203gmoL20?O_m`P0moOg0P3gkoL40?Og
m`80oooo1@3gmoL20?O_m`@0moOg0P3gkoL20?Ogm`80oooo=03gmoL@0?ooo`003P3ooolX0?Ogm`80
oooo4P3gmoL20?ooo`/0moOg0P3Wg]h208ASDP80S7=S0P2eU7/20;fUW080e[fe0P3Nc[d20>OFcP80
g/k61P3Nc[d20>OFcP80g/Je0P3Wa[D20>O>_@80ilJe0P3_e/H20>oNcP80imK>0P3Nc[d20>O>aP80
c[FU0P2mW9@20=Jm[@80_Ib<0P2eW8`20;fLU080S7=J0P2UNeX208aSBP80S6]B0P2LNf/20:F4L`80
_Ib<0P36W8@20;F<L`80YHA[0P36YI`40?Ogm`80mnog0P3gmoL20?O_m`h0moOg0P3gkoL]0?Ogm`80
oooo103gmoL20?ooo`80moOg0P3gkoLH0?Ogma00oooo000>0?ooobP0moOg0P3ooolB0?Ogm`80oooo
2`3gmoL20>ONgP80Q6=B0P2<Lf<20;FDN`80_JFL0P3F_KD20=k>_@80imK>0P3Nc/H60=k>_@80imK>
0P3Na[D20>O6]@80iljm0P3Wa[D20>oFaP80kmk>0P3We/h20=k>_@80ilk60P3>]JD20;fLU080e[f]
0P2mW8`20;FLS080_IbD0P2<LeX20:EkFP80S6=:0P2<Je8209akJ`80YHAc0P2mW8`20<JLQ080]Hac
0P2UQ6/20<JUW0@0moOg0P3gkoL20?Ogm`80mnog3P3gmoL20?O_mbd0moOg0P3oool40?Ogm`80oooo
0P3gmoL20?O_maP0moOg403oool000h0oooo>03gmoL20?ooo`80moOg1@3oool20?Ogm`80oooo103g
moL20?ooo`80knOW0P2UQ7<209b4L`80YHb4103>]JD20=Jm]@80e/Je0P3Nc[d80>OFcP80knON0P3W
g]H20>OFeP80imK>0P3_g/h20>O>aP80g/jm0P3F_KD20<k6_@80]Ib<0P2US8@20;fLU080W7]S0P2L
Nf/209AcFP80YHac0P24He820:F<N`80_Ib<0P36W8@20;FLS080YHak0P36W8@20>ONgPH0moOg0P3g
koL60?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3gkoLC0?Ogm`80oooo3P3gmoL20?ooo`P0moOg0P3o
ool80?Ogm`80oooo6P3gmoL@0?ooo`003P3ooolh0?Ogm`80oooo0P3gmoL50?ooo`80moOg0P3oool4
0?Ogm`80oooo0P3_inL20:F4L`80W8Ac0P2US8@40<jeY@80e[fe0P3Fa[D20=k>_@P0imK>0P3_imh2
0>ONeP80imKF0P3We/h20>oNcP80ilk60P3Nc[d20=Jm]@80c/Jm0P2eW8`20:F<Q080_IbD0P2LNf<2
09akJ`80U7=J0P2US7<208ASDP80YHak0P2mW8`20<JLQ080]Ib<0P2US7/20<JLQ080imkN1P3gmoL2
0?O_m`H0moOg0P3oool20?Ogm`80oooo103gmoL20?O_ma<0moOg0P3oool>0?Ogm`80oooo203gmoL2
0?ooo`P0moOg0P3ooolJ0?Ogma00oooo000>0?ooodL0moOg0P3gkoL20?Ogm`80oooo103gmoL20;FD
S080W7][0P2UQ7<20<je]@80g/K6103We/h20>OFaP80ilk60P3Na/H20>OFeP80g/k60P3Na/H20=Jm
]@80aZfL0P2mW8`20;FDN`80aZFD0P36[I`20;FLS080YHak0P24Je820:EkJ`80]Ib<0P2US7/40<J]
W080c[FU0P36[I`20:F<Q080aZfL0P3gkoL<0?Ogm`80oooo203gmoL20?O_m`@0moOg0P3oool20?Og
m`80oooo1P3gmoL20?O_m`80moOg0P3oool;0?Ogm`80oooo5P3gmoL60?ooo`80mnog303gmoL20?oo
o`X0moOg403oool000h0ooooA`3gmoL20?O_m`80moOg0P3oool40?Ogm`80]IB<0P2LNf/20:F4L`80
c[Fe0P3Na/H40>OFcP80imK60P3Wc/H20=k6aP80imKF0P3Nc/H20=k6aP80e[fe0P36[I`20;fLS080
]IAk0P36YI@20<J]W080]Ib<0P2US7/208A[DP80YG][0P2eW8`20:F<N`@0aZfL0P3>]JD20<J]W080
YHb40P36[I`20?O_m``0moOg0P3oool80?Ogm`80mnog103gmoL20?ooo`80moOg0P3oool60?Ogm`80
mnog0P3gmoL20?ooo`/0moOg0P3ooolF0?Ogm`H0oooo0P3gkoL<0?Ogm`80oooo2P3gmoL@0?ooo`00
3P3ooolV0?Ogm`80oooo6`3gmoL20?O_m`80oooo103gmoL20?ooo`X0moOg0P2mW9@20;FDS080a[Fe
0P3>]KD20=Jm]@@0imKF0P3We/h40>OFeP80imK>103F_KD20<JUW080_JFL0P2eU8`20<jeY@80g/jm
0P2mW9@20=Jm]@80g/K60P3F_KD20;fLU080]IAk0P3F_Jd20>oWi`H0oooo1P3gmoL20?ooo`X0moOg
0P3oool<0?Ogm`80mnog3`3gmoL20?ooo`80moOg2P3oool:0?Ogm`80oooo1P3gmoL40?ooo`80moOg
0P3ooolH0?Ogma00oooo000>0?ooobH0moOg0P3ooolK0?Ogm`80mnog0P3oool40?Ogm`80oooo2P3g
moL20;fLU080]IB<0P36]KD20<je]@80e[fe103We]H20>OFcP@0imKF0P3We/h40=Jm]@80aZFL0P2m
YI`20;FDS080c[FU0P3Nc[d20;fLU080e[fe0P3Na/H20=Jm]@80_IbD0P2eU7/20=Jm[@80knOW1P3o
ool60?Ogm`80oooo2P3gmoL20?ooo``0moOg0P3gkoL?0?Ogm`80oooo0P3gmoL:0?ooo`X0moOg0P3o
ool60?Ogm`@0oooo0P3gmoL20?oooaP0moOg403oool000h0oooo903gmoL20?O_mb/0moOg0P3oool2
0?Ogm`80oooo103gmoL20;f][@80_JFL0P3F_KD20<JUW080e[f]103Nc/H20>ONeP80imKF0P3_imh2
0?O_i`80knON0P3We/h20=k>_@80imK>0P3Nc/H20=k>_@80aZFL0P2mW8`20<jeY@80g/jm0P3_inL4
0?Ogm`@0oooo0P3gkoL>0?Ogm`80mnog103gmoL20?O_m`H0moOg0P3gkoL>0?Ogm`80mnog3`3gmoL2
0?O_m`80moOg0P3oool20?O_m`X0moOg0P3gkoL80?Ogm`80mnog5P3gmoL@0?ooo`003P3ooolT0?Og
m`80mnog:`3gmoL20?ooo`80moOg0P3oool40?Ogm`80_Jf]0P2mYI`20=Jm]@80aZFL0P3F_Jd40=k>
aP80imkF0P3We]H20>oWgP80mnoW0P3_imh20>OFcP80g/jm0P3We/h20=k>aP80g/jm0P36YI`20;fL
S080c[FU0P3Nc[d20>oWi`@0moOg103oool20?O_m`h0moOg0P3gkoL40?Ogm`80mnog1P3gmoL20?O_
m`h0moOg0P3gkoL?0?Ogm`80mnog0P3gmoL20?ooo`80mnog2P3gmoL20?O_m`P0moOg0P3gkoLF0?Og
ma00oooo000>0?ooobH0moOg0P3ooolS0?Ogm`80mnog103gmoL20?ooo`@0mnog1P3gmoL60?O_m`@0
knOW0P3Wg]h20?O_i`80knON0P3Nc[d40=Jm]@80g/jm0P3Nc/H40=k6aP80g/k>0P3_inL20?O_m`X0
moOg103oool20?Ogm`H0oooo2P3gmoL40?O_m``0moOg0P3gkoL20?Ogm`80oooo0P3gkoL60?Ogm`<0
oooo4P3gmoL20?ooo`80moOg0P3oool@0?Ogm`80oooo3P3gmoL20?ooo`H0moOg403oool000h0oooo
9P3gmoL20?ooob<0moOg0P3gkoL40?Ogm`80oooo103gkoL60?Ogm`H0mnog103_inL20>ONgP80mnoW
0P3_imh20=k>_@@0e[fe0P3Nc[d20=k>aP@0g/K60P3Nc/h20>oWi`80mnog2P3gmoL40?ooo`80moOg
1P3oool:0?Ogm`@0mnog303gmoL20?O_m`80moOg0P3oool20?O_m`H0moOg0`3ooolB0?Ogm`80oooo
0P3gmoL20?oooa00moOg0P3oool>0?Ogm`80oooo1P3gmoL@0?ooo`003P3ooolX0?Ogm`80mnog5`3g
moL20?ooo`80mnog203gmoL20?O_ma80moOg0P3oool:0?Ogm`P0mnog0P3oool<0?Ogm`@0oooo1P3g
moL20?ooo`P0moOg0P3gkoL20?Ogm`80oooo103gmoL20?ooo`H0moOg0P3oool20?Ogm`80oooo0P3g
moL20?ooo`80moOg0P3gkoL40?Ogm`80mnog5`3gmoL20?O_m`@0moOg0P3oool80?Ogm`80oooo703g
moL@0?ooo`003P3ooolX0?Ogm`80mnog5`3gmoL20?ooo`80mnog203gmoL20?O_ma80moOg0P3oool:
0?Ogm`P0mnog0P3oool<0?Ogm`@0oooo1P3gmoL20?ooo`P0moOg0P3gkoL20?Ogm`80oooo103gmoL2
0?ooo`H0moOg0P3oool20?Ogm`80oooo0P3gmoL20?ooo`80moOg0P3gkoL40?Ogm`80mnog5`3gmoL2
0?O_m`@0moOg0P3oool80?Ogm`80oooo703gmoL@0?ooo`003P3ooom;0?Ogm`80mnog103gmoL20?O_
m`80oooo1P3gmoL20?O_m`80moOg0P3gkoL40?Ogm`80oooo0P3gkoL<0?Ogm`80oooo103gmoL20?O_
m``0moOg0P3oool20?Ogm`80oooo1P3gmoL20?O_m`80oooo0P3gmoL40?oooa80moOg0P3oool40?O_
m`80moOg0P3gkoLA0?Ogm`80oooo303gmoL20?ooo`H0moOg0P3gkoL20?Ogm`@0oooo403gmoL20?oo
o`80moOg0P3gkoL20?Ogma00oooo000>0?oood/0moOg0P3gkoL40?Ogm`80mnog0P3oool60?Ogm`80
mnog0P3gmoL20?O_m`@0moOg0P3oool20?O_m``0moOg0P3oool40?Ogm`80mnog303gmoL20?ooo`80
moOg0P3oool60?Ogm`80mnog0P3oool20?Ogm`@0oooo4P3gmoL20?ooo`@0mnog0P3gmoL20?O_ma40
moOg0P3oool<0?Ogm`80oooo1P3gmoL20?O_m`80moOg103oool@0?Ogm`80oooo0P3gmoL20?O_m`80
moOg403oool000h0oooo:P3gmoL20?ooob<0moOg103oool60?Ogm`80mnog103gmoL20?ooo`H0moOg
0P3oool40?Ogm`80oooo1P3gmoL20?O_m``0moOg0P3gkoL20?Ogm`80oooo103gmoL40?ooo`H0moOg
0P3gkoL40?Ogm`80mnog0P3gmoL20?ooo`P0moOg0P3ooolB0?Ogm`<0oooo0P3gkoL80?Ogm`80oooo
103gmoL20?ooo`@0moOg0P3gkoL<0?Ogm`80mnog0P3ooolD0?Ogm`80oooo0P3gmoL@0?ooo`003P3o
oolZ0?Ogm`80oooo8`3gmoL40?ooo`H0moOg0P3gkoL40?Ogm`80oooo1P3gmoL20?ooo`@0moOg0P3o
ool60?Ogm`80mnog303gmoL20?O_m`80moOg0P3oool40?Ogm`@0oooo1P3gmoL20?O_m`@0moOg0P3g
koL20?Ogm`80oooo203gmoL20?oooa80moOg0`3oool20?O_m`P0moOg0P3oool40?Ogm`80oooo103g
moL20?O_m``0moOg0P3gkoL20?oooa@0moOg0P3oool20?Ogma00oooo000>0?ooob80moOg0P3oool4
0?Ogm`80mnog103gmoL20?O_maL0moOg0P3gkoL20?ooo`H0moOg0P3gkoL80?Ogm`80mnog0P3oool2
0?O_m`H0moOg0P3oool60?Ogm`80oooo0P3gmoL20?O_m`@0moOg0P3gkoLD0?Ogm`80oooo103gmoL2
0?O_m`80moOg0P3oool60?Ogm`80mnog103oool40?Ogm`80mnog0P3oool80?Ogm`80oooo1P3gmoL3
0?ooo`H0moOg0P3oool40?Ogm`80oooo103gmoL40?ooo`@0moOg0P3oool60?Ogm`80mnog403gmoL2
0?ooo`X0moOg403oool000h0oooo8P3gmoL20?ooo`@0moOg0P3gkoL40?Ogm`80mnog5`3gmoL20?O_
m`80oooo1P3gmoL20?O_m`P0moOg0P3gkoL20?ooo`80mnog1P3gmoL20?ooo`H0moOg0P3oool20?Og
m`80mnog103gmoL20?O_ma@0moOg0P3oool40?Ogm`80mnog0P3gmoL20?ooo`H0moOg0P3gkoL40?oo
o`@0moOg0P3gkoL20?ooo`P0moOg0P3oool60?Ogm`<0oooo1P3gmoL20?ooo`@0moOg0P3oool40?Og
m`@0oooo103gmoL20?ooo`H0moOg0P3gkoL@0?Ogm`80oooo2P3gmoL@0?ooo`003P3oool/0?Ogm`80
oooo;@3gmoL20?O_m`H0moOg0P3oool20?O_m`80moOg0P3oool80?Ogm`80oooo0P3gmoL20?ooo``0
moOg0P3gkoL20?Ogm`80oooo6P3gmoL20?O_m``0moOg0P3gkoL20?ooo`80mnog0P3oool40?Ogm`<0
oooo103gmoL20?O_maP0moOg0P3gkoLB0?Ogm`80mnog0P3oool:0?Ogma00oooo000>0?ooob`0moOg
0P3oool]0?Ogm`80mnog1P3gmoL20?ooo`80mnog0P3gmoL20?ooo`P0moOg0P3oool20?Ogm`80oooo
303gmoL20?O_m`80moOg0P3ooolJ0?Ogm`80mnog303gmoL20?O_m`80oooo0P3gkoL20?ooo`@0moOg
0`3oool40?Ogm`80mnog603gmoL20?O_ma80moOg0P3gkoL20?ooo`X0moOg403oool000h0oooo:03g
moL20?oooa/0moOg0P3gkoLD0?Ogm`@0mnog203gmoL20?O_m`@0oooo103gmoL20?ooo`80mnog2P3g
moL20?ooo`80moOg103gkoL40?Ogm`80oooo0P3gkoL20?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3o
ool20?Ogm`80oooo2P3gmoL20?ooo`X0moOg0P3gkoL20?Ogm`80oooo1`3gmoL20?ooo`H0moOg0P3o
ool20?Ogm`80oooo103gmoL20?ooo`80mnog2P3gmoL20?ooo`@0moOg0P3ooolB0?Ogm`@0mnog403o
ool000h0oooo:03gmoL20?oooa/0moOg0P3gkoLD0?Ogm`@0mnog203gmoL20?O_m`@0oooo103gmoL2
0?ooo`80mnog2P3gmoL20?ooo`80moOg103gkoL40?Ogm`80oooo0P3gkoL20?Ogm`80oooo0P3gmoL2
0?ooo`@0moOg0P3oool20?Ogm`80oooo2P3gmoL20?ooo`X0moOg0P3gkoL20?Ogm`80oooo1`3gmoL2
0?ooo`H0moOg0P3oool20?Ogm`80oooo103gmoL20?ooo`80mnog2P3gmoL20?ooo`@0moOg0P3ooolB
0?Ogm`@0mnog403oool000h0oooo;03gmoL20?oooaT0moOg0P3oool40?Ogm`80mnog0P3gmoL20?O_
m``0moOg0P3oool>0?Ogm`80mnog0P3ooolF0?Ogm`80mnog0P3gmoL20?ooo`80moOg0P3oool60?Og
m`80mnog0P3oool20?O_m`80oooo1P3gmoL20?O_ma00moOg0P3oool40?O_m`L0moOg0P3gkoL80?Og
m`80oooo3P3gmoL20?oooaP0moOg0P3gkoL20?Ogm`80oooo0P3gmoL@0?ooo`003P3oool/0?Ogm`80
oooo6@3gmoL20?ooo`@0moOg0P3gkoL20?Ogm`80mnog303gmoL20?ooo`h0moOg0P3gkoL20?oooaH0
moOg0P3gkoL20?Ogm`80oooo0P3gmoL20?ooo`H0moOg0P3gkoL20?ooo`80mnog0P3oool60?Ogm`80
mnog403gmoL20?ooo`@0mnog1`3gmoL20?O_m`P0moOg0P3oool>0?Ogm`80oooo603gmoL20?O_m`80
moOg0P3oool20?Ogma00oooo000>0?ooobh0moOg0P3gkoLA0?Ogm`80mnog0P3oool40?Ogm`80mnog
103gmoL40?O_m`H0moOg103oool60?Ogm`80mnog203gmoL20?O_m`@0moOg0P3oool20?Ogm`80mnog
0P3oool:0?Ogm`80oooo0P3gmoL20?ooo`80moOg0P3gkoL20?ooo`80moOg0P3gkoL20?Ogm`80mnog
103gmoL20?ooo`@0moOg0P3gkoL40?Ogm`80oooo0P3gkoL20?ooo`80moOg0P3gkoL20?Ogm`80mnog
0P3oool20?Ogm`80oooo1`3gmoL20?O_mah0moOg0P3gkoLL0?Ogma00oooo000>0?ooobh0moOg0P3g
koLA0?Ogm`80mnog0P3oool40?Ogm`80mnog103gmoL40?O_m`H0moOg103oool60?Ogm`80mnog203g
moL20?O_m`@0moOg0P3oool20?Ogm`80mnog0P3oool:0?Ogm`80oooo0P3gmoL20?ooo`80moOg0P3g
koL20?ooo`80moOg0P3gkoL20?Ogm`80mnog103gmoL20?ooo`@0moOg0P3gkoL40?Ogm`80oooo0P3g
koL20?ooo`80moOg0P3gkoL20?Ogm`80mnog0P3oool20?Ogm`80oooo1`3gmoL20?O_mah0moOg0P3g
koLL0?Ogma00oooo000>0?ooodT0moOg0P3oool20?Ogm`80oooo0P3gmoL20?O_m`@0oooo0P3gmoL2
0?O_m`80oooo403gmoL40?ooo`P0moOg0P3oool<0?Ogm`80oooo2P3gmoL80?ooo`P0moOg0P3gkoL2
0?Ogm`80oooo1P3gmoL80?ooo`d0moOg103oool80?Ogm`80mnog303gmoL20?ooo`P0moOg0P3oool8
0?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3oool40?Ogma00oooo000>0?ooodT0moOg0P3oool20?Og
m`80oooo0P3gmoL20?O_m`@0oooo0P3gmoL20?O_m`80oooo403gmoL40?ooo`P0moOg0P3oool<0?Og
m`80oooo2P3gmoL80?ooo`P0moOg0P3gkoL20?Ogm`80oooo1P3gmoL80?ooo`d0moOg103oool80?Og
m`80mnog303gmoL20?ooo`P0moOg0P3oool80?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3oool40?Og
ma00oooo000>0?ooob@0moOg0P3oool20?Ogm`80oooo103gmoL20?O_m`80moOg0P3gkoL:0?Ogm`<0
oooo303gmoL20?O_m`80moOg0P3gkoL20?Ogm`80mnog3P3gmoL20?O_m``0moOg0P3oool80?Ogm`80
oooo0P3gkoL20?Ogm`@0oooo5P3gmoL20?ooo`X0moOg0P3gkoL<0?Ogm`80oooo0P3gmoL20?ooo`D0
moOg0P3gkoL20?Ogm`80oooo1P3gmoL20?oooa00moOg0P3gkoL20?Ogm`80mnog703gmoL@0?ooo`00
3P3ooolT0?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3gkoL20?Ogm`80mnog2P3gmoL30?ooo``0moOg
0P3gkoL20?Ogm`80mnog0P3gmoL20?O_m`h0moOg0P3gkoL<0?Ogm`80oooo203gmoL20?ooo`80mnog
0P3gmoL40?oooaH0moOg0P3oool:0?Ogm`80mnog303gmoL20?ooo`80moOg0P3oool50?Ogm`80mnog
0P3gmoL20?ooo`H0moOg0P3oool@0?Ogm`80mnog0P3gmoL20?O_ma`0moOg403oool000h0oooo903g
moL20?ooo`@0moOg0P3ooolM0?Ogm`80mnog303gmoL20?ooo`80moOg0P3ooolD0?Ogm`@0oooo1P3g
moL20?O_m`@0moOg103ooolF0?Ogm`H0oooo5P3gmoL60?oooal0moOg0P3oool20?Ogm`80mnog0P3g
moL20?O_m`@0moOg0P3oool40?Ogm`80oooo0P3gkoL>0?Ogma00oooo000>0?ooob@0moOg0P3oool4
0?Ogm`80oooo7@3gmoL20?O_m``0moOg0P3oool20?Ogm`80oooo503gmoL40?ooo`H0moOg0P3gkoL4
0?Ogm`@0oooo5P3gmoL60?oooaH0moOg1P3ooolO0?Ogm`80oooo0P3gmoL20?O_m`80moOg0P3gkoL4
0?Ogm`80oooo103gmoL20?ooo`80mnog3P3gmoL@0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
A`3oool2@00002d0oooo0T00001F0?ooo`=00000C`3oool004T0oooo00=000000?ooo`3oool0;03o
ool00d000000oooo0?ooo`1D0?ooo`03@000003oool0oooo04h0oooo000k0?ooo`=000000`3oool3
@00000<0oooo0d0000050?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool0103oool0
0d000000oooo0?ooo`090?ooo`9000000P3oool3@0000080oooo0d0000030?ooo`=0000000D0oooo
@0000400001000000?ooo`02@0000080oooo00=000000?oood0000000d000000103ooom00000@000
0400000@0?ooo`=000000`3oool2@0000080oooo0d0000030?ooo`9000000P3oool3@00000d0oooo
0T0000030?ooo`E0000000D0oooo@000003ooom000000?ooo`03@0000080oooo0d0000030?ooo`90
0000A03oool003`0oooo00=000000?ooo`3oool00`3oool01D000000oooo0?ooo`3ooom000000080
oooo00=000000?ooo`3oool01`3oool00d000000oooo@000000@0?ooo`04@000003oool0oooo@000
0080oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom000000080oooo00A00000
0?ooo`3ooom000000`3oool01D000000oooo0?oood000000oooo00=000000`3oool00d000000oooo
0?ooo`0?0?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3ooom000000P3oool01D000000
oooo0?ooo`3ooom000000080oooo00A000000?ooo`3ooom00000403oool00d000000oooo0?ooo`03
@00000080?oood000000oooo@000003ooom000000?oood0000020?ooo`04@000003oool0oooo@000
00<0oooo00=000000?ooo`3oool0A03oool003`0oooo00=000000?ooo`3oool00`3oool01D000000
oooo0?ooo`3ooom000000080oooo00=000000?ooo`3oool01`3oool00d000000oooo@000000@0?oo
o`04@000003oool0oooo@0000080oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3o
oom000000080oooo00A000000?ooo`3ooom000000`3oool014000000oooo0?oood0000030?ooo`05
@000003oool0oooo0?oood0000004@3oool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo
@0000080oooo00E000000?ooo`3oool0oooo@00000020?ooo`04@000003oool0oooo@00000l0oooo
00=000000?ooo`3oool00`3oool02D000000oooo@000003ooom000000?oood000000oooo@0000002
0?ooo`04@000003oool0oooo@00000<0oooo0d0000140?ooo`00?03oool2@00000<0oooo0T000004
0?ooo`=000002P3oool00d000000oooo0?ooo`0?0?ooo`05@000003oool0oooo@000003oool01400
00000`3ooom00000@00000040?ooo`=0000000<0oooo@000040000000P3oool4@00000<0oooo0T00
00030?ooo`03@000003oool0oooo00l0oooo0d0000030?ooo`9000000`3oool00d000000oooo0?oo
o`020?ooo`9000000P3oool4@00000d0oooo0T0000030?ooo`90000000H0oooo@00004000000oooo
@000003oool4@00000<0oooo00A000000?ooo`3oool0oooo0d0000140?ooo`00?03oool014000000
oooo0?oood00000C0?ooo`03@000003ooom000000100oooo00A000000?ooo`3ooom00000803oool0
0d000000oooo0?ooo`0J0?ooo`03@000003oool0oooo02/0oooo00=000000?ooo`3oool0B03oool0
03/0oooo1D0000020?ooo`03@000003oool0oooo00l0oooo00=000000?ooo`3oool0403oool2@000
00P0oooo00=000000?ooo`3oool01`3oool00d000000oooo0?ooo`0;0?ooo`9000006`3oool2@000
02`0oooo0T00001:0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-7.15527, -3.20068, 0.495855, 
  0.495855}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox[
  "To reduce a background effect of the sample image, we employ a simple \
round shape of window. After window operation, we work out the angled and low \
resolution color image data. Figure 9 shows the color image samples.",
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
sampleW=Table[win128*sample[[i]],{i,dim[[1]]}];
sampleWD={sampleW,Table[Transpose[sampleW[[i]]],{i,dim[[1]]}],
\tTable[sampleW[[k,dim[[2]]-i+1,j]],
\t\t{k,dim[[1]]},{i,1,dim[[2]],2},{j,dim[[3]]}],
\tTable[sampleW[[k,i,dim[[3]]-j+1]],
\t\t{k,dim[[1]]},{i,dim[[2]]},{j,1,dim[[3]],2}]};\
\>", "Input",
  CellLabel->"In[69]:=",
  FormatType->InputForm],

Cell["\<\
samplewDG=Table[Show[convertRGB[sampleWD[[i]]],
\tAspectRatio->dim[[2]]/dim[[3]],
\tPlotLabel->StringForm[\"`1`\",label[[i]]],
\tDisplayFunction->Identity],{i,4}];\
\>", "Input",
  CellLabel->"In[71]:="],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[{{samplewDG[[1]],samplewDG[[2]]},{samplewDG[[3]],
\tsamplewDG[[4]]}}],PlotLabel->\"Fig.9. Color images\",
\tImageSize->{400,400}];\
\>", "Input",
  CellLabel->"In[72]:=",
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[.5 1.0125 -59 0 ]
[.5 1.0125 59 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.9) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Color) show
141.000000 12.812500 moveto
(images) show
177.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.014881 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 64 8 [128 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000B59C8C000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000DEC6B5E7C6B5E7CEBDE7C6B5EFD6C6EFDECEE7D6CEDECEBDE7CEC6CEB5A5BD9C94D6BDAD\
BD9C8CB59C8CBD9C948C735AA57B5A8C634A8C6B529C7B6BA58473BD9C8CC69C84
B58C73A5846BC6A59CF7F7F7F7F7F7F7EFF7000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000A58473A58C7BA57B6BBD947BC6A594
9C7B6B7B52428C6B527B524294735AB5947BC6A594BD9C8CA58C7BD6BDADD6BDB5D6BDADDEC6B5\
E7D6C6E7CEC6D6BDADC69C84B5947BB5947BA5847394736394735A946B52735242
84523994735A9C7B63BD947BA57B63B5947BF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000008C6B528C6B52A5846BA5846B946B52A5846B845239845A42845A42
9C6B4A946B529C7352845239A57B6B9C7352B58C73A57B63B5846BB5947B946B528C5A428C5A42\
9C73529C7352B58463B58463BD8C63BD8C63D6A584D6A584C6A594A57B639C7B6B
9C7B6B8C5A42734229845239A57B63A5846B9C7B63BD947BFFFFFFF7F7F7F7F7F7F7F7F7FFFFFF\
FFFFFFF7F7F7F7F7F7000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000D6B5A5\
A5846B946B52A57B5AB58C7394735A94735AA57B638C6B528C634A9C736394735A
8C6B52946B52A57B6394735A8C634AA57B5A9C73528C6B528C634A734A31734A3184634A845239\
8452398C5A428452319C6B4A845231845231945A319C6B4AAD7352A57B63BD8C63
C69C84DEC6B5B5947BBD9C8C9C7B6B734A3194735AA5846BB5947BB5947BF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000B5947BD6B5A5D6B5A5C6AD9C\
A57B5AB58C73A57B63A57B63B58463A57B5A94735AA5846BA5846B94735AA57B63
94735AA57B63845A42A57B5A9C6B4A946B52735242734A31A57B5A7352427B5A42845A427B5A42\
845231734A31734A316B39215A39297342297342297342298452319C6B4A845A42
8C634AA5846BC69C84BD947BE7BDA5CEB5A5BD9C8CA58C73946B52C69C84946B52EFE7E7FFFFFF\
FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000A5846BC6A59CCEB5A5DEAD9CD6B5A5C6A594\
BD947BBD947BB58C73BD947BBD947BB58C73A5846BA58C73B58C73A57B63B58463
B584638C634AC6946BA57B5A8C634ABD947B8C634A845A42A57B638C634A8C634A946B52845A42\
8C5A428452317342298452398452399C63398452397B5A429463428C5A42845239
844A318C5A429C7352B58463B58463C69C84BD947BE7BD9CD6B5A5A5846BA57B5ABD9C8CA5846B\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000946B52A5846BB58C73B58C73BD9C8CDEAD9CD6B5A5DEAD94CEAD94\
D6A58CD6AD8CC69C84C69C84C69C84B58C73BD947BB58C73BD947BB58C73BD947B
B5846BBD947BA57B5A9C7352A57B6B946342A5846BA57B5AB58C739C7352A57B63A57B5AA57B63\
C6946B8C634A9C73529C7352B5846BA57B5A946B52946B52845A427B5A42734A31
7352428C634A8452398452397B5A427B5A42946342B5734AC6946BD6AD84E7C6ADBD9C8CD6AD8C\
B58463F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000007B5A429C7352A57B5A8C634AB58C73C69C84D6BDADE7C6B5E7C6B5E7C6B5E7BDA5\
E7BDA5D6B5A5DEAD9CD6A584CEAD94D6A58CD6A58CD6A584D6A58CD6A584D6A584
C6946BC6946BB58C73B58C73B5846BB58C73B5846BAD7352B5846BB584639C73529C6B4AB5846B\
9C7352B584639C7352AD7352A57B63A57B5AA57B638C634A946B5294735AAD7352
94735A9C735294735A9C7352845239845A428C6B529C6B4A9C7352A57B5AA57B5AC6946BD6B5A5\
D6B5A5C69C84F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000946B528C634A9C7352A57B63BD947BD6A58CE7BD9CDEAD9CD6B5A5E7B59CE7B59CEFC6AD\
EFC6ADEFC6ADEFC6ADE7C6ADE7BDA5E7BDA5E7BDA5E7BDA5E7B59CDEAD9CDEAD8C
DEAD94DEAD94D6A584D6A584D69C7BD69C7BD69C7BD69C73DE9C7BD69C7BD69C73D69C73BD947B\
CE946BCE946BCE946BCE946BC6846BB58C73BD947BB58C73B5846BB57B5A9C6B4A
8C634A94735A946B52735A4A946B52946B52734A318C634A9C6B4A9C6B4A9C73529C6B4ABD8C63\
B58463DEAD94E7BD9CF7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000845231
7B5A428C5A429C7352B58463BD947BC69C84D6B5A5E7B59CE7BDA5EFC6A5EFB59CF7C6B5F7C6B5\
EFCEB5EFCEB5EFC6B5EFC6ADF7C6B5F7CEB5F7CEB5F7D6BDEFC6B5EFCEB5EFC6AD
EFC6ADEFC6A5EFB59CE7B59CE7B59CEFB594EFC6A5EFC6A5EFBD9CEFB59CEFBD9CEFB594E7B59C\
E7B59CDEAD8CE7AD94DEAD94D6A58CD6A58CD69C7BBD947BBD947BB58C73B5846B
AD7352A57B5A9C6B4A735242735242734A31734A315A42397342295A3121A5846B946B529C7352\
9C6B4AD69C7BC6946BE7BD9CF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000845A42A57B5A
7B5A42A57B5AA57B5ABD8C63C69C84DEAD94E7BD9CE7C6ADEFC6ADEFC6A5EFC6ADF7CEB5F7CEB5\
F7D6BDF7CEB5EFCEBDF7D6BDF7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5
F7CEB5F7D6BDF7CEB5EFC6ADF7CEB5EFC6ADF7CEB5EFC6ADEFC6ADEFC6A5EFC6ADEFC6ADEFC6A5\
EFC6A5E7BD9CEFBD9CE7B594E7B594DEAD9CDEAD8CCEAD94BD947BD69C7BCE946B
B5846BA57B639C73529C6B4A845A42734A31735242946B524221183918103921187B5A42845239\
A57B5A9C6B4AAD7352C6946BE7BDA5F7EFF7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000094735A946B52845A428C634A
84634A8C634AAD7352BD947BC69C84DEAD94EFC6A5EFC6ADEFC6ADF7CEB5F7CEB5F7D6BDF7D6BD\
F7CEB5EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFD6C6F7D6BD
F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7CEB5F7D6BDF7CEB5EFC6ADEFC6ADEFC6ADEFC6AD\
EFC6A5EFC6ADEFBD9CE7B59CE7B59CE7B59CE7B594DEAD8CD69C7BD6A58CBD947B
BD947BBD8C63AD7352945A42845239845A427342295A39295A3929422921522918211818211008\
A57B5AA57B63946342B57B5AC68C63E7CEBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000735242845A427B5A427352427B5A42
845A42946B529C7352C6946BD6AD8CE7BDA5E7BDA5EFC6ADF7CEB5F7CEB5F7D6BDF7D6BDF7D6BD\
EFD6C6EFD6C6F7DECEF7DECEEFD6C6F7D6BDF7D6BDEFD6C6EFD6C6EFD6C6EFD6C6
F7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7CEB5EFCEADEFCEADEFC6AD\
EFC6A5EFC6A5EFC6ADE7BDA5E7BD9CE7B594E7AD94DEAD8CDEAD8CDEA584DEA584
CE946BB58C73B5846BAD73529C6B4A8C5A42734A315A39295A3929522918422118522918391810\
291008946B529C73529C6B4ABD8C63DEAD8CEFEFE7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000845239845239845231845239845239735242
8452399C6B4AA57B63B58C73C69C84DEAD9CE7BDA5EFC6ADF7CEB5F7CEB5F7D6BDEFD6C6EFD6C6\
F7DECEEFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEEFD6C6F7DECEF7D6BDEFD6C6
F7DECEEFD6C6F7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7D6BDF7CEB5F7C6B5EFCEAD\
EFC6ADEFC6ADEFC6A5EFC6A5E7B59CE7B59CDEAD9CDEAD8CDEAD8CD6A584D6A58C
CE946BCE946BBD8C63A57B63A57B5A9C73528C5A425A39295A3121422118422921311818422118\
422118A57B63B5846B8C5A42AD7352C6946BE7BD9CF7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000007B5A427B5A42845239845239845231845A42845239
8C634A8C634AA57B5AB58C73C69C84D6A58CE7BD9CEFC6ADEFCEB5F7D6BDF7D6BDEFD6C6F7D6BD\
F7DECEF7DECEF7D6BDF7DECEF7D6BDF7DECEF7D6BDEFD6C6F7D6BDF7DECEF7D6BD
EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7C6B5F7CEB5F7CEB5EFC6AD\
EFC6ADEFC6ADEFB59CEFC6A5E7B59CE7B59CDEAD94DEAD8CDEAD8CDEAD8CD6A584
C69C84D69C7BB5846BA57B639C73529C73529C6B4A7B5A426B39215A3121391810391810422921\
391810946B52946B529C73529C6339C6946BC69C84D6A58CF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000007352428C5A42946B52946B52845A428C634A8452397B5A42
946B528C634A9C7352B5846BC6946BD6A58CE7BDA5EFC6ADF7CEB5F7CEB5F7CEB5F7D6BDF7D6BD\
F7D6BDF7DECEF7DECEEFD6C6F7D6BDF7DECEF7DECEEFD6C6F7D6BDF7DECEF7D6BD
EFD6C6EFD6C6F7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5F7D6BDF7CEB5F7CEB5EFC6ADF7CEB5\
EFC6ADEFC6A5EFC6A5E7BDA5E7BD9CE7BDA5E7B594DEAD94DEAD8CD6A58CD6A584
BD947BCE946BC6846BB58463B584639C6B4A9C6B4A8C5A42734A316B3921522110391810291008\
2910087B52428C634AA57B5AAD7352C69C84C6946BD6AD8CC6946BF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000084523984523984523984634A8C634A845239845A42845239
845A42845239A57B5AB57B5AC6946BE7B59CE7BDA5EFCEADEFCEBDF7CEB5F7D6BDF7D6BDEFD6C6\
EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6BDF7D6BDF7DECEF7DECEF7DECE
F7DECEF7DECEEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7C6B5F7CEB5F7CEB5F7CEB5EFCEADEFC6AD\
EFC6ADEFC6ADEFB59CE7BDA5E7BD9CE7BDA5E7B59CDEAD8CDEAD94DEA584D6A584
BD947BCE946BC6846BBD8C63B57B5AAD73529C6B4A845239734A315A3929734229422118391810\
3918105A31219C7352D69C73B58463D69C7BB57B5A9C7352946342CEAD94F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000844A29735242845A42A58C73946B52845239845A427B5A42845A42
845A428C5A42A57B5A9C7352D69C7BE7C6ADEFCEB5EFCEB5EFCEBDF7D6BDF7D6BDEFD6C6F7DECE\
F7DECEEFD6C6F7D6BDF7DECEF7DECEF7DECEF7D6BDF7DECEF7DECEF7DECEF7DECE
F7D6BDEFD6C6F7DECEEFD6C6EFD6C6F7DECEEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7C6B5F7CEB5\
EFC6B5EFC6ADE7C6ADE7BDA5EFC6ADE7B59CE7B59CDEAD94D6A584D6A584D69C7B
D69C7BBD947BC6946BBD8C63B56B52AD7352AD73528C5A429C6B4A734229522918522918422118\
5A3121522110BD947BA57B5A8C5A42BD947BAD73529C6B4AD6AD8C9C6B4AD6BDAD
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000C6A5949C7352734A31734A3184634A845239734A31734A31734A31845239
945A318C634A9C7352A57B5AD6A584E7C6B5EFCEB5EFCEB5EFC6ADD6A584BD9C8CDE8473DEAD9C\
EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DED6
EFD6C6EFD6C6F7DECEF7DECEF7DECEF7D6BDF7D6BDEFD6C6F7D6BDF7CEB5F7C6B5EFC6ADEFC6AD\
EFC6ADE7C6ADE7C6ADC69C84A57B63AD7352A57B63A57B63BD947BC69C84BD947B
CE946BD69C73CE946BBD8C63AD73529C7352AD73528452396B3921734A316B39215A3121391810\
3918104221188C634A94735A8C5A42A57B5AAD6342C6946BC69C849C6B4ABD8C63
EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFE7E7FFFFFF6B39217B4A295A31216B3921734A31845239734A319C6339
B56342B57B5ABD8C63C6846BC69C84EFC6ADDEC6B5E7BD9CEFC6B5F7D6BDEFD6C6EFD6C6F7C6B5\
B5846BA57B6394735AB56B52D6A584EFC6A5F7CEB5F7CEB5F7D6BDF7DECEF7D6BD
F7DECEEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5F7CEB5EFC6A5E7AD94BD8C63945A42845239945A42\
B56B52DEA584E7AD9CE7C6ADEFC6ADEFC6ADEFB59CE7BDA5DEAD94DEA584BD947B
A57B5ACE946BB58C73B5846BAD73529C6B4A9C6B4A8C5A426B39216B39215229185A3121522918\
522110735242845A42946B52A57B5A9C7352945A31BD8C63BD8C63D6AD8CBD947B
C69C84F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F7F7F7EFE7DEA58C7B946B52734A31734229734A31734A316B39219C6B4A
C68463CE946BC69C84BD947BD6A58CE7C6B5EFCEB5EFCEB5F7D6BDEFCEBDEFC6ADEFC6B5E7BDA5\
E7B59CE7AD9CE7B59CE7BDA5E7B59CD69C7BDEA584E7AD94EFC6A5F7D6BDF7CEB5
EFD6C6EFD6C6F7D6BDF7CEB5EFCEADEFC6ADE7B594D69C73DE9C7BBD947BD6A584D6A58CD6A584\
BD947BBD947BBD947BCE946BD69C7BD6A584D6A584DEAD8CE7AD8CDEAD94D6A58C
D6A584D69C7BCE946BC6846BBD8C63B57B5A945A428C634A8452396B39216B39215229185A3929\
734A317342296B39219C6B4ABD8C639C6B4A9C6339C6845ABD947BDEAD949C7352
BD947BEFDECEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7B5947BD6C6C6A58C7394735A7B5242734A31845239845239945A42
CE7363EFB59CE78C7BD69C7BDEAD8CEFC6B5EFCEB5E7B59CCEA594C6846B734A31846352846352\
5A42394229215A39298452398C6B52846352A57B63BD947BE7AD94EFBD9CF7CEB5
F7CEB5F7D6BDF7CEB5EFC6ADEFBD9CE7B59CDEA584BD947BC6846BAD735294735AA58C84A58C84\
5A39295229185A39295A3929734A315A4239735A4A7B5242A57B63B58463B5846B
CE946BD69C7BD69C7BBD947BB5846BB57B5A945A428C5A428C5A42734A316B39214221185A3929\
6B39216B3921734A319C6B4AAD73529C6B4A9C6339B57B5AAD7352D6AD84946342
BD8C63D69C73EFE7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7F7F7B5846BBD9C8C9C73528C634A5A3121845239945A426B3118
522918F7C6B5E7AD8CE7A594DEAD94EFCEBDF7D6BDEFCEBDE7C6ADE7AD9CB5846BC6846BD6BDB5\
E7D6CE7B7373736B63635A52847B73A57B6BC69C84BD947BE7AD9CDEAD94EFC6A5
F7D6BDF7D6BDEFCEB5EFC6ADE7B59CDEA584BD947BB5846BC6846BC69C84AD4231DEC6C6EFE7E7\
8C736394735A7B6B5A948C846B635ABD9C949C73528C6B52B5846BD6A584D6A584
DEAD94DEAD8CD6A58CD69C7BD69C73B5846BAD73529C6B4A845231734A315A3121291008422118\
8452398C5A427342299C6B4AB5846BB584639C6B4AA57B5AAD6342DEAD8C844A29
BD947BD6AD8CD6AD8CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7F7F7FFFFFF9C6B4AA57B638452398C5A42845239945A42522110
845231844A31F7C6B5CE946BDEA584EFCEB5F7D6BDEFD6C6EFD6C6EFD6C6EFCEBDE7C6B5DEAD9C\
BD947BB58C73D6A58CCEA594BD947BDEAD9CDEAD9CEFCEBDEFCEBDEFC6B5EFC6B5
F7D6BDF7D6BDF7D6BDEFC6ADDEAD94D69C7BC69C84D69C7BE7BD9CDEAD9CE7C6B5E7AD9CDEAD9C\
C6A59CBD9C8CB5846BB58C73C69C84C69C84C69C84CEA594E7BD9CE7BDA5DEAD9C
DEAD9CDEAD9CDEAD8CD6A584C69C84C6846BB57B5A945A42845239734A316B39215A31215A3121\
8452398452318C634A8C5A42B5846BBD8C63B57B5AB57B5A945A31E7BD94945A31
8C4A31C69C84D69C73E7D6CEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7EFF7F7F7F7A57B6BB58C739C6B4A734A319C6B4A734A318C4A31
5A3121734A317B4A29E7C6ADF7C6B5E7C6ADEFD6C6EFD6C6F7DECEEFD6C6EFD6C6F7D6BDEFD6C6\
EFCEBDEFCEBDEFB59CE7C6ADEFC6ADEFC6ADEFC6B5EFCEBDF7D6BDEFCEB5F7CEB5
F7D6BDEFD6C6F7D6BDEFC6ADE7A594DEAD8CD6A58CDEAD94DEAD94E7BDA5E7C6B5EFC6B5EFCEBD\
E7C6ADE7C6ADE7BDA5E7C6ADE7C6ADE7C6ADE7C6ADEFC6ADEFC6B5E7C6ADE7C6AD
D6B5A5E7BD9CDEAD8CD6A584D69C73C68463AD7352945A31844A315229185221106B3921734A31\
8C5A429C63398C5A428C5A42C69C84CE946BCE946BD69C73844A31DEAD84945A42
8C5A42B5846BD6A584E7C6ADF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF79C73529C7352845239734A31734229845239
844A315A3121734229845239EFC6B5F7CEB5EFCEBDEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6\
EFD6C6F7D6BDEFD6C6EFCEBDEFD6C6EFD6C6EFD6C6EFD6C6F7D6BDF7D6BDEFC6B5
EFD6C6EFD6C6F7D6BDE7BDA5E7AD94DEAD94E7B59CE7BDA5E7BDA5E7C6ADEFC6B5EFCEBDEFCEBD\
EFCEBDEFD6C6EFCEBDF7D6BDEFCEBDEFC6B5EFC6B5EFC6ADEFC6B5E7C6ADE7BDA5
E7BDA5DEAD94D6A584D69C7BCE946BB57B5A9C6B4A8452397342296B31186B39216B3921845239\
945A318C634A845239844A29D6AD8CD69C73C6946BD69C7BC69C84DEAD8C945A31
AD7352AD7352A5846BD6AD84F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79C7352945A318452315A31217B5A42734A31
734A31844A315229186B39215A3929EFC6ADEFC6B5EFD6C6F7D6BDEFD6C6EFD6C6F7DECEF7DECE\
EFD6C6EFD6C6F7D6BDF7DECEEFD6C6EFD6C6EFD6C6EFD6C6F7D6BDEFCEBDF7D6BD
F7D6BDF7D6BDF7C6B5E7B59CDEAD94E7B59CE7BD9CE7BDA5E7BDA5E7C6ADEFCEB5F7D6BDEFCEBD\
F7D6BDEFD6C6F7D6BDF7C6B5EFCEBDEFCEBDEFCEBDEFC6B5EFC6ADE7BDA5E7B59C
DEAD94DEAD8CD69C7BD69C73C67B5AB56B52945A42734A316B39216B39216B3921845239845231\
9C63399463428C5A4294735AB5846BD69C7BD69C73D69C73D6AD84C68C63AD6B39
844A29A57B5ABD947BD6AD8CE7DED6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7B5846B945A317B4A297B4A29845239
734A317B4A29844A31522918422118522918CEAD94EFCEB5EFCEB5F7D6BDEFD6C6EFD6C6EFD6C6\
EFD6C6F7DECEF7DECEF7DECEEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5EFC6B5F7D6BD
F7D6BDEFC6ADEFB59CDEAD94DEAD94DEAD8CE7B594E7B59CE7BDA5EFC6ADEFCEB5EFC6B5F7C6B5\
F7C6B5F7D6BDEFCEBDF7C6B5EFC6B5EFC6ADEFC6ADEFB59CE7B59CE7B59CDEAD94
DEA584D69C7BD69C73C68463B56B529C6B4A9463424221182110085A31215229188452398C5A42\
7B4A29945A319C63398452319C7352C69C84D69C73DEAD84EFCEADAD7352C68C63
8C5A42B58463AD7352E7BD94E7CEBDDECEBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F7EFF7F7F7F7F7F7F7F7F7F7F7EFE7C6946B9463429463426B3921734229
7342297B4A29844A317B4A29422118632910422118EFC6ADF7C6B5EFCEBDF7C6B5F7D6BDF7D6BD\
EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7C6B5EFD6C6EFD6C6
EFD6C6F7CEB5EFC6ADE7AD94D6A58CDEA584DEAD8CD6A58CDEAD94E7B59CEFC6ADEFC6B5EFC6B5\
EFCEB5F7CEB5EFC6ADEFC6ADEFC6A5EFC6ADEFC6A5EFB59CE7AD94E7AD8CDEAD8C
DEA584D69C73C6846BB57B5AAD7352AD6342734A312110083918105A39297B5A428452398C5A42\
9463427B4A29845231734A319C7352C6845ACE946BDEAD8CE7BDA5B5734AB57B5A
9C7352B57B5AC6946BE7BD9CE7C6ADC69C84DECEBDF7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7\
F7F7F7F7F7F7F7F7F7F7EFF7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7E7D6CEBD8C63946342945A426B3921
734A31844A317342297B4A29844A31632910632910A57B63E7C6ADF7C6B5F7C6B5F7C6B5EFD6C6\
F7D6BDF7D6BDF7D6BDEFD6C6F7CEB5F7CEB5F7C6B5F7D6BDEFC6B5EFD6C6EFD6C6
EFD6C6F7C6B5EFC6A5E7B594E7AD9CE7AD9CDEAD94DEAD8CDEA584DEA584EFB59CEFC6ADEFC6AD\
F7C6B5EFC6ADEFC6ADEFC6ADEFB59CEFB59CEFB59CE7B594E7AD8CDEAD8CDE9C7B
DE8473DE8473C68463B57B5AAD6B42946342291008422118391810734A31845239946342734229\
9C6B4A845231945A315A3121C6946BBD8C63D6AD84E7BD9CB57B5ABD8C63AD7352
B57B5AB58463BD947BD6AD8CDEC6B5DEC6B5D6BDADDECEBDF7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7D6AD8CB58463946342845231
8C4A316B39217B4A297342297B4A298442296B31185A3121EFC6B5E7C6ADEFC6ADEFC6ADF7CEB5\
F7C6B5F7D6BDF7D6BDF7CEB5F7CEB5F7CEB5F7C6B5EFD6C6DE9C7BDE7B6BEFC6AD
EFC6ADEFB59CE7A594B56342B56342C6846BDE9C7BB57B5AD69C73DEAD8CE7B59CEFC6A5EFC6A5\
EFC6ADEFC6ADEFC6ADEFC6A5EFB59CE7B59CE7AD94E7AD8CDEA584DEA584D69C7B
D69C73CE946BC68463B56B52AD63427342293918104229215A3121734A31845239845A429C6B4A\
9C6B4A8452319C6B4A8C5A42BD8C63DEAD84D69C73DEAD84C6845ABD8C639C6339
B57B5AB57B5AD69C73E7BD94D6BDADEFE7E7CEAD94EFE7E7D6B5A5F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F7EFF7F7EFF7F7F7F7F7F7F7EFE7E7DEC6B5C6A594BD947B9C6B4A
9C63399463428442297B4A297B4A29734A317B4A296B3921B58463E7C6B5EFC6B5EFC6B5F7CEB5\
F7CEB5F7CEB5F7CEB5F7D6BDF7CEB5EFCEB5F7CEB5F7CEB5F7CEB5EFC6ADEFC6AD
E7B59CDEAD8CDEA584E7AD94DEAD94DEA584DEAD8CE7AD94E7B594E7B59CEFBD9CE7BDA5EFC6A5\
EFC6ADEFC6ADEFB59CEFB59CE7B59CE7AD94DEAD8CDEA584DEA584D69C7BD69C7B
D69C73CE946BC67B5AB56B528C5A425A39296B39215A4239845A428452399C7352946342B5734A\
8452319C6339845239D6AD8CE7BD94D69C73DEA57BC68C63C6946BA57B5AB57B5A
BD8C63C69C84D69C73E7BD9CD6B5A5C6946BE7DED6E7BDA5F7EFF7EFE7E7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000F7EFF7F7EFF7F7EFE7F7EFF7F7EFF7DECEC6C69C84B57B5A
9C63399C6B4A844A29844A316B39217B4A297B4A297B4A297B4A29EFCEB5EFCEB5EFC6B5EFCEB5\
F7CEB5F7C6B5F7C6B5F7CEB5EFCEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5
EFCEB5EFC6ADEFC6A5EFC6A5EFC6A5E7B59CE7BD9CEFBD9CE7B59CE7BDA5E7B59CEFC6A5E7B59C\
EFC6A5E7B59CE7B59CE7AD94E7AD94E7B594DEAD8CDEA584DE9C7BDEA584D69C73
CE946BCE946BC684639C6B4A7342295A39293918107352428452399463429C6339AD73529C6339\
B57B5AA57B5ACE946BE7BD94E7BD94CE946BD69C73C6845ABD8C63B5734ABD8C63
B5734AD69C73D6AD84E7BDA5CEAD94C6946BD69C7BE7D6CEEFE7DEEFE7DEE7D6C6F7F7F7F7EFF7\
F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000F7EFE7F7F7F7F7EFF7EFEFE7F7EFE7EFE7DEDECEC6D6AD8C
B584639C6B4A9C6B4A8C5A428C4A29844A297342297B4A29844221845231EFCEB5EFC6ADEFCEB5\
EFCEADEFC6ADEFCEADEFC6A5EFCEADF7CEB5F7CEB5F7D6BDEFD6C6EFC6B5EFC6AD
F7D6BDEFC6ADEFC6A5F7CEB5F7D6BDEFC6B5EFC6ADE7BDA5E7B59CE7BDA5E7B59CE7B594E7B594\
E7B59CE7B594E7B59CE7B594E7AD94DEAD8CDEAD8CDEA584DEA584D69C7BD69C73
CE946BCE946BB57B5A845231423129291008845A42734A31845A429C7352BD8C639C6339C6845A\
AD6B42C6845AE7BD9CE7BD9CD69C73CE946BBD8C63B5734AB5734ABD8C63CE946B
D69C73CE946BE7BDA5E7C6ADC69C84C69C84C68C63E7DED6EFE7DEEFE7DEEFE7E7EFE7DEF7F7F7\
F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7E7D6CED6C6B5
D69C73C6946BAD73529463428C4A31945A31844A296B31187B42216B3118945A31EFCEBDEFCEBD\
EFCEB5EFC6ADEFC6ADEFC6A5E78C7BDE8473AD73529C4A31AD4A31BD5242AD7352
BD5242BD5242C65A4AB552399C4A319C31219C4229AD4A318C3121AD42319C4229844229945A42\
DE8473E7B594E7B594E7B594DEAD8CDEAD8CDEAD8CD69C7BD69C7BD69C73D69C7B
C68463B57B5A8C5A424A18083918106B3921734A31845A42BD8C63D6A584945A31D6A584B57B5A\
D69C7BE7BD9CEFCEADCE946BCE946BB56B39C6845AB57B5ABD8C63C68C63B57B5A
D6AD84E7BD94E7BDA5D6BDADD69C73D6AD84C69C84D6B5A5E7DED6EFEFE7EFE7DEEFEFE7F7EFF7\
EFEFE7000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000F7F7F7F7F7F7F7EFE7F7F7F7EFE7E7E7DED6
E7D6C6D6AD8CC6946BA57B5A9C6B4A9C6339945A317B4A298452397342296B39217B4A29EFCEBD\
EFC6B5EFC6ADEFC6ADEFC6A5EFCEADEFC6ADE78C7BDE8473DE8473DE8473EFC6B5
EFB59CE78C7BE78C7BE7A594EFB59CDE8473DE8473DE7B6BC6846BCE7363CE6B5AD69C7BDEAD8C\
DEAD94E7B594E7B59CDEAD94DEAD8CDEAD8CD6A584D69C7BCE946BDE8473C68463
B57B5A734A31522918522918522110845239522918D6A584DEAD8C9C6339D6AD8CB57B5ADEA57B\
D6AD84BD8C63C6845ACE9463AD6331C6845AB57B5ABD8C63C6946BCE946BD69C7B
D6AD8CE7BDA5E7C6B5BD947BB58463C6946BD69C73CEAD94EFE7DEEFE7DEEFEFE7EFEFE7EFE7DE\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000F7F7F7F7F7F7F7EFF7F7EFF7EFE7E7
E7D6C6DECEBDD6AD8CC6946BB5734AB5734AAD63428C4A31945A318452316B31186B3921844A29\
E7C6B5EFCEB5EFCEB5F7CEB5EFCEADEFC6ADEFC6ADEFC6A5E7BDA5E7AD94E7AD8C
DEA584DE9C7BE78C7BE78C7BE78C7BE78C7BE78C7BDEA584DE9C7BDEA584DEAD8CDEA584E7B594\
E7B594E7B59CDEAD94DEAD8CDEA584D6A584D69C7BCE946BCE946BC684638C5A42
8442297B4A296B39215229186B39218C634ACE946BAD7352945A31D6A584C67B4ACE9463B57B5A\
9C6339AD6B42CE8C5AC67B4AB5734ABD8C63B57B5AD69C73C6946BD6AD84D69C73
D6AD84E7C6ADD6AD84D69C73C69C84C69C84D69C73D6AD8CE7BDA5EFE7DEEFE7DEF7EFE7000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000F7F7F7F7F7F7F7EFF7EFE7E7
EFE7E7E7CEBDDECEBDC69C84C68C63AD7352B5734A946342945A31945A318452316B39216B3118\
844A29845A42EFC6B5EFC6ADEFCEADF7CEB5F7CEB5F7CEB5F7C6B5EFCEADEFC6AD
EFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFB59CEFB59CE7BDA5EFC6A5E7BD9CEFBD9CE7B59CE7B59C\
DEAD8CE7AD8CDEAD94DEAD8CDEA584D69C73CE946BCE8C639C63399C4A319C6339
8C4A318C4A296B39216B3921845239BD8C63B57B5A9C6B4AC69C848C4221B57B5A945A31AD6342\
B56B42C67B4AAD6B39C67B4ABD8C639C6339BD8C63BD8C63D69C73D69C73CEAD94
DEAD8CE7BD94BD8C63B56B42BD8C63C69C84C6946BD6AD84E7BD94E7D6CEEFEFE7000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000F7F7F7F7EFF7
EFEFE7EFE7E7DECEBDD6BDADBD947BBD8C63B57B5AAD6B429463429C6339945A31945A316B3921\
6B31187B42216B3921A5846BEFCEB5F7CEB5EFC6ADF7CEB5F7CEB5F7D6BDF7D6BD
F7D6BDF7D6BDEFD6C6F7D6BDF7C6B5F7C6B5EFC6ADEFC6ADEFC6ADE7BDA5E7B59CE7BD9CE7B594\
E7AD8CDEAD94DEA584D69C7BC6846BCE946BAD6342AD6342AD6B429C6B4AAD6342
9463429C4A31844A31734229C67B4AAD7352B57B5AB5734A6B31185221107B42219C6339C67B4A\
C6845AC67B4AC67B4AC6845AAD6B42C68C63BD8C63C6946BD69C73D6AD84E7BD9C
E7BD94BD8C63B5734ABD8C63C67B4AC6946BD6B5A5E7BD94CEB5A5000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000EFEFF7
F7EFE7F7EFF7F7EFF7E7CEBDCEAD94C6946BBD8C63AD7352AD6B42AD6B429C6339945A319C6339\
6329106B39217B4A296B39216B3921B58C73EFC6B5F7CEB5F7D6BDF7CEB5F7D6BD
F7C6B5F7D6BDF7C6B5F7CEB5F7C6B5EFC6ADEFC6A5EFC6ADEFB59CEFB59CE7AD94E7AD8CDEA584\
DEA57BD69C73CE946BB5734AB5734AB5734AB5734AC67B4AB5734AB57B5AB5734A
AD63429C6B4A845239844221B5734A945A31C6845A7B39186B3118522110632910AD6B39B56B42\
945229B56B42CE8C5AAD6B39BD8C63B5734AC6845AD69C73DEAD84E7BD94E7BDA5
D6AD8CB56B42BD8C63BD8C63CE946BC68C63D69C73D6AD8C000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000EFEFF7EFEFF7EFE7DEDEC6B5D6AD84C6946BB57B5AB5734AAD6B429C6339B5734A9C4A31\
945A315221107342296B39216B39216B3118845231DEAD94E7C6ADEFC6ADEFC6AD
EFC6ADEFC6A5EFC6A5EFB59CEFB59CEFB59CE7AD9CE7AD94E7AD94DEAD8CDEA584D69C7BC67B5A\
C67B5AC67B4AC67B5AC67B5AB57B5AB57B5AB57B5AC6845AC67B5AB57B5AC67B4A
B5734AAD6B42AD6B42C67B4A8C4A298C4A319C63398C5A428442216B31186B3921AD6331844221\
9C6339C67B4AC67B42B5734AAD6B39B5734ACE8C5AD69C7BDEAD84DEAD8CD6AD84
C6946BC6946BB57B5AB56B42D6AD84D6AD84000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000EFEFE7F7EFF7E7DED6D6B5A5D6AD84BD8C63B57B5AAD6B429C6B4A945A31945A31\
9C63398C4A297B39186B31186B39216B39217B3918DEAD94DEAD94DEAD8CDEAD8C
E7AD8CDEAD8CDEA584DEAD8CDEA584DEA584D69C7BDE9C73DE9C73CE946BCE946BCE946BC6846B\
CE8C63CE8C63C6846BCE946BCE946BC6846BCE946BCE946BCE946BC68463C6845A
C68463C6845AB5734ACE8C5AAD6B428C4A299C6B4A9C6B4A9C6339945A318442217B4221632910\
AD6331C67B42B56331C67B42B56B42C67B4ACE9463DEA573D69C7BDEAD84BD8C63
BD8C63CE9463BD8C63CE946BC6946B000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000F7EFE7E7D6C6D6AD8CD69C73C6845AB57B5AAD6B42B5734A945229\
9C63399C6339945A315A31216329106B31186B3921E7BD9CDEAD94E7B59CDEAD94
E7B594E7B594E7AD8CE7AD8CE7AD8CDEA584DEAD84DEA57BDE9C7BDEA57BDE9C7BDE9C7BDE9C73\
CE946BCE946BCE946BD69C73D69C73DE9C7BD69C73D69C73CE946BCE946BCE946B
CE8C63CE8C63C68463BD8C63B5734AAD6B42AD6B399C6339AD6342AD6B42AD6B429C63399C6339\
9C6339AD6331B56B39B56B42C67B42CE8C5ADEA573D69C73DEAD84C68C63AD6B39
AD6B39B5734AC68C63000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000D69C73D69C73BD8C63B5734AAD6B42AD6B42\
8C4A299C63399452298442216329106B3921632910E7BD9CE7BD9CE7BD9CE7BD9C
E7BD9CE7B594EFBD9CE7BD94E7AD8CEFB594E7AD8CDEAD84E7AD8CDEAD84DEA584DEAD84DEA584\
DEAD84DEA584DEA584DEA584DEAD8CDEAD84DEA57BDE9C7BD69C7BDEA57BD69C7B
D69C7BD69C73CE946BC6845ACE946BCE8C63B57B5AB56B52B5734AAD6B42AD6B42945A319C6B4A\
9C6B4A9452299C6339B56B42CE8C5ACE8C5ACE8C5ACE946BC67B4AC67B4AB5734A
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000BD8C63B57B5AB56B42AD6B42\
8C4A29844221945229945A318C4A296B39216B3118E7BDA5E7B59CEFC6A5E7BDA5
E7B594EFBD9CE7BD9CE7BD9CEFBD9CEFB594EFB59CE7BD94EFB594E7AD8CEFB594EFB594E7AD8C\
E7AD8CE7AD8CE7AD8CEFB594DEAD84E7AD8CDEAD8CDEAD84E7AD8CDEA57BDEA584
DEA57BD69C7BD69C73C6846BCE8C63CE9463D69C73CE946BC6845AC68463C6845AC6845AB57B5A\
9C63399C6B4A9C6B4AAD6B39CE8C5AC67B4AC67B42B56B39AD6B39000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000B5734A\
AD6B398C4A298C4A297B39188442218C4221632910DEAD94E7BD9CE7BDA5EFC6A5
E7BD9CE7BD9CEFBD9CEFB594E7BD94EFBD9CEFB594E7BD94EFBD9CEFBD9CE7BD94EFB594E7BD94\
EFB594EFB594EFBD9CE7B594E7B594E7B594E7BD94DEAD84EFB594DEAD84E7AD8C
DEAD8CDEAD84DEA584DE9C7BCE946BD69C73D69C73E7BD94E7BD9CCE8C63CE946BD69C73D69C73\
CE8C63B57B5AB56B529C6339C67B42B56B39000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000007B39186329105221106B3118DEAD94DEAD94E7B594E7BD9CE7BD9C
E7BDA5E7BD9CEFC6A5EFBD9CEFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFB594EFBD9CEFBD9C\
E7BD94EFBD9CEFB594E7BD9CEFB594E7B594E7B594E7AD8CE7B594E7B594E7B594
E7B594E7AD8CE7AD8CDEAD84DEA584DEA57BDEA57BDEA57BDEAD84E7BD9CDEAD84D69C7BD69C73\
D69C7BDE9C73DE9C73000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000DEAD9CDEAD94E7B594E7B594E7BDA5
E7BD9CEFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFBD9CEFC6A5EFBD9CEFBD9CEFBD9CEFBD9CE7BD9C\
EFBD9CEFBD9CEFB594EFB594E7BD94EFB594EFBD9CEFBD9CE7BD9CE7BD94EFB594
E7B594EFB594E7AD8CDEAD84E7AD8CEFB594E7AD8CE7AD8CEFB594E7AD8CE7BD94E7B594000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000EFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFBD9C\
EFB594E7BD9CEFBD9CEFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9CE7BD9CEFB594
E7BD94E7B594EFBD9CEFBD9CEFBD9CEFB594000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000EFBD9C000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.00744048 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 128 8 [64 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000EFBD9C000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000EFBD9CEFBD9CEFB594EFC6A5EFC6A5EFBD9CEFC6A5EFC6A5EFC6A5EFC6A5\
EFC6A5000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000EFB594EFBD9CE7B594EFB594EFBD9CEFBD9CEFC6A5EFBD9CEFB594EFBD9CEFBD9CEFC6A5\
EFBD9CEFC6A5EFC6A5000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
E7AD8CE7B594E7B594E7B594EFB594EFB594EFC6A5EFBD9CE7BD94EFBD9CEFC6A5EFBD9CEFBD9C\
EFC6A5EFBD9CEFBD9CEFBD9C000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000E7B594E7AD8C
E7AD8CEFB594DEAD84EFB594EFB594E7BD9CEFBD9CE7BD94EFB594EFBD9CEFBD9CEFBD9CEFC6A5\
EFC6A5EFBD9CEFBD9CE7BDA5E7B594DEAD9C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000DEAD8CE7BD9CE7AD8C
DEA57BE7AD8CE7AD8CE7B594E7B594EFB59CE7BD9CEFBD9CE7BD94EFBD9CEFBD9CEFBD9CEFC6A5\
EFBD9CEFBD9CEFBD9CE7BD9CE7BD9CDEAD94632910000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000DE9C73D69C7BD69C7BE7BD9C
DEA57BDEA57BDEAD84E7AD8CE7B594E7B594E7B594EFB594EFB594E7BD94EFBD9CEFBD9CEFBD9C\
EFBD9CEFBD9CE7BD9CE7BD9CE7B594DEAD945221107B3918000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000C67B42CE946BCE946BCE946BDEAD8C
DEAD8CCE946BDEA584E7AD8CE7BD94DEAD84E7AD8CEFB594E7BD94EFB59CE7BD9CE7BD9CEFBD9C\
EFBD9CEFBD9CE7BD9CEFC6A5E7BD947B4A296B31188C4A29B56B39000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000C67B42B56B52CE8C63D69C73CE8C63
E7BD94D69C73DE9C7BDEAD84E7AD8CEFB594E7BD94E7B594EFBD9CEFB594EFB594EFBD9CE7BD94\
EFBD9CEFB594E7BD9CEFC6A5E7BD9C6329108442218C4A29AD6B39000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000B56B39C67B428C5A42B57B5AC68C63C68463
DEAD94CE8C63D69C73DEAD8CDEAD84DEAD84DEAD84E7B594E7B594E7BD94EFB594EFB594EFB594\
EFBD9CEFB594E7BD9CE7BD9CE7B5944A18089452298C4A299C6339AD6B42000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000AD6B39C67B42CE8C5A9C6B4A9C6339C6845AC68463
CE946BCE9463C6846BD69C7BDEA584E7AD8CDEAD8CDEAD84E7AD8CE7AD8CEFB594E7AD8CE7BD94\
EFB594E7BD9CEFBD9CE7BDA5E7B59C6B31188C4A299452298C4A29B56B42BD8C63
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000C67B4AC6845AC67B4AAD6B39B5734AB57B5AC67B4A
B57B5AD69C7BCE8C5AD69C73DEA57BDEA584DEA584E7AD8CE7AD8CDEAD84E7AD8CE7AD8CE7AD8C\
EFB594E7AD8CEFBD9CDEAD94E7B59C6329106B3118AD6B39945A31AD6B42C6845A
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000B5734AC67B4ACE8C5ACE8C5A9C63399C6B4A945A31AD6B42
B56B52CE8C63C6845AD69C73D69C7BD69C7BDEA57BDEAD8CDEA584DEAD84DEAD84DEAD84DEAD84\
EFB594E7BD94E7B594E7BD9CE7BD9C6329106329109452298C4A29AD6B42BD8C63
D69C73000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000B56B42B5734AC6845AC6845AC67B429C6339945A31AD6B42AD6342
AD6B42C6845AC6845ACE8C63D69C73D69C73D69C73DEA57BDE9C7BDEA57BDE9C73DEA584DEAD84\
E7AD8CE7BD94E7B594E7B594DEAD9C6B31186B39219C4A319C4A319C6B4AC6845A
D69C73F7EFE7000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000B5734AAD6B39DEAD84DEA573C67B42B56B399C63399C6339AD6B42
9C6339AD6B42BD8C63CE8C63CE946BCE946BD69C73D69C73CE946BCE946BDE9C7BDEA57BDEA57B\
DEA584E7AD8CE7B594DEAD94DEAD946B3921632910945A319C6339B5734AB57B5A
D69C73E7D6C6000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000CE946BC6845ABD8C63CE946BCE9463C67B42C67B428C4A297B4221AD6B42
AD6B429C6339C6845AC6845AC68463CE946BD69C73CE946BCE946BD69C73DE9C73D69C7BDEA57B\
DEA57BDEA584E7AD8CE7B59CDEAD946B3118522918844221AD6B399C6B4AB5734A
C6946BE7BDA5F7EFE7000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000CE946BCE9463BD8C63D69C7BCE9463B56B42B56331AD63317B4221945A31
9C6B4A8C4A29CE8C5AC6845AC6845ACE946BCE946BCE946BC6846BCE8C63CE946BCE946BDE9C73\
DEA584DEAD8CDEAD8CDEAD8CDEAD947B39186B39217B39189C6339945A31AD6B42
BD8C63D6B5A5F7EFF7000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
D6AD84BD8C63C68C63C6946BD6AD84CE9463C67B42C67B42AD5A317B4A297B4221
AD6B427B4A29C6845AB56B52B57B5AC6845ACE8C63C6845AC6845AC67B5AC6845AD69C7BDEA584\
E7A594E7AD94E7AD94E7BDA5DEAD8C6B39216B39216B3921945A319C63399C6B4A
B57B5AD6AD8CEFEFE7EFEFF7000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
D6AD84B56B42C6946BD6AD84DEAD84CE8C5AAD6B39C67B429C6339AD63316B3118
8C5A428C4A31C67B4AAD6B42C67B4AC67B5AB57B5AB57B5AC67B5AC67B5AD69C7BDEAD8CE7AD94\
EFB59CEFB59CEFC6A5EFC6ADE7C6AD8452316B3921734229945A31B5734AAD6B42
B57B5AD6AD84EFE7DEEFEFF7000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
D69C73BD8C63C6946BD6AD84DEAD84C6845AAD6B39C67B4A9C6339B56B396B3118
8442219C6339B5734AAD6B42B57B5AB57B5AC67B5AC67B4AB5734ACE946BDEA584E7AD94EFB59C\
EFC6ADF7C6B5EFC6ADF7C6B5EFC6B5B584636B39217B4221844221945A31945A31
B57B5AD69C73E7CEBDF7EFF7000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000D6AD8C\
C68C63BD8C63B56B42E7BDA5DEAD84C6845ABD8C63CE8C5A945229AD6B39522110
7B3918945A318442219C6B4AB5734AB5734AB5734AB5734ACE946BDEA57BE7AD8CEFB59CEFC6AD\
EFC6ADF7CEB5F7D6BDF7D6BDF7D6BDEFC6B56B39217B4A29632910945A31AD6B42
AD7352C6946BE7CEBDF7EFF7EFEFF7000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000D6AD8C\
C6946BBD8C63C68C63E7BDA5D69C73C6845AC6845AC67B4A8C4221844221734A31
9C63398442217B42219C6339AD6B42AD6B42AD6B42B56B52D69C7BE7AD8CDEAD94EFC6A5EFC6A5\
F7CEB5F7C6B5EFD6C6EFD6C6F7D6BDEFCEADE7C6B57B4A29632910945A319C6339
9C6B4AC6946BE7C6ADEFE7E7F7F7F7000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000E7BD94\
C6946BBD8C63BD8C63E7BD9CD69C73BD8C63AD6B42C67B4AC6845A9C6339522110
B5734AAD73527342299C4A31AD6342AD6B42AD6342C6846BDEA584E7AD8CE7BD9CE7BDA5EFC6AD\
F7C6B5F7D6BDF7D6BDF7D6BDF7CEB5EFC6ADEFCEB56B39216B3118945A319C6339
AD6B42BD8C63D6BDADEFE7E7F7EFF7000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000E7BD94D6AD84\
C69C84BD8C63BD8C63E7BDA5D6AD84C6946BBD8C63C67B42BD8C63AD6331AD6B42
CE946BD69C7B632910844A29945A42AD6342C6846BD69C7BDEAD8CE7B594E7B59CEFC6ADEFC6A5\
F7C6B5F7D6BDF7C6B5F7C6B5F7CEB5F7CEB5EFC6B58C5A426B3921945A31945A31
9C6B4ABD8C63CEAD94E7DED6EFEFF7EFEFE7000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000E7D6CED6AD84\
C69C84B56B42E7BD94CEAD94D69C73BD8C63BD8C63AD6B39B56B42945A318C4221
9C6B4ABD8C636B39218C4A299C63399C6339CE946BDEA584DEAD94DEAD8CE7B59CE7BD9CE7BDA5\
EFB59CEFC6ADEFC6ADEFC6ADF7C6B5F7CEB5EFCEADEFC6B5844A296B3921945A31
946342AD7352C69C84E7CEBDEFE7E7F7F7F7000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000F7EFE7CEAD94\
C6946BC6946BE7C6B5D6AD84C6946BB57B5AAD6B39C67B42AD6B39B57B5AD69C73
BD8C639463426B3921844A31945A31CE8C63D69C7BDEA584DEAD8CE7B59CE7B594DEAD8CDEAD8C\
DEA584DEAD8CE7AD94E7B59CEFC6ADEFC6ADEFCEADEFC6B56B31186B3921945A31
945A31AD7352BD947BE7CEBDEFE7E7F7F7F7000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000F7EFE7EFE7DED6AD8C\
C69C84D69C73E7C6ADD69C73C6946BB57B5AB5734ACE8C5A9C6339CE9463D6A584
AD73528C634A5229187B4A298C5A42CE946BD69C7BDEA584DEAD94E7B594DEA584DEA584DEA584\
E78C7BE78C7BDE9C7BE7AD8CE7BDA5EFC6ADEFCEADEFCEB5E7C6B56B3921845231
8C4A31B5734AC6946BDECEBDEFE7E7F7EFF7F7F7F7000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000EFEFE7E7D6CEE7BD94\
C6946BC69C84E7BD94DEAD84D69C73B5734ABD8C63B5734AC6946BCE9463C6846B
D69C7B8452395221106B3921C6845ACE946BD69C7BDEAD8CE7B594E7B594DEAD8CCE6B5ACE6B5A\
DE8473DE8473DE8473DE7B6BDE7363EFC6A5EFC6ADEFC6ADEFC6B57B39186B3921
8452399C6339B57B5ADECEC6E7D6CEF7EFF7F7EFE7000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000EFEFE7EFE7DECEAD94\
C6946BBD947BE7BDA5D69C7BC6946BB57B5AAD6331C6845AD6AD84B57B5A9C6339
D6A584845239522918734A31C68463CE946BD6A584DEAD8CE7B59CDEAD94D69C7BCE7363DE7B6B\
DE8473E7A594E78C7BEFC6B5DE8473E78C7BEFCEADEFC6ADEFC6B57B4A29734229
7B4A299C6339A57B5AD6AD8CE7DED6F7F7F7F7F7F7000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000EFE7E7EFE7E7CEAD94\
C69C84C69C84E7BDA5D69C73CE9463AD6B42C6845ABD8C63DEAD84D6AD84B57B5A
B584636B31186B3921AD7352CE946BD69C7BD6A584E7B594E7B594E7AD94C65A4ACE7363C6634A\
C65A4ACE6B5ADE7363DE7363DE8473DE7B6BEFC6A5EFC6ADEFCEB5A5846B6B3921
945A31945A31A57B5AC6946BDECEBDF7F7F7F7F7F7000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000EFEFE7EFEFE7EFEFE7D6B5A5\
D6AD84D6BDADE7BD94B57B5ABD8C63C6845ACE946BEFCEADD69C7BD6A584D6A584
845A426B39214A1808B57B5AD69C7BD69C7BDEAD8CDEAD8CE7B594DE8473844229AD4231AD4A31\
9C3121B55239BD5242AD7352AD4A31AD7352E78C7BEFC6ADEFCEB5EFCEBD6B3118
6B3118945A31946342C6946BD6C6B5F7EFF7F7EFF7F7EFF7000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000F7EFF7EFE7DEEFE7E7E7D6C6\
D6AD84E7C6ADD6AD84B57B5ABD8C63C6845AAD7352E7BD9CB57B5A9C6B4AD69C7B
845A423918105A3929C68463D69C73D69C7BE7AD8CE7AD8CE7B594DEAD8CD6A58CD69C73C6634A\
C6634AC6634ACE6B5ACE6B5ACE6B5AE78C7BEFB59CEFC6ADEFCEB5EFCEBD844229
7B4A298C4A298C4A31B57B5AD6BDADEFE7E7F7EFE7F7EFF7000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000F7F7F7EFE7DEEFE7DEE7DED6\
C69C84E7C6ADCE946BCE946BB5734ABD8C63D69C73E7BD9CAD6B429C63399C7352
734A31291008845231CE946BD69C73DEA584DEAD8CE7AD94E7B59CE7B59CE7B594E7BDA5E7BDA5\
EFC6B5F7CEB5EFC6ADEFC6ADEFD6C6F7CEB5EFCEADEFCEADEFCEADEFC6AD845231
7B4A29844A298C5A429C6B4AD6AD8CEFE7DEEFEFE7F7F7F7000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000F7F7F7F7EFE7E7DED6EFE7DE\
D6AD8CE7C6ADCE946BB57B5AC68C63C6845AEFC6A5DEAD94C68C639C63399C7352
845231422118945A42CE946BDE8473DEA584DEAD8CE7AD94E7BD9CE7B59CE7BD9CE7BD9CE7B59C\
E7B59CEFC6ADEFC6A5F7CEB5F7CEB5F7CEB5EFC6ADEFC6ADF7C6B5EFCEB5D6B5A5
7B4A296B3118845231946342C69C84DEC6B5F7EFF7F7EFE7000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7EFE7DEE7D6CE\
C6946BE7BDA5D69C73BD8C63BD8C63D69C73E7BD94CE946BB57B5AAD7352946342
7352425A39299C6B4ACE946BD69C73DE9C7BDEAD8CE7AD94E7B59CEFC6A5EFC6A5E7BDA5EFBD9C\
E7B59CEFC6A5EFC6ADF7CEB5F7CEB5F7CEB5EFCEB5F7C6B5F7CEB5EFC6B5EFCEB5
7B4A297B4A29844A319C6B4AB57B5ADECEC6F7EFF7F7EFF7000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7EFF7EFE7E7E7D6C6\
BD8C63E7BDA5D69C7BC6946BC68C63D6AD84DEA573BD947B8C5A42B58463946B52
734A31522110B5734AC6846BD69C73DEA584E7AD8CE7B59CEFC6A5EFB59CEFC6A5EFB59CE7BD9C\
E7AD8CEFC6A5EFC6A5F7CEB5EFCEB5F7CEB5F7CEB5F7CEB5F7CEB5EFC6B5EFCEB5
844A296B31186B3921844A29B5734AD6C6B5F7EFE7F7EFF7F7F7F7000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7EFE7E7E7BDA5\
C6946BE7BD9CC69C84B57B5AC6946BDEA57BE7BD94845239845231946342845239
5A42395A3929B56B52CE946BD69C7BDEA584DEAD8CE7B59CEFB59CEFC6ADE7BDA5E7B59CE7AD94\
DEA584E7AD94DEAD8CEFC6ADF7CEB5F7CEB5F7CEB5F7CEB5F7CEB5EFC6B5E7C6B5
6B3921734A317B4A299463429C6B4AC6A594EFE7E7F7F7F7F7EFF7000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7E7CEC6E7D6CE\
D6BDADE7BD9CC6845AB57B5AC68C63EFCEADC6845A7B4A299C6339845239845231
4229215A3929B57B5AC6846BD69C7BDEA584E7AD94EFC6A5EFC6A5EFC6A5EFBD9CE7B594DEAD8C\
D69C7BDEA584E7B594EFB59CF7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7C6B5EFC6B5
6B31187B4A296B39218C4A31946342BD947BF7EFF7F7F7F7F7F7F7000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7\
EFE7E7E7BD94B57B5A9C6339C6845AD69C73BD8C639C6B4A9C6B4A845A42734A31
422921734229B56B52CE946BD69C7BDEA584E7AD94EFB59CEFC6ADEFC6ADEFC6A5DEAD8CB57B5A\
C6846BB56342EFB59CEFC6ADDE9C7BF7C6B5F7CEB5F7D6BDF7C6B5EFC6ADE7C6AD
5A31218442297342296B3921845231B58463EFE7E7F7F7F7F7F7F7000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7D6B5A5\
DEC6B5CEAD94BD8C639C6B4AB57B5ACE9463D6AD84945A319C73528C5A425A4239
3918108C5A42C67B5ACE946BD69C7BDEAD8CEFB594EFC6A5EFC6ADEFC6ADEFC6ADD69C7BDEA584\
E7AD8CDEAD8CEFC6ADF7C6B5EFCEB5F7CEB5F7CEB5F7D6BDF7CEB5F7CEB5EFC6AD
8452396B39217B42217B4A299C6339AD7352E7DEDEF7F7F7F7F7F7000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7DECEBD\
DEC6B5D6AD8CB58463AD7352B57B5AD6AD84C6946B945A319C6B4A946342734A31
422118946342B57B5ADE8473DE9C7BE7AD8CEFB59CEFB59CEFC6ADF7C6B5EFC6ADDEA584DEAD8C\
E7AD9CE7B594F7C6B5EFD6C6EFC6B5F7C6B5F7CEB5F7D6BDF7D6BDF7C6B5F7C6B5
A57B636329107B4A29844A316B3921946342E7D6CEF7F7F7F7EFE7000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7\
D6B5A5CEAD94B57B5ABD8C63D69C73DEA57BAD73528452319C6B4A9C6339734229
180808945A31B57B5ACE946BDEA584E7AD94EFB59CEFC6A5F7C6B5EFCEADEFC6ADE7AD94DEAD8C\
E7A594E7BDA5F7C6B5F7DED6F7D6BDEFC6ADF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5
E7C6B55229188C4A317B4A298452318C5A42E7CEC6F7F7F7F7EFF7000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
C69C84E7BD9CB57B5AB57B5AE7BDA5CE946B9C73528452319463428452395A3929
211008AD6342B57B5AD69C73DEAD8CE7AD94EFC6A5EFC6A5EFC6ADEFCEB5EFC6B5E7B59CD6A58C\
DEA584E7AD94F7CEB5EFD6C6F7C6B5F7CEB5F7D6BDF7D6BDEFD6C6F7D6BDEFCEBD
EFC6AD6329107B4A297B4A29734229946342C6946BF7F7F7F7F7F7000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
DECEBDCEAD94A57B5AB5734AEFCEADCE9463A57B5A845231845231734A31522918
2910089C6B4AC68463DEA584E7AD8CEFB59CEFC6ADEFC6ADEFC6B5F7C6B5EFC6ADEFC6ADDEAD94\
DEAD8CE7B59CEFC6B5F7D6BDEFCEBDF7D6BDEFD6C6EFD6C6EFD6C6EFD6C6F7D6BD
EFC6AD522110391810844A31845239844A29B5846BF7F7F7F7F7F7F7F7F7000000000000000000\
000000000000000000
000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
DECEBDE7BD94B58463C68C63EFCEADD69C739C73529C63397B4A298452395A3121
4221189C6B4AC68463D69C7BDEAD94E7B59CEFC6ADEFC6B5EFCEBDF7C6B5EFC6B5EFC6ADE7B59C\
DEAD8CDEAD94EFC6ADF7D6BDF7CEB5F7D6BDEFD6C6F7DECEEFD6C6EFD6C6F7D6BD
EFCEB55229185229187B4A298452397B4A29B5846BF7EFF7F7EFF7F7EFF7000000000000000000\
000000000000000000
000000000000000000000000000000000000000000F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
EFEFE7DEAD8CA57B5AB5734AE7BDA5D69C739C73528C5A42845231734A316B3921
7342299C6B4AD69C73D6A584E7B594E7C6ADEFC6B5EFCEBDF7C6B5F7C6B5EFD6C6EFC6B5E7B59C\
E7B594E7B59CF7C6B5F7D6BDF7D6BDEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7DECE
F7C6B5EFB59C4221187B4A298452317342299C7352F7F7F7F7EFF7F7F7F7000000000000000000\
000000000000000000
000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7D6AD8CA57B5AAD6B39D6AD84D69C73B5846B8C5A429C63398452396B3921
734A31B56B52D69C73DEAD8CE7B59CEFC6ADEFCEBDEFCEBDF7D6BDF7D6BDF7D6BDE7C6ADE7BDA5\
E7B59CE7B59CF7D6BDF7D6BDF7D6BDEFD6C6EFD6C6F7D6BDEFD6C6F7DECEEFD6C6
EFD6C6EFC6AD6B3921844A31734A315A3121945A31F7F7F7F7F7F7F7F7F7000000000000000000\
000000000000000000
000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7DEAD84AD7352AD6B42D6A584D69C73D69C73946342946342734A315A3121
8C4A31B56B52D69C73DEAD8CE7BDA5EFC6ADEFCEB5F7D6BDF7C6B5EFD6C6EFCEBDEFC6ADE7BDA5\
DEAD94E7B59CF7C6B5F7D6BDEFD6C6F7DECEEFD6C6F7D6BDF7D6BDF7DECEEFD6C6
EFD6C6F7C6B55229187342298452396B39219C6339F7F7F7F7F7F7F7F7F7000000000000000000\
000000000000000000
000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7D6AD84AD7352945A31C69C84C6946BD6AD8C845239945A316B39216B3118
845239B57B5AD69C7BDEAD94E7BDA5EFC6B5EFC6B5EFCEBDEFCEBDEFCEBDEFCEBDE7C6ADE7BDA5\
DEAD94E7BDA5EFD6C6EFC6B5F7D6BDEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6
EFD6C6F7CEB58452395A3121845239734A319C7352F7EFF7F7F7F7F7F7F7000000000000000000\
000000000000000000
000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7CEAD94BD8C638442219C6B4AD69C73C69C848C5A429C6B4A6B3921522918
945A31C68463D6A584DEAD9CE7BDA5EFC6ADEFC6B5EFC6B5EFCEBDEFD6C6E7CEBDDEAD9CDEAD9C\
DEAD8CEFC6ADEFD6C6F7CEB5F7D6BDEFCEBDEFC6B5EFCEBDEFD6C6F7DECEEFD6C6
EFD6C6EFC6B5E7C6AD5A39298C4A318C5A428C634ABDADADF7EFF7F7F7F7000000000000000000\
000000000000000000
000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7E7C6ADB5846B945A42844A31CE946BC69C848C5A428C5A426B3921522918
945A31C68463D6A584E7BD9CE7C6ADEFC6B5E7C6ADE7C6ADE7BDA5E7C6ADEFC6B5E7BDA5DEAD94\
DEAD8CEFC6ADEFD6C6F7CEB5F7D6BDEFC6B5EFC6ADEFB59CEFCEBDF7D6BDEFD6C6
EFD6C6E7C6ADE7C6AD734A318C4A319C6B4A9C6B4AA57B6BF7EFF7F7F7F7000000000000000000\
000000000000000000
000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7E7D6C6C6946B9C6B4A844A29B57B5ABD947B9C6B4A8C5A42632910734229
9C6B4AC6846BD6A584E7BD9CE7BDA5E7BDA5DEAD9CDEAD8CE7AD9CE7BDA5E7C6B5D6B5A5D6A58C\
DE9C7BEFB59CEFD6C6EFC6B5EFCEBDE7C6ADDEAD94EFC6ADEFC6B5EFCEBDEFD6C6
EFD6C6EFC6B5EFC6AD9C6339734A31845A428C5A428C4A29F7F7F7F7EFF7000000000000000000\
000000000000000000
000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7E7D6CEC69C84945A31945A31B57B5AB5846B8C634A8452395A3121734A31
945A42C6846BD6A584DEAD9CDEAD9CE7BD9CC69C84C69C84B5846BC6A59CE7AD9CDEAD9CD69C7B\
D69C7BEFC6ADF7D6BDEFC6B5EFCEBDDEAD9CBD947BD6A58CBD947BE7C6B5EFD6C6
EFD6C6EFCEB5CE946B844A315221108452398452399C6B4AF7F7F7F7F7F7000000000000000000\
000000000000000000
000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7EFE7E7D6AD849C6339945229B5734AB584638C5A42845239522918734A31
9C6B4AC6846BD6A58CDEAD9CDEAD94D6A58CA57B63A57B63735A4ADEC6C6C6846B9C4A31BD947B\
D69C7BEFC6A5F7D6BDE7C6ADEFC6B5DE8473A58473736B63DEAD9CB58463EFC6B5
EFD6C6EFCEB5E78C7BEFB5945A3121734A31734A31A57B5AF7F7F7F7F7F7000000000000000000\
000000000000000000
000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7D6AD8C844A29AD63429C6B4AB5846B734229845239291008734A31
9C6B4AB5846BD69C7BDEAD8CD6A584B5846B9C73526B635A7B6B5A8C7363DEC6C6C69C84B5846B\
DEA584EFC6ADF7D6BDEFC6A5E7AD9CC69C84847B73736B63E7D6CEC6846BE7AD9C
EFCEBDEFCEBDE7A594F7C6B56B31188452398C634ABD9C8CF7F7F7F7F7F7000000000000000000\
000000000000000000
000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7D69C7B844A29AD6342A57B5A9C7352734A31522918391810844A31
945A42C68463BD947BD6A58CBD947BA57B63423129635A52211818635A529C6B4AB58C73B58C73\
E7B594EFC6ADF7D6BDEFCEADBD947B94735A84736BB5B5BDC6B5B55A3929BD947B
EFC6ADE7C6B5E78C7BF7C6B58452398452397B4A29A5846BFFFFFFF7F7F7000000000000000000\
000000000000000000
000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7D69C73946342AD73529C6339AD7352734A316B3921422118734A31
8C5A42B57B5ABD947BD69C7BB5846BA57B63735A4A734A315A39295A3929A58C84AD7352BD947B\
E7B59CEFC6ADF7D6BDF7CEB5E7AD94A57B638C6B525A39295A4239846352C6846B
E7B59CEFC6B5D69C7BEFB59C945A428452397B5242A58C73B5947BF7F7F7000000000000000000\
000000000000000000
000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7D6A5849C6B4ABD8C639C6339B57B5A7342295A3121522918845239
8C5A42B56B52CE946BD69C7BCE946BB58C739C73525A4239846352A5847384634ABD947BDEA584\
EFC6A5EFC6ADF7D6BDF7CEB5EFC6ADD6A58494735A7B52427B5242B56B52DEAD94
E7C6ADEFC6B5D69C7BE7A5948C4A31845239734A31B59C8CAD7352F7F7F7000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7EFDECE9C7352BD947B9C6339BD8C636B3921734A315229186B3921
8C634AB57B5AC6846BD69C7BD6A58CE7AD8CD6A584D69C7BBD947BBD947BD6A58CBD947BD69C73\
EFC6ADF7CEB5EFD6C6F7CEB5EFC6A5DEA584E7B59CE7B59CE7B59CEFC6B5EFCEBD
EFCEB5E7C6B5BD947BCE946B9C6B4A734A31734229946B52EFE7DE000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7EFE7E7A57B5AC6946B946342AD7352734A315A3929522918845239
8C5A42AD7352BD8C63B58463D6A584E7B59CE7B59CE7BDA5EFC6ADE7BDA5B56B52AD6342E7AD94\
F7D6BDEFD6C6EFD6C6F7D6BDF7D6BDE7B59C9C7352C6846BEFD6C6F7D6BDF7D6BD
F7CEB5EFCEB5B58C73DE84739C4A319463426B39218C5A42FFFFFF000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7BD947BBD8C63945A31A57B5A845A425221105A31216B3921
8C5A429C6B4AB5846BCE946BBD947BDEAD94EFB59CEFC6ADE7AD9CB56B52845239BD8C63EFC6A5\
F7CEB5F7D6BDEFD6C6F7D6BDF7D6BDF7CEB5D6A58494735AB5846BEFD6C6F7D6BD
E7BD9CEFC6ADC6846BB57B5A9C63398452396B39217B4A29FFFFFF000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7AD6B42D69C73946342AD735284634A522918734229422118
8452399C6B4ABD8C63BD947BB5846BA57B63C6846BCE6B5A9C735294735AD6A584EFCEADF7CEB5\
EFD6C6EFD6C6EFD6C6F7DECEF7DECEF7DECEF7D6BDF7CEB5AD7352DE8473D6A584
BD947BE7C6B5B5846B945A42945A31845239734A31734229FFFFFF000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7BD8C63C69C84AD63428C5A428C634A3918105A3121734A31
8452399C7352BD8C63D69C73BD947BBD947BA57B63A57B63E7C6ADEFC6ADEFC6ADF7CEB5EFD6C6\
F7D6BDF7DECEEFD6C6F7DED6F7DECEF7DECEF7DECEF7DECEEFD6C6DE8473D6A584
EFCEB5E7C6B5A57B5A8C634A845239734A31845239734A319C7352000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7C69C84D6AD849C6B4A8C5A42B58C733918103918106B3921
9C6B4AA57B5AB57B5ABD947BD69C7BDEAD8CE7B59CE7C6ADEFC6ADEFC6ADEFCEB5F7D6BDEFD6C6\
EFD6C6F7DECEF7DECEF7DECEF7DED6F7DECEF7DECEF7DECEEFD6C6EFD6C6F7D6BD
EFCEB5EFC6ADAD73528C634A8C5A428452398C6B52734A319C6B4A000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7D6BDADD6AD8CAD73528C5A42BD947B5A3121522918734229
8C5A42AD7352BD8C63BD947BD69C7BD6A584E7B59CEFC6ADE7C6ADEFC6B5F7C6B5F7D6BDF7D6BD\
F7DECEEFD6C6EFD6C6F7DECEF7DECEF7D6BDF7DECEF7D6BDF7DECEEFD6C6F7D6BD
EFCEB5E7C6AD9C73528C5A42845A42845A42946B52845A42844A29000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7BD947BB5734A9C6B4AC6946B3918105A31215A3121
9C6B4AB57B5AB57B5AD69C73D6A584DEAD8CE7B594E7BDA5E7C6ADEFC6ADF7CEB5F7CEB5EFD6C6\
EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6BDF7DECEF7D6BDEFCEBD
EFCEB5E7BD9C9C73528452318452398C634A8C634A8C634A845239000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7946342B57B5AB584639C73523918104221185A3929
845239AD7352BD8C63CE946BD6A584DEAD94E7B59CE7BD9CEFB59CEFC6ADEFCEADF7CEB5F7C6B5\
EFD6C6EFD6C6F7DECEF7DECEF7DECEF7D6BDF7DECEF7DECEEFD6C6F7D6BDF7CEB5
EFCEADE7B59CB57B5A84523984523984523984634A845239000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7946342BD8C639C735294735A391810422118734A31
8C5A42A57B63B58463CE946BD6A584DEAD8CE7B59CE7B59CEFB59CEFC6ADEFCEADF7CEB5F7D6BD\
F7D6BDEFD6C6F7DECEF7DECEF7DECEF7D6BDF7DECEF7D6BDF7DECEF7D6BDF7D6BD
EFCEB5DEAD8CBD8C638C634A845A428C634A8C6B52845239000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7C6946BC6946BAD73528C634A2910083918106B3921
8C5A429C6B4AB58463CE946BD6A584DEAD8CE7B594E7BD9CEFC6A5EFC6ADEFC6ADF7CEB5F7CEB5\
F7D6BDEFD6C6EFD6C6F7D6BDF7D6BDF7DECEF7D6BDF7DECEF7D6BDF7D6BDF7CEB5
EFC6ADD6A58CB5846B8C634A7B5A428C634A946B528C5A42000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7E7DED6C6946B946342946B522910082910085A3121
734A31946B52B5846BD69C73D6A584DEAD8CDEAD94E7B59CEFB59CEFC6ADF7C6B5F7D6BDF7D6BD\
EFD6C6F7D6BDEFD6C6F7DECEF7D6BDF7D6BDF7DECEEFD6C6F7DECEF7D6BDF7CEB5
EFC6ADD6A584BD8C638C634A9C63398C5A428C634AA57B5A000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C69C849C6339946B523918103918105A3121
7B5A429C7352A57B63D69C7BD6A584DEAD8CDEAD94E7B59CEFB59CEFC6ADF7CEB5F7C6B5F7D6BD\
F7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7DECEEFD6C6F7D6BD
EFC6ADD6A58CB58C738C634A8452398452318452397B5A42000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEB5A5946342946B52391810291008422118
6B39218C634AB5846BBD947BD6A584D6A58CDEAD94EFBD9CEFC6A5F7CEB5F7CEB5F7CEB5F7D6BD\
F7D6BDF7D6BDF7D6BDF7DECEEFD6C6F7DECEF7DECEF7D6BDF7D6BDEFD6C6F7C6B5
EFC6ADD6AD8CB58C739C6B4A7B5A42735242734A31000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7BD9CAD7352B5846B422118311818422118
5A39299C7352A57B63CE946BD6A58CDEAD8CDEAD9CE7B59CEFC6A5EFC6ADF7C6B5F7D6BDF7D6BD\
F7D6BDEFD6C6EFD6C6EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEEFD6C6F7CEB5
EFC6ADDEAD9CB58C739C6B4A735242845239845239000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECECEC6845AB58463391810522918422921
5A39298C634AA57B63B58C73D69C7BDEAD8CE7B594E7BDA5EFC6ADEFC6ADF7CEB5F7CEB5F7D6BD\
EFD6C6F7D6BDEFD6C6F7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5
EFC6ADDEAD94BD947B946B527B5A42735242734A31000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFE7BD8C639C7352291008522918522918
5A39298C5A42AD7352B58C73DEA584DEAD8CE7AD94E7BD9CEFC6ADEFC6A5EFCEADF7CEB5F7CEB5\
F7D6BDF7D6BDF7D6BDEFD6C6EFD6C6F7D6BDEFD6C6F7DECEEFD6C6F7D6BDF7CEB5
EFC6ADE7BDA5C6946B946B527B5A427B5A42735242000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CE946B9C73525A39293918105A3121
734A31845239A57B5AB58C73D6A584D6A584DEAD94E7BD9CEFB59CEFC6A5EFC6A5F7C6B5F7CEB5\
F7CEB5F7D6BDF7D6BDF7D6BDEFD6C6F7DECEF7D6BDEFD6C6EFD6C6F7CEB5F7CEB5
EFC6ADE7B59CB58C73946B527B5A42946B52000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C68C63946342A57B5A211818422921
5A3929845A42945A42BD8C63BD947BD69C7BE7B594E7B59CEFBD9CEFC6A5EFC6ADEFC6ADF7D6BD\
F7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFD6C6F7CEB5F7D6BDF7CEB5
EFC6ADDEAD94BD947B8C634A8C634A946B52000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7D6B5A59463429C7B63291008522918
5A3121845A42946342A57B63D6A584D6A58CDEAD94E7B59CEFB59CEFC6A5EFC6A5EFC6ADEFC6AD\
F7CEB5F7CEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5EFCEADEFC6AD
EFB59CDEAD9CBD8C638C634A735242845239000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7E7BDA5AD7352A57B5A7B5A42391810
946B52734A319C6B4AA57B63CE946BBD947BDEAD8CE7B594EFBD9CEFC6A5EFC6ADEFC6A5EFC6AD\
EFC6ADEFC6ADF7D6BDF7CEB5F7D6BDF7D6BDF7CEB5EFCEBDF7D6BDF7CEB5EFC6A5
E7C6ADDEAD94BD8C63A57B5AA57B5A000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFD6BDADBD8C639C73527342295A3929
5A3929845239845A429C7352B5846BBD947BDEAD8CDEAD94E7B594EFC6A5EFC6ADEFC6A5EFC6A5\
EFC6ADEFC6ADEFC6ADF7C6B5F7CEB5F7CEB5F7CEB5F7CEB5F7D6BDF7C6B5EFC6A5
E7BDA5DEAD94BD8C63A57B63845239000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7C6946B9C6B4A946B525A3121
5A4239734A31735242A57B5AB5846BBD947BD69C7BD6A58CE7AD94E7B59CEFB594EFB59CEFC6A5\
EFB594E7B59CEFC6A5EFC6ADEFC6B5F7CEB5F7C6B5EFC6B5EFCEB5F7C6B5EFC6A5
E7B59CC69C84B584638C5A42845231000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7E7BD9CBD8C6394735A8C6B52
7B5A42735242845A429C7352B58463B5846BD69C73D6A584DEAD8CE7AD94DEA584E7AD8CE7AD8C\
E7B594E7AD94E7B59CEFC6ADEFC6A5EFC6B5EFC6ADEFCEB5E7C6ADEFC6A5EFB59C
DEAD9CD6A58CA5846B845239000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7BD9CB584639C6B4A9C6B4A
8C634A946B52735A4A94735A9C6B4AB5846BBD947BC6846BCE946BCE946BD69C73D69C7BD69C73\
D69C7BD6A584DEAD94DEAD8CE7B59CE7BDA5E7BDA5EFC6ADEFC6ADE7B59CD6B5A5
E7BD9CBD947B9C7352946B52000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7D6BDADCEAD94B57B5AB57B5A
6B3921A57B638C634AA57B63A58C73BD947BA57B63B5846BB58463B57B5AB58C73CE946BD69C7B\
CE946BC69C84D6A58CDEA584E7BD9CD6A584DEAD94E7BDA5E7BDA5EFC6A5D6B5A5
BD947BA57B6BA57B5A8C634A000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7D6B5A5C6946BA57B5A
9C6B4A845A429C73529C7352AD7352946B52A57B63A57B639C73529C73529C6B4AB58463AD7352\
B58C73B58C73C6946BD6A584D6A58CD6A58CCEAD94DEAD9CE7BDA5E7C6B5E7C6B5
C69C848C634A9C7352000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7D6AD8CCEB5A5B58463
94634294634294634294735A9C7B63946B52A58C73A57B5AB5846BBD947BA57B5AA57B63BD947B\
BD947BB5846BC6846BC69C84C69C84C69C84D6A58CD6A58CDEAD9CD6BDADCEA594
BD9C8CC6A5949C7363000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B58463BD9C8CD6AD84
B5734A7B5A428452398C634A734A31845A42946B52B5846B9C7352C6946BA57B5A9C7352A57B5A\
9463429C7352BD947BBD947BBD947BBD947BC69C84C69C84D6A58CDEAD94DEAD9C
B58C73A5846B000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECECEBD9C8CD6BDAD
BD947B9C6B4A8452399463429463428C5A428C5A42734A31A57B5A8C5A42A57B63B58463A57B63\
8C634AA5846BA57B63B58463B5846BBD947BC69C84C69C84C69C84D6B5A5D6B5A5
C6A594BD9C94000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7BD9C8CA5846B
E7BD9CC69C84B584638C5A428452399463428452398452397342298C5A42946B528C634A845A42\
BD947BA57B5A8C634AB58463B58C73A5846BBD947BB58C73BD947BD6B5A5CEB5A5
A5846B000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7BD947BA5846B
9C7B63C69C84A57B5AA57B5A845231845239845239734A3184523973524284634A946342845A42\
8C634A9C7352B58463B58C73B584639C7363BD947BA5846BA57B63D6A58CC6AD9C
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFEFE7E7C69C84
A58C73CEB5A5BD947BA5846B845A428452317342295A3929734A31845231845A42735242734A31\
946B52A57B5AA57B63A57B63A5846B94735AB58463A57B63A57B5AD6B5A5B5947B
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000FFFFFFF7EFF7F7F7F7F7F7F7F7F7F79C6B4A
B5846384634ACEB5A5B5846BA5846B734A315A31215A31217342296B39218452397B5A425A3121\
94735A9C7352A57B638C634AA5846BB58463B58C73B5947BA57B5AD6BDAD000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7B5947B
A5846B734A31BD9C8CDEC6B5BD8C63AD7352945A3184523184523184523984634A734A318C6B52\
A57B5A94735A946B5294735A8C634AA57B6394735AA57B5AA5846B000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000FFFFFFFFFFFFF7F7F7FFFFFFFFFFFF
A5846B9C7363A58C73B59C8CD6B5A5B58C73B584639C6B4A8C634A94735A8452397B5A429C7352\
A57B5A8C634A946B528C634A7B5A42946B52B584638C6B52D6B5A5000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000F7F7F7FFFFFFF7F7F7F7F7F7
BD947BA5846B8452398C5A429C7B6BC6A594D6A584BD8C63B584639C73528C5A42B5947BA57B63\
9C7352845239946B52845A42845239946B52A5846B8C6B52000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7
FFFFFFA57B63B584637B5A42946B528C6B52CEB5A5E7C6ADD6A58CD6A58CC69C84E7C6B5B58C73\
9C73527B5A42734A31845239A57B63A58473A5846B000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000F7F7F7F7EFF7
F7F7F7B5947BBD947B94735A73524294735AA58473B5947BD6BDADE7D6C6D6BDADD6BDADBD9C8C\
B5947B7B52427B5242C6A594A57B6BA58473000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFFFFFF7F7F7A57B63A5846BA57B638C6B529C7B6B9C7B63C6A594CEB5A5DEC6B5DEC6B5D6BDAD\
E7CEC6EFE7DEEFD6C6C6A59C000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000F7EFF7F7F7F7A5846BC69C84A584738C6B52A57B5ABD9C94BD9C8CBD9C94E7CEC6E7D6CE\
EFD6C6E7CEBDDEC6B5000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000E7DEDEA58C7BC69C84A58C7BA58C739C7B6BBD9C94B59C8CD6BDB5E7CEC6\
E7D6CE000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000B59C8C000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000EFBD9C000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFBD9C\
EFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFC6A5EFC6A5EFC6A5EFB594EFB594EFBD9C
EFBD9CEFBD9C000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000EFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFBD9C\
EFB594E7BD9CEFBD9CEFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9CE7BD9CEFB594
E7BD94E7B594EFBD9CEFBD9CEFBD9CEFB594000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000E7BD94EFBD9C
EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFBD9CEFBD9CEFC6A5EFBD9CEFBD9CEFC6A5EFBD9C\
EFBD9CEFB594E7BD94EFBD9CEFBD9CE7BD9CEFC6A5EFBD9CEFB594E7B594EFB594
E7B594E7B594E7B594E7B594E7BD94E7B594E7B594E7AD8CE7AD8C000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000DEAD9CDEAD94E7B594E7B594E7BDA5
E7BD9CEFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFBD9CEFC6A5EFBD9CEFBD9CEFBD9CEFBD9CE7BD9C\
EFBD9CEFBD9CEFB594EFB594E7BD94EFB594EFBD9CEFBD9CE7BD9CE7BD94EFB594
E7B594EFB594E7AD8CDEAD84E7AD8CEFB594E7AD8CE7AD8CEFB594E7AD8CE7BD94E7B594000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000006329104A1808DEAD94DEAD94E7BD9CE7B59CE7BD9C
E7BD9CEFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9C\
EFBD9CEFBD9CE7BD94E7BD94EFBD9CEFB594E7BD9CEFB594EFB59CE7B594E7B594
E7B594E7B594E7AD8CE7AD8CE7AD8CE7AD8CDEAD84DEA57BDEAD84E7AD8CDEAD84E7BD9CDEA57B\
DEAD8C000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000007B39186329105221106B3118DEAD94DEAD94E7B594E7BD9CE7BD9C
E7BDA5E7BD9CEFC6A5EFBD9CEFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFB594EFBD9CEFBD9C\
E7BD94EFBD9CEFB594E7BD9CEFB594E7B594E7B594E7AD8CE7B594E7B594E7B594
E7B594E7AD8CE7AD8CDEAD84DEA584DEA57BDEA57BDEA57BDEAD84E7BD9CDEAD84D69C7BD69C73\
D69C7BDE9C73DE9C73000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
B56B399452298C4A296B31186B31187B42217B4A29DEAD9CE7BD94E7BD9CEFC6A5
E7BD9CE7BD9CEFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFBD9CE7BD9CEFBD9CE7BD9CE7B594\
EFB59CEFBD9CE7BD94EFB594EFB594E7BD94E7AD8CE7BD94DEAD84E7B594E7BD94
E7B594E7AD8CE7AD8CDEA584DEA584CE946BD69C73DEAD8CE7BD9CDEAD8CCE8C63CE946BD69C73\
CE946BD69C73CE946BC67B4AC67B42000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000B5734A\
AD6B398C4A298C4A297B39188442218C4221632910DEAD94E7BD9CE7BDA5EFC6A5
E7BD9CE7BD9CEFBD9CEFB594E7BD94EFBD9CEFB594E7BD94EFBD9CEFBD9CE7BD94EFB594E7BD94\
EFB594EFB594EFBD9CE7B594E7B594E7B594E7BD94DEAD84EFB594DEAD84E7AD8C
DEAD8CDEAD84DEA584DE9C7BCE946BD69C73D69C73E7BD94E7BD9CCE8C63CE946BD69C73D69C73\
CE8C63B57B5AB56B529C6339C67B42B56B39000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000B5734AAD6B429C6339\
9C63398C42218C4A299452299452297B39184A1808E7BD9CE7B594E7BDA5E7BD9C
EFBD9CE7BD9CEFBD9CEFB594EFB594EFBD9CEFB594EFB594EFB594EFB594EFB594EFB594E7BD94\
E7BD94EFB594E7B594E7BD94E7B594E7B594DEAD84DEAD84DEAD84E7AD8CDEAD84
DEAD8CDEAD8CDE9C7BD69C73CE8C63CE8C63DEAD84DEAD94CE8C63C68463C68463C68C63C68463\
B57B5AAD73528C5A42AD6B42C67B42B56B39B56B39B56B39000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000BD8C63B57B5AB56B42AD6B42\
8C4A29844221945229945A318C4A296B39216B3118E7BDA5E7B59CEFC6A5E7BDA5
E7B594EFBD9CE7BD9CE7BD9CEFBD9CEFB594EFB59CE7BD94EFB594E7AD8CEFB594EFB594E7AD8C\
E7AD8CE7AD8CE7AD8CEFB594DEAD84E7AD8CDEAD8CDEAD84E7AD8CDEA57BDEA584
DEA57BD69C7BD69C73C6846BCE8C63CE9463D69C73CE946BC6845AC68463C6845AC6845AB57B5A\
9C63399C6B4A9C6B4AAD6B39CE8C5AC67B4AC67B42B56B39AD6B39000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000CE946BC6845AB5734AAD6B42AD6B39\
945A31945229AD6B399452296B31186B3118632910E7BDA5E7B59CE7BD9CDEAD94
E7BD9CEFBD9CEFBD9CE7AD8CE7AD8CEFB594E7B594E7AD8CE7AD8CE7AD8CDEAD84E7AD8CE7AD8C\
DEAD84DEAD84E7AD8CDEA584E7AD8CDEA584DEA584DEA584DEA584DEA57BDEA57B
D69C73D69C73CE946BCE8C5AC68463D69C7BC68C63B57B5AB56B52C67B4AB5734AB57B5A946342\
B5734A9C7352AD6B39AD6B42C67B4ACE8C5AC6845AB5734AC67B4AB57B5A000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000D69C73D69C73BD8C63B5734AAD6B42AD6B42\
8C4A299C63399452298442216329106B3921632910E7BD9CE7BD9CE7BD9CE7BD9C
E7BD9CE7B594EFBD9CE7BD94E7AD8CEFB594E7AD8CDEAD84E7AD8CDEAD84DEA584DEAD84DEA584\
DEAD84DEA584DEA584DEA584DEAD8CDEAD84DEA57BDE9C7BD69C7BDEA57BD69C7B
D69C7BD69C73CE946BC6845ACE946BCE8C63B57B5AB56B52B5734AAD6B42AD6B42945A319C6B4A\
9C6B4A9452299C6339B56B42CE8C5ACE8C5ACE8C5ACE946BC67B4AC67B4AB5734A
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000F7EFE7CEAD94D69C73C68C63C6845A9C63399C6B4A945A31\
9C4A319C63399C4A317B42216B39217B42216B3118E7BDA5DEAD9CE7BD9CE7B594
E7BD9CE7B594E7AD8CE7BD94E7AD8CE7AD8CE7AD8CDEAD84DEA584DEA584DEA584DE9C73DE9C7B\
DEA57BDE9C7BDE9C7BDEA584DEA57BDEA57BD69C73DE9C73D69C73D69C73D69C73
D69C73CE8C63CE8C63C6845ACE946BC6845AB5734AAD6B42AD6342AD6342946342AD6B429C6B4A\
945A31945A319C6339B56B39C67B42CE8C5AC6845ACE8C5AC6845ABD8C63B5734A
B5734AB56B42000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000F7EFE7E7D6C6D6AD8CD69C73C6845AB57B5AAD6B42B5734A945229\
9C63399C6339945A315A31216329106B31186B3921E7BD9CDEAD94E7B59CDEAD94
E7B594E7B594E7AD8CE7AD8CE7AD8CDEA584DEAD84DEA57BDE9C7BDEA57BDE9C7BDE9C7BDE9C73\
CE946BCE946BCE946BD69C73D69C73DE9C7BD69C73D69C73CE946BCE946BCE946B
CE8C63CE8C63C68463BD8C63B5734AAD6B42AD6B399C6339AD6342AD6B42AD6B429C63399C6339\
9C6339AD6331B56B39B56B42C67B42CE8C5ADEA573D69C73DEAD84C68C63AD6B39
AD6B39B5734AC68C63000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000F7EFE7F7EFE7E7BDA5D6AD84C6946BBD8C63B5734A9C63399C6B4A945A31\
AD6B398C4A298442215229185229186B31186B3118E7BD9CDEAD94E7B594E7B59C
E7B594E7AD8CE7AD8CDEA584DEA57BDEA57BDEA57BDEA57BDE9C73D69C7BD69C73DE9C73D69C73\
D69C73CE946BCE946BCE946BCE946BD69C73D69C73CE946BCE946BCE946BC68463
C68463C6845AB57B5AC6845AB56B429C6339945A31AD6B429C6339AD6B42AD6B427B42217B4221\
8C4A29B56331C67B42C67B42C67B42C6845ACE9463D69C73CE946BD6AD84BD8C63
B5734AC6845AC6845ACE946B000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000EFEFE7F7EFF7E7DED6D6B5A5D6AD84BD8C63B57B5AAD6B429C6B4A945A31945A31\
9C63398C4A297B39186B31186B39216B39217B3918DEAD94DEAD94DEAD8CDEAD8C
E7AD8CDEAD8CDEA584DEAD8CDEA584DEA584D69C7BDE9C73DE9C73CE946BCE946BCE946BC6846B\
CE8C63CE8C63C6846BCE946BCE946BC6846BCE946BCE946BCE946BC68463C6845A
C68463C6845AB5734ACE8C5AAD6B428C4A299C6B4A9C6B4A9C6339945A318442217B4221632910\
AD6331C67B42B56331C67B42B56B42C67B4ACE9463DEA573D69C7BDEAD84BD8C63
BD8C63CE9463BD8C63CE946BC6946B000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000EFEFF7F7EFF7EFEFE7E7C6B5D6AD8CC69C84B57B5AB57B5A9C6B4AAD63429C6339945A31\
945A316B39216B39216B31186B39216B39216B3921DEAD94DEAD8CDEAD94E7BDA5
E7AD94E7AD94E7A594E7AD94E7A594E7A594DEAD8CDEA584DEA584D69C7BCE8C63C6845ACE8C63\
C67B5AC6845AC6845AC6845AC6845ACE8C63CE8C63C6845AC6845AC6845AB57B5A
B57B5AB56B52B5734AC6845A9C63397B4A299C6339AD6B428C4A297B42217B39187B4A29945229\
AD5A31C67B42C67B42B5734AC67B42AD6B39CE9463D69C73D6AD84CE946BC6946B
C6845AC68C63C68C63BD8C63D6AD84D6AD84000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000EFEFF7EFEFF7EFE7DEDEC6B5D6AD84C6946BB57B5AB5734AAD6B429C6339B5734A9C4A31\
945A315221107342296B39216B39216B3118845231DEAD94E7C6ADEFC6ADEFC6AD
EFC6ADEFC6A5EFC6A5EFB59CEFB59CEFB59CE7AD9CE7AD94E7AD94DEAD8CDEA584D69C7BC67B5A\
C67B5AC67B4AC67B5AC67B5AB57B5AB57B5AB57B5AC6845AC67B5AB57B5AC67B4A
B5734AAD6B42AD6B42C67B4A8C4A298C4A319C63398C5A428442216B31186B3921AD6331844221\
9C6339C67B4AC67B42B5734AAD6B39B5734ACE8C5AD69C7BDEAD84DEAD8CD6AD84
C6946BC6946BB57B5AB56B42D6AD84D6AD84000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
EFEFF7F7EFF7F7EFF7E7CEBDD6B5A5D69C73C68C63B57B5AAD7352945A319C6339945A319C6339\
8442216329107B42217342296B39216B3118B58463EFC6ADEFC6B5F7D6BDF7C6B5
F7C6B5EFC6ADEFC6ADF7C6B5EFC6ADEFC6ADEFB59CEFB59CE7B59CE7AD94DEAD8CDEA584DE9C7B\
CE946BC67B4AB5734AB57B5AC67B4AC67B4AC67B5AB56B52B57B5AC67B4AB57B5A
B5734AAD6B42946342B5734A945A319C6339B5734A8442217B39186B3118734A31B56B398C4221\
9C6339B56B42C67B4AB56B39AD6B39B5734AC6845ACE8C5ADEAD84DEAD8CD6AD84
D69C73C6946BB5734ABD8C63D69C73D69C73D69C73000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000EFEFF7
F7EFE7F7EFF7F7EFF7E7CEBDCEAD94C6946BBD8C63AD7352AD6B42AD6B429C6339945A319C6339\
6329106B39217B4A296B39216B3921B58C73EFC6B5F7CEB5F7D6BDF7CEB5F7D6BD
F7C6B5F7D6BDF7C6B5F7CEB5F7C6B5EFC6ADEFC6A5EFC6ADEFB59CEFB59CE7AD94E7AD8CDEA584\
DEA57BD69C73CE946BB5734AB5734AB5734AB5734AC67B4AB5734AB57B5AB5734A
AD63429C6B4A845239844221B5734A945A31C6845A7B39186B3118522110632910AD6B39B56B42\
945229B56B42CE8C5AAD6B39BD8C63B5734AC6845AD69C73DEAD84E7BD94E7BDA5
D6AD8CB56B42BD8C63BD8C63CE946BC68C63D69C73D6AD8C000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7
EFEFF7EFE7E7E7D6C6E7C6ADC69C84C6946BB57B5A9C6B4A945A319C63399C6339945A31844A29\
6329107B4A297B4A296B3921E7C6B5F7CEB5EFCEADF7CEB5F7D6BDF7D6BDEFD6C6
F7D6BDEFD6C6F7C6B5F7C6B5F7C6B5F7CEB5EFC6ADEFC6A5EFC6A5EFC6A5E7BD9CDEAD94DEAD8C\
E7AD8CDEA584D69C7BCE946BB56B52AD6B42AD6B42B5734AAD6B42B56B52AD6B42
AD63429C63398442217B4221C6845A844221CE8C639C63396B3921734A31522110844221C67B4A\
8C4221B56B42C67B4AB56B39C6845AC6845AC6845ACE9463D69C73E7BD9CE7BDA5
D6AD84C68C63B57B5ABD8C63C6946BC6946BD6AD84D6AD8CD6AD84000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000F7F7F7F7EFF7
EFEFE7EFE7E7DECEBDD6BDADBD947BBD8C63B57B5AAD6B429463429C6339945A31945A316B3921\
6B31187B42216B3921A5846BEFCEB5F7CEB5EFC6ADF7CEB5F7CEB5F7D6BDF7D6BD
F7D6BDF7D6BDEFD6C6F7D6BDF7C6B5F7C6B5EFC6ADEFC6ADEFC6ADE7BDA5E7B59CE7BD9CE7B594\
E7AD8CDEAD94DEA584D69C7BC6846BCE946BAD6342AD6342AD6B429C6B4AAD6342
9463429C4A31844A31734229C67B4AAD7352B57B5AB5734A6B31185221107B42219C6339C67B4A\
C6845AC67B4AC67B4AC6845AAD6B42C68C63BD8C63C6946BD69C73D6AD84E7BD9C
E7BD94BD8C63B5734ABD8C63C67B4AC6946BD6B5A5E7BD94CEB5A5000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000EFEFE7F7F7F7EFEFF7
EFEFE7E7DED6DECEBDCEAD94BD947BBD8C63B5734A9C6B4A845239945A318C4A29945A31522918\
6B39217342298C5A42EFC6ADEFC6B5F7CEB5F7CEB5F7CEB5F7CEB5F7D6BDF7C6B5
F7D6BDF7C6B5F7C6B5F7D6BDF7C6B5F7C6B5EFC6ADEFC6A5EFC6ADEFC6ADEFC6A5E7B59CE7B59C\
E7B594DEAD94DEAD8CDEA584D69C7BCE946BC6846B9C6339AD6342AD6342945A42
9C6339844A297B4A296329109C6B4AD69C7B8C4A29CE946B946342AD6B426B3118AD63318C4A31\
BD8C63AD6331C67B42C67B4ABD8C63B58463C6946BB57B5AD6AD84CE9463E7BDA5
EFCEB5BD8C63B5734ABD8C63C68C63C69C84D69C73D6AD84D6AD8CE7BD94000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000F7F7F7F7F7F7F7EFF7EFE7E7
EFE7E7E7CEBDDECEBDC69C84C68C63AD7352B5734A946342945A31945A318452316B39216B3118\
844A29845A42EFC6B5EFC6ADEFCEADF7CEB5F7CEB5F7CEB5F7C6B5EFCEADEFC6AD
EFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFB59CEFB59CE7BDA5EFC6A5E7BD9CEFBD9CE7B59CE7B59C\
DEAD8CE7AD8CDEAD94DEAD8CDEA584D69C73CE946BCE8C639C63399C4A319C6339
8C4A318C4A296B39216B3921845239BD8C63B57B5A9C6B4AC69C848C4221B57B5A945A31AD6342\
B56B42C67B4AAD6B39C67B4ABD8C639C6339BD8C63BD8C63D69C73D69C73CEAD94
DEAD8CE7BD94BD8C63B56B42BD8C63C69C84C6946BD6AD84E7BD94E7D6CEEFEFE7000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000F7EFF7F7F7F7F7F7F7EFE7E7
E7D6CEE7CEBDCEB5A5BD947BB57B5AAD7352946342945A31945A31945A315A31216B39216B3118\
6B3118EFC6B5EFC6B5F7CEB5EFCEADEFC6ADEFC6ADF7C6B5EFC6ADEFBD9CE7B59C
E7AD94E7AD94DEAD8CDEAD8CDEAD8CDEA584DEAD8CDEAD8CDEAD8CDEAD8CE7B594E7B594E7B594\
E7B59CE7B594DEAD8CDEAD8CDEA584DE9C7BD69C7BD69C73CE8C63B56B52945A31
845231844A317342296B3921734A31946342CE946BBD8C63A57B5AD69C73C67B4AB57B5A844221\
AD6B39C6845AC67B42C67B4AAD6B39B57B5AB57B5AD69C7BC6946BD69C73D6AD84
E7BDA5E7C6B5BD8C63C6946BD69C7BC6946BC68C63CEAD94E7BD9CF7EFE7E7DED6000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000F7F7F7F7F7F7F7EFF7F7EFF7EFE7E7
E7D6C6DECEBDD6AD8CC6946BB5734AB5734AAD63428C4A31945A318452316B31186B3921844A29\
E7C6B5EFCEB5EFCEB5F7CEB5EFCEADEFC6ADEFC6ADEFC6A5E7BDA5E7AD94E7AD8C
DEA584DE9C7BE78C7BE78C7BE78C7BE78C7BE78C7BDEA584DE9C7BDEA584DEAD8CDEA584E7B594\
E7B594E7B59CDEAD94DEAD8CDEA584D6A584D69C7BCE946BCE946BC684638C5A42
8442297B4A296B39215229186B39218C634ACE946BAD7352945A31D6A584C67B4ACE9463B57B5A\
9C6339AD6B42CE8C5AC67B4AB5734ABD8C63B57B5AD69C73C6946BD6AD84D69C73
D6AD84E7C6ADD6AD84D69C73C69C84C69C84D69C73D6AD8CE7BDA5EFE7DEEFE7DEF7EFE7000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000F7EFE7F7F7F7F7EFF7EFEFE7E7D6CE
E7CEBDDECEC6C69C84B57B5AAD73529C6339AD6342845239844A296B39216B39217B39187B4A29\
EFC6B5EFC6B5EFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFB59CDE7363CE6B5ADE7B6B
DE7B6BDE8473DE8473DE8473DE8473DE8473CE6B5ACE6B5ACE6B5ACE6B5AD69C7BDEAD8CDEAD8C\
E7B594E7B594E7B594DEAD94DEAD8CDEA584D69C7BD69C7BCE946BC6846BC6845A
7B4A296B39216B31185221106B3118845239AD7352D69C7BB58463C6846BD6AD84CE9463D69C73\
C6946BC67B4AB5734AC6845ABD8C63AD6B39B5734ABD8C63D69C73BD8C63DEAD84
D6AD8CE7BD94E7BDA5C69C84D6AD84C6946BD69C73E7BD94DECEBDE7D6CEEFE7E7EFEFE7000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000F7F7F7F7F7F7F7EFE7F7F7F7EFE7E7E7DED6
E7D6C6D6AD8CC6946BA57B5A9C6B4A9C6339945A317B4A298452397342296B39217B4A29EFCEBD\
EFC6B5EFC6ADEFC6ADEFC6A5EFCEADEFC6ADE78C7BDE8473DE8473DE8473EFC6B5
EFB59CE78C7BE78C7BE7A594EFB59CDE8473DE8473DE7B6BC6846BCE7363CE6B5AD69C7BDEAD8C\
DEAD94E7B594E7B59CDEAD94DEAD8CDEAD8CD6A584D69C7BCE946BDE8473C68463
B57B5A734A31522918522918522110845239522918D6A584DEAD8C9C6339D6AD8CB57B5ADEA57B\
D6AD84BD8C63C6845ACE9463AD6331C6845AB57B5ABD8C63C6946BCE946BD69C7B
D6AD8CE7BDA5E7C6B5BD947BB58463C6946BD69C73CEAD94EFE7DEEFE7DEEFEFE7EFEFE7EFE7DE\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000F7F7F7F7F7F7EFEFF7F7F7F7E7D6D6DECEBD
CEAD94C6946BB58463A57B5A845239945A318C4A31945A316329106B39216B3921A5846BEFCEB5\
EFCEB5EFCEB5EFC6ADEFC6A5EFC6A5EFC6A5DE7B6BDE8473DE8473DE7B6BDE7363
DE7363DE7363DE8473CE6B5ACE6B5AC65A4AC6634AC6634AE78C7BCE7363CE7363C65A4AD6A58C\
E7AD94E7B594E7B594E7B594E7B594DEAD8CD6A584D69C7BD69C7BCE946BCE946B
C6845AAD73526B39216B39213918106B31188C5A42B58463C6946BB57B5ABD8C63D6AD84C6845A\
DEAD84EFCEADBD8C63B5734AC6845AC6845AAD6B42B57B5ACE9463C6946BD69C73
D69C73E7BDA5E7BDA5C69C84C6946BC69C84BD947BCEAD94EFE7DEEFE7E7F7EFE7EFE7E7EFE7E7\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7E7D6CED6C6B5
D69C73C6946BAD73529463428C4A31945A31844A296B31187B42216B3118945A31EFCEBDEFCEBD\
EFCEB5EFC6ADEFC6ADEFC6A5E78C7BDE8473AD73529C4A31AD4A31BD5242AD7352
BD5242BD5242C65A4AB552399C4A319C31219C4229AD4A318C3121AD42319C4229844229945A42\
DE8473E7B594E7B594E7B594DEAD8CDEAD8CDEAD8CD69C7BD69C7BD69C73D69C7B
C68463B57B5A8C5A424A18083918106B3921734A31845A42BD8C63D6A584945A31D6A584B57B5A\
D69C7BE7BD9CEFCEADCE946BCE946BB56B39C6845AB57B5ABD8C63C68C63B57B5A
D6AD84E7BD94E7BDA5D6BDADD69C73D6AD84C69C84D6B5A5E7DED6EFEFE7EFE7DEEFEFE7F7EFF7\
EFEFE7000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000F7EFF7F7EFF7F7EFE7F7EFF7EFE7E7E7D6CED6BDAD
BD947BB57B5A9463428C4A318C5A428C4A297B4A297B4A297B4A29844229EFCEBDEFCEBDEFC6B5\
EFCEB5F7CEB5EFC6ADEFC6A5EFB59CEFC6A5E78C7BCE7363CE6B5AC6634ACE6B5A
C6634ACE6B5ADE7B6BC6634AC6634AC6634AC6634AC6634AC6634AD69C73D6A584D6A58CDEAD8C\
DEAD8CE7B594E7B594E7AD8CE7AD8CDEAD8CE7AD8CDEA584D69C7BD69C7BD69C73
CE946BC684639C73525A39293918103918105A3929845A429C7352D69C7BC6946B9C6B4AD69C73\
B57B5AE7BD9CE7BD9CEFCEB5AD7352C6845AC6845AB57B5ABD8C63BD8C63B57B5A
D6AD84D6AD84E7BDA5E7C6ADC6946BD6AD84D69C73E7D6C6EFE7E7EFE7E7EFE7DEEFE7DEF7EFF7\
F7EFF7000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000F7EFE7F7F7F7F7EFF7EFEFE7F7EFE7EFE7DEDECEC6D6AD8C
B584639C6B4A9C6B4A8C5A428C4A29844A297342297B4A29844221845231EFCEB5EFC6ADEFCEB5\
EFCEADEFC6ADEFCEADEFC6A5EFCEADF7CEB5F7CEB5F7D6BDEFD6C6EFC6B5EFC6AD
F7D6BDEFC6ADEFC6A5F7CEB5F7D6BDEFC6B5EFC6ADE7BDA5E7B59CE7BDA5E7B59CE7B594E7B594\
E7B59CE7B594E7B59CE7B594E7AD94DEAD8CDEAD8CDEA584DEA584D69C7BD69C73
CE946BCE946BB57B5A845231423129291008845A42734A31845A429C7352BD8C639C6339C6845A\
AD6B42C6845AE7BD9CE7BD9CD69C73CE946BBD8C63B5734AB5734ABD8C63CE946B
D69C73CE946BE7BDA5E7C6ADC69C84C69C84C68C63E7DED6EFE7DEEFE7DEEFE7E7EFE7DEF7F7F7\
F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000F7EFF7F7EFE7F7EFF7F7EFF7EFE7E7DEC6B5E7BD9CC69C84
AD7352946342845231845231844A316B31187B4A297B4A297B4221D6B5A5EFCEB5EFCEB5EFCEB5\
F7C6B5F7CEB5EFC6ADF7CEB5EFC6ADF7CEB5F7CEB5F7D6BDF7CEB5F7D6BDF7CEB5
F7D6BDEFC6A5EFC6ADEFC6ADEFC6ADE7B59CE7B59CE7B59CE7B59CE7BD9CE7B59CE7BD9CEFC6A5\
E7B59CE7B594E7BD9CE7B59CE7AD94E7AD94DEAD8CDEA584DEA584D69C7BDE8473
CE946BCE946BB57B5A945A42522110422118734A31845231A5846B9C7352C69C849C6339945A31\
C68C63BD8C63DEAD94E7BD9CEFC6A5D6AD84C6845AC6845AC68C63B5734AB57B5A
B57B5ACE946BE7BDA5E7C6ADD69C73D6AD8CC6946BEFE7DEEFE7E7E7DED6EFE7DEF7EFE7F7F7F7\
F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000F7EFF7F7EFF7F7EFE7F7EFF7F7EFF7DECEC6C69C84B57B5A
9C63399C6B4A844A29844A316B39217B4A297B4A297B4A297B4A29EFCEB5EFCEB5EFC6B5EFCEB5\
F7CEB5F7C6B5F7C6B5F7CEB5EFCEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5
EFCEB5EFC6ADEFC6A5EFC6A5EFC6A5E7B59CE7BD9CEFBD9CE7B59CE7BDA5E7B59CEFC6A5E7B59C\
EFC6A5E7B59CE7B59CE7AD94E7AD94E7B594DEAD8CDEA584DE9C7BDEA584D69C73
CE946BCE946BC684639C6B4A7342295A39293918107352428452399463429C6339AD73529C6339\
B57B5AA57B5ACE946BE7BD94E7BD94CE946BD69C73C6845ABD8C63B5734ABD8C63
B5734AD69C73D6AD84E7BDA5CEAD94C6946BD69C7BE7D6CEEFE7DEEFE7DEE7D6C6F7F7F7F7EFF7\
F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F7F7F7F7F7F7F7EFF7F7EFF7F7EFE7DECEC6D6C6B5BD947BB5734A
9C6B4A844A298C5A426B39217B4A296B31187B4A29844A296B3921EFCEB5EFC6B5EFC6B5EFCEB5\
F7CEB5F7CEB5F7CEB5F7C6B5F7CEB5F7CEB5F7CEB5F7CEB5EFCEB5F7CEB5F7CEB5
EFC6A5EFC6A5E7B59CEFC6A5E7B59CE7AD8CE7B594E7BD9CE7B59CEFB59CEFBD9CEFC6A5EFB59C\
EFB59CEFC6ADEFC6A5E7B59CE7B59CE7AD94E7AD8CDEA584DEA584D69C7BD69C73
DE8473C6846BC68463B5734A734A31522110522918734A318C634A946B529C7352B584639C6B4A\
8C5A42946342BD947BC68C63DEA573EFC6A5D6AD84C67B4AC68C639C6B4AC6946B
BD8C63D69C7BD69C73E7BDA5CEAD94BD8C63E7C6B5E7D6C6EFE7E7EFE7E7EFE7E7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F7EFF7F7EFF7F7F7F7F7F7F7EFE7E7DEC6B5C6A594BD947B9C6B4A
9C63399463428442297B4A297B4A29734A317B4A296B3921B58463E7C6B5EFC6B5EFC6B5F7CEB5\
F7CEB5F7CEB5F7CEB5F7D6BDF7CEB5EFCEB5F7CEB5F7CEB5F7CEB5EFC6ADEFC6AD
E7B59CDEAD8CDEA584E7AD94DEAD94DEA584DEAD8CE7AD94E7B594E7B59CEFBD9CE7BDA5EFC6A5\
EFC6ADEFC6ADEFB59CEFB59CE7B59CE7AD94DEAD8CDEA584DEA584D69C7BD69C7B
D69C73CE946BC67B5AB56B528C5A425A39296B39215A4239845A428452399C7352946342B5734A\
8452319C6339845239D6AD8CE7BD94D69C73DEA57BC68C63C6946BA57B5AB57B5A
BD8C63C69C84D69C73E7BD9CD6B5A5C6946BE7DED6E7BDA5F7EFF7EFE7E7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F7F7F7F7EFE7F7F7F7F7EFF7F7EFF7E7BD9CBD947BAD7352946342
8C4A318C4A317B4A296B39216B39217B4A297B4A296B3118E7C6B5EFC6B5EFC6B5F7C6B5F7CEB5\
F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5EFCEADF7CEB5F7CEB5F7CEB5EFC6ADEFB59C
E7AD9CE7B594DE9C7BDEA584DEA584D69C7BD6A584DEAD8CDEAD8CE7B594E7B59CEFBD9CEFB59C\
EFC6A5EFC6A5EFC6A5EFB59CEFC6A5EFB594E7AD94DEAD8CDEA584D69C7BD69C7B
D69C73C6846BC68463B57B5A945A425A3929291008422921734A318452319C6B4A845239B5734A\
9C63399C63397B4A29D6A584C6845AD69C73EFCEADC6946BC68C63C68C63B57B5A
B58C73C6845AC6946BE7BD9CD6BDADD6BDADDECEBDE7D6CEE7D6CEE7CEC6F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7D6AD8CB58463946342845231
8C4A316B39217B4A297342297B4A298442296B31185A3121EFC6B5E7C6ADEFC6ADEFC6ADF7CEB5\
F7C6B5F7D6BDF7D6BDF7CEB5F7CEB5F7CEB5F7C6B5EFD6C6DE9C7BDE7B6BEFC6AD
EFC6ADEFB59CE7A594B56342B56342C6846BDE9C7BB57B5AD69C73DEAD8CE7B59CEFC6A5EFC6A5\
EFC6ADEFC6ADEFC6ADEFC6A5EFB59CE7B59CE7AD94E7AD8CDEA584DEA584D69C7B
D69C73CE946BC68463B56B52AD63427342293918104229215A3121734A31845239845A429C6B4A\
9C6B4A8452319C6B4A8C5A42BD8C63DEAD84D69C73DEAD84C6845ABD8C639C6339
B57B5AB57B5AD69C73E7BD94D6BDADEFE7E7CEAD94EFE7E7D6B5A5F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7E7DEDEC6946BAD73529463429C6339
7B4A297B4A296B39217B42217B4A296B39215A3121845239EFC6B5EFC6ADEFCEB5F7CEB5F7D6BD\
F7CEB5F7C6B5F7D6BDF7C6B5F7CEB5EFCEADF7CEB5F7D6BDEFCEB5EFC6B5F7C6B5
F7C6B5EFC6ADE7B594DEAD8CDEAD94E7AD8CE7B594DEA584CE8C63D69C7BE7B59CEFC6ADEFC6AD\
EFC6ADEFC6ADEFC6ADEFB59CEFC6A5EFC6A5EFB594E7AD8CDEAD8CDEA584D69C7B
CE946BCE946BC68463C67B5A9C73528C5A422910083918104229215A42397352428C5A42845239\
9C7352845231945A31522918D6AD84CE8C63CE9463E7BD9CB57B5ABD8C639C6B4A
AD7352BD8C63C6946BCEAD94DEC6B5DEC6B5C6AD9CD6B5A5F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7E7D6CEBD8C63946342945A426B3921
734A31844A317342297B4A29844A31632910632910A57B63E7C6ADF7C6B5F7C6B5F7C6B5EFD6C6\
F7D6BDF7D6BDF7D6BDEFD6C6F7CEB5F7CEB5F7C6B5F7D6BDEFC6B5EFD6C6EFD6C6
EFD6C6F7C6B5EFC6A5E7B594E7AD9CE7AD9CDEAD94DEAD8CDEA584DEA584EFB59CEFC6ADEFC6AD\
F7C6B5EFC6ADEFC6ADEFC6ADEFB59CEFB59CEFB59CE7B594E7AD8CDEAD8CDE9C7B
DE8473DE8473C68463B57B5AAD6B42946342291008422118391810734A31845239946342734229\
9C6B4A845231945A315A3121C6946BBD8C63D6AD84E7BD9CB57B5ABD8C63AD7352
B57B5AB58463BD947BD6AD8CDEC6B5DEC6B5D6BDADDECEBDF7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7E7CEC6AD73528C5A42945A31845231
7B4A297B4A29844A298C4A317B42215229185A3929E7C6B5EFC6B5F7CEB5F7CEB5F7D6BDF7D6BD\
F7D6BDEFD6C6F7D6BDEFD6C6F7D6BDF7C6B5EFC6ADF7D6BDF7D6BDEFD6C6F7DED6
EFD6C6F7C6B5EFC6ADE7BDA5E7AD94E7A594DEAD94DEAD8CDEA584E7AD94EFB59CEFC6ADEFC6AD\
EFCEADEFC6ADF7C6B5EFC6ADEFC6A5EFC6A5EFB59CEFB59CE7AD94E7AD8CDEA584
DE9C7BCE946BC6846BB57B5AAD6B42945A315229181808084221187342295229189C6339845231\
9C6B4A7B42218452318C5A42AD7352C68C63DEA57BDEA57BD69C73B57B5ABD8C63
AD7352B57B5AB57B5ACEAD94E7C6ADD6B5A5E7CEC6F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7EFF7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F7EFF7F7F7F7F7F7F7F7F7F7F7EFE7C6946B9463429463426B3921734229
7342297B4A29844A317B4A29422118632910422118EFC6ADF7C6B5EFCEBDF7C6B5F7D6BDF7D6BD\
EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7C6B5EFD6C6EFD6C6
EFD6C6F7CEB5EFC6ADE7AD94D6A58CDEA584DEAD8CD6A58CDEAD94E7B59CEFC6ADEFC6B5EFC6B5\
EFCEB5F7CEB5EFC6ADEFC6ADEFC6A5EFC6ADEFC6A5EFB59CE7AD94E7AD8CDEAD8C
DEA584D69C73C6846BB57B5AAD7352AD6342734A312110083918105A39297B5A428452398C5A42\
9463427B4A29845231734A319C7352C6845ACE946BDEAD8CE7BDA5B5734AB57B5A
9C7352B57B5AC6946BE7BD9CE7C6ADC69C84DECEBDF7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7\
F7F7F7F7F7F7F7F7F7F7EFF7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7EFEFF7B5846B946342844A296B3921845239
844A31844A317B4A293918105229185221105A3929EFC6ADF7CEB5F7D6BDEFD6C6EFD6C6EFD6C6\
EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDF7D6BDF7C6B5EFCEBDF7C6B5F7D6BD
F7C6B5EFC6B5EFB59CE7B59CD6A58CDEAD8CDEAD94DEAD94E7B59CEFC6ADEFC6ADEFC6ADEFC6B5\
F7C6B5F7CEB5EFC6B5F7C6B5EFC6ADEFC6A5EFC6ADEFB59CEFB59CE7AD94E7AD8C
D6A584DEA584CE946BC68463AD73529C6B4A8C4A31291008423129522918734229734A31845231\
8452319C6339845231845231A57B5ABD8C63CE9463DEAD8CEFCEADB57B5AB5734A
9C6B4AA57B5AB58463CEAD94DEC6B5DECEBDF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7B5846B945A317B4A297B4A29845239
734A317B4A29844A31522918422118522918CEAD94EFCEB5EFCEB5F7D6BDEFD6C6EFD6C6EFD6C6\
EFD6C6F7DECEF7DECEF7DECEEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5EFC6B5F7D6BD
F7D6BDEFC6ADEFB59CDEAD94DEAD94DEAD8CE7B594E7B59CE7BDA5EFC6ADEFCEB5EFC6B5F7C6B5\
F7C6B5F7D6BDEFCEBDF7C6B5EFC6B5EFC6ADEFC6ADEFB59CE7B59CE7B59CDEAD94
DEA584D69C7BD69C73C68463B56B529C6B4A9463424221182110085A31215229188452398C5A42\
7B4A29945A319C63398452319C7352C69C84D69C73DEAD84EFCEADAD7352C68C63
8C5A42B58463AD7352E7BD94E7CEBDDECEBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7DEC6C69C73528C5A42734229845231845231
844A317B4A29522918422118391810EFB59CEFCEBDF7C6B5F7D6BDF7DECEEFD6C6EFD6C6F7DECE\
EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDF7CEB5F7D6BD
F7D6BDF7C6B5EFC6ADE7B59CDEAD94E7B594E7B594E7B59CE7BDA5EFC6B5EFC6B5EFD6C6F7D6BD\
F7C6B5EFD6C6F7C6B5F7D6BDEFCEBDEFCEBDEFC6B5EFC6ADE7C6ADEFB59CE7B594
DEAD8CD6A584D69C7BD69C73B57B5A9C6B4A9C63397342296329106B3921734A31734A31946342\
8452319C63398C5A428C4A319C7352D6A584D69C73D6AD84E7BDA5BD8C63B5734A
845231A57B5AB57B5ADEAD8CE7D6C6EFEFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79C7352945A318452315A31217B5A42734A31
734A31844A315229186B39215A3929EFC6ADEFC6B5EFD6C6F7D6BDEFD6C6EFD6C6F7DECEF7DECE\
EFD6C6EFD6C6F7D6BDF7DECEEFD6C6EFD6C6EFD6C6EFD6C6F7D6BDEFCEBDF7D6BD
F7D6BDF7D6BDF7C6B5E7B59CDEAD94E7B59CE7BD9CE7BDA5E7BDA5E7C6ADEFCEB5F7D6BDEFCEBD\
F7D6BDEFD6C6F7D6BDF7C6B5EFCEBDEFCEBDEFCEBDEFC6B5EFC6ADE7BDA5E7B59C
DEAD94DEAD8CD69C7BD69C73C67B5AB56B52945A42734A316B39216B39216B3921845239845231\
9C63399463428C5A4294735AB5846BD69C7BD69C73D69C73D6AD84C68C63AD6B39
844A29A57B5ABD947BD6AD8CE7DED6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7AD73529C6339734A316B39218C5A42845239
7B4A297342296B3921522918A58473F7C6B5EFCEBDEFD6C6EFD6C6EFD6C6F7DECEF7DECEEFD6C6\
F7D6BDEFD6C6F7D6BDF7D6BDEFD6C6F7DECEF7DECEEFD6C6EFD6C6F7D6BDF7D6BD
EFD6C6F7C6B5F7C6B5E7B59CDEAD94DEAD94E7BD9CE7BDA5EFC6ADEFC6ADEFCEBDEFCEBDEFCEBD\
EFD6C6EFD6C6F7C6B5F7C6B5F7D6BDF7CEB5EFCEB5EFC6B5EFC6ADEFC6ADE7BDA5
DEAD94DEAD8CD6A584D69C73C68463B56B52945A428C4A315A31215A31216B3921734A31844A31\
9463429C6339946342945A31D69C73D69C73D69C73D69C73D6A584D6AD84AD6B42
AD6B42AD7352B58463DEAD84EFEFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF79C73529C7352845239734A31734229845239
844A315A3121734229845239EFC6B5F7CEB5EFCEBDEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6\
EFD6C6F7D6BDEFD6C6EFCEBDEFD6C6EFD6C6EFD6C6EFD6C6F7D6BDF7D6BDEFC6B5
EFD6C6EFD6C6F7D6BDE7BDA5E7AD94DEAD94E7B59CE7BDA5E7BDA5E7C6ADEFC6B5EFCEBDEFCEBD\
EFCEBDEFD6C6EFCEBDF7D6BDEFCEBDEFC6B5EFC6B5EFC6ADEFC6B5E7C6ADE7BDA5
E7BDA5DEAD94D6A584D69C7BCE946BB57B5A9C6B4A8452397342296B31186B39216B3921845239\
945A318C634A845239844A29D6AD8CD69C73C6946BD69C7BC69C84DEAD8C945A31
AD7352AD7352A5846BD6AD84F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7EFF7F7F7F7BDADAD945A318C634A8452318C5A428452318C4A31
6B39215A3929734229E7C6ADF7D6BDEFC6B5F7D6BDEFD6C6EFD6C6EFD6C6EFD6C6F7DECEEFD6C6\
EFD6C6F7D6BDEFCEBDEFC6B5EFC6B5EFCEBDEFCEBDF7D6BDF7D6BDF7C6B5F7CEB5
EFD6C6EFD6C6F7D6BDEFC6ADE7AD94DEAD8CDEAD94DEAD9CE7BD9CDEAD9CE7C6B5E7CEBDEFC6B5\
EFD6C6EFCEBDEFCEBDEFCEBDEFC6B5E7C6B5EFC6B5EFC6ADEFC6ADEFC6ADE7BDA5
E7BDA5DEAD9CDEAD8CD6A584DE8473C684639C6B4A945A31734A315229186B39216B3921734A31\
9C6B4A8C5A428C5A428C5A42C69C84C6946BD69C73D69C739C6B4AE7BD94844221
9C6B4ABD8C63C6946BCEAD94F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7EFF7F7F7F7A57B6BB58C739C6B4A734A319C6B4A734A318C4A31
5A3121734A317B4A29E7C6ADF7C6B5E7C6ADEFD6C6EFD6C6F7DECEEFD6C6EFD6C6F7D6BDEFD6C6\
EFCEBDEFCEBDEFB59CE7C6ADEFC6ADEFC6ADEFC6B5EFCEBDF7D6BDEFCEB5F7CEB5
F7D6BDEFD6C6F7D6BDEFC6ADE7A594DEAD8CD6A58CDEAD94DEAD94E7BDA5E7C6B5EFC6B5EFCEBD\
E7C6ADE7C6ADE7BDA5E7C6ADE7C6ADE7C6ADE7C6ADEFC6ADEFC6B5E7C6ADE7C6AD
D6B5A5E7BD9CDEAD8CD6A584D69C73C68463AD7352945A31844A315229185221106B3921734A31\
8C5A429C63398C5A428C5A42C69C84CE946BCE946BD69C73844A31DEAD84945A42
8C5A42B5846BD6A584E7C6ADF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7EFF7F7EFF7F7F7F7F7F7F78C4A29B5947B8C5A42946B52845A428C5A42734A31
5229189C6339E7AD8CEFC6ADE7AD94EFC6B5F7D6BDEFD6C6EFD6C6EFD6C6EFD6C6EFCEBDE7CEBD\
EFC6B5EFC6B5EFC6ADDEAD9CDEAD94E7BDA5E7C6ADEFC6B5EFCEBDE7C6ADEFC6B5
EFD6C6EFD6C6F7D6BDEFB59CDEAD94DE9C7BD6AD8CD6A58CCEAD94D6B5A5E7C6ADE7C6B5E7BDA5\
E7BDA5D6B5A5E7AD9CDEAD8CDEAD8CD6A58CDEAD9CDEAD9CE7BDA5E7BDA5E7BDA5
E7BD9CE7BD9CDEAD94D6A584CE946BC6846BB56B529C6B4A8452397342293918106329106B3921\
8C5A428C5A429C6B4A845239BD947BD69C7BB57B5ABD8C63844A29E7BD949C6B4A
8C4A31C6946BD6AD84E7D6C6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7F7F7FFFFFF9C6B4AA57B638452398C5A42845239945A42522110
845231844A31F7C6B5CE946BDEA584EFCEB5F7D6BDEFD6C6EFD6C6EFD6C6EFCEBDE7C6B5DEAD9C\
BD947BB58C73D6A58CCEA594BD947BDEAD9CDEAD9CEFCEBDEFCEBDEFC6B5EFC6B5
F7D6BDF7D6BDF7D6BDEFC6ADDEAD94D69C7BC69C84D69C7BE7BD9CDEAD9CE7C6B5E7AD9CDEAD9C\
C6A59CBD9C8CB5846BB58C73C69C84C69C84C69C84CEA594E7BD9CE7BDA5DEAD9C
DEAD9CDEAD9CDEAD8CD6A584C69C84C6846BB57B5A945A42845239734A316B39215A31215A3121\
8452398452318C634A8C5A42B5846BBD8C63B57B5AB57B5A945A31E7BD94945A31
8C4A31C69C84D69C73E7D6CEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7F7F7BD9C94A57B5A9C7352734A31845239734A31945A425A3121
945A31EFB594EFB59CE78C7BD6A58CEFCEB5EFCEBDEFD6C6EFD6C6EFC6B5E7AD9CB58463BD8C63\
DEAD9CBDADAD736B6373736BA58473C69C84DE8473DE8473EFC6B5EFC6B5E7C6AD
F7D6BDF7D6BDF7D6BDEFC6A5E7B59CD69C7BD6A584BD947BD6A5849C4A31C65A4AC6846BD6A58C\
DEC6C6947B73735A4AA57B6BA57B63A57B5AA57B63B5846BD6A58CDEAD94DEAD94
DEAD9CDEAD9CD6A58CD6A58CCE946BC6846BB56B529C6B4A8C5A42734A31845239522918522918\
8452398452398C5A429C6B4AB58463BD947BB5734AB57B5A945229E7BD9C9C6339
9C7352D6AD84D6AD84EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7F7F7B5846BBD9C8C9C73528C634A5A3121845239945A426B3118
522918F7C6B5E7AD8CE7A594DEAD94EFCEBDF7D6BDEFCEBDE7C6ADE7AD9CB5846BC6846BD6BDB5\
E7D6CE7B7373736B63635A52847B73A57B6BC69C84BD947BE7AD9CDEAD94EFC6A5
F7D6BDF7D6BDEFCEB5EFC6ADE7B59CDEA584BD947BB5846BC6846BC69C84AD4231DEC6C6EFE7E7\
8C736394735A7B6B5A948C846B635ABD9C949C73528C6B52B5846BD6A584D6A584
DEAD94DEAD8CD6A58CD69C7BD69C73B5846BAD73529C6B4A845231734A315A3121291008422118\
8452398C5A427342299C6B4AB5846BB584639C6B4AA57B5AAD6342DEAD8C844A29
BD947BD6AD8CD6AD8CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7FFFFFFF7EFF7A5846B8452317B4A295A3121845239845239845239
945A42F7C6B5DEA584E78C7BDEAD94E7C6B5EFCEB5EFC6ADDEAD9CBD947B94735A5A3929B5948C\
C6B5B5947B6BB5B5BD21181884736B5A4A4294735AB5846BBD947BE7B59CEFCEAD
F7D6BDF7D6BDF7CEB5EFC6ADE7BD9CE7B594BD947BB58C739C7352B58C73BD947B9C6B4ACEC6BD\
635A52B5BDCE21181873736B635A52BD9C94423129735242A57B63B58C73BD947B
D6A584D6A58CD6A584BD947BC6946BC68463AD7352945A42845239844A31422118391810422118\
522918845239734A31AD73529C7352A57B5AA57B5AB57B5AAD6342D6AD84844A29
BD8C63D69C7BDEC6B5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7B5947BD6C6C6A58C7394735A7B5242734A31845239845239945A42
CE7363EFB59CE78C7BD69C7BDEAD8CEFC6B5EFCEB5E7B59CCEA594C6846B734A31846352846352\
5A42394229215A39298452398C6B52846352A57B63BD947BE7AD94EFBD9CF7CEB5
F7CEB5F7D6BDF7CEB5EFC6ADEFBD9CE7B59CDEA584BD947BC6846BAD735294735AA58C84A58C84\
5A39295229185A39295A3929734A315A4239735A4A7B5242A57B63B58463B5846B
CE946BD69C7BD69C7BBD947BB5846BB57B5A945A428C5A428C5A42734A316B39214221185A3929\
6B39216B3921734A319C6B4AAD73529C6B4A9C6339B57B5AAD7352D6AD84946342
BD8C63D69C73EFE7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7AD7352BD9C94B59C8C8C5A42734A318C634A845239734A318C4A31
C68463E7A594D69C7BD69C7BDEAD8CEFC6B5E7C6B5E7C6ADE7BDA5DEAD94BD947BB56B528C634A\
7B52427B52427B524284523994735AC6846BD6A584E7B59CEFC6ADEFC6ADF7CEB5
F7D6BDF7D6BDF7CEB5EFC6ADEFC6ADEFC6A5E7B594DEA584D69C7BBD947BB5846B84634AA57B63\
A584739C7B6B846352634A425A4239734A319C7352BD8C63B58C73C6846BCE946B
D69C7BD69C7BBD947BCE946BBD8C63B56B52945A428C5A428452398452397342295229185A3929\
5A31215A31217342299C7352B57B5A9C73529C6339B57B5ABD8C63D6AD849C6B4A
BD8C63D6A584EFEFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F7F7F7EFE7DEA58C7B946B52734A31734229734A31734A316B39219C6B4A
C68463CE946BC69C84BD947BD6A58CE7C6B5EFCEB5EFCEB5F7D6BDEFCEBDEFC6ADEFC6B5E7BDA5\
E7B59CE7AD9CE7B59CE7BDA5E7B59CD69C7BDEA584E7AD94EFC6A5F7D6BDF7CEB5
EFD6C6EFD6C6F7D6BDF7CEB5EFCEADEFC6ADE7B594D69C73DE9C7BBD947BD6A584D6A58CD6A584\
BD947BBD947BBD947BCE946BD69C7BD6A584D6A584DEAD8CE7AD8CDEAD94D6A58C
D6A584D69C7BCE946BC6846BBD8C63B57B5A945A428C634A8452396B39216B39215229185A3929\
734A317342296B39219C6B4ABD8C639C6B4A9C6339C6845ABD947BDEAD949C7352
BD947BEFDECEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000FFFFFFFFFFFF7342298C5A425A31216B39216B39219463425A31219C4A31
B56B52DE8473CE946BB58C73D6A584EFCEB5E7BDA5F7CEB5F7D6BDF7D6BDEFD6C6F7D6BDF7D6BD\
EFD6C6E7A594C6846BA57B639C7352B56B52E7B59CEFC6A5F7D6BDF7D6BDF7D6BD
F7DECEEFD6C6F7D6BDEFD6C6F7CEB5F7D6BDEFBD9CE7AD94C6846BAD63429C7352B56B52B58C73\
E7BDA5E7C6ADEFC6ADE7C6ADE7BDA5E7BDA5E7B59CE7B59CE7B59CDEAD94D6A584
C6946BB58463CE946BBD8C63B57B5AAD73529C6B4A8C5A42845231845239632910522918522918\
5A3929522110734A318C5A42AD73529C6B4A946342C68C63C6946BE7BD9CA57B5A
C69C84EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFE7E7FFFFFF6B39217B4A295A31216B3921734A31845239734A319C6339
B56342B57B5ABD8C63C6846BC69C84EFC6ADDEC6B5E7BD9CEFC6B5F7D6BDEFD6C6EFD6C6F7C6B5\
B5846BA57B6394735AB56B52D6A584EFC6A5F7CEB5F7CEB5F7D6BDF7DECEF7D6BD
F7DECEEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5F7CEB5EFC6A5E7AD94BD8C63945A42845239945A42\
B56B52DEA584E7AD9CE7C6ADEFC6ADEFC6ADEFB59CE7BDA5DEAD94DEA584BD947B
A57B5ACE946BB58C73B5846BAD73529C6B4A9C6B4A8C5A426B39216B39215229185A3121522918\
522110735242845A42946B52A57B5A9C7352945A31BD8C63BD8C63D6AD8CBD947B
C69C84F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000BDADADFFFFFF845231734229734A31734A315A31218452397B4A29945A31
945A42945A42A57B63B5846BC69C84E7C6B5EFCEBDBD947BC69C84D6A584D69C7BDE8473B56B52\
AD7352D69C7BF7CEB5F7D6BDF7D6BDF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDEFD6C6F7CEB5F7CEB5F7CEB5EFCEADE7B59CD6A584B58C73\
94735A8C5A429C7352AD6342CE6B5AB58C73C6846BB58463A57B63A57B5AB5846B
BD947BBD947BDE8473BD8C63AD73529C6B4A9C6B4A8452399C6B4A4221187342297342296B3921\
52291842292184634A9C6B4AAD73529C6B4A946342BD8C63D69C73B5846BAD6B42
DECEBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000C6A5949C7352734A31734A3184634A845239734A31734A31734A31845239
945A318C634A9C7352A57B5AD6A584E7C6B5EFCEB5EFCEB5EFC6ADD6A584BD9C8CDE8473DEAD9C\
EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DED6
EFD6C6EFD6C6F7DECEF7DECEF7DECEF7D6BDF7D6BDEFD6C6F7D6BDF7CEB5F7C6B5EFC6ADEFC6AD\
EFC6ADE7C6ADE7C6ADC69C84A57B63AD7352A57B63A57B63BD947BC69C84BD947B
CE946BD69C73CE946BBD8C63AD73529C7352AD73528452396B3921734A316B39215A3121391810\
3918104221188C634A94735A8C5A42A57B5AAD6342C6946BC69C849C6B4ABD8C63
EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000009C6B4A7B5A42734A319C7B6B8C6B527B5A42845239734A318C5A42
8C5A428C634AAD7352AD7352D69C7BEFC6ADEFC6B5EFCEB5EFCEB5F7D6BDF7D6BDEFD6C6EFD6C6\
EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DED6F7DECEF7DECE
EFD6C6F7DECEF7DECEF7DECEEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDEFCEB5EFCEB5F7CEB5\
EFC6ADEFC6ADEFC6ADE7BDA5E7C6ADE7C6ADE7B59CDEAD94DEAD8CD6A58CD69C7B
D6A584BD947BB58C73B57B5AAD7352A57B5AAD73529C6B4A734A316B3921522110391810391810\
391810422118B58C738C634A8C5A42D69C739C6B4AB57B5AD6AD849C6B4AC69C84
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000844A29735242845A42A58C73946B52845239845A427B5A42845A42
845A428C5A42A57B5A9C7352D69C7BE7C6ADEFCEB5EFCEB5EFCEBDF7D6BDF7D6BDEFD6C6F7DECE\
F7DECEEFD6C6F7D6BDF7DECEF7DECEF7DECEF7D6BDF7DECEF7DECEF7DECEF7DECE
F7D6BDEFD6C6F7DECEEFD6C6EFD6C6F7DECEEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7C6B5F7CEB5\
EFC6B5EFC6ADE7C6ADE7BDA5EFC6ADE7B59CE7B59CDEAD94D6A584D6A584D69C7B
D69C7BBD947BC6946BBD8C63B56B52AD7352AD73528C5A429C6B4A734229522918522918422118\
5A3121522110BD947BA57B5A8C5A42BD947BAD73529C6B4AD6AD8C9C6B4AD6BDAD
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000008452398C6B528C634A9C73528C634A8C6B528C634A845A42845239
8452318452319C6B4A9C7352C6846BE7BD9CEFC6B5EFCEB5EFCEB5EFCEBDF7D6BDF7D6BDEFD6C6\
F7DECEF7DECEF7D6BDF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
F7DECEF7DECEF7DECEF7DECEF7DECEEFD6C6EFD6C6EFD6C6F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5\
EFC6ADEFC6A5E7C6ADEFC6ADE7BDA5E7BD9CE7B594DEAD94DEAD8CD6A58CD6A584
D69C7BD69C73CE946BB57B5AAD7352B57B5A9C73529C6B4A734A315A31216B39215A3121391810\
391810422118C6946BA57B639C6B4AD69C73B5734A8C634ABD947B9C6B4AF7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000084523984523984523984634A8C634A845239845A42845239
845A42845239A57B5AB57B5AC6946BE7B59CE7BDA5EFCEADEFCEBDF7CEB5F7D6BDF7D6BDEFD6C6\
EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6BDF7D6BDF7DECEF7DECEF7DECE
F7DECEF7DECEEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7C6B5F7CEB5F7CEB5F7CEB5EFCEADEFC6AD\
EFC6ADEFC6ADEFB59CE7BDA5E7BD9CE7BDA5E7B59CDEAD8CDEAD94DEA584D6A584
BD947BCE946BC6846BBD8C63B57B5AAD73529C6B4A845239734A315A3929734229422118391810\
3918105A31219C7352D69C73B58463D69C7BB57B5A9C7352946342CEAD94F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000008C6B528452398C634A8C6B52946B528C634A845A42845A42
8452398C634A9C7352BD8C63BD947BDEAD8CE7BDA5EFCEB5EFCEBDF7D6BDF7D6BDF7D6BDF7D6BD\
F7DECEF7DECEF7D6BDF7D6BDF7DECEF7DECEF7D6BDF7DECEF7DECEEFD6C6F7DECE
F7DECEF7DECEEFD6C6EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5EFCEADEFC6AD\
EFC6ADEFC6ADEFB59CE7B59CE7B59CE7B59CE7B59CE7AD94DEAD8CD6A58CD6A584
D69C7BCE946BB58C73B58463B58463A57B639C6B4A8C5A426B3921734A31522110422118422118\
39181042292194735ABD947B9C7352C6946BBD8C63A5846B946342E7CEC6F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000007352428C5A42946B52946B52845A428C634A8452397B5A42
946B528C634A9C7352B5846BC6946BD6A58CE7BDA5EFC6ADF7CEB5F7CEB5F7CEB5F7D6BDF7D6BD\
F7D6BDF7DECEF7DECEEFD6C6F7D6BDF7DECEF7DECEEFD6C6F7D6BDF7DECEF7D6BD
EFD6C6EFD6C6F7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5F7D6BDF7CEB5F7CEB5EFC6ADF7CEB5\
EFC6ADEFC6A5EFC6A5E7BDA5E7BD9CE7BDA5E7B594DEAD94DEAD8CD6A58CD6A584
BD947BCE946BC6846BB58463B584639C6B4A9C6B4A8C5A42734A316B3921522110391810291008\
2910087B52428C634AA57B5AAD7352C69C84C6946BD6AD8CC6946BF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000A57B5A8C5A428C634A84634A8C5A42845A429C6339
7342298C634AA57B63BD8C63B58C73D6A584E7BD9CEFC6ADEFCEB5F7CEB5F7D6BDF7D6BDF7D6BD\
F7DECEF7DECEEFD6C6F7DECEF7DECEF7DECEF7D6BDF7DECEF7D6BDEFD6C6F7DECE
F7D6BDEFD6C6EFD6C6F7D6BDEFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDEFC6ADF7C6B5EFCEAD\
EFC6ADEFC6ADEFB59CEFC6A5E7B59CE7B59CDEAD94DEAD94DEAD8CD6A58CD6A584
BD947BD69C73B58C73B5846B9C7352946B52845A42734A318452395A3121391810291008422921\
29100884634A946B529C6B4A946342C6946BC6946BC69C84E7DED6F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000007B5A427B5A42845239845239845231845A42845239
8C634A8C634AA57B5AB58C73C69C84D6A58CE7BD9CEFC6ADEFCEB5F7D6BDF7D6BDEFD6C6F7D6BD\
F7DECEF7DECEF7D6BDF7DECEF7D6BDF7DECEF7D6BDEFD6C6F7D6BDF7DECEF7D6BD
EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7C6B5F7CEB5F7CEB5EFC6AD\
EFC6ADEFC6ADEFB59CEFC6A5E7B59CE7B59CDEAD94DEAD8CDEAD8CDEAD8CD6A584
C69C84D69C7BB5846BA57B639C73529C73529C6B4A7B5A426B39215A3121391810391810422921\
391810946B52946B529C73529C6339C6946BC69C84D6A58CF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000845239734A31845231735242734A317B5A42
8C634A9C6B4AB58463B58C73D69C7BD6AD8CE7BD9CEFC6ADF7CEB5F7C6B5F7D6BDEFD6C6F7D6BD\
F7D6BDF7D6BDF7D6BDEFD6C6F7DECEF7DECEF7DECEF7DECEEFD6C6EFD6C6F7DECE
F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7C6B5F7CEB5F7CEB5F7CEB5EFC6AD\
F7CEB5EFC6ADEFC6A5EFC6A5EFBD9CE7B59CDEAD94DEAD8CD6A58CDEAD8CD6A584
D6A584BD947BB5846BB5846BA57B638C634A8C5A426B39215A3121422118422118291008392118\
3918109C7B63946B529C6339946342C69C84CEB5A5DECEC6F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000845239845239845231845239845239735242
8452399C6B4AA57B63B58C73C69C84DEAD9CE7BDA5EFC6ADF7CEB5F7CEB5F7D6BDEFD6C6EFD6C6\
F7DECEEFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEEFD6C6F7DECEF7D6BDEFD6C6
F7DECEEFD6C6F7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7D6BDF7CEB5F7C6B5EFCEAD\
EFC6ADEFC6ADEFC6A5EFC6A5E7B59CE7B59CDEAD9CDEAD8CDEAD8CD6A584D6A58C
CE946BCE946BBD8C63A57B63A57B5A9C73528C5A425A39295A3121422118422921311818422118\
422118A57B63B5846B8C5A42AD7352C6946BE7BD9CF7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000734A317352427352428452397B5A42
735242946B52B58463BD947BD6A584DEAD94EFC6A5EFC6ADEFC6B5EFCEB5F7CEB5F7D6BDF7D6BD\
F7D6BDF7D6BDF7D6BDF7DECEF7D6BDF7DECEEFD6C6F7D6BDF7D6BDEFD6C6F7D6BD
EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7CEB5F7CEB5EFCEADF7CEB5F7C6B5\
EFC6ADEFC6ADEFC6ADE7BDA5E7BDA5E7BD9CE7B594DEAD8CDEAD8CD6A58CD69C7B
D69C7BB58C73BD8C63A57B639C73528C634A8452395A39295A3121422921422118522918522918\
3918109C6B4AB584639C6B4AC6845AD6A584DECECEF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000735242845A427B5A427352427B5A42
845A42946B529C7352C6946BD6AD8CE7BDA5E7BDA5EFC6ADF7CEB5F7CEB5F7D6BDF7D6BDF7D6BD\
EFD6C6EFD6C6F7DECEF7DECEEFD6C6F7D6BDF7D6BDEFD6C6EFD6C6EFD6C6EFD6C6
F7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7CEB5EFCEADEFCEADEFC6AD\
EFC6A5EFC6A5EFC6ADE7BDA5E7BD9CE7B594E7AD94DEAD8CDEAD8CDEA584DEA584
CE946BB58C73B5846BAD73529C6B4A8C5A42734A315A39295A3929522918422118522918391810\
291008946B529C73529C6B4ABD8C63DEAD8CEFEFE7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000946B52946B52946B527B5A42
7B5A42946B52A5846BB58C73D69C7BE7B59CEFC6A5EFC6ADEFC6ADF7CEB5EFCEB5F7CEB5EFD6C6\
EFD6C6EFD6C6EFD6C6F7D6BDF7D6BDEFD6C6F7DECEF7D6BDEFD6C6F7D6BDF7D6BD
F7D6BDF7D6BDF7CEB5F7D6BDF7CEB5F7CEB5F7CEB5F7CEB5F7D6BDF7C6B5F7CEB5EFC6A5EFC6A5\
EFC6A5EFC6A5EFB59CE7BDA5E7BD9CE7B594DEAD94E7B594D6A584D6A584D6A584
B58C73B58C73A57B63A57B5A8C634A845239734229734A315A31215A3121422118391810211008\
5A3929B5846B9C7352B5734ACE946BCEAD94F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000094735A946B52845A428C634A
84634A8C634AAD7352BD947BC69C84DEAD94EFC6A5EFC6ADEFC6ADF7CEB5F7CEB5F7D6BDF7D6BD\
F7CEB5EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFD6C6F7D6BD
F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7CEB5F7D6BDF7CEB5EFC6ADEFC6ADEFC6ADEFC6AD\
EFC6A5EFC6ADEFBD9CE7B59CE7B59CE7B59CE7B594DEAD8CD69C7BD6A58CBD947B
BD947BBD8C63AD7352945A42845239845A427342295A39295A3929422921522918211818211008\
A57B5AA57B63946342B57B5AC68C63E7CEBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000084523984634A735242
8C634A8C634AA57B5ABD8C63D69C7BDEAD9CE7BDA5EFB59CEFC6ADEFC6ADF7CEB5EFCEADEFCEAD\
F7CEB5F7CEB5F7D6BDF7D6BDF7D6BDF7CEB5F7D6BDF7D6BDF7D6BDF7CEB5F7D6BD
EFCEB5F7CEB5EFCEBDF7CEB5F7CEB5F7CEB5EFCEADEFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFC6AD\
EFC6A5EFC6A5EFB59CE7B59CE7B59CE7B59CDEAD94DEAD94D6A58CD69C7BD6A584
B58C73A57B639C6B4A9463428C5A42845A42845A425A31215A3121522918391810291008B5846B\
9C7B639C6B4A946342BD8C63D6B5A5EFE7E7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000845A42A57B5A
7B5A42A57B5AA57B5ABD8C63C69C84DEAD94E7BD9CE7C6ADEFC6ADEFC6A5EFC6ADF7CEB5F7CEB5\
F7D6BDF7CEB5EFCEBDF7D6BDF7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5
F7CEB5F7D6BDF7CEB5EFC6ADF7CEB5EFC6ADF7CEB5EFC6ADEFC6ADEFC6A5EFC6ADEFC6ADEFC6A5\
EFC6A5E7BD9CEFBD9CE7B594E7B594DEAD9CDEAD8CCEAD94BD947BD69C7BCE946B
B5846BA57B639C73529C6B4A845A42734A31735242946B524221183918103921187B5A42845239\
A57B5A9C6B4AAD7352C6946BE7BDA5F7EFF7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000845239845239
84634AA57B63A57B5ABD8C63D69C7BDEAD94DEAD9CE7BDA5EFC6ADEFC6A5EFC6ADF7C6B5EFC6AD\
F7D6BDEFCEADF7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7D6BDF7C6B5
F7C6B5EFC6ADEFC6ADEFC6ADEFB59CEFC6ADEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6ADEFC6A5\
EFC6A5E7B594E7B594E7B59CDEAD94DEAD94DEAD8CD6A584BD947BBD947BB5846B
AD73529C7352946342845A42845A428452398452395A3929734A315A3929734A31734229A57B63\
9C7352B58463BD8C63D6AD8CD6BDADF7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000845231
7B5A428C5A429C7352B58463BD947BC69C84D6B5A5E7B59CE7BDA5EFC6A5EFB59CF7C6B5F7C6B5\
EFCEB5EFCEB5EFC6B5EFC6ADF7C6B5F7CEB5F7CEB5F7D6BDEFC6B5EFCEB5EFC6AD
EFC6ADEFC6A5EFB59CE7B59CE7B59CEFB594EFC6A5EFC6A5EFBD9CEFB59CEFBD9CEFB594E7B59C\
E7B59CDEAD8CE7AD94DEAD94D6A58CD6A58CD69C7BBD947BBD947BB58C73B5846B
AD7352A57B5A9C6B4A735242735242734A31734A315A42397342295A3121A5846B946B529C7352\
9C6B4AD69C7BC6946BE7BD9CF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
9C6B4A8452399C7352A5846BB58C73D6A58CDEAD94DEAD9CE7B59CEFB59CEFB59CEFC6A5EFC6AD\
E7C6ADEFC6ADEFCEB5EFC6ADEFC6ADEFC6ADEFC6B5EFC6ADEFC6A5EFC6ADEFC6AD
EFBD9CE7B59CE7AD8CE7AD94E7AD94E7B594EFB594E7AD8CE7AD8CE7AD8CE7AD8CDEA584DEAD8C\
E7AD94D6A584DEAD8CD6A584D6A584C69C84D69C73BD947BB5846BB58463B58463
A57B5A9C73528C5A42845A427B5A427352428C6B527B5A42734A318C6B52B5846B94735AA57B63\
BD8C63D6A584E7BD9CD6BDADF7EFF7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000946B528C634A9C7352A57B63BD947BD6A58CE7BD9CDEAD9CD6B5A5E7B59CE7B59CEFC6AD\
EFC6ADEFC6ADEFC6ADE7C6ADE7BDA5E7BDA5E7BDA5E7BDA5E7B59CDEAD9CDEAD8C
DEAD94DEAD94D6A584D6A584D69C7BD69C7BD69C7BD69C73DE9C7BD69C7BD69C73D69C73BD947B\
CE946BCE946BCE946BCE946BC6846BB58C73BD947BB58C73B5846BB57B5A9C6B4A
8C634A94735A946B52735A4A946B52946B52734A318C634A9C6B4A9C6B4A9C73529C6B4ABD8C63\
B58463DEAD94E7BD9CF7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000008C634A946B52A57B5AB5846BA57B6BB58C73BD947BDEAD94D6B5A5E7BDA5EFC6A5E7C6AD\
E7BDA5E7BDA5E7BDA5E7BD9CDEAD94DEAD94D6A584DEAD94E7BD9CD6A58CDEA584
D6A584D6A58CBD947BC69C84C6846BCE946BBD8C63D69C7BCE7363CE946BB57B5AB58C73B57B5A\
B57B5ABD8C63B58463B58463B5846BB5846BA57B63B58C73BD947BA5846BA58C73
A57B5AA57B638C634A8C634A94735AA57B63845A426B3921845239B57B5AB58463B57B5ABD8C63\
CEAD94D6B5A5D6BDADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000007B5A429C7352A57B5A8C634AB58C73C69C84D6BDADE7C6B5E7C6B5E7C6B5E7BDA5\
E7BDA5D6B5A5DEAD9CD6A584CEAD94D6A58CD6A58CD6A584D6A58CD6A584D6A584
C6946BC6946BB58C73B58C73B5846BB58C73B5846BAD7352B5846BB584639C73529C6B4AB5846B\
9C7352B584639C7352AD7352A57B63A57B5AA57B638C634A946B5294735AAD7352
94735A9C735294735A9C7352845239845A428C6B529C6B4A9C7352A57B5AA57B5AC6946BD6B5A5\
D6B5A5C69C84F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000009C7363A58C73C6A594CEA594BD9C8CDEAD9CCEA594DEAD9CD6BDADD6BDAD\
DEAD9CDEAD94D6A58CD6A584D6A58CBD947BC69C84D6A584C69C84C6946BC69C84
BD947BC6846BB58463B5846B9C7352BD947BA57B63BD947BB58463A57B63BD8C63A57B5A9C6B4A\
BD947BA57B5AB5846BA57B63A57B5AA5846BA58C7384634A946B52A57B5A9C7B63
8C6B5294735AA57B639463429C6B4A9463429C6B4A9463429C7352B58463D6AD84CEB5A5CEAD94\
D6AD8CE7CEC6F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000946B52A5846BB58C73B58C73BD9C8CDEAD9CD6B5A5DEAD94CEAD94\
D6A58CD6AD8CC69C84C69C84C69C84B58C73BD947BB58C73BD947BB58C73BD947B
B5846BBD947BA57B5A9C7352A57B6B946342A5846BA57B5AB58C739C7352A57B63A57B5AA57B63\
C6946B8C634A9C73529C7352B5846BA57B5A946B52946B52845A427B5A42734A31
7352428C634A8452398452397B5A427B5A42946342B5734AC6946BD6AD84E7C6ADBD9C8CD6AD8C\
B58463F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000BD9C94C69C84C6A594D6B5A5D6B5A5D6B5A5D6B5A5C69C84\
C69C84C69C84C69C84BD947BC69C84BD947BBD947BB5846BB5846BBD947BB58463
A57B5AA57B63946342A5846BA5846B8C634A734A31A57B63845A42B58463A57B5AA57B63A57B63\
8C5A429C6B4AA57B5A734229734A319C63398C5A42845A428C5A429C6339946342
9C6B4A9463429463428452399C63399C6B4ACEAD94BD947BD6AD8CD6BDAD8C634ABD9C8CA5846B\
DECECEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000A5846BC6A59CCEB5A5DEAD9CD6B5A5C6A594\
BD947BBD947BB58C73BD947BBD947BB58C73A5846BA58C73B58C73A57B63B58463
B584638C634AC6946BA57B5A8C634ABD947B8C634A845A42A57B638C634A8C634A946B52845A42\
8C5A428452317342298452398452399C63398452397B5A429463428C5A42845239
844A318C5A429C7352B58463B58463C69C84BD947BE7BD9CD6B5A5A5846BA57B5ABD9C8CA5846B\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000B5947BC6AD9CCEB5A5D6A58CC6A594\
A57B63B5846BA5846BBD947BBD947BB5846B9C7363B5846BB58463A57B63B58C73
A57B63B58463845A429C735294735A8C634AA57B5A845A428C634A946342845A4284634A845A42\
735242845239845239845239734A317342298452397B5A42845239845231845231
8C634AA57B5AA57B5AA57B5AA57B5AC69C84CEB5A59C7B639C7B63A5846BC6A594BD947BEFE7E7\
F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000B5947BD6B5A5D6B5A5C6AD9C\
A57B5AB58C73A57B63A57B63B58463A57B5A94735AA5846BA5846B94735AA57B63
94735AA57B63845A42A57B5A9C6B4A946B52735242734A31A57B5A7352427B5A42845A427B5A42\
845231734A31734A316B39215A39297342297342297342298452319C6B4A845A42
8C634AA5846BC69C84BD947BE7BDA5CEB5A5BD9C8CA58C73946B52C69C84946B52EFE7E7FFFFFF\
FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000CEB5A5D6BDADC6AD9C\
A57B5A946B52B5947BA57B63B58C73B5947BB58463946B52A5846BA57B5A8C634A
A57B63A57B638C634A9C7352A57B5A94735A8C6B525A3121734A317B5A42A57B5A845239845239\
6B39218452397342296B39215A31215A39295A31215A3121734A318C5A42A5846B
BD947BB5846BBD947BCEB5A5B5947B84634A947B6BB58463A5846B9C6B4AC6A59CF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000D6B5A5\
A5846B946B52A57B5AB58C7394735A94735AA57B638C6B528C634A9C736394735A
8C6B52946B52A57B6394735A8C634AA57B5A9C73528C6B528C634A734A31734A3184634A845239\
8452398C5A428452319C6B4A845231845231945A319C6B4AAD7352A57B63BD8C63
C69C84DEC6B5B5947BBD9C8C9C7B6B734A3194735AA5846BB5947BB5947BF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
D6B5A58C634A8C6B529C7B63B5846394735A946B52845A427B5A427B5A428C634A
8C634A946B5294735A8C634A8C634AA57B5AA5846B9C735294735A7B5A42A57B5A845239845231\
94735A946B528C634A9463429C6B4AA57B5AB58463C69C84B58C73BD947BD6B5A5
BD9C8CB59C8CA58C73A58C737B5A429C7363A58C73A5846BA57B6BFFFFFFF7F7F7FFFFFFFFFFFF\
F7F7F7F7EFF7FFFFFFF7EFF7FFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000008C6B528C6B52A5846BA5846B946B52A5846B845239845A42845A42
9C6B4A946B529C7352845239A57B6B9C7352B58C73A57B63B5846BB5947B946B528C5A428C5A42\
9C73529C7352B58463B58463BD8C63BD8C63D6A584D6A584C6A594A57B639C7B6B
9C7B6B8C5A42734229845239A57B63A5846B9C7B63BD947BFFFFFFF7F7F7F7F7F7F7F7F7FFFFFF\
FFFFFFF7F7F7F7F7F7000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000A5846B8C634AA5847394735AA57B63946B52845239
7B5242734A318C634A7B5A429C73639C7352BD947BB58C73DEC6B5E7C6B5D6B5A5C69C84DEAD9C\
D6A58CD6A58CD6A58CE7C6ADE7C6ADDEAD94CEB5A5A58C738C6B529C7B63946B52
845A427B5A428C634AB58463B5947BA57B63A57B6BFFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7\
F7F7F7000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000A58473A58C7BA57B6BBD947BC6A594
9C7B6B7B52428C6B527B524294735AB5947BC6A594BD9C8CA58C7BD6BDADD6BDB5D6BDADDEC6B5\
E7D6C6E7CEC6D6BDADC69C84B5947BB5947BA5847394736394735A946B52735242
84523994735A9C7B63BD947BA57B63B5947BF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000D6BDB5C6A59C
E7CEC6EFD6C6F7EFE7EFE7DEEFD6C6E7CEC6E7CEBDD6BDADDECEBDDEC6B5DEC6B5DEC6B5E7CEBD\
CEB5A5A58C73C6A594A58C739C7B639C7B6B9C7B6B8C634A8C6B52735A4AA57B63
A58C73A5846BA5846BA57B63FFFFFFF7F7F7F7F7F7FFFFFFF7EFF7000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000DEC6B5E7C6B5E7CEBDE7C6B5EFD6C6EFDECEE7D6CEDECEBDE7CEC6CEB5A5BD9C94D6BDAD\
BD9C8CB59C8CBD9C948C735AA57B5A8C634A8C6B529C7B6BA58473BD9C8CC69C84
B58C73A5846BC6A59CF7F7F7F7F7F7F7EFF7000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000E7D6CEEFDECEE7CEC6DECEBDD6BDB5CEC6BDB59C8CA58C84\
BD9C949C7B639C7B6B94735AA58C73846352A58C7BBD9C8CC69C84B59C8CA58C7B
C69C84E7DEDE000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000B59C8C000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFEFE7E7BDADADC6A594000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFE7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7\
F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFB5947BAD7352EFE7DE
FFFFFFFFFFFFFFFFFF9C73529C6B4A844A29845239000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000F7EFE7F7EFF7F7EFF7
F7F7F7F7EFF7F7EFE7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFBD9C94B5846BF7EFF7D6C6C6BD9C94A58C7B
7342296B3921845231734A317B5A427352428C6B528452398C6B52735242000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000F7EFF7F7EFF7F7F7F7F7EFE7F7EFF7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7\
F7EFF7BDADADA57B6B8C4A299C6B4AA57B5ABD9C8CA5846BA58C73B59C8C946B52
8C5A427B4A29734229734A31734A31845A428C634A8452398452398C5A42A57B5A7B5A42000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7F7EFE7
F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7EFE7EFEFF7F7EFF7DEC6C69C7352AD7352\
9C7352945A31B58C73B5947BA57B639C73529C735284523194735A8C5A42734A31
5A31215A3121734A3184634A9C7B6BA58C739C73528452398C634A946B528C5A427B5A42845239\
845239000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F7F7F7F7EFE7F7F7F7F7F7F7F7EFF7F7EFE7EFEFE7F7EFF7F7EFF7
F7EFE7EFE7E7F7EFF7EFE7E7E7DEDEE7D6CEE7CEC6C6946BB5846BB5846B9C7352945A319C6339\
9C73528C634A9C6B4A8C5A42845239734A318C634A7B4A297B5242734A31734229
6B39216B3921734A318452398C6B52946B528C634A84634A8C6B52946B528C634A845239734A31\
845239734A31735242000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7EFF7F7F7F7F7F7F7F7EFE7EFEFF7F7EFF7F7EFF7F7EFE7EFE7E7F7EFF7
DECEC6DEC6B5E7BD9CD6AD8CC6946BBD8C63AD7352946342946342945A318C5A42845231734A31\
845239845231734A31946B528C5A428452395A31215A3121734A318C634A734A31
6B3921734A315A3121734A317B5A428452398C6B528C634A946B52845A4284634A845239845231\
845231735242845A42946B5294735A000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000EFEFE7\
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7EFE7E7EFE7DEDEC6B5DECEC6
D6C6B5C6A594BD947BB58463AD73529463428C5A42946342844A297B4A297342295A31216B3921\
734A318C5A429C6B4A845A42845239734A31845239845239845239845239734A31
946342845239845239734A31845239845A428C634A8452398C634A8C634A8C5A42845231735242\
8452397352427B5A42946B52946B52845239000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7EFF7EFEFE7EFE7E7E7D6D6E7D6CEE7D6CEDECEC6E7BD9CC69C84
BD947BBD947BAD7352946342946342945A42945A316B39216B39217B4A298452317B5A428C5A42\
734229845231734A318C5A42945A42945A42945A42845239845239734A316B3921
5A3121734A317B4A29734A31734A317B5A42845A42845A42845A42845239845A42845A42734A31\
845239845239735242946B52845A4284634A845A42845239000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000EFEFF7F7F7F7F7EFF7EFEFF7\
EFE7E7EFE7E7EFE7E7E7D6CEE7DED6DECEBDD6C6B5D6BDADD6AD8CC69C84B57B5A
B5734A9C6B4A9463428452319C63396B3921845231734229845239845239845231734A31845239\
8452398C4A318C4A31734A315221105A31216B3118845239945A428C4A319C6B4A
9C4A319C6339945A318452398C5A42845A42845239845239845A427B5A429C63398452397B5A42\
7352427B5A427B5A427B5A428C634A735242A57B5A845239845231000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000EFEFF7F7EFE7EFEFF7EFEFE7EFEFE7\
EFE7E7E7D6CEE7D6C6E7CEBDE7D6C6CEAD94D69C73BD947BB58463AD73529C6339
9C6B4A9C63398C4A318C4A317B4A29734A317B4A29734229844A31734A31844A31734A317B4A29\
844A316B39215A3121522918845231945A31522918945A42CE7363C68463C68463
B56B52B56342945A42945A318C5A42845A42845231845A42845239946B527342298C634A8C634A\
845239735242845A427B5A4284634A8C634A7B5A4284634A7B5A429C6B4A000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000EFEFF7EFEFF7F7EFF7F7EFF7EFE7E7EFE7E7E7DED6\
E7CEBDE7CEBDDECEBDDECEC6D6AD8CC6946BC6946BB57B5A9C6B4A9463429C6B4A
844A299463428C4A316B39217B4A29844A317B4A297B4A29844A317B4A297B4A29844A31734229\
5A31215A3929734A319C6339844A31EFB594F7C6B5F7C6B5EFB59CE7A594CE946B
DE8473B57B5A945A428C634A8C634A8C5A428452318452398C634A8C634A8C634A8C634A9C6B4A\
9C6B4A946B52946B52946B528C634A8C634AA57B5AA57B638C5A42845239946B52
8C634A000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000EFEFE7F7EFF7EFEFF7F7EFF7F7EFF7E7D6C6DECEBDDECEBD\
DECEBDCEB5A5D6AD8CC69C84C6946BB58463AD73529463429C6B4A845231844A29
8C5A428442297B4A297B4A296B3921734229844A29844A317B4A29844A315229185229186B3921\
7342297342297B4A29E7AD8CF7C6B5EFB59CE7AD8CDEA584E78C7BD69C7BC69C84
CE946BBD8C63A57B639C7352AD7352A57B5A9C6B4AA57B5A9C73529C7352A57B63A57B5AB58463\
A57B63B584639C7352A5846BAD7352A57B5AA57B5AA57B5A9C73529C73528C634A
946B527B5A42000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000F7EFE7F7EFF7EFEFE7EFE7DEE7CEBDE7CEBDE7C6ADD6BDADCEAD94\
C69C84BD947BC6946BB57B5AA57B5AA57B5A9463428C4A318C5A42845231844A31
6B39217B4A296B39217342297B42217B4A298C4A317B4A293918105229184221186B3921522918\
845239E7C6ADE7C6ADEFC6ADCE946BE78C7BE7A594E78C7BD69C7BD69C7BBD947B
B58C73C6846BB5846BA57B5AAD73529C73529C7352B57B5ABD8C63B5846BBD8C63B58C73B58C73\
B58C73BD947BC6946BB58C73BD947BBD8C63BD8C63BD8C63B58463A5846B9C7352
A57B5A9C73529C7363000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000F7EFE7F7EFE7E7DED6E7C6B5DEC6B5D6B5A5CEAD94C69C84BD947BBD947B\
C68C63B57B5AB5734AAD73529C6B4A8452398C4A318C5A428C4A29844A316B3921
7B4A297B4A296B39217B4A297B4A29844A317B42214221185229184221183918105A3929A58473\
EFC6B5F7D6BDF7C6B5E7AD94DEA584D6A58CDEAD94DEAD94DEAD8CDEAD8CD6A58C
D6A584C69C84C69C84D6A584D69C7BD69C7BC6846BC6946BBD947BC6946BB58C73C69C84D69C7B\
C69C84D6A584D6AD8CD69C7BC69C84D69C7BC69C84D69C7BBD947BB58C73A57B63
B5846BA57B5AA58C73946B52000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000F7EFE7E7D6C6E7BDA5D6B5A5D6AD8CD6AD84D69C73C6946BC6946BBD8C63BD8C63\
AD7352AD7352B5734A9C63399C6339945A31945A318C4A29844A296B31187B4A29
6B3118734A317B4A298442296B3921632910522918632910522110522918EFB59CEFC6ADF7C6B5\
F7CEB5EFC6B5E7C6ADEFC6B5EFCEB5EFCEB5EFCEBDE7C6B5EFC6B5EFC6B5E7C6B5
EFCEB5EFC6ADE7C6B5E7C6B5EFC6ADE7C6ADE7BD9CE7B59CDEAD8CD6A58CD6A584D6A58CD6AD8C\
DEAD9CDEAD94E7BDA5E7B59CDEAD94DEAD9CDEAD94DEAD94C69C84D6A58CBD947B
A57B6B8C634AC6A594A5846BBD9C94000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000CEAD94D6AD8CD6AD84D6AD84C69C84C6946BC68C63BD8C63B57B5AB57B5AB5734A\
B5734A946342AD6342AD6342945A318C4A31844A297B4A297342297B4A297B4A29
7B4A297B4A297B4A296B31185A31216329105A39294221185A3929CEAD94EFCEBDEFC6B5EFCEBD\
EFCEBDF7D6BDEFD6C6F7D6BDF7D6BDEFCEBDF7D6BDEFCEB5EFCEB5E7C6B5EFCEB5
E7BDA5DEC6B5EFCEBDEFCEB5EFC6B5EFCEB5EFC6B5E7BDA5E7BDA5E7BDA5E7BD9CE7BD9CE7BD9C\
E7BDA5EFC6A5E7BDA5EFC6A5EFC6A5E7BDA5E7BD9CDEAD9CD6B5A5DEAD94D6A58C
B58C73B58C73CEA594B58C73C69C84000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000D69C73D69C73D69C73C6946BBD8C63B57B5AB57B5AB57B5AAD73529C6B4AAD6B429C6B4A\
946342945A318C4A318452397B4A29945A316B31187B4A297B4A297B4A297B4A29
844A296B39216B31185A3121845239A57B63E7C6B5EFC6ADEFC6ADEFCEB5F7C6B5EFD6C6EFD6C6\
EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFCEBDEFC6ADE7B59CE7C6ADEFCEB5
F7CEB5E7BD9CBD947BEFCEB5EFCEB5EFCEB5EFCEB5EFCEADEFCEB5EFC6ADEFC6ADEFC6ADEFC6AD\
EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFB59CE7C6ADE7BDA5E7B59CDEAD9CE7BD9C
BD947BC69C84BD9C8CB58C73C6A594A5846B000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
CE946BD69C73C68C63C6845ABD8C63B57B5AB57B5AB5734AAD7352AD6B42945A31946342845239\
945A31945A31945A31844A298452396329107B42217B4A298442217B42217B4A29
6B3921B58463E7C6B5EFC6B5EFC6B5E7C6ADEFC6B5F7C6B5F7CEB5EFCEB5F7D6BDF7D6BDEFD6C6\
EFD6C6EFD6C6F7DECEEFD6C6EFD6C6EFD6C6E7C6ADDEAD9CCEA594E7BDA5F7D6BD
F7D6BDEFC6B5C69C84EFC6ADEFCEB5EFCEBDEFCEB5EFCEBDEFCEBDF7CEB5EFCEB5EFCEB5F7CEB5\
F7CEB5EFC6B5F7CEB5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADE7BDA5E7B59CDEAD9C
DEAD94D6BDADDEAD9CBD9C8CD6B5A5C6A59CB5947B000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000BD8C63
C6845ABD8C63C6845AB57B5AB5734AAD6B429C6B4AAD6B42945A31AD6B429C63399C6339945A31\
945A31945A318452316B39217342296B39216B3118844229845231D6B5A5EFCEB5
EFCEB5E7C6B5EFC6B5E7C6ADEFC6ADF7C6B5F7CEB5EFCEBDF7D6BDF7D6BDF7DECEEFD6C6EFD6C6\
EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFC6B5E7AD9CBD947BC6846BDEAD94EFCEBD
F7D6BDF7D6BDD6A584D6A584F7D6BDF7D6BDEFCEBDF7CEB5F7D6BDF7CEB5F7CEB5F7D6BDF7C6B5\
F7CEB5EFCEB5F7CEB5F7CEB5F7CEB5EFC6ADEFC6A5EFC6A5EFC6A5EFB59CD6B5A5
D6B5A5E7C6B5CEA594DEAD9CD6B5A5CEB5A5C6AD9CB5947B000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000B5734AB57B5A
B5734AB5734A9C6339AD6B429C63399C6B4AAD63429C63399C63399C63399C6339945A318C4A29\
8452315A31216B31186B39216B39216B3921945A31EFCEBDEFCEB5EFCEB5EFCEB5
EFC6B5EFC6B5EFC6B5EFC6ADEFCEB5F7C6B5F7CEB5F7C6B5EFD6C6EFD6C6EFD6C6EFD6C6F7DECE\
EFD6C6EFD6C6EFD6C6EFD6C6EFCEBDE7AD9CB5846B94735A734A31BD947BEFC6AD
EFD6C6EFD6C6D69C7BBD9C8CF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7D6BDF7D6BDF7D6BD\
F7D6BDF7CEB5F7D6BDEFCEB5F7CEB5F7CEB5EFC6ADEFC6ADEFB59CEFB59CE7B59C
E7BDA5E7C6B5DEAD9CD6B5A5D6B5A5DEAD9CCEB5A5D6B5A5CEB5A5000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000AD6B42B56B42
AD6B42AD6B429C6B4AB5734A9C6B4A945A319C6339B5734A945A31945A31945A31945A31945A31\
6B39216B39216B39217B39187B4A29A5846BEFCEBDEFCEBDEFC6ADEFCEB5EFC6B5
EFC6B5EFC6B5F7C6B5EFC6ADF7CEB5F7C6B5F7D6BDF7D6BDEFD6C6EFD6C6EFD6C6F7DECEF7DECE\
EFD6C6F7DECEF7D6BDEFCEBDE7C6B5B58463C6846B5A3929846352B56B52EFC6B5
F7D6BDEFD6C6DE8473DE8473EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFD6C6EFD6C6\
EFD6C6F7D6BDF7D6BDF7CEB5F7D6BDEFCEADF7CEB5F7C6B5F7C6B5EFC6A5E7B59C
EFC6A5E7C6B5D6BDADDEAD94D6B5A5D6B5A5D6A58CD6B5A5D6BDAD000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000B5734A9C6339AD6B42
AD6B39AD6B42945A31945229945A31945A31945A319C4A319C63399C6339844A296B3921522918\
6B31186B3118844A297B4A29EFCEBDEFCEB5EFCEBDEFC6B5EFCEB5EFCEB5EFCEB5
EFCEB5F7CEB5F7CEB5F7CEB5F7D6BDEFD6C6F7D6BDF7D6BDEFD6C6EFD6C6F7DECEF7DECEEFD6C6\
EFD6C6EFD6C6EFD6C6E7CEBDDEAD9CBD8C63D6BDB5B5948C8463528C634AE7BDA5
F7D6BDF7C6B5B56B52DEAD9CEFD6C6F7DECEEFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BD\
EFD6C6F7D6BDF7D6BDEFD6C6F7D6BDEFCEADF7CEB5EFC6ADF7C6B5EFC6ADEFC6AD
E7C6ADE7BDA5D6BDADCEAD94C69C84C6A594C6A594C6AD9CC6AD9CD6B5A5000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000B56B39AD6B399C63398C4A29
945A318C4A299C4A319C6339AD6B399C6339945A31945A318442216329106329106B31186B3921\
844A296B3118E7C6B5EFC6B5EFC6B5EFCEB5EFCEB5EFCEB5EFCEADF7C6B5F7CEB5
F7CEB5F7CEB5F7CEB5F7C6B5F7CEB5F7D6BDF7D6BDEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7D6BD\
EFD6C6EFD6C6EFCEBDEFC6B5BD947BDEAD9CE7D6CEC6B5B55A42397B5242E7B59C
EFD6C6B5846BAD7352EFD6C6EFD6C6F7DECEF7DECEEFD6C6F7DECEF7D6BDF7DECEF7DECEF7D6BD\
F7DECEF7D6BDEFD6C6EFD6C6F7CEB5F7CEB5F7D6BDF7D6BDEFCEB5E7C6ADEFC6AD
E7BDA5E7BDA5DEAD9CD6A58CC69C84BD947BA57B63A57B5AA57B5AA5846BD6B5A5000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000009452298C4A298C4221844221
9452299C63399C63399C63398C4A298C4A296B39215221106329106B39217B4A297B4221734229\
845A42EFC6B5EFCEB5EFC6B5EFC6ADEFCEB5EFC6ADF7CEB5EFC6ADF7CEB5F7C6B5
F7CEB5F7CEB5F7CEB5F7D6BDF7C6B5F7D6BDEFD6C6F7D6BDEFD6C6F7DECEEFD6C6EFD6C6EFD6C6\
F7D6BDF7D6BDEFCEBDEFC6B5B58C73BDADAD7B7373947B6B4229217B5242E7AD9C
E7A594A57B63D69C7BF7DECEF7DECEEFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6BD\
EFD6C6F7D6BDEFD6C6EFD6C6EFD6C6F7CEB5F7CEB5EFCEADEFCEB5EFC6ADEFC6AD
E7BDA5D6B5A5DEAD94D6AD8CC69C84BD947BB5846BB58C73946B52946B528C634A000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000007B39188C4A298C4A298C4A29945229
AD6B399452299C4A31945A318442217B39186B39217342297B42217B4A297B4A296B39218C5A42\
EFC6B5EFC6B5EFCEB5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFCEADEFC6ADF7C6B5
F7CEB5F7CEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFD6C6F7DECEEFD6C6F7D6BDF7D6BD\
EFD6C6EFCEBDEFB59CEFC6ADD6A58C736B63736B63B5B5BD5A39297B5242E7B59C
C6846B94735AF7CEB5F7DECEF7DECEF7D6BDF7D6BDF7DECEF7D6BDF7DECEEFD6C6F7D6BDF7D6BD\
F7DECEF7D6BDF7DECEEFD6C6EFD6C6F7D6BDEFCEBDF7CEB5EFC6B5EFCEB5EFC6AD
E7BDA5DEAD9CD6A58CC69C84C69C84B58C73A5846BA57B63B5947BA57B5A8C6B528C6B52000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000006329106B31187B3918945229945A31
9452298442217B42215A31215229186B31186B31186B39217342296B39216B3921A5846BEFC6AD\
EFC6ADF7CEB5F7CEB5EFC6ADEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5F7CEB5F7CEB5
F7C6B5F7D6BDF7CEB5F7CEB5F7C6B5EFD6C6EFD6C6F7D6BDEFD6C6F7DECEEFD6C6F7DECEF7D6BD\
EFCEBDEFC6B5E7C6ADDEAD9CCEA59473736B635A52211818845239845239E7BDA5
A57B63B56B52F7D6BDF7DECEF7DECEF7DECEF7DECEF7DECEF7D6BDEFD6C6F7DECEF7DECEEFD6C6\
F7DECEF7DECEF7DECEF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5EFC6ADEFC6ADE7C6AD
E7BD9CD6A584D6A584C69C84BD947BBD947BBD947BA57B63A57B63B58C739C7B638C6B52000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000006329105221106B31188442219452298C4A29
6B31186329106B39216329105229186B39216B39216B39216B39216B3921E7C6B5EFCEB5EFC6B5\
EFCEADEFCEADEFCEADEFC6ADEFCEADEFC6A5E78C7BEFB59CEFCEADEFC6ADEFCEB5
F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7D6BDF7D6BDEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6\
EFD6C6EFC6B5EFC6ADDEAD94BD947BA58473847B7384736B8C6B5294735AE7B59C
9C7352D6A584F7D6BDF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6BDF7DECEF7D6BDF7DECE\
F7DECEF7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7C6B5EFC6ADE7BDA5
DEAD94CEAD94D6A58CC69C84C69C84BD947BBD947BB58463B58C7394735AB58463A5846BA5846B\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000004A18086B31187B42218C42217B39186B3921
6B31186B39217B42216B31186B31186B39216B39216B31186B3118B58C73F7CEB5F7CEB5F7CEB5\
F7CEB5EFC6ADEFC6ADEFC6ADEFC6ADEFC6A5DE8473EFC6A5F7CEB5F7CEB5F7CEB5
F7CEB5EFCEB5EFCEADF7CEB5EFCEADF7CEB5F7C6B5F7D6BDF7D6BDF7D6BDEFD6C6EFD6C6F7DECE\
EFD6C6EFCEBDEFC6ADE7BDA5DEAD9CC69C84A57B6B5A4A42846352C6846BD69C7B
B56B52EFC6A5F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7D6BDEFD6C6F7D6BDF7CEB5F7D6BDF7CEB5F7CEB5EFC6ADE7BDA5
DEAD94D6A58CBD947BB58C73BD947BB58C73B5846BA57B5AB5947B94735A94735AA5846B8C634A\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000DEAD9CDEAD94DEAD947B4A296329104A18086B3118
6329106329106B31186B39216B31187B39186B3921845231B58463EFC6B5EFCEADEFC6ADF7CEB5\
F7CEB5EFC6ADEFC6ADEFC6A5E78C7BDE7B6BAD7352E78C7BF7CEB5F7CEB5F7CEB5
F7CEB5F7CEB5F7CEB5F7C6B5F7CEB5F7C6B5EFC6ADF7CEB5F7D6BDF7D6BDEFD6C6EFD6C6F7DECE\
EFD6C6EFCEBDEFC6B5E7C6ADDEAD9CDE8473C69C8494735AA57B63D6A584DEA584
E7B59CF7CEB5F7DECEF7DECEF7DECEF7D6BDF7DECEF7D6BDF7D6BDF7DECEF7D6BDF7D6BDF7DECE\
F7DECEEFD6C6F7D6BDF7DECEF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5EFC6B5E7BDA5
D6A584D6A58CC69C84BD947BBD947BA5846B9C736394735AB58463A57B63946B52946B52A58473\
A58473000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000DEAD94DEAD94DEAD94DEAD9CDEAD94E7BD9CE7BDA5
E7BDA5E7BD9CE7BDA5E7BD9CE7BD9CDEAD94DEAD94DEAD94EFC6ADF7CEB5F7CEB5F7CEB5F7CEB5\
F7CEB5F7C6B5EFC6A5EFB59CDE8473DE84739C4A31CE7363F7D6BDF7D6BDF7CEB5
F7CEB5F7CEB5F7CEB5EFD6C6F7D6BDF7D6BDF7D6BDF7CEB5F7C6B5F7D6BDEFD6C6EFD6C6EFD6C6\
EFD6C6F7D6BDEFCEBDEFC6B5EFCEBDDE8473BD947BB5846BBD947BE7B59CE7AD94
EFC6A5F7CEB5F7DECEF7DECEF7DECEF7DECEF7DECEF7D6BDF7DECEEFD6C6F7DECEEFD6C6F7DECE\
EFD6C6F7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7D6BDEFC6ADE7BDA5
DEAD94D6A584D6A584B58C73B5846BA58C73B5846BA5846B946B528C6B52845A42A5846B94735A\
A58C7B000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000E7B594E7BD9CE7B594E7BD94E7BD9CE7B594E7B59C
E7B59CE7BD9CDEAD9CDEAD94DEAD94DEAD94DEAD8CE7C6ADEFC6B5F7D6BDF7D6BDF7CEB5F7CEB5\
F7C6B5EFC6ADE7BDA5DE7363DE8473DE8473AD4A31CE6B5AEFD6C6F7CEB5F7CEB5
EFCEB5F7CEB5F7CEB5DE9C7BEFCEB5EFC6B5F7D6BDF7C6B5EFCEBDF7CEB5F7D6BDF7D6BDEFD6C6\
F7D6BDF7D6BDF7D6BDEFCEBDEFCEBDEFC6B5E7AD9CBD947BE7AD94EFC6ADEFC6A5
F7D6BDF7D6BDF7DECEF7DECEF7DED6F7DECEF7DECEF7DECEF7DECEF7D6BDF7D6BDF7D6BDEFD6C6\
F7DECEF7D6BDEFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7CEB5EFC6B5EFC6A5E7B59C
E7BD9CD6A58CC69C84BD947BB5846BB58C73B58463A5846BA5846B8C634A7B5A42845239A57B63\
A57B6B000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000E7BD94E7B594E7B59CE7BD9CE7BD9CE7BDA5E7BDA5EFC6A5
E7BD9CE7BD9CE7BD9CE7B59CE7B594DEAD8CDEAD94EFC6ADF7D6BDF7CEB5F7D6BDF7D6BDF7D6BD\
EFCEADEFBD9CE7AD94CE6B5ADE8473DE7B6BBD5242C6634AEFC6B5F7D6BDF7CEB5
F7CEB5EFC6ADEFC6ADDE7B6BEFC6B5EFD6C6EFD6C6EFD6C6F7C6B5EFC6B5F7CEB5EFCEBDF7D6BD\
F7D6BDF7C6B5EFCEB5E7C6ADEFC6B5EFC6B5DEAD94E7B59CEFBD9CEFC6ADF7D6BD
F7D6BDF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEEFD6C6F7DECEEFD6C6F7DECEEFD6C6\
F7D6BDEFD6C6EFD6C6F7D6BDEFD6C6F7CEB5F7D6BDF7D6BDEFCEB5EFC6ADDEAD9C
D6A58CD6A584C6946BB58C73BD947BA57B63A57B6394735AA57B5A9C73637B5A42845A42946B52\
BD947BD6BDB5000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000EFBD9CE7BDA5E7BD9CE7BD9CEFC6A5EFC6A5E7BD9CE7BDA5
DEAD94E7BD9CE7B594DEAD94E7B59CDEAD8CE7BDA5EFC6ADF7C6B5F7D6BDEFD6C6F7D6BDF7C6B5\
EFC6ADE7B59CE7AD8CDE7B6BEFC6B5DE7363AD7352CE6B5AEFC6ADF7CEB5F7CEB5
F7CEB5EFC6ADEFB59CEFC6ADF7C6B5EFD6C6F7DED6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BD\
EFC6B5F7CEB5F7CEB5EFC6B5EFC6B5E7C6ADEFC6A5EFCEADF7CEB5F7CEB5F7CEB5
F7D6BDF7D6BDF7DECEF7DED6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6BDF7DECEF7D6BDF7DECE\
EFD6C6F7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5F7C6B5EFC6ADEFC6ADDEAD8C
DEA584D6A584C69C84BD947BB58463B58463B58C73A57B638C634A94735A8C634A845A42845239\
C6A594C6A59C000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000EFC6A5E7BD9CE7BD9CE7BDA5E7BD9CE7BD9CEFBD9CE7B594
E7BD9CE7BD9CE7BD9CE7B594E7B594E7AD8CE7AD94EFC6ADF7C6B5F7C6B5F7D6BDF7D6BDF7D6BD\
EFC6ADE7AD94DEA584DE7B6BEFB59CDE7363BD5242C6634AF7D6BDF7D6BDEFCEB5
EFC6A5E7B59CE7AD9CEFC6ADF7C6B5EFD6C6EFD6C6EFD6C6F7C6B5F7D6BDF7D6BDF7D6BDEFD6C6\
EFD6C6EFD6C6F7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7D6BDEFD6C6
F7DECEF7DECEEFD6C6EFD6C6EFD6C6F7D6BDF7DECEF7DECEF7DECEEFD6C6F7D6BDEFD6C6F7D6BD\
F7DECEEFD6C6F7D6BDF7D6BDF7D6BDEFCEB5F7CEB5F7C6B5EFC6ADEFBD9CDEAD94
D6A584C6946BBD947BB5846BA57B5AB58463A57B6394735AA57B638C6B528C634A9C6B4A7B5242\
9C7B6BE7CEC6000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000EFC6A5EFBD9CEFBD9CEFBD9CE7BD9CE7BD9CE7BD9CE7BD9CEFBD9C
EFBD9CE7B594E7B594E7B594E7AD8CDEAD8CE7AD94EFC6A5EFC6ADF7D6BDEFD6C6F7D6BDF7C6B5\
EFC6ADE7AD94DE9C7BDE8473E78C7BDE7363BD5242CE6B5AEFC6ADEFC6A5EFC6AD
EFC6A5DEAD8CE7B594EFB59CEFC6ADF7C6B5F7C6B5F7CEB5EFC6B5EFC6ADF7C6B5F7D6BDF7C6B5\
EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFD6C6
EFD6C6EFD6C6EFD6C6EFD6C6F7DECEEFD6C6F7DECEF7DECEF7DECEEFD6C6EFD6C6EFD6C6F7D6BD\
EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7CEB5F7D6BDEFC6ADEFC6A5E7B59CDEAD94
D6A58CC6946BC6846BBD947BA57B638C634AB58463A57B63A57B63946B52946B52946B52734A31\
7B5242EFD6C6DEC6B5000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000EFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFC6A5EFBD9CEFBD9CE7BD9C
EFBD9CEFBD9CE7AD8CE7AD8CE7AD8CDEA584E7A594EFC6A5EFC6ADF7C6B5F7C6B5EFD6C6F7C6B5\
EFC6ADDEAD8CE78C7BDE8473E78C7BDE8473C65A4ADE7B6BEFC6A5EFC6ADEFC6A5
E7B59CDEA584DE9C7BE7A594E7B594EFC6A5EFC6ADEFC6ADEFB59CEFB59CEFC6ADF7C6B5F7C6B5\
F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFCEB5F7CEB5F7CEB5F7CEB5F7D6BD
F7D6BDF7D6BDEFD6C6F7DECEF7DECEF7DECEF7DECEEFD6C6EFD6C6F7D6BDEFD6C6F7D6BDF7D6BD\
F7D6BDF7D6BDEFD6C6F7CEB5F7D6BDEFCEBDF7CEB5EFC6ADEFB59CE7AD8CD6A584
BD947BB58C73B58463A57B5A946342C6946B845A42845A428C634AA57B6394735A9C73528C634A\
8C6B52F7EFE7E7C6B5000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFB594EFB594E7BD9C
E7AD8CE7BD94E7BD94E7AD8CDEA584DEAD8CE7AD94EFB59CF7C6B5F7CEB5F7C6B5F7D6BDF7D6BD\
EFC6ADDEAD8CE78C7BDE8473E7A594CE6B5AB55239C6634AF7CEB5EFC6ADEFC6A5
EFC6A5E7AD94DEA584B56342DEAD8CE7B594E7BDA5E7AD94E7B59CDEAD94E7B59CE7B59CE7B59C\
E7BDA5EFC6ADEFC6ADEFB59CEFC6ADEFC6A5EFC6ADEFC6ADEFC6ADEFC6ADF7CEB5
EFD6C6F7D6BDEFD6C6F7DECEF7DECEEFD6C6F7DECEEFD6C6EFD6C6EFD6C6F7D6BDF7D6BDF7D6BD\
EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5EFC6ADEFC6ADE7B59CE7AD94D6A584
C69C84B58C73B5846B9C7352A5846BA57B5A9C7352A57B5A9C735294735A8C634A8452397B5A42\
7B5242EFE7DEE7CEBD000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000EFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFBD9CE7BD94EFB594EFBD9C
E7AD8CE7AD8CE7AD8CE7AD8CDEA57BDEA584E7A594EFB59CEFC6ADF7C6B5F7C6B5F7C6B5F7C6B5\
EFC6A5DEAD8CE78C7BDE8473EFB59CCE6B5A9C4A31C6634AF7D6BDEFC6ADEFC6A5
E7B59CDEAD94DEA584B56342DEAD94E7AD9CE7AD94D6A58CD6A58CDEAD94DEAD94DEAD94DEAD94\
E7AD94E7AD94E7A594DEAD94DEAD94E7B59CE7B59CE7BD9CEFBD9CEFC6ADEFCEAD
F7CEB5F7D6BDF7D6BDF7DECEEFD6C6EFD6C6F7DECEEFD6C6EFD6C6F7D6BDEFD6C6F7D6BDF7D6BD\
F7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7CEB5F7CEB5EFB59CE7B59CE7AD94D69C7B
C6846BB5846B9C7352A57B6BA5846B8C634A94735A9C6B4AA57B5A8C634A8C634AA57B6B9C7363\
94735AEFD6C6E7C6B5000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFC6A5EFBD9CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFB594
EFB594EFB594E7AD8CDEA584DEA57BDEA584E7A594EFB59CEFC6ADEFC6ADF7CEB5F7C6B5F7C6B5\
EFB59CDEA584E78C7BDE8473DE8473C65A4A9C3121C6634AEFC6B5E7B59CE7B59C
E7AD8CDEA584D69C7BC6846BE7AD8CE7AD9CE7A594DEA584DEAD8CDEAD8CE7B594E7B59CDEAD94\
DEAD94DEAD8CDEAD8CDE9C7BD69C7BD69C7BDEA584E7B594E7B59CEFC6A5EFC6AD
F7D6BDF7CEB5EFD6C6F7D6BDEFD6C6F7DECEEFD6C6EFD6C6F7D6BDF7D6BDEFD6C6F7D6BDF7D6BD\
F7D6BDEFD6C6F7D6BDF7CEB5F7CEB5F7CEB5EFC6ADEFC6ADEFB594E7B594D69C7B
CE946BB58C73BD947B9463428C634ABD947B8C634A946B5294735AA57B5AA57B5A9C73529C7352\
B5947BE7CEC6EFD6C6E7D6CE000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFBD9CEFBD9CEFB594EFB594EFB59C
E7B594E7AD8CE7AD8CDEAD84DEA57BD69C7BDEAD8CE7AD9CEFB59CEFC6A5EFC6ADEFC6ADEFC6AD\
EFB59CDEAD8CE78C7BCE6B5ADE8473C6634A9C4229C6634AEFC6ADE7B59CE7BD9C
E7B594DEAD8CD6A584DE9C7BE7B594DEAD94DEAD94DEAD8CDEAD94E7B594E7B594E7BD9CE7BD9C\
E7B59CDEAD94D6A58CD6AD8CC69C84D6A584BD947BBD947BDEA584E7B594E7B594
EFBD9CF7CEB5F7CEB5F7D6BDEFD6C6EFD6C6EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDEFD6C6F7D6BD\
F7D6BDF7D6BDF7D6BDF7CEB5F7CEB5EFCEADF7CEB5EFC6A5EFC6A5EFB594D69C7B
BD8C63B5846BA57B63A5846B734A318C634AA57B5A7352428C6B529C7352A5846BB58C73BD947B\
C6A594E7CEBDEFDECEEFDECE000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFC6A5EFC6A5EFBD9CEFC6A5EFC6A5EFBD9CEFBD9CE7BD94EFB594E7BD94
E7AD8CDEAD84DEAD84DEA57BDEA57BDE9C73DEA584E7AD94EFB59CEFC6ADEFC6A5EFC6ADEFC6A5\
E7BDA5DEAD8CDEA584CE6B5ADE7B6BC6634AAD4A31C6634AE7BDA5E7B59CEFBD9C
E7BD9CE7AD94DEAD8CB57B5ADEA584DEAD8CDEAD8CD6A58CDEAD94E7B59CE7B59CE7BDA5E7BDA5\
E7BDA5DEAD9CDEAD94D6A58CD69C7BBD947BB5846BB58C73BD947BDEA584D69C73
E7AD94EFC6A5F7CEB5EFD6C6EFD6C6F7D6BDEFD6C6F7C6B5F7D6BDF7CEB5F7D6BDF7D6BDF7D6BD\
F7D6BDF7D6BDF7CEB5F7CEB5F7D6BDEFC6ADEFC6ADEFC6A5EFC6A5E7AD8CD69C73
D69C7BAD7352BD947BA57B5AA57B63845A42845A42734A315A31218C6B529C7352A57B63B58C73\
BD9C8CD6BDADE7D6CEE7CEC6000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFB594EFB594
E7AD8CE7AD8CDEA584DE9C7BDE9C73DE9C73DEA584E7AD94E7B59CEFB59CEFC6A5EFC6ADEFC6AD\
EFC6A5DEAD8CDE9C7BCE6B5AC6846BE78C7B8C3121C6634AE7B59CE7B59CE7B59C
E7B59CE7B594DEAD8CD69C73CE8C63DEA584DEA584DEAD94E7B59CE7BDA5E7BDA5E7BDA5EFC6AD\
E7BDA5E7BD9CDEAD94CEAD94E7BD9CD6A584C6846B9C7352C6846BD69C7BDE9C7B
C6846BE7AD94F7CEB5F7D6BDEFD6C6F7D6BDF7CEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7C6B5\
F7CEB5F7CEB5F7CEB5F7D6BDF7CEB5EFC6ADEFC6ADEFC6A5EFBD9CE7AD8CDE9C7B
CE7363B5846BB58463B58C73845A42A57B638C634AA57B5A734A318C634A94735AB5846BDEC6B5\
A58C7BDECEBDDECEBDDECEBD000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9CE7BD9CEFBD9CEFB594E7AD8C
E7AD8CDEAD84DEA584DEA57BD69C7BCE946BD69C7BDEAD8CE7AD94EFB59CEFC6A5E7BDA5EFC6AD\
E7BD9CDEAD8CDEA584CE6B5ACE7363CE7363AD4231D69C73E7BDA5E7BD9CE7BDA5
EFB59CE7B59CE7B594DEAD8CD69C7BDEA584E7AD94E7B59CEFC6ADEFC6ADEFC6B5E7C6ADEFC6AD\
E7C6ADDEAD9CE7BDA5D6B5A5DEAD9C9C4A31C69C84B58C73AD7352BD947BBD947B
AD6342BD8C63EFCEADF7CEB5F7D6BDF7D6BDF7CEB5F7CEB5F7CEB5F7CEB5F7D6BDF7C6B5F7CEB5\
F7D6BDF7CEB5F7CEB5F7C6B5EFC6ADEFC6ADEFC6A5EFC6A5EFB59CE7AD8CD69C7B
CE946BB58463A57B639C7352B584638C634A9463427352427B5A42734A317B5A42B5947BE7C6B5\
D6BDADDEC6B5E7CEC6D6BDB5000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFB594EFBD9CE7BD94EFB594EFB594
DEAD84DEA584DEA584DE9C7BD69C73CE946BCE8C63DEA584DEAD8CE7AD94E7BD9CE7B59CEFC6A5\
EFBD9CE7B594DEAD8CD69C7BCE6B5ACE73639C4229D6A584E7B59CE7B59CE7B59C
EFBD9CEFBD9CE7B59CE7B59CE7B59CEFB59CEFB59CEFC6ADEFC6ADEFCEB5EFC6B5EFCEB5EFCEBD\
EFC6B5E7C6B5E7C6B5E7C6ADE7C6B5C65A4AAD4231BD947B94735AB5846BD6A584
9C7352945A42E7B59CF7C6B5EFCEB5F7D6BDF7CEB5F7CEB5F7CEB5F7CEB5EFC6ADF7CEB5F7CEB5\
F7CEB5EFCEADEFCEADF7CEB5EFC6ADEFC6ADEFC6ADEFC6A5EFBD9CE7AD8CD69C73
B57B5A9C7352BD8C63A57B63A57B5A8C634A845A427B5A42A57B5A734A31A57B5A946B52D6B5A5\
D6BDB5DEC6B5CEB5A5CEC6BD000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFC6A5EFBD9CEFC6A5EFBD9CEFBD9CEFBD9CE7BD9CEFB594EFB594EFB594
E7AD8CDEAD84DE9C73DE9C7BDE9C73CE946BC6845AD69C7BDEA584E7AD8CDEAD94E7BD9CE7B59C\
E7B59CE7B594DEA584DEAD8CD69C7BC65A4A844229D6A58CE7B594E7BD9CEFC6A5
EFC6A5E7BDA5EFBD9CEFC6A5EFC6ADEFC6ADEFC6ADEFC6B5EFC6ADEFC6B5EFD6C6F7D6BDEFCEBD\
EFCEBDE7CEBDEFC6B5E7C6B5E7AD9CC6846BDEC6C69C6B4AA58C8484634AD6A58C
B56B52845239D6A584EFC6ADEFCEB5F7C6B5F7CEB5EFCEADEFCEADEFC6ADF7C6B5F7CEB5F7CEB5\
F7C6B5F7CEB5EFCEADEFC6A5EFC6ADEFC6A5EFC6ADEFC6ADEFB594DEA584D69C73
B58C739C6B4AA57B5AA57B5AA57B63946B5284634A845A4284523984634A8452398C5A42C69C84\
D6BDADDEC6B5BD9C94B59C8C000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFBD9CEFBD9CEFBD9CE7BD9CEFBD9CEFBD9CE7B594E7BD94E7BD94E7AD8C
E7AD8CDEA584DE9C7BDE9C73D69C73C6846BCE8C63C67B5ADE9C7BDEA584DEAD8CE7B594E7B59C\
E7B59CE7B594E7B594DEAD8CDEAD8CD6A58C945A42DEAD8CE7B594EFC6A5E7B59C
EFB59CEFC6A5EFB59CEFC6A5EFC6ADEFC6ADEFC6ADEFC6B5EFC6B5F7C6B5F7D6BDEFCEBDEFCEBD\
EFCEBDEFC6B5EFCEBDE7BDA5DEAD9CD6A58CEFE7E7CEC6BDA58C84A57B63D6A584
B58C73945A42B58C73EFC6ADF7CEB5F7CEB5F7CEB5EFC6ADEFC6ADF7CEB5EFCEADEFC6ADEFC6AD\
EFCEADF7C6B5EFC6ADEFC6A5EFC6ADEFC6ADEFC6A5EFC6A5E7B59CDEAD8CBD947B
B57B5AB5846B9C6B4AA57B63A57B63845A42845A427B5A428452398452398452318C5A42DEAD9C\
DEC6B5E7CEBDD6BDADA58C84000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFC6A5EFB594EFBD9CEFBD9CEFBD9CE7BD94EFB59CEFB594E7BD94E7AD8C
DEAD84DEAD84DEA57BCE946BD69C73CE8C63C67B5AC67B5ACE946BDEA57BE7AD8CE7AD8CE7B594\
DEAD8CE7B59CE7B594E7B594DEAD94E7AD94DE8473DEAD8CE7B59CE7B59CEFC6A5
EFB59CEFC6ADEFC6A5EFC6ADEFC6ADF7C6B5EFCEADEFCEB5F7C6B5F7C6B5F7C6B5F7D6BDEFD6C6\
EFCEBDEFD6C6E7C6ADE7BDA5C6A59CDEC6C68C7363635A525A3929A58473BD947B
E7BDA5B56B5294735AEFC6ADEFC6ADEFC6B5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6ADF7CEB5\
EFC6ADEFC6ADEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5E7B59CE7AD94CE946B
B57B5A9C7352BD947BC6946B8C5A428C5A427352428452316B392184523994735A9C7352D6A58C\
E7D6C6CEB5A5BD9C8CBD9C94000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFBD9CE7BD9CEFB594EFBD9CEFBD9CEFBD9CEFBD9CEFB594EFB594E7AD8C
DEAD84DEA584DE9C7BCE946BCE946BCE8C63C6845AC67B4AC67B4AD69C73DEA584DEAD94DEAD94\
E7AD8CE7B594E7B59CE7B594E7B594E7B594E7B594E7B594E7B594E7B594E7B59C
EFC6ADEFC6ADEFC6A5EFC6ADEFC6ADEFC6ADEFC6ADF7CEB5F7CEB5F7D6BDEFD6C6EFD6C6EFD6C6\
EFD6C6EFCEBDE7C6ADD6B5A5BD9C8C947B7394735AB5BDCE5229189C7B6BBD947B
E7C6ADDEA5848C5A42E7C6ADEFC6ADEFC6ADEFC6A5EFC6ADEFC6ADEFC6A5EFC6ADEFC6ADEFC6AD\
EFC6ADEFC6ADEFC6A5EFC6A5EFC6ADEFC6A5E7BD9CE7B594DEAD8CD6A584CE946B
BD8C63B58463A57B5A8C634A9C6B4A845231845239734A318452398C5A42946B529C7352D6A58C\
E7CEC6A58C73B59C8C9C7B63000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
EFBD9CEFBD9CEFBD9CE7BD94EFB594E7BD94EFB594E7BD94EFBD9CE7B594E7AD8C
E7AD8CDEA584DE9C7BCE946BCE946BC6846BC6845AC67B5AB5734ACE946BD69C7BDEA584DEAD8C\
DEAD94DEAD8CDEAD94E7B594E7B59CE7B594E7B594E7B594E7B59CE7BD9CE7B59C
EFC6A5EFB59CEFC6A5EFC6ADEFC6ADEFC6ADF7C6B5EFC6ADEFC6B5EFCEBDF7C6B5F7D6BDF7C6B5\
EFCEBDEFCEBDE7BDA5E7AD9CB5846B735A4A7B6B5A2118185A3929846352BD947B
EFC6ADE7AD9C9C7352E7C6ADEFC6ADE7C6ADE7C6ADEFB59CEFB59CEFC6A5EFB59CEFB59CEFC6A5\
EFC6A5EFC6ADEFC6ADEFB59CEFBD9CEFB59CEFBD9CE7B594E7AD94DEAD8CCE946B
B584639C7352B5846B9C7352A57B5A734229845239734A317342298452318C634AB58463D6A58C\
D6BDADC6A594BD9C949C7B6BB59C8C000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFBD9CEFC6A5EFBD9CEFB594E7BD94E7BD9CEFB594E7B594E7BD94EFB594
DEA584DEA584DEA584D69C73CE946BCE946BC6845AC67B5AB57B5AB5734ACE946BD69C7BDEA584\
DEAD8CDEAD8CDEAD8CDEAD94DEAD94E7B594E7B594E7AD8CE7B594E7B59CE7AD94
E7B59CEFB59CEFB59CEFC6A5EFB59CEFC6ADEFC6ADEFC6ADF7C6B5F7C6B5F7D6BDF7C6B5F7C6B5\
F7D6BDEFCEBDE7C6ADDEAD8CB58C73A57B6B948C8473736B5A3929634A42CE946B
E7C6ADE7C6ADAD6342C69C84E7BDA5E7BDA5EFC6ADE7BDA5E7B59CE7BDA5EFC6A5EFC6A5EFC6A5\
EFC6A5E7BDA5E7BDA5E7BDA5E7B59CE7B59CE7B594E7B59CDEAD94D6A584CE946B
B58463AD7352A57B639C73527342298452398452396B39216B39219C6B4A946342B58463E7C6AD\
C69C84A58C738C735A94735A000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFC6A5EFC6A5EFBD9CE7BD94EFBD9CEFB594EFB594E7B594E7B594DEAD84
E7AD8CDEAD8CDEA57BD69C73CE946BCE946BC6845AB57B5AC67B4AB5734AB56B52C6846BD69C7B\
DEA584DEA584DEA584DEAD8CDEAD8CE7B594DEAD8CE7AD8CE7AD94E7AD94E7AD94
E7B59CE7B59CEFC6A5EFB59CEFC6A5EFB59CEFC6A5EFC6A5EFC6ADEFC6B5EFCEBDEFCEBDF7D6BD\
EFCEBDEFC6B5E7C6ADDEAD8CC69C84A57B636B635A635A52734A315A4239D69C7B
E7BDA5EFC6ADCE6B5AA57B63E7C6ADEFC6ADE7BDA5E7BD9CE7B59CE7BD9CE7B59CE7B59CEFBD9C\
E7B59CE7BDA5E7BD9CE7BD9CE7B59CE7B59CE7B594DEAD94D6A58CD6A584C6846B
B5846BA57B63A57B5AB5846B734A31845239734A315A39295A31218452319C6B4ABD8C63E7C6AD\
B5947B9C7B63A57B5AA58C73000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFC6A5EFC6A5E7BD9CEFB594EFB594E7B594E7BD94E7B594E7B594E7AD8C
DEA584DEAD84DEA57BDE9C7BD69C73C6846BCE8C63B57B5AC67B4AB5734AAD6B42CE946BCE946B\
D69C73DE9C7BD6A584DEA584DEAD8CDEAD8CDEAD8CDEAD8CDEAD8CE7AD94E7B594
E7AD94E7AD94EFB594E7B59CEFC6A5EFB59CEFC6A5EFC6ADEFC6A5EFC6ADEFCEBDEFCEBDF7CEB5\
EFC6B5E7C6B5E7C6ADD6A58CC69C84A57B5ABD9C94BD9C945A4239734A31D6A584
E7BDA5EFC6ADB58C73AD7352E7C6ADE7B59CE7BD9CE7BDA5E7B59CE7BDA5E7B59CE7B59CE7B59C\
E7B59CE7BD9CE7B594E7B594E7B59CE7B59CDEAD9CDEAD94D6A58CC69C84B58C73
B5846BA57B5AA5846BA57B5A9C63399C63397342297342295A3929845231A57B5ABD8C63DEAD94\
B5947B9C7B6B8C634A846352000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFC6A5EFBD9CEFC6A5EFBD9CE7BD9CE7B594E7AD8CE7BD94DEAD84DEAD8C
DEA584DEA57BD69C73D69C73D69C73CE946BCE8C63B57B5AC67B5AB5734AAD6B42AD6342C6846B\
CE946BD69C7BD69C7BD69C7BD6A584D6A584DEAD8CE7AD8CDEAD8CDEAD8CDEAD8C
E7AD8CDEAD8CE7AD94E7AD94EFB594EFB59CEFB59CEFC6A5EFC6ADEFC6ADEFC6B5EFCEBDEFCEB5\
EFC6B5EFC6B5E7C6ADDEAD9CC69C84A57B639C7352423129735A4A9C7352D6A584
E7B59CEFB59CC6846BA57B63E7B59CE7B59CE7B594E7B59CE7B59CE7B594DEAD94DEAD94DEAD94\
DEAD9CE7B594E7AD94DEAD94E7B594DEAD94DEAD8CDEAD8CD69C7BD69C73BD947B
A57B63A57B63A58C73946B528C5A428452398452397342295A3121945A31B58463D6A584CEB5A5\
A584739C7B6B8C6B52A58C7B000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFC6A5EFBD9CEFBD9CEFBD9CEFB594E7AD8CE7BD94DEAD84DEAD84DEAD84
DEA584DE9C7BDE9C73D69C73CE946BCE946BC6845AC6845AB56B52C67B4AB5734AAD63429C6339\
CE8C63D69C73CE946BD69C7BD69C7BD69C7BD69C7BDEA584DEA584DEA584DEA584
DEA584DEA584DEAD8CE7AD8CE7AD8CE7B594EFB59CEFB59CEFB59CEFB59CEFC6ADEFC6B5EFC6B5\
EFC6ADEFC6ADEFC6ADDEAD9CCEA594B5846B8C6B527352427B5242BD8C63DEAD8C
E7B59CE7BDA5B58463A57B63DEAD94DEAD94DEAD94DEAD8CE7AD94DEAD94DEAD94DEAD8CDEAD8C\
DEAD8CDEAD8CDEAD8CE7B594DEAD8CDEAD94CEAD94D6A584BD947BBD947BB58C73
B58C738C634A84634A946B52845A427B5A427B5A427342295A31219C6B4AC69C84D6A584A58C73\
9473638C634A9C7B6BBD9C8C000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFB594EFBD9CEFB594E7BD9CEFB59CE7B594DEAD84EFB594DEAD84E7AD8C
DEA584D69C7BD69C73CE946BCE946BCE946BC6845AC67B5AB57B5AB5734AAD6B42AD6B42AD6342\
9C6339CE8C63CE946BCE946BCE946BD69C7BD69C7BD69C7BDEA584DEA584DE9C7B
DEA584DEA584DEA584DEA584DEAD8CE7AD8CE7AD94E7AD94EFB59CE7B59CE7C6ADEFC6ADEFC6AD\
EFC6B5EFC6ADEFC6B5E7BDA5E7BD9CD6A58CB5846BA57B63A57B63B58C73E7AD8C
E7B59CDEAD94A57B63BD947BDEAD8CD6A584DEAD8CDEAD94DEAD8CDEAD8CDEAD8CDEAD8CD6A58C\
DEAD8CDEAD8CDEAD8CD6A584D69C7BD6A58CBD947BBD947BBD947BB5846BB5846B
BD947B946B52946B52845A428C5A42946342845239845231734A31AD7352B58C73C6A5948C6B52\
94735A8C6B52A58473C69C84000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFB594E7BD9CE7B594E7BD94E7B594E7B594E7B594DEAD84E7AD8CDEA57B
DEA57BDEA57BD69C73CE946BCE946BC68463C6845AB57B5AC67B4AB57B5AB56B529C6B4AAD6342\
9C4A31B56B52C68463C6846BDE8473CE946BD69C73D69C7BD69C7BD69C7BDEA584
D69C7BD69C7BD69C7BDEA584DEA584DEAD8CE7AD8CE7AD8CE7AD94E7B59CEFB59CE7BDA5EFC6AD\
E7C6ADEFC6ADE7C6ADE7BDA5E7BDA5DEAD94D6A584B58C73B58463C6846BDEAD94
DEAD94DEA584A57B5AC69C84D6A58CD6A584D6A58CDEA584D6A58CD6A58CD6A58CDEAD8CDEAD8C\
D6A584D6A58CDEA584D6A584D6A58CD69C7BD69C7BBD947BB58C73B58463B57B5A
A5846B94735AA57B5A7B5A429C63398C5A428452319C6B4A8C5A42A57B63BD947BA57B639C7B63\
946B52735A4ABD9C8CB59C8C000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFBD9CEFB594EFB594EFB594E7B594E7B594E7BD94E7AD8CDEAD84DEA584
DEA57BD69C7BD69C73CE946BC68463C6845AB57B5AC67B4AB57B5AB5734AAD6B42AD6342945A42\
9C6339945A318C5A42C6845AC68463CE946BD69C7BD69C73D69C73DE8473D69C73
D69C73D69C7BD69C7BD69C7BD69C7BDE9C7BDEA584DEAD8CE7AD8CDEAD94E7B594E7B59CE7BDA5\
E7BDA5E7BDA5E7C6ADE7BDA5DEAD9CDEAD94D6A584BD947BB5846BCE946BD6A58C
D6A584BD947BB5846BBD947BD69C7BD69C7BD6A584D6A584D6A584D6A584D6A584D6A584D6A584\
D6A58CD69C7BDEA584D6A584BD947BD6A584CE946BB5846BB5846BB584639C6B4A
A58C73AD73529C7B63734A31946342845239845231845A42A5846BBD8C63D6B5A59C7B6B946B52\
735242A57B63C69C84A58C7B000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFBD9CE7BD94E7B594E7B594E7B594E7B594E7B594DEAD8CDEAD8CDEA57B
D69C73D69C7BD69C73CE8C63C68463C68463B57B5AB5734AB5734AAD6342AD63429463429C6339\
8C4A318452318442297B4A29B57B5AC6845AC68463CE946BCE946BCE946BCE946B
DE8473D69C73D69C73D69C73CE946BDE8473DE9C7BDEA584D6A584DEA584DEAD8CDEAD94DEAD94\
E7BDA5E7BDA5D6B5A5E7BD9CDEAD9CDEAD9CDEAD94D6A584CE946BD69C7BD6A584
C6946BA57B5ABD947BCE946BD6A584D69C7BD69C7BBD947BD69C7BBD947BBD947BC69C84D6A584\
CE946BD69C7BCE946BB58C73BD947BB58C73B5846BAD7352AD7352A57B5A8C634A
A57B5A94735A8C6B527352429C6B4A844A318C634A8C634ABD947BC69C84BD9C8C9C7B6B845A42\
845239A58C73B58C73C69C84000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000EFBD9CE7B594E7B594EFB594E7B594E7AD8CE7AD8CDEAD84DEAD8CD69C7B
D69C73D69C73CE8C63CE8C63C6845AC6845AB56B52AD6B42AD6B429C6B4A9C63399C4A31844A29\
8C4A29844A317B4A296B3921734A31AD7352B57B5AC68463CE946BCE946BCE946B
C6846BCE946BC6846BCE946BCE946BDE8473CE946BD69C73DEA584D69C7BD6A584DEAD8CDEAD8C\
DEAD94DEAD9CE7BD9CE7BD9CDEAD9CDEAD9CDEAD8CD6A58CD69C7BD69C7BD69C7B
B58463CE946BBD947BD69C73BD947BBD947BD69C73CE946BCE946BCE946BD69C73D69C7BBD947B\
CE946BB58C73B58C73B58C73BD8C63A57B63A57B639C7352A57B5A9C735294735A
A57B639C735294735A8C634A9463428C5A42A57B5AA5846BB5846BDEC6B5B59C8C8C5A427B5A42\
94735AA5846BA5846BE7DEDE000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000EFBD9CE7B594E7AD8CE7AD8CE7AD8CE7AD8CDEA584DE9C7BD69C73
CE946BCE946BCE8C63C68463B57B5AB5734AB5734AAD6B42946342845239844221844A317B4A29\
6B39217342296B39216B31185229186B39218C5A429C7352B57B5AB57B5AC68463
C68463C67B5AC68463C68463C68463C68463C6846BC6846BCE946BD69C73D69C7BD69C7BD6A584\
D6A584DEAD8CDEAD8CDEAD94DEAD8CD6A58CD6A58CD6A584D69C7BBD947BCE946B
CE946BB58C73DE8473CE946BB58C73C6946BCE946BC6846BB58C73C6846BB58C73B5846BB5846B\
BD8C63BD8C63B5846BA57B63AD73529C6B4A9C73529463429C6B4A8C5A42946B52
8C634A94735AA57B638452399463429C7352A57B5AC69C84BD947BB5947BA58C737342298C634A\
9C7B63A5846BC6A59C000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000EFBD9CE7B594DEAD84E7AD8CDEAD84DEA584DE9C7BD69C73C6846B
CE8C5AC6845AC6845ABD8C63C6845ACE8C5AC6845AC67B4AB5734A8442217B4221734229632910\
6B39216B39215229185221105229186B39214A18085A3929845231945A429C6B4A
B5734AB56B52B57B5AB56B52C67B5AB57B5AB57B5AB57B5AC68463C68463D69C73D69C73D69C73\
D69C7BD6A584D6A584D6A584D6A584D6A58CD69C7BBD947BBD947BCE946BC6846B
BD8C63B5846BBD8C63BD8C63B57B5ABD8C63B57B5ABD8C63B58463B58463B5846BA57B63B5846B\
A57B63A57B63AD7352A57B5A945A429463429C6B4A845A42735242845A42735A4A
8C634A9C7352946342845239845239B58463A57B5ABD947BCEB5A5BD9C8CA58C73845239B58463\
BD947BA57B63F7F7F7000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000EFBD9CE7BD94E7AD8CE7AD8CDEA584DEA584CE946BCE8C63CE8C63
C68463CE946BCE946BB5734AB56B42AD6B429C63398C4A29945A31B5734AC6845AC67B4A9C6B4A\
845239734A316B39216B3118522110391810391810391810423129522110734229
734A318C5A42945A42AD63429C7352AD6B42AD6B42AD7352AD7352B56B52B57B5AC67B5AC68463\
CE946BDE8473D69C73CE946BC69C84CE946BD69C73C6946BB5846BBD8C63BD8C63
B57B5AAD7352AD7352AD7352AD7352B56B52AD7352B57B5AB58463B584639C73529C7352A57B63\
A57B5A9C73529C6B4A8C634A8452398C5A42845A42845A427352427B5A42946B52
94735A8452399C6B4A7B5A429C6339B58463A57B5AE7BDA5B5947B9C7B6B7B5A42A57B63B5947B\
A57B63FFFFFFF7F7F7000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000EFB594E7B594EFB594E7AD8CDEA57BCE946BD69C73CE8C63CE9463
D69C7BCE8C63C6845AAD6B429C63398C4A297B4A298C4A319C6339945A31844221AD7352D69C7B\
BD8C639463428C634A8452398452396B31186B39213918102910084221185A3929
5221105A39295A39297342298C5A42946342945A31AD63429C6B4A9C6B4A9C6B4AB56B52B56B52\
B57B5AC68463C68463C6846BC6846BC6846BB5846BC68463B57B5AB56B52B57B5A
AD73529C6B4A9C6B4A9C7352A57B5AAD7352B57B5AAD7352A57B639C6B4A946B529C73528C634A\
9C73528C634A8C5A42845239845A42845A42734A31845239734A31735242946B52
A57B63845A429463427B5A429C6B4AC69C84C69C84CEB5A584634A734A319C7363A5846BA57B63\
B5947BF7F7F7F7EFF7000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000E7B594E7AD8CDEAD84DEA57BD69C73D69C73DEAD84D69C73
C68C63B57B5AB5734AAD6B39945A319C6B4A9C63399C6339B5734AC6845ACE8C63B57B5A8C4A29\
B57B5ACE946BCE946BAD73525229188C5A42734A315A3929845A42734A31391810
5229186B3921291008391810291008291008522918734A318C4A319463429C6339945A42945A42\
9C6B4A9C6B4AAD7352B56B52B57B5AB56B52AD7352AD7352945A42945A42945A42
9C6B4A9C6B4A9C6B4AAD7352AD7352AD73529C73529C6B4A9C6B4A9C6B4A845A429C6B4A8C5A42\
8C5A42845239734A31734229734229845A42735242845239734A318C6B52734A31
845A428C6B529C6B4A946342CEAD94BD947BCEB5A5BD9C8C947B6B94735AA58C739C7B63A57B6B\
F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000E7AD8CE7AD8CDEA57BDEA57BDEAD8CE7BD94DEAD94CE946B
B57B5AB56B52AD6B429C6339AD6B429C6B4AAD6B428C5A428442217B39189C6339B5734ACE946B\
9C6B4ABD8C63AD7352D69C7BD6A584B58463845A42845A42734A31845231735242
734A315A4239422921422921391810422118180808211008291008422118734229734A318C4A31\
845239945A31945A319C6B4A945A429C6B4A9C6B4A945A428C5A428C5A428C634A
8C5A428C5A428452398452399C6B4A8C5A429C6B4A8452398C5A428C5A42734A317B5A426B3921\
5A39295A39295A3929734A315A39295A3121946B525A39295A42397B5A428C634A
6B39219C6B4A946342B5734ABD947BE7BD9C9C7B63A58C73B58463A5846BA5846BBD947BFFFFFF\
F7F7F7FFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000E7AD8CEFB594DEAD84DEAD84E7BD9CE7BD9CCE8C63C6845A
B56B52B5734AAD6342AD63429C63399C63398C4A298442217B39186B31186B39216B3118946342\
C69C84A57B5A945A31B58463DEAD8CC6946BBD8C639C7352845A42A5846B845239
8C634A845A42734A315A31214229213918104221183918104231292110086329106B39215A3121\
734229734A31844A318452398452398C5A428452318452398C5A42845239845239
8452316B39219C6B4A6B3921734A319C6B4A734A31734A316B3921734A318452396B39215A3121\
5A31215A31215A39295A31215A39295A3121422118734A31734229734A319C6B4A
8452399C73529C7352C6946BD6AD8CD6B5A59C7B63946B52A5846BB5947BA57B6BFFFFFFF7F7F7\
F7F7F7F7EFF7000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000E7AD8CE7AD8CE7BD9CDEAD8CCE8C63C68463C68463
C67B4AAD6B42AD6342AD6B42AD6B42945A317B42216B31186B3118522110734A31522110AD6B42\
8C4221D69C73D6A584C6846B9C6339B57B5AD6A584D69C7B9C73529C7352946342
946B52845239845231734A315A4239734A317342295A39295229185A31216B39216B39215A3121\
6B3118522918522918734229734A31734A31734A31844A31734A318452396B3921
8452396B3921422118734A316B39217342295A31215A3929734A316B39215A31215A3121422118\
4221184229215229185A31214229215229183918105A39295A31218C6B529C6B4A
B57B5AA57B5AB58463D6AD84D6BDADA5846BA5846BC69C849C6B4AB5947BFFFFFFF7F7F7F7F7F7\
F7EFF7000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000E7BD94DEAD84DEAD84CE8C63CE946BC68463C6845A
B5734AAD6B42946342AD6B42AD6B428442217B39186B3921734A316329105221107B42216B3118\
B57B5AC67B4AC67B4AD6AD84D6AD8CBD8C63945A31C6946BBD8C63C69C849C6339
9C73529C73529C6B4A8452397352428452395229187B5A42734229522918734A316B39216B3921\
6B39216B39215221103918106B39218452395A31214221186B39217342296B3921
6329105229187342296B39215221105229186B3921734229522110522110391810391810422118\
422921422118422118422118522918391810392118734A31A5846BB5846B9C7352
B58463A57B5AD6AD84E7C6AD8C634AA57B5AC6A594946B52C6A59CF7F7F7F7F7F7F7F7F7FFFFFF\
F7F7F7000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000E7B594E7BD9CD69C7BCE946BD69C73C68C63C6845A
B57B5A945A31AD6B429C63397B42217B42217B4A29AD6331B56B39AD6B398442219C6339AD6331\
945A31B57B5ACE9463CE9463B57B5AD6AD84D6A5849C6B4A9C63399C6339AD7352
B58463946342845239845A428C5A429463429C6339845239734A31845239734A31845239734A31\
6B39216B39216B39216329105A3121522918291008391810422118522918522918
5229185A31217342295A31213918105229185A3121422118422118391810291008391810291008\
3118185229185229183918102118182910087B5A42734229946B5294735A9C6B4A
B57B5AC6946BCEB5A5BD9C8CBD9C8CBD9C8CBD947BEFE7E7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7\
F7F7F7000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000DEA57BD69C73D69C73D69C73C68463B57B5A
9463429C6B4A9C6B4A9C63397B42216329109452298442218C4221B56B42C67B4AC67B4A8C4A31\
AD6342844221B57B5AD69C73DEA57BC6845AB57B5AD69C73C6845A945A319C6339
9C6B4AB5734AB5734A9C6B4A8452397342298452318C5A428452318C5A42946342845231844A31\
845239734A31734A316B39215A31215229184221184221185A39295A39295A3929
5229185229186B3921391810391810422118391810391810422118291008422921422921392118\
422118522918391810211008211008B5846B845239A57B639C7352A57B63BD8C63
BD8C63D6B5A5CEAD94D6AD8CA5846BA5846BEFE7E7FFFFFFF7F7F7F7F7F7FFFFFFFFFFFFF7F7F7\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000DEAD8CD69C7BCE946BCE8C63B57B5A9C6339
B5734A9C6B4A945A319C63398C4A29AD6331AD5A319C63399C63399452298C4221C6845ABD8C63\
B56B42AD6B399C6339C6946BD6AD84DEAD84D69C7BB57B5AAD6B42C68C63B57B5A
8C5A428452319C63399C6B4A9C73529C6B4A9C6B4A9463428452317B4A298452319C6339946342\
945A319C6B4A8C5A428C5A428452398452398452395229186B39215A3121734A31
5A39295221105229183918103918105A3121391810391810391810291008291008391810391810\
4221183918102910085A3929A57B5A9C7B63A57B5A9C73529C6B4ABD8C63B58463
CEAD94D6B5A5D6AD8CB58463DECECEF7F7F7F7EFF7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFFF7F7F7\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000DE9C73D69C73B57B5AAD73529C6B4A
9C7352945229945A31AD6331B56331C67B42C67B42C67B4AB56B42B56B42B56B42C67B4AAD6331\
C67B4AC6845AAD6B42C67B4ABD8C63EFCEADE7BD9CE7BD9CC6845ABD8C63A57B5A
9463429C63399C63398452318452318452317B42217B4A299C6339945A319C63399463429C6339\
8C634A8C5A429C63398C5A428452318452398C5A428452396B39215A3121734229
5221107352424229214221184221185221104221185A31214229217B524284634A946B529C7B63\
A57B639C6B4A946B52B5846BA57B639C6B4A9C6B4AB58463D69C7BD6A584DEAD94
D6B5A5C69C84E7CEC6F7F7F7FFFFFFF7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000DE9C73CE946BB56B528C5A429C6B4A
AD6B399C63399C6339B56B39C67B42B56331C67B42C67B42C67B4ACE8C5AC67B4AC67B4AC67B42\
AD6B39C67B42CE8C5AB5734AC6845ABD8C63EFCEADE7BD9CE7BD9CDEAD94CE946B
BD947B8452397B4A299C6B4A945A31945A318452318452318452319C63398C5A428C5A42946342\
8452398C5A428C5A429C6B4A8C634A8C5A42734229734A31734A317342296B3921
734A31845A4284634A8C634AB58C73BD947BC6946B9C735294735A8C634A946B52946B52946B52\
B5846BB584639C73529C7352946342946342AD7352BD8C63C6946BE7BD9CE7BD9C
D6BDADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000C67B4A9C6339AD6B42AD6B39
AD6B42B56B42B56B39B56B42C67B42C67B42B5734AB5734AB56B39AD6B39B56B39C6845AC67B4A\
C67B4AC67B4AC67B4AC6845ACE9463B5734ACE946BEFCEB5E7BD9CE7BD9CE7BD94
C68C63D6AD8CD6A5848C5A425229185A31218C5A42734A318452318452318C4A3194735A945A31\
844A298C5A428C5A428452398C5A429C6B4A9C6B4AAD73529C6B4A9C73529C6B4A
8C5A42946B529C6B4A94735A8C634AA57B5AA57B63D69C73BD947BA57B5A9C6B4A9C73529C6339\
8C5A429C6B4A9C6B4AB5734AB57B5ABD8C63C6946BD6AD8CE7BD9CD6BDADF7EFE7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7EFF7000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000C67B42C67B42C67B42CE8C5A
C67B4ACE8C5AC67B42C67B42C67B42B56B42C67B42AD6B39AD6B39BD8C63C6845AAD6B42BD8C63\
BD8C63AD6B39B5734ABD8C63AD6331C6845ACE946BAD7352D69C73EFC6A5E7BD94
DEA573E7BD94C6845ABD8C63D6AD84C6946BAD73529C7352A57B5A9C73529C7352B5846BD69C73\
D6AD8CC69C84C69C84BD947BB5846BB58463B5846B9C7352AD7352B57B5ABD8C63
AD7352A57B5AAD73528C5A428C5A428C5A429C6B4AB584639C7352AD73529463429C6339946342\
AD7352C6845ABD8C63CE946BC68C63D6B5A5E7BDA5D6BDADF7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7FFFFFF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000B56B39B56B39C67B4A
CE8C5ACE8C5ACE8C5ACE8C5AC6845AC67B4AAD6B39B5734AB5734AB5734AC6845AC68C63B58463\
9C6339B57B5ABD8C63AD6B39C6845AC6845AB56B39C6845ACE946BD6AD84CE946B
EFC6A5D69C73D69C73DEAD84CE8C63BD8C63C68C63C6845ABD8C63C69C84D6A584D69C7BD69C73\
D69C73C6946BCE946BD69C7BBD8C63BD947BB58463A57B5A9C6B4A9C73529C6B4A
9C6B4A9C73529C6B4AA57B5AD69C73BD947BD69C73D69C7BC6946BC69C84C6946BC6946BC69C84\
C6946BD6A584DEAD8CCEAD94E7CEBDEFE7E7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000B56B39C67B42
C6845ACE8C5AC6845ADEA573CE9463CE9463CE9463CE8C5AC6845AC6845AC6845ABD8C63C6946B\
BD8C63B57B5AB57B5AB5734AB57B5AAD6B42C6845AC6845ABD8C63C6845AD69C73
D6AD84DEA57BEFCEADD69C73CE9463D6AD84DEA57BCE946BCE9463D69C73D69C73D69C73D69C73\
C6946BD69C73CE946BB57B5AB57B5AB5734A9C6B4AA57B5A9C63399C63399C6339
946342945A31946342AD63429C6B4AAD7352B5734AB57B5ABD8C63C6946BC6946BC69C84CEB5A5\
E7BD9CDECECEEFEFE7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000B56B39B56B39
B5734ACE946BCE8C5AD69C73D69C73DEA573D69C73D69C7BCE8C5AD69C73CE9463C6946BB57B5A\
BD8C63D69C7BD69C73BD8C63BD8C63B57B5AB57B5AB57B5AB5734AC6845AC6845A
C67B4AC68C63C6946BDEAD84E7BD9CE7BD9CDEA57BDEAD8CDEAD8CDEAD84D6AD84D69C73D69C73\
D69C7BD69C73D69C73BD8C63B57B5AB57B5AA57B5AB57B5AB57B5AB57B5AC6845A
C68C63BD8C63BD8C63C6946BB57B5A9C6B4A8C634A9C7352A5846BD6AD8CC69C84D6A58CDECEC6\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000AD6B39
C67B4AC67B4AC6845ADEAD84CE946BD69C7BD6AD84DEAD84DEAD84DEAD84D69C73D69C73D6AD84\
D69C73C6946BC6946BD69C73C6946BCE9463BD8C63BD8C63B5734AC68C63BD8C63
C68C63C6946BC68C63C6845AB57B5AB57B5AD69C73E7BDA5EFCEADEFCEADE7BDA5D6AD84D6A584\
C69C849C6B4A844A31844A29945A31945229AD6342AD6342AD7352BD8C63BD947B
C6946BBD8C63D69C73C69C84D6AD84D6AD8CBD947B946342946342C6946BE7DED6F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
B57B5AC67B4ABD8C63C68C63D6AD84DEAD84CE946BDEAD8CDEAD8CE7BD94E7BD9CD6AD84CE9463\
D69C73D69C73D6AD84BD8C63CE946BC6946BC68C63BD8C63BD8C63B5734AB5734A
9C6B4AA57B5AC68C63BD8C63BD8C63BD8C63B57B5AB5734AB57B5AAD7352BD8C63C68C63D6AD84\
DEAD8CE7BD94DEAD84E7BD94E7BD94E7BD9CDEAD8CD6AD84D6AD84D6AD84DEAD94
E7BD9CD6AD8CB5846B9C6B4A9C6B4A9C6B4A9C6B4ACEAD94E7CEC6F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000B5734AB5734AAD6B39BD8C63BD8C63C6946BD6AD84D6AD84E7BDA5E7BDA5E7BD9CE7BDA5\
CEAD94D6AD84D69C73DEAD84D69C7BD69C73B57B5AB57B5ACE946BB57B5ABD8C63
C6946BB57B5AB57B5A9C63399C6B4AAD7352BD8C63B57B5AB5734AC68C63B5734AAD6B39AD6B42\
945A31844221945A429C6B4A945A319C6339844A29844A299463429C6B4A9C7352
A57B5ABD947BAD6B42BD8C63C69C84D6BDADF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000B5734AAD6B39B5734ABD8C63C6845AC6946BD69C73D6AD8CD6AD84E7BD94EFCEB5\
DEAD8CE7BDA5D6AD84D6AD8CD6AD8CD69C73D6AD84D6AD84D69C73B57B5AB5734A
BD8C63BD8C63B58C73B57B5AAD7352B57B5AAD73529C73529C6B4A8C5A42845231844A29AD6B42\
AD73529C6B4A8C5A428C4A318C4A319C7352BD947BBD8C63BD8C63BD8C63BD947B
C69C84C69C84DECEBDEFE7E7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000B56B42B5734AC6845ACE9463C68C63C6946BC6946BB56B42C68C63BD8C63BD8C63\
E7BD94E7C6B5E7C6ADE7BD94E7BDA5E7BDA5E7BD94D6AD84CE946BCE946BD69C73
D69C7BC69C84C6845AB57B5ABD8C63B58463B57B5AB57B5AA57B5AB58463A57B5AA57B5AAD7352\
AD7352BD8C63B5846BC6946BC69C84D6AD84D6AD8CD69C7BD69C73D6A584EFDECE
EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000C68C63C6845ABD8C63C68C63B57B5AB5734ABD8C63B57B5AB5734AB5734A\
BD8C63BD8C63D6AD84E7BDA5E7C6B5E7BDA5E7BDA5E7BDA5E7BDA5E7BDA5D6AD84
D69C73D69C73C6946BD69C73C6946BBD947BB57B5AC6946BB58463AD7352B57B5ABD947BB58463\
A5846BC6946BD6A584D6AD84D69C73D6AD84D6AD8CDEC6B5EFE7DEEFEFE7FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000CE946BCE946BBD8C63B56B42BD8C63BD8C63BD8C63BD8C63BD8C63\
B56B42C6946BD69C73C69C84BD947BC69C84D6BDADE7C6ADE7C6ADE7C6ADE7BDA5
E7BDA5E7BD9CE7BD9CE7BD94CEAD94D6AD8CCEAD94E7BD9CCEAD94E7BD94DEAD8CD6AD8CDEAD84\
D6AD84CEAD94E7C6ADE7D6C6E7D6CEEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000C6946BD6AD84D6AD84D69C73CE946BC6946BC67B4AC68C63\
BD8C63D69C7BC69C84D6AD84B58463C6946BD69C73C6946BC69C84D69C73CEAD94
CEAD94D6B5A5D6BDADD6BDADDEC6B5DEC6B5E7C6ADE7C6ADDEC6B5E7CEBDE7D6C6E7DED6EFEFE7\
F7EFE7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000D6AD84D6AD84D69C73C68C63C6946BC6946BC69C84\
C69C84C6946BC69C84C6946BC6946BC69C84D6AD84D6AD84C69C84D6AD8CC6946B
BD8C63C6946BD6BDADEFE7E7DEC6B5DEC6B5D6B5A5C69C84DECEBDDECEBDEFEFE7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000D69C73D69C73D6AD84D6B5A5D69C73\
C6946BC68C63D69C73D69C73D69C73BD947BC69C84D69C73C68C63C6946BD69C7B
E7C6B5E7DED6DECEBDCEAD94C6AD9CD6BDADE7CEC6DECEBDF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000D6AD8CD6AD8CE7BD94D6AD84\
D6AD84CEAD94D6AD8CE7BD94CEAD94CEAD94D6B5A5E7D6C6E7DED6EFE7DEE7D6CE
E7D6C6E7BDA5E7D6CEEFE7E7D6B5A5DECEBDF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000D6AD84CEB5A5D6AD8C\
E7BD94E7BD9CE7BDA5DECEBDEFE7DEEFE7DEE7DED6EFE7E7EFE7DEEFE7E7EFE7DE
EFE7E7F7EFF7E7D6CED6B5A5F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000E7BD94\
E7D6CEF7EFE7EFE7DEE7D6CEEFE7DEEFE7E7EFEFE7EFE7E7EFE7DEE7DED6EFE7DE
EFE7E7EFE7E7E7CEC6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
EFEFE7E7DED6EFE7DEEFE7E7EFEFE7F7EFE7EFE7DEEFE7DEEFE7E7EFE7DEE7D6C6
EFE7E7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F7EFE7EFEFE7EFEFE7EFE7E7EFEFE7EFE7DEEFE7DEF7EFE7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000EFE7DEEFE7E7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000EFEFE7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[72]:=",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00703ooonG000002P0ooooU`00
000N0?ooo`00703ooonG000002P0ooooU`00000N0?ooo`00703ooonG000002P0ooooU`00000N0?oo
o`00703ooonG000002P0ooooU`00000N0?ooo`00703ooonG000002P0ooooU`00000N0?ooo`00703o
oonG000002P0ooooU`00000N0?ooo`00703ooonG000002P0ooooU`00000N0?ooo`00703ooonG0000
02P0ooooU`00000N0?ooo`00703ooonG000002P0ooooU`00000N0?ooo`00703ooonG000002P0oooo
U`00000N0?ooo`00703ooonG000002P0ooooU`00000N0?ooo`00703ooonG000002P0ooooU`00000N
0?ooo`00703ooonG000002P0ooooU`00000N0?ooo`00703ooonG000002P0ooooU`00000N0?ooo`00
703ooonG000002P0ooooU`00000N0?ooo`00703ooonG000002P0ooooC00000020>nmW4T000007P3o
ool001`0ooooU`00000X0?oood`000000P3__Ia9000001h0oooo000L0?ooodX000000P2eW8a;0000
02P0oooo@00000040>nmW0<0kkFD1@3_aZD20>nmW0`0klJU?@00000N0?ooo`00703ooom:00000080
]Ib<B`00000X0?oooc/000000P3_]I@30>nmW080ikFD0P3_]I@50>nmW0<0klJU0P3__I`20>neU0D0
kkfL0P3_aZD30>nmW0@0klJU>@00000N0?ooo`00703ooolj000000030=k6]@3Wa[D0iljm0080ilJe
00D0kmK60>oNcP3We/h0g/jm0>O>aP020<jeY@040;fLU03F_Jd0_Ib<0;FLS080_IbD00D0S7=J0:Ek
FP2<HdX0S6]B09akJ`020:F4L`050;fLS036W8@0]Hac0:F4J`36YI`00`3gmoL00`3gkoL000000000
000i000002P0oooo>@0000020>N]S0L0ikFD1@3_]I@20>o6Y@<0kkfL0P3W_I@20>nmW0<0klJU103_
_I`30>o6Y@L0kkfL=P00000N0?ooo`00703ooolj000000030=k6]@3Wa[D0iljm0080ilJe00D0kmK6
0>oNcP3We/h0g/jm0>O>aP020<jeY@040;fLU03F_Jd0_Ib<0;FLS080_IbD00D0S7=J0:EkFP2<HdX0
S6]B09akJ`020:F4L`050;fLS036W8@0]Hac0:F4J`36YI`00`3gmoL00`3gkoL000000000000i0000
02P0oooo=00000020>NeU0D0ijf<0P3_]I@30=j]Q0@0kkFD0`3W_I`20>nmW0<0ikfD0P3_]I@70>nm
W0D0klJU103__I`30>NmY@80ikFD0P3N[I`b000001h0oooo000L0?oooc<0000000@0YHAc0:F<N`2U
Nf/0_IAk0P36YI@0102LNf/0Ne9208a[DP1kDT8209AcFP050;FDN`36YI@0_Ib<0:F<N`3F_Jd00P3F
_KD0103F_Jd0g/Je0>OFaP3Wc/H20=Jm[@050<JLQ02eU7/0]IAk0:F4L`2DLf<00P2DLeX01@2DJe80
Le9208AB>@2DLeX0W7]S0080_IAk00<0YG]S0;FDN`3gmoL00`3gmoL00`3gkoL0moOg0?Ogm`0d0000
02P0oooo<P0000020=j]S080ikfL0`3W[H`20=jUN`D0ijf<103W]I@30>neW080ikfL0`3__I`20>Nm
U0L0kkfL0P3_aZD70>nmW0D0ikfL0P3N[I@306<Y42l000007P3oool001`0oooo<`000000102UQ7<0
YHak0:EkJ`2mU7/20<JUU00409akJ`1kDT80S6]B07]B@P80U7=J00D0]IAk0<JUU02mW8`0YHak0=Jm
[@020=Jm]@040=Jm[@3Na[D0imK60>O>aP80e[f]00D0aYb40;FDN`2eU7/0YHAc09AcH`0209AcFP05
09A[DP1cDT80Q58i09AcFP2LNf<00P2mU7/00`2UNf<0]IAk0?Ogm`030?Ogm`030?O_m`3gmoL0moOg
03@00000:03oool_000000<0gYac103FW7/30>NmW0@0gZEk0`3N[H@20>N]S0L0ikFD1@3_]I@20>Nm
U0`0kkfL1@3W_I`20>NeU080gZfD0`1B8A0207/i62d000007P3oool001`0oooo<`000000102UQ7<0
YHak0:EkJ`2mU7/20<JUU00409akJ`1kDT80S6]B07]B@P80U7=J00D0]IAk0<JUU02mW8`0YHak0=Jm
[@020=Jm]@040=Jm[@3Na[D0imK60>O>aP80e[f]00D0aYb40;FDN`2eU7/0YHAc09AcH`0209AcFP05
09A[DP1cDT80Q58i09AcFP2LNf<00P2mU7/00`2UNf<0]IAk0?Ogm`030?Ogm`030?O_m`3gmoL0moOg
03@00000:03oool_000000<0gYac103FW7/30>NmW0@0gZEk0`3N[H@20>N]S0L0ikFD1@3_]I@20>Nm
U0`0kkfL1@3W_I`20>NeU080gZfD0`1B8A0207/i62d000007P3oool001`0oooo;P00000208a[DP<0
YHA[00<0U6]B0:F4J`24DST00`24FT80102LJdX0U6]B09acDP24DST20:EkJ`0509acDP2eS7<0YG]S
0;F4J`2eU7/00P2DJe8208aJ@P80W7=B0`2eQ6<20;f<H`80eZF40P36YI@01@2UNf<0W7][09akJ`2<
FT80Ld8Y0080Q58i00@0YG]S0:F4J`2LNf<0_IAk0P3oool30?Ogm`80oooo0`3gmoL_000002P0oooo
;@0000020<Ik@PL0cYA[1@3N[H`20<jDJ`<0gZF40P3W[H`20>NmU0<0gZf40P3W[H`30>neU080ikfD
0P3_]I`50>NmW0L0kkfL0P3W_I`30>o6Y@80ikfD0P1kBRT306/a6080S4XY0`2eJcTZ000001h0oooo
000L0?ooobh000000P2<Je830:F4J`0309A[DP2UQ6/0Q58i00<0Q5Y200@0W6]:09A[DP2LLe80Q58i
0P2UNf/01@2LLe80]Hac0:EkH`2eQ6/0]IAk0080U6]B0P2<FT8209acDP<0]HAS0P2mS6<20=JUQ080
aZFD00D0YG]S09akJ`2LNf/0S5Y207=2:@0208AB>@040:EkH`2UQ6/0W7]S0;fDN`80oooo0`3gmoL2
0?ooo`<0moOg;`00000X0?ooobd000000P36Nd830;E[DP80cXaS0P3FW7<30<j<H`80ikfD0P3FW7<3
0=jLN`80gZf40P3W[H`30>neU080ikfD0`3W]I@20>nmW0D0kkFD0P3__I`20>NmU0<0kkfL0P3_]I@2
0>NmW0<0klJU0P3W_I`206<Y40<0Q48Q0P2<BRT30:e[>BX000007P3oool001`0oooo:P0000020=Je
Y@040:F4J`2DJe80YG]J0;F<L`<0U7=J00@0YG]S08a[DP2<HdX0W7=S0P2DLeX0102<Je80U6]B0:Ek
H`2DLeX208aSBP040:EkFP2LLe80S6]B08aSBP<0LdXa00@0Q6=:08AB>@24DST0S5Y20P24DS401@2L
JdX0Q58a08AB<@2DFS40W6]:0080[G=B00D0YG]S0;f<H`36W8@0g/Je0;FDN`020;fLS00409akJ`1c
BS40U7=J0:F4J`<0]IAk1`3gmoL00`3oool0moOg0?O_m`0/000002P0oooo:P0000030;E[>@80aW]2
0`2<FT820;EkFP80aXaS0`36Q6<20=j]U080cXaS0`3FW7<20=j]S0L0gZf41@3W]I@20>NmU0L0kkFD
0`3__I`20>neU0D0ikfL0P3W]I@204XH20<0U58Y0P2<BRT309aS>@80[F]2:000000N0?ooo`00703o
oolZ00000080e[FU00@0YHA[09A[DP2UNeX0]Hac0`2DLeX0102UNf<0S6]B08aSBP2LLf<209AcFP04
08a[DP2DJe80YG]S09AcFP80S6=:00@0YG]J09acDP2<Je80S6=:0`1cBS401024HdX0Q58i08AB>@2<
FT8208AB<@0509a[BP24DS40Q58a09AJ<@2LJdX00P2]Le801@2UNf<0_HaS0<JLQ03Na[D0]IAk0080
_Ib<00@0W7][07=:<@2DLeX0YHA[0`2eU7/70?Ogm`030?ooo`3gmoL0mnog02`00000:03ooolX0000
0080[F/i0`36Nd820<j<FP<0W6]:0P2LHcT20<J4FP<0aXAS0P3>U6/20<jDH`<0aXA[0P3FW7/20=jU
Q0<0ijf<0P3N[H`30=j]Q0@0ijf<0`3_]I@20>N]S080ikfD0`3_]I@20>NmW080kkfL0`3W_JD20>Ne
W080Jc4H0`2<BRT209AB:@<0S4XY0P2eJd820;f<HbH000007P3oool001`0oooo9`0000000`2eU7/0
e[FU0=JeY@020<J]W0040:EkFP2eS7<0YG]S0:EkH`80]HAS00D0YG]J09AcFP2UQ6/0YHA[09AcFP02
0:EkH`0409AcFP2UNf<0Q5Y20:EkFP80W6]:00D0U6]B07=B@P1cBS40YG]J07=B@P0207]J@P0308AJ
@P1kFT80Q58a00<0LdXa00<0JcTQ05Xi:@1c@RT00P1c@RT208AB<@0509a[BP24FT80S6=:0:F4J`36
W8@00P2mU7/0103W_JD0c[FU0;fLS02US7<209A[DP030<JLQ02DJe80knOW0080oooo0P3gkoL80?Og
mbP00000:03ooolX00000080aW]:0`36Q5X20<IkBP<0[F/i0P2eLdX20;EkFP<0aW]:0P2eNeX20=JL
N`<0cXaJ0P3FW7<20=jUN`D0gZF41@3W[H`20=j]Q0L0ijf<0`3_]I@20>N]S080kkfL0`3N[I@20>Ne
W080HbT@0`1[<AP20:e[>@<0U5Xa0P2]Jd820<J4FRH000007P3oool001`0oooo9`0000000`2eU7/0
e[FU0=JeY@020<J]W0040:EkFP2eS7<0YG]S0:EkH`80]HAS00D0YG]J09AcFP2UQ6/0YHA[09AcFP02
0:EkH`0409AcFP2UNf<0Q5Y20:EkFP80W6]:00D0U6]B07=B@P1cBS40YG]J07=B@P0207]J@P0308AJ
@P1kFT80Q58a00<0LdXa00<0JcTQ05Xi:@1c@RT00P1c@RT208AB<@0509a[BP24FT80S6=:0:F4J`36
W8@00P2mU7/0103W_JD0c[FU0;fLS02US7<209A[DP030<JLQ02DJe80knOW0080oooo0P3gkoL80?Og
mbP00000:03ooolV00000080]G=:0P36NdX50<j<FP<0W6<i0P2LJdX209AJ<@<0[F]20P2eJe820<j<
H`<0aXAJ0P3FW7<50=JLN`80gZEk0`3N[H`20=jUQ0T0gZf40`3_]I@20>NmU080ikFD1@3W_I`506<Y
4080U58Y0`2<BRT20:e[@P80_HaS0`3FW7<S000001h0oooo000L0?ooobL0000000<0]IAk0=JeY@3F
]JD00P36[I`0102UNeX0]Hac0:EkH`2UNf<20;F4H`050:EkFP2DLeX0YHA[0:F4J`2DLeX00P2UNf<0
102DLeX0YG]S08AJ@P2UNeX209a[BP0509A[DP1cDT80LdXa0:EkFP1cDT800P1kFT800`24FT80NeY2
08AB<@0307=:<@0306/i8@1J>BT0Ld8Y0080Ld8Y0P24DS401@2LJdX0Q5Y208aSBP2UQ6/0aYb40080
_IAk00@0ikfU0<jeY@2mW8`0YHac0P2DJe800`36W8@0U6]B0>oWi`020?ooo`80mnog203gmoLX0000
02P0oooo9P0000020;EcBP80aW]:1@3>S5X309aS>@80W6]:0P2DFS430:e[@P80]F]B0P3>S6<30<J4
FP80eYac1@3FW7/20=jUN`<0gZf<0P3NYH@90=j]Q0<0kkFD0P3W_I@20>NeU0D0ikfL1@1S:A0209AB
:@<0S4XY0P2]Jd820;f<H`<0eYac8`00000N0?ooo`00703ooolU000000050:F4J`36YI`0c[FU0=j]
W03F]JD00P36YI@20;fDN`090;F<L`2mU7/0_IAk0;fDN`2eS7<0YHA[0:F<L`2eS7<0YG]S00<0]HAS
00<0S6=:0<JDJ`2UNeX00P2<HdX0102mU7/0S6=:08AJ@P2UNf<308aSBP0409A[DP24FT80S5Y208AB
<@80Ld8Y0P24DST00`2LHcT0Q58i07]J@P0209AS@P0508aJ@P24DST0Q4Xa08aJ@P2LLe800`2eQ6<0
0`36W8@0_IAk0>NmW0020=JeY@040:F4J`2UNeX0_Ib<0:F4J`H0moOg00D0mnog0?Ogm`3gmoL0moOg
0?O_m`020?OgmbH00000:03ooolS000000<0]F]20P2eLdX50<J4FP80aW]20`2LHcT209AJ<@80[F]2
0`2]Hd820:e[@PD0aXAJ0P3>S6<70=JLL`<0gZEk0P3NW7/20=jUN`<0gYac0P3NYH@20=j]Q0<0ijf<
0P3W_I@50>NeU080gZfL0P1[<AP306/i8@D0W4Xa0P2LJdX20<J4FP<0eYac0P3gknLQ000001h0oooo
000L0?ooobD0000000D0YHA[0<JUW03>]JD0gZfL0=JeY@020<JUU080_IAk00T0]Hac0;fDN`2mU7/0
_IAk0;F<L`2UQ6/0YHac0;F<L`2UNf<00`2eQ6<00`2<HdX0aYA[0:EkFP0208aSBP040;fDN`2<HdX0
Q5Y20:EkH`<0S6=:00@0U6]B08AJ@P2<FT80Q58a0P1c@RT208AB>@0309aS>@24DST0NeY20080U6=2
00D0S5Y208AB>@24BS40S5Y209acDP030;F4H`030<JLQ02mU7/0ikfL0080e[FU00@0YHA[0:EkFP2m
W8`0YHA[1P3gmoL01@3gkoL0moOg0?Ogm`3gmoL0mnog0080moOg9P00000X0?ooob<000000`2eLdX2
0:e[>@80gZf40`3NYG<20<Ik@P<0]F/i102LHcT30:e[@P80W6<i0P2]Jd830;f<H`80cXaS1@3>U6/5
0=JLL`@0cYA[0`3NW7/40=jUN`<0gZF40P3W[H`20>NeU0D0gZfD0P1[>B4306<Y4080U5Xa0`2LHcT2
0;EcBP80]G]J0`3FW7<20>OFaR4000007P3oool001`0oooo8@0000000`2DJe80YHA[0;F<L`020;F<
L`040;fLS03N[I`0e[FU0=j]U080cZfD00<0eZF<0=J]S036W8@00`36W8@01@2eS7<0_IAk0;F<L`2m
U7/0]Hac0080_IAk00@0]HA[0;fDN`2UNeX0W7=B0P2UNf/01@2DHd80YHA[0:EkFP2eS7<0W7=B0080
YG]S00@0YG]J0:EkH`36U6/0S6=:0`2LLe80102eQ6/0YG]J09A[DP2DJe8208AJ@P0407]J@P1cBS40
Le9208aSBP<0Q58i0P1kFT802@2DHd80]G=:0<JDJ`36U6/0eZf40>O6[@2mW8`0eZf<0;F4H`0@0?Og
mb800000:03ooolQ00000080cYA[0`36Q5X20;f<H`80cYA[0`3>U6<50<Ik@P80S4XY0P1k@R450:e[
@P80W6<i1@36Q5X20<J4H`<0cYA[0P3FW7<50<jDJ`80eYac0`3NW7<20=JLN`D0gZEk0P3NYH@20>N]
S0<0ikFL0P3N[I@206/a60<0DRTH0P24@R430:e[>@80W6]:0P2eLdX30<JDJ`80ikfU0P3gknLO0000
01h0oooo000L0?ooob40000000<0U6]B0:F4J`2eS7<00P2eS7<0102mW8`0gZfL0=JeY@3N[I@20<j]
U0030=JUS03F[H`0aYb400<0aYb400D0]Hac0;fDN`2eS7<0_IAk0;F<L`020;fDN`040;F4J`2mU7/0
YG]J09acDP80YG][00D0U6=20:F4J`2UNeX0]Hac09acDP020:EkH`040:EkFP2UNf<0aYA[08aSBP<0
W7=B00@0]HA[0:EkFP2DJe80U6]B0P24FT80101kFT80LdXa07=B@P2<HdX308AB>@80NeY200T0U6=2
0;EcBP36U6/0aYA[0=J]Q03WaZd0_Ib<0=J]S02eQ6<0403gmoLR000002P0oooo8@0000020<jDJ`<0
cYAS0P2mS6<20=JLN`<0cYAS0P2eJd830;ES<@80[F<a0P1k@R4309AJ<@80W6]:0P2<BRT30<j<FP@0
aXAJ203>U6/20<J4J`80cXaS1@3>U6/20=jLL`<0gZF41`3N[H`20=j]U080NcTH0`1[>B4207/i60<0
W6<i0P2DFS420:e[@P<0_HaS0P3F]JD20?O_mal000007P3oool001`0oooo7`000000101kFT80W7=B
0:EkFP2<HdX20;F<L`030<JLQ03F_Jd0ilJe0080ilJe0`3W_JD00`3F]JD0gZfL0=JUQ0020<j]U080
eZF<00<0eZF40=JUS03FYH@00P3FYH@20<JDJ`80]Hac0P2eQ6/01@2eS7<0]HA[0:ecDP2eQ6/0]HAS
0080W7=B00@0W6]:0;F4J`2LLe80]HAS0P2LLe801@2]Le80YG]S0:EkFP2UNf<0S6=:0080U6]B00D0
U7=J0:ecDP2DLeX0W7=B09AcFP0209acDP0408AB>@24FT80S6]B09a[BP80W7=B0P2UNeX00`36U6/0
e[FU0=JeY@020<JLQ0@0moOg0P3gkoL:0?Ogmb000000:03ooolO00000080eZf40P2mS6<30<J<H`80
aYA[0P3F[H@30<jDH`D0aW]20P2]FS4207]::@<0Nd8Q0P2]Jd8207]::@<0aXAJ0P2eJe820;EkFP<0
aXAJ0P3>S6<50<J4FP80aW]J0`36Q5X20=JLN`80gZF40`3WYI@40>N]U0<0ikfU0P3N[H`706/i8@<0
U5Xa0P2LHcT209a[BP<0]G]J0P3F[H`20>o_i`<0knog7000000N0?ooo`00703ooolO0000000407]J
@P2LLe80YG]J08aSBP80]Hac00<0aYb40=Jm[@3Wa[D00P3Wa[D30>NmY@030=JeY@3N[I`0eZF40080
cZfD0P3FYH`00`3FYH@0eZF<0=JUQ0020=JUQ080aYA[0P2eS7<20;F4J`050;F<L`2eQ6/0[G=B0;F4
J`2eQ6<00P2LLe80102LJdX0]HA[09acDP2eQ6<209acDP050:ecDP2UNf<0YG]J0:EkH`2<HdX00P2D
Je801@2DLeX0[G=B09AcFP2LLe80U7=J0080W7=B00@0Q58i08AJ@P2<Je80W6]:0P2LLe820:EkFP03
0<JDJ`3F]JD0e[FU0080aYb4103gmoL20?O_m`X0moOg8000000X0?oooal000000P3F[H@20;f<H`<0
aXaS0P36U6/20=J]Q0<0cYAS1@36Nd820:eJ<@80NdXY0`1k@R420:e[@P80NdXY0`36Q5X20;E[DP80
]G]J0`36Q5X20<j<H`D0aXAJ0P36NeX30<J4FP80eYak0P3NYH@30>NUU0@0ijfD0`3W_JD20=j]S0L0
JcTQ0`2DFS4209aS>@80W6]:0`2eNeX20=J]S080knoW0`3_koLL000001h0oooo000L0?oooal00000
00@0NeY209acDP2UNeX0S6=:0P2eS7<00`36W8@0e[f]0>O6]@020>O6]@<0ikfU00<0e[FU0=j]W03F
YH@00P3>[I@20=JUS0030=JUQ03FYH`0eZF40080eZF40P36U6/20;F<L`80]HA[00D0]Hac0;F4J`2]
Le80]HA[0;F4H`0209acDP0409a[BP2eQ6/0W7=B0;F4H`80W7=B00D0[G=B0:EkH`2UNeX0YG]S08aS
BP0209A[DP0509AcFP2]Le80U7=J09acDP2DLeX00P2LLe801024DST0Q5Y208a[DP2LJdX209acDP80
YG]J00<0aYA[0=JeY@3F]JD00P36W8@40?Ogm`80mnog2P3gmoLP000002P0oooo7`0000020=J]Q080
]F]20`36U6/20=J]Q080gZf40`3>S5X20:e[>@<0aW]20P2LHcT20:eS<@<0Jc4H0P2<FT8208a:<@<0
aW]:0P2]Jd820<IkBP<0aW]J1@2eNeX40<IkFP<0eYak0P3N[H`20>N]U0D0kkFL0P3_aZD30>o6[@80
ilJ]0P24DS4306/i8@80Ld8Y0`2DFS420;EcBP80[F]20`2eNeX20=J]Q080knON0`3_koLL000001h0
oooo000L0?oooad000000P2DJe80102<HdX0W7=B0:EkH`2mU7/20=JUS0030>NmW03N[I`0e[FU0080
ikFL1@3_aZd00`3WaZd0ikfU0>NmY@030>NmY@040>NeW03N[I`0gZf<0=j]S080gZfD0P3FYH@40=JL
N`030=JLL`3NW7/0eYak00<0eYac00<0_IAk0<jDJ`3>U6/00`3>U6/01036Q6/0]Hac0;fDN`2eS7<2
0;F4J`050;EkFP2LJdX0S6=:09AcFP2DJe800P1cFTX209A[DP0307=:<@2<HdX0W6]:0080W6]:00@0
W7=B09a[BP2mS6<0]HAS0P3N[I@00`3W_I`0mnoW0?Ogm`0>0?Ogmal00000:03ooolO00000080eYac
0P2mS6<30<JDJ`80eZf40P3N[H@30<J4FP80[F/i0`36NdX209aS>@80]F/i0`1[<AP208A28@80W6<i
0`2eLdX20:e[@PD0]G]J0P36NeX30<IkBP80]G=:0P3>U6/30=jUQ080ijfD0P3_]I`30>o6[@80mlJe
0P3_aZd30?O6]@80klJe0P2eQ6<306/i8@80Nd8Q0`24@R4409AJ<@<0]G]J0P3FW7<20>O>_@<0mnog
7000000N0?ooo`00703ooolM00000080U6]B00@0S6=:09acDP2UNf<0_IAk0P3FYH`00`3W_I`0gZfL
0=JeY@020>NeW0D0klJ]00<0ilJ]0>NmY@3W_JD00`3W_JD0103W]I`0gZfL0=j]S03N[H`20=j]U080
eZF4103FW7/00`3FW7<0gYak0=JLN`030=JLL`030;fDN`3>U6/0cYA[00<0cYA[00@0aXA[0;F<L`2m
U7/0]Hac0P2eQ6/01@2eNeX0W6]:08aSBP2DLeX0U6]B0080LeY:0P2DJe800`1cBS40S6=:09a[BP02
09a[BP0409acDP2LJdX0_HaS0;F4H`80gZfD00<0ikfL0?O_i`3gmoL03P3gmoLO000002P0oooo7000
00030=J]S080aXaS0P2mS6<30;E[@P80ikfU0P3N[H@30<J4FP80_HaS0`3>S5X209AB:@80[F/i0`1B
8A0207/i6080U5Xa0`24@R4209a[BPX0]G=:0P3>U6/20=jUN`<0ijf<0P3_]I`50>o6[@80mlje1`3g
e[d20>o6]@<0JcTQ0P1kBRT306<Y4080U5Xa0P2]Jd830:ecDP80aYA[0P3Wc[d30?O_m`80knog6P00
000N0?ooo`00703ooolK0000000808AB<@1kFT80S5Y208aJ@P2LLe80]HAS0;fDN`36W8@20=JeY@04
0>NeW03W_JD0klJU0>neW0<0mlJe0P3_c[D0103_a[D0klJ]0?O6]@3ga[D20?O>]@030?OF_@3_a[D0
klje00<0klJ]00<0klJU0>neW03W]I`00P3W]I`01@3_]I@0klJU0>o6Y@3__I`0kkFL0080kkfL00@0
kkFD0>NeW03W]I`0gZf<0P3W[I@0103N[I@0eZF<0=JUS03FW7/30;fDN`050;F<L`2eQ6/0[G=B0:Ek
FP2LJdX00`1cDT8207=:<@0805Y2>@1c@RT0Ld8Y05Xa8@2UQ6/0U6]B09acDP2LJdX20=JLN`030<JD
J`3W_I`0moOg00<0moOg00@0mnog0?Ogm`3gmoL0oooo2P3gmoLL000002P0oooo700000030=J]S080
aYA[0P2mS6<30<J<H`80ikfU0P3FW7<50<J4FP<0aW]:0P2<@R4208A28@<0LdXa0P2LHcT208A28@<0
Nd8Q0P2LHcT70:e[@P<0]F]B0P3FW7/20>N]S0<0gZfD103_aZD30?O>]@80mlJe1@3_e/H20?OF_@80
klj]0`3Wa[D207]::@<0HbT@0P2DFS4209aS>@<0W6]:0P36U6/20>O6[@<0knOW0P3gmoLJ000001h0
oooo000L0?oooa/0000000P0Q58a07]J@P2<FT80S5Y209acDP2eQ6<0_IAk0<JLQ080e[FU00@0ikFL
0>NmY@3_aZD0kkFL0`3ga[D20>o>]@040>o6]@3_aZd0mlJe0?O6]@80mlje00<0mmJm0>o6]@3_c[D0
0`3_aZd00`3_aZD0kkFL0>NeW0020>NeW0050>neU03_aZD0klJU0>nmW03_]I`00P3__I`0103_]I@0
ikFL0>NeW03N[H`20>N]U0040=j]U03FYH`0eZF<0=JLN`<0_IAk00D0]Hac0;F4J`2]Le80YG]J09a[
BP0307=B@P80LdXa00P0FT8i07=2:@1c@RT0FS4Q0:F4J`2DJe80W7=B09a[BP80eYak00<0aYA[0>Nm
W03gmoL00`3gmoL0103gkoL0moOg0?Ogm`3oool:0?Ogma`00000:03ooolL000000<0ikfD0P36U6/5
0;f<H`80ikfL0P3FW7<30;f<H`80[F]20`36NdX20<J4FP80W6<i0`1B8A020;EcBP80[G=B0`1c@RT2
09a:<@80[F=20`2]Jd820:eS@P<0aXA[0P3NYH@20>N]S0<0ikfL0P3W_JD20>o6[@<0mlJe1`3ge[d2
0?O>]@80klJ]0`3_c[D206/i8@<0Jc4H0P2DFS4209aS>@<0[F]20P2mS6<20=Jm[@<0knOW0P3gkoLJ
000001h0oooo000L0?oooaX0000000<0Q5Y20:EkFP1kFT800`2UNeX00`2mS6<0aYb40=j]U0020>Nm
W0040>O6[@3_aZd0klJU0>o6[@<0mlje00@0mmJm0?O>]@3_c[d0mmJm0P3gc[D50?OF_@<0mlje00<0
mmJm0?O>]@3_aZd00P3gc[D01@3_aZd0mlje0>o6[@3_aZd0klJU00<0klJ]0P3_aZD00`3W_I`0kkfL
0>nmW0020>NeU0030=j]W03N[H`0cZfD0080_IAk00D0eYak0<jDJ`2eQ6/0YG]S09acDP0209a[BP04
08AJ@P1cBS40Le9209A[DP80@R4H00D0>AP@03TQ601kFT80Q58i0:EkFP0209a[BP040:ecDP36U6/0
ikfU0?O_m`80moOg00<0mnog0?ooo`3gmoL0303gmoLK000002P0oooo6P0000020>NmU0<0eZf40P36
W8@50;f<H`80ikfU0P3F[H@30<JDJ`80_HaS0`36Nd820;f<H`80[F<a0`2]Jd820<jDJ`80eYak0`1S
:A0208A::@80U5Y20`2]Hd820<J4J`<0eYak0P3N[H`20>NeU0<0ikFL0P3_aZd20>o6Y@<0mlJe0P3g
e[d50?O6]@@0mlje0`3_a[D208aJ@P<0JcTQ102DFS4309a[BP80_HaS0P3>[I@30>ONeP80knog0P3_
knLH000001h0oooo000L0?oooaX0000000<0Q5Y20:EkFP1kFT800`2UNeX00`2mS6<0aYb40=j]U002
0>NmW0040>O6[@3_aZd0klJU0>o6[@<0mlje00@0mmJm0?O>]@3_c[d0mmJm0P3gc[D50?OF_@<0mlje
00<0mmJm0?O>]@3_aZd00P3gc[D01@3_aZd0mlje0>o6[@3_aZd0klJU00<0klJ]0P3_aZD00`3W_I`0
kkfL0>nmW0020>NeU0030=j]W03N[H`0cZfD0080_IAk00D0eYak0<jDJ`2eQ6/0YG]S09acDP0209a[
BP0408AJ@P1cBS40Le9209A[DP80@R4H00D0>AP@03TQ601kFT80Q58i0:EkFP0209a[BP040:ecDP36
U6/0ikfU0?O_m`80moOg00<0mnog0?ooo`3gmoL0303gmoLK000002P0oooo6P0000020>NmU0<0eZf4
0P36W8@50;f<H`80ikfU0P3F[H@30<JDJ`80_HaS0`36Nd820;f<H`80[F<a0`2]Jd820<jDJ`80eYak
0`1S:A0208A::@80U5Y20`2]Hd820<J4J`<0eYak0P3N[H`20>NeU0<0ikFL0P3_aZd20>o6Y@<0mlJe
0P3ge[d50?O6]@@0mlje0`3_a[D208aJ@P<0JcTQ102DFS4309a[BP80_HaS0P3>[I@30>ONeP80knog
0P3_knLH000001h0oooo000L0?oooaX0000000<0Q5Y20:EkFP1kFT800`2UNeX00`2mS6<0aYb40=j]
U0020>NmW0040>O6[@3_aZd0klJU0>o6[@<0mlje00@0mmJm0?O>]@3_c[d0mmJm0P3gc[D50?OF_@<0
mlje00<0mmJm0?O>]@3_aZd00P3gc[D01@3_aZd0mlje0>o6[@3_aZd0klJU00<0klJ]0P3_aZD00`3W
_I`0kkfL0>nmW0020>NeU0030=j]W03N[H`0cZfD0080_IAk00D0eYak0<jDJ`2eQ6/0YG]S09acDP02
09a[BP0408AJ@P1cBS40Le9209A[DP80@R4H00D0>AP@03TQ601kFT80Q58i0:EkFP0209a[BP040:ec
DP36U6/0ikfU0?O_m`80moOg00<0mnog0?ooo`3gmoL0303gmoLK000002P0oooo6P0000020>OFcP<0
eZf40P36W8@20;E[@P<0ikfD0P3>[I@20=JLL`D0_HaS0`2]JcT20;E[@P80U5Xa0`2<@R4209a[BP80
_HaS0`1[>B4208a::@D0W6<i0P3>U6/30=jUQ080gZfD0P3N[H`30>NeW080ikfL0P3W_JD30>neW0L0
klJ]0P3ga[D20?O>]@<0klj]0P3_a[D308A::@80JcTQ0P2DFS4309AS@P80[G=B0P36W8@30>O>_@80
knOW0P3gmoLH000001h0oooo000L0?oooaP0000000D0U7=J09A[DP24FT80S6=:08ASBP0208aSBP04
0:ecDP2mU7/0aYb40=j]U080klJU0P3_aZd20?O>]@<0mmJm00<0mlje0>oFaP3_e/H01`3ge[d00`3_
e/H0mmJm0?OF_@040?OF_@@0mlje00<0mmJm0?O>]@3_aZd0103_aZd0103_aZD0klJ]0>nmW03__I`3
0>NeW0050>NeU03N[H`0eYak0=JLN`3FYH`00P2mU7/01`2mS6<0[G=B09AJ@P2DFT80Q58i08AJ@P1c
@RT00`1J>BT01@12:B40DRTH024H600Q40P0YG]J0080YG]S00@0U6=20;EkFP36S6<0iljm4`3gmoLI
000002P0oooo6P0000020?O_i`<0cZfD1036U6/30>O6]@80eZf40P36U6/30;EkFP80[F/i0`36Nd82
0:e[>@80]G]J0`3FW7<20;f<H`80U6=20`1[>B4208A:<@80U5Xa0`3>S6<20=JLN`<0gZF40P3N[H`2
0>NeW0<0ikFD103N[H`30=jUQ080gZf<0P3W[I@30>NeW0@0klJ]0`3_cZd20>o6]@<0Jc4H0P1[>B45
09AJ<@80[G=B0P2mU7/30>O>_@80knOW0P3gmoLH000001h0oooo000L0?oooaP0000000D0U7=J09A[
DP24FT80S6=:08ASBP0208aSBP040:ecDP2mU7/0aYb40=j]U080klJU0P3_aZd20?O>]@<0mmJm00<0
mlje0>oFaP3_e/H01`3ge[d00`3_e/H0mmJm0?OF_@040?OF_@@0mlje00<0mmJm0?O>]@3_aZd0103_
aZd0103_aZD0klJ]0>nmW03__I`30>NeW0050>NeU03N[H`0eYak0=JLN`3FYH`00P2mU7/01`2mS6<0
[G=B09AJ@P2DFT80Q58i08AJ@P1c@RT00`1J>BT01@12:B40DRTH024H600Q40P0YG]J0080YG]S00@0
U6=20;EkFP36S6<0iljm4`3gmoLI000002P0oooo600000020?O_i`80knON0`3F[H`20<JLQ080eYac
0`3WaZd20=JLL`80aYA[0`2eNeX20;EcBP<0cXaJ0P2LHcT20<jDH`<0eZF40P2]Le8208aSBP<0DRTH
0P1kBRT208aJ@P<0cYA[0P3FW7/30=jUQ080gZfD0P3W]I@70=jUQ0D0ihak0P3NW7/30>N]S080ikfU
0P3_aZd30>o>[@80klje0`3Wa[D206/i8@80Q58a0`2<BS420;EcBP80aYA[0`3Nc[d20>oWi`80mnog
0`3gmoLE000001h0oooo000L0?oooaH000000P1cDT801@24FT80NeY207=B@P1kFT80Q5Y20080U6]B
00<0W7=B0<JDJ`3F[H`00`3W_JD00`3_aZd0mlje0?O>]@040?OF_@80kmK60P3gg/h20>oFaP80mmJm
1@3_e/H20?OF_@030>oFaP3ge[d0mmJm00<0mmJm0`3gc[D30>o>[@030>o6[@3_aZD0klJU0080klJ]
00@0ikfU0>NmW03W]I@0ijfD0`3N[H`20=jUQ0030<jDJ`2eS7<0]HA[0080[G=B00<0W6]:08aJ@P1c
BS400`1J>BT01@1B:AP0@R4H058Y600i6100:A080080U6]B00@0W7=B09a[BP2mS6<0gZf<0P3_knLB
0?OgmaP00000:03ooolH00000080knoW0P3We/h30>NmU080aYA[0P36W8@30>NmU080gZf40P3FW7<3
0;EcBP80_HaS0`2eLdX20<JDJ`80cYAS0`36Q6/20=JLN`80Q58i0`1B8A0206/i8@80aXAJ0`3>U6/2
0=JLN`<0gZf<103W]I@30=j]S0@0cV]J1`3NQ7<30=ikJ`80gW=S0P3_aZD50>o6[@<0klJe0P1k>AP2
06/i8@<0Q58i0P2LHcT20;EkFP<0g/k60P3We/h20?O_m`<0mnoW5@00000N0?ooo`00703ooolF0000
0080Le9200D0Q5Y207]J@P1cDT80NeY208AJ@P0209A[DP0309acDP36U6/0eZf<00<0ikfU00<0klJ]
0?O>]@3gc[D0103ge[d20>oFaP80mmk>0P3_e/H20?OF_@D0kmK60P3ge[d00`3_e/H0mmJm0?OF_@03
0?OF_@<0mlje0`3_cZd00`3_aZd0klJU0>o6Y@020>o6[@040>NmY@3W_I`0ikFD0>N]U0<0gZf<0P3N
YH@00`3>U6/0]Hac0;F4J`020:ecDP0309a[BP2<FT80LdXa00<0FSTY00D0DRTH048Q601B:AP0>AP@
02T@200209A[DP0409acDP2LJdX0_HaS0=j]S080knoW4P3gmoLH000002P0oooo600000020>o_i`80
knON0`3>[I@20<JDJ`80_IAk0`3W_JD20=JLN`80aYA[0`2eNeX20:eS<@<0aXAJ0P3F[H@20;EkFP<0
W6<i0P3FYH@208AB>@<0DRTH0P1cBS420<J4H`<0cYA[0P3FYH@30=j]S080ikFL0P3N[I@30=JLN`80
cW=S0P3NNf/30=j4L`80ijFD0P3WS7/30>o6]@80gXAc0P3WS7/30>o>[@80klJ]0`3_a[D207]::@80
Ld8Y0`1kBRT209aS>@80YG]J0`3F[H`20>ONePD0moOg5@00000N0?ooo`00703ooolF00000080Le92
00D0Q5Y207]J@P1cDT80NeY208AJ@P0209A[DP0309acDP36U6/0eZf<00<0ikfU00<0klJ]0?O>]@3g
c[D0103ge[d20>oFaP80mmk>0P3_e/H20?OF_@D0kmK60P3ge[d00`3_e/H0mmJm0?OF_@030?OF_@<0
mlje0`3_cZd00`3_aZd0klJU0>o6Y@020>o6[@040>NmY@3W_I`0ikFD0>N]U0<0gZf<0P3NYH@00`3>
U6/0]Hac0;F4J`020:ecDP0309a[BP2<FT80LdXa00<0FSTY00D0DRTH048Q601B:AP0>AP@02T@2002
09A[DP0409acDP2LJdX0_HaS0=j]S080knoW4P3gmoLH000002P0oooo600000020>o_i`80knON0`3>
[I@20<JDJ`80_IAk0`3W_JD20=JLN`80aYA[0`2eNeX20:eS<@<0aXAJ0P3F[H@20;EkFP<0W6<i0P3F
YH@208AB>@<0DRTH0P1cBS420<J4H`<0cYA[0P3FYH@30=j]S080ikFL0P3N[I@30=JLN`80cW=S0P3N
Nf/30=j4L`80ijFD0P3WS7/30>o6]@80gXAc0P3WS7/30>o>[@80klJ]0`3_a[D207]::@80Ld8Y0`1k
BRT209aS>@80YG]J0`3F[H`20>ONePD0moOg5@00000N0?ooo`00703ooolE000000<0Q58i00D0Q58a
08AB>@24DST0Le9208AB>@0209a[BP040:EkH`2eS7<0aYb40=j]W080ikfU00@0klJ]0?O>]@3gc[D0
mmJm0`3_e/H00`3gg/h0kmK60?ONcP050?ONcP030>oFaP3gg/h0mmJm0080kmK600@0mmk>0>oFaP3g
e[d0kmK61@3ge[d01P3gc[D0mmJm0?O>]@3gc[D0mlJe0>o>[@80klJ]0`3_aZD20>NeW0060=j]W03N
[H`0gZf<0=j]S03FYH@0eZF<0P3>U6/01`2mS6<0YG]S0:EkH`2UNeX0W7=B08aJ@P1J>BT00P1J<B40
0`128AP0@RTQ034H6002048Q6080YG]S00@0]HA[08aJ@P2]Le80aYA[0P3W_I`20?Ogm`030?O_m`3g
moL0moOg00l0moOg5P00000X0?oooaP00000103_inL30<j]U0@0aYb40`3W_JD20=JLL`80cYAS0`2]
Jd820<J4FP<0_HaS0P3N[H@20=J]Q0<0]G]J0P2eQ6<206/a60<0JcTQ0P2]Le820<jDJ`<0eYak0P3F
YH@50>NeU080ijfD0`36FTX20<icH`80aV=:0`36FTX20<i[FPD0gW=S0P3NQ7<20=ikJ`<0klJU0P3_
aZd30>o>]@80YHA[0P1[>B4509AJ<@80YG]J0`36U6/20=k>_@D0moOg5@00000N0?ooo`00703ooolE
000000<0Q58i00D0Q58a08AB>@24DST0Le9208AB>@0209a[BP040:EkH`2eS7<0aYb40=j]W080ikfU
00@0klJ]0?O>]@3gc[D0mmJm0`3_e/H00`3gg/h0kmK60?ONcP050?ONcP030>oFaP3gg/h0mmJm0080
kmK600@0mmk>0>oFaP3ge[d0kmK61@3ge[d01P3gc[D0mmJm0?O>]@3gc[D0mlJe0>o>[@80klJ]0`3_
aZD20>NeW0060=j]W03N[H`0gZf<0=j]S03FYH@0eZF<0P3>U6/01`2mS6<0YG]S0:EkH`2UNeX0W7=B
08aJ@P1J>BT00P1J<B400`128AP0@RTQ034H6002048Q6080YG]S00@0]HA[08aJ@P2]Le80aYA[0P3W
_I`20?Ogm`030?O_m`3gmoL0moOg00l0moOg5P00000X0?oooaD000001`3_knL30=JeY@80eZf40P3F
_Jd30>NmU080]G]J0P2mS6<30<J4FP80cYA[0`3_cZd20=JLN`D0eZF40P24FT8206/i8@<0BQP80P2e
NeX50=JLN`D0gZf<0P3W]I@20=j4L`<0Q48Y0P2]@S420:e:<@<0W34Q0P2eDST20;eB@P<0[G=B0P2]
BS420:ecDP<0ihak0P3_aZd30>o>]@80kljm1@1[<AP209AJ<@80U6=20`36U6/20=K6]@L0mnog4`00
000N0?ooo`00703ooolD00000080NeY20`24DST00`24DS40Q5Y208AB>@0308aSBP040:EkFP2eS7<0
aYb40=JUS080ikfL00D0klJ]0>o>]@3ge[d0mmJm0>oFaP020?OF_@80mmk>00T0mmJm0?ONcP3ge[d0
mmJm0?ONcP3ge[d0kmK60?OF_@3gg/h00P3ge[d20>oFaPD0mmJm00@0kmK60?OF_@3ge[d0mlJe0`3g
c[D30>o6[@80kkFL00@0klJU0>NeW03W]I`0gZfD103N[H`0103FYH@0aYb40=JLN`2eQ6/20:EkH`80
W7=B00D0W6]:07]J@P1[>B40JcTQ05Xa8@0203TH4003048Y8@0i6100U6]B0080U6]B00<0W7=B09aS
>@36U6/00P36W8@00`3FYH`0moOg0?Ogm`0B0?OgmaD00000:03ooolE000000<0mnog0P3_imh20>oW
i`<0imK60P3F[H@20>O6[@<0eZf40P2eNeX20;f<H`<0aXAJ0P2]Le830>NmW080]G]J0P2LJdX30=JL
N`80Q5Y20P0i610305Xi:@80aXAS0P3FW7<30=JLN`D0ijf<0P3W]I@20=j]S0<0eZF<0P3FW7<70<IS
BPL0cV]J0P3WS7/30>neW080klJ]0`3_c[D20>o>_@80Q48Y0`1kBRT208a::@80S4Xa0`2eNeX20=Jm
[@80knOW0`3gknL20?O_ma<000007P3oool001`0oooo5000000207]J@P<0Q58i00<0Q58a08AJ@P24
DST00`2<HdX0102UNeX0]Hac0<JLQ03FYH`20>NmW0050>o6[@3_c[D0mmJm0?OF_@3_e/H00P3ge[d2
0?ONcP090?OF_@3gg/h0mmJm0?OF_@3gg/h0mmJm0>oFaP3ge[d0mmk>0080mmJm0P3_e/H50?OF_@04
0>oFaP3ge[d0mmJm0?O6]@<0mlje0`3_aZd20>neW0040>o6Y@3W]I`0ikFL0=j]U0@0gZf<00@0eZF4
0<JLQ03FW7/0]HA[0P2UNf<209acDP0509a[BP1kFT80JcTQ06/i8@1J<B400P0i61000`12:B40>AP@
09A[DP0209A[DP0309acDP2LHcT0aYA[0080aYb400<0eZF<0?Ogm`3gmoL04P3gmoLE000002P0oooo
5@0000030?Ogm`@0knON0`3Wg]H20<JLQ080ilJ]1@3>U6/20;EcBP<0_HaS0P3FW7<30>NmW080[F]2
0P2LHcT309acDP80LdXa0P0Y40P308AB<@80cYA[0P3FW7<30=jUQ080gZf<0`3W[I@40>NeW0<0ikFD
103W_JD30>o6]@80mlje1@3_aZd20>oFaP80mlje203_cZd20>o6[@80Q58a0`1kBRT208A::@80S5Y2
0`2LJdX20=J]S080knON0`3_knL20?Ogma<000007P3oool001`0oooo4`0000000`1cDT80S5Y209A[
DP0209A[DP0508AJ@P2<HdX0Q58i07]J@P2DJe800P2<HdX0102LLe80]HA[0<JDJ`3FYH`20>NmY@04
0>o6[@3gc[D0mlje0?O>]@@0mmJm0P3gg/h00`3_e/H0mmJm0?OF_@020?ONcP030>oFaP3ge[d0mmk>
0080mmJm0P3_e/H00`3ge[d0kmK60?OF_@030?OF_@030?O>]@3ge[d0mlje0080mlje00<0klJ]0?O>
]@3_aZd00`3_aZD01@3W_JD0ikfL0>NmY@3W]I@0gZfD0080gZf<00D0eZF<0=JUQ02mU7/0cYA[0<J4
J`030;F4H`80W6]:00H0S5Y207=:<@1cBS40JcTQ058Q400i610202T@2080Ne9200@0S6=:0:EkFP2]
Le80aYb40P36U6/00`3F[H`0aYA[0?Ogm`0C0?Ogma@00000:03ooolE000000<0moOg0P3gknL20>ON
eP<0knON0P3F[H`20>O6[@<0cYA[0P2eNeX20<J<H`<0aXAJ0P3_aZD30=j]U080aXaS0P2LHcT309ac
DP80Q58a0P128AP309AJ@P80cYA[0P3NQ7<30=jUQ080gZf<0`3W[I@20>NmW080ikFL1@3W_I`50>Ne
W080klJ]0P3_aZD70?O>]@D0klJ]0`3ga[D20>o>]@80e[FU0`1kBRT206/a6080Q58a0`2DHd820<JL
Q080g/Je0`3gkoL20?O_ia<000007P3oool001`0oooo4`0000000`1cDT80S5Y209A[DP0209A[DP05
08AJ@P2<HdX0Q58i07]J@P2DJe800P2<HdX0102LLe80]HA[0<JDJ`3FYH`20>NmY@040>o6[@3gc[D0
mlje0?O>]@@0mmJm0P3gg/h00`3_e/H0mmJm0?OF_@020?ONcP030>oFaP3ge[d0mmk>0080mmJm0P3_
e/H00`3ge[d0kmK60?OF_@030?OF_@030?O>]@3ge[d0mlje0080mlje00<0klJ]0?O>]@3_aZd00`3_
aZD01@3W_JD0ikfL0>NmY@3W]I@0gZfD0080gZf<00D0eZF<0=JUQ02mU7/0cYA[0<J4J`030;F4H`80
W6]:00H0S5Y207=:<@1cBS40JcTQ058Q400i610202T@2080Ne9200@0S6=:0:EkFP2]Le80aYb40P36
U6/00`3F[H`0aYA[0?Ogm`0C0?Ogma@00000:03ooolE000000D0moOg0P3_imh30>OFcP80aYA[0P3W
_JD30=JLL`@0_HaS0`3FW7<20>NmU0<0cYA[0P2eNeX20:ecDP<0U6=20P1cDT8205Xi:@<0W6]:0P3>
U6/20=JLL`<0gYak0P3N[H`30>N]U080ikFL1@3_aZD20>NmY@80kkfL0`3W]I`20>o6Y@80klJ]1`3g
c[D30>o>]@80mlJe0`3gc[D20>o6]@80klje1@1kBRT208A:<@<0W6]:0P2eNeX20=k>aPD0mnog4`00
000N0?ooo`00703ooolC0000000307=B@P2<FT80U6]B0080U6]B00D0Q5Y208aSBP24DST0NeY209A[
DP0208aSBP0409acDP2eQ6/0aYA[0=JUS080ikfU00@0klJ]0?O>]@3gc[D0mlje103ge[d20?ONcP03
0>oFaP3ge[d0mmJm0080mmk>00<0kmK60?OF_@3gg/h00P3ge[d20>oFaP030?OF_@3_e/H0mmJm00<0
mmJm00<0mlje0?OF_@3gc[D00P3gc[D00`3_aZd0mlje0>o6[@030>o6Y@050>NmY@3W_I`0ikfU0>Ne
U03N[I@00P3N[H`01@3FYH`0eZF40;fDN`3>U6/0aXA[00<0]HAS0P2LJdX01P2<FT80LdXa07=:<@1[
>B40DR4@03TH4080:A080P1kDT80102<HdX0YG]J0:ecDP36W8@20<JDJ`030=J]S036U6/0moOg01<0
moOg5000000X0?oooaD000001@3gmoL20>oWgP<0imK>0P36U6/20>NmY@<0eYac102mS6<30=JLL`80
ikfD0`3>U6/20;EkFP80[G=B0`2DHd8207=B@P80FSTY0`2LJdX20<jDJ`80eYac0`3NW7/20=j]S0<0
ijfD0P3W]I`50>o6Y@80ikfU0P3__I`30>NeW080klJU0P3_aZd70?O>]@<0klje0P3ga[D30?O>]@80
klJe0P3_c[D507]::@80Q4Xa0`2LJdX20;EkFP80g/k61@3gkoLC000001h0oooo000L0?oooa<00000
0`24DST208ASBP0508aSBP24DST0Q5Y208AB>@24FT800P24DST0102UNeX0]G]J0<JDJ`3W]I`20>Nm
Y@030>o>[@3_c[d0mlje0080mmJm0`3_e/H60?ONcP80mmJm1P3gg/h60>oFaP030?O6]@3gc[D0mlje
0080mlje00@0klj]0>o6[@3_aZd0klJ]0P3_]I`01@3W_JD0ikfL0>NmY@3W]I`0gZf<0080gZfD00D0
gZF40=JUQ02mU7/0cYA[0<J4J`020;f<H`040;EkFP2]Le80W6]:08AB>@80LdXa00<0FSTY07=2:@12
8AP00P0i610205Xa8@0409acDP3FW7<0]HAS0=JLN`80]G]J00<0W7=B09AS@P3>[I@04`3gmoLD0000
02P0oooo4`0000050?Ogm`80mnog0P3_inL30>OFaP80_HaS0P3W_JD30=JLN`80aYA[0P36S6<30=J]
Q080gZEc0`2mU7/208aJ@P80]HAS0`2DJe8207=:<@80DR4@0`2eLdX20<J4J`80eYac0`3NYH@20>N]
S0<0ikFL0P3_aZD20>neW0<0klJU0P3_]I`20>NmW0<0ijf<103_aZD30?O>]@80klje2P3gc[D20>o6
]@80klje0`24BRT206/a6080JcTQ0`24BRT20;EcBP80e/Je0`3gknL20?O_m`80moOg4@00000N0?oo
o`00703ooolC000000<0Q58i0P24HdX01@2<HdX0Q58i08AJ@P24DST0Q5Y20080Q58i00@0YG]J0;Ek
FP36U6/0ikFL0P3W_JD00`3_cZd0kljm0?O>]@020?OF_@<0kmK61P3gg/h20?OF_@H0mmk>1P3_e/H0
0`3ga[D0mlje0?O>]@020?O>]@040>o>[@3_aZd0klJ]0>o6[@80kkFL00D0ikfU0>NmW03W_JD0ikFL
0=j]S0020=j]U0050=jUQ03FYH@0_IAk0<jDJ`36Q6/00P2mS6<0102eNeX0[G=B09a[BP24DST207=:
<@0305Xi:@1c@RT0@R4H0080>AP@0P1J<B40102LLe80eYac0;F4H`3FW7/20;EkFP0309acDP2DHd80
cZfD01<0moOg5000000X0?oooa<000001`3gmoL20>oWi`<0ikfU0P36U6/20>NmW0<0aYb40P2eNeX2
0<JDJ`<0gZEk0P3W_I@308AB>@80Q58a0P2DHd8308AB>@80FT8i0P1J>BT30;E[DP80cYA[0P3FW7/3
0=jUQ080gZf<0`3W]I`20>neW080klJ]0`3W_JD20>NeW080ijfD0`3NYH@20>N]U080gZf<0`3_aZd<
0?O>]@80klJe0P3Wa[D306/i8@80LdXa0P1kBRT309AS@P80W6]:0P36YI@30>oWi`80moOg0P3gkoLA
000001h0oooo000L0?oooa80000000@0Q4XY07=B@P24FT80YHac0P2DJe800`24DST0Q5Y207]J@P02
08AJ@P80S5Y200@0YG]J09acDP3FW7/0ilJ]0`3_c[D0103_c[d0mmJm0?OF_@3_e/H30?ONcP030>oF
aP3ge[d0mmk>00<0mmk>00<0mmJm0?ONcP3gg/h00`3gg/h00`3ge[d0kmK60?ONcP030>oFaP030?ON
cP3_e/H0mmJm00@0mmJm00@0mlJe0?O>]@3_a[D0klJ]0P3WaZd01@3W_JD0klJ]0>NeW03W]I`0gZfD
00<0eZF40P3FW7/01@2mU7/0aYA[0;f<H`2mS6<0]F]B0080[G=B00@0S5Y209a[BP2LJdX0Ld8Y0P1B
:AP020128AP0FS4Q058Q401B8A00_IAk0:EkFP2<FT80_IAk0P2]Le801@2LJdX0eZf<09a[BP3F_Jd0
oooo0180moOg4`00000X0?oooa<000001`3gmoL20>O>aP<0imK>0P3F_Jd20>NmW0<0aXAJ0P2eNeX2
0<J<H`<0klj]0P36Q5X307]::@80W6<i0P24DST308AB<@80@RTQ0P1J>BT30;EkFP80aXA[0P3FW7/3
0=jUQ080ijfD1`3_aZD30>nmW080ikFD0P3N[H`30=JLN`80gZF40P3W]I@30>neW0`0mlje0P3ga[D2
0>o6]@<0Jc4H0P1kBRT206/i8@<0S4Xa0P2DHd820;fDN`<0mnog103gmoLA000001h0oooo000L0?oo
oa80000000@0Q4XY07=B@P24FT80YHac0P2DJe800`24DST0Q5Y207]J@P0208AJ@P80S5Y200@0YG]J
09acDP3FW7/0ilJ]0`3_c[D0103_c[d0mmJm0?OF_@3_e/H30?ONcP030>oFaP3ge[d0mmk>00<0mmk>
00<0mmJm0?ONcP3gg/h00`3gg/h00`3ge[d0kmK60?ONcP030>oFaP030?ONcP3_e/H0mmJm00@0mmJm
00@0mlJe0?O>]@3_a[D0klJ]0P3WaZd01@3W_JD0klJ]0>NeW03W]I`0gZfD00<0eZF40P3FW7/01@2m
U7/0aYA[0;f<H`2mS6<0]F]B0080[G=B00@0S5Y209a[BP2LJdX0Ld8Y0P1B:AP020128AP0FS4Q058Q
401B8A00_IAk0:EkFP2<FT80_IAk0P2]Le801@2LJdX0eZf<09a[BP3F_Jd0oooo0180moOg4`00000X
0?oooa<000002@3gmoL50>oWi`80ikfD0`2eNeX209aS>@80aXAJ0`3FW7<20;f<H`D0W6]:0P24FT83
07=:<@80@RTQ0P1c@RT30;E[DP80cYA[0P3FW7/30=jUQ080ijfD0`3_]I`40>o6[@<0klJU0P3N[H`2
0;EkFP<0aXA[0P2eHd820>neW0<0klJ]0P3NW7/20?O6]@<0mlje0P3ge[d30?O6]@80klJ]0P3WaZd3
05Xa8@80Q48Y0P1c@RT306/i8@80Q58a0P2eQ6<30>oWi`@0moOg4@00000N0?ooo`00703ooolA0000
00050<JUU02LLe80LdXa07=:<@24HdX00P24DST307=:<@0808AB>@2DFS40S6=:08aSBP2LLe80YG]J
0=JUQ03Wa[D30>o>]@040>o6[@3FYH@0_Ib<0=j4L`80gZfL00<0kmK60?ONcP3gg/h0203gg/h20?ON
eP80kmK6103gg/h20?OF_@030>oFaP3ge[d0mlje0080mlJe0`3_aZd30>O6[@030<JLQ02UNf<0[G=B
0080YG]S0P2mU7/01@36W8@0_IAk0<jDJ`3FW7<0cYA[0080_HaS00@0[G=B09acDP2]Le80Q58i0P1[
>B400`1cBS40JcTQ05Xa8@0203TH4080@R4H00@0S6=:09AcFP2<FT80YG]J0P2]Hd801@36U6/0aYb4
09a[BP2mS6<0knOW01<0moOg4P00000X0?oooa<000002@3gmoL30=JeY@80g/Je0P3>[I@30;f<H`80
W6]:0P2eNeX30<jDH`80eZf40`2DFS4209acDP80S5Y20`1J@ST203TH4080S5Y20`36NeX20<jDJ`80
eYak0`3N[H`20>neU0<0klJU1`3_aZd20=JLN`80gZF40`3W[H`20=j]S080klJ]0`3ga[D20>o>]@D0
mlje0P3ge[d50?O>]@80klJ]0`24DST206/i8@80Nd8Q0`1kBRT209aS>@80[G=B0`3Wg]h40?Ogma40
00007P3oool001`0oooo4@0000001@36YI@0W7=B07=:<@1cBS40Q6=:0080Q58i0`1cBS402024DST0
U5Xa08aSBP2<HdX0W7=B0:EkFP3FYH@0ilJe0`3_c[D0103_aZd0eZF40;fLS03NQ7<20=j]W0030>oF
aP3gg/h0mmk>00P0mmk>0P3gg]H20>oFaP@0mmk>0P3ge[d00`3_e/H0mmJm0?O>]@020?O6]@<0klJ]
0`3WaZd00`36W8@0YG]S0:ecDP020:EkH`80_IAk00D0aYb40;fDN`3>U6/0eYac0<jDJ`020;f<H`04
0:ecDP2LLe80[G=B08AB>@80JcTQ00<0LdXa06/i8@1J<B400P0i6102048Q600408aSBP2DLeX0S5Y2
0:EkFP80[F=200D0aYA[0<JLQ02LJdX0_HaS0>oWi`0C0?Ogma800000:03ooolC000000T0moOg0`3F
]JD20=k6]@80cZfD0`2mS6<209a[BP80]G]J0`3>U6<20=J]Q0<0U5Xa0P2LLe8208aJ@P<0FT8i0P0i
610208aJ@P<0aW]J0P3>U6/20=JLN`<0gZf<0P3_]I@30>o6Y@L0klJ]0P3FW7/20=jUQ0<0ijf<0P3N
[H`20>o6[@<0mlJe0P3_c[D50?O>]@80mmJm1@3gc[D20>o6[@<0Q58i0P1[>B4207]28@<0NdXY0P2L
HcT20:ecDP<0imkN103gmoLA000001h0oooo000L0?oooa40000000D0aZFD09acDP1cBS40LdXa08AS
BP0208AB>@<0LdXa00P0Q58i09AJ<@2<HdX0S6=:09acDP2UNeX0eZF40>O6]@<0klje00@0klJ]0=JU
Q02mW8`0gXAc0P3N[I`00`3_e/H0mmk>0?ONcP080?ONcP80mmkF0P3_e/H40?ONcP80mmJm00<0kmK6
0?OF_@3gc[D00P3ga[D30>o6[@<0ilJ]00<0aYb40:EkH`2]Le800P2UNf<20;fDN`050<JLQ02mU7/0
cYA[0=JLL`3>U6/00P2mS6<0102]Le80W7=B0:ecDP24DST206/i8@0307=:<@1[>B40FS4Q0080>AP@
0P128AP0102<HdX0U7=J08aJ@P2UNeX20:eS@P050<JDJ`36W8@0W6]:0;f<H`3_inL04`3gmoLB0000
02P0oooo4`0000090?Ogm`<0g/jm0P3Na[D20=J]S0<0]HAS0P2]Le820;EkFP<0eZf40P36U6/309AJ
<@80W6]:0P2DHd8307=:<@80@R4H0P2DHd830;EkFP80gXAc0P3NW7/30>N]S0D0kkFL0P3_aZd20?O6
]@<0klJ]0P3NYH@20=j]S0<0ijfL0P3W]I@20?O6]@<0kmK60P3_a[D20?O6]@<0mlje1@3ge[d40?O6
]@<0YG]S0P1S:A0207]::@<0Q4Xa0P1[>B4209AS@P<0imK>0P3gmoL20?O_ia4000007P3oool001`0
oooo4@0000001@3_inL0oooo06/i8@1kBRT0FS4Q0080JcTQ00D0LdXa08AB>@1cBS40W6<i0;ES@P02
0;EkFP040;f<H`36Q6/0aYb40>o6[@80g/Je00<0ikfL0>o6]@3ge[d00P3_e/H20?O6]@040;F4J`2U
Nf<0U7=J0;E[DP80eZF400D0klJU0?O>]@3gc[D0mmJm0?ONcP020?OF_@030?ONcP3_e/H0mmJm00<0
mmJm0P3gc[D00`3_aZD0ijfD0;f<H`0209AJ@P0408AB>@2DFT80]F]B0=jUQ080ijfL00D0ilJ]0>o6
[@3_aZd0kkFL0>NmY@020=j]U0050=jUQ02mU7/0YG]J0<jDJ`2eS7<00P2eQ6/0102]Le80W6]:09a[
BP2<FT8306/i8@04058Y601J<B40DRTH058Q4080Le9200@0Q5Y209A[DP2UNeX0W7=B0P2DFS420;f<
H`030=J]S02mU7/0aYb401<0moOg4P00000X0?oooa<000000P3gkoL70?Ogm`<0mnog0P3F]JD20<j]
U0<0]G]J0P2mS6<20=JLL`<0gZEk0P2]Le8308AB<@80W6]:0P2LHcT307=2:@8060P80P2DFS430;Ek
FP80cYA[0P3NYH@30>N]U080kkFL0`3_aZD20?O6]@80klj]0`3_aZd20>N]U080gZf<0`3WYI@20>Nm
Y@80mlJe0`3gg]H20?OF_@80klJ]2P3ge[d20?O>]@<0ilJe0P1B:AP208a:<@<0NdXY0P24DS4208aJ
@P<0ilk60P3gmoL20?O_ma4000007P3oool001`0oooo4@0000001@3_inL0oooo06/i8@1kBRT0FS4Q
0080JcTQ00D0LdXa08AB>@1cBS40W6<i0;ES@P020;EkFP040;f<H`36Q6/0aYb40>o6[@80g/Je00<0
ikfL0>o6]@3ge[d00P3_e/H20?O6]@040;F4J`2UNf<0U7=J0;E[DP80eZF400D0klJU0?O>]@3gc[D0
mmJm0?ONcP020?OF_@030?ONcP3_e/H0mmJm00<0mmJm0P3gc[D00`3_aZD0ijfD0;f<H`0209AJ@P04
08AB>@2DFT80]F]B0=jUQ080ijfL00D0ilJ]0>o6[@3_aZd0kkFL0>NmY@020=j]U0050=jUQ02mU7/0
YG]J0<jDJ`2eS7<00P2eQ6/0102]Le80W6]:09a[BP2<FT8306/i8@04058Y601J<B40DRTH058Q4080
Le9200@0Q5Y209A[DP2UNeX0W7=B0P2DFS420;f<H`030=J]S02mU7/0aYb401<0moOg4P00000X0?oo
oa<000001@3gmoL20?O_m`D0moOg0P36W8@20>NmW0D0]G]J0P3W_JD30<jDJ`80W7=B0`24DS4209AS
@P80Q58i0`1J>BT2024@2080[F=20`2eNeX20=JLL`80gZf<0`3W[I@50>o6Y@80klJ]0P3_c[D30>o6
]@80ikFL0P3FYH`30=jUQ080ijfD0P3gc[D30>oFaP80mlJe0P3gc[D50?OF_@<0kmK60P3ge[d20>o>
_@<0klJ]0P1S:A0507]::@80Ld8Y0P2DHd830<JDJ`@0moOg4@00000N0?ooo`00703ooolA00000005
0?Ogm`3_imh0YHak09A[DP1cBS400P1c@RT207=:<@0306/i8@2LJdX0aXAS0080cYA[00@0aYb40;fD
N`3FYH`0ilJe0`3_c[D0103ge[d0kljm0>o6[@3_a[D20>NmY@040>NeW03W[I`0ikFL0>NmY@80ikFL
00D0eYak0=jUQ03W[I@0klJU0?OF_@020?O>]@80kmK600T0mmJm0?O>]@3_cZd0klj]0>o6[@3W]I@0
eYac0=jLN`2mU7/00P3FYH@00`3FYH`0eZF40;fDN`030;fDN`050<jDJ`3FW7/0eZF40=JUQ03N[H`0
0P3W[H`01@3N[I@0eZF<0=JUQ03FW7/0cYA[0080aXA[00@0_HaS0;EkFP2DFT80S6=:0P24DST206/i
8@03058Y601J>BT0LdXa0080Ld8Y00@0JcTQ09a[BP2mS6<0W6]:0P2LHcT01@36Q5X0_IAk0=j]U02L
Le80_IAk0080kmk>00<0oooo0?Ogm`3gmoL03P3gmoLB000002P0oooo4@00000>0?Ogm`80g/jm0P3>
[I@30:EkFP80]G=:0P3_cZd30<jDH`80YG]J1@24DS4207=:<@<0DRTH0P0Y40P209a[BP<0aXAS0P3N
YH@20>N]S0<0kkFL1@3_aZd20>o6]@80mlJe1@3_aZd20=j]U0<0gZf<0P3W]I`20>o6]@<0mmJm0P3_
c[d20?OF_@X0kmK60P3ge[d30>o6[@80DR4@0P0i610308A:<@80Q58i0P24BRT30;F4J`L0moOg3P00
000N0?ooo`00703ooolA000000050?Ogm`3_imh0YHak09A[DP1cBS400P1c@RT207=:<@0306/i8@2L
JdX0aXAS0080cYA[00@0aYb40;fDN`3FYH`0ilJe0`3_c[D0103ge[d0kljm0>o6[@3_a[D20>NmY@04
0>NeW03W[I`0ikFL0>NmY@80ikFL00D0eYak0=jUQ03W[I@0klJU0?OF_@020?O>]@80kmK600T0mmJm
0?O>]@3_cZd0klj]0>o6[@3W]I@0eYac0=jLN`2mU7/00P3FYH@00`3FYH`0eZF40;fDN`030;fDN`05
0<jDJ`3FW7/0eZF40=JUQ03N[H`00P3W[H`01@3N[I@0eZF<0=JUQ03FW7/0cYA[0080aXA[00@0_HaS
0;EkFP2DFT80S6=:0P24DST206/i8@03058Y601J>BT0LdXa0080Ld8Y00@0JcTQ09a[BP2mS6<0W6]:
0P2LHcT01@36Q5X0_IAk0=j]U02LLe80_IAk0080kmk>00<0oooo0?Ogm`3gmoL03P3gmoLB000002P0
oooo4@00000>0?Ogm`80g/jm0P3W_I@30;F4H`80aXaS0P3_cZd30=JLL`80W7=B0`2LHcT207]::@80
Q58i0`1J<B42048Q6080W6]:0`36Q6<20=JLN`80gZfD0`3W]I`20>o6[@<0klJe0P3_c[d20?O6]@<0
klJe0P3_aZd20>NeW0<0gZf<0P3N[I@20>o6[@<0mmJm0P3gc[D20?OF_@<0kmK60P3gg/h50>oFaP80
mmJm0`3_c[D4058Y60<0NdXY0P24DST207]::@<0]HA[1`3gkoL>000001h0oooo000L0?ooo`l00000
0`3gmoL0102eU7/0e/K60:F<L`2DLeX207]B@P0507=:<@24DST0Q58i09AJ@P3>Lf<00P3_]I`0103W
S7/0eYak0=j]S03_a[D20>o>]@040>NeW03>YI@0aXA[07=:<@<0Q6=B00@0FT8i048Y8@1J>BT0Q58i
0P2<Je801@24He80YG]S0;fDN`3W[I@0kkfL00<0mlje00<0mmJm0?O>]@3_aZd00P3__I`01@3W]I`0
gZF40;fDN`36Q6/0[G=B0080U7=J0P2US8@00`1J>BT0DRTH05Xi:@0205Xi:@0407=:<@1J@ST0LeY:
07]B@P80YG]S00<0]HAS0;F4J`3>U6/00P3FW7/20;fDN`030;F4J`2eNeX0U5Y200<0S5Y200@0LdXa
06/i8@128AP0FSTY0`1[>B40101cBS40W6]:0:ecDP2LJdX209aS>@050;EkFP2]Le80eZf409AS@P2m
S6<00P3FW7<00`3_imh0moOg0?Ogm`0?0?Ogma400000:03ooolA00000080moOg0P3gkoL:0?Ogm`80
knoW0P3N[H`30:EkFP80]G=:0P3W_JD30=JLL`80W7=B0`2<FT8208AB<@80LdXa0`1[>B4207=2:@80
W6]:0`3FW7<20=JUQ080ikFD0`3WaZd20>o6]@<0kljm103ga[D30>oFaP80klJe0P3W]I`30>NeU080
ikFL0P3ga[D50?OF_@`0kmK60P3gg/h30?O6]@80kkFL0P128AP307]::@80Q58a0P1c@RT309acDP80
moOg0P3gkoL30?Ogm`h000007P3oool001`0oooo3`0000030?Ogm`040;FDN`3Fa/H0YHac09AcFP80
Ne9200D0LdXa08AB>@24DST0U5Y20<icH`020>neW0040>N<N`3FW7/0gZf<0>o6]@80klje00@0ikFL
0<jUU036Q6/0LdXa0`24He80101J@ST0@RTQ05Xi:@24DST208a[DP0508ASDP2UNf<0_IAk0>N]U03_
_I`00`3gc[D00`3ge[d0mlje0>o6[@020>nmW0050>NeW03NYH@0_IAk0<J4J`2]Le800P2DLeX20:F<
Q00305Xi:@1B:AP0FSTY0080FSTY00@0LdXa05Y2>@1cFTX0Ne920P2UNf<00`2eQ6<0]HA[0<jDJ`02
0=JLN`80_IAk00<0]HA[0;EkFP2DFT800`2<FT80101cBS40JcTQ048Q601J>BT306/i8@0407=:<@2L
JdX0[G=B09a[BP80W6<i00D0]G]J0:ecDP3F[H@0U6=20;f<H`020=JLL`030>oWgP3gmoL0moOg00l0
moOg4@00000X0?oooa4000000P3gmoL20?O_m`X0moOg0P3_knL20=j]S0<0YG]J0P2eLdX20>NmY@<0
eYac0P2LLe8308aJ@P80Q58a0P1cBS4306/i8@80Ld8Y0P2LJdX30=JLL`80eZF40P3W]I@30>O6[@80
klJe0`3_c[d40?O6]@<0kmK60P3_a[D20>NeW0<0ikFD0P3W]I`20?O6]@D0mmJm303_e/H20?ONcP<0
mlJe0P3_]I`2048Q60<0NdXY0P24DS4207=2:@<0W7=B0P3gmoL20?O_m`<0moOg3P00000N0?ooo`00
703oool?000000<0moOg00@0]IAk0=K6aP2US7<0U7=J0P1kDT801@1cBS40Q58i08AB>@2DFT80cW=S
0080kkFL00@0ihak0=JLN`3N[H`0klJe0P3_c[D0103W]I`0cZFD0<J4J`1cBS4308ASDP0405Y2>@12
:B40FSTY08AB>@80S6]B00D0Q6=B0:EkH`2mU7/0ijfD0>nmW0030?O>]@030?OF_@3gc[D0klJ]0080
kkfL00D0ikFL0=jUQ02mU7/0aXA[0:ecDP0209AcFP80YHb400<0FSTY058Y601J>BT00P1J>BT0101c
BS40FT8i07=JBP1kDT820:EkH`030;F4H`2eQ6/0cYA[0080eYak0P2mU7/00`2eQ6/0]G]J09AJ@P03
08aJ@P0407=:<@1[>B40@R4H05Xi:@<0JcTQ00@0LdXa09a[BP2]Le80W6]:0P2LHcT01@2eNeX0[G=B
0=J]Q02DHd80_HaS0080eYac00<0knON0?Ogm`3gmoL03`3gmoLA000002P0oooo4@00000@0?Ogm`80
eZf<0`2UNeX20:e[>@80eZf40`3FW7<20;F4J`<0S5Y20P2LHcT208AB>@<0JcTQ0P1cBS420;E[DP<0
eYac0P3N[H`20>NeW0<0klJ]1@3_c[d70?OF_@80ilJ]0P3W_JD50>NeW0L0mmJm1@3_e/H20?OF_@<0
kmK60P3gg/h50>oFaP80klJ]0P1[>B4308A:<@80LdXa0P1J<B4309AJ<@L0moOg3P00000N0?ooo`00
703oool?000000@0moOg00<0]HA[0;fLS02LLe800P2<HdX01@1J<B40Q58i09AJ@P1[<AP0DRTH0080
mlJe00@0ijf<0>NUU03N[I@0kljm0P3ge[d01@3_c[d0ilJ]0>N]W02eQ6/0aXA[0080e[fe00@0imK>
07]cL`1cJf<0HeYB0P24Ng<01@2UNf/0aYb40;fDN`3W[I`0gZfD0080klJU0P3ge[d02@3_c[D0klJ]
0>NeW03W]I`0gZF40;fDN`2eQ6/0aXA[0<JLQ0020:e2<@040=k6aP3_inL0S7=S09AcFP80Nf]J00D0
U8b406]SFP2mW9@0W7=B08a[DP020;F4J`80eZF400<0gZfD0=j]S03FYH`00P3FW7/0103FW7<0]HA[
0:ecDP2LJdX208AB<@0507=:<@1J<B40:A08048Q6024DST00P2<FT80101c@RT0W6]:0;F4J`2eQ6<2
09a[BP050:EkFP2]Hd80gZf<08A::@2mU7/00`3F[H`?0?Ogm`030?O_m`3gmoL0000001000000:03o
oolA00000100moOg0P3N[H@30:ecDP80[F]20P3FYH@50=JLL`D0U6=20P1cBS4305Xa8@80S4Xa0P2e
Je830=JLL`80gZf<0P3W_JD30>o6[@80klje0`3ge[d20?O6]@80kmK60`3_c[d20>o6[@80ikfU0`3N
[I@20>NeW080mlJe0`3ge[d20>oFaP80mmk>0`3_e/H50?OF_@80mmk>1@3_e/H20?O6]@80DRTH0`1c
@RT208AB>@80JcTQ0`2LHcT70?Ogm`h000007P3oool001`0oooo3`0000040?Ogm`030;F4J`2mW8`0
W7=B0080S6=:00D0FS4Q08AB>@2DFT80Jc4H058Y60020?O6]@040>N]S03WYI@0gZfD0>o>_@80mmJm
00D0kljm0>O6[@3W[I`0]HA[0<J4J`020=Jm]@040>OFcP1kLg<0Lf]S06=JDP80Q7]c00D0YG][0<JL
Q02mU7/0ijfL0=j]U0020>o6Y@80mmJm00T0klje0>o6[@3W]I`0ikFL0=jUQ02mU7/0]HA[0<J4J`36
W8@00P2]@S40103Na/H0knOW08acH`2DLeX207][FP0509B<Q01[HeX0_IbD09acDP2<Je800P2eQ6/2
0=JUQ0030=j]U03N[H`0eZF<0080eYak00@0eYac0;F4J`2]Le80W6]:0P24DS401@1cBS40FS4Q02T@
20128AP0Q58i0080S5Y200@0Ld8Y09a[BP2eQ6/0]HAS0P2LJdX01@2UNeX0[F=20=j]S024BRT0_IAk
00<0eZf<3`3gmoL00`3gkoL0moOg0000000@000002P0oooo4@00000@0?Ogm`80eZf40`2]Le8209AJ
<@80aYb40`36U6/20=J]S0<0Q58i0P2DFS4206/i8@<0Jc4H0P24DST20;EkFP<0eYak0P3N[I@20>Nm
Y@D0klJe2P3_c[d20>O6[@80ikfU0`3N[I@20>NmY@80kmK60`3_a[D20?OF_A40kmK60P3gc[D208AB
>@<0FS4Q0P24DST207=:<@<0W7=B0P3gkoL50?Ogm`h000007P3oool001`0oooo3`0000040?Ogm`03
0?ooo`2LJdX0YG]S0080Q58i00D0S5Y208AB>@2DFT80DR4@08AB<@0208A:<@040?O6]@3>U6/0gZF4
0>o>]@80mmJm0`3_e/H0203_c[d0ilJe0=j]W03N[I`0_IAk0;F<L`3FYH`0cZFD0P2mU7/20=j]W080
kljm0`3_a[D30?OF_@080>o6[@3N[I@0gZfD0=JLN`36W8@0eYak0>NmW03N[I`20>O6]@040>N]W03N
[I`0aZFL0;fLS080]HA[00D0]Hac0<JLQ036W8@0aYb40<jUU0020>NmW0050>NmY@3N[I`0gZfL0=j]
W03N[H`00P3FYH@01036W8@0aXA[0;EkFP2DFT8208AB>@0507=:<@1[>B40FS4Q05Xa8@24DST00P24
DS40102<HdX0S5Y20;F4J`2mS6<30;EkFP0409AJ<@3W_I@0U5Xa08a:<@80aYb400<0eYac0>OFcP3o
ool03`3gmoLA000002P0oooo4@00000@0?Ogm`80cZfD0`2mS6<208A28@80W6]:0`3FW7<20<JLQ0<0
S5Y20P2LJdX206/i8@<0DRTH0P2DFS420<J4H`<0eZF40P3N[I`20>NmY@<0klJ]1@3_a[D20>o>_@80
kmK60`3Wc[d40=j]W0<0gZf<0P3_aZd20>oFaP<0mlje0P3ge[d20>o>_@<0klJe0P3_c[d30>oFaP80
mmk>1@3_e/H20>o6]@80ilJ]0`1J>BT208a:<@80S5Y20`2<HdX20;f][@80mnog0`3gmoL>000001h0
oooo000L0?ooo`l00000103gmoL00`3oool0W6]:0:EkH`0208AB>@0508aJ@P24DST0U5Y2058Q4024
DS400P24BS40103ga[D0cYA[0=jUQ03_c[D20?OF_@<0kmK600P0kljm0>O6]@3N[I`0gZfL0;fDN`2e
S7<0eZF<0<jUU080_IAk0P3N[I`20>o>_@<0klJe0`3ge[d0203_aZd0gZfD0=j]U03FW7/0aYb40=JL
N`3W_I`0gZfL0P3Wa[D0103W[I`0gZfL0<JUW02mW8`20;F4J`050;F<L`36W8@0aYb40<JLQ03>YI@0
0P3W_I`01@3W_JD0gZfL0=j]W03N[I`0gZf<0080eZF400@0aYb40<J4J`2eNeX0U5Y20P24DST01@1c
BS40JcTQ05Xa8@1J<B40Q58i0080Q58a00@0S6=:08aJ@P2eQ6/0_HaS0`2eNeX0102DFS40ikfD09AJ
<@2<BS420<JLQ0030=JLL`3We/h0oooo00l0moOg4@00000X0?oooa4000002`3gmoL30?O_m`80moOg
0P3WaZd30;F4J`80U5Y20P24BS430<jDJ`80aYb41@2<FT8206/i8@<0DRTH0P2DFS420<J4H`<0eZF4
0P3W_I`20>O6[@<0klJe1@3WaZd20>NmY@80ilJ]0`3_a[D20>NmY@80gZfD0`3N[H`20>o6[@80kmK6
0`3gc[D20?OF_@80klJe0`3_aZd20>neW0<0kljm0P3ge[d50>oFaP@0ilJ]0`1cBS4208a:<@D0W6]:
0P2UNf/20?O_m`<0moOg3P00000N0?ooo`00703oool?000000@0moOg00<0oooo09a[BP2UNf<00P24
DST01@2<FT80Q58i09AJ@P1B8A00Q58a0080Q4Xa00@0mlJe0<jDJ`3NYH@0klje0P3ge[d30>oFaP08
0>o>_@3Wa[D0gZfL0=j]W02mU7/0]Hac0=JUS03>YI@20;fDN`80gZfL0P3_c[d30>o6]@<0mmJm00P0
klJ]0=j]U03N[I@0eYak0<JLQ03FW7/0ikfL0=j]W080ilJe00@0ijfL0=j]W036YI`0_Ib<0P2eQ6/0
1@2eS7<0aYb40<JLQ036W8@0cZFD0080ikfL00D0ikfU0=j]W03N[I`0gZfL0=j]S0020=JUQ0040<JL
Q036Q6/0]G]J09AJ@P80Q58i00D0LdXa06/i8@1J<B40FS4Q08AB>@0208AB<@0408aSBP2<FT80]HA[
0;f<H`<0]G]J00@0U5Xa0>NmU02DFS40S4Xa0P36W8@00`3FW7<0imK>0?ooo`0?0?Ogma400000:03o
oolA000000/0moOg0`3gkoL20?Ogm`80ilJ]0`2eQ6/209AJ@P80Q4Xa0`3>U6/20<JLQ0D0S5Y20P1[
>B43058Y6080U5Xa0P36Q6<30=JUQ080ikfL0P3WaZd30>o6]@D0ilJ]0P3W_JD20>O6[@<0klJe0P3W
_JD20=j]U0<0gZf<0P3_aZd20>oFaP<0mlje0P3ge[d20>o6]@<0klJ]0P3_]I`30>o>_@80mmJm1@3_
e/H40>O6[@<0LdXa0P2<BS4509a[BP80YG][0P3gkoL30?Ogm`h000007P3oool001`0oooo3`000003
0?Ogm`040?O_m`3gmoL0YG][0;F<L`80W6]:00D0LdXa09a[BP1cBS40S4Xa05Xa8@0207=:<@0407]:
:@3WaZd0mlJe0>O6[@<0kmK600@0mmk>0>oFaP3_e/H0mmJm0P3_e/H20>o>_@030>neW03WaZd0klJ]
0080klJ]00@0klJe0>o>_@3ge[d0klje0P3gc[D0103ge[d0kmK60?OF_@3_aZd20>NUU0050=j]S03F
YH`0gZfD0=j]U03W_JD00P3Wa[D0103_a[D0kljm0>O6[@3WaZd20>NmY@@0ilJ]00<0klJ]0>o6]@3_
a[D00P3WaZd00`3F]JD0ikfL0=j]S0020=JUQ0040=JLL`36Q6<0[G=B09AJ<@80Q4Xa00D0DRTH058Q
401[>B40LdXa08aJ@P0209aS>@80S5Y200T0aYb40<jDJ`3>U6/0cYA[0=JLL`24BS40gZf409AJ@P2<
FT800P2eQ6/00`3FYH@0ilJ]0?Ogm`030?Ogm`030?O_m`3gmoL0moOg00T0moOg4@00000X0?oooa40
0000403gmoL20>OFaP<0aYA[0P2LJdX208A::@<0]G]J0P2mU7/309a[BP80S5Y20P1S:A0307=2:@80
W6]:0P36Q6/30=JUQ080ikfL1@3W_JD20=j]W0<0gZf<0P3W[I`20>NmY@<0ilJe0P3F]JD20=JUS0<0
gYak0P3_]I`20>oFaP<0klJe0P3_c[d20>O6[@<0gZfD0P3_aZd30>o6]@80kljm1@3_e/H20>o6]@80
klJ]0`2LHcT207=:<@80Q5Y20`2<FT8208a::@80moOg0`3gkoL>000001h0oooo000L0?ooo`l00000
0`3gmoL0103gkoL0moOg0:EkJ`2eS7<209a[BP0507=:<@2LJdX0LdXa08a:<@1J<B400P1cBS40101k
BRT0ilJ]0?O6]@3WaZd30>oFaP040?ONcP3_e/H0kmK60?OF_@80kmK60P3_c[d00`3_]I`0ilJ]0>o6
[@020>o6[@040>o6]@3_c[d0mmJm0>o>]@80mlje00@0mmJm0>oFaP3ge[d0klJ]0P3WYI@01@3N[H`0
eZF<0=j]U03N[I@0ikfU0080ilJe00@0klJe0>o>_@3WaZd0ilJ]0P3W_JD40>O6[@030>o6[@3_a[D0
klJe0080ilJ]00<0e[FU0>NmW03N[H`00P3FYH@0103FW7<0aXAS0:ecDP2DFS4208A:<@05058Y601B
8A00JcTQ07=:<@2<FT800P2LHcT208aJ@P090<JLQ03>U6/0cYA[0<jDJ`3FW7<0Q4Xa0=j]Q02DFT80
S5Y20080]HA[00<0eZF40>O6[@3gmoL00`3gmoL00`3gkoL0moOg0?Ogm`090?Ogma400000:03ooolA
00000100moOg0P3We/h30<JLQ0@0U5Xa0`2eNeX20;F4J`<0S6=:0P24DST205Xa8@<0LdXa0P2DFT82
0<J4J`<0eZF4103N[I`30>NmW0D0aYb40P2eQ6/20<JUW0<0ijfL0P3N[I`50=JLN`80klJ]0P3ge[d3
0>o6]@80kljm0P3N[I`30;fDN`80eZF<0`2mU7/20>O6]@D0kmK60P3_c[D20<jDJ`<0Q4Xa0P1B8A05
08AB>@80W6]:1@3gmoL>000001h0oooo000L0?ooo`l000001@3gmoL02@3gkoL0W7=B09acDP2LLe80
Q58i07=:<@1c@RT0Q58i08A:<@0205Xa8@0407=2:@24DST0klJe0?O>]@80kljm203_e/H00`3ge[d0
kmK60>o>_@050>oFaP80mmJm0P3_a[D20>oFaP060?OF_@3W_JD0ijfD0>N]U03N[I@0ikFL0P3W_JD0
0`3WaZd0klJe0>o6]@030>o>_@050>oFaP3_c[d0kljm0?OF_@3_c[d00P3_a[D0103_aZd0klJe0>o6
]@3WaZd20>NmY@080=j]U03FYH@0eYak0=JLN`3>U6/0]G]J09a[BP24DST207=2:@0506/a601[>B40
JcTQ08AB>@2DFS400P2<HdX01024DST0Q4XY0=J]S03FW7<20<JDJ`040=JLN`36W8@0gZf<09AJ<@<0
[G=B00<0YHA[0=J]Q03gknL03`3gmoLA000002P0oooo4@00000@0?Ogm`80knOW0`3F[H@209aS>@80
U58Y0`2eLdX20;F4H`<0S5Y20P24DST2058Y60<0LdXa0P2LJdX20<J4J`<0eZF<0P3N[I`20=j]U0<0
eZF<1@2UNf<207=JBP80g/K60`36Q6/209a:<@80_IAk0`3FW7/20>o6Y@80mmJm0`3WaZd20>o6]@80
gXAc0`2UQ7<207=[H`<0gZfL0P2eQ6<20>o6]@<0kmK60P3_c[D20>N<N`<0kkFD0P1J<B4507=:<@80
YG]J1@3gmoL>000001h0oooo000L0?ooo`l000001@3gmoL02@3gkoL0W7=B09acDP2LLe80Q58i07=:
<@1c@RT0Q58i08A:<@0205Xa8@0407=2:@24DST0klJe0?O>]@80kljm203_e/H00`3ge[d0kmK60>o>
_@050>oFaP80mmJm0P3_a[D20>oFaP060?OF_@3W_JD0ijfD0>N]U03N[I@0ikFL0P3W_JD00`3WaZd0
klJe0>o6]@030>o>_@050>oFaP3_c[d0kljm0?OF_@3_c[d00P3_a[D0103_aZd0klJe0>o6]@3WaZd2
0>NmY@080=j]U03FYH@0eYak0=JLN`3>U6/0]G]J09a[BP24DST207=2:@0506/a601[>B40JcTQ08AB
>@2DFS400P2<HdX01024DST0Q4XY0=J]S03FW7<20<JDJ`040=JLN`36W8@0gZf<09AJ<@<0[G=B00<0
YHA[0=J]Q03gknL03`3gmoLA000002P0oooo4@00000B0?Ogm`<0eZf<0P24BRT20:eS@P<0W6]:0P2e
Q6/307=2:@80Q58i0P0Y40P307=:<@80W6]:0P2eQ6/30=JLN`80gZf<0P3FYH@30;F4J`80W7=B0`1[
HeX207][FP80S7=S0`3Na/H20<JLQ080]HA[0`3NYH@20>o6[@80mmJm0`3_aZD20>N]W080aYb40`24
Ng<207=[H`<0imK>0P36Q6/20>N]W0D0kljm0P3WYI@30?O6]@80Jc4H0P24DST308aSBP80_Ib<1@3g
moL>000001h0oooo000L0?ooo`l000001P3gmoL01P2LLe80U5Xa09AJ<@24DS40FS4Q07]J@P80LdXa
0P24BS40101B:AP0JcTQ05Xi:@3_aZd20>o6]@040>oFaP3ge[d0kmK60>oFaP<0mmk>0P3_e/H00`3g
e[d0mmk>0>oFaP040>oFaP030?OF_@3_c[d0mmJm00<0mmJm00H0mlJe0>NeW03N[I@0gZfD0>NeW03W
_I`20>NmY@070>O6[@3_c[D0klje0?OF_@3_c[d0mmJm0>oFaP020?OF_@050?O6]@3_c[d0kljm0>o>
_@3_a[D00P3_aZd01@3W_JD0ikFL0=j]U03N[H`0eYak0080eYac00@0aW]J0;E[DP2DFT80LdXa101[
>B400`24DST0Q58a09aS>@0209AS@P0408aJ@P2DLeX0]HA[0=JLN`<0eYac00@0eZf40<J<H`2]JcT0
Q4XY0P2UNeX00`2mU7/0eZf<0>ONeP0?0?Ogma400000:03ooolA00000180moOg0`3FW7/208A::@80
[F=20`2UNeX209acDP<0LdXa0P1B:AP203TH40<0Q4Xa0P2DFT820<J4H`<0_IAk0P3FYH`20;fDN`<0
YG]S0P12<BT306=JDP808APH0P1SFU8309a[BP@0]Hac0`3W]I@20>o6[@80mmJm0`3_cZd20;fDN`80
U7=J0`24Lf/20;Fe_@<0a[Fe0P1J>BT20;fDN`<0klJ]0P3Wa[D20>N<N`<0mlJe1024DST307]::@80
YHA[0P3oool30?Ogm`h000007P3oool001`0oooo3`0000060?Ogm`0609acDP2DFS40U5Xa08AB<@1J
<B40NeY20P1cBS4208A:<@04058Y601[>B40FSTY0>o6[@80klJe00@0kmK60?OF_@3_e/H0kmK60`3g
g/h20>oFaP030?OF_@3gg/h0kmK600@0kmK600<0mmJm0>o>_@3ge[d00`3ge[d01P3ga[D0ikFL0=j]
U03N[I@0ikFL0>NmW080ikfU00L0ilJ]0>o>]@3_c[D0mmJm0>o>_@3ge[d0kmK60080mmJm00D0mlJe
0>o>_@3_c[d0kljm0>o6]@020>o6[@050>NmY@3W]I`0gZfD0=j]S03FW7/00P3FW7<01036NeX0]F]B
09AJ@P1cBS4406/i8@0308AB>@24DS40W6<i0080U6=200@0S5Y209AcFP2eQ6/0eYak0`3FW7<0103F
[H@0aXaS0:e[>@24BRT20:EkFP030;fDN`3F[H`0imkF00l0moOg4@00000X0?oooa4000004P3gmoL3
0=JLL`80U6=20P2]Le8309aS>@80[G=B0`1cBS4206/i8@80@R4H0`1cBS4208aJ@P80]G]J0`2mU7/2
0=JLN`80]HA[0`2UNf<207=JBP<0LdXa101J>BT30:F<Q080[G=B0P2mU7/30>NeW080klJ]0P3ge[d3
0?O>]@80ijfD0P2UNf<308a[DP80FSTY0`1J@ST208ASDP80aXA[0`3W]I`20>o6]@80eYak0`3_]I`2
09AJ@P80Q58i0`1kDT820:F<L`80]IAk0`3gmoL>000001h0oooo000L0?ooo`l000001P3gmoL01P2L
Le80U5Xa09AJ<@24DS40FS4Q07]J@P80LdXa0P24BS40101B:AP0JcTQ05Xi:@3_aZd20>o6]@040>oF
aP3ge[d0kmK60>oFaP<0mmk>0P3_e/H00`3ge[d0mmk>0>oFaP040>oFaP030?OF_@3_c[d0mmJm00<0
mmJm00H0mlJe0>NeW03N[I@0gZfD0>NeW03W_I`20>NmY@070>O6[@3_c[D0klje0?OF_@3_c[d0mmJm
0>oFaP020?OF_@050?O6]@3_c[d0kljm0>o>_@3_a[D00P3_aZd01@3W_JD0ikFL0=j]U03N[H`0eYak
0080eYac00@0aW]J0;E[DP2DFT80LdXa101[>B400`24DST0Q58a09aS>@0209AS@P0408aJ@P2DLeX0
]HA[0=JLN`<0eYac00@0eZf40<J<H`2]JcT0Q4XY0P2UNeX00`2mU7/0eZf<0>ONeP0?0?Ogma400000
:03ooolA00000180moOg0`3FW7<209AS@P80[G=B0`2LHcT20:ecDP<0LdXa0P1[>B42048Q60<0LdXa
0P2<FT820;EkFP<0_IAk0P3FW7/20;F4J`<0YG]S0P1cFTX307=:<@@0FSTY0`2US8@20:ecDP80_IAk
0`3W]I`20>o6[@80mmJm0`3gc[D20>N]U080YG]S0`2<Je8205Xi:@<0FT8i0P24He820<J4J`<0ikFL
0P3_a[D20=JLN`<0kkFL0P2DFT8208AB>@<0Ne920P2US7<20;FDN`<0moOg3P00000N0?ooo`00703o
ool?00000080mnog00<0moOg0?O_m`3gkoL00P3gkoL20;F4J`0509AJ<@1kBRT0NdXY08AB>@1cBS40
0P1kBRT01024BS40DRTH048Q601B:AP20<j]U080klje00<0mmJm0>oFaP3_e/H00`3_e/H30?ONcP80
kmK60`3ge[d00`3gc[D0klJe0?OF_@020?OF_@030>o6[@3_]I`0gZfD0080gZfD00D0gZf<0>NeU03W
]I`0ikfU0>o6[@020>o>]@040>o6]@3ga[D0mlJe0?OF_@80kljm00D0mlJe0>o6]@3_aZd0klJ]0>ne
W0030>NeW0040=j]U03NYH@0eYak0=JLL`80aXAS00@0]F]B09a[BP2DHd80@R4H0P0Q40P01@1J<B40
DRTH08AB>@2<FT80NdXY0080U5Xa00@0W6<i08AB<@2LLe80aYb40P3FW7<01@3N[H@0klj]0:ecDP36
S6<0S5Y20080]HAS00@0[G=B0>NmU03Wc[d0g/jm3P3gmoLA000002P0oooo4@00000B0?Ogm`<0eZF4
0P2LJdX20;f<H`<0W6<i0P2eNeX307=2:@80FS4Q0P1B:AP308AB>@80S5Y20P2eJe830<jDJ`80eYak
0P3>U6/30;F<L`80W7=B0`1J@ST208ASDP80YHAc0`24HdX20;fDN`80gZF40`3_aZD20>o6[@80mmJm
0`3gc[D20>o6[@80eZF40`2DLeX507]B@P80]F]B0P3N[I@30>O6[@80klJe0P3FW7/30>NUU080S4Xa
0P24DST307=:<@80]Ib<0P2]Le830?Ogm`h000007P3oool001`0oooo3`0000020?O_m`030?Ogm`3g
koL0mnog0080mnog0P2eQ6/01@2DFS40NdXY07]::@24DST0LdXa0080NdXY00@0Q4Xa058Y60128AP0
DRTH0P3>[I@20>o>]@030?OF_@3_e/H0kmK600<0kmK60`3gg/h20>oFaP<0mmJm00<0mlje0>o6]@3g
e[d00P3ge[d00`3_aZd0kkFL0=j]U0020=j]U0050=j]S03W]I@0ikFL0>NmY@3_aZd00P3_c[D0103_
a[D0mlJe0?O6]@3ge[d20>o>_@050?O6]@3_a[D0klJ]0>o6[@3_]I`00`3W]I`0103N[I@0gZF40=JL
N`3FW7<20<J4H`040;E[DP2LJdX0U6=2048Q60808A0800D0FS4Q058Y6024DST0S5Y207]::@0209AJ
<@0409aS>@24DS40W7=B0<JLQ080eYac00D0gZf40>o>[@2]Le80aXaS08aJ@P020;F4H`040:ecDP3W
_I@0iljm0=k>_@h0moOg4@00000X0?oooa<00000403gmoL30>oNcP80W7=B0P2mU7/309aS>@80_HaS
0`1[>B4207=:<@80DRTH0`1[>B4208aSBP80]G]J0`36Q6/20=JLN`80eZF<0`3W[H`20=JUQ0<0eYak
102mU7/30=JUS080_IAk0P3FW7<30>o6[@80mlje0P3_e/H30?O>]@80klJU0P3NYH@80>NeW080klJe
0P3_c[d30>o>]@80ilJe0P2mU7/30<jDJ`80W6]:0P1cBS4307=2:@80U6]B0P3_imhA000001h0oooo
000L0?oooa40000000D0mnog0?Ogm`3gmoL0moOg0?O_i`020<JDJ`80U6=200<0JcTQ07=2:@1c@RT0
0P1kBRT01024BS40NdXY048Q601S:A02048Q60040>o6[@3ga[D0kljm0?O6]@<0mmJm00<0kmK60?OF
_@3ge[d0103ge[d20?O>]@030?O6]@3_e/H0kmK60080kmK600<0mlje0>o6[@3W[I@00P3FYH`01@3N
YH@0gZf<0=JUS03N[I@0ikFL0080klJ]0P3_a[D00`3_c[D0mlje0>o6[@020>o6[@040>o6Y@3_aZd0
klJU0>neW080ijfD00D0ijf<0=j]S03NYH@0eYac0<J4J`020;EkFP040:ecDP2]Hd80LdXa024@2080
>AP@00D0FSTY07]J@P24DST0S5Y209AS@P0207]::@0408AB<@1cBS40W7=B0<J4FP80cYA[00D0gZf<
0>NmY@2eLdX0]G]J09acDP020;EkFP040<JDJ`3W_I`0ilJ]0<JLQ080g/jm00<0moOg0?O_m`3gmoL0
103gkoL30?Ogm`030?O_m`000000000001000000:03ooolC00000100moOg0`3_inL20:EkFP80aYA[
0`2DHd820:ecDP<0LdXa0P1J>BT2058Y60<0Q58i0P2<FT820:ecDP<0_HaS0P2eQ6<20=JUQ0D0ikFL
0`3W_JD20>o6[@80ikfU0`2eJe820:eS@P80ijfD0`3ge[d40>oFaPD0mmJm0P3W]I`309acDP80aXA[
0`3_e/H40?OF_@<0mlje0P3_c[D20;F<L`<0gXAc0P2LBS4209AS@P<0JcTQ0P2<FT820?oooa400000
7P3oool001`0oooo4@0000001@3gkoL0moOg0?Ogm`3gmoL0mnoW0080aYA[0P2DHd800`1[>B40Ld8Y
07=2:@0207]::@0408A:<@1kBRT0@R4H06<Y4080@R4H00@0klJ]0?O6]@3_c[d0mlJe0`3ge[d00`3_
e/H0mmJm0?OF_@040?OF_@80mlje00<0mlJe0>oFaP3_e/H00P3_e/H00`3gc[D0klJ]0>N]U0020=JU
S0050=jUQ03N[H`0eZF<0=j]U03W]I`00P3_aZd20>o6]@030>o>]@3gc[D0klJ]0080klJ]00@0klJU
0>o6[@3_aZD0kkFL0P3W[I@01@3W[H`0gZf<0=jUQ03FW7<0aXA[0080]G]J00@0[G=B0:eS@P1cBS40
8A080P0i61001@1J>BT0NeY208AB>@2<FT80U6=20080NdXY00@0Q58a07=:<@2LLe80aXAJ0P3>U6/0
1@3N[H`0ikfU0;EcBP2eNeX0W7=B0080]G]J00@0aYA[0>NmW03WaZd0aYb40P3Nc[d00`3gmoL0mnog
0?Ogm`040?O_m`<0moOg00<0mnog0000000000004000000X0?oooa<000004`3gmoL20;fDN`80_HaS
0`2DFS420:EkFP<0Q5Y20P1B8A0205Xa8@<0JcTQ0P2<FT8209a[BP<0]HA[0P3>U6/20;fDN`<0gZfD
0P3_]I`30>o6[@80ijfL0P2eJe8308AB>@80_HaS0P3_aZD30?O>]@80mmJm0P3_e/H50?OF_@80mlje
0`3FYH@209AcFP<0]HA[0P3_e/H20?OF_@<0ikfL0P3_aZd20<J4J`<0]G]J0P2LHcT208AB>@<0JcTQ
0P1kBRT20?oooa4000007P3oool001`0oooo4@0000000`3gmoL0mnoW0?Ogm`020?Ogm`80imK>00D0
_HaS09AS@P2DFT80JcTQ07=:<@0208A:<@0307=2:@1kBRT0Q4Xa00<0HbT@00<0YG]S0>O6[@3ga[D0
0P3ga[D20>oFaP<0mmJm00L0kmK60?O>]@3gc[D0mlje0?O6]@3ge[d0klJe00@0kmK600<0mlJe0>o6
Y@3W]I@00`3W[I`0103N[I@0gZf<0=jUQ03NYH@20>neW080klJ]00<0mlJe0>o6[@3_aZd00P3_aZd3
0>neW0050>NeU03W[H`0ijf<0=j]S03NW7/00P3NQ7<01`36Q6<0]G]J0;EkFP2]Jd80U6=202T@2012
8AP00P0i61001@1cBS40Q58i09AS@P1c@RT0W6]:0080Q58a00@0U5Xa05Xa8@36U6/0_HaS0P3F[H@0
1@3W_I`0]G]J0;f<H`2]Le80]G]J0080]HAS00@0_IAk0=J]S03Na[D0g/Je0P3F_Jd0103Nc[d0moOg
0?Ogm`3gkoL70?Ogma800000:03ooolC000001<0moOg0P2]Jd820=JLL`<0U6=20P2]Le8308ASBP80
DRTH0P1c@RT3048Q6080Q58i0P2LJdX30;f<H`80_IAk0P2eQ6/30:EkH`80aXA[0`3>JeX209acDP80
U7=J0`3FYH@20>o>[@80mlje1`3_e/H70?ONcP<0mmJm0P3gc[D30:ecDP80gXAc0P3FYH@30;fDN`80
ilJe0P2eQ6/309AJ@P80U5Xa0P24DST307=:<@80Ld8Y0P3ooolA000001h0oooo000L0?oooa400000
00<0moOg0?O_i`3gmoL00P3gmoL20>OFcP050;f<H`2DHd80U5Y206/i8@1cBS400P24BS400`1c@RT0
NdXY08A:<@0306<Y40030:EkH`3WaZd0mlJe0080mlJe0P3_e/H30?OF_@070>oFaP3gc[D0mlje0?O>
]@3ga[D0mmJm0>o6]@040>oFaP030?O6]@3_aZD0ikFD00<0ijfL00@0gZfD0=j]S03NYH@0gZF40P3_
]I`20>o6[@030?O6]@3_aZd0klJ]0080klJ]0`3_]I`01@3W]I@0ijf<0>N]S03N[H`0gYak0080gXAc
00L0aXAS0;EkFP2eNeX0[F]209AS@P0Y40P0@R4H0080>AP@00D0LdXa08AB>@2DHd80Ld8Y09a[BP02
08AB<@0409AJ<@1J<B40aYA[0;f<H`80eZf400D0ikfL0;EkFP2mS6<0[G=B0;EkFP020;F4H`040;fD
N`3F[H`0g/Je0=k6]@80e[f]00@0g/jm0?Ogm`3gmoL0mnog1`3gmoLB000002P0oooo4`00000C0?Og
m`80_HaS0P36W8@30:eS@P80S5Y20`2<HdX203TH4080FS4Q0`1cBS4208AB>@80W7=B0`2mS6<20=JL
L`D0_IAk1@2UNf<20>O6[@D0klJ]0P3gc[D20>oFaP<0mmJm0P3gg/h20>oFaP<0mmkF2@3gg/h30>oF
aP80gXAc0P3FYH@30>o>]@80ilJe0P2UNeX308aSBP80Q58i0P1cBS4308AB>@80LdXa0P2LLe8A0000
01h0oooo000L0?oooa40000000<0moOg0?O_i`3gmoL00P3gmoL20>OFcP050;f<H`2DHd80U5Y206/i
8@1cBS400P24BS400`1c@RT0NdXY08A:<@0306<Y40030:EkH`3WaZd0mlJe0080mlJe0P3_e/H30?OF
_@070>oFaP3gc[D0mlje0?O>]@3ga[D0mmJm0>o6]@040>oFaP030?O6]@3_aZD0ikFD00<0ijfL00@0
gZfD0=j]S03NYH@0gZF40P3_]I`20>o6[@030?O6]@3_aZd0klJ]0080klJ]0`3_]I`01@3W]I@0ijf<
0>N]S03N[H`0gYak0080gXAc00L0aXAS0;EkFP2eNeX0[F]209AS@P0Y40P0@R4H0080>AP@00D0LdXa
08AB>@2DHd80Ld8Y09a[BP0208AB<@0409AJ<@1J<B40aYA[0;f<H`80eZf400D0ikfL0;EkFP2mS6<0
[G=B0;EkFP020;F4H`040;fDN`3F[H`0g/Je0=k6]@80e[f]00@0g/jm0?Ogm`3gmoL0mnog1`3gmoLB
000002P0oooo4`00000C0?Ogm`80_HaS0P36W8@30:eS@P80S5Y20`2<HdX203TH4080FS4Q0`1cBS42
08AB>@80W7=B0`2mS6<20=JLL`D0_IAk1@2UNf<20>O6[@D0klJ]0P3gc[D20>oFaP<0mmJm0P3gg/h2
0>oFaP<0mmkF2@3gg/h30>oFaP80gXAc0P3FYH@30>o>]@80ilJe0P2UNeX308aSBP80Q58i0P1cBS43
08AB>@80LdXa0P2LLe8A000001h0oooo000L0?oooa4000001@3gmoL20>oWi`050=J]S02eQ6<0U6=2
08AB<@2<BS400P1[>B40101kBRT0Ld8Y07]::@24@RT206/a600305Xa8@3_a[D0ilJ]0080klJ]0P3g
c[D00`3ga[D0mmJm0?OF_@040?O>]@040?O6]@3_e/H0gYak0=ikJ`<0klJ]00<0kkFL0>NUU02eHd80
0P2eHd801@36Q6/0gYak0;EkFP3FW7<0gZf<0080ikFL0P3_aZD40>o6[@050>o6Y@3_]I`0ikFL0>N]
U03W[H`00`3NYH@0103FW7/0eYac0<jDJ`36Q6<20;E[DP040:eS@P1c@RT0>AP@048Y8@80FS4Q00<0
LdXa08AB>@24FT800P2LJdX208AB<@0409a[BP2<FT80_HaS0=j]Q080eYac00@0gZf40<J4FP2mS6<0
W6<i0`2eNeX0103FW7<0ikfD0=Jm[@3_inL20<j]U0030>oWi`3F]JD0moOg00P0moOg4P00000X0?oo
oa<000004`3gmoL20<JLQ080eZf40`2LJdX208aJ@P<0]Hac100i610306/i8@80W6]:0P2UNeX30;Ek
FP80_IAk0P3FW7/30=j]S080ikFL0`3WaZd40>o6[@<0klje0P3ge[d50>oFaPL0mmk>0P3gg]H70?ON
cPD0kmK60P3ge[d30>o>]@80klJ]0P2]Le8308aSBP80S5Y20P24DST308a[DP80LdXa0P2LJdXA0000
01h0oooo000L0?oooa4000001@3gmoL20>oWi`050=J]S02eQ6<0U6=208AB<@2<BS400P1[>B40101k
BRT0Ld8Y07]::@24@RT206/a600305Xa8@3_a[D0ilJ]0080klJ]0P3gc[D00`3ga[D0mmJm0?OF_@04
0?O>]@040?O6]@3_e/H0gYak0=ikJ`<0klJ]00<0kkFL0>NUU02eHd800P2eHd801@36Q6/0gYak0;Ek
FP3FW7<0gZf<0080ikFL0P3_aZD40>o6[@050>o6Y@3_]I`0ikFL0>N]U03W[H`00`3NYH@0103FW7/0
eYac0<jDJ`36Q6<20;E[DP040:eS@P1c@RT0>AP@048Y8@80FS4Q00<0LdXa08AB>@24FT800P2LJdX2
08AB<@0409a[BP2<FT80_HaS0=j]Q080eYac00@0gZf40<J4FP2mS6<0W6<i0`2eNeX0103FW7<0ikfD
0=Jm[@3_inL20<j]U0030>oWi`3F]JD0moOg00P0moOg4P00000X0?oooa<000004`3gmoL20=Jm[@80
eZf<0`2]Le8208aJ@P<0_IAk0P1J<B42058Y60<0Ld8Y0P2<FT820:ecDP<0_HaS0P2mU7/20=JLN`<0
eZF40P3W]I`30>o6[@80ilJ]0P3_a[D30?O6]@@0mmJm0`3gg/h40>oFaPD0mmk>0P3ge[d30?ONcP80
mmJm0`3gg/h20>oFaP80mmJm0`3_c[D20>O6[@80W7=B0`2<FT8408AJ@P<0U6]B0P24FT8208A::A40
00007P3oool001`0oooo4P0000020?O_m`80moOg0P3_inL01@3Na[D0aZFD0;fDN`2LJdX0W6<i0080
U6=200@0Q48Y07]::@1kBRT0LdXa0P1kBRT00`1[>B40]HAS0>O6]@020>o6]@D0mlje00@0mmJm0?O>
]@3gc[D0klje0`3gc[D30>o6[@040>NeW03N[H`0gZF40>N]U080gZfD00D0gZF40=j]S03W[I@0ikFD
0>NeW0020>nmW0040>NmY@3_aZD0klJ]0>o6[@<0kkFL00<0ikFL0>N]U03N[H`00`3NYH@20=JLN`03
0=JLL`3>U6/0aW]J0080]F]B00@0S5Y205Xi:@1[>B40FT8i0P24FT801@24DST0W7=B09AS@P2eLdX0
Q58a0080W6<i00@0Q58i0=J]S03W_I@0eYac0P3NYG/01@36S6<0aYA[0:EkFP2eNeX0_HaS0080aYb4
00@0eYac0>NmW03F]JD0aYA[0P3Wg]H00`3W_JD0mnog0>oWi`070?Ogma<00000:03ooolC000001<0
moOg0P3gkoL20;fDN`<0]G=:0P2LJdX30<JDJ`80>AP@1@1J<B4209a[BPD0]G]J0P3FW7<20=JUQ0<0
gZf<0P3W]I@30>NmY@80ilJ]0P3_aZd50?O>]@D0kmK63P3gg/h20?OF_@<0mmk>0P3ge[d20>o>_@<0
klje0P3W_I`209acDP<0Q58a0P24DST708aSBP80Q58i4@00000N0?ooo`00703ooolB00000080mnog
0P3gmoL20>oWi`050=k6]@36YI@0_IAk09a[BP2LHcT00P2DHd801024@RT0NdXY07]::@1cBS4207]:
:@0306/i8@2eQ6<0ilJe0080klJe1@3gc[D0103ge[d0mlje0?O>]@3_c[D30?O>]@<0klJ]00@0ikFL
0=j]S03NYH@0ijfD0P3N[I@01@3NYH@0gZf<0>N]U03W]I@0ikFL0080kkfL00@0ikfU0>o6Y@3_aZd0
klJ]0`3_]I`00`3W]I`0ijfD0=j]S0030=jUQ080eYak00<0eYac0<jDJ`36NeX00P2eJe80102<FT80
FSTY06/i8@1J@ST208AJ@P0508AB>@2LLe80U6=20;EcBP24DS400P2LHcT01024DST0eZf<0>NmU03F
W7<20=jUN`050<J<H`36U6/0YG]J0;EkFP2mS6<00P36W8@0103FW7<0ikfL0=JeY@36U6/20>ONeP03
0>NmY@3gkoL0knOW00L0moOg4`00000X0?oooaD000004`3gmoL209AS@P<0]G]J0P2eQ6<309acDP80
>AP@0P128AP305Xi:@80Q58i0P2]Le830;f<H`80cYA[0P3FYH@30=j]U080ikFL0`3W_I`20>neW080
klJ]0`3_cZd20?O>]@80mlJe1@3_e/H70?ONcP80mmJm1@3gg/h30>oFaP80mmJm0P3gc[D30>o>[@80
ikFL0P2eNeX708AB>@<0Q6=:0P24DSTC000001h0oooo000L0?oooa<000000P3gkoL0203gknL0mnog
0?O_m`3gkoL0g/k60<JLQ02eNeX0W6<i0P2LJdX00`24BRT0Q4Xa06/i8@0507]::@80klje00@0klJe
0>o>]@3_c[D0mlje0P3ga[D00`3gc[D0klje0>o>]@070?O>]@030>o>]@3_aZd0klJU00<0klJU00D0
ikFL0>NmW03__I`0ikFL0>NmY@020>NeW0030>o6Y@3W]I`0klJU00<0ikFL0P3W[I@00`3W]I@0gZf<
0=jUQ0020=jLN`050=jUQ03FW7<0cYA[0<jDJ`36Q6<00P2LJdX0101c@RT0FSTY03TH401cDT8208AB
>@0509AS@P2LHcT0[G=B09aS>@2eNeX00P2UNeX0103>U6/0ikfD0>NmU03>U6/20=JLL`050<J4FP2m
S6<0]G=:0;f<H`2eLdX00P3FW7<0103F[H@0ikfU0<j]U036U6/20=JLN`050>OFcP3_imh0knON0>OF
aP3gmoL00P3gkoL20?Ogma@00000:03ooolE000001<0moOg0P2DHd830;f<H`80W7=B0`2DLeX203TH
4080@R4H0`1cBS4208aJ@P80YG]S0`2eQ6<20<jDJ`80eZF40`3N[H`50>NeW080kkFL0P3_aZd30>o>
[@80mlje1@3ge[d20>oFaPL0mmk>0P3ge[d30?ONcP80mmJm0`3gg/h40?OF_@<0klje0P3N[H`20;f<
H`<0S6=:0P24FT8208aSBP<0S6]B0P24DSTC000001h0oooo000L0?oooa<000000P3gkoL0203gknL0
mnog0?O_m`3gkoL0g/k60<JLQ02eNeX0W6<i0P2LJdX00`24BRT0Q4Xa06/i8@0507]::@80klje00@0
klJe0>o>]@3_c[D0mlje0P3ga[D00`3gc[D0klje0>o>]@070?O>]@030>o>]@3_aZd0klJU00<0klJU
00D0ikFL0>NmW03__I`0ikFL0>NmY@020>NeW0030>o6Y@3W]I`0klJU00<0ikFL0P3W[I@00`3W]I@0
gZf<0=jUQ0020=jLN`050=jUQ03FW7<0cYA[0<jDJ`36Q6<00P2LJdX0101c@RT0FSTY03TH401cDT82
08AB>@0509AS@P2LHcT0[G=B09aS>@2eNeX00P2UNeX0103>U6/0ikfD0>NmU03>U6/20=JLL`050<J4
FP2mS6<0]G=:0;f<H`2eLdX00P3FW7<0103F[H@0ikfU0<j]U036U6/20=JLN`050>OFcP3_imh0knON
0>OFaP3gmoL00P3gkoL20?Ogma@00000:03ooolE000001<0moOg0P2DHd830;f<H`80W7=B0`2DLeX2
03TH4080@R4H0`1cBS4208aJ@P80YG]S0`2eQ6<20<jDJ`80eZF40`3N[H`50>NeW080kkFL0P3_aZd3
0>o>[@80mlje1@3ge[d20>oFaPL0mmk>0P3ge[d30?ONcP80mmJm0`3gg/h40?OF_@<0klje0P3N[H`2
0;f<H`<0S6=:0P24FT8208aSBP<0S6]B0P24DSTC000001h0oooo000L0?oooa<000000P3gkoL0203g
knL0mnog0?O_m`3gkoL0g/k60<JLQ02eNeX0W6<i0P2LJdX00`24BRT0Q4Xa06/i8@0507]::@80klje
00@0klJe0>o>]@3_c[D0mlje0P3ga[D00`3gc[D0klje0>o>]@070?O>]@030>o>]@3_aZd0klJU00<0
klJU00D0ikFL0>NmW03__I`0ikFL0>NmY@020>NeW0030>o6Y@3W]I`0klJU00<0ikFL0P3W[I@00`3W
]I@0gZf<0=jUQ0020=jLN`050=jUQ03FW7<0cYA[0<jDJ`36Q6<00P2LJdX0101c@RT0FSTY03TH401c
DT8208AB>@0509AS@P2LHcT0[G=B09aS>@2eNeX00P2UNeX0103>U6/0ikfD0>NmU03>U6/20=JLL`05
0<J4FP2mS6<0]G=:0;f<H`2eLdX00P3FW7<0103F[H@0ikfU0<j]U036U6/20=JLN`050>OFcP3_imh0
knON0>OFaP3gmoL00P3gkoL20?Ogma@00000:03ooolE000001<0moOg1@36U6/20:ecDP<0S6=:0P0Y
40P203TH40<0JcTQ0P2<FT8209a[BP<0]HAS0P3>U6/20=JUQ0<0gZf<0P3W]I@30>NmW080klJU1@3_
aZd40?O>]@<0mmJm103_e/H50?OF_@80mmk>0`3ge[d20?ONcPD0mmJm0P3gc[D30>o6[@80eZF<0P2e
Q6/308aSBP80NeY20P2<HdX309A[DP80S5Y24`00000N0?ooo`00703ooolC000000030?O_i`3gmoL0
mnog0080knoW00D0mnoW0>oWgP3Nc/H0eZf<0;F4H`0309a[BP0308aJ@P2<BRT0Q4XY0080Ld8Y00D0
NdXY08A28@24DS40klje0>o6[@020>o>]@040>o>[@3_aZd0klj]0>o6Y@80klj]0P3gc[D00`3ge[d0
kmK60>o6]@020>o6[@040?OF_@3_aZd0klJU0?O>]@80mmJm00D0klJe0>o6[@3W_JD0ikFL0>NmY@02
0>NeW080ikFD00H0ikFL0>NeU03W]I`0ikFL0>NeU03W[I@20=j]S0<0gZF400D0eYak0=JLL`3>U6/0
cYA[0;EkFP0208AB<@04048a:@0Y40P0Q5Y207=:<@80Q5Y200D0W7=B0;f<H`2LHcT0aXAJ0:e[@P02
0<J4FP80ikfL00@0eYac0<jDJ`2mS6<0_HaS0P2eLdX00`2mS6<0cYA[0=JLL`020<jDJ`040>NmY@3W
aZd0aYb40<JLQ080aXaS00D0imkF0>oWgP3_imh0knOW0>oWgP040?Ogma@00000:03ooolE000001<0
moOg0P3Wg]H30<JDJ`80U6=20`2DJe8402T@20<0FS4Q0P1cBS4209A[DP<0]HA[0P3FW7<20=JUQ0<0
gZf<0P3N[I@30>NeW080kkFL0P3_aZd30?O6]@@0mmJm0`3_e/H20?OF_@80kmK60`3gg/h40?OF_@<0
mmk>0P3_e/H30?ONcP80mmJm0P3gc[D30>o6[@80eZF40P2mS6<308aSBP80W6<i0P2<FT8308aSBP80
YG]J4`00000N0?ooo`00703ooolC000000030?O_i`3gmoL0mnog0080knoW00D0mnoW0>oWgP3Nc/H0
eZf<0;F4H`0309a[BP0308aJ@P2<BRT0Q4XY0080Ld8Y00D0NdXY08A28@24DS40klje0>o6[@020>o>
]@040>o>[@3_aZd0klj]0>o6Y@80klj]0P3gc[D00`3ge[d0kmK60>o6]@020>o6[@040?OF_@3_aZd0
klJU0?O>]@80mmJm00D0klJe0>o6[@3W_JD0ikFL0>NmY@020>NeW080ikFD00H0ikFL0>NeU03W]I`0
ikFL0>NeU03W[I@20=j]S0<0gZF400D0eYak0=JLL`3>U6/0cYA[0;EkFP0208AB<@04048a:@0Y40P0
Q5Y207=:<@80Q5Y200D0W7=B0;f<H`2LHcT0aXAJ0:e[@P020<J4FP80ikfL00@0eYac0<jDJ`2mS6<0
_HaS0P2eLdX00`2mS6<0cYA[0=JLL`020<jDJ`040>NmY@3WaZd0aYb40<JLQ080aXaS00D0imkF0>oW
gP3_imh0knOW0>oWgP040?Ogma@00000:03ooolE000001D0moOg0`36W8@209aS>@<0U6]B100i6103
05Xa8@80NeY20P2LLe830:EkH`80eYak0P3FYH@30=j]S080gZfD0`3W]I`20>neW080klJ]0`3gc[D2
0?O6]@L0mmJm0P3_e/H<0?OF_@<0mmk>0P3_e/H20?OF_@<0klJ]0P3FYH`20;F<L`<0S6=:0P24DST2
08AB<@<0Q58i0P1kFT8C000001h0oooo000L0?oooa@0000000<0mnog0?Ogm`3gkoL00`3gkoL00`3W
e/h0e/Je0=JLL`020<JDJ`040:ecDP2DHd80S4Xa09AJ<@80Q4XY00@0Jc4H07]28@1[<AP0U5Xa0`3_
c[d0103_c[D0klJ]0>o6[@3_aZD20>N<N`050=j4L`2]Le80W4Xa0:e:<@2mDT800P2]Le820;eB@P09
0<IJBP2eDST0W4Xa09a:<@2L<B40W48Y0:e:<@2<<B40[D8a0080W48Y00<0Q48Y09AJ@P3NQ7<0103W
]I@30=j]S0<0eYak00D0eYac0=JLN`36Q6<0]G]J08aJ@P0204XH200403TH401[>B40LdXa08AJ@P80
_HaS00D0eZF409AJ<@3FYH@0]G]J0=JLN`020>NmW0040>o>[@3>U6/0cYA[0;E[>@80aXAJ00D0]G]J
0;f<H`36S6<0]G]J0=J]Q0020>NmU0040>NmY@3F_Jd0eYac0=J]Q080aYb400D0e[FU0>ONeP3_knL0
knON0>o_i`020?O_m`030>o_i`000000000001<00000:03ooolH00000180moOg0`3>]JD209AS@P<0
U6]B0P0i610202T@20<0@R4H0P1[>B4208aSBP<0]HA[0P2mU7/20=JUQ0<0eZF<0P3N[I@30>nmW080
klJU1`3gc[D90?OF_@<0mmk>0P3_e/H50?ONcPD0mmJm0P3_e/H20?O6]@<0klJ]0P3F[H`20;F<L`<0
W6]:0P1kFT8207=B@P<0LdXa5@00000N0?ooo`00703ooolD000000030?O_m`3gmoL0mnog00<0mnog
00<0imK>0=K6]@3FW7<00P36U6/0102]Le80U6=208a:<@2DFS4208A::@0406/a601k@R40Jc4H09AJ
<@<0kljm00@0klje0>o6[@3_aZd0klJU0P3WS7/01@3NQ7<0[G=B09a:<@2]BS40_E920080[G=B0P2m
DT802@36FTX0]E8i09a:<@2LBS40W34Q09a2:@2]BS40S34Q0:e2<@0209a2:@0308A2:@2DFT80gXAc
00@0ikFD0`3N[H`30=JLN`050=JLL`3FW7/0aXAS0;EkFP2<FT800P1:60P0100i6100JcTQ07=:<@24
FT820;f<H`050=JUQ02DFS40eZF40;EkFP3FW7/00P3W_I`0103_cZd0cYA[0<jDJ`2eJcT20<J4FP05
0;EkFP2mS6<0aXaS0;EkFP3F[H@00P3W_I@0103W_JD0e[f]0=JLL`3F[H@20<JLQ0050=JeY@3Wg]H0
knoW0>oWgP3_knL00P3gkoL00`3_knL000000000000C000002P0oooo6000000B0?Ogm`<0ikfL0P2]
Le830;F4J`80@R4H0P0a61P3048Q6080FSTY0P2LLe830:EkH`80cYA[0P3FYH`30=j]S080gZfL0`3W
]I`20>o6Y@80klJ]0`3ga[D70?OF_@L0kmK6303gg/h20>oFaP80mlje0`3_aZd20=j]W080]Hac0`2L
JdX207=B@PD0Q58i5@00000N0?ooo`00703ooolE000000<0moOg00D0mnoW0?Ogm`3_inL0imkF0>OF
aP020=J]S0040<JDJ`2UNeX0W6]:09aS>@80U5Xa00D0NdXY08AB>@1c@RT0JcTQ07]::@020>o>_@04
0>o6]@3_aZd0klJ]0>o6Y@80klj]00<0klJ]0>N<N`3NQ7<00P3NQ7<20>o6]@040>neW03WS7/0ihak
0>NUU080kkFL0P3NQ7<00`3NNf/0aXA[0<icH`020<i[FP040=JLN`3N[H`0gZfD0>NeU080ikFL00D0
gZfD0=j]S03N[H`0eZF40=JLN`020<jDJ`040=j4L`36Q6<0]G]J07=:<@<0DRTH00@0DR4@08AB>@1B
:AP0eZF40P3N[H`01@2LHcT0eZf<0;EkFP3NYG/0eZf40080_HaS00@0aXAJ0<jDH`2]Hc40aXAJ0P2e
NeX01@2mS6<0aYA[0<jDJ`3FW7/0eZf<0080ikfU00@0ilJe0;fDN`2eQ6<0aYA[0P3FW7<00`3>[I@0
knON0>oWgP020>o_i`80knON5P00000X0?oooaP000004P3gmoL30=k>cP80aXAJ0`2eQ6<203TH4080
DRTH0`12:B4205Xi:@80S6=:0`2UNf<20;F<L`80eYak0`3N[H`20>NeU0<0ikfU103_aZd50?O>]@80
mmJm0`3_e/H20?OF_@80kmK61@3ge[d20>oFaPX0mmJm0P3_c[D30>o6[@80gZfD0P2mU7/309A[DP80
NeY20P1cDT8307=:<AD000007P3oool001`0oooo5@0000030?Ogm`050?O_i`3gmoL0knOW0>ONeP3W
e/H00P3F[H`01036U6/0YG]J09a[BP2LHcT209AJ<@0507]::@24DST0Ld8Y06/i8@1kBRT00P3_c[d0
103_a[D0klJ]0>o6[@3_aZD20>o>[@030>o6[@3WS7/0gXAc0080gXAc0P3_a[D0103_]I`0ihak0>N<
N`3WYI@20>neW080gXAc00<0gW][0<J4J`3>Lf<00P3>JeX0103FW7/0gZf<0=j]U03W]I@20>NeW005
0=j]U03N[H`0gZf<0=JUQ03FW7/00P3>U6/0103NQ7<0aXAS0;EkFP1cBS43058Y6004058Q4024DST0
DRTH0=JUQ080gZf<00D0W6<i0=J]S02eNeX0gZEk0=J]Q0020;f<H`040<J4FP3>U6<0[F<a0<J4FP80
]G]J00D0_HaS0<JDJ`3>U6/0eYak0=J]S0020>NmY@040>O6]@2mU7/0]HAS0<JDJ`80eYac00<0cZfD
0>oWgP3_imh00P3_knL20>oWgQH00000:03ooolH00000180moOg0`3Nc/h20<J4FP<0]HAS0P0i6102
058Y60<0@RTQ0P1J>BT208aSBP<0YG]S0P2eS7<20=JLN`<0gZf<0P3W]I@30>NmY@@0klJ]1@3gc[D2
0?OF_@<0kmK60P3ge[d20>oFaPD0mmJm0P3_e/H:0?OF_@80klje0`3_aZd20=j]U080_IAk0`2DJe82
07]J@P80Le920`1cBS4E000001h0oooo000L0?oooaD000000`3gmoL01@3gknL0moOg0>oWi`3Wg]H0
imK60080eZf<00@0aYA[0:EkFP2LJdX0W6<i0P2DFS401@1kBRT0Q58i07=2:@1[>B40NdXY0080kljm
00@0klJe0>o6[@3_aZd0klJU0P3_cZd00`3_aZd0ihak0=j4L`020=j4L`80klJe00@0kkFL0>N<N`3W
S7/0ijFD0P3_]I`20=j4L`030=ikJ`36Q6/0cW=S0080cV]J00@0eYak0=j]S03N[I@0ikFD0P3W]I`0
1@3N[I@0gZf<0=j]S03FYH@0eYak0080cYA[00@0gXAc0<J4H`2eNeX0LdXa0`1B:AP0101B8A00Q58i
058Y603FYH@20=j]S00509aS>@3F[H`0]G]J0=jUN`3F[H@00P2mS6<01036Q5X0cYAS0:eS<@36Q5X2
0;EkFP050;f<H`36U6/0cYA[0=JLN`3F[H`00P3W_JD0103Wa[D0_IAk0;F4H`36U6/20=JLL`030<j]
U03_imh0knON0080knoW0P3_imhF000002P0oooo6000000B0?Ogm`<0knoW0P2mS6<309acDP80:A08
1@1B:AP205Xi:@80S5Y20`2]Le820;F<L`80gZF40`3N[H`20>N]U0<0ikfL0P3_aZd20>o6Y@<0klj]
103gc[D70?OF_@D0kmK60P3ge[d30>oFaP80mmk>0`3_e/H20?OF_@80mlje0`3_aZd20>NmY@80aYA[
0`2DJe8407]J@P<0Le925@00000N0?ooo`00703ooolF000000<0moOg0P3gkoL01P3_inL0imK60=k>
_@3Nc[d0eZf<0<JDJ`80]G=:0P2]Hd801@2<BS40U5Xa08AB<@1[<AP0JcTQ0080Q4XY00@0ilJe0>o>
]@3_c[D0mlje0P3_cZd20>o6[@030>o6Y@3W_JD0ijfD0080ijf<00<0gZF40=jLN`3WS7/01@3WS7/0
0`3NYH@0gYak0=jUQ0020=j]S0040=jUQ03W]I@0ikFD0>NeW080gZfD00@0gZf<0=jUQ03FYH@0eYak
0`3>U6/01@36Q6<0S5Y208A2:@1kBRT0JcTQ0080DRTH00@0JcTQ08aSBP3>U6/0[G=B0P2DFS401@3F
YH@0aW]:0<jDH`2eNeX0W6<i0080[F]200@0cXaJ0<IkBP2eLdX0_HaS0P2eNeX01@3FW7<0aYA[0=J]
Q03FW7<0eZf40080ilJ]00@0eZf40=JLL`36W8@0aYb40P3FW7<01@3F[H`0ikfU0>oWgP3_imh0mnoW
01P00000:03ooolJ000001<0moOg0P3>U6/309acDP80FSTY0P0i610305Xa8@80LdXa0P24DST30:Ek
FP80]Hac1@3FYH@20=j]U0<0ikfL0P3_]I`50>o6Y@80mlJe1@3gc[D70?OF_@80kmK60P3gg/h30?OF
_@D0kmK6103gc[D30>o6[@80ikFL0P2eS7<309A[DP80NeY20P2DJe8H000001h0oooo000L0?oooaH0
00000`3gmoL20?O_m`060>oWi`3We/H0g/jm0=k>_@3F[H`0aYA[0P2eLdX20:eS@P0508a:<@2DFS40
Q58a06/a601[>B400P24BRT0103Wa[D0klje0>o>]@3gc[D20>o>[@80klJ]00<0klJU0>NmY@3W[I@0
0P3W[H`00`3NYH@0gYak0>N<N`050>N<N`030=jUQ03NW7/0gZF40080gZf<00@0gZF40>NeU03W]I@0
ikFL0P3N[I@0103N[H`0gZF40=JUQ03FW7/30<jDJ`050<J4H`2<FT80Q48Y07]::@1[>B400P1B:AP0
101[>B40S6=:0<jDJ`2]Le8209AJ<@050=JUQ036NdX0cYAS0;EkFP2LHcT00P2]Jd80103>S5X0aW]:
0;EcBP2mS6<20;EkFP050=JLL`36U6/0eZf40=JLL`3F[H@00P3WaZd0103F[H@0eYac0<JLQ036W8@2
0=JLL`050=J]S03W_JD0knON0>oWgP3gknL06000000X0?oooaX000004`3gmoL20<J<H`<0U6=20P2U
NeX2024H60<0@RTQ0P1J>BT208AJ@P<0U5Y20P2mS6<20;fDN`<0eYak0P3W]I@30>NeW080kkfL0P3_
aZD50>o6[@80mmJm0`3gc[D>0?OF_@80kmK60`3gc[D20?OF_@80mlje0`3_aZd20=j]U080_IAk1@2<
HdX209A[DQP000007P3oool001`0oooo600000020?Ogm`030?O_m`3_inL0knOW0080iljm00@0g/jm
0<JLQ036S6<0[G=B0P2eLdX01@2DHd80U5Xa09AJ<@24DS40JcTQ0080Jc4H00@0Q4XY08AJ@P3_a[D0
klJ]0P3_cZd30?O>]@030?O6]@3_cZd0klJ]00D0klJ]0P3_aZD20>neW0030>NmY@3_aZD0ikfL0080
kkfL0P3W]I`02@3N[H`0ijf<0=j]U03N[I@0gZf<0=jUQ03FW7<0cYA[0<j<H`0209aS>@0409a:<@2L
HcT0S4Xa08a::@<0JcTQ00@0Q58i0;f<H`2eNeX0W6]:0P36W8@01@2<@R40]G]J09AJ<@2]Hd80]F]2
0080aW]:00@0[F/i0<IkBP2mS6<0W6<i0`2mS6<20=JLL`080<j]U03N[H`0ikfD0>NmU02mS6<0]F]2
0;f<H`36W8@20<JDJ`040=J]Q03W_I@0imK>0>o_iaT00000:03ooolJ000000h0moOg0P3gkoL30?Og
m`80e[FU0`2DHd8209akH`80:A080`1B:AP205Xa8@80Q5Y20`2DHd820:EkH`80eZF40`3FYH`20=j]
U0<0ikFL0P3_]I`50>o6Y@@0klJ]1`3gc[D<0?OF_@<0mlje0P3_cZd20>o6[@<0kkFL0P3N[I`20;f<
H`<0S6=:0P1cDT8208AB>AP000007P3oool001`0oooo600000020?Ogm`030?O_m`3_inL0knOW0080
iljm00@0g/jm0<JLQ036S6<0[G=B0P2eLdX01@2DHd80U5Xa09AJ<@24DS40JcTQ0080Jc4H00@0Q4XY
08AJ@P3_a[D0klJ]0P3_cZd30?O>]@030?O6]@3_cZd0klJ]00D0klJ]0P3_aZD20>neW0030>NmY@3_
aZD0ikfL0080kkfL0P3W]I`02@3N[H`0ijf<0=j]U03N[I@0gZf<0=jUQ03FW7<0cYA[0<j<H`0209aS
>@0409a:<@2LHcT0S4Xa08a::@<0JcTQ00@0Q58i0;f<H`2eNeX0W6]:0P36W8@01@2<@R40]G]J09AJ
<@2]Hd80]F]20080aW]:00@0[F/i0<IkBP2mS6<0W6<i0`2mS6<20=JLL`080<j]U03N[H`0ikfD0>Nm
U02mS6<0]F]20;f<H`36W8@20<JDJ`040=J]Q03W_I@0imK>0>o_iaT00000:03ooolL000000`0moOg
0P3oool30?Ogm`80ikfU0`2]Le820:EkFP80NeY20`0i610209A[DP80LdXa0`2LJdX20:EkH`80cYA[
0`2mU7/20=j]S0<0ikFD0P3__I`20>o6Y@<0klJ]0P3_aZD70>o6[@80mmJm0`3gc[D40?OF_@<0mlje
0P3_c[d30?OF_@80mlje0P3_aZD30>O6[@80gZfD0P2mS6<50:EkFQX000007P3oool001`0oooo6000
00020?Ogm`030?O_m`3_inL0knOW0080iljm00@0g/jm0<JLQ036S6<0[G=B0P2eLdX01@2DHd80U5Xa
09AJ<@24DS40JcTQ0080Jc4H00@0Q4XY08AJ@P3_a[D0klJ]0P3_cZd30?O>]@030?O6]@3_cZd0klJ]
00D0klJ]0P3_aZD20>neW0030>NmY@3_aZD0ikfL0080kkfL0P3W]I`02@3N[H`0ijf<0=j]U03N[I@0
gZf<0=jUQ03FW7<0cYA[0<j<H`0209aS>@0409a:<@2LHcT0S4Xa08a::@<0JcTQ00@0Q58i0;f<H`2e
NeX0W6]:0P36W8@01@2<@R40]G]J09AJ<@2]Hd80]F]20080aW]:00@0[F/i0<IkBP2mS6<0W6<i0`2m
S6<20=JLL`080<j]U03N[H`0ikfD0>NmU02mS6<0]F]20;f<H`36W8@20<JDJ`040=J]Q03W_I@0imK>
0>o_iaT00000:03ooolL000000`0moOg0P3oool30?Ogm`80ikfU0`2]Le820:EkFP80NeY20`0i6102
09A[DP80LdXa0`2LJdX20:EkH`80cYA[0`2mU7/20=j]S0<0ikFD0P3__I`20>o6Y@<0klJ]0P3_aZD7
0>o6[@80mmJm0`3gc[D40?OF_@<0mlje0P3_c[d30?OF_@80mlje0P3_aZD30>O6[@80gZfD0P2mS6<5
0:EkFQX000007P3oool001`0oooo6P0000000`3gmoL0mnog0>o_i`020>oWi`040=k>_@3F_Jd0_IAk
0;f<H`80]G]J00<0[F]209AS@P2LHcT00P2DFS4206/i8@0406/a601k@R40JcTQ0:F4J`80klje00@0
mlje0>o6[@3gc[D0mlje1@3ge[d00`3_e/H0mmJm0?O6]@020?O6]@<0klJ]00L0ikfU0>NeW03W]I`0
ikfL0>NeU03W[H`0gZfD0080gZF400<0eYak0<J4J`3>U6/00P2]Hd820:e[@P0509a[BP2]Hd80U6=2
09a:<@24BS400P1c@RT01036NdX0[G=B0;EkFP2eLdX206/a6005058Q401k@R40W6<i0<IkBP36Q5X0
0`36NdX00`36Q5X0[F]20<J<H`020;f<H`050<JDJ`3FW7<0eZf40>NmW03W_I@00P2mS6<0102eLdX0
_HaS0<IkBP36U6/20=JeY@030>NmU03>]JD0000001X00000:03ooolL000000h0moOg0`3oool20=Jm
[@<0_HaS0P2LLe8207=2:@D0FSTY0P24DST308AJ@P80W7=B0P2eQ6/30;fDN`80gZf<0`3N[I@20>Ne
U080klJU0`3_aZd40>o6Y@L0klJ]0`3ga[D90?O>]@<0mmJm0P3ga[D20>o6Y@<0ikfU0P3N[I@20;f<
H`<0YG]S0P24DSTJ000001h0oooo000L0?oooaX0000000<0moOg0?O_m`3_knL00P3_inL0103Nc[d0
e[f]0;fDN`2mS6<20;EkFP030:e[@P2DHd80W6<i0080U5Xa0P1[>B40101[<AP0Nd8Q06/i8@2UQ6/2
0>o>]@040?O>]@3_aZd0mlje0?O>]@D0mmJm00<0kmK60?OF_@3ga[D00P3ga[D30>o6[@070>NmY@3W
]I`0ikFL0>NmW03W]I@0ijf<0=j]U0020=jUQ0030=JLN`36Q6/0cYA[0080[F=20P2]Jd801@2LJdX0
[F=209AS@P2LBS40Q4Xa0080Ld8Y00@0aW]:0:ecDP2eNeX0]G=:0P1[<AP01@1B8A00Nd8Q09aS>@36
NdX0aXAJ00<0aW]:00<0aXAJ0:e[@P36S6<00P2mS6<01@36U6/0eYac0=J]Q03W_I`0ikfD0080_HaS
00@0]G=:0;f<H`36NdX0aYA[0P3F]JD00`3W_I@0c[FU0000000J000002P0oooo7000000:0?Ogm`80
oooo1`3gmoL30<JDJ`80W6]:0P2DJe8305Xa8@80FT8i0P1cBS4307=B@P80YG]J0P2eQ6/30;fDN`80
eYak0`3FYH`20>N]U080ikFL0`3_]I@20>neW080klJU0`3_]I@20>NeW080klJU0`3_aZd20>o6]@80
mlje0`3ga[D20>o6]@<0klje0P3ga[D20>o6Y@<0ikFL0P36W8@20;F4H`<0S5Y20P24DS4J000001h0
oooo000L0?oooa/0000000<0knog0?O_i`3gkoL00P3gkoL00`3Wc[d0cZfD0<JDJ`020;f<H`050:ec
DP2]Jd80[F]209aS>@2DFS400P2LHcT00`1S:A00JcTQ07]::@0306/i8@050;F<L`3_a[D0mlje0?OF
_@3gc[D00P3ge[d0103ga[D0mmJm0?O6]@3gc[D20?O6]@030>o6[@3_aZD0klJ]0080kkFL0P3W[I@0
103W[H`0gZF40=jUN`3FW7<20<jDJ`@0]G=:00P0aW]:0;EcBP2eLdX0]G]J0;EcBP2]Hd80W6]:08AB
>@80Q48Q00@0]G=:09AJ<@36Q5X0NcTH0P1[<AP01@1B8A00HbT@0:e[>@2eJd80U58Y0080]F]200@0
cXaJ0:e[>@2mS6<0]G=:0P36Q5X01@3FW7<0gZf40>NmU03W_JD0eZf<0080]F]20P2mS6<01@3>U6/0
aXaS0=JLL`3FW7<0eZf<01`00000:03ooolO000000T0moOg0P3oool30?Ogm`80mnog0`3W_I`20;f<
H`80U7=J0`2<Je8207]J@P80Le920`24FT8209acDP80]HAS0`2eQ6/20=JLL`<0eZF40P3N[H`20>N]
U0<0gZF4103W[H`30>NeU080ijfD0P3W]I`30>o6[@80klJU0P3_a[D30>o6[@80klje0`3WaZd20>o6
Y@80kkFL0`3N[I`20=JUS080YHA[0`24DSTL000001h0oooo000L0?oooa/0000000<0knog0?O_i`3g
koL00P3gkoL00`3Wc[d0cZfD0<JDJ`020;f<H`050:ecDP2]Jd80[F]209aS>@2DFS400P2LHcT00`1S
:A00JcTQ07]::@0306/i8@050;F<L`3_a[D0mlje0?OF_@3gc[D00P3ge[d0103ga[D0mmJm0?O6]@3g
c[D20?O6]@030>o6[@3_aZD0klJ]0080kkFL0P3W[I@0103W[H`0gZF40=jUN`3FW7<20<jDJ`@0]G=:
00P0aW]:0;EcBP2eLdX0]G]J0;EcBP2]Hd80W6]:08AB>@80Q48Q00@0]G=:09AJ<@36Q5X0NcTH0P1[
<AP01@1B8A00HbT@0:e[>@2eJd80U58Y0080]F]200@0cXaJ0:e[>@2mS6<0]G=:0P36Q5X01@3FW7<0
gZf40>NmU03W_JD0eZf<0080]F]20P2mS6<01@3>U6/0aXaS0=JLL`3FW7<0eZf<01`00000:03ooolO
00000100moOg0`3W_I`20;F4H`D0W6]:0P2<HdX209A[DP<0LeY:0P2DLeX209a[BP<0]HA[0P2mU7/3
0<J4J`@0cYA[0`3FW7<20=JLN`80eYac0`3FW7/20=JUQ080gZfD0`3N[H`20>NeW0D0ikfU1@3_aZd2
0>NeW080e[FU0`3W_I`20;fDN`80W7=B0`2DJe8L000001h0oooo000L0?oooad000000`3_koL00`3_
imh0g/Je0=J]Q0020<JDJ`050;EkFP2eLdX0[F]209aS>@2eLdX00P2LBS400`2DFS40DR4@07=2:@03
06/i8@0406/a6024DS40gZfD0>O6[@@0klJ]0P3_aZD40>neW0040>N]W03W[I@0ijfD0=j]S080gZF4
00@0eYak0<IkFP36NeX0aW]:0`36NeX30;EkFP060<J4FP36NeX0aW]J0;EkFP36NdX0]G=:0P2]Jd82
0<IkBP0408a::@2<BS40W6<i08aJ@P80Q48Q00D0Jc4H06/i8@2]Hc40Q48Q09aS>@020<IkBP040<Ik
@P2eLdX0[F/i0;EcBP80cXaJ00@0eYak0=j]Q03N[H`0eZf40`36U6/0102eNeX0]F]20=J]Q03F[H@O
000002P0oooo7`0000070?Ogm`80mnog1`3gmoL30=Jm[@80cZfD1@2eNeX206/i8@80YG]S0`2<HdX2
0:EkH`80YHac0`2mU7/20:EkH`<0]HA[0P2eQ6<20;EkFP<0]Hac0P3>U6/20=JLN`<0cYA[0P36W8@2
0=JUS0<0gZF40P3W_I`20=JUQ0<0gZfD1@3W_JD20>o6Y@80e[FU0`2mU7/20:EkJ`80YG]J0`2<HdXL
000001h0oooo000L0?oooad000000`3_koL00`3_imh0g/Je0=J]Q0020<JDJ`050;EkFP2eLdX0[F]2
09aS>@2eLdX00P2LBS400`2DFS40DR4@07=2:@0306/i8@0406/a6024DS40gZfD0>O6[@@0klJ]0P3_
aZD40>neW0040>N]W03W[I@0ijfD0=j]S080gZF400@0eYak0<IkFP36NeX0aW]:0`36NeX30;EkFP06
0<J4FP36NeX0aW]J0;EkFP36NdX0]G=:0P2]Jd820<IkBP0408a::@2<BS40W6<i08aJ@P80Q48Q00D0
Jc4H06/i8@2]Hc40Q48Q09aS>@020<IkBP040<Ik@P2eLdX0[F/i0;EcBP80cXaJ00@0eYak0=j]Q03N
[H`0eZf40`36U6/0102eNeX0]F]20=J]Q03F[H@O000002P0oooo8@0000090?Ogm`<0mnog1@3gmoL2
0=JeY@80aYA[0`2UNeX209a[BP80Q5Y21@2LLe820:ecDP<0U6]B1@2UNf<409acDP<0W6]:0P2eQ6<2
0:ecDPD0]Hac0P36U6/30=JUQ0@0eZF<0`3>[I@20=j]W0<0ikfU103Wa[D30<JLQ080S6=:0P2LLe8O
000001h0oooo000L0?oooad000000`3_koL00`3_imh0g/Je0=J]Q0020<JDJ`050;EkFP2eLdX0[F]2
09aS>@2eLdX00P2LBS400`2DFS40DR4@07=2:@0306/i8@0406/a6024DS40gZfD0>O6[@@0klJ]0P3_
aZD40>neW0040>N]W03W[I@0ijfD0=j]S080gZF400@0eYak0<IkFP36NeX0aW]:0`36NeX30;EkFP06
0<J4FP36NeX0aW]J0;EkFP36NdX0]G=:0P2]Jd820<IkBP0408a::@2<BS40W6<i08aJ@P80Q48Q00D0
Jc4H06/i8@2]Hc40Q48Q09aS>@020<IkBP040<Ik@P2eLdX0[F/i0;EcBP80cXaJ00@0eYak0=j]Q03N
[H`0eZf40`36U6/0102eNeX0]F]20=J]Q03F[H@O000002P0oooo8@0000090?Ogm`<0mnog1@3gmoL2
0=JeY@80aYA[0`2UNeX209a[BP80Q5Y21@2LLe820:ecDP<0U6]B1@2UNf<409acDP<0W6]:0P2eQ6<2
0:ecDPD0]Hac0P36U6/30=JUQ0@0eZF<0`3>[I@20=j]W0<0ikfU103Wa[D30<JLQ080S6=:0P2LLe8O
000001h0oooo000L0?oooal0000000@0knoW0?O_m`3Wg]H0e[FU0P3F[H@0102mS6<0]G]J0:e[@P2L
JdX309AJ<@0409aS>@2<BRT0NcTH06/a60<0JcTQ00<0NcTH0=j]U03N[I@00`3N[H`0103W[H`0gZf<
0=jUQ03N[H`30=jUQ0030=JLN`3NW7<0gYac00@0cYA[00<0aXA[0<j<H`3>S6<00P36Q6/20<jDJ`03
0<J4J`3>U6/0cYA[0080cYA[00D0aXAS0<J4FP36Q6<0aXAJ0;EcBP020<j<FP040:e[@P2<BRT0W6]:
09a[BP80W6<i00D0U5Xa08A28@1k@R40HbT@0:eS<@020<Ik@P040;ES<@36Nd80]F]20<IkBP80cYAS
00<0gZEc0=JLN`3N[H@00P2mS6<20<jDH`030;f<H`3>U6/0aYA[02000000:03ooolQ000000T0moOg
0`3oool50?Ogm`80eZf<0P3>]JD30;F4H`L0U6=20P2DLeX209akH`<0U6]B0P2US7<30:EkFP80]HA[
0P2mU7/30:EkFP80YG]S1@2mU7/20;F4J`80aXA[1`36W8@50=JUS0<0gZfL0P3F_Jd20<jUU0<0_Ib<
0P36YI@209acHal000007P3oool001`0oooo7`000000103_knL0mnog0>ONeP3F]JD20=J]Q0040;f<
H`2eNeX0[F]209a[BP<0U5Xa00@0W6<i08a::@1k>AP0Jc4H0`1[>B400`1k>AP0gZfD0=j]U0030=j]
S0040>N]S03N[H`0gZF40=j]S0<0gZF400<0eYak0=jLL`3NW7<0103>U6/00`36Q6/0cXaS0<j<H`02
0<J4J`80cYA[00<0aXA[0<jDJ`3>U6/00P3>U6/01@36Q6<0aXAJ0<J4H`36Q5X0]G=:0080cXaJ00@0
[F]208a::@2LJdX0W6]:0P2LHcT01@2DFS40Q48Q07]28@1S:A00[F<a0080aW]200@0]F<a0<Ik@P2e
Jd80aW]:0P3>U6<00`3NYG<0eYak0=j]Q0020;f<H`80cYAS00<0_HaS0<jDJ`36U6/08000000X0?oo
ob<000003`3gmoL20;F4H`80_Ib<0`3F[H@20;EcBP80NeY20`24DST208aSBP80LdXa0`24FT8209A[
DP<0]HA[0P2LLe820<JDJ`<0YG]J0P2LLe820:EkFP<0U6=20P2LLe890;fDN`D0aYb40`3FYH`20=j]
U080gZfL0`2eS7<20:F4Jb4000007P3oool001`0oooo8@0000002@3gknL0imK60=J]S03F[H`0eYac
0<J4FP2eNeX0[F]20;EcBP0209AB:@80W6<i00T0U5Xa05Xa8@1S:A00HbT@06/a601[>B40ikfL0=j]
U03W]I`00P3N[I@20>NeU0@0ijf<00D0gZF40=j]Q03NYG/0gYak0=jUN`030=jLN`030=jLL`3>U6/0
cYA[0080cYA[0P3FW7<00`3NW7/0eYac0=JLL`040<jDJ`80cXaS00L0aXAS0;f<H`2mS6<0]G=:0:e[
@P2]JcT0W6<i0080[F=20P2]Jd8309aS>@80[F<a00@0]F/i0;E[@P36Nd80cXaJ0P3NYG<00`3FW7<0
gZf40<J<H`020:e[>@80]G=:00<0aXaS0000000000008000000X0?ooob<000003`3gmoL20=k>cP80
_Ib<0`3F_Jd20;fDN`80W6]:0`24DST409AS@PD0S5Y20`1cBS420:EkFP80S5Y20`2UNf<20;F4H`80
YG]S0`2<HdX20:F4J`80YG]S0`2eQ6<20;F4J`80_IAk2036W8@40=JeY@<0aZFD0P2mW9@Q000001h0
oooo000L0?ooob40000000T0mnoW0>OFaP3F[H`0eZf<0=JLL`36Q5X0]G]J0:e[@P2eLdX00P2DDRT2
09aS>@0909AJ<@1J<B40HbT@06<Y401[<AP0JcTQ0>NmW03N[I@0ikFL0080gZfD0P3W]I@40>N]S005
0=jUQ03N[H@0gZEk0=jLN`3NYG/00`3NW7/00`3NW7<0cYA[0<jDJ`020<jDJ`80eYac00<0gYak0=JL
L`3FW7<0103>U6/20<j<H`070<J4H`2mS6<0_HaS0;EcBP2]Jd80[F/i09aS>@020:eS@P80[F]20`2L
HcT20:eS<@040;E[>@2eJd80aW]20<j<FP80gZEc00<0eYac0=j]Q036S6<00P2]JcT20;EcBP030<J<
H`000000000002000000:03ooolV00000080moOg0P3gkoL:0?Ogm`80_Ib<0`2UQ6/20>NmW080aYb4
0`2eQ6<208aJ@P80Q58i0`2DHd8508AB>@80Ld8Y0P2<FT8309A[DP80S6=:0P24FT830;fDN`80YG]J
0P2<HdX30;F4H`80]Hac0P2UQ6/30;fDN`80]Hac0`2mU7/20=JeY@80c[FU0`2UQ6/S000001h0oooo
000L0?ooobD000000P3FW7<00`2mS6<0]G=:0:e[@P020:e[@P0408a::@2LHcT0U58Y08A28@80HbT@
00<0JcTQ06<Y403W_I`01@3W_I`00`3W]I@0kkfL0>NmU0020>N]S0050>neU03W[H`0gZf40>N]S03N
[H@00P3NYH@00`3N[H@0gZF40=j]Q0040=jUQ0040=j]S03N[H@0gZEk0=jLN`80eYak00D0gZEk0=JL
N`3FW7/0eYac0<jDJ`020<J4FP040<jDJ`3>S6<0]G]J0;E[DP80]G=:0P2]Jd800`2DFS40W6]:09a[
BP0209AB:@0309aS>@2eJd80cXaJ00<0cXaJ00@0cYA[0<IkBP36NdX0]G=:9P00000X0?ooobP00000
1@3gmoL20?O_m`<0moOg0P3gkoL20;fDN`<0YHA[0P2LNf<20<JLQ0D0YG]J0P24DS4508AB>@<0LdXa
0P24DST207=B@P<0Q6=:0P2DHd8208AJ@P<0S6=:0P2LLe820;F4H`<0]Hac0P2eQ6<209acH`<0_IAk
0P2UQ6/30:EkH`80eZF<0P36[I`V000001h0oooo000L0?ooobD000000P3FW7<00`2mS6<0]G=:0:e[
@P020:e[@P0408a::@2LHcT0U58Y08A28@80HbT@00<0JcTQ06<Y403W_I`01@3W_I`00`3W]I@0kkfL
0>NmU0020>N]S0050>neU03W[H`0gZf40>N]S03N[H@00P3NYH@00`3N[H@0gZF40=j]Q0040=jUQ004
0=j]S03N[H@0gZEk0=jLN`80eYak00D0gZEk0=JLN`3FW7/0eYac0<jDJ`020<J4FP040<jDJ`3>S6<0
]G]J0;E[DP80]G=:0P2]Jd800`2DFS40W6]:09a[BP0209AB:@0309aS>@2eJd80cXaJ00<0cXaJ00@0
cYA[0<IkBP36NdX0]G=:9P00000X0?ooobP000001@3gmoL20?O_m`<0moOg0P3gkoL20;fDN`<0YHA[
0P2LNf<20<JLQ0D0YG]J0P24DS4508AB>@<0LdXa0P24DST207=B@P<0Q6=:0P2DHd8208AJ@P<0S6=:
0P2LLe820;F4H`<0]Hac0P2eQ6<209acH`<0_IAk0P2UQ6/30:EkH`80eZF<0P36[I`V000001h0oooo
000L0?ooobD000000P3FW7<00`2mS6<0]G=:0:e[@P020:e[@P0408a::@2LHcT0U58Y08A28@80HbT@
00<0JcTQ06<Y403W_I`01@3W_I`00`3W]I@0kkfL0>NmU0020>N]S0050>neU03W[H`0gZf40>N]S03N
[H@00P3NYH@00`3N[H@0gZF40=j]Q0040=jUQ0040=j]S03N[H@0gZEk0=jLN`80eYak00D0gZEk0=JL
N`3FW7/0eYac0<jDJ`020<J4FP040<jDJ`3>S6<0]G]J0;E[DP80]G=:0P2]Jd800`2DFS40W6]:09a[
BP0209AB:@0309aS>@2eJd80cXaJ00<0cXaJ00@0cYA[0<IkBP36NdX0]G=:9P00000X0?ooobP00000
2P3gmoL20?ooo`80knOW0`36W8@20:F<L`80c[FU0`2mU7/20:F4J`80Q5Y20`24DS4207=2:@<0FSTY
0P1cBS4208AB<@<0Q5Y20P1cDT8207=:<@<0U6]B0P2UNeX50:EkH`80YHA[0P2DLeX30;F4H`80YG]S
0`2UNeX20=JeY@80]IAk9P00000N0?ooo`00703ooolW000000030;f<H`2eNeX0]F]20080[F]200@0
S4XY08A28@2DDRT0U5Xa0P2<BRT01@1[>B40Jc4H0>NmY@3W]I`0klJU0080ikfU00@0ikFD0>nmW03W
_I`0ikfL0P3__I`01@3_]I@0kkFL0>NmU03_]I@0ijf<00<0kkFD1@3W[H`01@3_]I@0gZf40>N]S03N
[H`0gZf40080ijf<00D0gZEk0=jUQ03NYG/0eYak0=JLL`020<J4J`040<j<H`3>U6<0eYac0<jDJ`80
aXAJ00D0aXAS0<J4FP36Q5X0]G]J09aS>@0309a[BP030:e[>@3>S5X0aW]:0080aW]200<0]F/i0:e[
>@0000009`00000X0?ooobX000000`3oool20?O_m`L0moOg0`2LJdX20;F4H`80Q6=:0`3>]JD20;F4
J`80YHA[0`1cBS4505Xa8@80Ld8Y0P1[>B4308AB>@80NeY20P1J<B4309AcFP80W7=B0P2UNf<308aS
BP80YHA[0P2eQ6<30;F<L`80]IAk0`2UNeX20=Jm[BP000007P3oool001`0oooo9`0000000`2mS6<0
]G]J0;E[@P020:e[@P0408a::@24@R40U58Y09AJ<@80S4XY00D0JcTQ06/a603W_JD0ikFL0>o6Y@02
0>NmY@040>NeU03__I`0ikfL0>NmW080kkfL00D0kkFD0>neW03W_I@0kkFD0>N]S0030>neU0D0ijf<
00D0kkFD0=j]Q03W[H`0gZf<0=j]Q0020>N]S0050=jUN`3NYH@0gZEk0=JLN`3FW7<00P36Q6/0103>
S6<0cYAS0=JLL`3>U6/20<J4FP050<J4H`36Q5X0aXAJ0;EkFP2LHcT00`2LJdX00`2]JcT0cXaJ0<Ik
BP020<Ik@P030;E[>@2]JcT0000002L00000:03oool]000000T0moOg0`2eU7/20:F4J`80LdXa0`2m
W8`20=k6]@80_HaS0`2]Le8209AJ<@D0Q58a0P24DST308ASBP80LdXa0P2<Je830:EkFP80U7=J0P2D
Je8309AcFP80S6=:0P2UNf<309AcFP80YG]J0`2UQ6/Z000001h0oooo000L0?ooobX000000P2eLdX0
102]JcT0S4XY08a::@1k>AP208A28@0508a28@1S:A00gZfD0>NmW03W_JD00P3_aZD20>NmW0070>nm
W03_]I@0ikfD0>NmU03__I`0kkFD0>NmU0020>nmW080ikfD00@0kkFD0>NmU03_]I@0kkFD0P3__I`3
0>NeU0090>NmU03N[H@0kkFD0>neU03N[H@0ijf<0=j]S03N[H@0gZF40080gYak00@0cYA[0=JLL`3F
W7<0ikfD0P3W_I`01@3>S6<0cYA[0=JLL`3FW7<0cXaS0080]G]J00@0]F]B09aS>@36Nd80]F/i;000
000X0?ooobd000001@3oool20?Ogm`D0oooo0P2UQ6/209acH`<0YHac0P2eW8`20=JeY@<0]Hac0P2e
Q6<309a[BP80S6=:0P2DLeX308AB>@80NeY20P2LLe830:EkFP80S6=:0P2DJe8308aSBP80NeY20P2D
Je830;F4H`80S6]B0`3F]JDZ000001h0oooo000L0?ooobX000000P2eLdX0102]JcT0S4XY08a::@1k
>AP208A28@0508a28@1S:A00gZfD0>NmW03W_JD00P3_aZD20>NmW0070>nmW03_]I@0ikfD0>NmU03_
_I`0kkFD0>NmU0020>nmW080ikfD00@0kkFD0>NmU03_]I@0kkFD0P3__I`30>NeU0090>NmU03N[H@0
kkFD0>neU03N[H@0ijf<0=j]S03N[H@0gZF40080gYak00@0cYA[0=JLL`3FW7<0ikfD0P3W_I`01@3>
S6<0cYA[0=JLL`3FW7<0cXaS0080]G]J00@0]F]B09aS>@36Nd80]F/i;000000X0?ooobl000000`3g
moL20?ooo`D0moOg0P2mU7/20:F4J`<0Q58i0P2<FT8209akJ`<0aZFD0P3FYH@30;f<H`80]HAS0P2L
Le8308aJ@P80]IAk0P2UNf<309acDP80Q58i0P2DJe8308AJ@P80Q58i0P2DJe830:F4J`80S6]B;@00
000N0?ooo`00703oool^0000000507/i601S:A00DR4@058Q401[<AP00P3N[I@0203W]I@0ikfL0>Nm
W03W_I`0ikfU0>NmW03_aZD0kkfL0P3_aZD50>nmW080kkFD0P3__I`01P3W_I@0kkfL0>neU03_]I@0
ikfL0>neU080ikFD00<0ijf<0>NeU03W]I@00`3W]I@20>N]S080gZf400@0gZF40=jUN`3NYG/0gZEk
0P3N[H@01@3W_I`0gZf40=JLN`3FW7<0eYak00<0gYac;`00000X0?oooc8000001`3gmoL20?ooo`80
YG]S0`2eQ6<207]J@P80U6]B0`2<Je820<jeY@<0ilJ]103FYH`30<JLQ080ilJe0P2eS7<309acDP80
NeY20P1cBS4308AB>@80YG]S0P2UQ7<30:F4Jbl000007P3oool001`0oooo;P0000001@1k>AP0HbT@
058Q401B8A00Jc4H0080gZfD00P0ikFD0>NmW03W_I`0ikfL0>NmY@3W_I`0klJU0>nmW080klJU1@3_
_I`20>neU080kkfL00H0ikfD0>nmW03_]I@0kkFD0>NmW03_]I@20>NeU0030>N]S03W]I@0ikFD00<0
ikFD0P3W[H`20=j]Q0040=jUQ03NYG/0gZEk0=jUN`80gZf400D0ikfL0=j]Q03FW7/0eYac0=JLN`03
0=jLLbl00000:03ooolb000000L0moOg0P3oool20:EkH`<0]HAS0P1kFT8209A[DP<0S6]B0P3>]JD3
0>O6[@@0eZF<0`36W8@20>O6]@80]Hac0`2LLe8207]J@P80LdXa0`24DST20:EkH`80YHAc0`2UQ6/_
000001h0oooo000L0?ooobh0000000D0NcTH06<Y401B8A00DR4@06/a60020=j]U0080>NeU03W_I`0
ikfL0>NmW03W_JD0ikfL0>o6Y@3__I`20>o6Y@D0kkfL0P3_]I@20>nmW0060>NmU03__I`0kkFD0>ne
U03W_I`0kkFD0P3W]I@00`3W[H`0ikFD0>NeU0030>NeU080ijf<0P3N[H@0103NYH@0gZEk0=jUN`3N
YG/20=j]Q0050>NmW03N[H@0eYak0=JLL`3FW7/00`3NW7<_000002P0oooo=00000020?Ogm`<0mnog
0P3gmoL20;FDN`<0_IAk0P2DLeX207=B@P<0U7=J0P2UQ7<30;FDN`80e[f]0P3We/H50=Jm[@80_Ib<
0`2eU7/407]B@P<0aZFD0P2UNf/20:F4Lc8000007P3oool001`0oooo<`000000103N[I`0gZfD0>Ne
U03W]I@20>NmY@030>NmW03__I`0kkfL00<0kkfL00<0klJU0>nmW03_aZD01@3__I`00`3W_I`0kkfL
0>nmW0030>neU0040>NmU03_]I@0kkfL0>nmW080ikfL00D0ikfD0>neU03W]I@0kkFD0>N]S0020=j]
Q0040>N]S03_]I@0ijf<0>N]S080kkFD00<0ijf<0>NmU03W]I@0=000000X0?ooocT000000P3oool2
0?Ogm`<0YG]S0P2UQ6/20:EkH`<0S6]B0P2LNf/309akH`80aZFD0P3>]JD50=k6]@80e[f]0`3Wc/H2
0>oWgP80kmK60`36YI`f000001h0oooo000L0?oooc<0000000@0gZfL0=j]U03W]I@0ikFD0P3W_JD0
0`3W_I`0kkfL0>nmW0030>nmW0030>o6Y@3__I`0klJU00D0kkfL00<0ikfL0>nmW03__I`00`3_]I@0
103W_I@0kkFD0>nmW03__I`20>NmW0050>NmU03_]I@0ikFD0>neU03W[H`00P3N[H@0103W[H`0kkFD
0>N]S03W[H`20>neU0030>N]S03W_I@0ikFD03@00000:03ooolk00000080mnog0`3gmoL20:F4J`80
aYb40`2UQ7<208a[DP<0YG]J0P2mW9@20;fLS0<0_IbD0P3Wc/H20>OFcP<0kmK60P3Wc[d20=k6]CT0
00007P3oool001`0oooo>P0000050>o6Y@80kkfL0P3_aZD50>nmW0040>neU03W_I`0kkfL0>nmW0<0
klJU103__I`0103W_I`0kkFD0>NmU03W]I@40>nmW0030>neU0000000000003T00000:03ooom00000
0080imkN0P2US7/30<JLQ080YHak0`2US7<209akJ`80_IbD0`2eW8`20=Jm]@80ilk60`3We/hm0000
01h0oooo000L0?ooocX000001@3_aZD20>nmW080klJU1@3__I`0103_]I@0ikfL0>nmW03__I`30>o6
Y@@0kkfL00@0ikfL0>neU03W_I@0ikFD103__I`00`3_]I@000000000000i000002P0ooooC0000002
0;FLS4T000007P3oool001`0ooooBP0000020>nmW4/00000:03ooonG000001h0oooo000L0?ooodX0
00000P3__Ia;000002P0ooooU`00000N0?ooo`00703ooom:00000080kkfLB`00000X0?oooiL00000
7P3oool001`0ooooU`00000X0?oooiL000007P3oool001`0ooooU`00000X0?oooiL000007P3oool0
01`0ooooU`00000X0?oooiL000007P3oool001`0ooooU`00000X0?oooiL000007P3oool001`0oooo
U`00000X0?oooiL000007P3oool001`0ooooU`00000X0?oooiL000007P3oool001`0ooooU`00000X
0?oooiL000007P3oool001`0ooooU`00000X0?oooiL000007P3oool001`0ooooU`00000X0?oooiL0
00007P3oool001`0ooooU`00000X0?oooiL000007P3oool001`0ooooU`00000X0?oooiL000007P3o
ool001`0ooooU`00000X0?oooiL000007P3oool001`0ooooU`00000X0?oooiL000007P3oool001`0
ooooU`00000X0?oooiL000007P3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
06<0oooo00=000000?ooo`3oool01P3oool00d000000oooo0?ooo`2b0?ooo`03@000003oool0oooo
00H0oooo00=000000?ooo`3oool0H`3oool00680oooo00=000000?ooo`3oool0203oool00d000000
oooo0?ooo`2`0?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool0HP3oool00640oooo
00=000000?ooo`3oool00P3oool3@00000D0oooo00=000000?ooo`3oool0[P3oool00d000000oooo
0?ooo`030?ooo`=00000103oool00d000000oooo0?ooo`1Q0?ooo`00H@3oool00d000000oooo0?oo
o`020?ooo`03@000003oool0oooo00D0oooo00=000000?ooo`3oool0[P3oool00d000000oooo0?oo
o`020?ooo`04@000003oool0oooo@00000@0oooo00=000000?ooo`3oool0H@3oool00640oooo00=0
00000?ooo`3oool00P3oool00d000000oooo0?ooo`050?ooo`03@000003oool0oooo0:h0oooo00=0
00000?ooo`3oool00P3oool014000000oooo0?oood0000040?ooo`03@000003oool0oooo0640oooo
001Q0?ooo`03@000003oool0oooo0080oooo0d0000050?ooo`03@000003oool0oooo0:h0oooo00=0
00000?ooo`3oool00`3oool3@00000@0oooo00=000000?ooo`3oool0H@3oool00680oooo00=00000
0?ooo`3oool0203oool00d000000oooo0?ooo`2`0?ooo`03@000003oool0oooo00@0oooo00E00000
0?ooo`3oool0oooo@000001T0?ooo`00H`3oool00d000000oooo0?ooo`060?ooo`03@000003oool0
oooo0;80oooo00=000000?ooo`3oool00P3oool2@0000080oooo00=000000?ooo`3oool0H`3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool001`0ooooU`00000X
0?oooiL000007P3oool001`0ooooU`00000X0?oooiL000007P3oool001`0ooooU`00000X0?oooiL0
00007P3oool001`0ooooU`00000X0?oooiL000007P3oool001`0ooooU`00000X0?oooiL000007P3o
ool001`0ooooU`00000X0?oooiL000007P3oool001`0ooooU`00000X0?oooiL000007P3oool001`0
ooooU`00000X0?oooiL000007P3oool001`0ooooU`00000X0?oooiL000007P3oool001`0ooooU`00
000X0?oooiL000007P3oool001`0ooooU`00000X0?oooiL000007P3oool001`0ooooU`00000X0?oo
oiL000007P3oool001`0ooooU`00000X0?oooiL000007P3oool001`0ooooU`00000X0?oooiL00000
7P3oool001`0ooooU`00000X0?oooiL000007P3oool001`0ooooBP0000020>nmW4/00000:03ooom2
000000030?Ogm`3gkoL0moOg00L0moOg00<0mnog0?Ogm`3gmoL01@3gmoM3000001h0oooo000L0?oo
odX000000P3__Ia;000002P0oooo@P0000000`3gmoL0mnog0?Ogm`070?Ogm`030?O_m`3gmoL0moOg
00D0moOg@`00000N0?ooo`00703ooolo000000P0klJU00<0kkfL0>o6Y@3__I`00`3__I`40>o6Y@<0
kkFD0`3__Ia0000002P0oooo?00000050?Ogm`80mnog2@3gmoL00`3gkoL0moOg0?Ogm`060?Ogm`03
0?ooo`3_inL0_Jf]0080aZFD?@00000N0?ooo`00703ooolj000000D0klJU0P3__I`20>o6Y@D0kkfL
00@0kkFD0>NmW03__I`0kkfL0`3_aZD40>nmW0040>NmW03_]I@0ikfD0>NeU0@0kkfL00<0kkFD0000
00000000>@00000X0?ooocT0000000<0moOg0?O_m`3gmoL00`3gmoL0103gknL0mnog0?Ogm`3gmoL3
0?O_m`<0moOg0`3gkoL40?Ogm`050?ooo`2eU7/0]IAk0:ecDP3_imh00`3oool209acDP0309a[BP24
BRT0Q58i03X000007P3oool001`0oooo=P000000103W_I@0kkfL0>nmW03_aZD50>nmW0040>o6Y@3_
_I`0kkfL0>o6Y@<0kkfL00@0klJU0>nmW03__I`0kkFD0P3W_I@20>nmW0030>NmW03_aZD0kkfL0080
kkFD00<0ikFD0>neU03W]I@0103W]I@00`3W_I@0ikFD0>NeU0030>N]S3L00000:03ooole00000007
0?O_i`3gkoL0mnog0?O_m`3gmoL0mnog0?O_i`040?Ogm`030?O_m`3gmoL0moOg00<0mnog00<0moOg
0?O_m`3gmoL0103gmoL0103oool0_IbD0;F4J`3gkoL20=K6aP050;fLU02US7/0Ld8Y06/i8@24DS40
0P1cBS40101kFT80Le9208a[DP24DST208a[DP0307=B@P000000000003@000007P3oool001`0oooo
<`000000103N[I`0gZfD0>NeU03W]I@20>NmY@030>NmW03__I`0kkfL00<0kkfL00<0klJU0>nmW03_
aZD01@3__I`00`3W_I`0kkfL0>nmW0030>neU0040>NmU03_]I@0kkfL0>nmW080ikfL00D0ikfD0>ne
U03W]I@0kkFD0>N]S0020=j]Q0040>N]S03_]I@0ijf<0>N]S080kkFD00<0ijf<0>NmU03W]I@0=000
000X0?oooc<000000P3gkoL00`3gmoL0mnoW0?O_m`020?O_m`T0moOg00<0mnog0?Ogm`3gmoL00P3g
moL02@3gkoL0_Jf]0:EkJ`2UNf/0S4XY09a[BP2UNeX0_Ib<0:F4J`020:F<L`050;FLS02DJe80S5Y2
07]::@1c@RT00`1cBS400`24FT80S6=:08AB>@0208AB>@0308aJ@P2UNeX0NeY203@000007P3oool0
01`0oooo<000000206<Y400504XH203N[I@0gZfD0>NmW03W]I`00`3W_I`60>nmW080klJU203__I`3
0>NmU0040>nmW03_]I@0ikfL0>neU080kkFL103W]I@50>N]S0090=j]Q03NYG/0gZf40=j]Q03W[H`0
gZf40>NmW03NYG/0gZf<03800000:03oool`000000@0moOg0`3gkoL20?O_i`040?O_m`3gmoL0mnog
0?Ogm`80mnog00D0moOg0?O_m`3gknL0knog0?O_m`020=k6aP0409acDP2]Le80W7=B09AJ<@80]Hac
00D0]IAk0:EkH`2LLe80W7=B08AB<@0209AcFP0508aJ@P1cBS40FS4Q05Xa8@1cBS400P24HdX0102L
Nf/0YHac09acDP24DST208aSBP0309A[DP2<FT80NeY20080Q58i<P00000N0?ooo`00703oool^0000
000507/i601S:A00DR4@058Q401[<AP00P3N[I@0203W]I@0ikfL0>NmW03W_I`0ikfU0>NmW03_aZD0
kkfL0P3_aZD50>nmW080kkFD0P3__I`01P3W_I@0kkfL0>neU03_]I@0ikfL0>neU080ikFD00<0ijf<
0>NeU03W]I@00`3W]I@20>N]S080gZf400@0gZF40=jUN`3NYG/0gZEk0P3N[H@01@3W_I`0gZf40=JL
N`3FW7<0eYak00<0gYac;`00000X0?ooobh0000000<0moOg0?O_i`3gmoL00P3gmoL00`3gkoL0mnoW
0>o_i`030?O_m`040?O_i`3_inL0mnog0>oWi`80imkN00<0imK>0>O>aP36U6/00P2eQ6/209acDP04
09AJ<@2LHcT0W7=B08aSBP80W6]:00D0S5Y208AB>@1cBS40S6=:07]::@0207]B@P0507=:<@1c@RT0
JcTQ06/i8@1cBS400P24DST0102<Je80U6]B08aSBP24HdX208a[DP0509A[DP2<HdX0Q58i07=:<@24
DST00P1cBS400`1cDT8000000000000]000001h0oooo000L0?ooobh0000000D0NcTH06<Y401B8A00
DR4@06/a60020=j]U0080>NeU03W_I`0ikfL0>NmW03W_JD0ikfL0>o6Y@3__I`20>o6Y@D0kkfL0P3_
]I@20>nmW0060>NmU03__I`0kkFD0>neU03W_I`0kkFD0P3W]I@00`3W[H`0ikFD0>NeU0030>NeU080
ijf<0P3N[H@0103NYH@0gZEk0=jUN`3NYG/20=j]Q0050>NmW03N[H@0eYak0=JLL`3FW7/00`3NW7<_
000002P0oooo;P0000000`3gmoL0mnoW0?Ogm`020?Ogm`030?O_m`3gknL0knoW00<0mnog00@0mnoW
0>oWi`3gkoL0knOW0P3Wg]h00`3We/h0ilk60<JDJ`020;F4J`80W7=B00@0U5Xa09aS>@2LLe80S6=:
0P2LJdX01@2<FT80Q58i07=:<@2<HdX0NdXY0080Ne9200D0LdXa07=2:@1[>B40JcTQ07=:<@0208AB
>@0408a[DP2DJe80S6=:08ASBP80S6]B00D0U6]B08aSBP24DST0LdXa08AB>@0207=:<@0307=B@P00
0000000002d000007P3oool001`0oooo;00000000`2eJcT0U58Y08a::@0306/a600507]28@1kBRT0
gZfL0>NmU03W_I`00P3_aZD20>NmW0030>o6Y@3__I`0kkfL00D0kkfL00L0ikfL0>nmW03__I`0ikfL
0>NeU03_]I`0kkfL0080ikfD0P3_]I@00`3W_I@0ijf<0>NmU0020=j]Q0030>NeU03W_I@0ikFD0080
ijf<0`3NYH@00`3>U6/0eYac0=j]S0020>NmW0050=j]S03>S6<0cYA[0=JLL`3>U6/00P3FW7<00`3>
U6/0aW]:0<Ik@P0]000002P0oooo;0000000103gmoL0mnog0?Ogm`3gmoL20?O_i`050>o_m`3gkoL0
mnog0?O_i`3_inL00P3gkoL0103Nc/H0g/Je0>NmW03F[H`20<JDJ`050;f<H`2]Le80U6=209AS@P2D
FS400P2<FT801024DS40LdXa08AB>@24DS4207=:<@0309A[DP2<FT80Q58i0080FS4Q0P1cBS401@2<
HdX0LdXa06/i8@1cBS40FS4Q0080LdXa00@0NeY208AB>@2<Je80S6=:0P2DJe800`24FT80Q6=:08AB
>@0208AB<@80Le9200<0Q5Y209A[DP2DLeX0;@00000N0?ooo`00703ooolZ00000080]G=:00@0[F/i
08a::@2<BRT0NcTH0P24@R401@2<@R40HbT@0=j]U03W_I`0ikfU0080klJU0P3W_I`01`3__I`0kkFD
0>NmU03W_I@0kkfL0>neU03W_I@00P3__I`20>NmU0040>neU03W_I@0kkFD0>neU080kkfL0`3W]I@0
2@3W_I@0gZf40>neU03_]I@0gZf40>N]S03N[H`0gZf40=jUQ0020=jLN`040<jDJ`3FW7<0eYac0>Nm
U080ikfL00D0cXaS0<jDJ`3FW7<0eYac0<j<H`020;EkFP040;E[DP2LHcT0aW]20;E[>B`00000:03o
oolZ00000080knoW0P3gmoL20?O_m`<0moOg00@0mnog0>oWi`3_imh0g/Je0P3Nc/H0103Fa[D0aZFD
0;fDN`2eQ6<20:ecDP0509AS@P2<FT80U6=208A::@1kBRT00P1c@RT0101J<B40JcTQ07=:<@2<FT82
09a[BP0308AJ@P24DST0LdXa00D0Q58i00@0LdXa09AS@P24DST0Q58i0P1cBS401024DST0Q5Y208aS
BP24DST308aSBP0408aJ@P24DS40Le9208AB>@80Le9200@0NeY209A[DP2DJe80Q58i;000000N0?oo
o`00703ooolX000000030;EcBP2]Jd80W6<i0080W6<i00<0S48Q08a::@2DDRT00P2DDRT01@1k>AP0
BQP80>NmW03W]I@0ikfU0080ikfL00<0kkfL0>NmW03__I`00`3_]I@00`3__I`0kkFD0>neU0050>ne
U080ikfD00@0kkFD0>NeU03W]I@0ikfD0P3W]I@40=j]Q0050>N]S03N[H@0gZf<0=j]S03NW7/00P3F
W7<20<j<H`040=j]Q03N[I@0cXaS0<j<H`80aXAS00<0aXaS0<J4H`2eNeX00P2]Le800`2<FT80[F]2
0<Ik@P040;E[>BT00000:03ooolX000000@0moOg00@0mnog0?Ogm`3gkoL0knoW0P3_inL01@3We]H0
imK>0>OFcP3Nc/H0ikfL0080aYb40P2mU7/01P2]Le80U6=209AS@P2DHd80U5Y209AJ<@80JcTQ00L0
NdXY08AB<@24DS40NeY208aJ@P1c@RT0Q58a0080LdXa00@0S5Y209AJ@P2DFT80U5Y20`24DST01@1c
BS40JcTQ05Xa8@1cBS40NdXY00<0LdXa00<0NeY208AJ@P24FT800P24FT801024DST0Q5Y208AJ@P1c
BS4308AB>@0407=B@P2DJe80Q5Y208ASBP80Q5Y200<0Q58i0000000000009`00000N0?ooo`00703o
oolW000000030;f<H`2eNeX0]F]20080[F]200@0S4XY08A28@2DDRT0U5Xa0P2<BRT01@1[>B40Jc4H
0>NmY@3W]I`0klJU0080ikfU00@0ikFD0>nmW03W_I`0ikfL0P3__I`01@3_]I@0kkFL0>NmU03_]I@0
ijf<00<0kkFD1@3W[H`01@3_]I@0gZf40>N]S03N[H`0gZf40080ijf<00D0gZEk0=jUQ03NYG/0eYak
0=JLL`020<J4J`040<j<H`3>U6<0eYac0<jDJ`80aXAJ00D0aXAS0<J4FP36Q5X0]G]J09aS>@0309a[
BP030:e[>@3>S5X0aW]:0080aW]200<0]F/i0:e[>@0000009`00000X0?ooobL0000000<0knog0?Og
m`3gkoL00P3_koL30>oWi`080>OFcP3Wg]H0imkF0=k>_@3Fa[D0e[f]0=J]S036W8@20;EkFP040;Ec
BP2LJdX0U6=208AB<@80W6<i00<0JcTQ08AB<@1c@RT00P24DST208AB<@0307=:<@24DST0Q58i00<0
S4Xa00D0LdXa058Q401J<B40Jc4H08AB>@0209AJ@P0508a:<@2LJdX0W4Xa09aS>@2DFS400P24DST0
102<FT80Q5Y208AB>@24DST208AJ@P0507]J@P2LHcT0Q58i07]J@P1cDT80101kFT801P2<HdX0Le92
0:EkFP2UNeX0Q58i08AB<BP000007P3oool001`0oooo9P000000103>U6/0aXAJ0;EcBP2]Jd820:e[
>@0409AJ<@2DDRT0[F/i09AB:@<0Jc4H00@0HbT@0>NmY@3W]I`0ikfL0P3N[I@00`3W_I`0kkfL0>nm
W0030>N]S0030>neU03W]I@0ijf<0080ijf<0P3N[H@20>N]S080gZf40P3W[H`00`3NYH@0ijf<0=jU
Q0040=jUQ080gZEk0P3FW7<01`3>U6/0cXaJ0<j<FP36Q6<0eYak0<J<H`2eNeX00P2eJe801@36NdX0
]G=:0;EkFP2DHd80]G=:0080W7=B00@0[F/i0:e[@P36NdX0cXaJ0P36Q5X00`2eLdX0aW]:0;EkFP0W
000002P0oooo9P0000000`3_koL0mnoW0>o_m`030>o_i`040>oWi`3We/h0imK60>O>_@80imK600D0
cZfD0=JLL`2mU7/0]HAS0:ecDP0209aS>@0409a[BP2LHcT0S4Xa08a:<@80NdXY00D0LdXa07]::@1c
@RT0Q4Xa07=:<@0208A:<@0407=:<@1kBRT0Q4Xa06/i8@80FS4Q00D0DRTH08AB<@2DFS40DRTH09AJ
@P020<icH`80aXAS00<0]F]B0;ES@P2DFT800P2DFS40102<FT80Q5Y208AB<@24FT8208AB>@0509A[
DP1c@RT0S6=:08aSBP24DST00P1cDT801024FT80NeY208ASBP2<HdX207]J@P0308ASBP1kFT80W6]:
02L000007P3oool001`0oooo9@0000020=JLL`030;f<H`2eLdX0[F]20080[F]200@0S4XY09aS>@2D
DRT0Q48Q0P1S:A000`1[>B40HbT@0>NmW0050>NmW0030>NeU03__I`0ikfD0080ijf<00D0kkFD0>N]
S03N[H@0ijf<0=j]Q0020=jUQ0030=j]Q03NYH@0gZf400@0gZF400@0gZf<0=j]Q03NYG/0gYak0P3F
W7/01@3NYG/0eYak0=JLN`3FW7<0cYA[0080aXAJ00@0cYA[0<j<H`2eNeX0]F]B0P2eLdX20:e[@P03
09AJ<@2LJdX0W6]:0080U58Y00<0W6<i0;E[@P3>S5X00`3>S5X0103>U6/0aW]:0<IkBP2eLdXV0000
02P0oooo8`0000030>o_m`80mnog0P3_inL20>ONeP80iljm00@0g/jm0=k>aP3F[H`0eZf<0P36U6/0
0`2eNeX0W6]:09AS@P0209a[BP0408A::@2DHd80S4Xa06/i8@80NdXY00@0Q4Xa07]::@1kBRT0Q4Xa
0`1kBRT01024BS40Ld8Y05Xa8@1J>BT207=:<@0309aS>@24BS40kkFD0080mlJe0P3_]I`01@3WYI@0
cYA[0=j4L`2eNeX0U5Y200<0S6=:00<0S5Y208AB<@24DST01@2<HdX209a[BP@0U6]B0P2<HdX20:Ek
FP050:EkH`2<FT80Q58i09A[DP2<HdX09@00000N0?ooo`00703ooolU00000080eYac00<0_HaS0;Ec
BP2]Jd800P2]Jd80102<BRT0W6<i09AB:@24@R4206<Y400306/i8@1S:A00ikfL00D0ikfL00<0ikFD
0>nmW03W_I@00P3W[H`01@3_]I@0ijf<0=j]Q03W[H`0gZf40080gZF400<0gZf40=jUQ03N[H@0103N
YH@0103N[H`0gZf40=jUN`3NW7/20=JLN`050=jUN`3FW7/0eYak0=JLL`3>U6/00P36Q5X0103>U6/0
cXaS0;EkFP2eJe820;EcBP80[F]200<0U5Xa09a[BP2LJdX00P2DDRT00`2LHcT0]F]20<j<FP030<j<
FP040<jDJ`36NdX0aW]:0;EcBRH00000:03ooolS000000<0knog0P3gkoL20>oWi`80imkF0P3Wc[d0
103Nc[d0g/k60=J]S03F[H`20<JDJ`030;EkFP2LJdX0U6=20080W6]:00@0Q4XY09AS@P2<BS40JcTQ
0P1kBRT01024BS40NdXY07]::@24BS4307]::@0408A:<@1c@RT0FS4Q05Xi:@80LdXa00<0W6<i08A:
<@3_]I@00P3ga[D20>neW0050>NUU03>U6/0gXAc0;EkFP2DFT800`2<HdX00`2<FT80Q58a08AB>@05
08aSBP80W6]:102DJe8208aSBP80YG]J00D0YG]S08aJ@P24DST0U6]B08aSBP0U000001h0oooo000L
0?ooob80000000P0mnoW0<j]U03>[I@0eYac0<J<H`36Q5X0W6<i09a[BP80U5Xa00@0W4Xa09aS>@2L
BS40Nd8Q0P1[>B401@1k@R40Jc4H0>NmY@3N[I`0ikfL0080ikFD00@0ikfL0>NeU03W[H`0ikfD103W
[H`00`3N[H@0gZF40=jUQ0020=jUQ0030=jLL`3NW7/0gZEk00<0gYak00D0gZF40=jUN`3NYG/0eYac
0=jLL`050=JLL`80cXaS0P36Q5X0103>U6/0aXAJ0;EcBP2]Jd830:eS@P0309AS@P2]Jd80W6]:00<0
U5Xa00@0W6<i0;E[>@36Nd80cXaJ0P36Q5X00`3>S5X0aXAJ0;f<H`020;EcBP80]F]28`00000X0?oo
ob80000000@0knoW0?O_m`3gkoL0knog0P3gkoL00`3We/H0g/jm0=k>_@020=k>_@030<jeY@3F[H`0
aYb40080aYA[00D0]HAS0:ecDP2DHd80W6]:08AB<@0208A::@0408aJ@P24@RT0NdXY07]::@80JcTQ
00D0Ld8Y08A::@24BS40NdXY08A:<@03058Y600306/i8@1c@RT0Ld8Y0080NdXY00D0ijf<0?O6]@3_
]I`0ijf<0=jUQ0020>N<N`050=JLN`36W8@0cYA[0;f<H`2UNf<00P2LLe80102]Le80YG]J09a[BP2U
NeX309acDP040:EkH`2UNeX0]HAS0:EkH`80]HAS00<0W7=B0:F4J`2]Le80102UNeX209acDP0408aS
BP2DJe80NeY207]J@R<000007P3oool001`0oooo8@0000002@3gknL0imK60=J]S03F[H`0eYac0<J4
FP2eNeX0[F]20;EcBP0209AB:@80W6<i00T0U5Xa05Xa8@1S:A00HbT@06/a601[>B40ikfL0=j]U03W
]I`00P3N[I@20>NeU0@0ijf<00D0gZF40=j]Q03NYG/0gYak0=jUN`030=jLN`030=jLL`3>U6/0cYA[
0080cYA[0P3FW7<00`3NW7/0eYac0=JLL`040<jDJ`80cXaS00L0aXAS0;f<H`2mS6<0]G=:0:e[@P2]
JcT0W6<i0080[F=20P2]Jd8309aS>@80[F<a00@0]F/i0;E[@P36Nd80cXaJ0P3NYG<00`3FW7<0gZf4
0<J<H`020:e[>@80]G=:00<0aXaS0000000000008000000X0?ooob40000000D0mnoW0?O_m`3_knL0
knoW0>oWgP020>O>_@080>O6[@3F_Jd0cZfD0<j]U036W8@0_IAk0<JDJ`2eNeX30:EkFP0409AS@P2<
BS40S5Y208AB<@80Q4Xa00@0JcTQ07]::@1[>B40Ld8Y0P1k@R401@1kBRT0S4Xa07]::@0i6100DRTH
0080@R4H00<0JcTQ058Y6024DST00`3WaZd01@3_aZd0cYA[0>N<N`3WYI@0ihak00<0eYak00@0_IAk
0;F<L`36Q6/0]HA[0P2UNeX0102]Le80W7=B09acDP2eNeX20;f<H`030;F4J`2mS6<0]Hac0080]Hac
0P2mU7/00`36U6/0]Hac0;fDN`040;f<H`040;F4H`2UQ6/0W7=B0:EkFP80W7=B00<0W7=S00000000
00008000000N0?ooo`00703ooolP00000080mnoW00P0ikfU0=J]Q03F[H@0aYA[0;f<H`2eLdX0W6<i
09a[BP80U5Xa00<0[F/i08a::@24@R400`1B:AP206/a60030>NmW03N[I@0ikFD0080ikFL00@0ikFD
0>N]S03W[H`0gZF41@3NYG/01@3NW7<0eYak0=JLL`3FW7<0gYac0080eYac1@3>U6/20=JLL`@0cYA[
0P36Q6<02036Q5X0]G]J0<J4FP36Q5X0]F]209aS>@2DFS40[F]20P2LHcT20:e[@P80Nd8Q00<0S4XY
0;ES<@2eHc400`36Nd802036Q5X0cYAS0<jDH`3FW7<0cYA[0=J]Q02mS6<0]G=:0`36Q5X00`3>U6/0
00000000000O000002P0oooo800000020?O_i`070>ONeP3Wa[D0ilJe0=k6]@3F]JD0cZfD0<JLQ003
0;fDN`040<J<H`2eNeX0]G=:0:ecDP80W6]:00D0Q58i08a:<@2<FT80S4XY08A:<@0206/i8@80NdXY
00T0JcTQ07]::@1kBRT0NdXY08A:<@1k@R40@R4H058Y60128AP00P0i6100101J>BT0YHAc0>o6]@3g
e[d20?O6]@030>N]U03NYH@0eZF<0080gZfD0`3N[H`0103FYH`0eZF40<JLQ036W8@20=JUQ080eYak
00T0aXA[0<JDJ`2mU7/0_IAk0<JDJ`2eS7<0aYb40=JLN`36W8@00P3FYH@0103F[H`0eYak0<JLQ03F
W7/20<JLQ0050=JLN`2mU7/0]Hac0:EkH`2eQ6/00P2UNeX00`2US7<0U6]B0000000P000001h0oooo
000L0?oooal0000000@0knoW0?O_m`3Wg]H0e[FU0P3F[H@0102mS6<0]G]J0:e[@P2LJdX309AJ<@04
09aS>@2<BRT0NcTH06/a60<0JcTQ00<0NcTH0=j]U03N[I@00`3N[H`0103W[H`0gZf<0=jUQ03N[H`3
0=jUQ0030=JLN`3NW7<0gYac00@0cYA[00<0aXA[0<j<H`3>S6<00P36Q6/20<jDJ`030<J4J`3>U6/0
cYA[0080cYA[00D0aXAS0<J4FP36Q6<0aXAJ0;EcBP020<j<FP040:e[@P2<BRT0W6]:09a[BP80W6<i
00D0U5Xa08A28@1k@R40HbT@0:eS<@020<Ik@P040;ES<@36Nd80]F]20<IkBP80cYAS00<0gZEc0=JL
N`3N[H@00P2mS6<20<jDH`030;f<H`3>U6/0aYA[02000000:03ooolO000000040?O_i`3We/H0ikfU
0=JeY@80eZf<00@0eZf40=JLL`36U6/0aYA[0`2mS6<20:ecDP040;EcBP2LHcT0W6<i09aS>@80U5Xa
00<0S4XY08A::@1[<AP00P1kBRT0101[<AP0LdXa07]::@24@RT206/i8@0506<Y401B:AP0HbT@058Q
401B:AP00P3_]I`0103_aZd0mlJe0?O>]@3_a[D20>O6[@050>o6]@3_c[D0klje0>o>_@3Wa[D00`3_
a[D00`3Wa[D0klje0>o6[@030>O6]@040>o6[@3WaZd0ikfL0>NeW080gZf<00D0eZF<0=JUQ03FYH`0
eZf<0=j]W0020=j]U0040>NmY@3W]I`0gZfD0=j]W0<0gZfD00@0aYb40=JUS02mU7/0YG][0P2<HdX0
0`36YI@0YHA[0;fLU00P000001h0oooo000L0?oooad000000P3_koL0103gkoL0knoW0>O6]@3F[H`2
0<JLQ080]G]J00<0W6]:0:eS@P2LHcT00`2DFS4206/i8@0306/a601[>B40JcTQ0080JcTQ00<0gZfD
0=j]S03N[I@00P3W_JD20>N]U0030>NUU03W[I@0ijFD0080ijFD00@0gZf<0=jUQ03NYH@0eYak0P3>
S6<00`36Q5X0cXaS0<IkFP050<J4FP80cXaS1036Q5X20;EkFP080;E[DP2eLdX0aXAJ0<J4FP2LHcT0
NdXY09aS>@2]Jd8208a::@0507]28@1k>AP0NdXY09AB:@2]FS400`36Nd800`2eLdX0aW]20:e[>@02
0<jDH`050=JLL`3F[H@0cYA[0<JDJ`36Q5X00`36S6<00`2mS6<0eZf40=J]Q00O000002P0oooo7`00
0000103>[I@0eZf<0=J]Q03F[H@20<JLQ0030<JDJ`36S6<0_HaS0080]G]J0`2eLdX00`2DHd80[F=2
0:eS@P0209AJ<@0408a:<@24BRT0NdXY07=2:@H0NdXY00P0Jc4H05Xa8@1J<B40HbT@05Xi:@128AP0
FSTY0<j]U080kljm00@0klJe0>o>_@3_c[d0mmJm0P3_e/H20?OF_@030>o>_@3ge[d0klje0080klje
00D0ilJe0>o>]@3W_JD0g/Je0>o>_@020>o>]@030>o6]@3_c[D0klJe00@0ikfU0`3W_I`0103W_JD0
klJU0>o6Y@3W_JD20>o6Y@070>NmY@3W_I`0ikfL0=j]W03F]JD0gZfD0=JUS0030;F<L`030<jUU02e
S7<0aYb4020000007P3oool001`0oooo7@0000020>o_m`040?O_m`3_knL0ilJe0=J]S080aYb40P2e
NeX00`2LJdX0[F=209aS>@0309AJ<@80JcTQ00<0Jc4H06/i8@1[>B400P1[>B400`3N[I@0gZf<0=j]
U0020>NmY@80ijfD00<0ijFD0>N]U03WYI@00P3WYI@0103N[H`0gZF40=jUQ03FW7/20<j<H`030<J4
FP3>S6<0aW]J00D0aXAJ0P3>S6<40<J4FP80]G]J00P0]F]B0;EcBP36Q5X0aXAJ09aS>@1kBRT0W6<i
0:e[@P80S4XY00D0Nd8Q07/i601kBRT0U58Y0:eJ<@030<Ik@P030;EcBP36Nd80[F/i0080cYAS00D0
eYac0=J]Q03>U6/0aYA[0<J4FP030<J<H`030;f<H`3F[H@0eZf401l00000:03ooolO000000040<j]
U03F[H`0eZf40=J]Q080aYb400<0aYA[0<J<H`2mS6<00P2eNeX30;EcBP0309AS@P2]Hd80[F=20080
U5Xa00@0S4Xa08A::@1kBRT0Ld8Y1P1kBRT0201[<AP0FS4Q05Xa8@1S:A00FSTY048Q601J>BT0cZfD
0P3_c[d0103_a[D0kljm0>o>_@3ge[d20>oFaP80mmJm00<0kljm0?OF_@3_c[D00P3_c[D01@3Wa[D0
klje0>NmY@3Na[D0kljm0080klje00<0klJe0>o>]@3_a[D0103W_JD30>NmW0040>NmY@3_aZD0klJU
0>NmY@80klJU00L0ikfU0>NmW03W_I`0gZfL0=JeY@3N[I@0eZF<00<0]Hac00<0cZFD0;F<L`36W8@0
8000000N0?ooo`00703ooolM000000<0knog00<0knON0=k6]@3F[H@00P36U6/01@2eNeX0]G=:0:e[
@P2LHcT0]G=:0080W4Xa00<0U5Xa058Q401c@RT00`1[>B40101[<AP0Q58a0=j]U03WaZd40>o6[@80
klJU103_]I`0103W[I`0ijfD0>N]U03N[H`20=jUQ0040=JLN`36NeX0aW]J0<IkBP<0aW]J0`2eNeX0
1P36Q5X0aW]J0<IkFP2eNeX0aW]:0;EcBP80[F]20P36NdX0102<BRT0S4Xa09aS>@2<FT8208A28@05
06/a601[>B40[F<a08A28@2LHcT00P36NdX01036Nd80]G=:0:e[>@2eLdX20<j<FP040=JLN`3N[H@0
gZf<0=J]Q0<0aYA[00@0]G]J0;E[@P3F[H@0eZf47`00000X0?oooad00000103FW7<00`36U6/0_HaS
0;EkFP030;EkFP030:ecDP2LJdX0[F]20080W6]:00@0U6=209AJ<@2<BS40Q58i0P1kBRT00`2DFS40
Jc4H07]::@0407]::@0408A::@1[>B40Jc4H05Xa8@80Q58i00D0YG]S0>O6]@3_aZd0klJ]0>o>]@02
0?O6]@T0kmK600T0kljm0>o6[@3W]I`0ikFL0>O6[@3_c[D0mlje0>NmW02mU7/01@3_c[D00`3_cZd0
klje0>o>]@0:0>o6[@080>neW03WaZd0ilJ]0>NmY@3W]I`0gZfL0>NmW02mU7/20<JLQ0040;fLS02e
S7<0aZFD0:F4Jal000007P3oool001`0oooo700000001`3_koL0mnog0?O_m`3gkoL0iljm0=JeY@3F
W7<00P36S6<01@2eNeX0[G=B09AJ<@2LHcT0U5Xa0080W6<i00@0Q48Q06<Y401k@R40Ld8Y0P1[>B40
1@1[<AP0]HAS0>o6[@3_a[D0mmJm00<0mlJe0P3_aZd0103ga[D0klJ]0>o6[@3_aZd20>neW0080>Ne
W03W[I@0gZf<0=j]S03NYH@0gYak0<jDJ`36NdX20;EcBP050;EkFP36NdX0aW]:0<IkFP2eJe800P2e
NeX01@36NdX0]G]J0;EcBP2]Jd80U6=20080]G=:00@0U5Xa09aS>@2eLdX0Q48Q0P1k>AP01@1[<AP0
LdXa0;E[>@2<@R40W6<i0080]F]200@0aW]:0;E[>@2]JcT0]G=:0P36Q5X01@3>S5X0gZf40=j]S03F
[H@0eYac0080aYA[00<0]G=:0;f<H`3FW7<00`3FW7<M000002P0oooo700000001P3>U6/0eYac0=JL
L`36S6<0aXAJ0;f<H`<0]G]J00D0]G=:0:ecDP2]Jd80U5Xa09AS@P0208AB>@<0U5Xa00P0Q4XY08AB
>@24DST0HbT@07]28@1kBRT0Q48Q07]28@80NdXY00<0JcTQ0;F4H`3Wa[D00`3_a[D01@3WaZd0klJe
0?O6]@3gc[D0klje00<0mmJm0`3_e/H20?ONcP<0kmK600D0ilJ]0=j]W03>YI@0cZFD0>NmY@020?OF
_@070>o6]@36W8@0klJ]0>o6[@3_c[D0kljm0>o>]@030>o>_@030?O>]@3_c[D0klje0080mlje0P3_
a[D00`3gc[D0klJ]0>o6[@040>o6[@040>NmY@3W]I`0gZfL0=j]U080e[f]00@0gZfL0;fLS03F]JD0
aZFL0P2eU7/M000001h0oooo000L0?oooa/0000000<0knog0?O_i`3gkoL00P3gkoL00`3Wc[d0cZfD
0<JDJ`020;f<H`050:ecDP2]Jd80[F]209aS>@2DFS400P2LHcT00`1S:A00JcTQ07]::@0306/i8@05
0;F<L`3_a[D0mlje0?OF_@3gc[D00P3ge[d0103ga[D0mmJm0?O6]@3gc[D20?O6]@030>o6[@3_aZD0
klJ]0080kkFL0P3W[I@0103W[H`0gZF40=jUN`3FW7<20<jDJ`@0]G=:00P0aW]:0;EcBP2eLdX0]G]J
0;EcBP2]Hd80W6]:08AB>@80Q48Q00@0]G=:09AJ<@36Q5X0NcTH0P1[<AP01@1B8A00HbT@0:e[>@2e
Jd80U58Y0080]F]200@0cXaJ0:e[>@2mS6<0]G=:0P36Q5X01@3FW7<0gZf40>NmU03W_JD0eZf<0080
]F]20P2mS6<01@3>U6/0aXaS0=JLL`3FW7<0eZf<01`00000:03ooolK000000080;f<H`36Q5X0_HaS
0;f<H`36Q5X0]G]J0;EcBP2]Jd8209a[BP030:e[@P2DFS40[F]20080W6<i102DFS402@24DS40JcTQ
07=2:@1c@RT0JcTQ06/a6024@RT0Q58a0=JeY@030>o>]@030>O6]@3_a[D0ilJ]0080klJ]00<0mlJe
0?O>]@3_c[d00P3ge[d20?ONcPP0kmK600<0klJe0>N]W02mU7/00P36Q6/0103N[I@0kljm0?OF_@3g
e[d30=JUQ080mmJm00@0kljm0?O>]@3ge[d0mmJm0P3gc[D00`3ge[d0mlJe0?O>]@020>o>]@<0mlje
00<0klJ]0>o6Y@3_aZD00P3_aZD00`3_]I`0e[FU0=JeY@020>O6]@040<jUU03N[I`0e[FU0<jeY@80
aZfL00<0]IAk0000000000006P00000N0?ooo`00703ooolJ00000080moOg00L0knog0>oWi`3_inL0
imK60>O6[@36W8@0aYA[0080]G]J00D0W6]:09AJ<@2LHcT0W6<i09AJ<@0208A::@0406<Y401kBRT0
NdXY06/i8@80ilJe00<0mlje0>o>[@3gc[D00P3ge[d20>oFaP030?OF_@3_e/H0mlJe00<0mlJe00<0
mlje0>o6[@3_aZD00P3_aZD20>NmW0040=j]U03N[H`0ijf<0=jUQ080eYak00D0cYA[0;E[DP2]Jd80
[F]20;EcBP020:e[@P050;E[DP2]Jd80[F=209aS>@24@R400P1k@R401036Q5X0Q48Q0<j<H`2LHcT2
06/i8@0507=:<@1B8A00Q48Q0<IkBP2<@R400P2eJd800`36NdX0]F/i0<J4FP030<J4FP050<jDH`3F
W7<0ikfL0>NmY@3F[H@00P36S6<0102eNeX0_HaS0<JDJ`36U6/20=J]Q0030=J]S03F[H@0000001X0
0000:03ooolJ000000030;EcBP2eNeX0]G=:0080]G=:00@0W6<i0:e[@P2LHcT0W6]:0P2]Hd8409aS
>@0609AJ<@2<BRT0S4XY08AB<@1J<B40Jc4H101[>B400`2DFS40kljm0>o>]@030>o>]@<0klJe00H0
klJ]0>o>]@3_c[D0mlJe0?O>]@3ga[D50>oFaP030?ONcP3_e/H0kmK600<0kmK600@0kljm0>N]W02e
Q6/0U7=J0P1cBS401@2mU7/0klJ]0>oFaP3_e/H0eYak0080_Ib<1P3ge[d00`3gc[D0mmJm0?OF_@02
0?OF_@80mlje00@0mmJm0>o>]@3gc[D0mlje0`3_aZd20>neW0050>NeW03W_JD0ilJe0>O6]@3N[I`0
0P3F]JD01@3N[I`0c[FU0<jeY@3F]JD0c[FU01/000007P3oool001`0oooo6P0000000`3gmoL0mnog
0>o_i`020>oWi`040=k>_@3F_Jd0_IAk0;f<H`80]G]J00<0[F]209AS@P2LHcT00P2DFS4206/i8@04
06/a601k@R40JcTQ0:F4J`80klje00@0mlje0>o6[@3gc[D0mlje1@3ge[d00`3_e/H0mmJm0?O6]@02
0?O6]@<0klJ]00L0ikfU0>NeW03W]I`0ikfL0>NeU03W[H`0gZfD0080gZF400<0eYak0<J4J`3>U6/0
0P2]Hd820:e[@P0509a[BP2]Hd80U6=209a:<@24BS400P1c@RT01036NdX0[G=B0;EkFP2eLdX206/a
6005058Q401k@R40W6<i0<IkBP36Q5X00`36NdX00`36Q5X0[F]20<J<H`020;f<H`050<JDJ`3FW7<0
eZf40>NmW03W_I@00P2mS6<0102eLdX0_HaS0<IkBP36U6/20=JeY@030>NmU03>]JD0000001X00000
:03ooolJ000000030:e[@P2eJd80[F]20080[F]200@0W6]:0;EcBP2LJdX0U5Xa0P2LHcT00`2eLdX0
U5Xa09AJ<@0409AJ<@<0JcTQ00@0NcTH07]::@1kBRT0YHA[0P3_c[d00`3_aZd0klje0>o6]@030>o6
]@050?O6]@3_aZd0mlje0?O>]@3ga[D00P3ge[d40>oFaP80mmk>00T0kmK60?ONcP3ge[d0mmJm0>o>
_@3Wa[D0]HAS0<J4J`1J>BT00P24He80102eJe80klJe0?OF_@3_e/H30=j4L`80kmK61P3ge[d30>oF
aP<0mmJm00<0mlje0?OF_@3_cZd00P3gc[D20?O6]@030>o6Y@3W]I`0klJU0080ilJe00@0e[f]0=j]
U03F]JD0e[FU0P3FYH`00`3F]JD0e[f]0000000J000001h0oooo000L0?oooaT0000000@0knoW0?Og
m`3_koL0knoW0P3Wg]H0103Nc[d0cZfD0;fDN`2mS6<20;EcBP0509a[BP24DST0U5Xa08a::@2DFS40
0P1B:AP0101[>B40Ld8Y08aJ@P3_aZd20>o6]@@0mlje00@0mmJm0?O6]@3ga[D0mmJm0P3ga[D01P3g
e[d0mlJe0?O6]@3ga[D0klJ]0>o6Y@80klJ]0P3_aZD20>NeW0090>NeU03N[I@0gZf<0=j]S03NYH@0
eYak0<jDJ`36Q6/0W6<i00<0[F=200@0U5Y209aS>@24BRT0NdXY0P1S:A00102LJdX0eYak08a::@3>
U6/209AS@P050:e[@P1[<AP0[F<a08a:<@2mS6<00P2]Hc401036Nd80aW]:0;f<H`2eQ6<20<JDJ`05
0;EkFP3F[H@0cYAS0>NmY@3_c[D00P2mS6<0102eLdX0_HaS0<J<H`36W8@20=JLL`030=J]Q03F[H`0
ikfD01X00000:03ooolI000000040;EcBP2LHcT0[F]20:e[>@80[F]200<0U5Xa09AB:@2DFS400`2D
FS401@2LBS40W6<i09aS>@24BRT0JcTQ0080DRTH0P1[<AP01`24BRT0NdXY0>o>_@3_c[d0klje0>o>
_@3_a[D01@3_c[D30?O>]@80mmJm00<0kmK60?OF_@3ge[d00P3_e/H30?ONcPD0kmK600D0iljm0=j]
W02mS6<0e[fe0;FDS00208ASDP0508aSBP3W_JD0mmJm0?O6]@2eJe800P3N[I`0103_e/H0mmk>0>oF
aP3_e/H60?OF_@070>oFaP3ge[d0mmJm0?OF_@3_e/H0mmJm0>o>[@020?O>]@050>o6[@3ga[D0klJ]
0>o6[@3WaZd00P3W_JD00`3F_Jd0cZfD0<JLQ0030<JUU080aZfL00<0e[FU0000000000006000000N
0?ooo`00703ooolI000000040>o_i`3gmoL0knog0>o_i`80imkF00@0g/jm0<j]U02mU7/0_HaS0P2e
LdX01@2LJdX0Q58i09AJ<@2<BRT0U5Xa0080DRTH00@0JcTQ07=2:@2<FT80klJ]0P3_a[D40?O>]@04
0?OF_@3ga[D0mlJe0?OF_@80mlJe00H0mmJm0?O6]@3ga[D0mlJe0>o6[@3_aZD20>o6[@80klJU0P3W
]I`02@3W]I@0gZfD0=j]S03N[H`0gZF40=JLN`3>U6/0aXA[09aS>@030:eS@P0409AJ@P2LHcT0Q4XY
07]::@80HbT@00@0W6]:0=JLN`2<BRT0cYA[0P2DHd801@2]Jd80Jc4H0:eS<@2<BS40_HaS0080[F<a
00@0aW]20<IkBP2mS6<0]HAS0P36U6/01@2eNeX0eZf40<jDH`3W_JD0klje0080_HaS00@0]G=:0;f<
H`36S6<0aYb40P3FW7<00`3F[H@0eZf<0>NmU00J000002P0oooo6@000000102eLdX0W6<i0:e[@P2]
JcT20:e[@P0309AJ<@2DDRT0U5Xa00<0U5Xa00D0W4Xa09aS>@2LHcT0Q4XY06/i8@02058Y6080Jc4H
00L0Q4XY07]::@3_c[d0kljm0>o>]@3_c[d0klJe00D0klje0`3gc[D20?OF_@030>oFaP3ge[d0mmJm
0080kmK60`3gg/h50>oFaP050>O>_@3N[I`0_HaS0=Jm]@2eU8`00P24He801@2<HdX0ikfU0?OF_@3g
a[D0]F]B0080gZfL00@0kmK60?ONcP3_e/H0kmK61P3ge[d01`3_e/H0mmJm0?OF_@3ge[d0kmK60?OF
_@3_cZd00P3gc[D01@3_aZd0mlJe0>o6[@3_aZd0ilJ]0080ikfU00<0e[f]0<j]U036W8@00`36YI@2
0<J]W0030=JeY@000000000001P000007P3oool001`0oooo600000020?Ogm`030?O_m`3_inL0knOW
0080iljm00@0g/jm0<JLQ036S6<0[G=B0P2eLdX01@2DHd80U5Xa09AJ<@24DS40JcTQ0080Jc4H00@0
Q4XY08AJ@P3_a[D0klJ]0P3_cZd30?O>]@030?O6]@3_cZd0klJ]00D0klJ]0P3_aZD20>neW0030>Nm
Y@3_aZD0ikfL0080kkfL0P3W]I`02@3N[H`0ijf<0=j]U03N[I@0gZf<0=jUQ03FW7<0cYA[0<j<H`02
09aS>@0409a:<@2LHcT0S4Xa08a::@<0JcTQ00@0Q58i0;f<H`2eNeX0W6]:0P36W8@01@2<@R40]G]J
09AJ<@2]Hd80]F]20080aW]:00@0[F/i0<IkBP2mS6<0W6<i0`2mS6<20=JLL`080<j]U03N[H`0ikfD
0>NmU02mS6<0]F]20;f<H`36W8@20<JDJ`040=J]Q03W_I@0imK>0>o_iaT00000:03ooolH00000005
0;E[>@2]JcT0W6<i08a::@2DFS400P2<BRT0102LBS40W6<i0:e[>@2LHcT309AJ<@0408A28@1S:A00
HbT@06/a6080JcTQ00<0Q4XY06/a603Wa[D00`3_a[D30>o>]@030>o>[@3ga[D0mlje00@0mlje00<0
mlJe0?O>]@3gc[D00P3ge[d60>oFaP030?OF_@3_e/H0kmK60080kljm00D0klJe0;fDN`3N[I`0imK>
0<Je]@0205Y2>@0507]B@P3W]I`0kmK60;F4J`2]Le800`3_e/H20?ONcP040>oFaP3gg/h0mmk>0?OF
_@80mmk>00@0mmJm0?ONcP3ge[d0mmJm0P3_e/H20?O>]@<0mmJm00<0klje0>O6[@3_aZd00`3W_JD0
103N[I`0eZF<0<JLQ02mU7/20:EkH`80YG]J00<0YHA[0=JeY@0000006000000N0?ooo`00703ooolH
000000050?O_m`3gmoL0moOg0>oWi`3We/h00P3Wc[d0103>]JD0_IAk0;EkFP2]Le8209AS@P<0U5Xa
00<0FS4Q06/i8@1[<AP00P1[<AP20>o6]@030?O>]@3_cZd0klj]0080klJ]00<0mlJe0>o6[@3__I`0
0P3W]I`20>N]U0@0gZf<00<0gZF40=j]S03N[H`00P3N[H`40>NeU0030>NeW03W]I@0gZf<0080gZf<
00@0gZF40=jLN`3FW7/0eYac0P3>S6<01@2eJe80U5Xa08AB<@24BS40Ld8Y0080JcTQ00@0LdXa09AS
@P3>U6/0_HaS0P2UNeX01@3FW7<0aW]:0;EkFP24@R40[F/i0080aXAJ00<0aW]20<IkBP2]JcT00`2e
NeX01@3FW7/0aYA[0=JLL`3F[H@0ikfU0080ilJe00@0_HaS0<JDJ`3FW7/0aYA[0P36S6<0103>[I@0
ikfL0?O_i`3Wg]HI000002P0oooo600000001@2DDRT0S4XY08a28@24@R40U58Y00@0W6<i0P2<BRT2
06/i8@05058Q401S:A00JcTQ07]::@1k@R400P1c@RT01024FT80klJe0>o>]@3_a[D20>o6[@050>o>
]@3_aZd0mlje0>o6[@3gc[D00P3ga[D30?O>]@080?OF_@3ga[D0mlJe0?OF_@3_e/H0mmJm0>oFaP3g
g/h40>oFaP80mmJm0P3_c[d01@3_a[D0]Hac0;f][@1kLg<0U7][0080@RTQ00D0Ne920>N]W03WYI@0
YG]S0=JLN`030?ONcP030>oFaP3gg/h0mmk>00D0mmk>00@0mmJm0>oFaP3ge[d0mmJm0`3_e/H30?O>
]@050>o>[@3_c[D0klJ]0>o6[@3W_JD00P3F]JD0103N[I@0eZf<0<JLQ02mU7/20;F4J`040;F<L`2D
Je80U6]B08aSBQT000007P3oool001`0oooo5P0000030?Ogm`80mnog00H0knOW0>OFaP3Nc[d0g/jm
0=J]S036U6/20;EcBP80[F=200D0S4Xa09AJ<@24DS40Jc4H06/i8@0208A::@040>O6]@3_c[D0klje
0?O>]@80klj]0P3_aZd00`3_aZD0ikfU0>N]U0020>N]S0030=jUQ03NW7/0ihak00D0ihak00<0gZF4
0=jLN`3NYH@00P3N[H`0103NYH@0ikFD0>NeU03W]I`20=j]U0040=j]S03NYH@0eZF40=JLN`<0cYA[
00D0aXAS08aJ@P24@RT0NdXY06/i8@02058Y600406/i8@2<HdX0cYA[0:ecDP80U5Xa00D0eZF40<Ik
BP3>U6<0]G]J09aS>@020:e[@P040<j<FP36NdX0]G=:0;f<H`80]G]J00D0eYac0<JDJ`3F[H@0eYac
0=J]Q0020>O6[@040=J]Q03FW7<0aYb40<JLQ080eYac00D0eZf<0>NmY@3_imh0knON0?O_i`0H0000
02P0oooo5P00000207/i60<0S4XY00P0U58Y0:e[>@2DDRT0U58Y09a:<@2DFS40Q48Q07/i6080JcTQ
00D0Ld8Y07]28@1kBRT0NdXY06/i8@0208aJ@P80klJe00<0klje0>o6[@3_aZd0103_aZd0103_cZd0
klJ]0?O6]@3ga[D30?O>]@H0mmJm00@0kmK60?ONcP3_e/H0kmK60P3ge[d01P3_e/H0kljm0>neW03_
]I`0klJ]0=JUS080Lf]S00P0]KFm05Xi:@1J>BT0Ne920>NeW036Q6/0U7=J0?O>]@<0mmk>0P3ge[d0
1@3gg/h0mmJm0?OF_@3gg/h0kmK60080mmJm00@0mmk>0?OF_@3ge[d0mmk>0P3_e/H0203ge[d0kljm
0>o>_@3gc[D0klJe0>o>]@3_aZd0ikfU0P3N[I`0103FYH`0aYb40<JLQ02eS7<20:F4J`030:EkH`2e
U7/0YG]J0080S6]B6000000N0?ooo`00703ooolF00000080mnoW00D0moOg0?O_m`3_knL0imK>0>O>
_@020=k>aP040<JLQ02eNeX0[G=B09aS>@80[F=200D0Q58i08A::@1[>B40JcTQ07/i600207]::@80
klJe1@3_aZd0103_aZD0kkFL0=icH`3>JeX30=ikJ`H0gXAc103>JeX20=JLN`80gZf<103W]I@00`3N
[I@0gZf<0=jUQ0020=JLN`80cYA[00D0aXA[0<J4FP1kBRT0JcTQ06/a6002058Q400406/a6024DST0
[G=B0=JLN`80]HAS00D0aXA[0=J]Q03>U6<0eYac0<JDJ`020<IkBP040;EcBP36Q5X0_HaS0:e[>@80
]G=:00D0_HaS0=JLL`2mS6<0gZf40=J]S0020>NmU0040>NmY@36W8@0eZf40<JDJ`80eYac00D0ikfD
0=k>_@3We/h0knOW0>o_i`0H000002P0oooo5P00000206<Y400506/a601k>AP0U58Y09AJ<@2DDRT0
0P24@R400`1k@R40FS4Q058Y600306/a600506/i8@1c@RT0JcTQ06/i8@2UQ6/00`3_aZd20?O>]@03
0>o6[@3_aZD0klJU00@0klJU0`3gc[D0103ga[D0mmJm0?O>]@3gc[D20?O6]@80kmK600<0mmJm0>oF
aP3gg/h00P3_e/H0103gg/h0mmJm0>o>_@3_a[D20>O6[@050=j]W03>YI@0Lg=[06=JDP0Q61P00`24
DST0103W_JD0YG]S0;E[DP3ge[d60?ONcP80mmJm00@0kmK60?ONcP3gg/h0kmK6103gg/h50?OF_@05
0?O>]@3_aZd0klJ]0>O6[@3W_I`00`3FYH@00`36W8@0_IAk0;fDN`020;fDN`80YG]S00<0]Hac09ak
H`2<Je806000000N0?ooo`00703ooolE000000<0moOg00D0mnoW0?Ogm`3_inL0imkF0>OFaP020=J]
S0040<JDJ`2UNeX0W6]:09aS>@80U5Xa00D0NdXY08AB>@1c@RT0JcTQ07]::@020>o>_@040>o6]@3_
aZd0klJ]0>o6Y@80klj]00<0klJ]0>N<N`3NQ7<00P3NQ7<20>o6]@040>neW03WS7/0ihak0>NUU080
kkFL0P3NQ7<00`3NNf/0aXA[0<icH`020<i[FP040=JLN`3N[H`0gZfD0>NeU080ikFL00D0gZfD0=j]
S03N[H`0eZF40=JLN`020<jDJ`040=j4L`36Q6<0]G]J07=:<@<0DRTH00@0DR4@08AB>@1B:AP0eZF4
0P3N[H`01@2LHcT0eZf<0;EkFP3NYG/0eZf40080_HaS00@0aXAJ0<jDH`2]Hc40aXAJ0P2eNeX01@2m
S6<0aYA[0<jDJ`3FW7/0eZf<0080ikfU00@0ilJe0;fDN`2eQ6<0aYA[0P3FW7<00`3>[I@0knON0>oW
gP020>o_i`80knON5P00000X0?oooaD0000000P0HbT@058Q401B8A00Jc4H08A28@2DDRT0S4XY06/a
6080HbT@00<0JcTQ06<Y401B:AP01P1[>B40103Wa[D0klje0>o6]@3_a[D30>o>[@080>o6[@3_cZd0
klj]0>o6Y@3WS7/0kkFL0>o>[@3_aZd20>o>]@L0mlje0P3ge[d70>oFaP080>o6]@3_aZd0klJ]0=j]
U02mU7/0YHAc08AkL`24Lf/208a[DP0509AcFP3W]I`0W7=B0=JUQ03ge[d0203gg/h00`3ge[d0mmk>
0?OF_@020?ONcP80mmJm00@0kmK60?OF_@3ge[d0mmJm0`3gc[D0103ga[D0klJ]0>NmY@3N[I@20<j]
U0030=JUS036W8@0aYb400<0_IAk00@0]HAS0;F<L`2DLeX0]HAS0`2UQ6/F000001h0oooo000L0?oo
oaD000000`3gmoL01@3gknL0moOg0>oWi`3Wg]H0imK60080eZf<00@0aYA[0:EkFP2LJdX0W6<i0P2D
FS401@1kBRT0Q58i07=2:@1[>B40NdXY0080kljm00@0klJe0>o6[@3_aZd0klJU0P3_cZd00`3_aZd0
ihak0=j4L`020=j4L`80klJe00@0kkFL0>N<N`3WS7/0ijFD0P3_]I`20=j4L`030=ikJ`36Q6/0cW=S
0080cV]J00@0eYak0=j]S03N[I@0ikFD0P3W]I`01@3N[I@0gZf<0=j]S03FYH@0eYak0080cYA[00@0
gXAc0<J4H`2eNeX0LdXa0`1B:AP0101B8A00Q58i058Y603FYH@20=j]S00509aS>@3F[H`0]G]J0=jU
N`3F[H@00P2mS6<01036Q5X0cYAS0:eS<@36Q5X20;EkFP050;f<H`36U6/0cYA[0=JLN`3F[H`00P3W
_JD0103Wa[D0_IAk0;F4H`36U6/20=JLL`030<j]U03_imh0knON0080knoW0P3_imhF000002P0oooo
5@000000201S:A00DR4@058Q401[<AP0Q48Q09AB:@2<BRT0Jc4H0P1S:A000`1[>B40HbT@058Y6006
06/i8@040>O6]@3_c[D0klJe0>o6]@<0klj]00P0klJ]0>o>[@3_cZd0klJU0>N<N`3_]I`0klj]0>o6
[@80klje1`3gc[D20?OF_@L0kmK600P0klJe0>o6[@3_aZd0gZfD0;fDN`2UQ7<0Q7]c08AcJ`80S6]B
00D0U7=J0>NeW02LLe80eZF40?OF_@080?ONcP030?OF_@3gg/h0mmJm0080mmk>0P3ge[d0103_e/H0
mmJm0?OF_@3ge[d30?O>]@040?O6]@3_aZd0ikfU0=j]U080cZfD00<0eZF<0<JLQ036W8@00`2mU7/0
102eQ6<0]Hac09AcFP2eQ6<30:F4JaH000007P3oool001`0oooo5@0000030?Ogm`050>o_m`3gmoL0
imKF0=k>_@3>[I@00P36U6/0102eQ6<0YG]J08AB>@2DFS4208a:<@0509AJ<@1S:A00JcTQ06/i8@2U
Q6/0103_c[D00`3_aZd0klJU0>o6Y@020>o6Y@040=ikJ`3NQ7<0gXAc0=ikJ`@0gW=S00D0gXAc0<i[
FP3>JeX0cV]J0<IJBP020<ISBP070>N<N`3>Lf<0cW=S0<icH`36FTX0eZF<0>N]U0050>NeU0030=j]
S03FYH@0eYak0080eYak0P3>U6/00`36Q5X0[G=B06/i8@0206/i8@0403TH401[<AP0S5Y20;F4H`80
aYA[00D0]G]J0;f<H`3F[H@0aXAJ0=j]Q0020>o>[@040;f<H`2eLdX0aXAJ0<J4FP80[F]200<0]G]J
0<jDH`36U6/00P3FW7<30>NmY@030<JLQ036U6/0aYb40080_IAk00@0cZfD0>oWgP3_inL0mnoW0`3_
inLF000002P0oooo5@000000201:60P0Jc4H06/a601k@R40S48Q07/i601[>B40Jc4H0P1[>B400`1k
@R40Jc4H06/a600306/i8@80Jc4H00<0]Hac0?O>]@3gc[D00`3gc[D50>o6[@030>o6Y@3NQ7<0klJU
00D0mlje00<0klje0>o>[@3gc[D00P3_cZd00`3gc[D0mlJe0?OF_@020?OF_@<0kmK600<0mmk>0>oF
aP3_c[d00P3_aZd01@3W_JD0gZfL0<JLQ02UNf/0FTY20080Q6=B00@0aXA[0=JLN`2eJe80klJU403g
g/h0103ge[d0kmK60?OF_@3gc[D20?OF_@80mlje00<0klJ]0>NmY@3N[I@00P3FYH`0102mU7/0]Hac
0;fDN`2eS7<20;F4J`050:EkFP2eU7/0U7=J09AcFP2UQ6/00P2<HdXF000001h0oooo000L0?oooa@0
000000<0mnog0?Ogm`3gkoL00`3gkoL00`3We/h0e/Je0=JLL`020<JDJ`040:ecDP2DHd80S4Xa09AJ
<@80Q4XY00@0Jc4H07]28@1[<AP0U5Xa0`3_c[d0103_c[D0klJ]0>o6[@3_aZD20>N<N`050=j4L`2]
Le80W4Xa0:e:<@2mDT800P2]Le820;eB@P090<IJBP2eDST0W4Xa09a:<@2L<B40W48Y0:e:<@2<<B40
[D8a0080W48Y00<0Q48Y09AJ@P3NQ7<0103W]I@30=j]S0<0eYak00D0eYac0=JLN`36Q6<0]G]J08aJ
@P0204XH200403TH401[>B40LdXa08AJ@P80_HaS00D0eZF409AJ<@3FYH@0]G]J0=JLN`020>NmW004
0>o>[@3>U6/0cYA[0;E[>@80aXAJ00D0]G]J0;f<H`36S6<0]G]J0=J]Q0020>NmU0040>NmY@3F_Jd0
eYac0=J]Q080aYb400D0e[FU0>ONeP3_knL0knON0>o_i`020?O_m`030>o_i`000000000001<00000
:03ooolD000000080=j]W03N[I@0gZfD0=j]U01kBRT0HbT@04XH201[<AP306<Y400406/a601[>B40
Jc4H07/i6080JcTQ00D0Q58a0;F4H`3_a[D0klj]0>o6[@030?O>]@80klJ]00H0klJU0>N<N`3WS7/0
gW][0:ecDP3WS7/70?O>]@060?O6]@3gc[D0mlje0?O6]@3_aZd0mlje0P3ge[d30>oFaP030?ONcP3_
e/H0kljm0080klJe00D0ilJ]0=j]W03NQ7<0aYb409AcFP020:EkH`040=JUQ03NYH@0ikFL0?O>]@@0
mmk>00<0mmJm0?ONcP3ge[d00P3ge[d00`3gg/h0mmJm0?OF_@020?ONcP80kmK600<0mmJm0?ONcP3g
e[d00`3ge[d20?O>]@030>o6]@3W_JD0eZF40080eZF<00@0aYb40;fDN`2mU7/0YHA[0P2LLf<00`2D
LeX0]HAS0:EkH`0209A[DP<0YHAc5@00000N0?ooo`00703ooolD00000080mnog0P3gknL01@3gkoL0
knOW0>OFcP3F_Jd0_IAk0080]G]J00@0U6=208a:<@2<FT80S4XY101kBRT00`24@RT0kljm0>o>_@02
0>o6]@040>o>]@3gc[D0klJ]0>o6Y@80kkFL00D0klJU0>N<N`3>Lf<0cV]J0<ISBP020<i[FP030<IS
BP3>JeX0gW][00L0aV=:00@0eYac0=JUQ03FYH@0eZF<0P3N[H`30>NeU080ijf<00<0gZf<0>N]S03N
YH@00`3FW7/0103FW7<0cYA[0<J4H`2LLe8205Xi:@80>AP@00T0FSTY08AJ@P2LLe80W7=B0=JLN`36
U6/0W6]:0=JLL`2eNeX00`3W_I`00`3_c[D0[G=B0<J4FP020<J4FP040;EkFP2mS6<0_HaS0;EkFP<0
eZf400@0ikfU0>O6[@36U6/0eZf40P3FW7<00`3We/H0knOW0>oWi`020>oWgP<0mnog5@00000X0?oo
oa@00000103N[I@00`3N[I`0gZfD0>NmW0020>NmY@80ikfL00<0ikfU0>NmW03W_I`0103N[I@00`3_
aZd0mlje0?O>]@040?O>]@030?O6]@3_aZD0kkFL00<0gXAc00@0W4Xa0<icH`3ge[d0mmJm1@3gc[D0
0`3_e/H0mmJm0?OF_@020?OF_@030?O>]@3ga[D0mmJm00D0kmK600P0mmJm0>o>_@3_c[d0klJe0>o>
_@3NQ7<0_IAk0;F4J`80_IAk00@0ikFL0>N]U03_aZD0mlje1P3gg/h0203ge[d0mmk>0?ONcP3_e/H0
mmk>0>oFaP3gg/h0kmK60P3ge[d00`3_e/H0mmJm0?OF_@030?OF_@050?O>]@3ge[d0klJ]0>NmY@3N
[I@00`3FYH@00`2eS7<0]HA[0:F<L`020;F4J`050:F4J`2DJe80S6]B08AJ@P2UQ6/00P2DLeX00`2U
S7/000000000000C000001h0oooo000L0?oooa<0000000<0mnoW0?Ogm`3gkoL00P3_knL01@3gknL0
knON0=k>aP3F[H`0]HAS00<0W6]:00<0S5Y208a::@24BRT00P1c@RT01@1kBRT0Q48Q08AB<@3_c[D0
klJ]0080klje00@0klj]0>o6[@3_cZd0klJU0P3_cZd20?O>]@030?OF_@3_e/H0klJe0080klJ]00@0
mmJm0>o6[@3_aZD0mlje0P3ge[d01@3_a[D0klJ]0>NmY@3W]I`0ikfU0080ikFL0P3W]I@01P3W]I`0
ikFD0>NeW03W]I`0ikFD0>N]U080gZf<0`3NYH@01@3FW7/0eYac0<jDJ`3>U6/0]G]J0080Q58a00@0
@S4Y02T@2024FT80LdXa0P24FT801@2LLe80_HaS09aS>@36Q5X0[F]20080aXAJ0P3W_I`0103FW7<0
cYA[0;f<H`2mS6<20;EcBP030;f<H`3>U6/0eYac0080cYA[00@0ikfU0>O6[@36W8@0aYb40P36S6<0
1@3Wg]H0knON0>oWgP3_inL0knON00@0moOg5000000X0?oooa@0000000L0ikFD0>NmW03W]I@0ikFD
0>NmU03W_I`0ikFD0080ikFL0P3W_I`0103N[I`0gZfD0=j]U03N[I@20=j]S0040>O6[@3_a[D0mmJm
0?OF_@<0mlje00@0mlJe0>o6[@3W_JD0gW=S0`3NQ7<00`2]BS40cV]J0>oFaP030?O>]@040>o>]@3g
c[D0mlje0=jLN`80klje00D0klJe0?OF_@3ga[D0kljm0?O>]@030?OF_@030>oFaP3ge[d0mmJm0080
mmJm0P3_c[d00`3_a[D0ijfL0;fDN`020>N]U0040>o6[@3_aZD0mmJm0?OF_@<0mmk>00<0mmkF0?ON
cP3gg/h00`3gg/h30?OF_@040>oFaP3gg/h0mmJm0?OF_@80kmK6103ge[d01@3gc[D0klJe0>o6Y@3W
]I`0ikfL0080eZF<00@0aYb40;fDN`2eQ6/0]Hac0P2eQ6<20:F4J`0308aSBP1kFT80Q58i0080YG]S
00<0YG][0000000000004`00000N0?ooo`00703ooolC000000030?O_m`3gknL0mnog0080mnog00D0
knOW0=k6]@3W_I`0aYb40:ecDP0209AS@P80Q58a00<0Q4Xa06/a601kBRT00P1kBRT00`1k@R40e[FU
0>o>]@030>o>]@040?O6]@3gc[D0klJ]0?O>]@80klJ]0P3gc[D00`3ge[d0mlje0?OF_@020?O>]@03
0?OF_@3_aZD0klJ]00<0klJ]103W]I`01`3W_I`0ikFL0>NeW03W_I`0klJU0>NeW03W]I@00P3W_I`0
103W]I`0ijfD0>N]U03N[H`30=jUQ0050=JLN`3NQ7<0cYA[0<jDJ`2eNeX00P2DFT80101B8A00@R4H
07=:<@24DS420:F4J`0509acDP36W8@0W6<i09AJ<@36S6<00P2mS6<0103N[I@0ikfL0>o6Y@3F[H@3
0<J4FP040<J<H`2eLdX0]G]J0;EkFP80cYA[00@0ikfU0>O6[@3FW7<0eZf<0P36U6/01@3_imh0knOW
0>ONeP3_imh0mnoW00@0moOg5000000X0?oooa<0000000<0ikfD0>NeU03W]I`00`3W_I`20>NmY@03
0>o6Y@3W_I`0ikfL0080ikfL00<0ikFL0>NeU03N[H`00P3N[I@00`3_aZd0mmJm0?O>]@040?OF_@04
0>o>[@3__I`0ijfD0<i[FP80gXAc00D0gW][0;eB@P36HdX0klJe0?OF_@030?O>]@80klJ]00<0gW][
0>o6]@3_a[D00`3_e/H01@3ga[D0klJe0?O>]@3gc[D0kljm0080mmJm00@0mlJe0>o>]@3_c[D0ilJ]
0P3_a[D01@3N[I@0ikFL0>nmW03__I`0klJ]0080mmJm203gg/h20>oFaP050?ONcP3_e/H0mmk>0>oF
aP3ge[d00`3_e/H00`3ge[d0kmK60?O>]@030?OF_@040>o>]@3_aZd0gZfL0=JUS080eZF400<0aYA[
0;F<L`2mU7/00`2UNf<01@2DLeX0YG]J09acH`1kFT80Q5Y20080U6]B00<0_IAk0=Jm]@0000004`00
000N0?ooo`00703ooolC00000080mnog00P0mnoW0?O_m`3gkoL0mnog0=k>aP36W8@0]G]J09aS>@80
W6]:00<0Q4XY08A:<@1[>B401@1kBRT20>o>]@040>o6]@3_c[D0klje0?O>]@80mlJe00<0mlje0>o>
]@3_c[D01`3gc[D00`3_c[D0klJ]0>o6Y@030>o6Y@050>NeW03W_I`0kkfL0>NeW03W_JD00P3W]I`0
0`3_aZD0ikFL0>o6Y@030>NeW080ijfD00<0ikFD0=j]S03NYH@00P3NW7/01@3NYH@0eYac0<jDJ`3>
U6/0aXAS0080W6]:00@0Ld8Y05Xi:@0i6100Le920P24DST01@2DHd80W6<i0:ecDP2LHcT0]G]J0080
YG]J00@0cYA[0>NmU03W_I@0cYA[0P3FW7<01@36Q5X0_HaS0;EcBP2mS6<0]G=:0080eYac00@0eZf4
0>NmY@3>[I@0aYA[0P3FW7/01@3We/h0knON0>oWgP3We/H0moOg0080mnog0P3gmoLD000002P0oooo
4`0000000`3__I`0ikfU0>NmW0020>NmW080klJU00<0ikfL0>NmY@3N[I@00P3W_I`0103W]I@0gZfD
0>NeW03N[H`20>NmY@050>o6[@3ga[D0mmJm0>oFaP3ge[d00P3ga[D0103_aZd0ikFL0>N]S03NNf/2
0>o6]@040=icH`2]Le80cV]J0>o6[@@0mlje00<0klJ]0>neW03_aZd00P3ga[D00`3_e/H0mmkF0>oF
aP060?OF_@040>o6]@3gc[D0mlje0?O>]@80klJe00<0ilJ]0>o6Y@3_cZd0103gc[D20?OF_@030?ON
cP3gg]H0mmkF00H0mmk>00D0mmJm0?ONcP3ge[d0mmk>0>oFaP020?OF_@040>oFaP3ge[d0mmJm0?OF
_@80mlje00D0mlJe0>o6[@3_aZd0gZf<0=jUQ0020=JUQ0040<JLQ02mU7/0]HAS0;F4H`80]Hac00D0
YG]S08aSBP2DLeX0S6=:08AJ@P0208AB>@030<JUU036YI`0000001<000007P3oool001`0oooo4`00
00020?O_m`080?O_i`3gkoL0mnog0?O_m`3Nc/H0aYb40;EkFP2LHcT209a[BP0308A::@24BS40JcTQ
00D0NdXY0P3_c[D0103_a[D0klje0>o>]@3gc[D20?O6]@030?O>]@3_c[D0klje00L0mlje00<0klje
0>o6[@3_aZD00`3_aZD01@3W]I`0ikfL0>nmW03W]I`0ikfU0080ikFL00<0klJU0>NeW03_aZD00`3W
]I`20>N]U0030>NeU03N[H`0gZF40080gYak00D0gZF40=JLL`3>U6/0cYA[0<J4H`0209a[BP0407=2
:@1J>BT0>AP@07=B@P80Q58i00D0U6=209aS>@2]Le80W6<i0;EkFP020:EkFP040<jDJ`3W_I@0ikfD
0<jDJ`80eYac00D0aXAJ0;f<H`2eLdX0_HaS0;EcBP020=JLL`040=J]Q03W_JD0cZfD0<JDJ`80eYak
00D0imK>0>oWgP3_imh0imK60?Ogm`020?O_m`80moOg5000000X0?oooa<0000000<0kkfL0>NmY@3W
_I`00P3W_I`20>o6Y@030>NmW03W_JD0gZfD0080ikfL00@0ikFD0=j]U03W]I`0gZf<0P3W_JD01@3_
aZd0mlJe0?OF_@3_e/H0mmJm0080mlJe00@0klJ]0>NeW03W[H`0gW][0P3_a[D0103NLf<0[G=B0<i[
FP3_aZd40?O>]@030>o6[@3_]I`0klJ]0080mlJe00<0kmK60?ONeP3_e/H01P3ge[d0103_a[D0mlje
0?O>]@3gc[D20>o6]@030>O6[@3_aZD0klj]00@0mlje0P3ge[d00`3gg/h0mmkF0?ONeP060?ONcP05
0?OF_@3gg/h0mmJm0?ONcP3_e/H00P3ge[d0103_e/H0mmJm0?OF_@3ge[d20?O>]@050?O6]@3_aZd0
klJ]0=j]S03NYH@00P3FYH@01036W8@0_IAk0;F4H`2eQ6<20;F<L`050:EkH`2<HdX0U7=J08aSBP24
FT800P24DST00`36YI@0aZFL0000000C000001h0oooo000L0?oooa8000000P3gmoL20?O_m`80mnoW
00D0g/k60=K6]@2mU7/0]G=:09a[BP0208A::@0408aJ@P1[>B40NdXY06/a6080NdXY00<0Q4XY06/i
8@3_c[D00P3_a[D20>o>]@<0mlje00<0mlJe0?O>]@3gc[D00`3gc[D0103_c[D0mlje0?O>]@3gc[D2
0>o6Y@090>NeW03_aZD0ikFL0>NeW03W[H`0ikFD0>NmW03W]I`0kkFL0080kkfL00@0klJU0>neW03_
]I`0klJ]0P3_aZD20>NeW0030>N]U03W[H`0gZF40080gZF400D0eYak0=JLL`3NQ7<0aXA[0<J4H`02
0;EcBP0407=:<@1B8A00DRTH07=:<@80S6=:00D0U6]B09acDP2eQ6<0W6]:08aJ@P0209AS@P040;fD
N`36S6<0gZEc0>o6Y@80eZf400D0aW]:0<J<H`2LJdX0aYA[0;f<H`020=JLN`040=JLL`3W_JD0cZfD
0;f<H`80ilJe00D0imK60>oWi`3_inL0knOW0?O_m`050?Ogma<00000:03ooolC000000030>o6Y@3W
_I`0ikfL0080ikfU0P3W_I`00`3__I`0ikFD0>NmW0030>NmW080ikFD00@0ijf<0>N]U03W[I@0klJ]
0P3ga[D40?OF_@040>o6[@3W[I@0gZF40=ikJ`80kkFL00<0gW=S0;eB@P36HdX00P3ge[d20>o>]@04
0>o6Y@3W]I`0ijfL0>o6[@80mlJe0`3_e/H00`3ga[D0mmJm0?OF_@020?OF_@<0kmK60P3ge[d00`3_
e/H0mmJm0?OF_@020?OF_@80mlje00@0mmJm0>oFaP3gg/h0mmk>103_e/H00`3ge[d0mmk>0?ONcP02
0?ONcP050>oFaP3ge[d0kmK60?OF_@3gg/h00P3_e/H30?OF_@080>o>]@3gc[D0mlje0?O6]@3_aZd0
kkfL0=j]U03FYH@20<JDJ`040;fDN`2eQ6/0YG]J0;F4H`80YG]S00D0U7=J0:EkH`2<Je80S6=:09a[
BP0207]B@P0309akJ`3Wc/H0000001<000007P3oool001`0oooo4P0000020?O_m`80moOg0P3_inL0
1@3Na[D0aZFD0;fDN`2LJdX0W6<i0080U6=200@0Q48Y07]::@1kBRT0LdXa0P1kBRT00`1[>B40]HAS
0>O6]@020>o6]@D0mlje00@0mmJm0?O>]@3gc[D0klje0`3gc[D30>o6[@040>NeW03N[H`0gZF40>N]
U080gZfD00D0gZF40=j]S03W[I@0ikFD0>NeW0020>nmW0040>NmY@3_aZD0klJ]0>o6[@<0kkFL00<0
ikFL0>N]U03N[H`00`3NYH@20=JLN`030=JLL`3>U6/0aW]J0080]F]B00@0S5Y205Xi:@1[>B40FT8i
0P24FT801@24DST0W7=B09AS@P2eLdX0Q58a0080W6<i00@0Q58i0=J]S03W_I@0eYac0P3NYG/01@36
S6<0aYA[0:EkFP2eNeX0_HaS0080aYb400@0eYac0>NmW03F]JD0aYA[0P3Wg]H00`3W_JD0mnog0>oW
i`070?Ogma<00000:03ooolB000000040>o6Y@3__I`0kkfL0>nmW0D0ikfL0P3__I`40>NeU0090>N]
S03N[H`0ijfD0>N]U03_aZD0klJ]0?OF_@3_e/H0mmJm0080mlJe00@0klJ]0>N]U03NW7/0gXAc0P3W
S7/01@3NLf<0_E920<i[FP3_aZd0klJU0080klJ]00@0klJU0=j]S03W]I@0kkFL0P3_aZd20?O6]@03
0?O>]@3_a[D0klJ]0080mlJe00<0mmJm0?O6]@3_e/H0103_e/H70?OF_@H0kmK600<0mmk>0>oFaP3g
g/h00`3gg/h30>oFaP040?OF_@3_e/H0kmK60>oFaP<0mmJm00P0mlje0?OF_@3ge[d0klJ]0>o6Y@3W
]I`0gZfD0=JUS080aYA[00@0aXA[0;fDN`2UNf<0S6=:0P2eQ6<20:EkH`<0U6]B0P1cBS400`1kDT80
kmK60=k6]@0C000001h0oooo000L0?oooa80000000<0moOg0?O_i`3gmoL00`3gkoL0103W_I`0_IAk
0:ecDP2DHd8308a:<@0307]::@1[>B40JcTQ00<0NdXY00D0Jc4H0>O6]@3_a[D0klJe0?O6]@080?O>
]@050>o>[@3gc[D0mlje0?O>]@3_aZd00P3_]I`00`3W[I`0ikFD0=jLN`030=jUQ0050=JLN`3FYH@0
gZf<0=j]S03W]I@00P3W]I`00`3__I`0kkFL0>o6Y@030>o6Y@050>neW03_aZD0kkFD0>N]U03N[H`0
0P3NYH@20=JLN`030=JLL`36Q6/0aXAS0080]G]J00@0U5Y205Xi:@0Y40P0@RTQ0P1cBS401024DS40
W6]:08AB>@2eLdX309aS>@0407]::@3FYH@0aXAJ0=JLL`80klj]00D0aYA[0<J<H`36S6<0]G]J0;F<
L`020<J4FP040<JDJ`3W_I`0e[f]0=Jm[@80g/jm0P3We/h00`3Wc/H0moOg0?Ogm`050?Ogma<00000
:03ooolB000000040>o6Y@3__I`0kkfL0>nmW0<0klJU0P3__I`0103W_I`0kkfL0>nmW03__I`30>N]
S0050=jUQ03WYI@0ijFD0>o6Y@3_aZd00P3ga[D01`3_e/H0mlJe0?O6]@3_aZd0gZf<0>N<N`3NQ7<0
0P3WS7/01@3NQ7<0aUY:0=ikJ`3_aZD0klJ]0080klJU00@0ikFL0=jUQ03NW7/0ijFD0P3W]I@00`3_
aZD0klJ]0>o6[@020>neW080klJ]0P3ga[D70?OF_@030>o>]@3gc[D0mlje0080mlje0`3ge[d00`3_
e/H0mmk>0?ONcP030?ONcP<0kmK600<0mmJm0>oFaP3ge[d0103ge[d0103_e/H0mlje0?OF_@3_c[d2
0?O>]@050>o6[@3_]I`0ijf<0=JUQ02mU7/00P2eS7<0102eQ6<0YG]J09AS@P36U6/308AJ@P0408aS
BP2UNf<0U7=J09acDP80S6=:00<0S6]B0?O_i`3Wa[D04`00000N0?ooo`00703ooolA000000D0moOg
0P3_inL01@3F[H`0]HAS09AS@P24DS40S4Xa0080JcTQ00@0NdXY07=2:@1kBRT0Q48Y0P1[<AP00`1J
<B40klJe0>O6[@020>o6[@80mlje00<0mlJe0?OF_@3ge[d0103gc[D0103ga[D0kmK60=jLN`3NNf/3
0>o6[@030>neW03WYI@0]F=20080]F=200D0aXA[0=jLN`2eNeX0eYac0=j]S0020>NeW080klJU103_
aZd01@3_aZD0kkFL0>NeW03W[I@0ijf<00<0gZF400@0eYak0=JLL`3>U6/0aXAS0P2eJe80102]Hd80
Ld8Y03TH4012:B4205Xa8@0307=:<@24DST0Q5Y20080W6]:0P24DS40102LJdX0S5Y20;f<H`3N[H@2
0=JLL`040=j]Q036Q5X0_HaS09aS>@<0]G]J00@0eYac0>NmU03F_Jd0knOW0P3>[I@00`3_inL0e[FU
0?Ogm`080?Ogma800000:03ooolB000000030>o6Y@3__I`0kkfL00@0kkfL0P3_]I@00`3W_I`0ijf<
0>NmU0020>NmU0030>N]S03NYH@0gZf<0080ijfD00@0kkFL0?O6]@3gc[D0mlJe0`3ge[d0103_aZd0
gZf<0>N<N`3NQ7<20>NUU0050<i[FP2eDST0aV=:0?O>]@3_aZd00`3_aZD00`3W[I@0gZF40;ES@P02
0=j]S0050>NeU03W_JD0ijfD0>NeW03N[I@0103W]I`01`3W_JD0klJ]0>o6[@3_aZd0kkFL0>o6[@3_
aZD01@3_aZd0103gc[D0kmK60?OF_@3_e/H30?ONcP030>oFaP3gg/h0kmK600<0kmK60`3ge[d00`3_
e/H0mmJm0?OF_@030?OF_@080?O>]@3_aZd0klJ]0>o6[@3W]I`0ijfD0=JUQ036W8@20;F<L`040;F4
J`2LLe80YHA[0:EkFP80W7=B00D0YG]J09acDP2DLeX0S6=:08AB>@0207]J@P0307]B@P3_imh0iljm
01<000007P3oool001`0oooo4@0000040?Ogm`070?O_m`3Wg]h0imkN0<JDJ`2]Le80U6=209aS>@03
07]::@0406/i8@1k@R40NdXY06/i8@80FS4Q00D0Q58i0>o6]@3_aZd0klje0?O>]@020?OF_@040?O>
]@3ga[D0mmJm0?O6]@80mlje00D0klj]0?O>]@3ge[d0klje0>o6]@030?O6]@030>o6[@3W]I@0gZf<
0080gZfD00D0ijf<0>NeU03NYH@0cXaS0=JLN`020>NeW0H0klJ]00D0kkFL0>o6Y@3_aZD0kkFD0>N]
S0020=j]S0050=jUQ03FW7/0cYA[0<jDJ`36Q6<00P36NeX0102LLe80S5Y202T@200i6102048Y8@05
05Y2>@1cDT80S5Y208AB>@2LLe800P24DS40102DFS40DRTH0=J]Q03>S6<20<jDH`050>NmW02eNeX0
_HaS09a[BP2]Le800P2mS6<01036U6/0cZfD0=k6]@3Na[D20<J]W0040=JeY@3gmoL0moOg0?O_m`H0
moOg00<0mnog0000000000004000000X0?oooa80000000@0klJU0>nmW03__I`0kkfL0P3_aZD0103_
_I`0ikfD0>neU03__I`50>N]S0060=jUN`3NYH@0ijFD0>NUU03_]I`0klJ]1@3ga[D0103_aZD0gZf<
0>N<N`3NQ7<20>neW0050<i[FP2LBS40aV=:0?OF_@3_aZd00P3_aZD0103W]I`0gZfD0=jUQ02eHd82
0=j]U0040>N]W03W[I@0eZF<0=JUS0D0gZfD0P3W[I@20>NUU080gZfD0P3W]I`01P3W_I`0kkfL0>nm
W03_aZd0klj]0?O>]@80mmJm0P3gg/h20>oFaP060?ONcP3_e/H0kmK60>oFaP3ge[d0kmK61P3ge[d5
0?O>]@050>neW03W]I`0ijfD0=JLN`36Q6/00P2eQ6/0102LLe80YG][0:F4J`2<HdX209AcFP0509a[
BP2UNeX0S6=:08aSBP2UNf/00P2LLf<00`2DLeX0kmK60>O6]@0C000001h0oooo000L0?oooa400000
103gmoL01`3gkoL0imkN0>ONgP36U6/0[G=B09AS@P2LHcT00`1kBRT0101[>B40Nd8Q07]::@1[>B42
05Xa8@0508AB>@3_a[D0klJ]0>o>]@3gc[D00P3ge[d0103gc[D0mlJe0?OF_@3ga[D20?O>]@050>o>
[@3gc[D0mmJm0>o>]@3_a[D00`3ga[D00`3_aZd0ikFD0=j]S0020=j]U0050>N]S03W]I@0gZF40<j<
H`3FW7/00P3W]I`60>o6[@050>neW03_aZD0klJU0>neU03W[H`00P3N[H`01@3NYH@0eYak0<jDJ`3>
U6/0aXAS0080aW]J00@0W7=B08aJ@P0Y40P0>AP@0P12:B401@1J@ST0Le9208aJ@P24DST0W7=B0080
Q58a00@0U5Xa058Y603F[H@0cXaS0P3>U6<01@3W_I`0]G]J0;f<H`2LJdX0[G=B0080_HaS00@0aYA[
0<j]U03Na[D0g/Je0P36[I`0103F]JD0moOg0?Ogm`3gkoL60?Ogm`030?O_m`000000000001000000
:03ooolB000000040>o6Y@3__I`0kkfL0>nmW080klJU00@0kkfL0>NmU03_]I@0kkfL1@3W[H`01P3N
YG/0gZF40>NUU03WYI@0kkFL0>o6[@D0mlJe00@0klJU0=j]S03WS7/0gXAc0P3_]I`01@3>JeX0W4Xa
0<ISBP3ge[d0klJ]0080klJU00@0ikFL0=j]U03NYH@0]F=20P3N[I@0103W[I`0ijfD0=JUS03FYH`5
0=j]U080ijfD0P3WYI@20=j]U080ikFL00H0ikfL0>nmW03__I`0klJ]0>o>[@3gc[D20?OF_@80mmk>
0P3_e/H01P3gg/h0kmK60>oFaP3_e/H0mmJm0>oFaPH0mmJm1@3gc[D01@3_]I`0ikFL0>N]U03FW7/0
aXA[0080]HA[00@0W7=B0:EkJ`2UQ6/0S6=:0P2DLeX01@2LJdX0YG]J08aSBP2<HdX0YG][0080W7=S
00<0U7=J0>oFaP3Wa[D04`00000N0?ooo`00703ooolA000000030?Ogm`3gknL0moOg0080moOg0P3W
e/h01@2mS6<0U6=209AJ@P1[>B40LdXa0080Q4Xa00<0Ld8Y07]::@24BS400`1S:A000`2UNf<0ilJ]
0?O6]@020?O6]@80kmK60`3ge[d01`3_e/H0mlje0?O>]@3gc[D0mlJe0?OF_@3_a[D0103_e/H00`3g
a[D0klJU0>NeU0030>N]W0040=j]U03N[H`0gZF40=jUQ080kkFL0P3_aZd00`3ga[D0klJ]0>o6[@02
0>o6[@<0kkFL00D0ikFD0>N]S03W[H`0gZf<0=jLN`020=j4L`070<J4H`2eNeX0]G]J0:e[@P2DHd80
:A08048Q600203TH400507=:<@24DST0U6=207=2:@2LJdX00P24DS40102DFS40FS4Q0<JDJ`2mS6<2
0=J]Q0050>NmW02eNeX0_HaS0:ecDP2eNeX00P2eQ6<0102mU7/0eZf<0=k6]@3Na[D20=Jm[@040=k>
_@3gmoL0moOg0?O_m`L0moOg4P00000X0?oooa40000000@0klJU0>nmW03_aZD0klJU1P3__I`40>ne
U0040>N]S03NYH@0gZEk0=jUQ080ijFD00@0kkFL0>o6[@3_aZd0mlje0`3ga[D00`3_]I`0gZF40>N<
N`030=j4L`040<IJBP2L<B40aV=:0>o6]@<0ikFL00@0ijf<0=jUQ03FW7/0aXA[0P3W[H`00`3W[I`0
ijFD0=jUQ0020=j]S080ikFD00<0ikFL0=j]U03N[I@00`3N[H`01@3NW7/0eYak0=JLN`3NYH@0ikFD
0080ikFL00D0klJU0>o6[@3ge[d0mlje0>oFaP020?OF_@040>oFaP3gg/h0kmK60>oFaP<0mmJm00@0
kmK60?OF_@3ge[d0mmJm0P3_e/H0103ge[d0mlje0?O>]@3gc[D30>o6[@040>neU03W]I@0eYak0<jD
J`80]Hac00@0_IAk09AS@P2<HdX0_IAk0P2<HdX0102DJe80U7=J0:EkFP2UNeX309acDP040;FDN`3W
c/H0kmK60>OFcQ8000007P3oool001`0oooo4@0000001@3gmoL0mnog0?O_m`3gmoL0mnog0080ilk6
00@0[G=B08aJ@P2DFS40Q58a0`1kBRT01024BRT0S4Xa07]28@1B:AP205Xi:@040>O6]@3_a[D0mlje
0?O>]@@0mmJm00<0kmK60?OF_@3_e/H00P3ge[d01@3ga[D0klJ]0?OF_@3ge[d0kmK60080mmkF00@0
kmK60?O6]@3_aZd0ikfU0P3W[I@01@3WYI@0gZfD0=j]S03NYH@0ijfD0080kkFL0P3_aZd01@3_cZd0
klJ]0?O6]@3ga[D0klJ]0080klJU0P3_]I`20>N]U0050>N]S03NYH@0gYak0<jDJ`36Q6/00P2eNeX0
102]Jd80U5Xa058Y600H20P2048Q600507=2:@1B:AP0W6<i08AB<@2LJdX00P1k@R401024DS40S5Y2
0:ecDP36S6<30=jUN`040=JLL`2eNeX0_HaS0:ecDP<0]G]J00<0cZfD0>O6[@3F]JD00P3Wc/H00`3g
koL0moOg0?Ogm`060?Ogm`80mnog4P00000X0?oooa40000000D0klJU0>nmW03__I`0kkfL0>o6Y@03
0>nmW080kkFD00<0kkFL0>NeU03W[H`00P3W[H`00`3N[H@0gZEk0=JLN`020=j]S0030>N]W03_]I`0
klJU00@0klJ]00@0kkFL0=j]S03WS7/0cV]J0P3NQ7<01@36HdX0W48Y0<ISBP3_aZd0ikFL0080ikfL
00@0ikFD0=j]S03FYH@0gYak0P3W]I@20=j]U0030=j]S03N[I@0ikFD0080ikFD0P3W_I`01`3W]I`0
gZfD0=JUS03FYH`0eZf<0<JLQ03FYH@00P2mU7/20=jUQ080ikFD00<0kkfL0?O>]@3gc[D00P3ge[d4
0>oFaP@0mmJm00<0kmK60?OF_@3ge[d00`3ge[d20?O>]@030>o>[@3gc[D0mlje0080klJU00<0kkFD
0=JLN`2mS6<00P2eQ6/0102UNf<0YHA[07=:<@2<HdX20:EkFP0507=B@P2<Je80W7=B0:F4J`2eS7<0
0P2mU7/01036YI@0iljm0>oNcP3_g/hB000001h0oooo000L0?oooa40000000D0mnog0?Ogm`3gmoL0
moOg0?O_i`020<JDJ`80U6=200<0JcTQ07=2:@1c@RT00P1kBRT01024BS40NdXY048Q601S:A02048Q
60040>o6[@3ga[D0kljm0?O6]@<0mmJm00<0kmK60?OF_@3ge[d0103ge[d20?O>]@030?O6]@3_e/H0
kmK60080kmK600<0mlje0>o6[@3W[I@00P3FYH`01@3NYH@0gZf<0=JUS03N[I@0ikFL0080klJ]0P3_
a[D00`3_c[D0mlje0>o6[@020>o6[@040>o6Y@3_aZd0klJU0>neW080ijfD00D0ijf<0=j]S03NYH@0
eYac0<J4J`020;EkFP040:ecDP2]Hd80LdXa024@2080>AP@00D0FSTY07]J@P24DST0S5Y209AS@P02
07]::@0408AB<@1cBS40W7=B0<J4FP80cYA[00D0gZf<0>NmY@2eLdX0]G]J09acDP020;EkFP040<JD
J`3W_I`0ilJ]0<JLQ080g/jm00<0moOg0?O_m`3gmoL0103gkoL30?Ogm`030?O_m`00000000000100
0000:03ooolA00000080klJU00<0kkfL0>o6Y@3_aZD00`3__I`0103W_I@0kkFD0>NmU03W[H`30=j]
Q080gZEk00P0gYac0=jUQ03NYH@0ijfD0>neW03_aZd0klJU0>o6[@80klJU00@0ikfU0=j]S03NYH@0
cV]J0P3NNf/01@36HdX0[DXa0<ISBP3W_JD0ikFL0080kkfL00@0ikfL0>N]U03N[H`0]G]J0P3NYH@2
0=j]S0030=JUS03N[I@0ikFL0080ikFL0`3W_JD0203N[I`0gZfD0=j]U03FYH`0eYak0;fDN`2eQ6/0
]Hac0P2mU7/01@3NYH@0eYac0>N]U03_aZD0mlje00<0kmK600<0mmJm0>oFaP3ga[D00P3ge[d00`3g
c[D0mmJm0?OF_@040?OF_@80mlje00@0mmJm0>o6[@3_aZd0klJ]0P3_aZD00`3W[H`0eYac0=JLN`02
0:ecDP030;fDN`2UNeX0YG]S00<0Q5Y200D0LdXa05Xa8@2<Je80W7=B0:EkH`020;F<L`040;fLS03F
_Jd0imK>0>O>aQ8000007P3oool001`0oooo3`0000020?Ogm`050?O_m`3gmoL0moOg0?Ogm`3_koL0
0P2eQ6/0102DHd80Q4XY06/i8@24DST308A:<@0407]::@0i6100DRTH058Q4080FSTY00<0klJ]0?O>
]@3ge[d02P3_e/H20?OF_@030?O6]@3_c[d0mlJe0080mmJm00@0mlJe0>o6]@3_]I`0ikFL0P3FYH`0
103N[H`0gZfD0=j]U03W]I`40>o6[@030>o6]@3ga[D0mlje0080klJe00@0mlJe0>o6[@3_aZD0klJ]
0`3_]I`01@3W[I@0ijf<0=JUQ03NYH@0cYA[0080aXAS00@0[G=B09a[BP2<BS40:A080P12<BT00`1B
:AP0Ld8Y07=:<@0208AB<@80W6<i0P24DS402@2UNeX0_HaS0<jDH`3>U6<0gZf<0>o>[@2eNeX0]G=:
09a[BP020:EkFP040;F4H`3>[I@0g/Je0=k>_@80mnog303gmoLA000002P0oooo4@0000030>o6Y@H0
kkfL0P3_]I@30>N]S0040=jUQ03NW7/0gYac0=jLL`80gZF400@0ijfD0>NeW03_]I`0klJU0`3_aZd0
103_aZD0gZf<0=jLN`3>JeX20<J4J`030>N<N`2<<B40aV=:00D0ikFL00<0ikFD0=j]S03FW7<00P3>
S6<20=jUQ0030=j]U03W]I`0ikfU00<0ikfU00<0klJ]0>NmY@3W_I`00P3N[I@01@3>[I@0ikfL0=JU
Q036Q6/0W7=B0080aXA[00D0eYak0=jLN`36Q6/0ijfD0?O>]@020?OF_@040>oFaP3ge[d0mlje0?O>
]@D0mmJm00<0mlJe0?O>]@3gc[D00P3gc[D00`3ge[d0mlje0>o6[@020>o6[@050>o6Y@3__I`0ijf<
0=jLN`3>Lf<00P2eQ6/0102eQ6<0]Hac08AJ@P2UNf<208aSBP050:EkFP1cBS40S6=:09AcFP2eQ6/0
0P3Na[D0102US7/0g/jm0=k>_@3Nc[dB000001h0oooo000L0?ooo`l000000P3gkoL00`3gmoL0mnog
0?O_m`020?O_m`80]HA[00D0U5Xa07]::@1kBRT0Q58i07=:<@0207]::@0408A:<@1B:AP0@R4H058Y
6080cZfD0P3_c[D00`3ge[d0kmK60>oFaP030>oFaP<0mmk>0P3_e/H30?OF_@030?O>]@3_a[D0mmJm
0080mmJm00<0klJ]0>neW03N[I@00P3N[I@01@3N[H`0ikFD0>NeW03W_JD0klJ]0080klje00@0klJe
0?O6]@3ga[D0mmJm0P3_c[d01@3ga[D0klJe0>o6[@3_aZd0kkFL00<0ikFL00@0gZfD0=jUQ03FW7/0
eYac0P36Q6<0102eJe80W6]:09AS@P128AP2024@200505Xa8@1B:AP0Q58i08aJ@P1kBRT00P2DFS40
102LHcT0Q58a09acDP36W8@20=JLL`050=j]Q03_cZd0[G=B0<J<H`2<FT800P2eQ6<0102]Le80ikfD
0>O>_@3Nc[d>0?Ogma400000:03ooolA000000030>o6Y@3__I`0kkfL00@0kkfL00<0ikfL0>nmW03_
]I@00P3W[H`20=j]Q0040=jUQ03NYG/0eYak0<jDJ`80eYak00D0gZf<0>N]U03_]I`0klJU0>NmY@02
0>o6[@040>NmW03N[H`0gZF40<i[FP<0cW=S00@0[D8a0=JLL`3W_JD0ikfL0P3W_JD0103_]I`0ikFL
0>NeU03N[H`20=JLN`030=jUQ03W[I@0ikFL0080klJ]0P3_a[D0103WaZd0klJ]0>O6[@3N[I`20>Nm
Y@050=JeY@3N[I`0W4Xa0<JLQ02eS7<00P2]Le820;fDN`030:eS@P2mS6<0klj]0080mlje0P3ge[d5
0?O>]@040?OF_@3ga[D0mlje0?OF_@<0mlje00<0mlJe0>o6[@3_aZd00`3_aZD0103_]I`0ijf<0=JL
N`3>U6/20;F4H`040:EkH`2LLe80]HAS08aSBP80U6=200D0Le9207]J@P1cBS40NeY20;FDN`020>O6
]@040=Jm[@3Na[D0ilk60=Jm]A8000007P3oool001`0oooo3`0000030?Ogm`80mnog00H0moOg0=k6
aP2LLe80W7=B08aJ@P1c@RT208AB<@0708A:<@1kBRT0NdXY058Y60128AP0>AP@0>neW0020>o>_@03
0?O6]@3ge[d0mmk>0080kmK60P3gg/h90>oFaP030?OF_@3gc[D0mmJm0080mmJm00<0mlJe0>o6[@3W
]I`00P3N[I@20>NeU0030>NeW03W_JD0klJe0080klJe00@0kmK60?OF_@3ga[D0kmK60P3ga[D01@3g
e[d0kljm0>o>_@3_a[D0klJ]0080ilJ]00D0kkFL0>NeU03N[H`0eZF40=JLN`020=JLL`040;EkFP2L
JdX0W6<i07=2:@80HbT@00D0JcTQ07=:<@1cBS40U6=208AB<@0209aS>@0408aJ@P2<BS40W7=B0=JU
Q080eYac00D0eZf40>NmY@2mS6<0]G=:08AB<@020:EkFP040;EkFP3N[H`0imK60>o_i`/0moOg00<0
mnog0?Ogm`3gmoL04@00000X0?oooa40000000<0klJU0>nmW03__I`00P3__I`20>neU0050>nmW03W
_I@0kkFD0>neU03N[H@00`3NYH@00`3NW7/0eYac0<jDJ`020<j<H`050=jUQ03N[H`0ijfD0>NmW03W
]I`00P3_aZD0103__I`0ikFD0=j]S03FW7/20<i[FP030<icH`2L@RT0eZF400@0ikFL0P3__I`40>Ne
W080kkFL0P3_aZd01P3_c[D0klJe0>o6]@3_c[D0kljm0>o6]@<0ilJe00D0ilJ]0>O6]@36FTX0[D8a
0;fDN`0209AcFP050;F4J`3FYH@0W7=B09AJ@P3W]I`00P3ga[D00`3_c[D0mmJm0?O>]@040?O>]@04
0>o6[@3gc[D0mlje0?O>]@<0klj]00<0mlje0>o6[@3_aZd00P3_aZd01@3_aZD0kkfL0>N]S03FW7<0
]G]J0080W7=B00@0_HaS0:EkH`2UNeX0S6=:0P24FT801@1kFT80YG]J07=:<@2UNeX0U6]B0080e[FU
00@0e[fe0=k6]@3>]JD0c/Jm4P00000N0?ooo`00703oool?000000<0moOg0P3gkoL01P3gmoL0g/K6
09acDP2LLe80S5Y207=2:@80Q58a00L0Q4Xa07]::@1kBRT0DRTH048Q600i6100kkFL0080kljm00<0
mlJe0?OF_@3gg/h00P3_e/H20?ONcPT0kmK600<0mmJm0?O>]@3ge[d00P3ge[d00`3ga[D0klJ]0>Ne
W0020=j]U080ikFD00<0ikFL0>NmY@3_a[D00P3_a[D0103_e/H0mmJm0?O6]@3_e/H20?O6]@050?OF
_@3_c[d0kljm0>o6]@3_aZd00P3WaZd01@3_]I`0ikFD0=j]S03FYH@0eYak0080eYac00@0]G]J09a[
BP2LHcT0Ld8Y0P1S:A001@1[>B40LdXa07=:<@2DHd80Q58a0080W6<i00@0S5Y208a:<@2LLe80eZF4
0P3FW7<01@3F[H@0ikfU0;f<H`2eLdX0Q58a0080YG]J00@0]G]J0=j]S03We/H0knoW2`3gmoL00`3g
koL0moOg0?Ogm`0A000002P0oooo4@0000000`3_aZD0kkfL0>nmW0020>nmW080kkFD00D0kkfL0>Nm
U03_]I@0kkFD0=j]Q0030=jUQ0030=jLN`3FW7<0cYA[0080cXaS00D0gZF40=j]S03W[I@0ikfL0>Ne
W0020>o6Y@040>nmW03W]I@0gZf<0=JLN`80cV]J00<0cW=S09a2:@3FYH@0103W]I`20>nmW0@0ikFL
0P3_]I`20>o6[@060>o>]@3_a[D0klJe0>o>]@3_c[d0klJe0`3Wa[D01@3WaZd0ilJe0<IJBP2]@S40
_IAk0080U7=J00D0]HA[0=JUQ02LLe80U5Y20>NeW0020?O6]@030>o>]@3ge[d0mlje00@0mlje00@0
klJ]0?O>]@3gc[D0mlje0`3_cZd00`3gc[D0klJ]0>o6[@020>o6[@050>o6Y@3__I`0ijf<0=JLL`2e
NeX00P2LLe80102mS6<0YG]S0:EkFP2<HdX208AJ@P0507]J@P2UNeX0LdXa0:EkFP2DJe800P3F]JD0
103F_KD0g/Je0<jeY@3>a[dB000001h0oooo000L0?ooo`l000001P3gmoL01P2LLe80U5Xa09AJ<@24
DS40FS4Q07]J@P80LdXa0P24BS40101B:AP0JcTQ05Xi:@3_aZd20>o6]@040>oFaP3ge[d0kmK60>oF
aP<0mmk>0P3_e/H00`3ge[d0mmk>0>oFaP040>oFaP030?OF_@3_c[d0mmJm00<0mmJm00H0mlJe0>Ne
W03N[I@0gZfD0>NeW03W_I`20>NmY@070>O6[@3_c[D0klje0?OF_@3_c[d0mmJm0>oFaP020?OF_@05
0?O6]@3_c[d0kljm0>o>_@3_a[D00P3_aZd01@3W_JD0ikFL0=j]U03N[H`0eYak0080eYac00@0aW]J
0;E[DP2DFT80LdXa101[>B400`24DST0Q58a09aS>@0209AS@P0408aJ@P2DLeX0]HA[0=JLN`<0eYac
00@0eZf40<J<H`2]JcT0Q4XY0P2UNeX00`2mU7/0eZf<0>ONeP0?0?Ogma400000:03ooolA00000003
0>o6Y@3__I`0klJU00@0kkfL00D0ikfL0>neU03_]I@0kkFD0>N]S0020=j]Q0040=jLL`3NW7/0gYac
0<jDJ`80aXAJ00D0eYak0=jUQ03W[H`0gZfD0>NmW0030>NeW0030>NeU03NYH@0gZf<0080eYak00D0
aUY:08A2:@3FYH`0ikFD0>NmW0030>o6Y@030>NmY@3__I`0klJU00@0klJ]00<0klJe0>o6[@3_a[D0
0P3_e/H0103ge[d0kljm0>o>_@3Wc[d20>o6]@050>O6]@3W[I`0aXA[0=k6aP2LJdX00P2US8@01@24
HdX0eZF<0;E[DP24DST0eZF40080klJ]00<0klje0?O6]@3gc[D00`3_cZd01@3_aZd0mlJe0?O>]@3g
c[D0mlJe0080mlje00@0klj]0>o6Y@3_aZd0klJU0`3_aZd0103_]I@0gZF40=JLL`2eS7<209a[BP80
YG]J00T0YG]S09A[DP24HdX0Q6=:08AJ@P24DST0Q6=:08AB>@2<FT800P36W8@0103F_Jd0g/Je0;fL
U02eW8`B000001h0oooo000L0?ooo`l00000103gmoL00`3gkoL0moOg0:ecDP0209aS>@0507=:<@1[
>B40S5Y208AB>@1kBRT00P1c@RT0101[>B40DRTH0:F4L`3ga[D20>o>_@<0kmK60P3gg/h20>oFaP04
0?OF_@3_e/H0mmJm0?OF_@80kmK60P3gg/h20>oFaP<0mmJm00@0kmK60?O6]@3ga[D0ikFL0`3N[I@0
103W_I`0ikfU0>o6[@3_aZd40>o>_@80kmK60`3ga[D0103ge[d0mlje0>o>]@3_a[D30>o6[@040>Nm
Y@3N[I@0gZf<0=JUQ080eYac00@0aXAS0;E[DP2DFT80S4Xa0`1J<B40101[>B40LdXa08A:<@2DHd82
09aS>@0309AS@P2DFS40eYac00@0eYac00@0eZF40=J]Q02]Jd80[F]20P2]Le800`2eQ6<0gZf40>o_
i`0?0?Ogma400000:03ooolA000000<0kkfL00D0ikfL0>nmW03__I`0kkfL0>NeU0020>NmU080ijf<
0P3NYH@0103NW7/0gYac0=JLL`36Q6/20<j<H`050<IkFP3NW7/0gZF40=j]S03W]I@00`3W]I`20>Ne
U0<0gZf<00D0eZF<09AJ@P3N[H`0ikFD0>o6Y@020>NeW0040>neW03_aZD0kkFL0>o6Y@@0klJ]0P3_
a[D00`3ga[D0mmJm0?OF_@030>o>_@080>o6]@3_c[d0kljm0>NmY@3N[I`0eZF<0>oWi`3>a[d20:F<
Q0050:EkH`3FYH@0]Hac09AJ@P2eS7<00P3_aZd30?O>]@<0klJ]00D0mlje0>o>[@3_aZd0klJ]0>o>
[@020?O6]@040>o6[@3_aZD0klJ]0>o6[@<0klJU00@0ikFL0=j]S02mU7/0]G]J0P2eQ6/00`2LJdX0
YG]S0:EkH`0308AJ@P0507]J@P24DST0Q58i08AB<@2<FT800P3N[I`0103Na[D0iljm0=Jm[@2US8@B
000001h0oooo000L0?ooo`l000001@3gmoL02@3gkoL0W7=B09acDP2LLe80Q58i07=:<@1c@RT0Q58i
08A:<@0205Xa8@0407=2:@24DST0klJe0?O>]@80kljm203_e/H00`3ge[d0kmK60>o>_@050>oFaP80
mmJm0P3_a[D20>oFaP060?OF_@3W_JD0ijfD0>N]U03N[I@0ikFL0P3W_JD00`3WaZd0klJe0>o6]@03
0>o>_@050>oFaP3_c[d0kljm0?OF_@3_c[d00P3_a[D0103_aZd0klJe0>o6]@3WaZd20>NmY@080=j]
U03FYH@0eYak0=JLN`3>U6/0]G]J09a[BP24DST207=2:@0506/a601[>B40JcTQ08AB>@2DFS400P2<
HdX01024DST0Q4XY0=J]S03FW7<20<JDJ`040=JLN`36W8@0gZf<09AJ<@<0[G=B00<0YHA[0=J]Q03g
knL03`3gmoLA000002P0oooo4@0000000`3_aZD0kkFD0>nmW0020>nmW080ikfD00@0kkFL0>neU03W
_I@0ijf<0`3N[H@0103NYG/0cYA[0=JLL`3>S6<30<IkFP040<jDJ`3NYG/0ijf<0>N]S080ikFD00@0
gZf<0>NeW03W]I@0ikFD0P3N[I@00`3W[I@0gXAc0=j]S0020>NeW080klJU00<0kkFL0>o6[@3_aZD0
0`3_aZd00`3ga[D0klj]0>o>]@040?O6]@040?OF_@3_e/H0kljm0>oFaP80ilJ]00D0ikfU0<JUW03N
a/H0S7=S06=JDP0205Xi:@050:F4L`2mU7/0ikfU0;E[DP2DLeX00`3_aZd00`3_a[D0klJ]0>o6[@05
0>o6[@040?O>]@3_aZd0klJ]0>o6[@L0klJU00@0ikFL0>N]U03>U6/0]G]J0P2LLe80102mU7/0aYA[
08aJ@P2<FT8207=B@P0508AB<@1[>B40Q58i09AcFP2LLe800P3FYH`0103We/H0c[FU0;fLS02mW9@B
000001h0oooo000L0?ooo`l000000`3gmoL0103gkoL0moOg0;f][@2DFS4208aSBP0508AB<@2<FT80
Q58a08a:<@1[>B400P1J>BT0101c@RT0ilJ]0?OF_@3_a[D20?OF_@@0kmK600H0mmk>0>oFaP3_e/H0
kmK60?OF_@3_c[d30>o6]@80kljm0P3ge[d00`3ga[D0mlje0?O>]@020>oFaP090?OF_@3_aZd0ijfD
0>N]U03N[H`0gZfD0=j]W03W_I`0gZfL0080ilJe00<0iljm0>o6]@3_e/H0103_c[d00`3_a[D0ilJe
0>o6]@040>o6[@80ikfU00P0gZfL0=j]S03FYH@0eZF40=j4L`36Q6<0W6]:09AJ<@80LdXa00D0DRTH
06/i8@1[>B40LdXa09a[BP0408aJ@P030<JLQ036U6/0eYac0080eYac00@0W6]:0>NmU024@R40W6]:
0P2mS6<00`36U6/0cZfD0?Ogm`0?0?Ogma400000:03ooolA000000030>nmW03W_I`0kkFD00D0kkfL
0P3_]I@01@3W[H`0gZf40=jUQ03NYH@0gYak0080cYA[00<0cXaS0<J4FP36Q5X00P36NdX00`3FW7<0
gZF40=j]U0020=j]U0030>N]S03W]I@0ikFL00P0ikFD0P3W]I`20>o6[@030>o6Y@3_aZd0klJ]00<0
klJ]0P3gc[D00`3ge[d0kmK60>oFaP030>oFaP080>o>_@3WaZd0ilJ]0=JeY@2mW8`0U7]c09AcFP2e
_Lh2058Y600509akJ`2mU7/0ilJ]0=jUQ02<FT800P3WaZd20>o6[@050>o6Y@3_aZd0klJ]0>o6[@3_
aZD01P3_aZd20>o6Y@090>o6[@3_aZD0ikfL0>NmW03W]I@0gZf<0=JUQ03>U6/0_HaS0080]HAS00@0
YG]J08aSBP2LJdX0Q58a0P24DST01@1cBS40Q58i08aJ@P2DJe80W7=B0080eZF<00@0ilk60:F<L`2e
W8`0W7]S4P00000N0?ooo`00703oool?000000<0moOg00@0mnog0?Ogm`2UNf/0]Hac0P2LJdX01@1c
BS40W6]:07=:<@2<BS40FS4Q0080LdXa00@0NdXY0>O6[@3ga[D0ilJ]0`3_e/H0103gg/h0kmK60>oF
aP3ge[d20>oFaP80kljm00<0kkFL0>O6[@3_aZd00P3_aZd0103_a[D0kljm0?OF_@3_c[D20?O>]@04
0?OF_@3_e/H0mmJm0>o6[@80ijFD00D0gZf<0=JUS03N[I@0gZfD0>NmY@020>O6]@040>o6]@3_c[d0
ilJ]0>O6[@80ikfU103WaZd00`3_aZd0klJe0>o6]@020>O6[@030=JeY@3W_I`0gZf<0080eZF400@0
eYac0<J4H`2]Le80U5Xa0P24BS401@1B:AP0DR4@06/i8@1cBS40S5Y20080W6<i0P2<FT802@36W8@0
cYA[0<jDJ`3>U6/0eYac08A:<@3N[H@0U5Y208aJ@P020;F4J`030=JUQ03WaZd0moOg00<0moOg00<0
mnog0?Ogm`3gmoL02@3gmoLA000002P0oooo3`0000040>nmW0030>NmU03_]I@0ikfD0080kkFD00<0
ikfD0>nmW03W]I@00P3W[H`20=jUQ0040=jLN`3>U6/0cYA[0<J4J`80aXAJ00D0aW]J0;EcBP3>U6/0
eYak0=jUQ0020=j]S0040=j]U03N[H`0gZfD0>NeU080ikFL0`3W]I@01`3W]I`0ikfL0>NeW03W]I`0
klJU0>neW03_aZD0103_aZd0103ga[D0klJ]0>o6]@3_c[d20?O6]@040?OF_@3ga[D0kljm0>o>_@80
ikfU00D0ijfL0;F4J`1cFTX0Nf]J024H600205Xi:@0508ASDP2mU7/0klJ]0>N]W02LLe800P3WaZd0
0`3_aZd0ilJ]0>O6[@030>neW0030>o6Y@3_]I`0kkFL0080klJU0`3_aZd00`3_]I`0kkfL0>neW002
0>nmW0050>NeU03W[I@0gZf<0<jDJ`2eQ6<00P2LLe80102eQ6/0W7=B0:EkFP1c@RT208AB>@0507=:
<@1c@RT0Q58a08aSBP2eQ6<00P3FYH`01@3F_Jd0aZFD0;fLU02LNf/0]Ib<014000007P3oool001`0
oooo3`0000030?Ogm`040?O_m`3gmoL0YG][0;F<L`80W6]:00D0LdXa09a[BP1cBS40S4Xa05Xa8@02
07=:<@0407]::@3WaZd0mlJe0>O6[@<0kmK600@0mmk>0>oFaP3_e/H0mmJm0P3_e/H20>o>_@030>ne
W03WaZd0klJ]0080klJ]00@0klJe0>o>_@3ge[d0klje0P3gc[D0103ge[d0kmK60?OF_@3_aZd20>NU
U0050=j]S03FYH`0gZfD0=j]U03W_JD00P3Wa[D0103_a[D0kljm0>O6[@3WaZd20>NmY@@0ilJ]00<0
klJ]0>o6]@3_a[D00P3WaZd00`3F]JD0ikfL0=j]S0020=JUQ0040=JLL`36Q6<0[G=B09AJ<@80Q4Xa
00D0DRTH058Q401[>B40LdXa08aJ@P0209aS>@80S5Y200T0aYb40<jDJ`3>U6/0cYA[0=JLL`24BS40
gZf409AJ@P2<FT800P2eQ6/00`3FYH@0ilJ]0?Ogm`030?Ogm`030?O_m`3gmoL0moOg00T0moOg4@00
000X0?ooo`l00000103__I`00`3W_I@0kkFD0>NmU0020>neU0030>NmU03__I`0ikFD0080ijf<0P3N
YH@0103NW7/0cYA[0<jDJ`36Q6/20<J4FP050<IkFP2eLdX0cYA[0=JLN`3NYH@00P3N[H`0103N[I@0
gZf<0=j]U03W]I@20>NeW0<0ikFD00L0ikFL0>NmW03W]I`0ikFL0>o6Y@3_]I`0klJU00@0klJ]00@0
mlJe0>o6[@3_a[D0kljm0P3ga[D0103ge[d0mlJe0>o>_@3_c[d20>NmY@050>N]W02eQ6/0LeY:07][
FP0Q61P00P1J>BT01@24He80_IAk0>o6[@3W[I`0W7=B0080ilJ]00<0klJ]0>O6[@3WaZd00`3_]I`0
0`3_aZD0kkFL0>neW0020>o6Y@<0klJ]00<0kkFL0>nmW03_]I`00P3__I`01@3W]I@0ijfD0=j]S03>
U6/0]HAS0080W7=B00@0]HA[09acDP2UNeX0Ld8Y0P24DST01@1cBS40Ld8Y08AB<@2<HdX0]HAS0080
eZF<00D0e[f]0<JUU02mW9@0W7][0;FLS00A000001h0oooo000L0?ooo`l000000`3gkoL20?Ogm`09
08a::@2eU7/0S5Y208aJ@P2DJe80Q5Y208aJ@P1cBS40DRTH0080W6<i00@0ijf<0>o6[@3W[I@0klJe
0P3ge[d40>oFaP030>o>_@3Wc[d0iljm0080klJe00T0klJ]0=j]W03N[I@0gZfD0>NmY@3WaZd0klJe
0>o>_@3WaZd00P3_a[D20>oFaP090?OF_@3_]I`0gZfD0=j]U03NW7/0eZf<0=JUS03>[I@0e[FU0080
ilJ]00@0ilJe0>NmY@3W_JD0e[FU0P3W[I`20=j]S0030=JUS03N[I`0gZfL00@0ikfU0P3W_I`01`3N
[I@0eZF40=JUQ03>U6/0aXA[0;E[DP2LJdX00P24DST0101c@RT0>AP@06<Y401[>B4308aJ@P0409a[
BP24DST0_IAk0=JLN`80]G]J00D0_HaS08A::@3W_I@0W6]:08a:<@020<JDJ`030=J]Q03We/H0moOg
00P0moOg0P3gkoL50?Ogma400000:03ooolA000000050>nmW03_aZD0kkfL0>neU03W_I@00P3W_I`0
103_]I@0ikFD0>NmU03_]I@40=jUQ0030=JLL`3>U6/0cYA[0080aXAJ00D0aW]J0;EkFP2eLdX0cYA[
0=JLN`020=jUQ0<0gZf<0`3N[I@20>NeU0030>N]S03W]I@0ikFL0080ijfD00@0ikFL0>neW03_]I`0
klJU0P3_]I`30>o6[@80mlJe0P3ge[d20?O6]@090?OF_@3_c[d0ilJ]0>O6[@3N[H`0]Hac0:EkJ`2D
S8@0Lg=[0080FSTY00D0HdY20<jDJ`3WaZd0ilJ]0:eS@P020<JLQ080ikfU00D0klJ]0>NmY@3W]I`0
ikFL0>NmY@040>o6Y@@0ikfU0P3W]I`20>NeU0050>NeW03N[I@0eZF40<jDJ`2eQ6<00P2]Le800`2U
Nf<0W7=B07=2:@0308AB>@80JcTQ00<0W6]:09AS@P2eQ6<00P3WaZd01036W8@0YHac08acFP2DLeXB
000001h0oooo000L0?ooo`l00000103gmoL00`3oool0W6]:0:EkH`0208AB>@0508aJ@P24DST0U5Y2
058Q4024DS400P24BS40103ga[D0cYA[0=jUQ03_c[D20?OF_@<0kmK600P0kljm0>O6]@3N[I`0gZfL
0;fDN`2eS7<0eZF<0<jUU080_IAk0P3N[I`20>o>_@<0klJe0`3ge[d0203_aZd0gZfD0=j]U03FW7/0
aYb40=JLN`3W_I`0gZfL0P3Wa[D0103W[I`0gZfL0<JUW02mW8`20;F4J`050;F<L`36W8@0aYb40<JL
Q03>YI@00P3W_I`01@3W_JD0gZfL0=j]W03N[I`0gZf<0080eZF400@0aYb40<J4J`2eNeX0U5Y20P24
DST01@1cBS40JcTQ05Xa8@1J<B40Q58i0080Q58a00@0S6=:08aJ@P2eQ6/0_HaS0`2eNeX0102DFS40
ikfD09AJ<@2<BS420<JLQ0030=JLL`3We/h0oooo00l0moOg4@00000X0?oooa4000000P3_aZD00`3_
_I`0ikfD0>nmW0030>neU080ikFD00H0gZf40>N]S03N[H`0gZf<0=jUN`3FW7<20<jDJ`80aXAJ00D0
]G]J0<IkBP2eLdX0]F]B0<J4J`020=JLN`<0gZF40`3N[H`00`3W]I@0gZf<0>N]S0040>N]U080ikFL
00D0klJU0>neW03_aZD0klJU0>neW0020>o6Y@030>o6[@3_a[D0kljm0080kljm00<0mmJm0>o>_@3_
a[D00P3WaZd01@3N[H`0aYb40:EkH`1[HeX0HeYB0080LdXa00D0FT8i0=JLN`3W_JD0klJ]0<i[FP02
0:EkH`040>O6[@3_aZd0ikfU0>NmW080ikFL00D0ikfL0>NeW03W]I`0kkfL0>NeW0020>NmY@80ikfL
0P3W]I`20>NeU0050=j]U03FYH`0eZF40<J4J`2eQ6/00P2UNf<0102UNeX0]HA[07=:<@24DST207=:
<@0505Xi:@1J<B40Q58a09a[BP2mS6<00P3WaZd0102eU7/0W7]S0:EkFP2US7<B000001h0oooo000L
0?ooo`l00000103gmoL00`2mW9@0YG]J09acDP0207=:<@0508AB>@1cBS40U5Y205Xa8@2DFS400P3_
]I@0103_]I`0ihak0=JUS03_c[D20>o>_@80kmK600<0klJe0>N]W02eQ6<00P2mS6<0103N[I`0_Jf]
07=[H`1cLf/20:F4L`030<JLQ03NQ7<0gXAc0080klJe0P3WaZd30?OF_@080>o6Y@3W]I`0ikFL0=JL
N`3FYH@0_IAk0=JUQ02LBS420<IJBP040<J4J`3FYH`0g/K609AkL`80LeY:00D0YG][0:EkH`2UNeX0
YG]S0;F4J`020=JUS080gZfD0P3N[I`30=JUS0040<jDJ`36Q6/0]F]B09a[BP80S5Y200@0LdXa08AB
>@1B:AP0DRTH0`24DST0102<FT80W6]:0;F4H`2mU7/20;EcBP050;EkFP2DDRT0ikfL09aS>@2LLe80
0`3F[H@00`3_inL0moOg0?Ogm`0>0?Ogma400000:03ooolA00000080klJU00<0ikfL0>neU03_]I@0
0P3W]I@01@3W_I@0ikFD0>NeU03W[H`0gZF40080gZf400@0gZEk0=jLN`3FW7<0aXA[0P3>S6<0102e
NeX0aW]:0;EcBP2]Jd830<jDJ`040=JLL`3NW7/0eZF40=jUQ0H0gZf<00<0ijfD0>NeU03W]I@00P3W
[I@02@3_]I@0ikFL0>o6Y@3_aZD0kkFL0>o6Y@3_aZd0klJU0>o6[@030>o>_@030?O>]@3_a[D0ilJe
0080ilJ]00<0eZF<0<JLQ02UNeX00P2mW9@205Y2>@0507=:<@3FYH@0ikfU0>o6[@2eS7<00P2]Le80
103WaZd0ikFL0>NmW03W_JD20>NeW0030>NmY@3W]I`0ikFL0080ikFL0P3W_I`20>NeU080ikFL0P3N
[I`01@3N[I@0eZF<0<JLQ02eS7<0]HA[0080YG]J00@0YHA[0:EkFP2LHcT0W6<i0`1c@RT0101J>BT0
Q58a0:EkFP2mS6<20=j]U0040;FDN`2LNf/0S6=:08ASDQ8000007P3oool001`0oooo3`0000040?Og
m`030;F4J`2mW8`0W7=B0080S6=:00D0FS4Q08AB>@2DFT80Jc4H058Y60020?O6]@040>N]S03WYI@0
gZfD0>o>_@80mmJm00D0kljm0>O6[@3W[I`0]HA[0<J4J`020=Jm]@040>OFcP1kLg<0Lf]S06=JDP80
Q7]c00D0YG][0<JLQ02mU7/0ijfL0=j]U0020>o6Y@80mmJm00T0klje0>o6[@3W]I`0ikFL0=jUQ02m
U7/0]HA[0<J4J`36W8@00P2]@S40103Na/H0knOW08acH`2DLeX207][FP0509B<Q01[HeX0_IbD09ac
DP2<Je800P2eQ6/20=JUQ0030=j]U03N[H`0eZF<0080eYak00@0eYac0;F4J`2]Le80W6]:0P24DS40
1@1cBS40FS4Q02T@20128AP0Q58i0080S5Y200@0Ld8Y09a[BP2eQ6/0]HAS0P2LJdX01@2UNeX0[F=2
0=j]S024BRT0_IAk00<0eZf<3`3gmoL00`3gkoL0moOg0000000@000002P0oooo4@0000001@3_aZD0
kkfL0>o6Y@3__I`0ikfL0080ikFD00D0ijf<0>NmU03N[H@0gZf<0=jUQ0020=jUN`<0eYac00P0cYA[
0<j<H`3>S6<0]G]J0<IkFP2eLdX0[F]20:eS@P80aXA[00@0cYA[0=JLN`3FW7/0eYak0`3FYH@00`3N
[H`0ijf<0=j]S0030=j]S0040>N]S03N[H`0ijfD0>N]U080kkFD0P3_]I`00`3_aZD0klJ]0>o6[@02
0>o6]@040>o>_@3_c[D0klJe0>o6]@80ilJ]00D0gZfL0<JLQ02UNf<0W7=B048a:@0207=JBP0509ac
DP3FYH@0ikFL0>neW036Q6/00P2UNf<20>NeW0050>NeU03W]I`0ikFL0>NeW03W]I@00`3N[I@01`3N
[I`0ikFD0>NeU03W[I@0gZfD0>NeU03N[I@00`3N[H`00`3FW7/0eYac0;fDN`030:EkH`030:F<L`2D
Je80S5Y200<0Q58i00D0Ld8Y05Xa8@2DFS40]HAS0=JUQ0020<jeY@040:F4L`2LNf/0S6]B0:F<Na80
00007P3oool001`0oooo3`0000030?Ogm`040?ooo`3gkoL0YHA[08AB<@80NdXY00D0FS4Q08AB>@24
DST0Q58i09AJ@P020?O6]@040=jUQ03WS7/0gZfD0>O6]@80klje00D0klJ]0=j]W02mU7/0U7=J05Xi
:@020;FDS0040<Je]@2DNf/0]KFm024H6080Q7=[00D0FTY209AcFP2eQ6/0_IAk0>NeW0020>o>[@80
mmJm00T0mlje0>o6[@3W_I`0ikfL0>NeU02mU7/0]Hac09acDP2eS7<00P2mU7/0102LJdX0c/Jm06=J
DP2e_Lh2024H600507=cJ`1SFU80_IbD048a:@1cDT800P2UNf<01@2eS7<0_IAk0=JUQ03FYH`0eZF4
0080_IAk00@0aYA[0<J4H`2]Le80U5Y20P24DST01@24BS40@R4H03TH40128AP0DRTH0080Q58i00<0
LdXa0:ecDP2LLe800`2UNeX01@2eNeX0[F=20=J]Q024BRT0_HaS0080eYak00<0g/Je0?Ogm`3gmoL0
3`3gmoLA000002P0oooo4@0000001@3_aZD0kkfL0>nmW03__I`0kkFD0080ijf<00D0ikfD0=j]Q03N
[H@0gZf40=jUQ0020=jLN`040=jLL`3FW7<0cYA[0<jDJ`<0aXAJ00@0]F]B0<IkBP2eLdX0[F=20P2L
HcT00`3>S6<0eYac0<jDJ`050=JLN`L0gZF400D0gZf<0>N]S03W[H`0ijf<0>NeU0040>neW080klJ]
0P3_a[D40>o6[@050=j]W03>YI@0]HA[08a[DP1cDT800P1kDT801@2mS6<0gZf<0>NeW03W_JD0]HAS
0080YG]S0`3N[I@00`3N[H`0ijfD0>N]U0020=j]U0H0gZf<00<0ikFD0=j]S03N[I@00P3>[I@00`3F
YH@0_IAk0;fDN`020;F<L`80S6=:00<0Q6=:09A[DP24FT800`1kFT801@1c@RT0FS4Q09a[BP36W8@0
eZF40080YHac00@0U7=S08aSBP2LNf/0_Ib<4P00000N0?ooo`00703oool?000000<0moOg00@0]IAk
0=K6aP2US7<0U7=J0P1kDT801@1cBS40Q58i08AB>@2DFT80cW=S0080kkFL00@0ihak0=JLN`3N[H`0
klJe0P3_c[D0103W]I`0cZFD0<J4J`1cBS4308ASDP0405Y2>@12:B40FSTY08AB>@80S6]B00D0Q6=B
0:EkH`2mU7/0ijfD0>nmW0030?O>]@030?OF_@3gc[D0klJ]0080kkfL00D0ikFL0=jUQ02mU7/0aXA[
0:ecDP0209AcFP80YHb400<0FSTY058Y601J>BT00P1J>BT0101cBS40FT8i07=JBP1kDT820:EkH`03
0;F4H`2eQ6/0cYA[0080eYak0P2mU7/00`2eQ6/0]G]J09AJ@P0308aJ@P0407=:<@1[>B40@R4H05Xi
:@<0JcTQ00@0LdXa09a[BP2]Le80W6]:0P2LHcT01@2eNeX0[G=B0=J]Q02DHd80_HaS0080eYac00<0
knON0?Ogm`3gmoL03`3gmoLA000002P0oooo4@0000001@3_]I@0kkfL0>neU03W_I`0kkFL0080ikFD
00D0gZf40>neU03N[H@0ijf<0=jUQ0020=JLN`040=JLL`3>U6/0cYA[0<jDJ`80aXAJ00<0aW]J0;Ek
FP2eLdX00P2]Jd820:eS@P0309aS>@3>S6<0cYA[00<0cYA[0`3FW7/20=jUQ080gYak103NYH@20=j]
S0050>N]S03W[I@0ijfD0>neW03W]I`00P3WaZd20>o6[@080>o6]@3_aZd0klJe0>o6]@3W_JD0ikfL
0=JUS02eQ6/30:EkH`050;F<L`3W[H`0ikFL0=j]U02UNf<00P2mU7/0103N[H`0eZF40=j]S03N[I@5
0=j]S0030=JUS03N[H`0gZf<0080gZf<00<0eZF40=JLN`3FYH`0102mU7/20;F4J`070;fDN`2DJe80
U6]B09A[DP24FT80S5Y209AS@P0208AB>@0508AB<@1cBS40[G=B0;F<L`36YI@00P2<Je80102DLeX0
S6]B0:F4L`36W8@B000001h0oooo000L0?ooo`l000000`3gmoL0102eU7/0e/K60:F<L`2DLeX207]B
@P0507=:<@24DST0Q58i09AJ@P3>Lf<00P3_]I`0103WS7/0eYak0=j]S03_a[D20>o>]@040>NeW03>
YI@0aXA[07=:<@<0Q6=B00@0FT8i048Y8@1J>BT0Q58i0P2<Je801@24He80YG]S0;fDN`3W[I@0kkfL
00<0mlje00<0mmJm0?O>]@3_aZd00P3__I`01@3W]I`0gZF40;fDN`36Q6/0[G=B0080U7=J0P2US8@0
0`1J>BT0DRTH05Xi:@0205Xi:@0407=:<@1J@ST0LeY:07]B@P80YG]S00<0]HAS0;F4J`3>U6/00P3F
W7/20;fDN`030;F4J`2eNeX0U5Y200<0S5Y200@0LdXa06/i8@128AP0FSTY0`1[>B40101cBS40W6]:
0:ecDP2LJdX209aS>@050;EkFP2]Le80eZf409AS@P2mS6<00P3FW7<00`3_imh0moOg0?Ogm`0?0?Og
ma400000:03ooolA000000050>neU03__I`0kkFD0>NmW03_]I`00P3W]I@01@3N[H@0kkFD0=j]Q03W
[H`0gZF40080eYak00@0eYac0<jDJ`3>U6/0cYA[0P36Q5X00`36NeX0]G]J0;EcBP020:e[@P80[F=2
00<0W6<i0<j<H`3>U6/00`3>U6/30=JLN`80gZF40P3NW7/40=jUQ080gZf<00D0ijf<0>N]U03W[I@0
kkFL0>NeW0020>O6[@80klJ]00P0klJe0>o6[@3_a[D0klJe0>NmY@3W_I`0eZF<0;F4J`<0YG]S00D0
]Hac0>N]S03W]I`0gZfD0:EkH`020;fDN`040=j]S03FYH@0gZf<0=j]U0D0gZf<00<0eZF<0=j]S03N
[H`00P3N[H`00`3FYH@0eYak0=JUS0040;fDN`80]HA[00L0_IAk09A[DP2DJe80U6]B08AJ@P2<FT80
U6=20080Q58i00D0Q58a07=:<@2]Le80]Hac0<JUU00208a[DP0409AcFP2<Je80YHAc0<JLQ1800000
7P3oool001`0oooo3`0000030?Ogm`040:ecDP2mW9@0]Ib<08aJ@P80LdXa00D0S6=:08AB>@1cBS40
S4Xa0<J4H`020>NUU080eYak00T0gZf<0>o6]@3Wa[D0ilJe0>O6[@3W_JD0gZfD0;fDN`2eJe800P2<
HdX307]B@P0608AB>@2DLeX0U7=J0<J4J`3FYH@0ikFL0P3_aZd20?O>]@80mmJm00T0mlje0>o6[@3_
aZd0klJ]0>o6Y@3W]I@0gZF40=JLN`2mU7/00P2eQ6/01024HdX0YG]S0:F4L`2LNf/208ASDP0506=:
@P1J@ST0LdXa09acDP2mS6<00P2eS7<01@36Q6/0cYA[0=JLN`3FW7/0_IAk0080cYA[00@0_HaS0;E[
DP2DFT80S5Y20`24DST00`1c@RT0DRTH05Xi:@0305Xa8@0407=2:@2LLe80]G]J09acDP80W6<i00D0
]G]J0;f<H`3F[H@0W6]:0;f<H`020=JUQ0030>o_i`3gmoL0moOg00l0moOg4@00000X0?oooa400000
00@0kkFD0>NmW03W]I@0ikfD103W]I@00`3N[H@0ijf<0=jUN`030=jUN`040=JLL`3>U6/0cYA[0<J4
H`80aXAJ00D0]G]J0<IkBP2eNeX0]F]B09a[BP020:eS@P0409a:<@2eJe80aXAS0<J4J`80gXAc00<0
cYA[0=JLL`3FW7/00P3FW7/20=jUQ0<0eYak0`3NYH@01@3N[H`0ijf<0>N]S03W[I@0ikFL0080kkFL
00@0ikfU0>o6[@3WaZd0klJ]0P3WaZd20>NmY@030=j]U03FYH@0]Hac0080]HAS00D0aXA[0=j]U03N
[I@0gZF40:EkFP020<JLQ0040=JUS03FYH@0eZF<0=jUQ0@0eZF<0P3N[H`01P3FYH@0eZF<0=JUS03N
YH@0eZF40=JUS0<0eYak00D0_IAk0;F<L`2eQ6<0]G]J0:F4J`0209AcFP040:EkFP1kFT80W6<i08aJ
@P80Q58a00D0W6]:08aJ@P2UNf<0_IAk0:EkH`0209akH`0409A[DP1cFTX0_Ib<0;FLS18000007P3o
ool001`0oooo4@0000001@3gmoL0knON0:F<N`2DJe80LdXa0080Ld8Y0P1cBS400`1[>B40W6]:0<J4
H`020<jDJ`040<JLQ02mU7/0eZF<0>O6]@<0klje00@0mmJm0>o>_@3_aZd0klJe0P3W_JD0103W]I`0
ijfL0>NeW03W_JD20>NeW0050=JLN`3NYH@0ijfD0>o6Y@3ge[d00P3gc[D20>oFaP090?OF_@3gc[D0
klj]0>o>[@3_aZd0ikFD0=JLL`3NW7/0_IAk0080eZF400<0eZF<0=JUQ02mU7/00`2mU7/01@3>U6/0
eYak0=JUQ03FYH@0gZf<0080ijf<00D0gZfD0=JUS03FYH@0eYak0<jDJ`020<J4J`040;f<H`2eNeX0
U5Y208aSBP80Q58i0P1[>B400`1B:AP0FSTY07=:<@0207=2:@0406/i8@2LJdX0_HaS09a[BP80W6<i
00D0aXAJ0;fDN`3N[I@0W7=B0;fDN`020>oNcP030?ooo`3gmoL0moOg00h0moOg4P00000X0?oooa40
000000@0kkfL0>neU03_]I@0kkFD0`3W]I@01@3W_I@0ijf<0=j]Q03NYH@0gZEk0080eYak00@0eYac
0<jDJ`36Q6<0aXAJ0P2eNeX01@36NdX0]G]J0;EcBP2]Jd80[F=20080U5Y200@0W6<i09AJ<@2<FT80
aXAJ0P36Q6<01@3>U6/0eYak0=JLL`3FW7<0gXAc00<0eYac1@3FW7/01@3NW7/0gZF40=j]S03W[H`0
gZfD0080ikFD00@0ikFL0>NmY@3W_JD0ikfU0P3WaZd01@3W_JD0gZfL0=j]U03FYH@0_IAk0080]HA[
00D0cYA[0=JUS03FYH@0_IAk0;F4J`020;fDN`80eYak203FYH@01`3FYH`0eYak0=JLN`3NYH@0eZF4
0;fDN`3FYH@00P3>U6/20;F4J`030;F4H`2LJdX0YHac0080[G=B00@0W7]S07=:<@2DHd80Q58i0P24
DS401@24FT80YHA[0;f<H`3F]JD0W7][0080U6]B00@0Le920:EkH`36W8@0YHak4P00000N0?ooo`00
703ooolA00000080oooo00<0Ld8Y08aJ@P1J<B400`1[>B40102DHd80FS4Q09a:<@2eJe820=j4L`04
0<jDJ`2eS7<0eZF40>o>]@80ikfU00@0mlje0?OF_@3ge[d0kmK60`3ge[d0103_e/H0ijFD0<J4J`2U
Nf<209acDP030;E[DP3W]I`0klJU00@0mmJm00@0mmk>0>oFaP3ge[d0kmK60P3gc[D01@3ge[d0kkfL
0>N]U036Q6/0[F=20080W7=B00@0]F]B0;F<L`3W_JD0ilJ]0P3_aZd00`3WaZd0ikfU0>NmY@040>Ne
W0050=j]U03FYH@0aYA[0;F4H`3>U6/00P2mS6<0102eNeX0[G=B09a[BP2<FT8208AB<@0508AB>@1S
:A00DRTH058Y601J>BT00P1B8A00101cBS40S5Y20:ecDP2LJdX209AS@P050<J<H`36U6/0ikfL0:Ek
FP36W8@00P3_inLA0?Ogma800000:03ooolA000000030>nmW03W_I@0ikFD00D0ikFD0P3N[H`01P3N
YG/0eYac0=JLN`3FW7/0eYac0<j<H`80aXAS0P2eNeX20;EcBP80[F=200L0U6=209aS>@2LHcT0S4Xa
08AB<@24@RT0NdXY0080]G]J00<0aXAJ0<J4H`3>U6/0103>U6/0103NQ7<0eYac0=JLL`3FW7<20<jD
J`050=j4L`3NW7/0gZF40=JUQ03NYH@00P3N[H`20=j]U080ikfU0P3F]JD01@3W_I`0gZfL0=j]W03N
[I@0eZF40080cYA[00D0eYak0=JUQ036U6/0YG]J0;fDN`020<jDJ`040=JUQ03FW7/0eYak0;fDN`80
eYak0P2mU7/00`36W8@0eZF40<jDJ`020=JLN`040<jDJ`2eS7<0_IAk0;F<L`80]HA[0P2]Le800`2U
NeX0S6=:0:EkFP0209AcFP0408a[DP1cDT80W6]:08A:<@<0S6=:00@0_IAk0<JLQ02mW8`0W7][0P24
FT801024DST0YHac0;F<L`36W8@B000001h0oooo000L0?oooa40000000D0knOW0?ooo`1[>B40NdXY
05Xa8@0206/i8@0507=:<@24DST0LdXa09aS>@2eHd800P2eNeX0102mS6<0aXA[0<JLQ03_aZd20=k6
]@030>NmW03_a[D0mmJm0080kmK60P3ga[D0102eQ6/0YG]S09AcFP2eJe820=JUQ0050>o6Y@3gc[D0
mlje0?OF_@3gg/h00P3ge[d00`3gg/h0kmK60?OF_@030?OF_@80mlje00<0klJU0>N]U02mS6<00P2D
FT801024DST0U5Y20;E[DP3NYH@20>N]W0050>O6[@3_aZd0klJ]0>neW03W_JD00P3N[I@01@3NYH@0
_IAk0:EkFP3>U6/0]Hac0080]HA[00@0[G=B09a[BP2LJdX0S5Y20`1[>B40101B:AP0FS4Q058Y601B
8A0207=B@P0408AJ@P2DJe80YG]J09acDP80U5Xa0P2mS6<00`3F[H`0_IAk0<JLQ00C0?Ogma800000
:03ooolA000000050>nmW03W]I@0ikFD0>neU03W]I@00`3W[H`00`3N[H@0gZf<0=JLN`030=JLL`80
cXaS0P36Q5X20;E[DP80[F]200<0W6]:09aS>@2LBS400P24BRT0102<BRT0Q4Xa07]::@1[>B4207=:
<@030:ecDP2eNeX0aXAS00@0cYA[00<0aXA[0<jDJ`36Q6/00`3>U6/01@3NQ7<0cYA[0=JLL`3NYH@0
eYak0080eZF40P3N[H`00`3N[I@0gZfL0>NmW0020>NmW080gZfL00<0gZf<0=JUS03FW7/00`3FW7/0
0`2eQ6<0cYA[0;fDN`020=JLL`80_IAk00<0eYac0<jDJ`3>U6/00P3>U6/0103FW7<0eYak0;fDN`3>
U6/40;F<L`090;f<H`2UNf<0YG]S0:EkH`2LLe80YG]J09acDP2DLeX0YG]S0080W7=B00@0U7=J08aS
BP2DHd80S5Y20P2UNeX01@2UQ6/0]HA[0=k6]@2eW8`0S5Y20080NeY200@0U7=J0:F4J`2UQ6/0imkN
4P00000N0?ooo`00703ooolA000000040;f][@3oool0Q58a07=2:@<0LdXa00@0FS4Q08AB>@1kBRT0
U5Xa0`2DFT80102UNf<0]HA[0<JLQ03Wa[D20>o>_@050;fDN`36W8@0eZF40=JLN`3NQ7<00P2eJe80
0`2]Le80eYak0?O>]@030?OF_@L0mmk>103_e/H20?OF_@050>oFaP3gc[D0mlje0?O>]@3_cZd00P3W
]I`0103FYH@0]Hac09AcFP2<FT8209acDP050:eS@P3>JeX0]Hac0<J4J`2eQ6<00P2UNf<01@2UNeX0
]HA[0;fDN`2mU7/0gXAc0080_HaS00@0[G=B09a[BP2LJdX0Q58i0P2LJdX01@128AP0Ld8Y07=2:@1[
>B40DRTH0080@RTQ00@0Q6=:09a[BP2]Le80W6]:0P2DHd801@2mS6<0eYac0;F4J`2]Jd80g/jm01<0
moOg4P00000X0?oooa80000000<0kkfL0>NeU03W[H`0103W[H`00`3NYH@0gYak0=JLL`030<jDJ`03
0<j<H`36Q6<0]G]J00<0]G=:00D0[F]209AS@P24DST0Q48Q08A:<@0207]::@0406/i8@1c@RT0JcTQ
06/a6080DRTH00<0JcTQ08aJ@P2LLe800P2eNeX30<J4H`030<IkFP36Q6<0aXAS00<0aXAS0P36Q6/0
0`3>U6/0eYac0=JLN`020=JLN`80eZF40`3N[H`01@3N[I@0gZf<0=JUS03FYH`0eZF40080eYak00D0
_IAk0<jDJ`3>U6/0]Hac0=j4L`020<jDJ`040;F<L`36U6/0cYA[0<J4J`80]Hac00@0aXA[0;F<L`2e
Q6/0]HA[0`2mS6<0102eQ6/0YG]S0:ecDP2LJdX209acDP0509AS@P2LJdX0S5Y209A[DP2<HdX00P2D
LeX0102UNf<0Q58i09AS@P2LLe820:EkFP050<JLQ02mU7/0]IAk0:F<L`1c@RT00P2<HdX00`2LNf<0
YHA[0<JUW00C000001h0oooo000L0?oooa40000000D0aZFD09acDP1cBS40LdXa08ASBP0208AB>@<0
LdXa00P0Q58i09AJ<@2<HdX0S6=:09acDP2UNeX0eZF40>O6]@<0klje00@0klJ]0=JUQ02mW8`0gXAc
0P3N[I`00`3_e/H0mmk>0?ONcP080?ONcP80mmkF0P3_e/H40?ONcP80mmJm00<0kmK60?OF_@3gc[D0
0P3ga[D30>o6[@<0ilJ]00<0aYb40:EkH`2]Le800P2UNf<20;fDN`050<JLQ02mU7/0cYA[0=JLL`3>
U6/00P2mS6<0102]Le80W7=B0:ecDP24DST206/i8@0307=:<@1[>B40FS4Q0080>AP@0P128AP0102<
HdX0U7=J08aJ@P2UNeX20:eS@P050<JDJ`36W8@0W6]:0;f<H`3_inL04`3gmoLB000002P0oooo4P00
0000103__I`0ikFD0=j]Q03W[H`20=j]Q0050=jUQ03NW7/0eYac0<J4J`3>S5X00`36Q5X00`2mS6<0
aXAJ0<j<FP020<J4FP050<IkBP2eLdX0Q48Q07]28@1c@RT00P1S:A0206/i8@09058Y601B8A00DRTH
058Y601[>B40BQP805Xi:@24DS40U5Y20080W6]:00@0]G=:0;E[DP2eNeX0]F]B0P36NeX30;EkFP80
aXAS103FW7<00`3FW7/0eZF40=JUQ0030=JUQ0030=JUS03FW7/0_IAk0080_IAk00@0cYA[0<J4J`2m
S6<0]HA[0`2mS6<0102eNeX0_HaS0;EkFP2mS6<30;F4H`030;F4J`2UNf<0]HA[00<0YG]S00@0[G=B
0:EkFP2DFT80U6=20P2LJdX01@24FT80Le9208AJ@P1cFTX0S6=:0080W7=B00@0U6=208AB>@24DST0
]HAS0P2UNeX01@2mU7/0c[FU0;fLS02US7<0Q58i0080]HAS00<0_IAk0:EkH`3gmoL04`00000N0?oo
o`00703ooolA000000050<JUU02LLe80LdXa07=:<@24HdX00P24DST307=:<@0808AB>@2DFS40S6=:
08aSBP2LLe80YG]J0=JUQ03Wa[D30>o>]@040>o6[@3FYH@0_Ib<0=j4L`80gZfL00<0kmK60?ONcP3g
g/h0203gg/h20?ONeP80kmK6103gg/h20?OF_@030>oFaP3ge[d0mlje0080mlJe0`3_aZd30>O6[@03
0<JLQ02UNf<0[G=B0080YG]S0P2mU7/01@36W8@0_IAk0<jDJ`3FW7<0cYA[0080_HaS00@0[G=B09ac
DP2]Le80Q58i0P1[>B400`1cBS40JcTQ05Xa8@0203TH4080@R4H00@0S6=:09AcFP2<FT80YG]J0P2]
Hd801@36U6/0aYb409a[BP2mS6<0knOW01<0moOg4P00000X0?oooa80000000@0kkfL0>NeU03N[H@0
ijf<0P3N[H@01@3NYH@0gYak0=JLL`36Q6/0cXaJ00<0aXAJ00<0_HaS0<J4FP3>S5X00P36Q5X01@36
NdX0]G=:08A28@1k@R40Ld8Y0080HbT@0P1[>B402@1B:AP0DR4@058Y601B:AP0JcTQ04XH201J>BT0
Q58a09AJ@P0209a[BP040;EcBP2eJe80]G]J0;E[DP80aW]J0`2eNeX20<J4H`@0eYac00<0eYak0=JU
Q03FYH@00`3FYH@00`3FYH`0eYak0;fDN`020;fDN`040<jDJ`36Q6/0_HaS0;F4J`<0_HaS00@0]G]J
0;f<H`2eNeX0_HaS0`2eQ6<00`2eQ6/0YG]S0;F4J`030:EkH`040:ecDP2UNeX0U5Y209AS@P80W6]:
00D0Q5Y207=B@P24FT80LeY:08aSBP0209acDP0409AS@P24DST0Q58i0;F4H`80YG]J00D0_IAk0<je
Y@2mW8`0YHac08AB>@020;F4H`030;fDN`2UNf<0moOg01<000007P3oool001`0oooo4P000000102L
JdX0NeY207=:<@2LNf/208a[DP0307]J@P24DST0LdXa0080S5Y20P2<HdX20:ecDP040=JLN`3_aZd0
klJe0>o6]@80klje0P3ge[d40>oFaPP0mmk>00D0mmkF0?ONcP3gg/h0mmk>0>oFaP030?ONcPH0kmK6
00D0mmJm0>o>]@3_c[D0klje0?O>]@040>o6[@050>NmY@3WaZd0ilJ]0>NeW03N[I@00P3N[H`01@3F
YH`0eYak0=JUQ02mU7/0]Hac0080]G]J00@0[G=B0:EkFP2]Le80W6]:0P1cBS400`1[>B40DR4@03TH
400203TH4080@R4H00@0]Hac08aSBP2<FT80eYac0P2LJdX0102eNeX0eZf409a[BP36W8@C0?Ogma<0
0000:03ooolB000000040>nmW03W_I@0ijf<0>N]S0<0gZF400@0cYA[0<j<H`3>S6<0aXAS0`3>U6/0
0`2eLdX0]F]20:e[@P0209aS>@0508a::@2DFS40]G=:0<J4FP36NdX00P2LJdX01024DST0LdXa06/i
8@1[<AP2058Q40<0>AP@00P0@S4Y058Q401c@RT0Ld8Y07=:<@2<FT80U5Y20:eS@P80W7=B0P2]Jd82
0:ecDP070;E[DP2eNeX0]G]J0<IkFP36Q6<0cYA[0=j4L`020=JLL`050<jDJ`36W8@0cYA[0=JLL`36
U6/00P2eQ6/20;f<H`030;EkFP2]Le80[G=B00<0[G=B00<0]F]B0:ecDP2eNeX00`2eQ6<209acDP08
0:EkH`2UNeX0W7=B09acDP2LJdX0S6=:08AB>@2<FT8308AJ@P0407=B@P1kFT80U6]B09AcFP80Q58i
00@0W6]:07]J@P2LHcT0]HAS0P2UNeX01@3W_JD0]IAk09akJ`1kFT80YG]S0080]IAk00<0YG]S0?oo
o`3gmoL04`00000N0?ooo`00703ooolB0000000408A::@1cDT80Q5Y20:F<L`80U6]B00<0Q58i08AJ
@P1kFT800P24FT8208aJ@P040:EkFP2LLe80eYak0>O6[@<0klje00@0kljm0?OF_@3ge[d0kmK60`3g
g/h00`3_e/H0mmJm0?ONcP030?ONcP030?OF_@3gg/h0mmk>00<0mmk>00<0mmJm0>oFaP3gg/h00`3_
e/H00`3gg/h0kmK60?OF_@040?OF_@040?O6]@3gc[D0klJe0>o6[@80ilJ]00D0ikfU0>o6[@3W]I`0
ikFL0=j]U0030=JUQ080eYak00D0_IAk0<JDJ`2mS6<0_HaS0;E[DP020:ecDP0408aJ@P2LJdX0W6]:
07=2:@80DRTH00P0@R4H05Xa8@1B8A00DR4@0;fDN`2UNeX0S5Y20;fDN`80[G=B00D0W6]:0=J]S02L
JdX0e[f]0?ooo`0B0?Ogma<00000:03ooolB000000040>neU03W]I@0kkFD0>N]S080gZEk00D0cYA[
0=JLL`3>S6<0cYAS0=JLN`020<j<H`040<J4FP2]Jd80W6<i08a::@80NdXY00D0S4Xa09aS>@2DFS40
Q48Q0:ecDP020=JLN`030;f<H`2DHd80S6=:00<0Q58i00D0Jc4H06/i8@0i6100:A08048Q600205Xi
:@04058Q401J>BT0FSTY07=2:@80S5Y200<0U6=209AJ<@2]Hd80102LJdX20;E[DP040;EkFP36Q6<0
aXAS0<J4H`<0aXA[00L0]HA[0<J4H`2eNeX0]G]J0;E[DP2eNeX0[G=B0080W6]:0P2LLe80102UNeX0
[G=B0;EkFP2]Le820:EkH`0509a[BP2DJe80W7=B08aSBP2LLe800P2<HdX0102<FT80Q58i08AJ@P24
FT8207=:<@0508AB>@1cBS40Le9209A[DP2UNf<00P24FT800`2DHd80NeY209a[BP030<JLQ0050<je
Y@24HdX0LdXa09acH`2UQ6/00P2UNf<00`2eU7/0moOg0?O_m`0C000001h0oooo000L0?oooa800000
00@0Q58i08a[DP2<HdX0W7=B0P2<HdX0102<Je80S6=:08AJ@P24DST308AB<@0409a[BP2LLe80aXA[
0>NmW080klJe0P3_c[D00`3_c[d0mmJm0?OF_@020>oFaP80mmk>00<0mmJm0?ONcP3gg/h03P3gg/h3
0>oFaPH0mlje00T0klJ]0>o6Y@3WaZd0ilJ]0>o6[@3W_JD0ikfL0>NeU03N[I@00P3N[H`01@3FYH`0
eZF40=JLN`3FW7<0cYA[0080]G]J00@0[G=B0;EkFP2LLe80W6]:0P1cBS400`1J<B40JcTQ05Xa8@02
03TH4080@R4H00@0aYA[0:EkH`2LJdX0eYac0P2eLdX0102<HdX0_IAk09a[BP3gkoLC0?Ogma<00000
:03ooolC000000030>NeU03W[H`0gZf40080gZEk0P3FW7<00`3N[H@0eYac0<J<H`020;EkFP040;Ec
BP2]JcT0U5Xa09a[BP<0W6<i00@0]G=:0<J4FP3>S6<0]G]J0P2<BRT0102eNeX0cYA[0<jDJ`2]Le82
058Y600508aJ@P1cBS40FSTY08AJ@P1cBS400P0i6100101B:AP0JcTQ02T@200i610302T@2004058Y
601cBS40S4Xa09AS@P80W6<i0P2DFT8209a[BP80[G=B00<0]F]B0;EkFP2eJe800P2]Le8409AJ@P<0
W6]:102]Le800`2LLe80W6]:09a[BP0209a[BP0408AJ@P2LJdX0S5Y208aJ@P80Q58i00@0LdXa07=2
:@1c@RT0Q5Y20P1cDT801@24DST0LdXa08a[DP1cBS40Q5Y20080S6]B00@0W6]:09AS@P3>[I@0_IAk
0P3>]JD01@2mW8`0U7][09AcFP2US7<0W7]S0080YG][0P3gmoLD000001h0oooo000L0?oooa<00000
0`24DST208ASBP0508aSBP24DST0Q5Y208AB>@24FT800P24DST0102UNeX0]G]J0<JDJ`3W]I`20>Nm
Y@030>o>[@3_c[d0mlje0080mmJm0`3_e/H60?ONcP80mmJm1P3gg/h60>oFaP030?O6]@3gc[D0mlje
0080mlje00@0klj]0>o6[@3_aZd0klJ]0P3_]I`01@3W_JD0ikfL0>NmY@3W]I`0gZf<0080gZfD00D0
gZF40=JUQ02mU7/0cYA[0<J4J`020;f<H`040;EkFP2]Le80W6]:08AB>@80LdXa00<0FSTY07=2:@12
8AP00P0i610205Xa8@0409acDP3FW7<0]HAS0=JLN`80]G]J00<0W7=B09AS@P3>[I@04`3gmoLD0000
02P0oooo4`0000020>N]S0<0gZEk00D0gZf<0>NmU03N[I@0cYA[0;EkFP020;E[DP040:e[@P2LHcT0
[F]209a[BP80[F]200D0S5Y208A28@1k>AP0W6<i0;EcBP020<jDJ`0409a[BP2mS6<0[G=B0=JLN`80
eZF400D0]HAS08AJ@P24FT80LdXa08AB<@0207=B@P0407=:<@1J@ST0@RTQ048Y8@80>AP@00D0@R4H
01P8200Q40P0:A08048Q600207=2:@0307=:<@2<BS40Q58i00<0U5Xa00D0W6]:09AJ@P2LJdX0W6]:
09AJ@P0308aJ@P0308aSBP2<FT80S5Y200<0Q58i00@0W6]:08aJ@P2LJdX0Q58i0`2<FT800`1cBS40
NeY206/i8@0405Xi:@0307=:<@1J>BT0FS4Q0080U6]B00D0FSTY05Y2>@1kFT80S6=:06/i8@0209a[
BP0409AS@P2eLdX0_IAk0>NmW080W7]S00D0YHac0;F4H`2UQ6/0YHA[0;fDN`020?ooo`030?Ogm`3o
ool0000001<000007P3oool001`0oooo4`0000000`2<Je80Q58i08aSBP0208a[DP0509A[DP2<HdX0
Q5Y208AJ@P24DST00P2<HdX0102LLe80_HaS0;fDN`3N[H`20>NmY@030>o>]@3_c[d0mmJm00@0mmJm
0P3gg/h20?OF_@<0mmk>00@0mmJm0?ONcP3gg/h0kmK6103gg/h40>oFaP@0mmJm0`3gc[D0103_cZd0
klJ]0>o6[@3_aZd20>neW0@0ikFL00P0ijfD0=j]S03N[H`0eZF<0=JUQ03FW7/0cYA[0;F<L`<0]HAS
00<0YG]S09a[BP2<FT800P1[>B401@1cBS40DR4@048Q60128AP0>AP@0080@RTQ00@0U7=J0;fDN`2L
Le80aYA[0P2mS6<00`2UQ6/0U6=20>O>aP0C0?Ogma@00000:03ooolC000000030>N]S03_]I@0gZf4
0080gZf40P3W_I`00`3>S6<0aXAJ0;E[DP020;EcBP80[F=20P2LHcT208a::@0508A28@1k>AP0Jc4H
06/i8@1[<AP00P2DHd801036W8@0YG]J09AJ<@2eQ6<20=j]S0050<JDJ`2mS6<0W7=B08AJ@P2UQ6/0
0P24DST0102<HdX0Q5Y207=:<@1J<B42048Y8@0503TH40128AP0>AP@048a:@0Q40P00P1S:A00101[
>B40FS4Q07=2:@1cBS4208A:<@80Q58i00<0S5Y208AB<@24DST00P2<FT8208AB>@0308AB<@1[>B40
W6]:0080JcTQ00@0LdXa09a[BP1cBS40LdXa0P1[>B400`1cBS40Q58i06/i8@0405Xa8@0405Xi:@1J
<B40FSTY05Xa8@80@R4H00D0LdXa07=2:@1cBS40W6]:08AB>@0309acDP030<JDJ`3F[H`0e[FU0080
W7]S00D0U6]B0:F4J`2eU7/0YG][0?ooo`030?Ogm`030?O_m`0000000000018000007P3oool001`0
oooo4`0000000`2<Je80Q58i08aSBP0208a[DP0509A[DP2<HdX0Q5Y208AJ@P24DST00P2<HdX0102L
Le80_HaS0;fDN`3N[H`20>NmY@030>o>]@3_c[d0mmJm00@0mmJm0P3gg/h20?OF_@<0mmk>00@0mmJm
0?ONcP3gg/h0kmK6103gg/h40>oFaP@0mmJm0`3gc[D0103_cZd0klJ]0>o6[@3_aZd20>neW0@0ikFL
00P0ijfD0=j]S03N[H`0eZF<0=JUQ03FW7/0cYA[0;F<L`<0]HAS00<0YG]S09a[BP2<FT800P1[>B40
1@1cBS40DR4@048Q60128AP0>AP@0080@RTQ00@0U7=J0;fDN`2LLe80aYA[0P2mS6<00`2UQ6/0U6=2
0>O>aP0C0?Ogma@00000:03ooolC000000030>N]S03_]I@0gZf40080gZf40P3W_I`00`3>S6<0aXAJ
0;E[DP020;EcBP80[F=20P2LHcT208a::@0508A28@1k>AP0Jc4H06/i8@1[<AP00P2DHd801036W8@0
YG]J09AJ<@2eQ6<20=j]S0050<JDJ`2mS6<0W7=B08AJ@P2UQ6/00P24DST0102<HdX0Q5Y207=:<@1J
<B42048Y8@0503TH40128AP0>AP@048a:@0Q40P00P1S:A00101[>B40FS4Q07=2:@1cBS4208A:<@80
Q58i00<0S5Y208AB<@24DST00P2<FT8208AB>@0308AB<@1[>B40W6]:0080JcTQ00@0LdXa09a[BP1c
BS40LdXa0P1[>B400`1cBS40Q58i06/i8@0405Xa8@0405Xi:@1J<B40FSTY05Xa8@80@R4H00D0LdXa
07=2:@1cBS40W6]:08AB>@0309acDP030<JDJ`3F[H`0e[FU0080W7]S00D0U6]B0:F4J`2eU7/0YG][
0?ooo`030?Ogm`030?O_m`0000000000018000007P3oool001`0oooo4`0000000`1cDT80S5Y209A[
DP0209A[DP0508AJ@P2<HdX0Q58i07]J@P2DJe800P2<HdX0102LLe80]HA[0<JDJ`3FYH`20>NmY@04
0>o6[@3gc[D0mlje0?O>]@@0mmJm0P3gg/h00`3_e/H0mmJm0?OF_@020?ONcP030>oFaP3ge[d0mmk>
0080mmJm0P3_e/H00`3ge[d0kmK60?OF_@030?OF_@030?O>]@3ge[d0mlje0080mlje00<0klJ]0?O>
]@3_aZd00`3_aZD01@3W_JD0ikfL0>NmY@3W]I@0gZfD0080gZf<00D0eZF<0=JUQ02mU7/0cYA[0<J4
J`030;F4H`80W6]:00H0S5Y207=:<@1cBS40JcTQ058Q400i610202T@2080Ne9200@0S6=:0:EkFP2]
Le80aYb40P36U6/00`3F[H`0aYA[0?Ogm`0C0?Ogma@00000:03ooolD00000080ijf<0P3W_I`01@3N
[H`0cXaS0<J4H`36Q6<0aW]:0080[F]200@0[F=20:e[@P2]Jd80U5Xa0P1k@R4206/a6003058Q401c
BS40DR4@0080[F]200@0S48Q0=JLL`3FYH@0aXA[0P2LHcT00`2eNeX0eZF40=JLN`0209acDP80U6=2
00@0U6]B08AB>@24DS40LdXa0P1J@ST01@1cBS40Ld8Y05Xi:@1B:AP0FS4Q00<0JcTQ00<0FS4Q06/a
601B:AP00P1B:AP01@1c@RT0LdXa07=:<@1cBS40Q4Xa0080LdXa00D0Q58i06/i8@24DST0JcTQ048Q
600207=:<@0406/i8@1c@RT0FS4Q05Xi:@80LdXa00<0JcTQ05Xa8@1J<B400P128AP2048Y8@04058Y
601J<B40@RTQ058Y6080>AP@00D0FSTY05Xa8@2<Je80W6]:0;EkFP020:EkFP030;F4H`3F[H@0e[f]
00<0YHA[00@0aYb409a[BP2eU7/0oooo0`3gmoL00`3gkoL000000000000C000001h0oooo000L0?oo
oa@0000000T0YG]J08aJ@P2<HdX0S6=:08ASBP2<FT80Q5Y209aS>@1c@RT00P2<HdX0102UNf<0_HaS
0;F<L`3FYH@20>NmW0030>o6[@3_c[D0mlje00@0mmJm0P3gg/h00`3_e/H0mmk>0?ONcP020?ONcP04
0?OF_@3gg/h0mmJm0>oFaP80mmk>00@0mmJm0>oFaP3_e/H0mmJm0`3_e/H40?OF_@80klJ]00@0mlJe
0>o>[@3_aZd0klJ]0P3_]I`00`3_aZD0ikFL0>NeW0020=j]U080gZf<00D0eZF<0=JUQ02mU7/0eYac
0;F<L`020;F4J`0409acDP2DJe80Q5Y207=:<@80Q58i00D0FS4Q03TH400Y40P0@RTQ02T@200208AS
BP0309A[DP2LJdX0U6=200<0aYA[00<0aYb40>ONeP3gmoL04P3gmoLE000002P0oooo500000002@3W
_I@0gZf40=j]Q03N[H@0cXaS0<jDJ`36Q6<0aXAJ0;EcBP020:e[@P0409AS@P2]Jd80[F]208A28@80
NcTH00D0JcTQ07=:<@1S:A00DR4@07]28@0206/a60040;EkFP36NdX0aW]:0=J]Q080eZf<00D0_HaS
09AJ<@36U6/0_HaS0<JLQ00209aS>@80W7=B00T0W6]:08AB>@1cDT80Le9208AB>@1B:AP0NeY207=2
:@1B:AP00P1cBS4406/i8@80DR4@00D0>AP@06/i8@24DST0FS4Q048Q600206/i8@0507=2:@1[>B40
HbT@058Y601c@RT00P1[>B40101B8A00DRTH06/i8@1c@RT3058Q4080>AP@00<0@R4H048Y8@128AP0
0`128AP02@1B:AP0>AP@03TQ600i8AP0LdXa0:F4J`2eQ6/0W7=B0;F4H`020:EkFP040=J]Q03WaZd0
S6=:0:EkFP80aZFD00<0U6]B0<JUW03gmoL00P3gmoL20?ooo`030?Ogm`000000000001<000007P3o
ool001`0oooo5000000207]J@P<0Q58i00<0Q58a08AJ@P24DST00`2<HdX0102UNeX0]Hac0<JLQ03F
YH`20>NmW0050>o6[@3_c[D0mmJm0?OF_@3_e/H00P3ge[d20?ONcP090?OF_@3gg/h0mmJm0?OF_@3g
g/h0mmJm0>oFaP3ge[d0mmk>0080mmJm0P3_e/H50?OF_@040>oFaP3ge[d0mmJm0?O6]@<0mlje0`3_
aZd20>neW0040>o6Y@3W]I`0ikFL0=j]U0@0gZf<00@0eZF40<JLQ03FW7/0]HA[0P2UNf<209acDP05
09a[BP1kFT80JcTQ06/i8@1J<B400P0i61000`12:B40>AP@09A[DP0209A[DP0309acDP2LHcT0aYA[
0080aYb400<0eZF<0?Ogm`3gmoL04P3gmoLE000002P0oooo500000002@3W]I@0ikfL0=JLN`3FW7/0
cYA[0=JLL`36S6<0aXAJ0;EkFP0209AJ<@040:e[@P2LHcT0Nd8Q07]28@80NdXY00D0[F<a0;E[>@2]
JcT0Q48Q09aS>@020:eS<@0409AJ<@2eNeX0cYAS0<jDH`80]G]J00<0eZf40=JUQ02LJdX00P2LHcT2
0:ecDP040;F4H`2DHd80Q58i08AJ@P80S5Y200D0U6=209aS>@24DST0LdXa08AB>@0207=:<@0308AB
>@1cBS40JcTQ00<0JcTQ00D0HbT@05Xa8@1B:AP0:A0803TH4002048Q60<0DRTH00L0FS4Q07=2:@1J
<B40FS4Q03TH401B:AP0FS4Q00<0@R4H00D0>AP@02T@200i6100:A08034H6003058Y600303TH400Q
61P0:A080080NeY200D0Ld8Y09A[DP2DLeX0W6]:0;EkFP020<JDJ`040<jeY@2mW8`0_Ib<0;fLS080
_IAk00@0knOW0?Ogm`3gmoL0oooo103gmoLE000001h0oooo000L0?oooaD0000000P0Q58i07=:<@1c
BS40Q58a07=B@P1cBS40NeY208aSBP80W6]:00@0]HAS0;F<L`3FW7/0eZf<0P3W_I`01@3_aZd0mlje
0?O6]@3ge[d0kmK600D0mmJm00<0kmK60?ONcP3gg/h00`3gg/h20>oFaP80mmk>2@3ge[d00`3ga[D0
mlje0?O>]@020?O>]@030>o6[@3gc[D0klJ]00<0klJU00@0kkfL0>NeW03N[I@0gZf<0P3FYH`0103N
[H`0eZF40=JUQ02mU7/30;F4J`040:EkH`2<HdX0S5Y206/i8@80FS4Q0P128AP00`0Y40P0>B4H03TH
400209akH`0409A[DP2LHcT0U6=20<JLQ080c[FU00<0g/k60?Ogm`3gmoL04@3gmoLF000002P0oooo
5@0000000`3NYG/0eYac0=JLL`020=JLL`030<J4H`2eNeX0U6=200<0W6]:00<0W6<i07]28@1S:A00
0P2DDRT00`24@R40S48Q0;E[@P020<IkBP80S4Xa00@0[F=208A28@2eNeX0eYac0P3NYG/01@36Q5X0
]G]J0=JLL`36Q5X0U5Xa0080W6<i00@0W6]:0;EcBP2eLdX0W6]:0P24DST01@1c@RT0Q58a08aJ@P24
DS40S5Y20080U6=200<0Q58a08A:<@24DST00`1cBS400`1[>B40FS4Q058Y6002048Q60@0FSTY0P1B
:AP01@1[>B40>AP@03TH400i6100@R4H0080>AP@0P128AP01@0Y40P0@RTQ048Y8@0i8AP0@R4H0080
DRTH00@0>AP@024@200Q40P0]HA[0P24DST00`2UNf<0W7=B0:EkH`020;f<H`80e[FU00@0cZfD0=J]
S02UQ6/0YHA[0P3_inL00`3oool0moOg0?Ogm`020?ooo`80moOg5P00000N0?ooo`00703ooolE0000
00<0Q58i00D0Q58a08AB>@24DST0Le9208AB>@0209a[BP040:EkH`2eS7<0aYb40=j]W080ikfU00@0
klJ]0?O>]@3gc[D0mmJm0`3_e/H00`3gg/h0kmK60?ONcP050?ONcP030>oFaP3gg/h0mmJm0080kmK6
00@0mmk>0>oFaP3ge[d0kmK61@3ge[d01P3gc[D0mmJm0?O>]@3gc[D0mlJe0>o>[@80klJ]0`3_aZD2
0>NeW0060=j]W03N[H`0gZf<0=j]S03FYH@0eZF<0P3>U6/01`2mS6<0YG]S0:EkH`2UNeX0W7=B08aJ
@P1J>BT00P1J<B400`128AP0@RTQ034H6002048Q6080YG]S00@0]HA[08aJ@P2]Le80aYA[0P3W_I`2
0?Ogm`030?O_m`3gmoL0moOg00l0moOg5P00000X0?oooaD0000000P0gZf<0=JLN`3FW7/0cYA[0<j<
H`2eNeX0W6<i0;EcBP80W6]:00@0U5Xa09aS>@2<BRT0[F<a0P2]FS4209aS>@0309AB:@2<@R40aXAJ
0080_HaS00@0]F]20:e[>@2LHcT0aYA[0P3F[H@01@3N[H@0eYak0;EkFP2]Jd80aXaS0080]G]J00@0
S5Y208AB<@2LHcT0W6]:0P2LLe8209a[BP0309AS@P24DS40NdXY0080Q58a00@0W6<i09AS@P2DFS40
W6]:0`2<FT8308AB>@08058Y601[>B40JcTQ05Xa8@1cBS40FSTY058Q401B:AP303TH400305Xa8@0i
6100>AP@0080>AP@0P0Y40P203TH4007048Q600i6100>AP@02T@201J>BT0YG]J09akH`020:EkFP05
09acDP2LJdX0_HaS0;F4H`3>[I@00P3F]JD0103F[H`0]HAS0=k>cP3gmoL20?O_m`050?ooo`3gmoL0
moOg0?Ogm`3oool00P3gmoLF000001h0oooo000L0?oooaH000000P1cBS4207=B@P0308AB>@1kFT80
Le920080U6]B00@0]HAS0;fDN`3FYH@0gZfD0P3_aZD0103_aZd0klJe0>o>]@3gc[D60?OF_@050?ON
cP3ge[d0mmJm0?ONcP3_e/H00P3ge[d00`3_e/H0mmJm0?OF_@020>oFaP@0mmJm00<0kmK60?OF_@3g
e[d00P3gc[D20>o>[@030?O>]@3ga[D0klJ]00<0klJ]0P3W_JD00`3W_I`0ikFD0=j]S0020=j]S005
0=JUS03FW7/0eYak0;F<L`2mS6<00P2UNf<0102LLe80S6=:08AB>@1J>BT205Xa8@05048Y8@128AP0
DRTH058Y600i61000P2LJdX0102eQ6<0W6]:0<J4FP3FYH@20=k>cQ80moOg6000000X0?oooaH00000
0P3NW7<01@3FW7<0]G]J0:ecDP2LJdX0W7=B0080U58Y00<0U5Xa0:eS<@2eHc400`36Nd801@36NdX0
]F]20;E[@P2eJd80aW]:0080[F<a00@0aW]:0<J4FP2]Jd80aW]:0P2mS6<01@3_cZd0ikfL0>NmW036
Q5X0_HaS0080YG]J00<0U6=209aS>@2LHcT01024DS40101k@R40NdXY09aS>@2DFS4209aS>@0409AS
@P2LHcT0S6=:08aJ@P80W6<i00D0S5Y208AB<@24DST0S5Y208AB>@0206/i8@0505Xa8@1c@RT0DR4@
07=B@P12:B400`128AP00`1B8A00@R4H05Xa8@02048Y8@0507]B@P24HdX0U6]B09akH`2UNf<00P2L
JdX00`2DJe80]HA[0:EkH`0309a[BP050;F4H`3FW7/0eZF40=j]U03F]JD00P36W8@0103Wc/H0moOg
0?ooo`3gmoL30?O_m`80moOg00<0mnog0?Ogm`0000005`00000N0?ooo`00703ooolF00000080LdXa
0P1cDT800`24DST0NeY207=B@P0209A[DP040;F4H`2mU7/0eZF40=j]U080klJU00@0klJ]0>o6]@3_
c[D0mlje1P3ge[d01@3gg/h0mmJm0?OF_@3gg/h0kmK60080mmJm00<0kmK60?OF_@3ge[d00P3_e/H4
0?OF_@030>oFaP3ge[d0mmJm0080mlje0P3_cZd00`3gc[D0mlJe0>o6[@030>o6[@80ikfU00<0ikfL
0>NeU03N[H`00P3N[H`01@3FYH`0eYak0=JLN`2eS7<0_HaS0080YG]S00@0W7=B08aSBP24DST0FSTY
0P1J<B401@12:B40@R4H058Y601B:AP0>AP@0080W6]:00@0]HAS09a[BP36Q5X0eZF40P3Nc/hB0?Og
maP00000:03ooolF00000080gYac00D0eYac0;EkFP2]Le80W6]:09acDP0209AB:@0309AJ<@2]Hc40
]F<a00<0aW]200D0aW]:0;E[@P2eJd80]F]20<IkBP020:eS<@040<IkBP36Q5X0[F]20<IkBP80_HaS
00D0klj]0>NmW03W_I`0aXAJ0;f<H`020:EkFP0309AS@P2LHcT0W6<i00@0Q58a00@0Nd8Q07]::@2L
HcT0U5Xa0P2LHcT0102DHd80W6<i08aSBP2<FT8209aS>@0508aJ@P24DS40Q58i08aJ@P24DST00P1[
>B401@1J<B40Ld8Y058Q401cDT80@RTQ00<0@R4H00<0DR4@048Q601J<B400P12:B401@1kDT80Q6=:
09A[DP2LNf<0YG]S0080W6]:00<0U6]B0;F4J`2UNf<00`2LJdX01@2eQ6<0eYak0=JUQ03N[I@0e[FU
0080aYb400@0ilk60?Ogm`3oool0moOg0`3gkoL20?Ogm`030?O_m`3gmoL0000001L000007P3oool0
01`0oooo5P00000207=B@P0508AJ@P1kFT80Le9207]J@P24FT800P2DJe800`2LLe80aYA[0=J]S003
0>NmY@030>o6[@3gc[D0mlje00@0mmJm0P3_e/H20?ONcP80kmK60P3ge[d50>oFaP80mmJm00<0kmK6
0?OF_@3ge[d00`3ge[d30?O>]@<0klj]00<0klJ]0>o6Y@3_aZD00P3_aZd0103W_JD0ikfL0>NeU03W
[I@30=j]S080gZF400<0cYA[0;F<L`2eQ6/00P2]Le800`2LJdX0S5Y207=:<@0305Xi:@05058Y6012
8AP0DRTH03TH400Y40P00P2DJe80102LLe80W6]:0;f<H`3N[H`20>o_ia80moOg6000000X0?oooaH0
00000P3NW7<01@3>U6/0]F]B08aJ@P2LJdX0[F/i00<0W6<i00<0]F/i0<Ik@P2eHc400`36Nd801036
NdX0cXaJ0<IkBP36NdX20<Ik@P040:e[>@36Nd80cXaJ0;EcBP80aXAJ00D0_HaS0>o>[@3W_I`0ikfL
0=j]U0020<jDJ`040;fDN`24DST0NdXY09a[BP<0U5Xa0`24DS401P2LHcT0S5Y208aJ@P2<FT80U6=2
08AB>@<0S5Y200@0W6]:08aSBP2<FT80Ld8Y0`1cBS401@1c@RT0JcTQ07=:<@24FT80Q6=:0080S6=:
00@0]Hac0;fDN`36U6/0W7=B0P2DLeX01@2<HdX0U6]B09A[DP2DJe80]HA[0080]HAS0P2LLe8209AS
@P80[G=B00D0_HaS0<JDJ`3W_I`0ikfL0=Jm[@0;0?Ogm`030?ooo`3gmoL0000001L000007P3oool0
01`0oooo6000000309A[DP80NeY20P2DJe80102UQ6/0]Hac0=JLN`3W]I`20>o6Y@80klJ]00<0mlje
0>o>]@3gc[D01@3_e/H30?OF_@040>oFaP3gg/h0mmJm0>oFaPD0mmJm00<0mlje0?OF_@3gc[D0103g
c[D0103ge[d0mlJe0?O>]@3gc[D40>o6Y@80kkFL00D0ikfU0>NmW03W]I@0gZfD0>NeU0040=JUQ080
]Hac00L0YG]S0:EkFP2UNeX0S6=:08AB>@1c@RT0LdXa00<0FS4Q00@0@R4H03TH400Q40P0FSTY0P2e
Q6/0102LLe80]G=:0<jDJ`3>[I@20?Ogm`030?O_m`3gmoL0moOg00h0moOg6@00000X0?oooaP00000
00D0aW]:09aS>@2]Jd80[F/i0:e[@P020;E[@P040;E[>@2eJd80aW]20<Ik@P<0]G=:00@0]F/i0:e[
>@2eJcT0aXAJ1@36NdX01P36Q5X0cYAS0<jDH`2eLdX0cYA[0>o>]@80ikfL0P3W_I@01036S6<0eZf<
0=JUQ02<FT82058Y600305Xa8@2<FT80LdXa0080Q58a0P2<BS400`2DLeX0U5Xa08A::@0308aJ@P05
08AB>@2<FT80W6]:09a[BP2]Le800P2LJdX01@2LLe80W6]:08aJ@P2DJe80W6]:0080U7=J00@0S6=:
0:EkFP2UNf<0eYac0P2mU7/01@2UNeX0W6]:09acDP2LHcT0S5Y200<0W6]:00<0]G=:0;EkFP2mS6<0
0P36U6/0103F[H`0ikfL0=Jm[@3gknL;0?Ogm`030?ooo`3gkoL0000001P000007P3oool001`0oooo
600000001@2DLeX0U6]B08AJ@P2<HdX0Q6=:0080S6=:00@0[G=B0;fDN`36W8@0gZfD0P3_aZD20>o6
[@80mlje0`3ge[d00`3gc[D0kmK60>oFaP070?OF_@030>oFaP3ge[d0mmJm00@0mmJm103gc[D00`3g
e[d0mlje0>o6[@040>o6[@040>o6Y@3_aZd0kkfL0>nmW0<0ikFL00D0ikFD0=j]S03FW7/0eYak0=JU
S0020;fDN`070;f<H`2]Le80U5Y209AJ@P24DST0Q5Y207=2:@0305Xi:@05048Y8@1B:AP08APH024@
202UNeX00P2UNf<0102DHd80]G]J0<J<H`3Wc[dC0?OgmaT00000:03ooolH000000<0aW]200@0cXaJ
0<IkBP3>S5X0cXaJ0`36Nd800`2eJd80aW]20<Ik@P020:e[>@030;f<H`36Q5X0[F]200<0_HaS00<0
[F/i0;EcBP2mS6<00P2]Hc401@36Q5X0cYA[0:ecDP3FW7<0klJU0080ikfD00@0gZEc0>NmU036Q5X0
_HaS0P3F[H@01036U6/0[G=B09acDP2UNeX309acDP030;F4J`3FW7<0eZf<00<0aYb400D0_IAk0;F4
J`2eQ6<0]HA[09acDP020:ecDP050;EkFP2mS6<0[G=B0:EkFP2]Le80102<FT802@2LJdX0]HAS09ac
DP2LLe80[G=B09AS@P2LHcT0U6=20:ecDP020<J4FP040;f<H`3>U6/0aXaS0=JeY@80ikfU00<0e[f]
0?Ogm`3gkoL0203gmoL20?O_m`040?Ogm`3gkoL0moOg0?oooaT000007P3oool001`0oooo6@000000
0`24DST0Q6=:07=B@P0308aSBP040:EkFP2mS6<0eYak0=j]W080ikfU00@0kkFL0>o6[@3_aZd0mlje
0`3_cZd20?O>]@@0mmJm00D0mlje0?OF_@3ge[d0mmJm0?O>]@020?OF_@030>o>]@3gc[D0kljm00@0
mlje00<0klj]0>o6[@3_aZd00`3_aZd0103_aZD0klJ]0>o6Y@3_aZD20>neW0<0ikFL0P3N[I@20=JU
S0050=JLN`3FYH@0]Hac0:EkH`2LJdX00P2DHd800`2<FT80Q5Y208AJ@P0305Xa8@05058Y600i6100
:A080;F4J`2LNf<00P2LJdX0102DHd80_HaS0=JeY@3_inL20?Ogm`80mnog3P3gmoLJ000002P0oooo
6@0000020;E[>@030<IkBP3>S5X0cXaJ00<0cXaJ00@0aXAJ0<IkBP2]JcT0[F/i0`2eLdX02036Q5X0
aXaS0;F4H`2eQ6<0W6<i0;EkFP2mS6<0[F/i0`36Q5X0102eJcT0aXAJ0<jDJ`3F[H@20<jDJ`040>o6
Y@3FW7<0eYac0=j]Q080cXaS00D0_HaS0<J<H`36Q5X0_HaS0<JLQ0020=JUQ0040=JLN`3FW7<0eYac
0<JDJ`80cYA[00D0eYak0;f<H`2mU7/0]HAS0:EkFP0209a[BP0509acDP2LJdX0W6]:09acDP2LJdX0
0P2UNeX0103FW7<0_IAk0=JLL`3FW7/20<JDJ`050<JLQ036U6/0aYA[0<JLQ036U6/00P3FYH@0103N
[H`0cZfD0>O>_@3_inL20?O_m`X0moOg00<0mnog0?Ogm`3gmoL00P3gmoL00`3gkoL000000000000H
000001h0oooo000L0?oooaX0000000<0Q5Y20:EkFP1kFT800`2UNeX00`2mS6<0aYb40=j]U0020>Nm
W0040>O6[@3_aZd0klJU0>o6[@<0mlje00@0mmJm0?O>]@3_c[d0mmJm0P3gc[D50?OF_@<0mlje00<0
mmJm0?O>]@3_aZd00P3gc[D01@3_aZd0mlje0>o6[@3_aZd0klJU00<0klJ]0P3_aZD00`3W_I`0kkfL
0>nmW0020>NeU0030=j]W03N[H`0cZfD0080_IAk00D0eYak0<jDJ`2eQ6/0YG]S09acDP0209a[BP04
08AJ@P1cBS40Le9209A[DP80@R4H00D0>AP@03TQ601kFT80Q58i0:EkFP0209a[BP040:ecDP36U6/0
ikfU0?O_m`80moOg00<0mnog0?ooo`3gmoL0303gmoLK000002P0oooo6P0000000`2eJcT0aW]20<J4
FP020<j<FP030<J4FP3NYG<0cYAS00<0cYAS00D0cXaJ0<J4FP36Q5X0aXAJ0;f<H`020<JDJ`040;f<
H`2eNeX0]G]J0;EcBP80]G]J00D0[F]20<J4FP36Q5X0_HaS0<J4FP020=JLL`040=J]Q03NYG/0klj]
0=JLL`80cYAS00@0eZf40=jUN`3>U6/0cYAS1@3FW7<01036U6/0eYac0<jDJ`3>U6/20;EkFP030;Ec
BP2LJdX0YG]J00@0W6<i00<0U6=209AJ<@2DHd800P2]Hd80102LJdX0[G=B0;EcBP2eNeX20;f<H`80
aYA[00<0aYb40<jeY@3W_I`00P3Nc/h00`3_knL0moOg0?Ogm`030?Ogm`030?ooo`3gmoL0moOg0080
moOg0P3gkoL00`3oool0moOg0?Ogm`040?Ogm`030?ooo`000000000001T000007P3oool001`0oooo
6P0000000`24FT80YG]J07]J@P030:EkFP030;f<H`36W8@0gZfD0080ikfL00@0ilJ]0>o6[@3_aZD0
klJ]0`3gc[D0103ge[d0mlje0>o>_@3ge[d20?O>]@D0mmJm0`3gc[D00`3ge[d0mlje0>o6[@020?O>
]@050>o6[@3gc[D0klJ]0>o6[@3_aZD00`3_aZd20>o6Y@030>NmW03__I`0kkfL0080ikFD00<0gZfL
0=j]S03>[I@00P2mU7/01@3FW7/0cYA[0;F4J`2UNf<0W7=B0080W6]:00@0Q5Y207=:<@1cDT80U6]B
0P128AP01@0i6100>B4H07]J@P24DST0YG]J0080W6]:00@0[G=B0<JDJ`3W_JD0mnog0P3gmoL00`3g
koL0oooo0?Ogm`0<0?Ogma/00000:03ooolJ000000030;E[>@36Nd80aXAJ0080cXaJ00<0aXAJ0=jU
L`3>U6<00`3>U6<01@3>S5X0aXAJ0<J4FP36Q5X0_HaS0080aYA[00@0_HaS0;EkFP2eNeX0]G=:0P2e
NeX01@2]Jd80aXAJ0<J4FP2mS6<0aXAJ0080eYac00@0eZf40=jUN`3_cZd0eYac0P3>U6<0103F[H@0
gZEk0<jDJ`3>U6<50=JLL`040<JDJ`3FW7<0cYA[0<jDJ`80]G]J00<0]G=:09a[BP2UNeX0102LHcT0
0`2DHd80U5Xa09AS@P020:eS@P0409a[BP2]Le80]G=:0;EkFP80_HaS0P36U6/00`36W8@0c[FU0>Nm
W0020=k>cP030>o_i`3gmoL0moOg00<0moOg00<0oooo0?Ogm`3gmoL00P3gmoL20?O_m`030?ooo`3g
moL0moOg00@0moOg00<0oooo0000000000006@00000N0?ooo`00703ooolJ00000080Q58i00L0Q6=:
0:EkH`2UNf<0YG]J0;f<H`3FW7/0gZfD0080gZfL00D0ikfU0>o6[@3_aZD0klJ]0?O6]@020>o6[@03
0?OF_@3_cZd0mlje00L0mlje00@0mmJm0?O6]@3ga[D0mlJe0`3_aZd20>neW0030>o6[@3_aZD0klJU
00@0klJU00<0klJ]0>o6Y@3_aZD00`3W]I@01@3W]I`0gZfD0=j]U03N[H`0eZF400<0_IAk00@0]HA[
0:ecDP2LLe80U6=20`24FT8208AB>@0805Xi:@1cBS40LdXa05Xi:@1cBS40Ld8Y0:EkH`2LLe820;F4
H`040;f<H`3F[H`0e[f]0?Ogm`80oooo3`3gmoLK000002P0oooo6P0000020;E[>@040;EcBP3>U6/0
cYA[0<j<FP80eYac00P0gZEc0=JLL`3FW7<0eYak0<j<FP3FW7<0cYAS0<JDJ`80]G]J00<0_HaS0=JL
N`3FW7<00`2mS6<30;EkFP080;EcBP36Q5X0aXAJ0<J4FP36NdX0aXaS0<JDJ`3N[H@30>NmW0040=jU
N`3N[H`0gZf<0=j]Q080eZf40P3FW7<01@3FW7/0eYac0=JLL`3FW7<0_HaS0080]G]J00<0YG]J0;Ek
FP2eNeX00P2eNeX01036Q5X0aXaS0;f<H`2mS6<20<JDJ`040;EkFP2LJdX0S6=:09acDP80YHA[00@0
eZf<0<JLQ03FYH`0g/k6103gmoL00`3gkoL0moOg0?O_m`020?O_m`030?Ogm`3gkoL0moOg00P0moOg
0P3gkoL20?Ogma/000007P3oool001`0oooo6`0000002024DS40NeY208aJ@P2<FT80W7=B0;F4H`2m
U7/0aYb40P3F]JD0103W]I`0ikfU0>o6Y@3_]I`30?O6]@80klje00@0klJe0>o6[@3ga[D0mlJe0P3g
c[D00`3ge[d0klJe0>o>]@030>o6[@030>o6Y@3_]I`0ikFL0080ikFL00D0kkFD0>o6Y@3_aZD0kkfL
0>neW0020>nmW0040>neU03W]I`0ikFL0=j]S080ijfD00@0gZfD0=JUS03FYH`0eYak0`2mU7/01@2e
S7<0]HA[0:ecDP2UNeX0W6]:00<0Le920P1cBS40201J@ST0Ld8Y07=2:@1J<B40YHA[09A[DP2LLe80
W6]:0P3FW7/00`36U6/0ikfL0?Ogm`030?Ogm`040?O_m`3gmoL0moOg0?ooo`X0moOg7000000X0?oo
oa/0000000P0[F/i0<IkBP36NdX0aW]:0<J4FP3N[H@0cYA[0=JLN`80eZf40`3N[H@20=JLL`80eZf4
00@0eYac0<JDJ`36U6/0eYac0P36U6/01@3>U6<0_HaS0;f<H`2eLdX0aXaS0080_HaS00@0aXaS0<JD
J`36S6<0aXAJ0`2eNeX0103FW7<0ikfU0>o>[@3_cZd20>NmY@040=J]Q03FYH@0aYb409a[BP80Q4Xa
00<0Q4XY09AJ<@2DDRT00P2]Hd820:ecDP050;f<H`2mU7/0aYA[0;f<H`3FW7<00P36W8@00`3F[H@0
eZf<0;fDN`0309AS@P030<JDJ`3Wg]H0moOg00L0moOg00<0mnog0?ooo`3oool00P3gmoL00`3oool0
moOg0?Ogm`050?Ogm`040?O_m`3gmoL0moOg0?Ogma`000007P3oool001`0oooo700000001`2LJdX0
Q58i08AB>@2LLe80YHA[0;F<L`3FYH`00P3N[I@01@3N[I`0ikFL0>neW03_]I`0klJU0080klJ]00<0
ilJ]0>o6[@3_c[D0103_aZd00`3_a[D0klJ]0>o6Y@030>o6[@030>nmW03W]I`0ijf<00<0ijfD00<0
ikFD0>neU03W[H`0103W[H`0103NYH@0gZf<0>N]U03FYH@20=j]S080eZF400<0aYb40=JLL`2mU7/0
0P2eQ6/20;F4H`030:EkFP2LLe80S5Y20080Q5Y200@0NeY207=B@P2<Je80NeY20P1cBS401@2<Je80
]HA[09AcFP2UNf<0_HaS0080eZF400<0ikfL0=Jm[@3gkoL0103gmoL00`3oool0moOg0?Ogm`090?Og
mad00000:03ooolL000000070;EkFP36NdX0aW]:0;f<H`36S6<0eZf40=j]Q0020<jDJ`80gZf<00<0
ikfD0>NmW03F[H@00P3>U6<20=JLL`060=J]Q02mS6<0cYA[0<jDJ`36U6/0aXaS0P2mS6<30;EcBP03
09a[BP2UNeX0aXaS00@0_HaS00@0]G]J0;EcBP2eNeX0[G=B0P2mS6<01036S6<0eZf40=j]S03W_I@2
0=j]Q080ikfD00<0ikfL0=j]S03F[H@00`3F[H@0103N[I@0ikfL0=J]S02eQ6/509a[BP030<j]U03W
c/H0ilk600@0moOg00<0mnog0?Ogm`3gmoL03`3gmoL0103gkoL0moOg0?Ogm`3gmoLM000001h0oooo
000L0?oooad000000P2DJe80102<HdX0W7=B0:EkH`2mU7/20=JUS0030>NmW03N[I`0e[FU0080ikFL
1@3_aZd00`3WaZd0ikfU0>NmY@030>NmY@040>NeW03N[I`0gZf<0=j]S080gZfD0P3FYH@40=JLN`03
0=JLL`3NW7/0eYak00<0eYac00<0_IAk0<jDJ`3>U6/00`3>U6/01036Q6/0]Hac0;fDN`2eS7<20;F4
J`050;EkFP2LJdX0S6=:09AcFP2DJe800P1cFTX209A[DP0307=:<@2<HdX0W6]:0080W6]:00@0W7=B
09a[BP2mS6<0]HAS0P3N[I@00`3W_I`0mnoW0?Ogm`0>0?Ogmal00000:03ooolM000000<0]G=:00<0
[F/i0;f<H`2mS6<00P36U6/20=J]Q080ikfU00L0ikfL0>NmY@3W_JD0cZfD0=J]Q03FW7<0gZf40080
eYak00D0eYac0;EkFP2eNeX0cYA[0;EkFP020;f<H`040<JDJ`2eNeX0]G]J09aS>@80W6]:00D0[G=B
0;f<H`2eNeX0]G=:0<J<H`020;EcBP040:e[>@2]Jd80U5Xa08A28@80U5Y200<0W6]:09AJ<@2LHcT0
0P24BRT209AS@P0509a[BP2LLe80YG]J0;fDN`2]Jd800P2mS6<00`36W8@0e[f]0?O_m`0A0?Ogm`04
0?ooo`3gmoL0moOg0?O_m`H0moOg7`00000N0?ooo`00703ooolM00000080S6=:00@0U6]B0:EkFP2e
Q6/0YG][0P2eS7<01@2mU7/0gZfD0=JeY@3W_JD0klJU0080ilJ]0`3W_JD0203W_I`0gZfD0=j]U03N
[I@0eZF40=j]U03W_I`0eZF<0P3NYH@0103FYH@0eZF<0;fDN`36W8@20<J4J`050<jDJ`2mS6<0eYak
0<icH`3>U6/00P2eNeX0102eS7<0]G]J0;EkFP2mS6<30;F4H`80]HA[00P0YG]S0;F<L`2mU7/0_IAk
0:F4J`2US7<0YG]J0:EkH`<0S6=:00@0U7=J0:EkH`24FT80JcTQ0P24DST01@2eNeX0]HAS0;EkFP2m
S6<0cZfD0080e[FU00<0e[f]0?Ogm`3gmoL01P3gmoL00`3gkoL0moOg0?Ogm`050?Ogmal00000:03o
oolO000000040;EcBP2]JcT0]G=:0;f<H`80aXAJ00D0aYA[0=JLL`3F[H`0eZf40>NmU0020>o>]@03
0=j]S03W_JD0eZf400<0eZf<00D0eYac0=J]Q03F[H@0eYac0;EkFP020;EcBP80_HaS00T0]Hac0;Ek
FP2]Le80[G=B0;EkFP2]Le80W7=B09a[BP2<FT800P24DS401024BRT0[F]20:ecDP2LJdX208aJ@P80
S4Xa00<0W7=B0;fDN`2mS6<00`2mS6<0102mU7/0aYb40<JLQ03Nc[d20>oWi`030?Ogm`3oool0moOg
01X0moOg8000000N0?ooo`00703ooolO0000000407]J@P2LLe80YG]J08aSBP80]Hac00<0aYb40=Jm
[@3Wa[D00P3Wa[D30>NmY@030=JeY@3N[I`0eZF40080cZfD0P3FYH`00`3FYH@0eZF<0=JUQ0020=JU
Q080aYA[0P2eS7<20;F4J`050;F<L`2eQ6/0[G=B0;F4J`2eQ6<00P2LLe80102LJdX0]HA[09acDP2e
Q6<209acDP050:ecDP2UNf<0YG]J0:EkH`2<HdX00P2DJe801@2DLeX0[G=B09AcFP2LLe80U7=J0080
W7=B00@0Q58i08AJ@P2<Je80W6]:0P2LLe820:EkFP030<JDJ`3F]JD0e[FU0080aYb4103gmoL20?O_
m`X0moOg8000000X0?oooal0000000@0]F]20;EcBP36Q5X0cYAS0P36S6<20<JDJ`030;E[@P36S6<0
_HaS0080_HaS00@0ikfD0>O6]@3WaZd0ikfD0`3W_JD0103W_I@0eZf40<jDJ`3>U6/20=JLL`040=JL
N`36W8@0aXAJ0;EkFP80_HaS00D0]HAS0;EkFP2eNeX0YG]J0;F4H`030:EkFP80[G=B00P0_HaS0;F4
J`2eQ6/0aYA[0<JLQ03F[H@0eZf<0=JLN`80eYac00<0eZF40>oNcP3_inL08@3gmoLP000001h0oooo
000L0?oooal0000000@0NeY209acDP2UNeX0S6=:0P2eS7<00`36W8@0e[f]0>O6]@020>O6]@<0ikfU
00<0e[FU0=j]W03FYH@00P3>[I@20=JUS0030=JUQ03FYH`0eZF40080eZF40P36U6/20;F<L`80]HA[
00D0]Hac0;F4J`2]Le80]HA[0;F4H`0209acDP0409a[BP2eQ6/0W7=B0;F4H`80W7=B00D0[G=B0:Ek
H`2UNeX0YG]S08aSBP0209A[DP0509AcFP2]Le80U7=J09acDP2DLeX00P2LLe801024DST0Q5Y208a[
DP2LJdX209acDP80YG]J00<0aYA[0=JeY@3F]JD00P36W8@40?Ogm`80mnog2P3gmoLP000002P0oooo
7`000000102eJd80]G=:0<J4FP3>U6<20<J<H`80aYA[00<0]F]20<J<H`2mS6<00P2mS6<0103W_I@0
ilJe0>O6[@3W_I@30>NmY@040>NmU03F[H@0cYA[0<jDJ`80eYac00@0eYak0<JLQ036Q5X0]G]J0P2m
S6<01@2eQ6<0]G]J0;EkFP2UNeX0]HAS00<0YG]J0P2]Le80202mS6<0]HA[0;F4J`36U6/0aYb40=J]
Q03F[H`0eYak0P3FW7<00`3FYH@0kmk>0>oWi`0Q0?Ogmb0000007P3oool001`0oooo800000000`2L
Lf<0YHac0<JUU0020<jUU0040;fLS03N[I`0cZFD0=j]W0<0e[f]00@0gZfL0=j]U03FYH`0eZF40P3F
YH`01@2mU7/0aYb40=JUQ036W8@0aYA[0080aYb400@0_IAk0<J4J`2eQ6<0]HA[0P2LLe801@2mU7/0
YG]S0;fDN`2eQ6<0YG]S0080_HaS00@0YG]J09a[BP2mU7/0YG]J0P2eQ6/01@2UNf<0YG]J0:F4J`2U
S7<0Q6=:0080U6]B00D0YG]J09akH`2<Je80U7=J0:EkH`0209AS@P0409a[BP2DHd80W6]:09AS@P80
W7=B00D0]HAS0=J]Q03>]JD0cZfD0=J]S0020>O>aP@0moOg0P3oool90?Ogmb400000:03ooolP0000
00030<J<H`36Q5X0_HaS0080aXaS00@0]G]J0;EcBP2mS6<0]G]J0`2eLdX20;f<H`040=J]Q03W_JD0
ilJe0>O6]@D0ikfU0P3F[H@20=JLL`090<JDJ`3FW7<0aYA[0<JDJ`2mU7/0]G]J0<JDJ`2eQ6<0[G=B
0080]G]J00@0_IAk0;F4H`2UQ6/0aYA[0P3FYH@01@3F[H@0eYac0=J]Q03F[H`0g/Je0080knON00<0
knoW0?ooo`3gmoL0803gmoLQ000001h0oooo000L0?ooob40000000<0U6]B0:F4J`2eS7<00P2eS7<0
102mW8`0gZfL0=JeY@3N[I@20<j]U0030=JUS03F[H`0aYb400<0aYb400D0]Hac0;fDN`2eS7<0_IAk
0;F<L`020;fDN`040;F4J`2mU7/0YG]J09acDP80YG][00D0U6=20:F4J`2UNeX0]Hac09acDP020:Ek
H`040:EkFP2UNf<0aYA[08aSBP<0W7=B00@0]HA[0:EkFP2DJe80U6]B0P24FT80101kFT80LdXa07=B
@P2<HdX308AB>@80NeY200T0U6=20;EcBP36U6/0aYA[0=J]Q03WaZd0_Ib<0=J]S02eQ6<0403gmoLR
000002P0oooo8@0000020<jDJ`80_HaS00<0]F]20;f<H`2mS6<0102mS6<0102eJd80aYA[0=JLL`36
W8@20;fDN`030<JLQ03F_Jd0ilJ]0080ilJ]0`3W_JD20>NmW0080>NmU03>[I@0cZfD0=J]S03>[I@0
ikfL0<j]U03W_I@20=j]S0040=J]S03N[H@0eZf40<j]U080ilJ]00<0imK60>OFcP3_inL09P3gmoLR
000001h0oooo000L0?ooob80000000@0_IbD0<JLQ036W8@0aZFD103F]JD50<JLQ0030;fDN`36W8@0
aYb40080_IAk0P2eQ6/01P2mU7/0]HAS0;F4H`2UNeX0YG]S09AS@P<0YHA[00D0S6=:07=:<@2UNf<0
Q5Y20;F4H`020:EkFP80YG]S00T0S5Y209a[BP2UNeX0YG]J07=2:@1cBS40W6<i08aJ@P24FT800P2<
FT800`2LHcT0U6=209a[BP0209AS@P80Q58i00@0W6<i09a[BP3>[I@0_IAk0P3F[H`01@3F_Jd0S6=:
0;fLS02UQ6/0g/k>0080oooo203gmoL00`3gkoL0moOg0?Ogm`020?Ogmb<00000:03ooolR00000008
0<JDJ`3F[H@0eZf40=J]Q03FW7<0cYA[0<JDJ`36NdX20<J<H`040;f<H`3FW7/0aYb40=J]Q080]HAS
00D0aYA[0=JLL`36U6/0aYb40=JLL`030<j]U0030=JeY@3F_Jd0e[f]00<0g/Je0P3WaZd01`3Na[D0
iljm0>OFaP3We/H0imkF0>o_i`3gknL0103gmoL00`3oool0moOg0?Ogm`0T0?Ogmb<000007P3oool0
01`0oooo9@0000001@2UQ6/0aZFL0<jeY@3N[I`0e[FU0080aZFD0P2mU7/02@2eS7<0_IAk0;fDN`2m
U7/0]Hac0:F4J`2US7<0]Hac0:EkH`030;F4H`0308aSBP36U6/0YG]J0080S6=:00@0_IAk08aSBP24
FT80YG]S0`2<HdX0102DJe80Q5Y208aJ@P24DS4207=2:@80Q58i00<0W6<i08AB>@1kFT800P2DHd80
1@2<FT80Q58i08A:<@2<FT80W7=B00<0]HAS00<0aYb40;fDN`3W_I`00P3F]JD0102UQ6/0YG]J0;fL
S02UQ6/60?Ogm`050?O_m`3gmoL0moOg0?Ogm`3gkoL00P3gmoLV000002P0oooo8`0000030=J]Q004
0=JLL`36S6<0aYA[0<JDJ`<0aYb400<0aYA[0<JLQ036U6/00P36U6/01@36W8@0eZf40=J]Q036W8@0
eZf<0080aYA[00@0_HaS0<JDJ`3F_Jd0knOW0`3Na[D0103F]JD0aYb40=k>_@3Nc[d20>o_ib`0moOg
9@00000N0?ooo`00703ooolV000000040;FDN`36[I`0c[FU0=JUS080aZFD00<0YG]S0;F4J`2UQ6/0
0`2mU7/01@2eQ6/0W7=S0;F4J`2eQ6<0YG]S0080]Hac00@0YG]S0;F4H`24FT80W7=B0P2DLeX01@2<
HdX0YG]J08AJ@P2<HdX0U6=20080Q5Y200<0Q6=:08AJ@P1cDT801024DST0101cBS40Ld8Y08AB>@1k
FT8208AB>@80Q58a00<0S6=:0:EkFP2UNeX00`2UNeX00`36W8@0c[FU09akH`0209akH`040:F4J`36
YI@0_IAk0>oWi`<0mnog0P3gmoL01@3gkoL0moOg0?Ogm`3gmoL0mnog0080moOg9`00000X0?ooobH0
00000P3FW7<01P3F[H@0e[FU0=JLL`3FW7<0aYA[0<J<H`@0eYac00D0_IAk0<JLQ03FW7<0aXaS0<JD
J`020=JLN`040>O6]@3Wg]H0g/jm0<j]U080aZfL00@0e[f]0>O>aP3Nc[d0mnog;@3gmoLW000001h0
oooo000L0?ooobH0000000@0]IAk0<J]W03>]JD0eZF<0P36YI@00`2UNf<0]HA[0:F4J`030;fDN`05
0;F4J`2LLf<0]HA[0;F4H`2UNf<00P2eS7<0102UNf<0]HAS08AJ@P2LLe8209AcFP0508aSBP2UNeX0
Q5Y208aSBP2DHd800P24FT800`24HdX0Q5Y207=B@P0408AB>@0407=:<@1c@RT0Q58i07]J@P80Q58i
0P24DS400`2<HdX0YG]J0:EkFP030:EkFP030<JLQ03>]JD0W7]S0080W7]S00@0YHA[0<JUU02mU7/0
knOW0`3gkoL20?Ogm`050?O_m`3gmoL0moOg0?Ogm`3gkoL00P3gmoLW000002P0oooo9P0000020=JL
L`060=J]Q03F]JD0eYac0=JLL`36U6/0aXaS103FW7<01@2mU7/0aYb40=JLL`36S6<0aYA[0080eYak
00@0ilJe0>ONeP3Nc[d0cZfD0P36[I`0103F_Jd0ilk60=k>_@3gkoL]0?OgmbL000007P3oool001`0
oooo9`0000000`2eU7/0e[FU0=JeY@020<J]W0040:EkFP2eS7<0YG]S0:EkH`80]HAS00D0YG]J09Ac
FP2UQ6/0YHA[09AcFP020:EkH`0409AcFP2UNf<0Q5Y20:EkFP80W6]:00D0U6]B07=B@P1cBS40YG]J
07=B@P0207]J@P0308AJ@P1kFT80Q58a00<0LdXa00<0JcTQ05Xi:@1c@RT00P1c@RT208AB<@0509a[
BP24FT80S6=:0:F4J`36W8@00P2mU7/0103W_JD0c[FU0;fLS02US7<209A[DP030<JLQ02DJe80knOW
0080oooo0P3gkoL80?OgmbP00000:03ooolW00000080eZf<00L0ikfD0=J]Q03F[H@0eZf40<j]U03F
[H`0ikfD00<0cZfD00@0e[FU0>OFaP3Wg]H0knON0P3We/h0103We/H0ikfU0>OFcP3_inL20=JeY@03
0=k>_@3gkoL0moOg00P0moOg0P3gkoLS0?OgmbP000007P3oool001`0oooo:0000000203>]JD0e[f]
0<J]W036[I`0YG]J09A[DP2eU7/0YG]S0P2eS7<01@2eU7/0]HAS09A[DP2UQ6/0YG]J0080S6=:0P2U
Nf<02@2<HdX0W7=B0:EkFP2UNeX0U7=J08a[DP1J<B40LdXa07]J@P020:EkFP80Q58i00L0JcTQ08AB
>@1c@RT0Ld8Y06/i8@1J<B40FSTY0080FS4Q0P1cBS401@2<FT80YHA[0;fDN`2eQ6/0_IAk0080c[FU
00@0]IAk08ASBP2DNf/0]HAS0P2UQ6/00`2LJdX0aZFL0?Ogm`060?Ogm`050?O_m`3gmoL0oooo0?oo
o`3gmoL0:@00000X0?ooobP0000000P0eZf40<jeY@3F[H`0eZf<0>NmU03W_I`0ikfU0=k>_@<0knON
00@0imkF0>oWi`3_imh0knOW0P3_imh0103_inL0mnog0>OFcP3F]JD40?Ogm`030?O_m`3gmoL0moOg
02X0moOg:@00000N0?ooo`00703ooolZ00000080e[FU00@0YHA[09A[DP2UNeX0]Hac0`2DLeX0102U
Nf<0S6]B08aSBP2LLf<209AcFP0408a[DP2DJe80YG]S09AcFP80S6=:00@0YG]J09acDP2<Je80S6=:
0`1cBS401024HdX0Q58i08AB>@2<FT8208AB<@0509a[BP24DS40Q58a09AJ<@2LJdX00P2]Le801@2U
Nf<0_HaS0<JLQ03Na[D0]IAk0080_Ib<00@0W7][07=:<@2DLeX0YHA[0`2eU7/70?Ogm`030?ooo`3g
moL0mnog02`00000:03ooolZ00000080ikfD00@0imK>0?O_i`3_imh0imK>0P3_imh01@3_inL0knoW
0>oWi`3_imh0imkF0080knON0P3_inL00`3Wc/H0moOg0?Ogm`0]0?Ogmb`000007P3oool001`0oooo
;0000000103F]JD0S6=:08a[DP2LNf<20;F4H`0309AcFP2DJe80Q5Y20080NeY20`2<HdX00`2DJe80
U7=J08aSBP0208aSBP050:EkFP2UQ6/0W7=B09AcFP1kFT800P2UNeX01024DST0Q58a09AcFP2DJe82
08aSBP0509AS@P2LJdX0YG]J0;F4H`36W8@00P2eS7<0102mU7/0e[FU0;fLS02eW8`30:F<L`0407]J
@P2LLf<0YHac0:F4J`80YG][00D0oooo0?Ogm`3oool0oooo0?Ogm`020?O_m`030?ooo`3gkoL0oooo
02d00000:03oool/000000040>o_i`3Wg]H0knON0>oWi`80knoW00D0mnoW0>oWgP3_imh0knOW0>oW
gP020>OFaP040>oWi`3gmoL0moOg0?Ogm`<0mnog00<0moOg0?O_m`3gmoL09`3gmoL]000001h0oooo
000L0?ooobh000000P2<Je830:F4J`0309A[DP2UQ6/0Q58i00<0Q5Y200@0W6]:09A[DP2LLe80Q58i
0P2UNf/01@2LLe80]Hac0:EkH`2eQ6/0]IAk0080U6]B0P2<FT8209acDP<0]HAS0P2mS6<20=JUQ080
aZFD00D0YG]S09akJ`2LNf/0S5Y207=2:@0208AB>@040:EkH`2UQ6/0W7]S0;fDN`80oooo0`3gmoL2
0?ooo`<0moOg;`00000X0?ooobh0000000H0mnoW0>o_i`3_knL0knoW0>oWi`3_knL20>oWgP040?O_
i`3gmoL0moOg0?O_m`L0moOg00<0mnog0?Ogm`3gmoL0903gmoL_000001h0oooo000L0?oooc000000
0P2UQ6/01@2<HdX0YHAc09AcFP2UNf<0U6]B0080Q58i00@0Ne9207=:<@2<HdX0NeY20P2LLf<01@2L
Le80_IAk0;F<L`3Na[D0ilJe0080e[FU00<0aYb40=j]W03FYH`00`3FYH`20>O6[@030=j]U03>]JD0
YHac0080S6]B00D0W7]S09A[DP24FT80NeY208aSBP020;F4H`040;FDN`2UNf<0YG][0?ooo`<0moOg
00@0oooo0?Ogm`3gmoL0moOg<P00000X0?oooc0000000P3_imh00`3_inL0mnog0?O_m`020?Ogm`80
mnog203gmoL00`3gkoL0moOg0?Ogm`080?Ogm`030?O_m`3gmoL0moOg01H0moOg<P00000N0?ooo`00
703oool`00000080YHA[00D0S6=:0:F4L`2DLeX0YG]S09A[DP0208AB>@0407]B@P1cBS40S6=:07]J
@P80W7=S00D0W7=B0;fDN`2eS7<0g/Je0>O6]@020=JeY@030<JLQ03N[I`0eZF<00<0eZF<0P3WaZd0
0`3N[I@0c[FU0:F<L`0208a[DP0509akH`2DJe80Q5Y207]J@P2<HdX00P2eQ6<0102eU7/0YG]S0:Ek
J`3oool30?Ogm`040?ooo`3gmoL0moOg0?Ogmc800000:03oool`00000080knON00<0knOW0?O_m`3g
koL00P3gmoL20?O_m`P0moOg00<0mnog0?Ogm`3gmoL0203gmoL00`3gkoL0moOg0?Ogm`0F0?Ogmc80
00007P3oool001`0oooo<`000000102UQ7<0YHak0:EkJ`2mU7/20<JUU00409akJ`1kDT80S6]B07]B
@P80U7=J00D0]IAk0<JUU02mW8`0YHak0=Jm[@020=Jm]@040=Jm[@3Na[D0imK60>O>aP80e[f]00D0
aYb40;FDN`2eU7/0YHAc09AcH`0209AcFP0509A[DP1cDT80Q58i09AcFP2LNf<00P2mU7/00`2UNf<0
]IAk0?Ogm`030?Ogm`030?O_m`3gmoL0moOg03@00000:03ooolc000000030>o_i`3gkoL0moOg02d0
moOg=000000N0?ooo`00703ooolf000000070=Jm]@36YI`0aZFL0>O>aP3_e/H0mnoW0>oWgP020>oF
aP040>O>aP3Wc[d0e[f]0=k>_@@0g/Je00<0iljm0<jeY@2US7<00P36YI@01@2US7<0W7]S09akJ`2L
Nf/0S6=:0080S6]B00<0LeY:0:EkH`2US7<00P2UQ6/20:EkH`040?ooo`3gmoL0moOg0?ooo`80mnog
=`00000X0?ooocD00000;03gmoLf000001h0oooo000L0?ooocX0000000<0g/Je0>O6]@3Wc[d00P3W
a[D01@3_e/H0kmk>0>OFcP3Nc[d0ilk60080c[FU00@0_IbD0=Jm[@2mW8`0]Ib<0P2mW9@01@2<LeX0
YG]J08aSBP2<Je80W7][0080YHAc00D0_Ib<0<JLQ02eS7<0YHA[0<JUW0030?Ogm`030?O_m`000000
000003T00000:03oooli000000L0moOg00@0mnog0?Ogm`3gmoL0moOg0P3gkoLG0?OgmcX000007P3o
ool001`0oooo?`0000001@3We/h0kmk>0>O>aP3Nc[d0e[fe0080c/Jm00@0]Ib<0:F<Q02mW9@0W7]S
0P2LNf/01@2DLeX0YHac08ASDP2US7/0_Ib<0080aYb400@0]Ib<0:F<N`36W8@0imkN@000000X0?oo
oc`0000000@0moOg0?O_m`3gkoL0moOg0P3gkoL=0?Ogm`030?O_m`3gmoL0moOg00P0moOg?@00000N
0?ooo`00703ooom:00000080]Ib<B`00000X0?oood8000004P3gmoM3000001h0oooo000L0?oooiL0
0000:03ooonG000001h0oooo000L0?oooiL00000:03ooonG000001h0oooo000L0?oooiL00000:03o
oonG000001h0oooo000L0?oooiL00000:03ooonG000001h0oooo000L0?oooiL00000:03ooonG0000
01h0oooo000L0?oooiL00000:03ooonG000001h0oooo000L0?oooiL00000:03ooonG000001h0oooo
000L0?oooiL00000:03ooonG000001h0oooo000L0?oooiL00000:03ooonG000001h0oooo000L0?oo
oiL00000:03ooonG000001h0oooo000L0?oooiL00000:03ooonG000001h0oooo000L0?oooiL00000
:03ooonG000001h0oooo000L0?oooiL00000:03ooonG000001h0oooo000L0?oooiL00000:03ooonG
000001h0oooo000L0?oooiL00000:03ooonG000001h0oooo000L0?oooiL00000:03ooonG000001h0
oooo000L0?oooiL00000:03ooonG000001h0oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo001S0?oo
o`03@000003oool0oooo00H0oooo00=000000?ooo`3oool0/P3oool00d000000oooo0?ooo`060?oo
o`03@000003oool0oooo06<0oooo001R0?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3o
ool0/03oool00d000000oooo0?ooo`080?ooo`03@000003oool0oooo0680oooo001Q0?ooo`03@000
003oool0oooo0080oooo140000040?ooo`03@000003oool0oooo0:h0oooo00A000000?ooo`3oool0
oooo140000050?ooo`03@000003oool0oooo0640oooo001Q0?ooo`03@000003oool0oooo0080oooo
0d0000050?ooo`03@000003oool0oooo0:h0oooo00=000000?ooo`3oool00P3oool014000000oooo
0?oood0000040?ooo`03@000003oool0oooo0640oooo001Q0?ooo`03@000003oool0oooo00@0oooo
00=000000?ooo`3oool00`3oool00d000000oooo0?ooo`2^0?ooo`03@000003oool0oooo0080oooo
00A000000?ooo`3ooom00000103oool00d000000oooo0?ooo`1Q0?ooo`00H@3oool00d000000oooo
0?ooo`030?ooo`9000001@3oool00d000000oooo0?ooo`2^0?ooo`03@000003oool0oooo0080oooo
0d0000050?ooo`03@000003oool0oooo0640oooo001R0?ooo`03@000003oool0oooo00P0oooo00=0
00000?ooo`3oool0/03oool01D000000oooo0?ooo`3ooom0000000H0oooo00=000000?ooo`3oool0
HP3oool006<0oooo00=000000?ooo`3oool01P3oool00d000000oooo0?ooo`2b0?ooo`04@000003o
oom00000@00000D0oooo00=000000?ooo`3oool0H`3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool009X0oooo0T00001A0?ooo`900000X@3oool009`0oooo00=0
00000?ooo`3oool0D03oool00d000000oooo0?ooo`2N0?ooo`00SP3oool3@00000<0oooo0d000003
0?ooo`=000001@3oool014000000oooo0?ooo`3oool2@00000H0oooo00=000000?ooo`3oool02@3o
ool2@00000<0oooo0T0000020?ooo`=000000`3oool2@0000080oooo0d00000=0?ooo`=0000000L0
oooo@000003ooom000000?oood000000oooo00A000000P3oool3@0000080oooo0T0000020?ooo`90
0000V03oool008l0oooo00=000000?ooo`3oool00`3oool01D000000oooo0?ooo`3ooom000000080
oooo00=000000?ooo`3oool02@3oool00d000000oooo0?ooo`0>0?ooo`03@000003oool0oooo0080
oooo00A000000?ooo`3ooom000000P3oool01D000000oooo0?ooo`3ooom000000080oooo00A00000
0?ooo`3ooom000003`3oool02D000000oooo0?oood000000oooo@000003ooom000000?ooo`03@000
0080oooo00I000000?ooo`3ooom000000?oood0000060?ooo`03@000003oool0oooo09D0oooo002?
0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003o
ool0oooo00P0oooo0T00000@0?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3ooom00000
0P3oool01D000000oooo0?ooo`3ooom000000080oooo00A000000?ooo`3ooom000003`3oool02400
0000oooo0?oood000000oooo@000003ooom000000`3oool014000000oooo0?oood0000020?ooo`03
@000003ooom00000009000000`3oool00d000000oooo0?ooo`2F0?ooo`00S`3oool2@00000<0oooo
0T0000040?ooo`=000002@3oool00d000000oooo@000000@0?ooo`03@000003oool0oooo00<0oooo
0T0000030?ooo`03@000003oool0oooo0080oooo0T0000020?ooo`A00000303oool2@0000080oooo
0T0000000`3ooom000000?ooo`020?ooo`9000000`3oool3@00000040?oood0000100000@00000<0
oooo0T00002G0?ooo`00S`3oool014000000oooo0?oood00000C0?ooo`03@000003ooom000000100
oooo00=000000?oood000000203oool00d000000oooo0?ooo`390?ooo`00SP3oool5@0000080oooo
00=000000?ooo`3oool03`3oool2@0000100oooo0d0000070?ooo`9000006@3oool00d000000oooo
0?ooo`2_0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0976966, -0.0500106, 
  0.00550224, 0.00550224}, {{17.75, 190.813}, {389.875, 
  216.813}} -> {-24.4158, -5.46868, 0.847859, 0.423928}, {{208.125, 
  381.188}, {389.875, 216.813}} -> {-92.9132, -10.9374, 0.423928, 
  0.847859}, {{17.75, 190.813}, {199.5, 26.375}} -> {-24.3814, -172.283, 
  0.847528, 0.847528}, {{208.125, 381.188}, {199.5, 
  26.375}} -> {-185.73, -172.283, 0.847528, 0.847528}}]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "We remove the needless variables, because the computations of color image \
eigen pattern require an enormous memories. Checking the used memories \
reveals that our ",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " front-end is now using about 2.5 mega bytes memories. Even though a \
relatively small memory is used, next section may require a virtual memory \
use.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
Remove[\"sample\",\"sampleW\",\"samplewDG\"];
memoryUsed\
\>", "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    InterpretationBox[\(2462\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ 2462, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Eigen patterns",
  FormatType->InputForm,
  FontFamily->"Times New Roman"]], "Subsubsection",
  FormatType->InputForm],

Cell[TextData[{
  "\t",
  StyleBox[
  "We compute the color image eigen patterns. The red, green and blue color \
components are not independently computed but simultaneously computed. This \
leads to a enormous memory. Figure 10 shows the color image eigen patterns. \
Surprisingly, all of the color images in Fig. 9 take the similar eigen \
patterns, even if their images are the angled and low-resolution ones.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
eigen3D=Table[eigenPattern[Flatten[sampleWD[[i]]],
\tresolution],{i,4}];\
\>", "Input",
  CellLabel->"In[75]:=",
  FormatType->InputForm],

Cell["\<\
eigen3DG=Table[ListPlot3D[convert2D[eigen3D[[i]],xReso,yReso],
\tPlotRange->All,Mesh->False,Boxed->False,
\tPlotLabel->StringForm[\"`1`\",label[[i]]],
\tDisplayFunction->Identity],{i,4}];\
\>", "Input",
  CellLabel->"In[76]:=",
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[{{eigen3DG[[1]],eigen3DG[[2]]},{eigen3DG[[3]],
\teigen3DG[[4]]}}],PlotLabel->\"Fig.10. Eigen patterns\",
\tImageSize->{400,400}];\
\>", "Input",
  CellLabel->"In[77]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[.5 .82364 -68 0 ]
[.5 .82364 68 12.5625 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.10) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Eigen) show
147.000000 12.812500 moveto
(patterns) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -11 0 ]
[.5 .82364 11 12.5625 ]
[.18671 .18355 -5.87859 -9 ]
[.18671 .18355 .12141 0 ]
[.40046 .09948 -10.9232 -9 ]
[.40046 .09948 1.07679 0 ]
[.63268 .00821 -10.0892 -9 ]
[.63268 .00821 1.91076 0 ]
[.78828 .12893 0 -6.13096 ]
[.78828 .12893 6 2.86904 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 12 3.00782 ]
[.96661 .40202 0 -5.87517 ]
[.96661 .40202 12 3.12483 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01441 .32593 -18 -2.79376 ]
[.01441 .32593 0 6.20624 ]
[.00431 .38921 -24 -2.84748 ]
[.00431 .38921 0 6.15252 ]
[-0.0062 .45508 -24 -2.90365 ]
[-0.0062 .45508 0 6.09635 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.19579 .19302 m
.20033 .19776 L
s
[(5)] .18671 .18355 .95953 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(10)] .40046 .09948 .82054 1 Mshowa
.64007 .01906 m
.64377 .02448 L
s
[(15)] .63268 .00821 .68154 1 Mshowa
.125 Mabswid
.23703 .17687 m
.23971 .17975 L
s
.27893 .16047 m
.28157 .16339 L
s
.32151 .14379 m
.32411 .14675 L
s
.36479 .12685 m
.36734 .12985 L
s
.4535 .09211 m
.45595 .0952 L
s
.49897 .07431 m
.50137 .07743 L
s
.54521 .0562 m
.54755 .05937 L
s
.59224 .03779 m
.59452 .041 L
s
.1552 .20892 m
.15797 .21172 L
s
.11524 .22456 m
.11804 .22733 L
s
.0759 .23997 m
.07874 .24269 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.77594 .1334 m
.76978 .13563 L
s
[(5)] .78828 .12893 -1 .36244 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(10)] .88369 .27502 -1 .3316 Mshowa
.95406 .40586 m
.94779 .40778 L
s
[(15)] .96661 .40202 -1 .30559 Mshowa
.125 Mabswid
.79613 .16428 m
.79242 .1656 L
s
.81573 .19425 m
.81201 .19555 L
s
.83476 .22337 m
.83104 .22465 L
s
.85326 .25166 m
.84953 .25292 L
s
.88871 .30589 m
.88497 .30711 L
s
.90572 .33191 m
.90197 .33311 L
s
.92227 .35722 m
.91851 .3584 L
s
.93838 .38186 m
.93462 .38303 L
s
.75514 .10158 m
.75145 .10294 L
s
.73369 .06877 m
.73001 .07015 L
s
.71157 .03492 m
.70789 .03634 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02668 .32128 m
.03281 .31895 L
s
[(500)] .01441 .32593 1 -0.37917 Mshowa
.01663 .38468 m
.02279 .38242 L
s
[(1000)] .00431 .38921 1 -0.36723 Mshowa
.00617 .4507 m
.01235 .4485 L
s
[(1500)] -0.0062 .45508 1 -0.35475 Mshowa
.125 Mabswid
.03444 .27233 m
.0381 .27091 L
s
.03252 .28443 m
.03619 .28301 L
s
.03059 .29661 m
.03426 .2952 L
s
.02864 .3089 m
.03232 .30749 L
s
.0247 .33376 m
.02838 .33237 L
s
.02271 .34634 m
.02639 .34496 L
s
.0207 .35902 m
.02439 .35764 L
s
.01867 .3718 m
.02237 .37043 L
s
.01457 .39767 m
.01827 .39632 L
s
.0125 .41077 m
.0162 .40942 L
s
.01041 .42397 m
.01411 .42263 L
s
.0083 .43728 m
.012 .43595 L
s
.00403 .46423 m
.00774 .46292 L
s
.00186 .47787 m
.00558 .47657 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.38461 .58461 .40512 .60371 .43942 .59342 .41918 .57408 Mtetra
.41918 .57408 .43942 .59342 .47416 .583 .45421 .56341 Mtetra
.45421 .56341 .47416 .583 .50935 .57244 .48969 .55259 Mtetra
.48969 .55259 .50935 .57244 .54499 .56175 .52564 .54164 Mtetra
.52564 .54164 .54499 .56175 .58111 .55092 .56207 .53054 Mtetra
.56207 .53054 .58111 .55092 .61769 .53994 .59898 .51929 Mtetra
0 .057 .574 r
.59898 .51929 .61769 .53994 .6628 .73621 .63803 .55723 Mtetra
.667 .48 .622 r
.63803 .55723 .6628 .73621 .69233 .51755 .67429 .49634 Mtetra
.664 .741 .908 r
.67429 .49634 .69233 .51755 .73041 .50613 .71272 .48463 Mtetra
.71272 .48463 .73041 .50613 .76899 .49455 .75168 .47276 Mtetra
.75168 .47276 .76899 .49455 .80811 .48282 .79117 .46073 Mtetra
.79117 .46073 .80811 .48282 .84775 .47092 .83121 .44853 Mtetra
.83121 .44853 .84775 .47092 .88795 .45886 .87181 .43616 Mtetra
.87181 .43616 .88795 .45886 .92871 .44664 .91298 .42361 Mtetra
0 .017 .567 r
.91298 .42361 .92871 .44664 .97065 .43873 .96433 .48306 Mtetra
.664 .741 .908 r
.36361 .56506 .38461 .58461 .41918 .57408 .39846 .55427 Mtetra
.39846 .55427 .41918 .57408 .45421 .56341 .43377 .54333 Mtetra
.43377 .54333 .45421 .56341 .48969 .55259 .46955 .53226 Mtetra
.46955 .53226 .48969 .55259 .52564 .54164 .50581 .52103 Mtetra
.50581 .52103 .52564 .54164 .56207 .53054 .54255 .50966 Mtetra
.625 .136 0 r
.54255 .50966 .56207 .53054 .59898 .51929 .58077 .55695 Mtetra
0 0 0 r
.58077 .55695 .59898 .51929 .63803 .55723 .61754 .48645 Mtetra
.625 .517 .711 r
.61754 .48645 .63803 .55723 .67429 .49634 .6558 .4746 Mtetra
.664 .741 .908 r
.6558 .4746 .67429 .49634 .71272 .48463 .69459 .46259 Mtetra
.69459 .46259 .71272 .48463 .75168 .47276 .73392 .45042 Mtetra
.73392 .45042 .75168 .47276 .79117 .46073 .77379 .43807 Mtetra
.77379 .43807 .79117 .46073 .83121 .44853 .81423 .42556 Mtetra
.81423 .42556 .83121 .44853 .87181 .43616 .85524 .41286 Mtetra
.07 .4 .856 r
.85524 .41286 .87181 .43616 .91298 .42361 .9014 .43956 Mtetra
.582 .81 .417 r
.9014 .43956 .91298 .42361 .96433 .48306 .93903 .38692 Mtetra
.664 .741 .908 r
.34209 .54503 .36361 .56506 .39846 .55427 .37723 .53397 Mtetra
.37723 .53397 .39846 .55427 .43377 .54333 .41284 .52277 Mtetra
.41284 .52277 .43377 .54333 .46955 .53226 .44892 .51142 Mtetra
.44892 .51142 .46955 .53226 .50581 .52103 .48549 .49991 Mtetra
.48549 .49991 .50581 .52103 .54255 .50966 .52255 .48825 Mtetra
.742 .265 0 r
.52255 .48825 .54255 .50966 .58077 .55695 .56087 .54603 Mtetra
.935 .816 .703 r
.56087 .54603 .58077 .55695 .61754 .48645 .59822 .46445 Mtetra
.664 .741 .908 r
.59822 .46445 .61754 .48645 .6558 .4746 .63683 .4523 Mtetra
.63683 .4523 .6558 .4746 .69459 .46259 .67599 .43998 Mtetra
.67599 .43998 .69459 .46259 .73392 .45042 .71569 .42749 Mtetra
.71569 .42749 .73392 .45042 .77379 .43807 .75596 .41482 Mtetra
.75596 .41482 .77379 .43807 .81423 .42556 .79681 .40198 Mtetra
.79681 .40198 .81423 .42556 .85524 .41286 .83823 .38894 Mtetra
.01 .357 .831 r
.83823 .38894 .85524 .41286 .9014 .43956 .88504 .41877 Mtetra
.898 .828 .769 r
.88504 .41877 .9014 .43956 .93903 .38692 .9229 .36231 Mtetra
.664 .741 .908 r
.32005 .5245 .34209 .54503 .37723 .53397 .35548 .51317 Mtetra
.35548 .51317 .37723 .53397 .41284 .52277 .39138 .50169 Mtetra
.39138 .50169 .41284 .52277 .44892 .51142 .42777 .49006 Mtetra
.42777 .49006 .44892 .51142 .48549 .49991 .46465 .47826 Mtetra
.767 .292 0 r
.46465 .47826 .48549 .49991 .52255 .48825 .50156 .53598 Mtetra
0 0 0 r
.50156 .53598 .52255 .48825 .56087 .54603 .53996 .45418 Mtetra
.612 .483 .681 r
.53996 .45418 .56087 .54603 .59822 .46445 .57839 .44189 Mtetra
.664 .741 .908 r
.57839 .44189 .59822 .46445 .63683 .4523 .61737 .42943 Mtetra
.61737 .42943 .63683 .4523 .67599 .43998 .6569 .41679 Mtetra
.6569 .41679 .67599 .43998 .71569 .42749 .69699 .40396 Mtetra
.69699 .40396 .71569 .42749 .75596 .41482 .73766 .39096 Mtetra
.73766 .39096 .75596 .41482 .79681 .40198 .77892 .37777 Mtetra
0 .09 .627 r
.77892 .37777 .79681 .40198 .83823 .38894 .82644 .42543 Mtetra
0 0 0 r
.82644 .42543 .83823 .38894 .88504 .41877 .86324 .3508 Mtetra
.628 .533 .727 r
.86324 .3508 .88504 .41877 .9229 .36231 .90633 .33702 Mtetra
.664 .741 .908 r
.29746 .50347 .32005 .5245 .35548 .51317 .33318 .49186 Mtetra
.33318 .49186 .35548 .51317 .39138 .50169 .36938 .48009 Mtetra
.36938 .48009 .39138 .50169 .42777 .49006 .40608 .46816 Mtetra
.40608 .46816 .42777 .49006 .46465 .47826 .44329 .45606 Mtetra
0 .148 .652 r
.44329 .45606 .46465 .47826 .50156 .53598 .48043 .48682 Mtetra
.788 .651 .711 r
.48043 .48682 .50156 .53598 .53996 .45418 .51926 .43136 Mtetra
.664 .741 .908 r
.51926 .43136 .53996 .45418 .57839 .44189 .55806 .41874 Mtetra
.55806 .41874 .57839 .44189 .61737 .42943 .5974 .40595 Mtetra
.5974 .40595 .61737 .42943 .6569 .41679 .63731 .39297 Mtetra
.63731 .39297 .6569 .41679 .69699 .40396 .6778 .37981 Mtetra
.6778 .37981 .69699 .40396 .73766 .39096 .71887 .36646 Mtetra
.71887 .36646 .73766 .39096 .77892 .37777 .76054 .35291 Mtetra
0 .091 .628 r
.76054 .35291 .77892 .37777 .82644 .42543 .80822 .40044 Mtetra
.917 .797 .713 r
.80822 .40044 .82644 .42543 .86324 .3508 .84575 .3252 Mtetra
.664 .741 .908 r
.84575 .3252 .86324 .3508 .90633 .33702 .88931 .31104 Mtetra
.27431 .48191 .29746 .50347 .33318 .49186 .31031 .47 Mtetra
.31031 .47 .33318 .49186 .36938 .48009 .34682 .45793 Mtetra
.34682 .45793 .36938 .48009 .40608 .46816 .38383 .44569 Mtetra
.64 .141 0 r
.38383 .44569 .40608 .46816 .44329 .45606 .41958 .48947 Mtetra
.762 .895 .493 r
.41958 .48947 .44329 .45606 .48043 .48682 .45943 .42069 Mtetra
.625 .529 .726 r
.45943 .42069 .48043 .48682 .51926 .43136 .49803 .40793 Mtetra
.664 .741 .908 r
.49803 .40793 .51926 .43136 .55806 .41874 .53718 .39498 Mtetra
.53718 .39498 .55806 .41874 .5974 .40595 .5769 .38185 Mtetra
.5769 .38185 .5974 .40595 .63731 .39297 .6172 .36852 Mtetra
.6172 .36852 .63731 .39297 .6778 .37981 .65808 .355 Mtetra
.65808 .355 .6778 .37981 .71887 .36646 .69957 .34128 Mtetra
0 0 .503 r
.69957 .34128 .71887 .36646 .76054 .35291 .74643 .39655 Mtetra
0 0 0 r
.74643 .39655 .76054 .35291 .80822 .40044 .7844 .31323 Mtetra
.614 .495 .695 r
.7844 .31323 .80822 .40044 .84575 .3252 .82778 .29889 Mtetra
.664 .741 .908 r
.82778 .29889 .84575 .3252 .88931 .31104 .87181 .28433 Mtetra
.25056 .4598 .27431 .48191 .31031 .47 .28686 .44759 Mtetra
.28686 .44759 .31031 .47 .34682 .45793 .32368 .4352 Mtetra
.32368 .4352 .34682 .45793 .38383 .44569 .36101 .42264 Mtetra
.621 .122 0 r
.36101 .42264 .38383 .44569 .41958 .48947 .39671 .46524 Mtetra
.876 .759 .729 r
.39671 .46524 .41958 .48947 .45943 .42069 .43727 .39699 Mtetra
.664 .741 .908 r
.43727 .39699 .45943 .42069 .49803 .40793 .47623 .38388 Mtetra
.47623 .38388 .49803 .40793 .53718 .39498 .51575 .37059 Mtetra
.51575 .37059 .53718 .39498 .5769 .38185 .55585 .3571 Mtetra
.55585 .3571 .5769 .38185 .6172 .36852 .59653 .34341 Mtetra
.59653 .34341 .6172 .36852 .65808 .355 .63782 .32952 Mtetra
.63782 .32952 .65808 .355 .69957 .34128 .67973 .31542 Mtetra
0 .294 .788 r
.67973 .31542 .69957 .34128 .74643 .39655 .72516 .34683 Mtetra
.811 .676 .716 r
.72516 .34683 .74643 .39655 .7844 .31323 .76545 .28658 Mtetra
.664 .741 .908 r
.76545 .28658 .7844 .31323 .82778 .29889 .80929 .27183 Mtetra
.80929 .27183 .82778 .29889 .87181 .28433 .85381 .25686 Mtetra
.2262 .43712 .25056 .4598 .28686 .44759 .26281 .42459 Mtetra
0 .094 .589 r
.26281 .42459 .28686 .44759 .32368 .4352 .297 .45395 Mtetra
.879 .988 .723 r
.297 .45395 .32368 .4352 .36101 .42264 .33758 .39899 Mtetra
.664 .741 .908 r
.33758 .39899 .36101 .42264 .39671 .46524 .37578 .38591 Mtetra
.613 .501 .702 r
.37578 .38591 .39671 .46524 .43727 .39699 .41453 .37264 Mtetra
.664 .741 .908 r
.41453 .37264 .43727 .39699 .47623 .38388 .45384 .35918 Mtetra
.45384 .35918 .47623 .38388 .51575 .37059 .49373 .34553 Mtetra
.49373 .34553 .51575 .37059 .55585 .3571 .53422 .33167 Mtetra
.53422 .33167 .55585 .3571 .59653 .34341 .5753 .3176 Mtetra
0 .251 .753 r
.5753 .3176 .59653 .34341 .63782 .32952 .61835 .34903 Mtetra
.762 .926 .564 r
.61835 .34903 .63782 .32952 .67973 .31542 .65934 .28883 Mtetra
.664 .741 .908 r
.65934 .28883 .67973 .31542 .72516 .34683 .70232 .27412 Mtetra
.621 .525 .724 r
.70232 .27412 .72516 .34683 .76545 .28658 .74597 .25918 Mtetra
.664 .741 .908 r
.74597 .25918 .76545 .28658 .80929 .27183 .79028 .244 Mtetra
.79028 .244 .80929 .27183 .85381 .25686 .83529 .22859 Mtetra
.2012 .41384 .2262 .43712 .26281 .42459 .23811 .40098 Mtetra
0 .304 .777 r
.23811 .40098 .26281 .42459 .297 .45395 .27289 .42215 Mtetra
.814 .721 .763 r
.27289 .42215 .297 .45395 .33758 .39899 .31353 .3747 Mtetra
.664 .741 .908 r
.31353 .3747 .33758 .39899 .37578 .38591 .35207 .36127 Mtetra
.35207 .36127 .37578 .38591 .41453 .37264 .39117 .34764 Mtetra
.39117 .34764 .41453 .37264 .45384 .35918 .43084 .33381 Mtetra
.43084 .33381 .45384 .35918 .49373 .34553 .47111 .31978 Mtetra
.47111 .31978 .49373 .34553 .53422 .33167 .51199 .30554 Mtetra
.51199 .30554 .53422 .33167 .5753 .3176 .55348 .29108 Mtetra
0 .189 .704 r
.55348 .29108 .5753 .3176 .61835 .34903 .59674 .32604 Mtetra
.898 .809 .752 r
.59674 .32604 .61835 .34903 .65934 .28883 .63837 .26149 Mtetra
.664 .741 .908 r
.63837 .26149 .65934 .28883 .70232 .27412 .68181 .24635 Mtetra
.68181 .24635 .70232 .27412 .74597 .25918 .72592 .23098 Mtetra
.72592 .23098 .74597 .25918 .79028 .244 .77072 .21537 Mtetra
.77072 .21537 .79028 .244 .83529 .22859 .81623 .19951 Mtetra
0 .296 .769 r
.17555 .38995 .2012 .41384 .23811 .40098 .20946 .41058 Mtetra
.889 .982 .815 r
.20946 .41058 .23811 .40098 .27289 .42215 .25052 .36335 Mtetra
.628 .554 .752 r
.25052 .36335 .27289 .42215 .31353 .3747 .28883 .34975 Mtetra
.664 .741 .908 r
.28883 .34975 .31353 .3747 .35207 .36127 .32771 .33595 Mtetra
.32771 .33595 .35207 .36127 .39117 .34764 .36716 .32195 Mtetra
.36716 .32195 .39117 .34764 .43084 .33381 .40721 .30774 Mtetra
.40721 .30774 .43084 .33381 .47111 .31978 .44786 .29331 Mtetra
.44786 .29331 .47111 .31978 .51199 .30554 .48913 .27867 Mtetra
0 .339 .816 r
.48913 .27867 .51199 .30554 .55348 .29108 .53112 .3036 Mtetra
.843 .985 .707 r
.53112 .3036 .55348 .29108 .59674 .32604 .57359 .2487 Mtetra
.615 .514 .716 r
.57359 .2487 .59674 .32604 .63837 .26149 .6168 .23336 Mtetra
.664 .741 .908 r
.6168 .23336 .63837 .26149 .68181 .24635 .6607 .21779 Mtetra
.6607 .21779 .68181 .24635 .72592 .23098 .70528 .20196 Mtetra
.70528 .20196 .72592 .23098 .77072 .21537 .75058 .18589 Mtetra
.75058 .18589 .77072 .21537 .81623 .19951 .79661 .16955 Mtetra
0 .356 .815 r
.1492 .36542 .17555 .38995 .20946 .41058 .18334 .38361 Mtetra
.822 .749 .783 r
.18334 .38361 .20946 .41058 .25052 .36335 .2248 .33809 Mtetra
.664 .741 .908 r
.2248 .33809 .25052 .36335 .28883 .34975 .26345 .32412 Mtetra
.26345 .32412 .28883 .34975 .32771 .33595 .30267 .30994 Mtetra
.30267 .30994 .32771 .33595 .36716 .32195 .34249 .29555 Mtetra
.34249 .29555 .36716 .32195 .40721 .30774 .38291 .28094 Mtetra
.38291 .28094 .40721 .30774 .44786 .29331 .42395 .2661 Mtetra
.42395 .2661 .44786 .29331 .48913 .27867 .46563 .25104 Mtetra
.112 .453 .885 r
.46563 .25104 .48913 .27867 .53112 .3036 .50777 .26887 Mtetra
.823 .743 .777 r
.50777 .26887 .53112 .3036 .57359 .2487 .55094 .2202 Mtetra
.664 .741 .908 r
.55094 .2202 .57359 .2487 .6168 .23336 .5946 .20441 Mtetra
.5946 .20441 .6168 .23336 .6607 .21779 .63897 .18838 Mtetra
.63897 .18838 .6607 .21779 .70528 .20196 .68404 .17208 Mtetra
.68404 .17208 .70528 .20196 .75058 .18589 .72984 .15553 Mtetra
.72984 .15553 .75058 .18589 .79661 .16955 .77639 .1387 Mtetra
.842 .922 .886 r
.11941 .36165 .1492 .36542 .18334 .38361 .15997 .32628 Mtetra
.628 .562 .761 r
.15997 .32628 .18334 .38361 .2248 .33809 .19838 .31214 Mtetra
.664 .741 .908 r
.19838 .31214 .2248 .33809 .26345 .32412 .23736 .29778 Mtetra
.23736 .29778 .26345 .32412 .30267 .30994 .27694 .2832 Mtetra
.27694 .2832 .30267 .30994 .34249 .29555 .31712 .2684 Mtetra
.31712 .2684 .34249 .29555 .38291 .28094 .35792 .25337 Mtetra
.35792 .25337 .38291 .28094 .42395 .2661 .39936 .23811 Mtetra
.259 .549 .927 r
.39936 .23811 .42395 .2661 .46563 .25104 .44073 .2487 Mtetra
.858 .972 .864 r
.44073 .2487 .46563 .25104 .50777 .26887 .48419 .20686 Mtetra
.627 .56 .76 r
.48419 .20686 .50777 .26887 .55094 .2202 .52762 .19086 Mtetra
.664 .741 .908 r
.52762 .19086 .55094 .2202 .5946 .20441 .57175 .17461 Mtetra
.57175 .17461 .5946 .20441 .63897 .18838 .61659 .15809 Mtetra
.61659 .15809 .63897 .18838 .68404 .17208 .66216 .14131 Mtetra
.66216 .14131 .68404 .17208 .72984 .15553 .70847 .12424 Mtetra
.70847 .12424 .72984 .15553 .77639 .1387 .75556 .1069 Mtetra
.749 .714 .819 r
.09233 .32882 .11941 .36165 .15997 .32628 .13248 .3 Mtetra
.664 .741 .908 r
.13248 .3 .15997 .32628 .19838 .31214 .17121 .28546 Mtetra
.17121 .28546 .19838 .31214 .23736 .29778 .21054 .27069 Mtetra
.21054 .27069 .23736 .29778 .27694 .2832 .25047 .2557 Mtetra
.25047 .2557 .27694 .2832 .31712 .2684 .29103 .24047 Mtetra
.29103 .24047 .31712 .2684 .35792 .25337 .33221 .225 Mtetra
.33221 .225 .35792 .25337 .39936 .23811 .37405 .2093 Mtetra
.444 .65 .946 r
.37405 .2093 .39936 .23811 .44073 .2487 .41594 .21024 Mtetra
.755 .712 .812 r
.41594 .21024 .44073 .2487 .48419 .20686 .45973 .17712 Mtetra
.664 .741 .908 r
.45973 .17712 .48419 .20686 .52762 .19086 .50361 .16065 Mtetra
.50361 .16065 .52762 .19086 .57175 .17461 .5482 .14391 Mtetra
.5482 .14391 .57175 .17461 .61659 .15809 .59353 .12689 Mtetra
.59353 .12689 .61659 .15809 .66216 .14131 .6396 .10959 Mtetra
.6396 .10959 .66216 .14131 .70847 .12424 .68645 .092 Mtetra
.68645 .092 .70847 .12424 .75556 .1069 .73408 .07411 Mtetra
.648 .642 .831 r
.06574 .28771 .09233 .32882 .13248 .3 .10421 .27298 Mtetra
.664 .741 .908 r
.10421 .27298 .13248 .3 .17121 .28546 .14328 .25802 Mtetra
.14328 .25802 .17121 .28546 .21054 .27069 .18295 .24283 Mtetra
.18295 .24283 .21054 .27069 .25047 .2557 .22324 .2274 Mtetra
.22324 .2274 .25047 .2557 .29103 .24047 .26417 .21173 Mtetra
.26417 .21173 .29103 .24047 .33221 .225 .30575 .19581 Mtetra
.559 .703 .937 r
.30575 .19581 .33221 .225 .37405 .2093 .34745 .18888 Mtetra
.75 .837 .918 r
.34745 .18888 .37405 .2093 .41594 .21024 .39091 .1632 Mtetra
.645 .631 .822 r
.39091 .1632 .41594 .21024 .45973 .17712 .43453 .1465 Mtetra
.664 .741 .908 r
.43453 .1465 .45973 .17712 .50361 .16065 .47887 .12952 Mtetra
.47887 .12952 .50361 .16065 .5482 .14391 .52394 .11227 Mtetra
.52394 .11227 .5482 .14391 .59353 .12689 .56976 .09472 Mtetra
.56976 .09472 .59353 .12689 .6396 .10959 .61635 .07688 Mtetra
.61635 .07688 .6396 .10959 .68645 .092 .66373 .05874 Mtetra
.66373 .05874 .68645 .092 .73408 .07411 .71192 .04029 Mtetra
.03634 .26033 .06574 .28771 .10421 .27298 .07513 .24518 Mtetra
.07513 .24518 .10421 .27298 .14328 .25802 .11454 .22979 Mtetra
.11454 .22979 .14328 .25802 .18295 .24283 .15456 .21416 Mtetra
.15456 .21416 .18295 .24283 .22324 .2274 .19522 .19828 Mtetra
.19522 .19828 .22324 .2274 .26417 .21173 .23652 .18214 Mtetra
.23652 .18214 .26417 .21173 .30575 .19581 .2785 .16575 Mtetra
.652 .738 .912 r
.2785 .16575 .30575 .19581 .34745 .18888 .32107 .1503 Mtetra
.665 .688 .862 r
.32107 .1503 .34745 .18888 .39091 .1632 .3645 .13215 Mtetra
.664 .741 .908 r
.3645 .13215 .39091 .1632 .43453 .1465 .40857 .11494 Mtetra
.40857 .11494 .43453 .1465 .47887 .12952 .45337 .09744 Mtetra
.45337 .09744 .47887 .12952 .52394 .11227 .49893 .07965 Mtetra
.49893 .07965 .52394 .11227 .56976 .09472 .54525 .06155 Mtetra
.54525 .06155 .56976 .09472 .61635 .07688 .59236 .04315 Mtetra
.59236 .04315 .61635 .07688 .66373 .05874 .64029 .02443 Mtetra
.612 .719 .921 r
.64029 .02443 .66373 .05874 .71192 .04029 .68937 .01097 Mtetra
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.19579 .19302 m
.20033 .19776 L
s
[(5)] .18671 .18355 .95953 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(10)] .40046 .09948 .82054 1 Mshowa
.64007 .01906 m
.64377 .02448 L
s
[(15)] .63268 .00821 .68154 1 Mshowa
.125 Mabswid
.23703 .17687 m
.23971 .17975 L
s
.27893 .16047 m
.28157 .16339 L
s
.32151 .14379 m
.32411 .14675 L
s
.36479 .12685 m
.36734 .12985 L
s
.4535 .09211 m
.45595 .0952 L
s
.49897 .07431 m
.50137 .07743 L
s
.54521 .0562 m
.54755 .05937 L
s
.59224 .03779 m
.59452 .041 L
s
.1552 .20892 m
.15797 .21172 L
s
.11524 .22456 m
.11804 .22733 L
s
.0759 .23997 m
.07874 .24269 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -11 0 ]
[.5 .82364 11 12.5625 ]
[.18671 .18355 -5.87859 -9 ]
[.18671 .18355 .12141 0 ]
[.40046 .09948 -10.9232 -9 ]
[.40046 .09948 1.07679 0 ]
[.63268 .00821 -10.0892 -9 ]
[.63268 .00821 1.91076 0 ]
[.78828 .12893 0 -6.13096 ]
[.78828 .12893 6 2.86904 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 12 3.00782 ]
[.96661 .40202 0 -5.87517 ]
[.96661 .40202 12 3.12483 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01433 .32643 -18 -2.79418 ]
[.01433 .32643 0 6.20582 ]
[.00415 .39025 -24 -2.84837 ]
[.00415 .39025 0 6.15163 ]
[-0.00646 .45672 -24 -2.90504 ]
[-0.00646 .45672 0 6.09496 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.19579 .19302 m
.20033 .19776 L
s
[(5)] .18671 .18355 .95953 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(10)] .40046 .09948 .82054 1 Mshowa
.64007 .01906 m
.64377 .02448 L
s
[(15)] .63268 .00821 .68154 1 Mshowa
.125 Mabswid
.23703 .17687 m
.23971 .17975 L
s
.27893 .16047 m
.28157 .16339 L
s
.32151 .14379 m
.32411 .14675 L
s
.36479 .12685 m
.36734 .12985 L
s
.4535 .09211 m
.45595 .0952 L
s
.49897 .07431 m
.50137 .07743 L
s
.54521 .0562 m
.54755 .05937 L
s
.59224 .03779 m
.59452 .041 L
s
.1552 .20892 m
.15797 .21172 L
s
.11524 .22456 m
.11804 .22733 L
s
.0759 .23997 m
.07874 .24269 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.77594 .1334 m
.76978 .13563 L
s
[(5)] .78828 .12893 -1 .36244 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(10)] .88369 .27502 -1 .3316 Mshowa
.95406 .40586 m
.94779 .40778 L
s
[(15)] .96661 .40202 -1 .30559 Mshowa
.125 Mabswid
.79613 .16428 m
.79242 .1656 L
s
.81573 .19425 m
.81201 .19555 L
s
.83476 .22337 m
.83104 .22465 L
s
.85326 .25166 m
.84953 .25292 L
s
.88871 .30589 m
.88497 .30711 L
s
.90572 .33191 m
.90197 .33311 L
s
.92227 .35722 m
.91851 .3584 L
s
.93838 .38186 m
.93462 .38303 L
s
.75514 .10158 m
.75145 .10294 L
s
.73369 .06877 m
.73001 .07015 L
s
.71157 .03492 m
.70789 .03634 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.0266 .32178 m
.03273 .31946 L
s
[(500)] .01433 .32643 1 -0.37907 Mshowa
.01646 .38573 m
.02262 .38347 L
s
[(1000)] .00415 .39025 1 -0.36703 Mshowa
.00591 .45233 m
.01209 .45014 L
s
[(1500)] -0.00646 .45672 1 -0.35443 Mshowa
.125 Mabswid
.03442 .27243 m
.03809 .27101 L
s
.03249 .28462 m
.03616 .2832 L
s
.03054 .29691 m
.03422 .2955 L
s
.02858 .3093 m
.03226 .30789 L
s
.0246 .33437 m
.02829 .33298 L
s
.02259 .34705 m
.02628 .34567 L
s
.02057 .35984 m
.02426 .35847 L
s
.01852 .37273 m
.02222 .37137 L
s
.01439 .39883 m
.01809 .39748 L
s
.01229 .41204 m
.016 .4107 L
s
.01018 .42536 m
.01389 .42403 L
s
.00806 .43879 m
.01176 .43747 L
s
.00375 .46599 m
.00746 .46468 L
s
.00156 .47976 m
.00528 .47846 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.38461 .58461 .40512 .60371 .43942 .59342 .41918 .57408 Mtetra
.41918 .57408 .43942 .59342 .47416 .583 .45421 .56341 Mtetra
.45421 .56341 .47416 .583 .50935 .57244 .48969 .55259 Mtetra
.48969 .55259 .50935 .57244 .54499 .56175 .52564 .54164 Mtetra
.52564 .54164 .54499 .56175 .58111 .55092 .56207 .53054 Mtetra
.56207 .53054 .58111 .55092 .61769 .53994 .59898 .51929 Mtetra
0 .043 .56 r
.59898 .51929 .61769 .53994 .6628 .73621 .63806 .55799 Mtetra
.668 .481 .623 r
.63806 .55799 .6628 .73621 .69233 .51755 .67429 .49634 Mtetra
.664 .741 .908 r
.67429 .49634 .69233 .51755 .73041 .50613 .71272 .48463 Mtetra
.71272 .48463 .73041 .50613 .76899 .49455 .75168 .47276 Mtetra
.75168 .47276 .76899 .49455 .80811 .48282 .79117 .46073 Mtetra
.79117 .46073 .80811 .48282 .84775 .47092 .83121 .44853 Mtetra
.83121 .44853 .84775 .47092 .88795 .45886 .87181 .43616 Mtetra
.87181 .43616 .88795 .45886 .92871 .44664 .91298 .42361 Mtetra
0 0 .543 r
.91298 .42361 .92871 .44664 .97089 .44052 .96467 .48561 Mtetra
.664 .741 .908 r
.36361 .56506 .38461 .58461 .41918 .57408 .39846 .55427 Mtetra
.39846 .55427 .41918 .57408 .45421 .56341 .43377 .54333 Mtetra
.43377 .54333 .45421 .56341 .48969 .55259 .46955 .53226 Mtetra
.46955 .53226 .48969 .55259 .52564 .54164 .50581 .52103 Mtetra
.50581 .52103 .52564 .54164 .56207 .53054 .54255 .50966 Mtetra
.627 .138 0 r
.54255 .50966 .56207 .53054 .59898 .51929 .58077 .55708 Mtetra
0 0 0 r
.58077 .55708 .59898 .51929 .63806 .55799 .61754 .48645 Mtetra
.625 .516 .71 r
.61754 .48645 .63806 .55799 .67429 .49634 .6558 .4746 Mtetra
.664 .741 .908 r
.6558 .4746 .67429 .49634 .71272 .48463 .69459 .46259 Mtetra
.69459 .46259 .71272 .48463 .75168 .47276 .73392 .45042 Mtetra
.73392 .45042 .75168 .47276 .79117 .46073 .77379 .43807 Mtetra
.77379 .43807 .79117 .46073 .83121 .44853 .81423 .42556 Mtetra
.81423 .42556 .83121 .44853 .87181 .43616 .85524 .41286 Mtetra
.1 .421 .867 r
.85524 .41286 .87181 .43616 .91298 .42361 .90122 .43797 Mtetra
.609 .839 .459 r
.90122 .43797 .91298 .42361 .96467 .48561 .93903 .38692 Mtetra
.664 .741 .908 r
.34209 .54503 .36361 .56506 .39846 .55427 .37723 .53397 Mtetra
.37723 .53397 .39846 .55427 .43377 .54333 .41284 .52277 Mtetra
.41284 .52277 .43377 .54333 .46955 .53226 .44892 .51142 Mtetra
.44892 .51142 .46955 .53226 .50581 .52103 .48549 .49991 Mtetra
.48549 .49991 .50581 .52103 .54255 .50966 .52255 .48825 Mtetra
.784 .317 0 r
.52255 .48825 .54255 .50966 .58077 .55708 .56093 .55152 Mtetra
.953 .836 .69 r
.56093 .55152 .58077 .55708 .61754 .48645 .59822 .46445 Mtetra
.664 .741 .908 r
.59822 .46445 .61754 .48645 .6558 .4746 .63683 .4523 Mtetra
.63683 .4523 .6558 .4746 .69459 .46259 .67599 .43998 Mtetra
.67599 .43998 .69459 .46259 .73392 .45042 .71569 .42749 Mtetra
.71569 .42749 .73392 .45042 .77379 .43807 .75596 .41482 Mtetra
.75596 .41482 .77379 .43807 .81423 .42556 .79681 .40198 Mtetra
.79681 .40198 .81423 .42556 .85524 .41286 .83823 .38894 Mtetra
0 .349 .826 r
.83823 .38894 .85524 .41286 .90122 .43797 .88511 .41936 Mtetra
.908 .845 .77 r
.88511 .41936 .90122 .43797 .93903 .38692 .9229 .36231 Mtetra
.664 .741 .908 r
.32005 .5245 .34209 .54503 .37723 .53397 .35548 .51317 Mtetra
.35548 .51317 .37723 .53397 .41284 .52277 .39138 .50169 Mtetra
.39138 .50169 .41284 .52277 .44892 .51142 .42777 .49006 Mtetra
.42777 .49006 .44892 .51142 .48549 .49991 .46465 .47826 Mtetra
.789 .319 0 r
.46465 .47826 .48549 .49991 .52255 .48825 .50154 .53896 Mtetra
0 0 0 r
.50154 .53896 .52255 .48825 .56093 .55152 .53996 .45418 Mtetra
.61 .476 .674 r
.53996 .45418 .56093 .55152 .59822 .46445 .57839 .44189 Mtetra
.664 .741 .908 r
.57839 .44189 .59822 .46445 .63683 .4523 .61737 .42943 Mtetra
.61737 .42943 .63683 .4523 .67599 .43998 .6569 .41679 Mtetra
.6569 .41679 .67599 .43998 .71569 .42749 .69699 .40396 Mtetra
.69699 .40396 .71569 .42749 .75596 .41482 .73766 .39096 Mtetra
.73766 .39096 .75596 .41482 .79681 .40198 .77892 .37777 Mtetra
0 .12 .654 r
.77892 .37777 .79681 .40198 .83823 .38894 .82622 .42312 Mtetra
0 0 0 r
.82622 .42312 .83823 .38894 .88511 .41936 .86324 .3508 Mtetra
.627 .531 .726 r
.86324 .3508 .88511 .41936 .9229 .36231 .90633 .33702 Mtetra
.664 .741 .908 r
.29746 .50347 .32005 .5245 .35548 .51317 .33318 .49186 Mtetra
.33318 .49186 .35548 .51317 .39138 .50169 .36938 .48009 Mtetra
.36938 .48009 .39138 .50169 .42777 .49006 .40608 .46816 Mtetra
.40608 .46816 .42777 .49006 .46465 .47826 .44329 .45606 Mtetra
0 .111 .618 r
.44329 .45606 .46465 .47826 .50154 .53896 .48041 .48848 Mtetra
.788 .648 .707 r
.48041 .48848 .50154 .53896 .53996 .45418 .51926 .43136 Mtetra
.664 .741 .908 r
.51926 .43136 .53996 .45418 .57839 .44189 .55806 .41874 Mtetra
.55806 .41874 .57839 .44189 .61737 .42943 .5974 .40595 Mtetra
.5974 .40595 .61737 .42943 .6569 .41679 .63731 .39297 Mtetra
.63731 .39297 .6569 .41679 .69699 .40396 .6778 .37981 Mtetra
.6778 .37981 .69699 .40396 .73766 .39096 .71887 .36646 Mtetra
.71887 .36646 .73766 .39096 .77892 .37777 .76054 .35291 Mtetra
0 .064 .604 r
.76054 .35291 .77892 .37777 .82622 .42312 .80841 .40255 Mtetra
.935 .821 .709 r
.80841 .40255 .82622 .42312 .86324 .3508 .84575 .3252 Mtetra
.664 .741 .908 r
.84575 .3252 .86324 .3508 .90633 .33702 .88931 .31104 Mtetra
.27431 .48191 .29746 .50347 .33318 .49186 .31031 .47 Mtetra
.31031 .47 .33318 .49186 .36938 .48009 .34682 .45793 Mtetra
.34682 .45793 .36938 .48009 .40608 .46816 .38383 .44569 Mtetra
.652 .154 0 r
.38383 .44569 .40608 .46816 .44329 .45606 .41955 .49029 Mtetra
.757 .889 .483 r
.41955 .49029 .44329 .45606 .48041 .48848 .45943 .42069 Mtetra
.623 .525 .722 r
.45943 .42069 .48041 .48848 .51926 .43136 .49803 .40793 Mtetra
.664 .741 .908 r
.49803 .40793 .51926 .43136 .55806 .41874 .53718 .39498 Mtetra
.53718 .39498 .55806 .41874 .5974 .40595 .5769 .38185 Mtetra
.5769 .38185 .5974 .40595 .63731 .39297 .6172 .36852 Mtetra
.6172 .36852 .63731 .39297 .6778 .37981 .65808 .355 Mtetra
.65808 .355 .6778 .37981 .71887 .36646 .69957 .34128 Mtetra
0 .005 .545 r
.69957 .34128 .71887 .36646 .76054 .35291 .74619 .39303 Mtetra
0 0 0 r
.74619 .39303 .76054 .35291 .80841 .40255 .7844 .31323 Mtetra
.613 .492 .691 r
.7844 .31323 .80841 .40255 .84575 .3252 .82778 .29889 Mtetra
.664 .741 .908 r
.82778 .29889 .84575 .3252 .88931 .31104 .87181 .28433 Mtetra
.25056 .4598 .27431 .48191 .31031 .47 .28686 .44759 Mtetra
.28686 .44759 .31031 .47 .34682 .45793 .32368 .4352 Mtetra
.32368 .4352 .34682 .45793 .38383 .44569 .36101 .42264 Mtetra
.645 .147 0 r
.36101 .42264 .38383 .44569 .41955 .49029 .39665 .46678 Mtetra
.88 .762 .727 r
.39665 .46678 .41955 .49029 .45943 .42069 .43727 .39699 Mtetra
.664 .741 .908 r
.43727 .39699 .45943 .42069 .49803 .40793 .47623 .38388 Mtetra
.47623 .38388 .49803 .40793 .53718 .39498 .51575 .37059 Mtetra
.51575 .37059 .53718 .39498 .5769 .38185 .55585 .3571 Mtetra
.55585 .3571 .5769 .38185 .6172 .36852 .59653 .34341 Mtetra
.59653 .34341 .6172 .36852 .65808 .355 .63782 .32952 Mtetra
.63782 .32952 .65808 .355 .69957 .34128 .67973 .31542 Mtetra
0 .283 .78 r
.67973 .31542 .69957 .34128 .74619 .39303 .72521 .34758 Mtetra
.824 .695 .721 r
.72521 .34758 .74619 .39303 .7844 .31323 .76545 .28658 Mtetra
.664 .741 .908 r
.76545 .28658 .7844 .31323 .82778 .29889 .80929 .27183 Mtetra
.80929 .27183 .82778 .29889 .87181 .28433 .85381 .25686 Mtetra
.2262 .43712 .25056 .4598 .28686 .44759 .26281 .42459 Mtetra
0 .2 .689 r
.26281 .42459 .28686 .44759 .32368 .4352 .29729 .44987 Mtetra
.883 .992 .763 r
.29729 .44987 .32368 .4352 .36101 .42264 .33758 .39899 Mtetra
.664 .741 .908 r
.33758 .39899 .36101 .42264 .39665 .46678 .37578 .38591 Mtetra
.612 .498 .7 r
.37578 .38591 .39665 .46678 .43727 .39699 .41453 .37264 Mtetra
.664 .741 .908 r
.41453 .37264 .43727 .39699 .47623 .38388 .45384 .35918 Mtetra
.45384 .35918 .47623 .38388 .51575 .37059 .49373 .34553 Mtetra
.49373 .34553 .51575 .37059 .55585 .3571 .53422 .33167 Mtetra
.53422 .33167 .55585 .3571 .59653 .34341 .5753 .3176 Mtetra
0 .24 .745 r
.5753 .3176 .59653 .34341 .63782 .32952 .61837 .34965 Mtetra
.757 .921 .554 r
.61837 .34965 .63782 .32952 .67973 .31542 .65934 .28883 Mtetra
.664 .741 .908 r
.65934 .28883 .67973 .31542 .72521 .34758 .70232 .27412 Mtetra
.62 .523 .722 r
.70232 .27412 .72521 .34758 .76545 .28658 .74597 .25918 Mtetra
.664 .741 .908 r
.74597 .25918 .76545 .28658 .80929 .27183 .79028 .244 Mtetra
.79028 .244 .80929 .27183 .85381 .25686 .83529 .22859 Mtetra
.2012 .41384 .2262 .43712 .26281 .42459 .23811 .40098 Mtetra
0 .153 .646 r
.23811 .40098 .26281 .42459 .29729 .44987 .27244 .42796 Mtetra
.855 .773 .77 r
.27244 .42796 .29729 .44987 .33758 .39899 .31353 .3747 Mtetra
.664 .741 .908 r
.31353 .3747 .33758 .39899 .37578 .38591 .35207 .36127 Mtetra
.35207 .36127 .37578 .38591 .41453 .37264 .39117 .34764 Mtetra
.39117 .34764 .41453 .37264 .45384 .35918 .43084 .33381 Mtetra
.43084 .33381 .45384 .35918 .49373 .34553 .47111 .31978 Mtetra
.47111 .31978 .49373 .34553 .53422 .33167 .51199 .30554 Mtetra
.51199 .30554 .53422 .33167 .5753 .3176 .55348 .29108 Mtetra
0 .188 .703 r
.55348 .29108 .5753 .3176 .61837 .34965 .59674 .32607 Mtetra
.896 .805 .751 r
.59674 .32607 .61837 .34965 .65934 .28883 .63837 .26149 Mtetra
.664 .741 .908 r
.63837 .26149 .65934 .28883 .70232 .27412 .68181 .24635 Mtetra
.68181 .24635 .70232 .27412 .74597 .25918 .72592 .23098 Mtetra
.72592 .23098 .74597 .25918 .79028 .244 .77072 .21537 Mtetra
.77072 .21537 .79028 .244 .83529 .22859 .81623 .19951 Mtetra
0 .327 .793 r
.17555 .38995 .2012 .41384 .23811 .40098 .20957 .40942 Mtetra
.887 .979 .823 r
.20957 .40942 .23811 .40098 .27244 .42796 .25052 .36335 Mtetra
.622 .536 .736 r
.25052 .36335 .27244 .42796 .31353 .3747 .28883 .34975 Mtetra
.664 .741 .908 r
.28883 .34975 .31353 .3747 .35207 .36127 .32771 .33595 Mtetra
.32771 .33595 .35207 .36127 .39117 .34764 .36716 .32195 Mtetra
.36716 .32195 .39117 .34764 .43084 .33381 .40721 .30774 Mtetra
.40721 .30774 .43084 .33381 .47111 .31978 .44786 .29331 Mtetra
.44786 .29331 .47111 .31978 .51199 .30554 .48913 .27867 Mtetra
0 .307 .793 r
.48913 .27867 .51199 .30554 .55348 .29108 .53112 .30541 Mtetra
.836 .979 .683 r
.53112 .30541 .55348 .29108 .59674 .32607 .57359 .2487 Mtetra
.615 .514 .716 r
.57359 .2487 .59674 .32607 .63837 .26149 .6168 .23336 Mtetra
.664 .741 .908 r
.6168 .23336 .63837 .26149 .68181 .24635 .6607 .21779 Mtetra
.6607 .21779 .68181 .24635 .72592 .23098 .70528 .20196 Mtetra
.70528 .20196 .72592 .23098 .77072 .21537 .75058 .18589 Mtetra
.75058 .18589 .77072 .21537 .81623 .19951 .79661 .16955 Mtetra
0 .386 .837 r
.1492 .36542 .17555 .38995 .20957 .40942 .18347 .38242 Mtetra
.819 .749 .786 r
.18347 .38242 .20957 .40942 .25052 .36335 .2248 .33809 Mtetra
.664 .741 .908 r
.2248 .33809 .25052 .36335 .28883 .34975 .26345 .32412 Mtetra
.26345 .32412 .28883 .34975 .32771 .33595 .30267 .30994 Mtetra
.30267 .30994 .32771 .33595 .36716 .32195 .34249 .29555 Mtetra
.34249 .29555 .36716 .32195 .40721 .30774 .38291 .28094 Mtetra
.38291 .28094 .40721 .30774 .44786 .29331 .42395 .2661 Mtetra
.42395 .2661 .44786 .29331 .48913 .27867 .46563 .25104 Mtetra
.118 .457 .887 r
.46563 .25104 .48913 .27867 .53112 .30541 .50777 .26865 Mtetra
.816 .732 .772 r
.50777 .26865 .53112 .30541 .57359 .2487 .55094 .2202 Mtetra
.664 .741 .908 r
.55094 .2202 .57359 .2487 .6168 .23336 .5946 .20441 Mtetra
.5946 .20441 .6168 .23336 .6607 .21779 .63897 .18838 Mtetra
.63897 .18838 .6607 .21779 .70528 .20196 .68404 .17208 Mtetra
.68404 .17208 .70528 .20196 .75058 .18589 .72984 .15553 Mtetra
.72984 .15553 .75058 .18589 .79661 .16955 .77639 .1387 Mtetra
.844 .924 .885 r
.11937 .36195 .1492 .36542 .18347 .38242 .15997 .32628 Mtetra
.629 .567 .765 r
.15997 .32628 .18347 .38242 .2248 .33809 .19838 .31214 Mtetra
.664 .741 .908 r
.19838 .31214 .2248 .33809 .26345 .32412 .23736 .29778 Mtetra
.23736 .29778 .26345 .32412 .30267 .30994 .27694 .2832 Mtetra
.27694 .2832 .30267 .30994 .34249 .29555 .31712 .2684 Mtetra
.31712 .2684 .34249 .29555 .38291 .28094 .35792 .25337 Mtetra
.35792 .25337 .38291 .28094 .42395 .2661 .39936 .23811 Mtetra
.237 .536 .923 r
.39936 .23811 .42395 .2661 .46563 .25104 .4407 .24965 Mtetra
.861 .976 .858 r
.4407 .24965 .46563 .25104 .50777 .26865 .48419 .20686 Mtetra
.628 .561 .76 r
.48419 .20686 .50777 .26865 .55094 .2202 .52762 .19086 Mtetra
.664 .741 .908 r
.52762 .19086 .55094 .2202 .5946 .20441 .57175 .17461 Mtetra
.57175 .17461 .5946 .20441 .63897 .18838 .61659 .15809 Mtetra
.61659 .15809 .63897 .18838 .68404 .17208 .66216 .14131 Mtetra
.66216 .14131 .68404 .17208 .72984 .15553 .70847 .12424 Mtetra
.70847 .12424 .72984 .15553 .77639 .1387 .75556 .1069 Mtetra
.738 .702 .817 r
.09253 .32738 .11937 .36195 .15997 .32628 .13248 .3 Mtetra
.664 .741 .908 r
.13248 .3 .15997 .32628 .19838 .31214 .17121 .28546 Mtetra
.17121 .28546 .19838 .31214 .23736 .29778 .21054 .27069 Mtetra
.21054 .27069 .23736 .29778 .27694 .2832 .25047 .2557 Mtetra
.25047 .2557 .27694 .2832 .31712 .2684 .29103 .24047 Mtetra
.29103 .24047 .31712 .2684 .35792 .25337 .33221 .225 Mtetra
.33221 .225 .35792 .25337 .39936 .23811 .37405 .2093 Mtetra
.431 .643 .946 r
.37405 .2093 .39936 .23811 .4407 .24965 .41592 .211 Mtetra
.758 .712 .809 r
.41592 .211 .4407 .24965 .48419 .20686 .45973 .17712 Mtetra
.664 .741 .908 r
.45973 .17712 .48419 .20686 .52762 .19086 .50361 .16065 Mtetra
.50361 .16065 .52762 .19086 .57175 .17461 .5482 .14391 Mtetra
.5482 .14391 .57175 .17461 .61659 .15809 .59353 .12689 Mtetra
.59353 .12689 .61659 .15809 .66216 .14131 .6396 .10959 Mtetra
.6396 .10959 .66216 .14131 .70847 .12424 .68645 .092 Mtetra
.68645 .092 .70847 .12424 .75556 .1069 .73408 .07411 Mtetra
.649 .651 .838 r
.06574 .28771 .09253 .32738 .13248 .3 .10421 .27298 Mtetra
.664 .741 .908 r
.10421 .27298 .13248 .3 .17121 .28546 .14328 .25802 Mtetra
.14328 .25802 .17121 .28546 .21054 .27069 .18295 .24283 Mtetra
.18295 .24283 .21054 .27069 .25047 .2557 .22324 .2274 Mtetra
.22324 .2274 .25047 .2557 .29103 .24047 .26417 .21173 Mtetra
.26417 .21173 .29103 .24047 .33221 .225 .30575 .19581 Mtetra
.551 .7 .938 r
.30575 .19581 .33221 .225 .37405 .2093 .34741 .18944 Mtetra
.755 .843 .918 r
.34741 .18944 .37405 .2093 .41592 .211 .39091 .1632 Mtetra
.644 .627 .818 r
.39091 .1632 .41592 .211 .45973 .17712 .43453 .1465 Mtetra
.664 .741 .908 r
.43453 .1465 .45973 .17712 .50361 .16065 .47887 .12952 Mtetra
.47887 .12952 .50361 .16065 .5482 .14391 .52394 .11227 Mtetra
.52394 .11227 .5482 .14391 .59353 .12689 .56976 .09472 Mtetra
.56976 .09472 .59353 .12689 .6396 .10959 .61635 .07688 Mtetra
.61635 .07688 .6396 .10959 .68645 .092 .66373 .05874 Mtetra
.66373 .05874 .68645 .092 .73408 .07411 .71192 .04029 Mtetra
.03634 .26033 .06574 .28771 .10421 .27298 .07513 .24518 Mtetra
.07513 .24518 .10421 .27298 .14328 .25802 .11454 .22979 Mtetra
.11454 .22979 .14328 .25802 .18295 .24283 .15456 .21416 Mtetra
.15456 .21416 .18295 .24283 .22324 .2274 .19522 .19828 Mtetra
.19522 .19828 .22324 .2274 .26417 .21173 .23652 .18214 Mtetra
.23652 .18214 .26417 .21173 .30575 .19581 .2785 .16575 Mtetra
.647 .736 .914 r
.2785 .16575 .30575 .19581 .34741 .18944 .32103 .15081 Mtetra
.669 .689 .86 r
.32103 .15081 .34741 .18944 .39091 .1632 .3645 .13215 Mtetra
.664 .741 .908 r
.3645 .13215 .39091 .1632 .43453 .1465 .40857 .11494 Mtetra
.40857 .11494 .43453 .1465 .47887 .12952 .45337 .09744 Mtetra
.45337 .09744 .47887 .12952 .52394 .11227 .49893 .07965 Mtetra
.49893 .07965 .52394 .11227 .56976 .09472 .54525 .06155 Mtetra
.54525 .06155 .56976 .09472 .61635 .07688 .59236 .04315 Mtetra
.59236 .04315 .61635 .07688 .66373 .05874 .64029 .02443 Mtetra
.609 .717 .922 r
.64029 .02443 .66373 .05874 .71192 .04029 .68939 .01127 Mtetra
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.19579 .19302 m
.20033 .19776 L
s
[(5)] .18671 .18355 .95953 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(10)] .40046 .09948 .82054 1 Mshowa
.64007 .01906 m
.64377 .02448 L
s
[(15)] .63268 .00821 .68154 1 Mshowa
.125 Mabswid
.23703 .17687 m
.23971 .17975 L
s
.27893 .16047 m
.28157 .16339 L
s
.32151 .14379 m
.32411 .14675 L
s
.36479 .12685 m
.36734 .12985 L
s
.4535 .09211 m
.45595 .0952 L
s
.49897 .07431 m
.50137 .07743 L
s
.54521 .0562 m
.54755 .05937 L
s
.59224 .03779 m
.59452 .041 L
s
.1552 .20892 m
.15797 .21172 L
s
.11524 .22456 m
.11804 .22733 L
s
.0759 .23997 m
.07874 .24269 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -11 0 ]
[.5 .82364 11 12.5625 ]
[.18671 .18355 -5.87859 -9 ]
[.18671 .18355 .12141 0 ]
[.40046 .09948 -10.9232 -9 ]
[.40046 .09948 1.07679 0 ]
[.63268 .00821 -10.0892 -9 ]
[.63268 .00821 1.91076 0 ]
[.78828 .12893 0 -6.13096 ]
[.78828 .12893 6 2.86904 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 12 3.00782 ]
[.96661 .40202 0 -5.87517 ]
[.96661 .40202 12 3.12483 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01432 .32651 -24 -2.79424 ]
[.01432 .32651 0 6.20576 ]
[.00412 .3904 -24 -2.8485 ]
[.00412 .3904 0 6.1515 ]
[-0.0065 .45695 -24 -2.90524 ]
[-0.0065 .45695 0 6.09476 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.19579 .19302 m
.20033 .19776 L
s
[(5)] .18671 .18355 .95953 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(10)] .40046 .09948 .82054 1 Mshowa
.64007 .01906 m
.64377 .02448 L
s
[(15)] .63268 .00821 .68154 1 Mshowa
.125 Mabswid
.23703 .17687 m
.23971 .17975 L
s
.27893 .16047 m
.28157 .16339 L
s
.32151 .14379 m
.32411 .14675 L
s
.36479 .12685 m
.36734 .12985 L
s
.4535 .09211 m
.45595 .0952 L
s
.49897 .07431 m
.50137 .07743 L
s
.54521 .0562 m
.54755 .05937 L
s
.59224 .03779 m
.59452 .041 L
s
.1552 .20892 m
.15797 .21172 L
s
.11524 .22456 m
.11804 .22733 L
s
.0759 .23997 m
.07874 .24269 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.77594 .1334 m
.76978 .13563 L
s
[(5)] .78828 .12893 -1 .36244 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(10)] .88369 .27502 -1 .3316 Mshowa
.95406 .40586 m
.94779 .40778 L
s
[(15)] .96661 .40202 -1 .30559 Mshowa
.125 Mabswid
.79613 .16428 m
.79242 .1656 L
s
.81573 .19425 m
.81201 .19555 L
s
.83476 .22337 m
.83104 .22465 L
s
.85326 .25166 m
.84953 .25292 L
s
.88871 .30589 m
.88497 .30711 L
s
.90572 .33191 m
.90197 .33311 L
s
.92227 .35722 m
.91851 .3584 L
s
.93838 .38186 m
.93462 .38303 L
s
.75514 .10158 m
.75145 .10294 L
s
.73369 .06877 m
.73001 .07015 L
s
.71157 .03492 m
.70789 .03634 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02659 .32185 m
.03272 .31953 L
s
[(1000)] .01432 .32651 1 -0.37906 Mshowa
.01644 .38588 m
.0226 .38362 L
s
[(2000)] .00412 .3904 1 -0.367 Mshowa
.00587 .45257 m
.01206 .45038 L
s
[(3000)] -0.0065 .45695 1 -0.35439 Mshowa
.125 Mabswid
.03442 .27244 m
.03809 .27102 L
s
.03248 .28465 m
.03616 .28323 L
s
.03053 .29695 m
.03421 .29554 L
s
.02857 .30936 m
.03225 .30795 L
s
.02459 .33445 m
.02827 .33307 L
s
.02258 .34716 m
.02626 .34578 L
s
.02055 .35996 m
.02424 .35859 L
s
.0185 .37287 m
.0222 .3715 L
s
.01436 .399 m
.01806 .39765 L
s
.01227 .41223 m
.01597 .41089 L
s
.01015 .42556 m
.01386 .42423 L
s
.00802 .43901 m
.01173 .43769 L
s
.00371 .46624 m
.00742 .46493 L
s
.00152 .48003 m
.00524 .47873 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.38461 .58461 .40512 .60371 .43942 .59342 .41918 .57408 Mtetra
.41918 .57408 .43942 .59342 .47416 .583 .45421 .56341 Mtetra
.45421 .56341 .47416 .583 .50935 .57244 .48969 .55259 Mtetra
.48969 .55259 .50935 .57244 .54499 .56175 .52564 .54164 Mtetra
.52564 .54164 .54499 .56175 .58111 .55092 .56207 .53054 Mtetra
.56207 .53054 .58111 .55092 .61769 .53994 .59898 .51929 Mtetra
0 .056 .573 r
.59898 .51929 .61769 .53994 .6628 .73621 .63804 .55728 Mtetra
.667 .48 .623 r
.63804 .55728 .6628 .73621 .69233 .51755 .67429 .49634 Mtetra
.664 .741 .908 r
.67429 .49634 .69233 .51755 .73041 .50613 .71272 .48463 Mtetra
.71272 .48463 .73041 .50613 .76899 .49455 .75168 .47276 Mtetra
.75168 .47276 .76899 .49455 .80811 .48282 .79117 .46073 Mtetra
.79117 .46073 .80811 .48282 .84775 .47092 .83121 .44853 Mtetra
.83121 .44853 .84775 .47092 .88795 .45886 .87181 .43616 Mtetra
.87181 .43616 .88795 .45886 .92871 .44664 .91298 .42361 Mtetra
0 .001 .553 r
.91298 .42361 .92871 .44664 .97077 .43965 .96453 .4846 Mtetra
.664 .741 .908 r
.36361 .56506 .38461 .58461 .41918 .57408 .39846 .55427 Mtetra
.39846 .55427 .41918 .57408 .45421 .56341 .43377 .54333 Mtetra
.43377 .54333 .45421 .56341 .48969 .55259 .46955 .53226 Mtetra
.46955 .53226 .48969 .55259 .52564 .54164 .50581 .52103 Mtetra
.50581 .52103 .52564 .54164 .56207 .53054 .54255 .50966 Mtetra
.63 .141 0 r
.54255 .50966 .56207 .53054 .59898 .51929 .58077 .55727 Mtetra
0 0 0 r
.58077 .55727 .59898 .51929 .63804 .55728 .61754 .48645 Mtetra
.625 .517 .711 r
.61754 .48645 .63804 .55728 .67429 .49634 .6558 .4746 Mtetra
.664 .741 .908 r
.6558 .4746 .67429 .49634 .71272 .48463 .69459 .46259 Mtetra
.69459 .46259 .71272 .48463 .75168 .47276 .73392 .45042 Mtetra
.73392 .45042 .75168 .47276 .79117 .46073 .77379 .43807 Mtetra
.77379 .43807 .79117 .46073 .83121 .44853 .81423 .42556 Mtetra
.81423 .42556 .83121 .44853 .87181 .43616 .85524 .41286 Mtetra
.067 .398 .855 r
.85524 .41286 .87181 .43616 .91298 .42361 .90143 .43976 Mtetra
.578 .807 .412 r
.90143 .43976 .91298 .42361 .96453 .4846 .93903 .38692 Mtetra
.664 .741 .908 r
.34209 .54503 .36361 .56506 .39846 .55427 .37723 .53397 Mtetra
.37723 .53397 .39846 .55427 .43377 .54333 .41284 .52277 Mtetra
.41284 .52277 .43377 .54333 .46955 .53226 .44892 .51142 Mtetra
.44892 .51142 .46955 .53226 .50581 .52103 .48549 .49991 Mtetra
.48549 .49991 .50581 .52103 .54255 .50966 .52255 .48825 Mtetra
.772 .302 0 r
.52255 .48825 .54255 .50966 .58077 .55727 .56091 .54986 Mtetra
.947 .829 .694 r
.56091 .54986 .58077 .55727 .61754 .48645 .59822 .46445 Mtetra
.664 .741 .908 r
.59822 .46445 .61754 .48645 .6558 .4746 .63683 .4523 Mtetra
.63683 .4523 .6558 .4746 .69459 .46259 .67599 .43998 Mtetra
.67599 .43998 .69459 .46259 .73392 .45042 .71569 .42749 Mtetra
.71569 .42749 .73392 .45042 .77379 .43807 .75596 .41482 Mtetra
.75596 .41482 .77379 .43807 .81423 .42556 .79681 .40198 Mtetra
.79681 .40198 .81423 .42556 .85524 .41286 .83823 .38894 Mtetra
0 .336 .818 r
.83823 .38894 .85524 .41286 .90143 .43976 .88522 .42032 Mtetra
.907 .838 .765 r
.88522 .42032 .90143 .43976 .93903 .38692 .9229 .36231 Mtetra
.664 .741 .908 r
.32005 .5245 .34209 .54503 .37723 .53397 .35548 .51317 Mtetra
.35548 .51317 .37723 .53397 .41284 .52277 .39138 .50169 Mtetra
.39138 .50169 .41284 .52277 .44892 .51142 .42777 .49006 Mtetra
.42777 .49006 .44892 .51142 .48549 .49991 .46465 .47826 Mtetra
.791 .322 0 r
.46465 .47826 .48549 .49991 .52255 .48825 .50154 .53922 Mtetra
0 0 0 r
.50154 .53922 .52255 .48825 .56091 .54986 .53996 .45418 Mtetra
.61 .478 .676 r
.53996 .45418 .56091 .54986 .59822 .46445 .57839 .44189 Mtetra
.664 .741 .908 r
.57839 .44189 .59822 .46445 .63683 .4523 .61737 .42943 Mtetra
.61737 .42943 .63683 .4523 .67599 .43998 .6569 .41679 Mtetra
.6569 .41679 .67599 .43998 .71569 .42749 .69699 .40396 Mtetra
.69699 .40396 .71569 .42749 .75596 .41482 .73766 .39096 Mtetra
.73766 .39096 .75596 .41482 .79681 .40198 .77892 .37777 Mtetra
0 .114 .648 r
.77892 .37777 .79681 .40198 .83823 .38894 .82627 .42362 Mtetra
0 0 0 r
.82627 .42362 .83823 .38894 .88522 .42032 .86324 .3508 Mtetra
.627 .529 .724 r
.86324 .3508 .88522 .42032 .9229 .36231 .90633 .33702 Mtetra
.664 .741 .908 r
.29746 .50347 .32005 .5245 .35548 .51317 .33318 .49186 Mtetra
.33318 .49186 .35548 .51317 .39138 .50169 .36938 .48009 Mtetra
.36938 .48009 .39138 .50169 .42777 .49006 .40608 .46816 Mtetra
.40608 .46816 .42777 .49006 .46465 .47826 .44329 .45606 Mtetra
0 .098 .605 r
.44329 .45606 .46465 .47826 .50154 .53922 .4804 .48907 Mtetra
.79 .649 .707 r
.4804 .48907 .50154 .53922 .53996 .45418 .51926 .43136 Mtetra
.664 .741 .908 r
.51926 .43136 .53996 .45418 .57839 .44189 .55806 .41874 Mtetra
.55806 .41874 .57839 .44189 .61737 .42943 .5974 .40595 Mtetra
.5974 .40595 .61737 .42943 .6569 .41679 .63731 .39297 Mtetra
.63731 .39297 .6569 .41679 .69699 .40396 .6778 .37981 Mtetra
.6778 .37981 .69699 .40396 .73766 .39096 .71887 .36646 Mtetra
.71887 .36646 .73766 .39096 .77892 .37777 .76054 .35291 Mtetra
0 .092 .629 r
.76054 .35291 .77892 .37777 .82627 .42362 .80822 .4004 Mtetra
.923 .807 .714 r
.80822 .4004 .82627 .42362 .86324 .3508 .84575 .3252 Mtetra
.664 .741 .908 r
.84575 .3252 .86324 .3508 .90633 .33702 .88931 .31104 Mtetra
.27431 .48191 .29746 .50347 .33318 .49186 .31031 .47 Mtetra
.31031 .47 .33318 .49186 .36938 .48009 .34682 .45793 Mtetra
.34682 .45793 .36938 .48009 .40608 .46816 .38383 .44569 Mtetra
.633 .134 0 r
.38383 .44569 .40608 .46816 .44329 .45606 .41959 .48904 Mtetra
.765 .897 .498 r
.41959 .48904 .44329 .45606 .4804 .48907 .45943 .42069 Mtetra
.623 .524 .721 r
.45943 .42069 .4804 .48907 .51926 .43136 .49803 .40793 Mtetra
.664 .741 .908 r
.49803 .40793 .51926 .43136 .55806 .41874 .53718 .39498 Mtetra
.53718 .39498 .55806 .41874 .5974 .40595 .5769 .38185 Mtetra
.5769 .38185 .5974 .40595 .63731 .39297 .6172 .36852 Mtetra
.6172 .36852 .63731 .39297 .6778 .37981 .65808 .355 Mtetra
.65808 .355 .6778 .37981 .71887 .36646 .69957 .34128 Mtetra
0 0 .523 r
.69957 .34128 .71887 .36646 .76054 .35291 .74631 .39484 Mtetra
0 0 0 r
.74631 .39484 .76054 .35291 .80822 .4004 .7844 .31323 Mtetra
.614 .495 .695 r
.7844 .31323 .80822 .4004 .84575 .3252 .82778 .29889 Mtetra
.664 .741 .908 r
.82778 .29889 .84575 .3252 .88931 .31104 .87181 .28433 Mtetra
.25056 .4598 .27431 .48191 .31031 .47 .28686 .44759 Mtetra
.28686 .44759 .31031 .47 .34682 .45793 .32368 .4352 Mtetra
.32368 .4352 .34682 .45793 .38383 .44569 .36101 .42264 Mtetra
.636 .137 0 r
.36101 .42264 .38383 .44569 .41959 .48904 .39668 .46618 Mtetra
.881 .765 .729 r
.39668 .46618 .41959 .48904 .45943 .42069 .43727 .39699 Mtetra
.664 .741 .908 r
.43727 .39699 .45943 .42069 .49803 .40793 .47623 .38388 Mtetra
.47623 .38388 .49803 .40793 .53718 .39498 .51575 .37059 Mtetra
.51575 .37059 .53718 .39498 .5769 .38185 .55585 .3571 Mtetra
.55585 .3571 .5769 .38185 .6172 .36852 .59653 .34341 Mtetra
.59653 .34341 .6172 .36852 .65808 .355 .63782 .32952 Mtetra
.63782 .32952 .65808 .355 .69957 .34128 .67973 .31542 Mtetra
0 .272 .772 r
.67973 .31542 .69957 .34128 .74631 .39484 .72525 .34831 Mtetra
.823 .691 .718 r
.72525 .34831 .74631 .39484 .7844 .31323 .76545 .28658 Mtetra
.664 .741 .908 r
.76545 .28658 .7844 .31323 .82778 .29889 .80929 .27183 Mtetra
.80929 .27183 .82778 .29889 .87181 .28433 .85381 .25686 Mtetra
.2262 .43712 .25056 .4598 .28686 .44759 .26281 .42459 Mtetra
0 .119 .613 r
.26281 .42459 .28686 .44759 .32368 .4352 .29707 .45297 Mtetra
.88 .989 .733 r
.29707 .45297 .32368 .4352 .36101 .42264 .33758 .39899 Mtetra
.664 .741 .908 r
.33758 .39899 .36101 .42264 .39668 .46618 .37578 .38591 Mtetra
.613 .5 .701 r
.37578 .38591 .39668 .46618 .43727 .39699 .41453 .37264 Mtetra
.664 .741 .908 r
.41453 .37264 .43727 .39699 .47623 .38388 .45384 .35918 Mtetra
.45384 .35918 .47623 .38388 .51575 .37059 .49373 .34553 Mtetra
.49373 .34553 .51575 .37059 .55585 .3571 .53422 .33167 Mtetra
.53422 .33167 .55585 .3571 .59653 .34341 .5753 .3176 Mtetra
0 .236 .742 r
.5753 .3176 .59653 .34341 .63782 .32952 .61838 .34989 Mtetra
.755 .919 .551 r
.61838 .34989 .63782 .32952 .67973 .31542 .65934 .28883 Mtetra
.664 .741 .908 r
.65934 .28883 .67973 .31542 .72525 .34831 .70232 .27412 Mtetra
.62 .521 .721 r
.70232 .27412 .72525 .34831 .76545 .28658 .74597 .25918 Mtetra
.664 .741 .908 r
.74597 .25918 .76545 .28658 .80929 .27183 .79028 .244 Mtetra
.79028 .244 .80929 .27183 .85381 .25686 .83529 .22859 Mtetra
.2012 .41384 .2262 .43712 .26281 .42459 .23811 .40098 Mtetra
0 .186 .676 r
.23811 .40098 .26281 .42459 .29707 .45297 .27254 .42668 Mtetra
.839 .749 .764 r
.27254 .42668 .29707 .45297 .33758 .39899 .31353 .3747 Mtetra
.664 .741 .908 r
.31353 .3747 .33758 .39899 .37578 .38591 .35207 .36127 Mtetra
.35207 .36127 .37578 .38591 .41453 .37264 .39117 .34764 Mtetra
.39117 .34764 .41453 .37264 .45384 .35918 .43084 .33381 Mtetra
.43084 .33381 .45384 .35918 .49373 .34553 .47111 .31978 Mtetra
.47111 .31978 .49373 .34553 .53422 .33167 .51199 .30554 Mtetra
.51199 .30554 .53422 .33167 .5753 .3176 .55348 .29108 Mtetra
0 .207 .718 r
.55348 .29108 .5753 .3176 .61838 .34989 .59671 .32495 Mtetra
.889 .798 .752 r
.59671 .32495 .61838 .34989 .65934 .28883 .63837 .26149 Mtetra
.664 .741 .908 r
.63837 .26149 .65934 .28883 .70232 .27412 .68181 .24635 Mtetra
.68181 .24635 .70232 .27412 .74597 .25918 .72592 .23098 Mtetra
.72592 .23098 .74597 .25918 .79028 .244 .77072 .21537 Mtetra
.77072 .21537 .79028 .244 .83529 .22859 .81623 .19951 Mtetra
0 .341 .804 r
.17555 .38995 .2012 .41384 .23811 .40098 .20962 .40892 Mtetra
.886 .978 .827 r
.20962 .40892 .23811 .40098 .27254 .42668 .25052 .36335 Mtetra
.623 .54 .739 r
.25052 .36335 .27254 .42668 .31353 .3747 .28883 .34975 Mtetra
.664 .741 .908 r
.28883 .34975 .31353 .3747 .35207 .36127 .32771 .33595 Mtetra
.32771 .33595 .35207 .36127 .39117 .34764 .36716 .32195 Mtetra
.36716 .32195 .39117 .34764 .43084 .33381 .40721 .30774 Mtetra
.40721 .30774 .43084 .33381 .47111 .31978 .44786 .29331 Mtetra
.44786 .29331 .47111 .31978 .51199 .30554 .48913 .27867 Mtetra
0 .324 .805 r
.48913 .27867 .51199 .30554 .55348 .29108 .53112 .30447 Mtetra
.84 .982 .695 r
.53112 .30447 .55348 .29108 .59671 .32495 .57359 .2487 Mtetra
.616 .517 .718 r
.57359 .2487 .59671 .32495 .63837 .26149 .6168 .23336 Mtetra
.664 .741 .908 r
.6168 .23336 .63837 .26149 .68181 .24635 .6607 .21779 Mtetra
.6607 .21779 .68181 .24635 .72592 .23098 .70528 .20196 Mtetra
.70528 .20196 .72592 .23098 .77072 .21537 .75058 .18589 Mtetra
.75058 .18589 .77072 .21537 .81623 .19951 .79661 .16955 Mtetra
0 .372 .827 r
.1492 .36542 .17555 .38995 .20962 .40892 .18341 .383 Mtetra
.824 .755 .787 r
.18341 .383 .20962 .40892 .25052 .36335 .2248 .33809 Mtetra
.664 .741 .908 r
.2248 .33809 .25052 .36335 .28883 .34975 .26345 .32412 Mtetra
.26345 .32412 .28883 .34975 .32771 .33595 .30267 .30994 Mtetra
.30267 .30994 .32771 .33595 .36716 .32195 .34249 .29555 Mtetra
.34249 .29555 .36716 .32195 .40721 .30774 .38291 .28094 Mtetra
.38291 .28094 .40721 .30774 .44786 .29331 .42395 .2661 Mtetra
.42395 .2661 .44786 .29331 .48913 .27867 .46563 .25104 Mtetra
.079 .431 .873 r
.46563 .25104 .48913 .27867 .53112 .30447 .50776 .27029 Mtetra
.828 .747 .774 r
.50776 .27029 .53112 .30447 .57359 .2487 .55094 .2202 Mtetra
.664 .741 .908 r
.55094 .2202 .57359 .2487 .6168 .23336 .5946 .20441 Mtetra
.5946 .20441 .6168 .23336 .6607 .21779 .63897 .18838 Mtetra
.63897 .18838 .6607 .21779 .70528 .20196 .68404 .17208 Mtetra
.68404 .17208 .70528 .20196 .75058 .18589 .72984 .15553 Mtetra
.72984 .15553 .75058 .18589 .79661 .16955 .77639 .1387 Mtetra
.841 .921 .886 r
.11943 .36143 .1492 .36542 .18341 .383 .15997 .32628 Mtetra
.629 .565 .763 r
.15997 .32628 .18341 .383 .2248 .33809 .19838 .31214 Mtetra
.664 .741 .908 r
.19838 .31214 .2248 .33809 .26345 .32412 .23736 .29778 Mtetra
.23736 .29778 .26345 .32412 .30267 .30994 .27694 .2832 Mtetra
.27694 .2832 .30267 .30994 .34249 .29555 .31712 .2684 Mtetra
.31712 .2684 .34249 .29555 .38291 .28094 .35792 .25337 Mtetra
.35792 .25337 .38291 .28094 .42395 .2661 .39936 .23811 Mtetra
.28 .561 .931 r
.39936 .23811 .42395 .2661 .46563 .25104 .44075 .24777 Mtetra
.855 .968 .871 r
.44075 .24777 .46563 .25104 .50776 .27029 .48419 .20686 Mtetra
.626 .555 .755 r
.48419 .20686 .50776 .27029 .55094 .2202 .52762 .19086 Mtetra
.664 .741 .908 r
.52762 .19086 .55094 .2202 .5946 .20441 .57175 .17461 Mtetra
.57175 .17461 .5946 .20441 .63897 .18838 .61659 .15809 Mtetra
.61659 .15809 .63897 .18838 .68404 .17208 .66216 .14131 Mtetra
.66216 .14131 .68404 .17208 .72984 .15553 .70847 .12424 Mtetra
.70847 .12424 .72984 .15553 .77639 .1387 .75556 .1069 Mtetra
.751 .717 .82 r
.09231 .32902 .11943 .36143 .15997 .32628 .13248 .3 Mtetra
.664 .741 .908 r
.13248 .3 .15997 .32628 .19838 .31214 .17121 .28546 Mtetra
.17121 .28546 .19838 .31214 .23736 .29778 .21054 .27069 Mtetra
.21054 .27069 .23736 .29778 .27694 .2832 .25047 .2557 Mtetra
.25047 .2557 .27694 .2832 .31712 .2684 .29103 .24047 Mtetra
.29103 .24047 .31712 .2684 .35792 .25337 .33221 .225 Mtetra
.33221 .225 .35792 .25337 .39936 .23811 .37405 .2093 Mtetra
.441 .648 .946 r
.37405 .2093 .39936 .23811 .44075 .24777 .41594 .2104 Mtetra
.759 .719 .816 r
.41594 .2104 .44075 .24777 .48419 .20686 .45973 .17712 Mtetra
.664 .741 .908 r
.45973 .17712 .48419 .20686 .52762 .19086 .50361 .16065 Mtetra
.50361 .16065 .52762 .19086 .57175 .17461 .5482 .14391 Mtetra
.5482 .14391 .57175 .17461 .61659 .15809 .59353 .12689 Mtetra
.59353 .12689 .61659 .15809 .66216 .14131 .6396 .10959 Mtetra
.6396 .10959 .66216 .14131 .70847 .12424 .68645 .092 Mtetra
.68645 .092 .70847 .12424 .75556 .1069 .73408 .07411 Mtetra
.647 .641 .83 r
.06574 .28771 .09231 .32902 .13248 .3 .10421 .27298 Mtetra
.664 .741 .908 r
.10421 .27298 .13248 .3 .17121 .28546 .14328 .25802 Mtetra
.14328 .25802 .17121 .28546 .21054 .27069 .18295 .24283 Mtetra
.18295 .24283 .21054 .27069 .25047 .2557 .22324 .2274 Mtetra
.22324 .2274 .25047 .2557 .29103 .24047 .26417 .21173 Mtetra
.26417 .21173 .29103 .24047 .33221 .225 .30575 .19581 Mtetra
.548 .699 .939 r
.30575 .19581 .33221 .225 .37405 .2093 .3474 .1897 Mtetra
.757 .845 .918 r
.3474 .1897 .37405 .2093 .41594 .2104 .39091 .1632 Mtetra
.645 .63 .821 r
.39091 .1632 .41594 .2104 .45973 .17712 .43453 .1465 Mtetra
.664 .741 .908 r
.43453 .1465 .45973 .17712 .50361 .16065 .47887 .12952 Mtetra
.47887 .12952 .50361 .16065 .5482 .14391 .52394 .11227 Mtetra
.52394 .11227 .5482 .14391 .59353 .12689 .56976 .09472 Mtetra
.56976 .09472 .59353 .12689 .6396 .10959 .61635 .07688 Mtetra
.61635 .07688 .6396 .10959 .68645 .092 .66373 .05874 Mtetra
.66373 .05874 .68645 .092 .73408 .07411 .71192 .04029 Mtetra
.03634 .26033 .06574 .28771 .10421 .27298 .07513 .24518 Mtetra
.07513 .24518 .10421 .27298 .14328 .25802 .11454 .22979 Mtetra
.11454 .22979 .14328 .25802 .18295 .24283 .15456 .21416 Mtetra
.15456 .21416 .18295 .24283 .22324 .2274 .19522 .19828 Mtetra
.19522 .19828 .22324 .2274 .26417 .21173 .23652 .18214 Mtetra
.23652 .18214 .26417 .21173 .30575 .19581 .2785 .16575 Mtetra
.651 .737 .913 r
.2785 .16575 .30575 .19581 .3474 .1897 .32106 .15044 Mtetra
.665 .684 .858 r
.32106 .15044 .3474 .1897 .39091 .1632 .3645 .13215 Mtetra
.664 .741 .908 r
.3645 .13215 .39091 .1632 .43453 .1465 .40857 .11494 Mtetra
.40857 .11494 .43453 .1465 .47887 .12952 .45337 .09744 Mtetra
.45337 .09744 .47887 .12952 .52394 .11227 .49893 .07965 Mtetra
.49893 .07965 .52394 .11227 .56976 .09472 .54525 .06155 Mtetra
.54525 .06155 .56976 .09472 .61635 .07688 .59236 .04315 Mtetra
.59236 .04315 .61635 .07688 .66373 .05874 .64029 .02443 Mtetra
.612 .719 .921 r
.64029 .02443 .66373 .05874 .71192 .04029 .68937 .01096 Mtetra
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.19579 .19302 m
.20033 .19776 L
s
[(5)] .18671 .18355 .95953 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(10)] .40046 .09948 .82054 1 Mshowa
.64007 .01906 m
.64377 .02448 L
s
[(15)] .63268 .00821 .68154 1 Mshowa
.125 Mabswid
.23703 .17687 m
.23971 .17975 L
s
.27893 .16047 m
.28157 .16339 L
s
.32151 .14379 m
.32411 .14675 L
s
.36479 .12685 m
.36734 .12985 L
s
.4535 .09211 m
.45595 .0952 L
s
.49897 .07431 m
.50137 .07743 L
s
.54521 .0562 m
.54755 .05937 L
s
.59224 .03779 m
.59452 .041 L
s
.1552 .20892 m
.15797 .21172 L
s
.11524 .22456 m
.11804 .22733 L
s
.0759 .23997 m
.07874 .24269 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -11 0 ]
[.5 .82364 11 12.5625 ]
[.18671 .18355 -5.87859 -9 ]
[.18671 .18355 .12141 0 ]
[.40046 .09948 -10.9232 -9 ]
[.40046 .09948 1.07679 0 ]
[.63268 .00821 -10.0892 -9 ]
[.63268 .00821 1.91076 0 ]
[.78828 .12893 0 -6.13096 ]
[.78828 .12893 6 2.86904 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 12 3.00782 ]
[.96661 .40202 0 -5.87517 ]
[.96661 .40202 12 3.12483 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01432 .32651 -24 -2.79424 ]
[.01432 .32651 0 6.20576 ]
[.00412 .3904 -24 -2.8485 ]
[.00412 .3904 0 6.1515 ]
[-0.0065 .45695 -24 -2.90524 ]
[-0.0065 .45695 0 6.09476 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.19579 .19302 m
.20033 .19776 L
s
[(5)] .18671 .18355 .95953 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(10)] .40046 .09948 .82054 1 Mshowa
.64007 .01906 m
.64377 .02448 L
s
[(15)] .63268 .00821 .68154 1 Mshowa
.125 Mabswid
.23703 .17687 m
.23971 .17975 L
s
.27893 .16047 m
.28157 .16339 L
s
.32151 .14379 m
.32411 .14675 L
s
.36479 .12685 m
.36734 .12985 L
s
.4535 .09211 m
.45595 .0952 L
s
.49897 .07431 m
.50137 .07743 L
s
.54521 .0562 m
.54755 .05937 L
s
.59224 .03779 m
.59452 .041 L
s
.1552 .20892 m
.15797 .21172 L
s
.11524 .22456 m
.11804 .22733 L
s
.0759 .23997 m
.07874 .24269 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.77594 .1334 m
.76978 .13563 L
s
[(5)] .78828 .12893 -1 .36244 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(10)] .88369 .27502 -1 .3316 Mshowa
.95406 .40586 m
.94779 .40778 L
s
[(15)] .96661 .40202 -1 .30559 Mshowa
.125 Mabswid
.79613 .16428 m
.79242 .1656 L
s
.81573 .19425 m
.81201 .19555 L
s
.83476 .22337 m
.83104 .22465 L
s
.85326 .25166 m
.84953 .25292 L
s
.88871 .30589 m
.88497 .30711 L
s
.90572 .33191 m
.90197 .33311 L
s
.92227 .35722 m
.91851 .3584 L
s
.93838 .38186 m
.93462 .38303 L
s
.75514 .10158 m
.75145 .10294 L
s
.73369 .06877 m
.73001 .07015 L
s
.71157 .03492 m
.70789 .03634 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02659 .32185 m
.03272 .31953 L
s
[(1000)] .01432 .32651 1 -0.37906 Mshowa
.01644 .38588 m
.0226 .38362 L
s
[(2000)] .00412 .3904 1 -0.367 Mshowa
.00587 .45257 m
.01206 .45038 L
s
[(3000)] -0.0065 .45695 1 -0.35439 Mshowa
.125 Mabswid
.03442 .27244 m
.03809 .27102 L
s
.03248 .28465 m
.03616 .28323 L
s
.03053 .29695 m
.03421 .29554 L
s
.02857 .30936 m
.03225 .30795 L
s
.02459 .33445 m
.02827 .33307 L
s
.02258 .34716 m
.02626 .34578 L
s
.02055 .35996 m
.02424 .35859 L
s
.0185 .37287 m
.0222 .3715 L
s
.01436 .399 m
.01806 .39765 L
s
.01227 .41223 m
.01597 .41089 L
s
.01015 .42556 m
.01386 .42423 L
s
.00802 .43901 m
.01173 .43769 L
s
.00371 .46624 m
.00742 .46493 L
s
.00152 .48003 m
.00524 .47873 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.38461 .58461 .40512 .60371 .43942 .59342 .41918 .57408 Mtetra
.41918 .57408 .43942 .59342 .47416 .583 .45421 .56341 Mtetra
.45421 .56341 .47416 .583 .50935 .57244 .48969 .55259 Mtetra
.48969 .55259 .50935 .57244 .54499 .56175 .52564 .54164 Mtetra
.52564 .54164 .54499 .56175 .58111 .55092 .56207 .53054 Mtetra
.56207 .53054 .58111 .55092 .61769 .53994 .59898 .51929 Mtetra
0 .056 .573 r
.59898 .51929 .61769 .53994 .6628 .73621 .63804 .55728 Mtetra
.667 .48 .623 r
.63804 .55728 .6628 .73621 .69233 .51755 .67429 .49634 Mtetra
.664 .741 .908 r
.67429 .49634 .69233 .51755 .73041 .50613 .71272 .48463 Mtetra
.71272 .48463 .73041 .50613 .76899 .49455 .75168 .47276 Mtetra
.75168 .47276 .76899 .49455 .80811 .48282 .79117 .46073 Mtetra
.79117 .46073 .80811 .48282 .84775 .47092 .83121 .44853 Mtetra
.83121 .44853 .84775 .47092 .88795 .45886 .87181 .43616 Mtetra
.87181 .43616 .88795 .45886 .92871 .44664 .91298 .42361 Mtetra
0 .001 .553 r
.91298 .42361 .92871 .44664 .97077 .43965 .96453 .4846 Mtetra
.664 .741 .908 r
.36361 .56506 .38461 .58461 .41918 .57408 .39846 .55427 Mtetra
.39846 .55427 .41918 .57408 .45421 .56341 .43377 .54333 Mtetra
.43377 .54333 .45421 .56341 .48969 .55259 .46955 .53226 Mtetra
.46955 .53226 .48969 .55259 .52564 .54164 .50581 .52103 Mtetra
.50581 .52103 .52564 .54164 .56207 .53054 .54255 .50966 Mtetra
.63 .141 0 r
.54255 .50966 .56207 .53054 .59898 .51929 .58077 .55727 Mtetra
0 0 0 r
.58077 .55727 .59898 .51929 .63804 .55728 .61754 .48645 Mtetra
.625 .517 .711 r
.61754 .48645 .63804 .55728 .67429 .49634 .6558 .4746 Mtetra
.664 .741 .908 r
.6558 .4746 .67429 .49634 .71272 .48463 .69459 .46259 Mtetra
.69459 .46259 .71272 .48463 .75168 .47276 .73392 .45042 Mtetra
.73392 .45042 .75168 .47276 .79117 .46073 .77379 .43807 Mtetra
.77379 .43807 .79117 .46073 .83121 .44853 .81423 .42556 Mtetra
.81423 .42556 .83121 .44853 .87181 .43616 .85524 .41286 Mtetra
.067 .398 .855 r
.85524 .41286 .87181 .43616 .91298 .42361 .90143 .43976 Mtetra
.578 .807 .412 r
.90143 .43976 .91298 .42361 .96453 .4846 .93903 .38692 Mtetra
.664 .741 .908 r
.34209 .54503 .36361 .56506 .39846 .55427 .37723 .53397 Mtetra
.37723 .53397 .39846 .55427 .43377 .54333 .41284 .52277 Mtetra
.41284 .52277 .43377 .54333 .46955 .53226 .44892 .51142 Mtetra
.44892 .51142 .46955 .53226 .50581 .52103 .48549 .49991 Mtetra
.48549 .49991 .50581 .52103 .54255 .50966 .52255 .48825 Mtetra
.772 .302 0 r
.52255 .48825 .54255 .50966 .58077 .55727 .56091 .54986 Mtetra
.947 .829 .694 r
.56091 .54986 .58077 .55727 .61754 .48645 .59822 .46445 Mtetra
.664 .741 .908 r
.59822 .46445 .61754 .48645 .6558 .4746 .63683 .4523 Mtetra
.63683 .4523 .6558 .4746 .69459 .46259 .67599 .43998 Mtetra
.67599 .43998 .69459 .46259 .73392 .45042 .71569 .42749 Mtetra
.71569 .42749 .73392 .45042 .77379 .43807 .75596 .41482 Mtetra
.75596 .41482 .77379 .43807 .81423 .42556 .79681 .40198 Mtetra
.79681 .40198 .81423 .42556 .85524 .41286 .83823 .38894 Mtetra
0 .336 .818 r
.83823 .38894 .85524 .41286 .90143 .43976 .88522 .42032 Mtetra
.907 .838 .765 r
.88522 .42032 .90143 .43976 .93903 .38692 .9229 .36231 Mtetra
.664 .741 .908 r
.32005 .5245 .34209 .54503 .37723 .53397 .35548 .51317 Mtetra
.35548 .51317 .37723 .53397 .41284 .52277 .39138 .50169 Mtetra
.39138 .50169 .41284 .52277 .44892 .51142 .42777 .49006 Mtetra
.42777 .49006 .44892 .51142 .48549 .49991 .46465 .47826 Mtetra
.791 .322 0 r
.46465 .47826 .48549 .49991 .52255 .48825 .50154 .53922 Mtetra
0 0 0 r
.50154 .53922 .52255 .48825 .56091 .54986 .53996 .45418 Mtetra
.61 .478 .676 r
.53996 .45418 .56091 .54986 .59822 .46445 .57839 .44189 Mtetra
.664 .741 .908 r
.57839 .44189 .59822 .46445 .63683 .4523 .61737 .42943 Mtetra
.61737 .42943 .63683 .4523 .67599 .43998 .6569 .41679 Mtetra
.6569 .41679 .67599 .43998 .71569 .42749 .69699 .40396 Mtetra
.69699 .40396 .71569 .42749 .75596 .41482 .73766 .39096 Mtetra
.73766 .39096 .75596 .41482 .79681 .40198 .77892 .37777 Mtetra
0 .114 .648 r
.77892 .37777 .79681 .40198 .83823 .38894 .82627 .42362 Mtetra
0 0 0 r
.82627 .42362 .83823 .38894 .88522 .42032 .86324 .3508 Mtetra
.627 .529 .724 r
.86324 .3508 .88522 .42032 .9229 .36231 .90633 .33702 Mtetra
.664 .741 .908 r
.29746 .50347 .32005 .5245 .35548 .51317 .33318 .49186 Mtetra
.33318 .49186 .35548 .51317 .39138 .50169 .36938 .48009 Mtetra
.36938 .48009 .39138 .50169 .42777 .49006 .40608 .46816 Mtetra
.40608 .46816 .42777 .49006 .46465 .47826 .44329 .45606 Mtetra
0 .098 .605 r
.44329 .45606 .46465 .47826 .50154 .53922 .4804 .48907 Mtetra
.79 .649 .707 r
.4804 .48907 .50154 .53922 .53996 .45418 .51926 .43136 Mtetra
.664 .741 .908 r
.51926 .43136 .53996 .45418 .57839 .44189 .55806 .41874 Mtetra
.55806 .41874 .57839 .44189 .61737 .42943 .5974 .40595 Mtetra
.5974 .40595 .61737 .42943 .6569 .41679 .63731 .39297 Mtetra
.63731 .39297 .6569 .41679 .69699 .40396 .6778 .37981 Mtetra
.6778 .37981 .69699 .40396 .73766 .39096 .71887 .36646 Mtetra
.71887 .36646 .73766 .39096 .77892 .37777 .76054 .35291 Mtetra
0 .092 .629 r
.76054 .35291 .77892 .37777 .82627 .42362 .80822 .4004 Mtetra
.923 .807 .714 r
.80822 .4004 .82627 .42362 .86324 .3508 .84575 .3252 Mtetra
.664 .741 .908 r
.84575 .3252 .86324 .3508 .90633 .33702 .88931 .31104 Mtetra
.27431 .48191 .29746 .50347 .33318 .49186 .31031 .47 Mtetra
.31031 .47 .33318 .49186 .36938 .48009 .34682 .45793 Mtetra
.34682 .45793 .36938 .48009 .40608 .46816 .38383 .44569 Mtetra
.633 .134 0 r
.38383 .44569 .40608 .46816 .44329 .45606 .41959 .48904 Mtetra
.765 .897 .498 r
.41959 .48904 .44329 .45606 .4804 .48907 .45943 .42069 Mtetra
.623 .524 .721 r
.45943 .42069 .4804 .48907 .51926 .43136 .49803 .40793 Mtetra
.664 .741 .908 r
.49803 .40793 .51926 .43136 .55806 .41874 .53718 .39498 Mtetra
.53718 .39498 .55806 .41874 .5974 .40595 .5769 .38185 Mtetra
.5769 .38185 .5974 .40595 .63731 .39297 .6172 .36852 Mtetra
.6172 .36852 .63731 .39297 .6778 .37981 .65808 .355 Mtetra
.65808 .355 .6778 .37981 .71887 .36646 .69957 .34128 Mtetra
0 0 .523 r
.69957 .34128 .71887 .36646 .76054 .35291 .74631 .39484 Mtetra
0 0 0 r
.74631 .39484 .76054 .35291 .80822 .4004 .7844 .31323 Mtetra
.614 .495 .695 r
.7844 .31323 .80822 .4004 .84575 .3252 .82778 .29889 Mtetra
.664 .741 .908 r
.82778 .29889 .84575 .3252 .88931 .31104 .87181 .28433 Mtetra
.25056 .4598 .27431 .48191 .31031 .47 .28686 .44759 Mtetra
.28686 .44759 .31031 .47 .34682 .45793 .32368 .4352 Mtetra
.32368 .4352 .34682 .45793 .38383 .44569 .36101 .42264 Mtetra
.636 .137 0 r
.36101 .42264 .38383 .44569 .41959 .48904 .39668 .46618 Mtetra
.881 .765 .729 r
.39668 .46618 .41959 .48904 .45943 .42069 .43727 .39699 Mtetra
.664 .741 .908 r
.43727 .39699 .45943 .42069 .49803 .40793 .47623 .38388 Mtetra
.47623 .38388 .49803 .40793 .53718 .39498 .51575 .37059 Mtetra
.51575 .37059 .53718 .39498 .5769 .38185 .55585 .3571 Mtetra
.55585 .3571 .5769 .38185 .6172 .36852 .59653 .34341 Mtetra
.59653 .34341 .6172 .36852 .65808 .355 .63782 .32952 Mtetra
.63782 .32952 .65808 .355 .69957 .34128 .67973 .31542 Mtetra
0 .272 .772 r
.67973 .31542 .69957 .34128 .74631 .39484 .72525 .34831 Mtetra
.823 .691 .718 r
.72525 .34831 .74631 .39484 .7844 .31323 .76545 .28658 Mtetra
.664 .741 .908 r
.76545 .28658 .7844 .31323 .82778 .29889 .80929 .27183 Mtetra
.80929 .27183 .82778 .29889 .87181 .28433 .85381 .25686 Mtetra
.2262 .43712 .25056 .4598 .28686 .44759 .26281 .42459 Mtetra
0 .119 .613 r
.26281 .42459 .28686 .44759 .32368 .4352 .29707 .45297 Mtetra
.88 .989 .733 r
.29707 .45297 .32368 .4352 .36101 .42264 .33758 .39899 Mtetra
.664 .741 .908 r
.33758 .39899 .36101 .42264 .39668 .46618 .37578 .38591 Mtetra
.613 .5 .701 r
.37578 .38591 .39668 .46618 .43727 .39699 .41453 .37264 Mtetra
.664 .741 .908 r
.41453 .37264 .43727 .39699 .47623 .38388 .45384 .35918 Mtetra
.45384 .35918 .47623 .38388 .51575 .37059 .49373 .34553 Mtetra
.49373 .34553 .51575 .37059 .55585 .3571 .53422 .33167 Mtetra
.53422 .33167 .55585 .3571 .59653 .34341 .5753 .3176 Mtetra
0 .236 .742 r
.5753 .3176 .59653 .34341 .63782 .32952 .61838 .34989 Mtetra
.755 .919 .551 r
.61838 .34989 .63782 .32952 .67973 .31542 .65934 .28883 Mtetra
.664 .741 .908 r
.65934 .28883 .67973 .31542 .72525 .34831 .70232 .27412 Mtetra
.62 .521 .721 r
.70232 .27412 .72525 .34831 .76545 .28658 .74597 .25918 Mtetra
.664 .741 .908 r
.74597 .25918 .76545 .28658 .80929 .27183 .79028 .244 Mtetra
.79028 .244 .80929 .27183 .85381 .25686 .83529 .22859 Mtetra
.2012 .41384 .2262 .43712 .26281 .42459 .23811 .40098 Mtetra
0 .186 .676 r
.23811 .40098 .26281 .42459 .29707 .45297 .27254 .42668 Mtetra
.839 .749 .764 r
.27254 .42668 .29707 .45297 .33758 .39899 .31353 .3747 Mtetra
.664 .741 .908 r
.31353 .3747 .33758 .39899 .37578 .38591 .35207 .36127 Mtetra
.35207 .36127 .37578 .38591 .41453 .37264 .39117 .34764 Mtetra
.39117 .34764 .41453 .37264 .45384 .35918 .43084 .33381 Mtetra
.43084 .33381 .45384 .35918 .49373 .34553 .47111 .31978 Mtetra
.47111 .31978 .49373 .34553 .53422 .33167 .51199 .30554 Mtetra
.51199 .30554 .53422 .33167 .5753 .3176 .55348 .29108 Mtetra
0 .207 .718 r
.55348 .29108 .5753 .3176 .61838 .34989 .59671 .32495 Mtetra
.889 .798 .752 r
.59671 .32495 .61838 .34989 .65934 .28883 .63837 .26149 Mtetra
.664 .741 .908 r
.63837 .26149 .65934 .28883 .70232 .27412 .68181 .24635 Mtetra
.68181 .24635 .70232 .27412 .74597 .25918 .72592 .23098 Mtetra
.72592 .23098 .74597 .25918 .79028 .244 .77072 .21537 Mtetra
.77072 .21537 .79028 .244 .83529 .22859 .81623 .19951 Mtetra
0 .341 .804 r
.17555 .38995 .2012 .41384 .23811 .40098 .20962 .40892 Mtetra
.886 .978 .827 r
.20962 .40892 .23811 .40098 .27254 .42668 .25052 .36335 Mtetra
.623 .54 .739 r
.25052 .36335 .27254 .42668 .31353 .3747 .28883 .34975 Mtetra
.664 .741 .908 r
.28883 .34975 .31353 .3747 .35207 .36127 .32771 .33595 Mtetra
.32771 .33595 .35207 .36127 .39117 .34764 .36716 .32195 Mtetra
.36716 .32195 .39117 .34764 .43084 .33381 .40721 .30774 Mtetra
.40721 .30774 .43084 .33381 .47111 .31978 .44786 .29331 Mtetra
.44786 .29331 .47111 .31978 .51199 .30554 .48913 .27867 Mtetra
0 .324 .805 r
.48913 .27867 .51199 .30554 .55348 .29108 .53112 .30447 Mtetra
.84 .982 .695 r
.53112 .30447 .55348 .29108 .59671 .32495 .57359 .2487 Mtetra
.616 .517 .718 r
.57359 .2487 .59671 .32495 .63837 .26149 .6168 .23336 Mtetra
.664 .741 .908 r
.6168 .23336 .63837 .26149 .68181 .24635 .6607 .21779 Mtetra
.6607 .21779 .68181 .24635 .72592 .23098 .70528 .20196 Mtetra
.70528 .20196 .72592 .23098 .77072 .21537 .75058 .18589 Mtetra
.75058 .18589 .77072 .21537 .81623 .19951 .79661 .16955 Mtetra
0 .372 .827 r
.1492 .36542 .17555 .38995 .20962 .40892 .18341 .383 Mtetra
.824 .755 .787 r
.18341 .383 .20962 .40892 .25052 .36335 .2248 .33809 Mtetra
.664 .741 .908 r
.2248 .33809 .25052 .36335 .28883 .34975 .26345 .32412 Mtetra
.26345 .32412 .28883 .34975 .32771 .33595 .30267 .30994 Mtetra
.30267 .30994 .32771 .33595 .36716 .32195 .34249 .29555 Mtetra
.34249 .29555 .36716 .32195 .40721 .30774 .38291 .28094 Mtetra
.38291 .28094 .40721 .30774 .44786 .29331 .42395 .2661 Mtetra
.42395 .2661 .44786 .29331 .48913 .27867 .46563 .25104 Mtetra
.079 .431 .873 r
.46563 .25104 .48913 .27867 .53112 .30447 .50776 .27029 Mtetra
.828 .747 .774 r
.50776 .27029 .53112 .30447 .57359 .2487 .55094 .2202 Mtetra
.664 .741 .908 r
.55094 .2202 .57359 .2487 .6168 .23336 .5946 .20441 Mtetra
.5946 .20441 .6168 .23336 .6607 .21779 .63897 .18838 Mtetra
.63897 .18838 .6607 .21779 .70528 .20196 .68404 .17208 Mtetra
.68404 .17208 .70528 .20196 .75058 .18589 .72984 .15553 Mtetra
.72984 .15553 .75058 .18589 .79661 .16955 .77639 .1387 Mtetra
.841 .921 .886 r
.11943 .36143 .1492 .36542 .18341 .383 .15997 .32628 Mtetra
.629 .565 .763 r
.15997 .32628 .18341 .383 .2248 .33809 .19838 .31214 Mtetra
.664 .741 .908 r
.19838 .31214 .2248 .33809 .26345 .32412 .23736 .29778 Mtetra
.23736 .29778 .26345 .32412 .30267 .30994 .27694 .2832 Mtetra
.27694 .2832 .30267 .30994 .34249 .29555 .31712 .2684 Mtetra
.31712 .2684 .34249 .29555 .38291 .28094 .35792 .25337 Mtetra
.35792 .25337 .38291 .28094 .42395 .2661 .39936 .23811 Mtetra
.28 .561 .931 r
.39936 .23811 .42395 .2661 .46563 .25104 .44075 .24777 Mtetra
.855 .968 .871 r
.44075 .24777 .46563 .25104 .50776 .27029 .48419 .20686 Mtetra
.626 .555 .755 r
.48419 .20686 .50776 .27029 .55094 .2202 .52762 .19086 Mtetra
.664 .741 .908 r
.52762 .19086 .55094 .2202 .5946 .20441 .57175 .17461 Mtetra
.57175 .17461 .5946 .20441 .63897 .18838 .61659 .15809 Mtetra
.61659 .15809 .63897 .18838 .68404 .17208 .66216 .14131 Mtetra
.66216 .14131 .68404 .17208 .72984 .15553 .70847 .12424 Mtetra
.70847 .12424 .72984 .15553 .77639 .1387 .75556 .1069 Mtetra
.751 .717 .82 r
.09231 .32902 .11943 .36143 .15997 .32628 .13248 .3 Mtetra
.664 .741 .908 r
.13248 .3 .15997 .32628 .19838 .31214 .17121 .28546 Mtetra
.17121 .28546 .19838 .31214 .23736 .29778 .21054 .27069 Mtetra
.21054 .27069 .23736 .29778 .27694 .2832 .25047 .2557 Mtetra
.25047 .2557 .27694 .2832 .31712 .2684 .29103 .24047 Mtetra
.29103 .24047 .31712 .2684 .35792 .25337 .33221 .225 Mtetra
.33221 .225 .35792 .25337 .39936 .23811 .37405 .2093 Mtetra
.441 .648 .946 r
.37405 .2093 .39936 .23811 .44075 .24777 .41594 .2104 Mtetra
.759 .719 .816 r
.41594 .2104 .44075 .24777 .48419 .20686 .45973 .17712 Mtetra
.664 .741 .908 r
.45973 .17712 .48419 .20686 .52762 .19086 .50361 .16065 Mtetra
.50361 .16065 .52762 .19086 .57175 .17461 .5482 .14391 Mtetra
.5482 .14391 .57175 .17461 .61659 .15809 .59353 .12689 Mtetra
.59353 .12689 .61659 .15809 .66216 .14131 .6396 .10959 Mtetra
.6396 .10959 .66216 .14131 .70847 .12424 .68645 .092 Mtetra
.68645 .092 .70847 .12424 .75556 .1069 .73408 .07411 Mtetra
.647 .641 .83 r
.06574 .28771 .09231 .32902 .13248 .3 .10421 .27298 Mtetra
.664 .741 .908 r
.10421 .27298 .13248 .3 .17121 .28546 .14328 .25802 Mtetra
.14328 .25802 .17121 .28546 .21054 .27069 .18295 .24283 Mtetra
.18295 .24283 .21054 .27069 .25047 .2557 .22324 .2274 Mtetra
.22324 .2274 .25047 .2557 .29103 .24047 .26417 .21173 Mtetra
.26417 .21173 .29103 .24047 .33221 .225 .30575 .19581 Mtetra
.548 .699 .939 r
.30575 .19581 .33221 .225 .37405 .2093 .3474 .1897 Mtetra
.757 .845 .918 r
.3474 .1897 .37405 .2093 .41594 .2104 .39091 .1632 Mtetra
.645 .63 .821 r
.39091 .1632 .41594 .2104 .45973 .17712 .43453 .1465 Mtetra
.664 .741 .908 r
.43453 .1465 .45973 .17712 .50361 .16065 .47887 .12952 Mtetra
.47887 .12952 .50361 .16065 .5482 .14391 .52394 .11227 Mtetra
.52394 .11227 .5482 .14391 .59353 .12689 .56976 .09472 Mtetra
.56976 .09472 .59353 .12689 .6396 .10959 .61635 .07688 Mtetra
.61635 .07688 .6396 .10959 .68645 .092 .66373 .05874 Mtetra
.66373 .05874 .68645 .092 .73408 .07411 .71192 .04029 Mtetra
.03634 .26033 .06574 .28771 .10421 .27298 .07513 .24518 Mtetra
.07513 .24518 .10421 .27298 .14328 .25802 .11454 .22979 Mtetra
.11454 .22979 .14328 .25802 .18295 .24283 .15456 .21416 Mtetra
.15456 .21416 .18295 .24283 .22324 .2274 .19522 .19828 Mtetra
.19522 .19828 .22324 .2274 .26417 .21173 .23652 .18214 Mtetra
.23652 .18214 .26417 .21173 .30575 .19581 .2785 .16575 Mtetra
.651 .737 .913 r
.2785 .16575 .30575 .19581 .3474 .1897 .32106 .15044 Mtetra
.665 .684 .858 r
.32106 .15044 .3474 .1897 .39091 .1632 .3645 .13215 Mtetra
.664 .741 .908 r
.3645 .13215 .39091 .1632 .43453 .1465 .40857 .11494 Mtetra
.40857 .11494 .43453 .1465 .47887 .12952 .45337 .09744 Mtetra
.45337 .09744 .47887 .12952 .52394 .11227 .49893 .07965 Mtetra
.49893 .07965 .52394 .11227 .56976 .09472 .54525 .06155 Mtetra
.54525 .06155 .56976 .09472 .61635 .07688 .59236 .04315 Mtetra
.59236 .04315 .61635 .07688 .66373 .05874 .64029 .02443 Mtetra
.612 .719 .921 r
.64029 .02443 .66373 .05874 .71192 .04029 .68937 .01096 Mtetra
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.19579 .19302 m
.20033 .19776 L
s
[(5)] .18671 .18355 .95953 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(10)] .40046 .09948 .82054 1 Mshowa
.64007 .01906 m
.64377 .02448 L
s
[(15)] .63268 .00821 .68154 1 Mshowa
.125 Mabswid
.23703 .17687 m
.23971 .17975 L
s
.27893 .16047 m
.28157 .16339 L
s
.32151 .14379 m
.32411 .14675 L
s
.36479 .12685 m
.36734 .12985 L
s
.4535 .09211 m
.45595 .0952 L
s
.49897 .07431 m
.50137 .07743 L
s
.54521 .0562 m
.54755 .05937 L
s
.59224 .03779 m
.59452 .041 L
s
.1552 .20892 m
.15797 .21172 L
s
.11524 .22456 m
.11804 .22733 L
s
.0759 .23997 m
.07874 .24269 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[77]:=",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00N03oool5
@0000080oooo00=000000?ooo`3oool0_@3oool5@0000080oooo00=000000?ooo`3oool0A`3oool0
07X0oooo00M000000?ooo`3oool0oooo@000003ooom000000<00oooo00M000000?ooo`3oool0oooo
@000003ooom0000004P0oooo001j0?ooo`03@000003oool0oooo00<0oooo00=000000?ooo`3oool0
_P3oool00d000000oooo0?ooo`030?ooo`03@000003oool0oooo04H0oooo001j0?ooo`04@000003o
ool0oooo0?ooo`900000`@3oool014000000oooo0?ooo`3oool2@00004T0oooo001j0?ooo`05@000
003oool0oooo0?oood000000`P3oool01D000000oooo0?ooo`3ooom0000004X0oooo001i0?ooo`90
00000`3oool3@0000;l0oooo0T0000030?ooo`=00000B03oool00?l0ooooT@3oool008P0oooo00<0
0000@000003oool0a03oool00`00001000000?ooo`0n0?ooo`00QP3oool200000080oooo00<00000
0?ooo`3oool0`03oool200000080oooo00<000000?ooo`3oool0?03oool008<0oooo0`00000409bh
j`030000003oool0oooo0;d0oooo0`00000409^gk0030000003oool0oooo03`0oooo00200?ooo`80
000000=0000009bhj`2L^>/01@2L^>/00`3oool000000?ooo`2j0?ooo`80000000=0000009^gk02K
]n`01@2K]n`00`3oool000000?ooo`0l0?ooo`00OP3oool200000080ZKgX2@2L^>/00`3oool00000
0?ooo`2g0?ooo`8000000P2Y_NP909^gk0030?ooo`000000oooo03/0oooo001j0?ooo`@00000102Y
_NP909bhj`03@00000000000oooo0;<0oooo100000040:Vmj0T0VkO/00=000000000003oool0>`3o
ool007T0oooo0P0000000d000000ZKgX0:Vmj0050:Vmj0T0W;S[00<0oooo0000003oool0/@3oool2
00000003@000002Y_NP0ZKgX00D0ZKgX2@2K]n`00`3oool000000?ooo`0j0?ooo`00E03oool5@000
0080oooo00=000000?ooo`3oool0603oool3000000/0ZKgX1P2L^>/30:Vmj0030000003oool0oooo
08/0oooo1D0000020?ooo`03@000003oool0oooo01P0oooo0`00000;0:Vmj0H0VkO/0`2Y_NP00`00
0000oooo0?ooo`0i0?ooo`00EP3oool01d000000oooo0?ooo`3ooom000000?oood0000005P3oool3
000000h0ZKgX102L^>/50:Vmj0030?ooo`000000oooo08d0oooo00M000000?ooo`3oool0oooo@000
003ooom0000001H0oooo0`00000>0:Vmj0@0VkO/1@2Y_NP00`3oool000000?ooo`0i0?ooo`00EP3o
ool01d000000oooo0?ooo`3ooom000000?oood000000503oool300000003@000002Y_NP0ZKgX01L0
ZKgX00<0oooo0000003oool0S03oool01d000000oooo0?ooo`3ooom000000?oood000000503oool3
00000003@000002Y_NP0ZKgX01L0ZKgX00<0oooo0000003oool0>03oool005H0oooo00M000000?oo
o`3oool0oooo@000003ooom000000140oooo0`00000M0:Vmj0030?oood000000oooo08`0oooo00M0
00000?ooo`3oool0oooo@000003ooom000000140oooo0`00000M0:Vmj0030?oood000000oooo03P0
oooo001F0?ooo`07@000003oool0oooo0?oood000000oooo@000000?0?ooo`03000004000000oooo
0200ZKgX00<0oooo0000003oool0R`3oool01d000000oooo0?ooo`3ooom000000?oood0000003`3o
ool00`00001000000?ooo`0P0:Vmj0030?ooo`000000oooo03L0oooo001E0?ooo`900000103oool0
0d000000oooo0?ooo`0;0?ooo`<00000902Y_NP00`3oool000000?ooo`290?ooo`900000103oool0
0d000000oooo0?ooo`0;0?ooo`<00000902Y_NP00`3oool000000?ooo`0f0?ooo`00I`3oool20000
00030?ooo`2Y_NP0ZKgX02@0ZKgX00<0oooo0000003oool0V`3oool2000000030?ooo`2Y_NP0ZKgX
02D0ZKgX00<000000?ooo`3oool0=@3oool006@0oooo0P0000000d000000ZKgX0:Vmj00X0:Vmj003
0?ooo`000000oooo09L0oooo0P0000000d000000ZKgX0:Vmj00X0:Vmj0030?ooo`000000oooo03D0
oooo001R0?ooo`800000;@2Y_NP00`3ooom00000000000050?ooo`03@000003oool0oooo08d0oooo
0P00000^0:Vmj003@00000000000oooo00@0oooo00=000000?ooo`3oool0;@3oool005l0oooo0`00
000`0:Vmj0030?ooo`000000oooo00<0oooo00=000000?oood000000R`3oool300000340ZKgX00<0
00000?ooo`3oool00P3oool00d000000oooo@000000^0?ooo`00G03oool300000003@000002Y_NP0
ZKgX0340ZKgX00<0oooo0000003oool0103oool00d000000oooo0?ooo`260?ooo`<0000000=00000
0:Vmj02Y_NP0<P2Y_NP00`000000oooo0?ooo`030?ooo`03@000003oool0oooo02`0oooo001J0?oo
o`80000000<0oooo0:Vmj02Y_NP0=@2Y_NP0103oool000000?ooo`3oool2@00008L0oooo0P000000
0`3oool0ZKgX0:Vmj00f0:Vmj0030000003oool0oooo00900000;`3oool003/0oooo00=000000?oo
o`3oool06@3oool200000003@000002Y_NP0ZKgX03T0ZKgX00@000000?ooo`3ooom00000J@3oool0
0d000000oooo0?ooo`0I0?ooo`80000000=000000:Vmj02Y_NP0>@2Y_NP010000000oooo0?oood00
000`0?ooo`00>P3oool00d000000oooo@000000H0?ooo`8000000P2Z/=`m0:Vmj0030000003ooom0
000000900000IP3oool00d000000oooo@000000H0?ooo`8000000P2[/=`m0:Vmj0030000003ooom0
000000900000;P3oool003`0oooo00=000000?ooo`3oool04`3oool3000000D0Z[3L?@2Y_NQ/0?oo
o`03@000003oool0oooo01<0oooo0`0000050:^`g3d0ZKgX<P3oool003X0oooo0T00000C0?ooo`<0
000000=000000:Z`g02Z/=`01@2Z/=`m0:Vmj0030000003oool0oooo06L0oooo0T00000C0?ooo`<0
000000=000000:^`g02[/=`01@2[/=`m0:Vmj0030000003oool0oooo02l0oooo000j0?ooo`03@000
003oool0oooo0100oooo0P000000103oool0Y[cY0:Jlj@2V_>T80:Z`g0H0ZKgX0`2UXM8d0:Vmj003
0000003oool0oooo06H0oooo00=000000?ooo`3oool0403oool2000000040?ooo`2U_>T0YKcY0:Fl
j@P0Zk3L1P2Y_NP30:BPdC@0ZKgX00<000000?ooo`3oool0;P3oool003X0oooo0d00000=0?ooo`80
000000=000000:Jlj@2V_>T0102V_>T90:Z`g0T0YJ7B<`2Y_NP00d00000000000?ooo`1V0?ooo`=0
00003@3oool200000003@000002U_>T0YKcY00@0YKcY2@2[/=`90:BPdC<0ZKgX00=000000000003o
ool0;P3oool004P0oooo0P0000020:Vmj0P0Y[cY1`2Z/=`20;oFj`P0YJ7B=02Y_NP00`000000oooo
0?ooo`1c0?ooo`8000000P2Y_NP80:Flj@L0Zk3L0P31en/80:BPdC@0ZKgX00<000000?ooo`3oool0
;@3oool004D0oooo0`0000050:Vmj0P0Y[cY102Z/=`40;oFj`T0YJ7B=02Y_NP00`000000oooo0?oo
o`1_0?ooo`<000001@2Y_NP80:Flj@@0Zk3L1031en/90:BPdC@0ZKgX00<000000?ooo`3oool0;03o
ool004<0oooo0P0000000`2Y_NQ000000:Vmj0050:Vmj0P0Y[cY0`2Z/=`60;oFj`L0YJ7B0P31]/lc
0:Vmj0030000003oool0oooo06d0oooo0P0000000`2Y_NQ000000:Vmj0060:Vmj0L0YKcY0`2[/=`6
0<7Gj`L0Y:3A0P32]/lc0:Vmj0030000003oool0oooo02`0oooo00100?ooo`<000002`2Y_NP80:Jl
j@P0_mK[1P2UXM840<6fcc<0ZKgX00<000000?ooo`3oool0J@3oool3000000`0ZKgX1`2U_>T80<7G
j`H0Y:3A1032]/lc0:Vmj0030000003oool0oooo02/0oooo000m0?ooo`<0000000=000000:Vmj02Y
_NP0302Y_NP808nck`P0_mK[0`2UXM860<6fc`L0ZKgX0`2PSl8Y0:Vmj003@00000000000oooo06H0
oooo0`0000000d000000ZKgX0:Vmj00=0:Vmj0L0SK?`2031en/30:BPd@H0`[K?1`2Y_NP30:2?`RT0
ZKgX00=000000000003oool0:`3oool003/0oooo0P00000C0:Vmj0T0Sk?_1P2oe^/20:FQdPP0`KK?
102Y_NP50:2?`RX0ZKgX00<000000?ooo`3oool0H`3oool2000001@0ZKgX202=/o060<7Gj`80Y:3A
2032]/l40:Vmj0D0X8o2:P2Y_NP00`000000oooo0?ooo`0Z0?ooo`00>03oool00`00001000000000
000F0:Vmj0T0Sk?_1P2oe^/:0<6fc`T0X8o2:P2Y_NP00`000000oooo0?ooo`1O0?ooo`0300000400
0000000001L0ZKgX202=/o060<7Gj`X0`[K?2@2PSl8Z0:Vmj0030000003oool0oooo02T0oooo000f
0?ooo`80000000<0oooo0:Vmj02Y_NP05`2Y_NP608nck`<0ZKgX1P1aY_880<6fc`030=_hg@2PSl80
X8o200L0X8o2:P2Y_NP00`3oool000000?ooo`1M0?ooo`80000000<0oooo0:Vmj02Y_NP05`2Y_NP6
08fcl0<0ZKgX1P1^Y?880<:fc`030=cif`2PSl80X8o200L0X8o2:P2Y_NP00`3oool000000?ooo`0Y
0?ooo`00<`3oool3000000030?ooo`2Y_NP0ZKgX02<0ZKgX1@1aY_870<6fc`<0foSM2@2PSl8Z0:Vm
j003@000003oool0oooo05T0oooo0`0000000`3oool0ZKgX0:Vmj00S0:Vmj0D0KZCb1`32]/l30=ci
f`T0X8o2:P2Y_NP00d000000oooo0?ooo`0X0?ooo`00<@3oool2000000030:Vmj4000000ZKgX02H0
ZKgX1P1aY_850<6fc`@0foSM202PSl820=:naRT0ZKgX00<0oooo0000003oool0E`3oool200000003
0:Vmj4000000ZKgX02H0ZKgX1P1^Y?850<:fc`@0g?WK202PSl820=2kaBT0ZKgX00<0oooo0000003o
ool0:03oool002h0oooo0`00000/0:Vmj0H0LJKb0`31]/l60=_hg@H0X8o2103B_/HY0:Vmj0030000
003oool0oooo05<0oooo0`00000/0:Vmj0H0KZCb0`32]/l60=cif`H0X8o2103@^lDY0:Vmj0030000
003oool0oooo02L0oooo000[0?ooo`<0000000=000000:Vmj02Y_NP0;@2Y_NP00`12S>d0LJKb076V
lP02076VlP80`KK?1`3Kn=d50:2?`PD0d[k61P2Y_NP309f3]b40ZKgX00<000000?ooo`3oool0C`3o
ool300000003@000002Y_NP0ZKgX02d0ZKgX00<0?8W/06jTlP1^Y?800P1^Y?820<:fc`L0g?WK1@2P
Sl850=2ka@H0ZKgX0`2MPkLQ0:Vmj0030000003oool0oooo02H0oooo000Y0?ooo`800000=02Y_NP5
04:<k@T0foSM102PSl860=:naPT0WH>g802Y_NP00d00000000000?ooo`030?ooo`E000000P3oool0
0d000000oooo0?ooo`100?ooo`800000=02Y_NP503b9k0T0g?WK102PSl860=2ka@T0WH>g802Y_NP0
0d00000000000?ooo`030?ooo`E000000P3oool00d000000oooo0?ooo`0I0?ooo`009`3oool20000
03L0ZKgX1@12S>d30:Vmj00301achP3Kn=d0foSM0080foSM0`2PSl860=:naP030=Ol]02MPkL0WH>g
00L0WH>g8@2Y_NP00`000000oooo0?ooo`040?ooo`07@000003oool0oooo0?oood000000oooo@000
000o0?ooo`800000=`2Y_NP503b9k0<0ZKgX00<07WCS0=cif`3LnM/00P3LnM/30:2?`PH0d;_500<0
e_Z^09f3]`2MPkL01`2MPkLQ0:Vmj0030000003oool0oooo00@0oooo00M000000?ooo`3oool0oooo
@000003ooom0000001X0oooo000W0?oood80ZKgX0P0LLn830=_hg@030:2?`P3B_/H0d[k600D0d[k6
0P3Go;@909f3]`h0ZKgX0`2NQ[T@0:Vmj0030000003oool0oooo00<0oooo00M000000?ooo`3oool0
oooo@000003ooom0000003l0oooo@P2Y_NP201idh`<0g?WK00<0X8o20=2ka@3@^lD01@3@^lD20=Kj
[PT0WH>g3P2Y_NP309j5^100ZKgX00<000000?ooo`3oool00`3oool01d000000oooo0?ooo`3ooom0
00000?oood0000006P3oool002<0oooo00E000000?ooo`3oool0oooo000000120:Vmj0@077?R1`3B
_/H30=Ol]0P0WH>g0P3Ucl0;0:Vmj0H0WXJi402Y_NP00`000000oooo0?ooo`020?ooo`07@000003o
ool0oooo0?oood000000oooo@000000k0?ooo`05@000003oool0oooo0?ooo`000000@P2Y_NP401id
h`L0d;_50`3FnZh809f3]`80iLk02`2Y_NP609j5^100ZKgX00<000000?ooo`3oool00P3oool01d00
0000oooo0?ooo`3ooom000000?oood0000006P3oool00280oooo00=000000?oood0000000P3oool0
0`000000oooo0:Vmj0060:Vmj080YJCD>@2Y_NP401achPD0d[k6103Go;@809f3]`<0iLo0202Y_NP8
09j6^A00ZKgX0P0000030?ooo`07@000003oool0oooo0?oood000000oooo@000000j0?ooo`03@000
003ooom000000080oooo00<000000?ooo`2Y_NP01P2Y_NP20:JVeST0ZKgX100NM><50=2ka@@0e_Z^
202MPkL30>G>`0P0ZKgX202NQKP@0:Vmj08000000`3oool01d000000oooo0?ooo`3ooom000000?oo
od0000006P3oool00280oooo00I000000?oood000000oooo0000040000030?ooo`<0ZKgX1@2UY=@i
0:Vmj0<077?R103B_/H60=Ol]0H0WH>g103Ucl080:Vmj0T0WXJi402Y_NP00`000000oooo0?ooo`02
@00000@0oooo00=000000?ooo`3oool0>@3oool01T000000oooo@000003oool00000@00000<0oooo
0`2Y_NP50:JVeST0ZKgX0`0NM><40=2ka@H0e_Z^1P2MPkL40>G>`0P0ZKgX2@2NQKP@0:Vmj0030000
003oool0oooo00900000103oool00d000000oooo0?ooo`0I0?ooo`008P3oool01D000000oooo@000
003oool0000000D0oooo2@2UY=@h0:Vmj003001Fd00LLn8077?R00<0d[k61P3Go;@509f3]`H0iLo0
202Y_NP709j6^@80cjfg402Y_NP00`000000oooo0?ooo`110?ooo`05@000003ooom000000?ooo`00
00001@3oool90:JVeSP0ZKgX00<004k;01idh`0NM><00`3@^lD60=Kj[PD0WH>g1P3Uc/080:Vmj0L0
WXFh0P3B/KP@0:Vmj0030000003oool0oooo0240oooo000R0?ooo`06@000003ooom000000?ooo`00
001000001@3oool90:FTe3L0ZKgX0P00E]00100LLn80d[k60=:naP3Go;@20:Vmj0D0eobd102MPkL5
0>G?`080`nf@1`2Y_NP709j6^@<0cjfg3`2Y_NP00`000000oooo0?ooo`110?ooo`06@000003ooom0
00000?ooo`00001000001@3oool90:JVeSL0ZKgX0P00C//0100NM><0d;_50=2ka@3FnZh20:Vmj0D0
e_Z^102MPkL50>G>`080`N^=1`2Y_NP709j5^0<0d[6h3`2Y_NP00`000000oooo0?ooo`0Q0?ooo`00
8`3oool014000000oooo0?ooo`0000060?ooo`P0YJCD0P2o]]4o0:Vmj004000`]03Go;@0eobd0=Ol
]0<0WH>g1P3Ucl030<?]T0H0ZKgX1P2NQ[T40<n]]`D0ZKgX0`2MO[480:Vmj0030000003oool0oooo
0440oooo00A000000?ooo`3oool000001P3oool80:JVeP80_;?A?`2Y_NP01000<;<0e_Z^0=Kj[P3F
nZh309f3]`H0iLk00`31jhd60:Vmj0H0WXFh103B/KP50:Vmj0<0W7f`202Y_NP00`000000oooo0?oo
o`0P0?ooo`009P3oool00`00001000000?ooo`050?ooo`H0YJCD102o]]4o0:Vmj003000`]03Go;@0
eobd0080WH>g1P3Ucl040<?]T0L0ZKgX102NQ[T60<n]]`P0WGja1`2Y_NP00d000000oooo0?ooo`14
0?ooo`03000004000000oooo00D0oooo1P2VY]H40;bcdCl0ZKgX00<0032c0=Kj[P3FnZh00P2MPkL6
0>G>`0@0`N^=1P2Y_NP609j5^0D0d[6h202LOK070:Vmj003@000003oool0oooo0200oooo000V0?oo
o`03000004000000oooo00H0oooo0`2UY=@70;nfd@@0ZKgX0`2PSl8h0:Vmj004000`]03Go;@0eobd
09f3]`D0iLo01P33kI060:Vmj0@0WXJi1P3?[KL809en/@P0ZKgX00<000000?ooo`3oool0@`3oool0
0`00001000000?ooo`060?ooo`<0YZKF1`2l/m450:Vmj0<0XI73=`2Y_NP01000<;<0e_Z^0=Kj[P2M
PkL50>G>`0H0`N^=1P2Y_NP409j5^0H0d[6h202LOK080:Vmj0030000003oool0oooo01l0oooo000V
0?ooo`030000003oool0oooo00H0oooo0P2UY=@90;nfd@L0X8o2>02Y_NP2000`]0H0iLo01033kI08
0:Vmj0<0WXJi1P3?[KL00`000000WGja09en/@0709en/@P0ZKgX00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`060?ooo`80YZKF2@2l/m480:6A`cL0ZKgX0P00<;<60>G>`0@0`N^=202Y_NP3
09j5^0H0d[6h00<0000009am/02LOK001`2LOK080:Vmj0030000003oool0oooo01h0oooo000G0?oo
o`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool01T000000oooo0?ooo`3oool0
0000@00000T0oooo2@2o]]400`3Gk>80X8o20:2?`P060:2?`SP0ZKgX0P00<;@40>G?`0030<?]T02Y
_NP0ZKgX00H0ZKgX00@004_90:Vmj02Y_NP0ZKgX0P2NQ[T70<n]]`8000001`2MO[420>[<]PL0ZKgX
00=000000000003oool0<`3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo
00I000000?ooo`3oool0oooo0000040000090?ooo`T0_;?A00<0f>cR0:6A``2QTL<01P2QTL<h0:Vm
j080032c103Uc/000`31jhd0ZKgX0:Vmj0060:Vmj0040018a`2Y_NP0ZKgX0:Vmj0<0WXFh1P3B/KP2
000000P0W7f`00<0km:e0:Vmj02Y_NP01@2Y_NP00d00000000000?ooo`0N0?ooo`005P3oool00d00
0000oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool20000
00X0oooo1`2o]]430=O/hPP0X8o2=`2Y_NP20010`004000`]03Ucl00iLo00<?]T0T0ZKgX0`00BlT2
0:Vmj00309j6^@3?[KL0cjfg00@0cjfg0`00000709en/@<0j/bf1`2Y_NP00`000000oooo0?ooo`0a
0?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo@0000002
0?ooo`8000002P3oool70;bcd@<0f>cR202QTL<g0:Vmj08003fn00@0032c0>G>`03Uc/00`N^=2@2Y
_NP20018a`80ZKgX0P2NQKP60=:a^0<000001`2LOK030>oB]@L0ZKgX00<000000?ooo`3oool07@3o
ool001P0oooo00I000000?ooo`3ooom000000?oood0000020?ooo`03@000003ooom000000080oooo
00<00000@000003oool02P3oool50;nfd@@0encR1`2PSl820=:ob3T0ZKgX0P3Ucl0;0:Vmj0@004_9
1`3?[KL3000000H0WGja103Zc;H50:Vmj0<0X8Rj00<000000?ooo`3oool0<P3oool01T000000oooo
0?oood000000oooo@0000080oooo00=000000?oood0000000P3oool00`00001000000?ooo`0:0?oo
o`D0_;?A103Hk>870:6A``80dKo9>@2Y_NP20>G>`0/0ZKgX0P00B<L20:Vmj00309j5^03B/KP0d[6h
00@0d[6h0`00000709am/0<0km:e1@2Y_NP30:27^@030000003oool0oooo01`0oooo000F0?ooo`90
00000`3oool00d000000oooo@00000020?ooo`03@000003ooom000000080oooo00<000000?ooo`3o
ool02P3oool40;nfd@D0encR1P2PSl840=:ob4H0ZKgX0`00BlT60<n]]`@000001P2MO[450>[<]PL0
X8Rj00<000000?ooo`3oool0<03oool2@00000<0oooo00=000000?oood0000000P3oool00d000000
oooo@00000020?ooo`030000003oool0oooo00X0oooo102l/m450=S/hPH0XI73103A_lU60:Vmj0<0
04S71P3B/KP4000000H0W7f`1@3_d[D70:27^@030000003oool0oooo01`0oooo000F0?ooo`03@000
003oool0oooo0080oooo00=000000?oood0000000P3oool00d000000oooo@00000020?ooo`030000
04000000oooo00/0oooo0P2o]]470=O/hP@0X8o21P3B_lP50:Vmj0<0X8g0?P2Y_NP3001;b@D0cjfg
1@00000409en/@D0j/bf00<000000:28^P2PR;X01P2PR;X00d000000oooo0?ooo`0_0?ooo`03@000
003oool0oooo0080oooo00=000000?oood0000000P3oool00d000000oooo@00000020?ooo`030000
04000000oooo00/0oooo0P2l/m470=S/hP@0XI731P3A_lT50:Vmj0<0WhVl?P2Y_NP30018a`D0d[6h
1@00000509am/0@0km:e00<000000:27^@2PQkT01P2PQkT00d000000oooo0?ooo`0K0?ooo`005P3o
ool3@00000<0oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3oool0000000h0oooo
203Gk>840:2?`PL0d[o8202PSL0n0:Vmj08004_9103?[KL20:Vmj0@00000102MO[450>[<]P800000
1`2PR;X00`3oool000000?ooo`0_0?ooo`=000000`3oool00d000000oooo0?ooo`020?ooo`05@000
003oool0oooo0?ooo`0000003P3oool80=S/hP@0XI731`3A_lT809n9_3h0ZKgX0P00B<L40=:a^080
ZKgX1000000409am/0D0km:e0P0000070:27^@030?ooo`000000oooo01/0oooo000U0?ooo`03@000
003oool0oooo0140oooo0`3Gk>830:2?`PL0d[o800<0ho_@0:2=`02PSL001`2PSL0n0:Vmj08004_9
0`3?[KL20:Vmj004000GX00000000000000000<0WGja1@3Zc;H3000000H0X8Rj0P3Udl@00`000000
oooo0?ooo`0m0?ooo`03@000003oool0oooo0140oooo0`3Hk>830:6A``L0dKo900<0ho[B09n9_02O
RK`01`2ORK`n0:Vmj08004S70`3B/KP20:Vmj004000@VP0000000000000000@0W7f`103_d[D30000
00H0X8Ni0P3Xf<D00`000000oooo0?ooo`0J0?ooo`00903oool00`000000oooo0?ooo`0C0?ooo`04
001Kd03Gk>80encR0:2?`PL0d[o80`3Snm090:2=`0d0ZKgX0`2LP;<]0:Vmj08004_90P3?[KL40:Vm
j003000GX0000000000000<0WGja1@3Zc;H3000000H0X8Rj0`3Udl@00`000000oooo0?ooo`020?oo
o`E000000P3oool00d000000oooo0?ooo`0_0?ooo`030000003oool0oooo01<0oooo00@006;F0=S/
hP3Hk>80XI731`3A_lT30>?jdPT0WhVl3@2Y_NP309ao/bh0ZKgX00<004S70=:a^03B/KP0102Y_NP0
0`0049X000000000000309am/0D0km:e0`0000060:27^@<0j=S500<000000?ooo`3oool00P3oool5
@0000080oooo00=000000?ooo`3oool03@3oool002@0oooo00<00000@000003oool0503oool2001K
d0L0d[o8103Snm080:2=`080d;S3202Y_NP809b0/bd0ZKgX00<004_90<n]]`3?[KL01@2Y_NP01000
5j0000000000002MO[450>[<]PD00000102PR;X50>GCa0030000003oool0oooo00<0oooo00M00000
0?ooo`3oool0oooo@000003ooom000000300oooo00<00000@000003oool0503oool2001RePL0dKo9
103Sn]8809n9_080f/G5202Y_NP809ao/bh0ZKgX00<004S70=:a^02Y_NP0102Y_NP2000000<0W7f`
103_d[D5000000@0X8Ni1@3Xf<D00`000000oooo0?ooo`030?ooo`07@000003oool0oooo0?oood00
0000oooo@000000>0?ooo`003`3oool5@0000080oooo00=000000?ooo`3oool00P3oool00d000000
oooo0?ooo`020?ooo`05@000003oool0oooo0?ooo`0000005`3oool2001Kd0H0d[o81@3Snm060:2=
`0@0d;S31`2Y_NP809b0/bh0ZKgX00<004_90:Vmj02Y_NP01@2Y_NP00`005j00000009en/@050>[<
]PD00000102PR;X40>GCa00309C?JP000000oooo00@0oooo00=000000?ooo`3oool00`3oool00d00
0000oooo0?ooo`0I0?ooo`E000000P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo
0080oooo00E000000?ooo`3oool0oooo0000000G0?ooo`8006;F1P3A_lT50>?jdPL0WhVl0`3JaLD7
0:Vmj0P0W7nc=P2Y_NP20000000309am/03_d[D0km:e00<0km:e1@0000040:27^@@0j=S500<0VmIe
0000003oool0103oool00d000000oooo0?ooo`030?ooo`03@000003oool0oooo00`0oooo000A0?oo
o`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000003ooom000000080oooo00=0
00000?oood0000000P3oool00`00001000000?ooo`0F0?ooo`8005_@103B_lP60>?kd0D0X8g01P3@
^<<70:Vmj0P0W82c=@2Y_NP2000GX0D0j/bf00<0ZKgX0000000000000`0000030:28^PD0iM?40P2D
cfX00`000000oooo0?ooo`020?ooo`04@000003oool0oooo0?ooo`9000007P3oool01d000000oooo
0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom00000
0080oooo00<00000@000003oool05P3oool2001ReP@0dKo91P3Sn]8609n9_0D0f/G51`2Y_NP809ao
/cD0ZKgX00<001jW0000002LOK00103_d[D00`2Y_NP0000000000003000000<0X8Ni1@3Xf<D209_F
M@030000003oool0oooo0080oooo00A000000?ooo`3oool0oooo0T00000?0?ooo`004@3oool01d00
0000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003o
oom000000080oooo00<000000?ooo`3oool0603oool00`00Fm00d[o80=:ob0080>?kd0@0X8g01@3@
^<<20>7l^@H0ZKgX1`2LP;<20>32^SH0ZKgX00<001NP0>[<]P3Zc;H00P3Zc;H00`2Y_NP00U_D009K
e00300000080X8Rj1@3Udl@309C?JP8000000`3oool01D000000oooo0?ooo`3ooom0000001l0oooo
00M000000?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood0000000P3oool00d00
0000oooo@00000020?ooo`030000003oool0oooo01P0oooo00<006;F0=6ob@3A_lT01`3Sn]8509n9
_0D0f/G50P3RoL<60:Vmj0L0W7nc0P3Q`kXf0:Vmj0D0km:e00<0ZKgX001Id`00FM<00`0000020:27
^@D0j=S50`2KeWD2000000<0oooo00E000000?ooo`3oool0oooo@000000@0?ooo`004@3oool01d00
0000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003o
oom000000080oooo00=000000?ooo`3oool06@3oool60:Vmj004001=aP3Snm00ho_@0>?kd0<0X8g0
1P3@^<<30>7l^@D0ZKgX1`2LP;<30>32^SH0ZKgX00<001NP0>[<]P3Zc;H00`2Y_NP3009Ke0800000
00<0X8Rj0>GCa03Udl@00P3Udl@409C?JP04@00000000000oooo0?ooo`9000000`3oool3@00001d0
oooo00M000000?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood0000000P3oool0
0d000000oooo@00000020?ooo`03@000003oool0oooo01T0oooo1P2Y_NP40>?jdP<0WhVl1P3JaLD3
0>;m``D0ZKgX1`2LOk<30>73^SH0ZKgX0`3_d[D30:Vmj0<005WC0P0000000`2PQkT0j=S50>SHa@02
0>SHa@@0VmIe00A000000000003oool0oooo0T0000030?ooo`=000003P3oool00140oooo00M00000
0?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo
@00000020?ooo`030000003oool0oooo01X0oooo1`2Y_NP01000CLH0ho_@0>?kd02PSL060=2h``D0
hObi102Y_NP609b0/`D0h<:j1`2OQkT_0:Vmj080j/bf102Y_NP4009Ke0@0iM?41@2DcfX20?ooo`03
0000003oool0oooo02@0oooo00M000000?ooo`3oool0oooo@000003ooom000000080oooo00=00000
0?oood0000000P3oool00d000000oooo@00000020?ooo`030000003oool0oooo01X0oooo1`2Y_NP2
0>?jdP<0WhVl1@3JaLD50>;m``@0ZKgX1P2LOk<50>73^PL0WhJh;`2Y_NP20>oB]@@0ZKgX1000FM<4
0>SHa@D0VmIe0P3oool00`000000oooo0?ooo`0E0?ooo`00403oool2@00000@0oooo00=000000?oo
o`3oool00P3oool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo0000040000007@3oool7
0:Vmj08004g61P3@^<<70>7l^@@0ZKgX1@2LP;<40>32^P030<?UOP2OQkT0WhNi00H0WhNi=@2Y_NP0
100AI]/00U_D009Ke002Fm@30>GCa0H0U<mZ00<0oooo0000003oool0903oool2@00000@0oooo00=0
00000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo000004000000
7@3oool70:Vmj080ho[B00<0WhVl0=[5a@3JaLD00`3JaLD70>;m``@0ZKgX1@2LOk<40>73^P030<7S
N`2OQ[P0WhJh00H0WhJh=@2Y_NP0100IJmd005WC001Id`00FM<30>SHa@H0VmIe00<0oooo0000003o
ool05P3oool002<0oooo00<000000?ooo`3oool07@3oool70:Vmj08004g6103@^<<60>7l^@H0ZKgX
102LP;<50>32^P80`nEn202OQkTd0:Vmj0<04FKK00<00U_D0>GCa03Udl@00P2Y_NP509C?JP80oooo
00=000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0M0?ooo`L0ZKgX00<002NU0=[5a@3JaLD0
0`3JaLD60>;m``H0ZKgX102LOk<50>73^P80`N=k202OQ[Pd0:Vmj0<06F_M00<005WC0>SHa@3Xf<D0
0P2Y_NP509_FM@80oooo00=000000?ooo`3oool0503oool002<0oooo00<00000@000003oool07P3o
ool70:Vmj08004g60`3@^<<20>7l^@X0ZKgX0`2LP;<50>32^P<0`nEn1`2OQkT20<VV]S/0ZKgX00<0
00BA09C?JP2DcfX00P2DcfXj0?ooo`03000004000000oooo01h0oooo1`2Y_NP00`009jD0f/G50=[5
a@020=[5a@80h_g32P2Y_NP309ao/`D0hL>j0`31hg/709n6^080bJFd>`2Y_NP00`0008/0VmIe09_F
M@0209_FMAT0oooo000S0?ooo`030000003oool0oooo01l0oooo202Y_NP20=2h``030>7l^@2Y_NP0
ZKgX00X0ZKgX0`2LP;<50>32^P@0`nEn1P2OQkT30<VV]S/0ZKgX00@0oooo09C?JP2DcfX0U<mZ0`00
194g0?ooo`030000003oool0oooo01l0oooo202Y_NP20=[5a@030>;m``2Y_NP0ZKgX00X0ZKgX0`2L
Ok<50>73^P<0`N=k1`2OQ[P30<VU]3/0ZKgX00@0oooo09_FM@2KeWD0VmIe0`0008/F0?ooo`008`3o
ool00`00001000000?ooo`0P0?oooaL0ZKgX00<0W82c0>32^P3P`[X00`3P`[X50<?UOPD0WhNi1@39
Y[H709ak[S40ZKgX103oool309C?JP8000BA=`3oool00`00001000000?ooo`0P0?oooaL0ZKgX00<0
W7nc0>73^P3Q`kX00`3Q`kX50<7SN`D0WhJh1@39YK@709ai[340ZKgX103oool309_FM@80002;5P3o
ool000d0oooo1D0000020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool0
0d000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo5P2Y_NP00`2LP;<0h<:j0>32^P03
0>32^PD0`nEn1@2OQkT50<VV]PP0W7^^;02Y_NP80?ooo`<0U<mZ0P00194Q0?ooo`E000000P3oool0
0d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0Q0?oooaH0ZKgX00<0W7nc0>73^P3Q`kX00`3Q`kX50<7SN`D0WhJh1@39YK@8
09ai[2`0ZKgX203oool309_FM@80002;5P3oool000l0oooo00M000000?ooo`3oool0oooo@000003o
oom000000080oooo00=000000?oood0000000P3oool00d000000oooo@00000030?ooo`03@000003o
ool0oooo0280oooo5@2Y_NP50>32^P030<?UOP2Y_NP0ZKgX00@0`nEn0`2OQkT50<VV]P030000002L
Njh0W7^^00L0W7^^:@2Y_NP;0?ooo`80U<mZ00<000BA0?ooo`3oool08P3oool01d000000oooo0?oo
o`3ooom000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom0000000<0
oooo00=000000?ooo`3oool08P3ooolE0:Vmj0D0hL>j00<0`N=k0:Vmj02Y_NP01031hg/309n6^0D0
bJFd0P00000809ai[2T0ZKgX2`3oool209_FM@030000R`3oool0oooo01D0oooo000?0?ooo`03@000
003oool0oooo00<0oooo00I000000?ooo`3ooom000000?oood0000020?ooo`03@000003ooom00000
0080oooo00<000000?ooo`3oool0903ooolE0:Vmj0@0h<:j102Y_NP00`009JH0`nEn0<?UOP0209n7
^@H0bJJf0P00000809ak[P030>o@/`2Y_NP0ZKgX0280ZKgX403oool00`2DcfX000BA0?ooo`0S0?oo
o`03@000003oool0oooo00<0oooo00I000000?ooo`3ooom000000?oood0000020?ooo`03@000003o
oom000000080oooo00<000000?ooo`3oool0903ooolE0:Vmj0@0hL>j102Y_NP30<7SN`<0WhJh1@39
YK@2000000P0W7V/00<0lmJ`0:Vmj02Y_NP08P2Y_NP@0?ooo`0309_FM@0008/0oooo01H0oooo000?
0?ooo`04@000003oool0oooo0?ooo`9000000`3oool00d000000oooo@00000020?ooo`03@000003o
oom000000080oooo00<00000@000003oool09@3ooolE0:Vmj080h<:j00<0`nEn0:Vmj02Y_NP00`2Y
_NP010009JH0`nEn0<?UOP2OQkT50<VV]P<000001`2LNjh30>o@/`D0ZKgX0`2OQ;HI0:Vmj1<0oooo
00<0U<mZ0?ooo`3oool08P3oool014000000oooo0?ooo`3oool2@00000<0oooo00=000000?oood00
00000P3oool00d000000oooo@00000020?ooo`03000004000000oooo02D0oooo5@2Y_NP20>73^P03
0<7SN`2Y_NP0ZKgX00<0ZKgX00@001bN0<7SN`2OQ[P0WhJh1@39YK@3000000L0W7V/0`3ce[050:Vm
j0<0WhBe6@2Y_NPC0?ooo`0309_FM@3oool0oooo01D0oooo000?0?ooo`05@000003oool0oooo0?oo
od000000103oool00d000000oooo@00000020?ooo`03@000003ooom000000080oooo00<000000?oo
o`3oool09P3ooolD0:Vmj080h<:j1`2Y_NP2000UYPH0bJJf0`00000709ak[P@0km2c1`2OQ;HE0:Vm
j3`0oooo00E000000?ooo`3oool0oooo@00000040?ooo`03@000003ooom000000080oooo00=00000
0?oood0000000P3oool00`000000oooo0?ooo`0V0?oooa@0ZKgX0P3Q`kX70:Vmj003000LWP31hg/0
WhJh00D0bJFd0`00000709ai[0@0lmJ`1`2OQ;DE0:Vmj2l0oooo000>0?ooo`9000000`3oool3@000
00<0oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom0000002T0oooo702Y_NP2
000UYPH0bJJf0`00000609ak[P@0km2c00<0000009n4]P2OQ;H01P2OQ;H>0:Vmj440oooo0T000003
0?ooo`=000000`3oool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo0?oood000000:@3o
oolL0:Vmj08001bN1P39YK@4000000D0W7V/103ce[000`000000WhBe09n4]@0609n4]@l0ZKgX=03o
ool004d0oooo702Y_NP2000UYP@0bJJf00<000000:Vmj00000000P00000509ak[P@0km2c0P000007
09n4]P`0ZKgXPP3ooolL0:Vmj003000LWP39YK@0bJFd00<0bJFd00<000000:Vmj00000000P000005
09ai[0@0lmJ`0P00000709n4]@d0ZKgX=P3oool004h0oooo702Y_NP00`009JH0bJJf0<VV]P020<VV
]P80ZKgX0`00000409ak[P@0km2c0`00000609n4]P80ZWZO202Y_NR60?oooa`0ZKgX00<001bN0<VU
]039YK@00P39YK@20:Vmj0<000001@2LNJ`30??F/0<000001P2OQ;D20:]kW`P0ZKgX>P3oool004l0
oooo6`2Y_NP2000UYP<0bJJf0`2Y_NP2000000@0W7^^103_d;<3000000H0WhBf0`2ZNYl50:Vmj8T0
oooo6`2Y_NP00`0079h0bJFd0<VU]0020<VU]0<0ZKgX0P00000409ai[0@0lmJ`0`00000609n4]@<0
Zg^O1@2Y_NPl0?ooo`00D@3ooolJ0:Vmj003000UYP39Y[H0bJJf00D0ZKgX00@0000009ak[P2LNjh0
W7^^103_d;<4000000D0WhBf1@2ZNYn?0?oooaX0ZKgX00<001bN0<VU]039YK@01@2Y_NP2000000<0
W7V/0`3ce[04000000D0WhBe1@2[Nim00?ooo`00DP3ooolJ0:Vmj080bJJf1@2Y_NP010000000W7^^
09ak[P2LNjh40>o@/`030:Vmj0000000000000800000102OQ;H50:YjWi00oooo6P2Y_NP20<VU]0D0
ZKgX0P00000309ai[0<0lmJ`00<0ZKgX0000000000000P00000409n4]@D0Zg^O@03oool005<0oooo
6@2Y_NP00`009JH0ZKgX0:Vmj0050:Vmj0030000002LNjh0km2c00<0km2c0`2Y_NP3000000<0WhBf
1P2ZNYnA0?oooaT0ZKgX00<001bN0:Vmj02Y_NP01@2Y_NP00`000000W7V/09ai[0030??F/0<0ZKgX
0`00000309n4]@H0Zg^O@03oool005@0oooo802Y_NP00`000000W7^^0>o@/`030>o@/`@0ZKgX0P00
000309n4]PH0ZWZOTP3ooolQ0:Vmj080W7V/0`3ce[040:Vmj08000000`2OQ;D60:]kWd00oooo001E
0?ooob00ZKgX103_d;<30:Vmj080oooo00@000jB0000002OQ;H0WhBf1`2ZNYnC0?ooob00ZKgX00@0
00000??F/03ce[00lmJ`0`2Y_NP20?ooo`04000;S`000000WhBe09n4]@L0Zg^O@03oool005H0oooo
802Y_NP30>o@/`D0oooo0P003Y800`000000WhBf0:YjW`050:YjWiD0oooo802Y_NP30??F/0D0oooo
0P002hl00`000000WhBe0:]kW`050:]kWd40oooo001G0?oooa`0ZKgX303oool2000>TPL0ZWZOUP3o
oolL0:Vmj0`0oooo0P002hl70:]kWd40oooo001H0?oooaT0ZKgX3P3oool2000>TPL0ZWZOU`3ooolI
0:Vmj0h0oooo0P002hl70:]kWd40oooo001I0?oooaD0ZKgX4@3oool2000>TPL0ZWZOV03ooolE0:Vm
j140oooo0P002hl70:]kWd40oooo001J0?oooa80ZKgX4`3oool2000>TPL0ZWZOV@3ooolB0:Vmj1<0
oooo0P002hl70:]kWd40oooo001K0?ooo`h0ZKgX5`3oool2000>TPH0ZWZOVP3oool>0:Vmj1L0oooo
0P002hl60:]kWd40oooo001L0?ooo`L0ZKgX7@3oool2000>TPH0ZWZOV`3oool70:Vmj1d0oooo0P00
2hl60:]kWd40oooo001M0?ooo`@0ZKgX7`3oool2000>TPH0ZWZOW03oool40:Vmj1l0oooo0P002hl6
0:]kWd40oooo00200?ooo`8000jB1@2ZNYo00?ooo`8000^?1@2[Nim20?ooo`00P@3oool00`003Y80
ZWZO0:YjW`030:YjWl40oooo00<000^?0:]kW`2[Nil00`2[Nim20?ooo`00P@3oool00`003Y80ZWZO
0:YjW`030:YjWl40oooo00<000^?0:]kW`2[Nil00`2[Nim20?ooo`00P@3oool2000>TP@0ZWZO`@3o
ool2000;S`@0Zg^O@P3oool00840oooo0P003Y840:YjWl40oooo0P002hl40:]kWd80oooo00220?oo
o`03000>TP2ZNYl0ZWZO0080ZWZO`P3oool00`002hl0Zg^O0:]kW`020:]kWd80oooo00220?ooo`03
000>TP2ZNYl0ZWZO0080ZWZO`P3oool00`002hl0Zg^O0:]kW`020:]kWd80oooo00220?ooo`03000>
TP2ZNYl0ZWZO0080ZWZO`P3oool00`002hl0Zg^O0:]kW`020:]kWd80oooo00220?ooo`04000>TP2Z
NYl0ZWZO0:YjWl<0oooo00@000^?0:]kW`2[Nil0Zg^O@`3oool008<0oooo0`2ZNYo40?ooo`<0Zg^O
@`3oool008<0oooo00<000jB0:YjW`2ZNYl0a03oool00`002hl0Zg^O0:]kW`130?ooo`00P`3oool0
0`003Y80ZWZO0:YjW`340?ooo`03000;S`2[Nil0Zg^O04<0oooo00230?ooo`03000>TP2ZNYl0ZWZO
0<@0oooo00<000^?0:]kW`2[Nil0@`3oool008@0oooo0P2ZNYo50?ooo`80Zg^O@`3oool008@0oooo
0P2ZNYo50?ooo`80Zg^O@`3oool008@0oooo0P2ZNYo50?ooo`80Zg^O@`3oool008@0oooo00<000jB
0?ooo`3oool0a03oool00`002hl0oooo0?ooo`120?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00I`3oool00d000000oooo0?ooo`060?ooo`03@000003oool0oooo0;/0oooo00=0
00000?ooo`3oool01P3oool00d000000oooo0?ooo`1F0?ooo`00IP3oool00d000000oooo0?ooo`08
0?ooo`03@000003oool0oooo0;T0oooo00=000000?ooo`3oool0203oool00d000000oooo0?ooo`1E
0?ooo`00I@3oool00d000000oooo0?ooo`020?ooo`=000001@3oool00d000000oooo0?ooo`2g0?oo
o`03@000003oool0oooo00<0oooo0d0000040?ooo`03@000003oool0oooo05@0oooo001U0?ooo`03
@000003oool0oooo0080oooo00=000000?ooo`3oool01@3oool00d000000oooo0?ooo`2g0?ooo`03
@000003oool0oooo0080oooo00A000000?ooo`3ooom00000103oool00d000000oooo0?ooo`1D0?oo
o`00I@3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00D0oooo00=000000?ooo`3o
ool0]`3oool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo@00000@0oooo00=000000?oo
o`3oool0E03oool006D0oooo00=000000?ooo`3oool00P3oool3@00000D0oooo00=000000?ooo`3o
ool0]`3oool00d000000oooo0?ooo`030?ooo`=00000103oool00d000000oooo0?ooo`1D0?ooo`00
IP3oool00d000000oooo0?ooo`080?ooo`03@000003oool0oooo0;T0oooo00=000000?ooo`3oool0
103oool01D000000oooo0?ooo`3ooom0000005L0oooo001W0?ooo`03@000003oool0oooo00H0oooo
00=000000?ooo`3oool0^`3oool00d000000oooo0?ooo`020?ooo`9000000P3oool00d000000oooo
0?ooo`1F0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00N03oool5@0000080oooo00=000000?ooo`3oool0_@3oool5
@0000080oooo00=000000?ooo`3oool0A`3oool007X0oooo00M000000?ooo`3oool0oooo@000003o
oom000000<00oooo00M000000?ooo`3oool0oooo@000003ooom0000004P0oooo001j0?ooo`03@000
003oool0oooo00<0oooo00=000000?ooo`3oool0_P3oool00d000000oooo0?ooo`030?ooo`03@000
003oool0oooo04H0oooo001j0?ooo`04@000003oool0oooo0?ooo`900000`@3oool014000000oooo
0?ooo`3oool2@00004T0oooo001j0?ooo`05@000003oool0oooo0?oood000000`P3oool01D000000
oooo0?ooo`3ooom0000004X0oooo001i0?ooo`9000000`3oool3@0000;l0oooo0T0000030?ooo`=0
0000B03oool00?l0ooooT@3oool008P0oooo00<00000@000003oool0a03oool00`00001000000?oo
o`0n0?ooo`00QP3oool200000080oooo00<000000?ooo`3oool0`03oool200000080oooo00<00000
0?ooo`3oool0?03oool008<0oooo0`0000040?ooo`030000003oool0oooo0;d0oooo0`0000040?oo
o`030000003oool0oooo03`0oooo00210?ooo`8000000`3oool409bhj`030?ooo`000000oooo0;/0
oooo0P0000030?ooo`@0W;S[00<0oooo0000003oool0?03oool007h0oooo0`0000000`2L^>]00000
09bhj`0709bhj`030?ooo`000000oooo0;L0oooo0`0000000`2L^>]0000009bhj`0709bhj`030?oo
o`000000oooo03/0oooo001k0?ooo`<0000000@0oooo0:Vmj02Y_NP0ZKgX2@2L^>/00`3oool00000
0?ooo`2d0?ooo`<0000000@0oooo0:Vmj02Y_NP0ZKgX2@2L^>/00`3oool000000?ooo`0k0?ooo`00
N@3oool200000003@000003oool0ZKgX00D0ZKgX2@2L^>/00`3oool000000?ooo`2a0?ooo`800000
00=000000?ooo`2Y_NP01@2Y_NP909bhj`030?ooo`000000oooo03X0oooo001D0?ooo`E000000P3o
ool00d000000oooo0?ooo`0H0?ooo`<0000000<0oooo0:Vmj02Y_NP01`2Y_NP709bhj`<0ZKgX00<0
00000?ooo`3oool0R`3oool5@0000080oooo00=000000?ooo`3oool0603oool3000000030?ooo`2Y
_NP0ZKgX00L0ZKgX1`2L^>/30:Vmj0030000003oool0oooo03T0oooo001F0?ooo`07@000003oool0
oooo0?oood000000oooo@000000G0?ooo`8000000P3oool<0:Vmj0@0W;S[1@2Y_NP00`3oool00000
0?ooo`2=0?ooo`07@000003oool0oooo0?oood000000oooo@000000G0?ooo`8000000P3oool<0:Vm
j0@0W;S[1@2Y_NP00`3oool000000?ooo`0i0?ooo`00EP3oool01d000000oooo0?ooo`3ooom00000
0?oood000000503oool300000003@000002Y_NP0ZKgX01L0ZKgX00<0oooo0000003oool0S03oool0
1d000000oooo0?ooo`3ooom000000?oood000000503oool300000003@000002Y_NP0ZKgX01L0ZKgX
00<0oooo0000003oool0>03oool005H0oooo00M000000?ooo`3oool0oooo@000003ooom000000180
oooo0P00000M0:Vmj0030?ooo`000000oooo08`0oooo00M000000?ooo`3oool0oooo@000003ooom0
00000180oooo0P00000M0:Vmj0030?ooo`000000oooo03P0oooo001F0?ooo`07@000003oool0oooo
0?oood000000oooo@000000?0?ooo`<00000802Y_NP00d00000000000?ooo`2;0?ooo`07@000003o
ool0oooo0?oood000000oooo@000000?0?ooo`<00000802Y_NP00d00000000000?ooo`0g0?ooo`00
E@3oool2@00000@0oooo00=000000?ooo`3oool0303oool2000000030:Vmj4000000ZKgX0240ZKgX
00<0oooo0000003oool0R@3oool2@00000@0oooo00=000000?ooo`3oool0303oool2000000030:Vm
j4000000ZKgX0240ZKgX00<0oooo0000003oool0=P3oool006L0oooo0`00000W0:Vmj0030000003o
ool0oooo09X0oooo0`00000W0:Vmj0030000003oool0oooo03D0oooo001T0?ooo`80000000=00000
0?ooo`2Y_NP0:02Y_NP00`3oool000000?ooo`2G0?ooo`80000000=000000?ooo`2Y_NP0:02Y_NP0
0`3oool000000?ooo`0e0?ooo`00HP3oool2000000030?ooo`2Y_NP0ZKgX02/0ZKgX0P0000050?oo
o`03@000003oool0oooo08d0oooo0P0000000`3oool0ZKgX0:Vmj00[0:Vmj08000001@3oool00d00
0000oooo0?ooo`0]0?ooo`00G`3oool3000000030?ooo`2Y_NP0ZKgX02h0ZKgX00<000000?ooo`3o
ool00P3oool00d000000oooo@000002;0?ooo`<0000000<0oooo0:Vmj02Y_NP0;P2Y_NP00`000000
oooo0?ooo`020?ooo`03@000003ooom0000002h0oooo001M0?ooo`80000000=000000:Vmj02Y_NP0
<P2Y_NP00`000000oooo0?ooo`030?ooo`03@000003oool0oooo08L0oooo0P0000000d000000ZKgX
0:Vmj00b0:Vmj0030000003oool0oooo00<0oooo00=000000?ooo`3oool0;03oool005X0oooo0`00
000g0:Vmj0040?ooo`000000oooo0?ooo`900000Q`3oool3000003L0ZKgX00@0oooo0000003oool0
oooo0T00000_0?ooo`00F03oool2000000030?ooo`2Y_NP0ZKgX03P0ZKgX00@000000?ooo`3ooom0
0000QP3oool2000000030?ooo`2Y_NP0ZKgX03P0ZKgX00@000000?ooo`3ooom00000<03oool003/0
oooo00=000000?ooo`3oool05`3oool3000000030:Vmj4000000ZKgX03X0ZKgX00=000000000003o
ool00d00001W0?ooo`03@000003oool0oooo01L0oooo0`0000000`2Y_NQ000000:Vmj00j0:Vmj003
@00000000000oooo00=00000;P3oool003X0oooo00=000000?oood0000005P3oool2000000040?oo
o`2Z[m/0ZZoK0:Z_fcd0ZKgX00<000000?ooo`3oool0J03oool00d000000oooo@000000F0?ooo`80
000000@0oooo0:Z_f`2Z[m/0ZZoK?@2Y_NP00`000000oooo0?ooo`0`0?ooo`00?03oool00d000000
oooo0?ooo`0A0?ooo`80000000=000000?ooo`2Z[m/01@2Z[m/m0:Vmj0030000003oool0oooo06T0
oooo00=000000?ooo`3oool04@3oool200000003@000003oool0ZZoK00D0ZZoK?@2Y_NP00`000000
oooo0?ooo`0_0?ooo`00>P3oool2@0000180oooo0P0000020?ooo`P0ZZoK1`2Y_NP30:FQdS@0ZKgX
00<000000?ooo`3oool0IP3oool2@0000180oooo0P0000020?ooo`P0ZZoK1`2Y_NP30:FQdS@0ZKgX
00<000000?ooo`3oool0;P3oool003X0oooo00=000000?ooo`3oool03P3oool300000080oooo0`2V
_>T80:Z_f`@0ZKgX1@2UXM8d0:Vmj0030000003oool0oooo06H0oooo00=000000?ooo`3oool03P3o
ool300000080oooo0`2V_>T80:Z_f`@0ZKgX1@2UXM8d0:Vmj0030000003oool0oooo02h0oooo000j
0?ooo`=000002`3oool3000000030:JljD000000Y[cY00H0Y[cY202Z[m/90:FQdS@0ZKgX00<00000
0?ooo`3oool0I@3oool3@00000/0oooo0`0000000`2V_>U000000:Jlj@060:Jlj@P0ZZoK2@2UXM8d
0:Vmj0030000003oool0oooo02d0oooo00160?ooo`80000000@0oooo0:Vmj02Y_NP0ZKgX202V_>T6
0:Z_f`<0`MS[202UXM8e0:Vmj0030000003oool0oooo0700oooo0P000000103oool0ZKgX0:Vmj02Y
_NP80:Jlj@H0ZZoK0`31f>/80:FQdSD0ZKgX00<000000?ooo`3oool0;03oool004<0oooo0`000000
0d000000ZKgX0:Vmj0040:Vmj0P0Y[cY0`2Z[m/50<7Hj`T0YJ7B=02Y_NP00`000000oooo0?ooo`1]
0?ooo`<0000000=000000:Vmj02Y_NP0102Y_NP80:Jlj@<0ZZoK1@31f>/90:FQdS@0ZKgX00<00000
0?ooo`3oool0;03oool00440oooo0P00000<0:Vmj0L0Y[cY2031f>/70:FQdP80`[S@=02Y_NP00`00
0000oooo0?ooo`1Z0?ooo`800000302Y_NP70:Jlj@P0`MS[1`2UXM820<:hd3@0ZKgX00<000000?oo
o`3oool0:`3oool003h0oooo0`00000?0:Vmj0L0S;;`1`31f>/60:FQdP@0`[S@<`2Y_NP00d000000
00000?ooo`1W0?ooo`<000003`2Y_NP708bbl0L0`MS[1P2UXM840<:hd3<0ZKgX00=000000000003o
ool0:`3oool003`0oooo0P0000000`3oool0ZKgX@000000@0:Vmj0P0S;;`1P31f>/30:FQdPL0`[S@
1P2Y_NP30:2>`BX0ZKgX00<000000?ooo`3oool0I03oool2000000030?ooo`2Y_NQ000000100ZKgX
202</_060<7Hj`<0YJ7B1`32^=060:Vmj0<0X8k1:P2Y_NP00`000000oooo0?ooo`0Z0?ooo`00>@3o
ool3000000030?ooo`2Y_NP0ZKgX0180ZKgX2@2</_050<7Hj`80YJ7B2@32^=090:2>`BX0ZKgX00<0
00000?ooo`3oool0H03oool3000000030?ooo`2Y_NP0ZKgX0180ZKgX2@2</_050<7Hj`80YJ7B2@32
^=090:2>`BX0ZKgX00<000000?ooo`3oool0:@3oool003L0oooo0P0000000d000000ZKgX0:Vmj00F
0:Vmj0H0S;;`0`2Y_NP5072UlPT0`[S@00<0f_ON0:2>`@2PS/401`2PS/4Z0:Vmj0030?ooo`000000
oooo05h0oooo0P0000000d000000ZKgX0:Vmj00F0:Vmj0H0S;;`0`2Y_NP5072UlPT0`[S@00<0f_ON
0:2>`@2PS/401`2PS/4Z0:Vmj0030?ooo`000000oooo02T0oooo000d0?ooo`<000006`2Y_NP408bb
l0D0ZKgX1P1`YO870<:hd0<0f_ON2@2PS/4Z0:Vmj0030000003oool0oooo05X0oooo0`00000K0:Vm
j0@0S;;`1@2Y_NP6072UlPL0`[S@0`3Jmmh90:2>`BX0ZKgX00<000000?ooo`3oool0:03oool00340
oooo0`0000000d000000ZKgX0:Vmj00U0:Vmj0H0L:Gb1@32^=040=[ggPP0X8k10P3C_lHY0:Vmj003
@00000000000oooo05L0oooo0`0000000d000000ZKgX0:Vmj00U0:Vmj0H0L:Gb1@32^=040=[ggPP0
X8k10P3C_lHY0:Vmj003@00000000000oooo02P0oooo000_0?ooo`800000:`2Y_NP6072UlP@0`[S@
1P3Jmmh60:2>`@@0dko6:@2Y_NP00`000000oooo0?ooo`1D0?ooo`800000:`2Y_NP6072UlP@0`[S@
1P3Jmmh60:2>`@@0dko6:@2Y_NP00`000000oooo0?ooo`0W0?ooo`00;03oool200000003@000002Y
_NP0ZKgX02`0ZKgX1P1`YO820<:hd0L0f_ON1@2PS/450=>oaPH0ZKgX0`2MQ;LQ0:Vmj0030000003o
ool0oooo0500oooo0P0000000d000000ZKgX0:Vmj00/0:Vmj0H0L:Gb0P32^=070=[ggPD0X8k11@3C
_lH60:Vmj0<0WHBg8@2Y_NP00`000000oooo0?ooo`0V0?ooo`00:P3oool2000000030?ooo`2Y_NP0
ZKgX02l0ZKgX1P17Snh90=[ggP@0X8k11P3C_lH909f4]b00ZKgX00<0oooo0000003oool00`3oool5
@0000080oooo00=000000?ooo`3oool0@@3oool2000000030?ooo`2Y_NP0ZKgX02l0ZKgX1P17Snh9
0=[ggP@0X8k11P3C_lH909f4]b00ZKgX00<0oooo0000003oool00`3oool5@0000080oooo00=00000
0?ooo`3oool06@3oool002P0oooo0P0000000`3oool0ZKgX0:Vmj00b0:Vmj0P0Aho^1P3Jmmh30:2>
`@H0dko600<0eo^a09f4]`2MQ;L01`2MQ;LQ0:Vmj003@000003oool0oooo00@0oooo00M000000?oo
o`3oool0oooo@000003ooom000000400oooo0P0000000`3oool0ZKgX0:Vmj00b0:Vmj0P0Aho^1P3J
mmh30:2>`@H0dko600<0eo^a09f4]`2MQ;L01`2MQ;LQ0:Vmj003@000003oool0oooo00@0oooo00M0
00000?ooo`3oool0oooo@000003ooom0000001X0oooo000W0?ooocT0ZKgX1@17Snh30:Vmj00301A^
g`3Jmmh0f_ON00<0f_ON00<0X8k10=>oaP3C_lH01@3C_lH20=Ok/@T0WHBg8@2Y_NP00`000000oooo
0?ooo`030?ooo`07@000003oool0oooo0?oood000000oooo@000000o0?ooocT0ZKgX1@17Snh30:Vm
j00301A^g`3Jmmh0f_ON00<0f_ON00<0X8k10=>oaP3C_lH01@3C_lH20=Ok/@T0WHBg8@2Y_NP00`00
0000oooo0?ooo`030?ooo`07@000003oool0oooo0?oood000000oooo@000000J0?ooo`008`3oool0
0d000000oooo0?ooo`020?oood40ZKgX1@0DK]l70=>oaP<0eo^a202MQ;L20>?<`0d0ZKgX0`2NQKP@
0:Vmj0030?ooo`000000oooo00<0oooo00M000000?ooo`3oool0oooo@000003ooom0000003/0oooo
00=000000?ooo`3oool00P3ooom10:Vmj0D056kO1`3C_lH30=Ok/@P0WHBg0P3Sc<0=0:Vmj0<0WXFh
402Y_NP00`3oool000000?ooo`030?ooo`07@000003oool0oooo0?oood000000oooo@000000J0?oo
o`008P3oool00d000000oooo@00000020?ooo`03000004000000ZKgX0400ZKgX1@0DK]l50=>oaP@0
eo^a202MQ;L30>?<`0P0ZKgX202NQKP@0:Vmj0030000003oool0oooo0080oooo00M000000?ooo`3o
ool0oooo@000003ooom0000003X0oooo00=000000?oood0000000P3oool00`00001000000:Vmj010
0:Vmj0D056kO1@3C_lH40=Ok/@P0WHBg0`3Sc<080:Vmj0P0WXFh402Y_NP00`000000oooo0?ooo`02
0?ooo`07@000003oool0oooo0?oood000000oooo@000000J0?ooo`008P3oool00d000000oooo@000
00020?ooo`04@000003oool0oooo0?ooo`@0ZKgX0`2UY=@i0:Vmj0@056kO1@3C_lH50=Ok/@H0WHBg
103Sc<080:Vmj0P0WXFh402Y_NP01400000000000?ooo`3oool2@00000@0oooo00=000000?ooo`3o
ool0>@3oool00d000000oooo@00000020?ooo`04@000003oool0oooo0?ooo`@0ZKgX0`2UY=@i0:Vm
j0@056kO1@3C_lH50=Ok/@H0WHBg103Sc<080:Vmj0P0WXFh402Y_NP01400000000000?ooo`3oool2
@00000@0oooo00=000000?ooo`3oool06@3oool00280oooo00=000000?oood0000000P3oool00`00
0000oooo0?ooo`020?ooo`L0YJCD>@2Y_NP401A^g`<0dko61P3Gnk4609f4]`D0hlc0202Y_NP809j5
^100ZKgX00<0oooo0000003oool0@P3oool00d000000oooo@00000020?ooo`030000003oool0oooo
0080oooo1`2UY=@i0:Vmj0@056kO0`3C_lH60=Ok/@H0WHBg1@3Sc<080:Vmj0P0WXFh402Y_NP00`3o
ool000000?ooo`0R0?ooo`008P3oool00d000000oooo@00000020?ooo`03@000003oool0oooo00<0
oooo202UY=@h0:Vmj003001BcP0DK]l056kO0080dko61`3Gnk4509f4]`D0hlc00P31jhd70:Vmj0L0
WXFh0P3B/;L@0:Vmj0030000003oool0oooo0440oooo00=000000?oood0000000P3oool00d000000
oooo0?ooo`030?ooo`P0YJCD>02Y_NP00`00D/h056kO01A^g`020=>oaPL0eo^a1@2MQ;L50>?<`080
`N^=1`2Y_NP709j5^080d[2g402Y_NP00`000000oooo0?ooo`0Q0?ooo`008`3oool01D000000oooo
0?ooo`3oool0000000D0oooo2@2UY=@g0:Vmj08005;>0P0DK]l0103C_lH0eo^a0:Vmj02Y_NP50=Ok
/@<0WHBg1P3Sc<030<7[S@H0ZKgX1`2NQKP30=:`]`l0ZKgX00<0oooo0000003oool0@P3oool01D00
0000oooo0?ooo`3oool0000000D0oooo2@2UY=@g0:Vmj08005;>0P0DK]l0103C_lH0eo^a0:Vmj02Y
_NP50=Ok/@<0WHBg1P3Sc<030<7[S@H0ZKgX1`2NQKP30=:`]`l0ZKgX00<0oooo0000003oool08@3o
ool002H0oooo00<00000@000003oool01@3oool70:FTe080`;OA?`2Y_NP01000=;L0eo^a0=Ok/@3G
nk4309f4]`D0hlc01031jhd60:Vmj0H0WXFh103B/;L50:Vmj0<0WGja202Y_NP00d000000oooo0?oo
o`140?ooo`03000004000000oooo00D0oooo1`2UY=@20<2gdCl0ZKgX00@003Bg0=Ok/@3Gnk40eo^a
0`2MQ;L50>?<`0@0`N^=1P2Y_NP609j5^0@0d[2g1@2Y_NP309en/@P0ZKgX00=000000?ooo`3oool0
803oool002H0oooo00<000000?ooo`3oool01P3oool40:FTe0D0`;OA?`2Y_NP00`00=;L0eo^a0=Ok
/@0209f4]`D0hlc01P31jhd60:Vmj0@0WXFh1P3B/;L809en/@L0ZKgX00<0oooo0000003oool0A03o
ool00`000000oooo0?ooo`060?ooo`@0YJCD1@30]m4o0:Vmj003000d]`3Gnk40eo^a0080WHBg1@3S
c<060<7[S@H0ZKgX102NQKP60=:`]`P0WGja1`2Y_NP00`3oool000000?ooo`0P0?ooo`009P3oool0
0`00001000000?ooo`060?ooo`<0YJCD1`30]m450:Vmj0<0XI33=`2Y_NP01000=;L0eo^a0=Ok/@2M
Q;L50>?<`0@0`N^=202Y_NP409j5^0H0d[2g202MO[480:Vmj0030?ooo`000000oooo04<0oooo00<0
0000@000003oool01P3oool30:FTe0L0`;OA1@2Y_NP30:6@`cL0ZKgX00@003Bg0=Ok/@3Gnk40WHBg
1@3Sc<040<7[S@P0ZKgX102NQKP60=:`]`P0WGja202Y_NP00`3oool000000?ooo`0O0?ooo`00403o
ool5@0000080oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03@000003o
ool0oooo0080oooo00<000000?ooo`3oool01`3oool:0<2gd@P0XI33=`2Y_NP2000d]`D0hlc000<0
`N^=0:Vmj02Y_NP01P2Y_NP01000ALD0ZKgX0:Vmj02Y_NP309j5^0H0d[2g00<0000009en/@2MO[40
1`2MO[480:Vmj0030000003oool0oooo02`0oooo1D0000020?ooo`03@000003oool0oooo0080oooo
00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo
2P30]m480:6@`cL0ZKgX0P00=;L50>?<`0030<7[S@2Y_NP0ZKgX00H0ZKgX00@004G50:Vmj02Y_NP0
ZKgX0`2NQKP60=:`]`030000002MO[40WGja00L0WGja202Y_NP00`000000oooo0?ooo`0N0?ooo`00
4P3oool01d000000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@00000020?oo
o`03@000003ooom0000000<0oooo00=000000?ooo`3oool0203oool80<2gd@030=O[hP2QT<<0XI33
00H0XI33>02Y_NP00`00?;d003Bg0>?<`0020>?<`0030<7[S@2Y_NP0ZKgX00L0ZKgX0P00ALD20:Vm
j080WXFh1`3B/;L2000000L0WGja0P3/c[H80:Vmj0030000003oool0oooo02d0oooo00M000000?oo
o`3oool0oooo@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo@000
00030?ooo`03@000003oool0oooo00P0oooo2030]m400`3Gjn80XI330:6@``060:6@`cP0ZKgX00<0
03bm000d]`3Sc<000P3Sc<000`31jhd0ZKgX0:Vmj0070:Vmj08004G50P2Y_NP209j5^0L0d[2g0P00
000709en/@80k<jf202Y_NP00`000000oooo0?ooo`0M0?ooo`004P3oool01d000000oooo0?ooo`3o
oom000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom0000000<0oooo
00<000000?ooo`3oool02@3oool60<2gd@<0en_R202QT<<i0:Vmj003000d]`3Sc<00hlc000/0ZKgX
0P00ALD20:Vmj00309j5^03B/;L0d[2g00@0d[2g0`00000709en/@<0k<jf1@2Y_NP30:27^@030000
003oool0oooo02`0oooo00M000000?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oo
od0000000P3oool00d000000oooo@00000030?ooo`030000003oool0oooo00T0oooo1P30]m430=O[
hPP0XI33>@2Y_NP00`00=;L0hlc00>?<`00;0:Vmj08004G50P2Y_NP00`2NQKP0d[2g0=:`]`040=:`
]`<000001`2MO[430>c>]PD0ZKgX0`2PQkT00`000000oooo0?ooo`0L0?ooo`004P3oool01d000000
oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom0
00000080oooo00<00000@000003oool02P3oool40<2gd@D0en_R1`2QT<<20=;1bDL0ZKgX0`00ALD7
0=:`]`<000001P2MO[450>c>]PL0X8Ni00<000000?ooo`3oool0;03oool01d000000oooo0?ooo`3o
oom000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom000000080oooo
00<00000@000003oool02P3oool40<2gd@D0en_R1`2QT<<20=;1bDL0ZKgX0`00ALD70=:`]`<00000
1P2MO[450>c>]PL0X8Ni00<000000?ooo`3oool0703oool00180oooo00M000000?ooo`3oool0oooo
@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo@00000020?ooo`03
0000003oool0oooo00/0oooo0P30]m470=O[hPD0XI331@3B`LT50:Vmj0<0WhZm?P2Y_NP20015a@H0
d[2g1000000609en/@@0k<jf00<000000:27^@2PQkT01P2PQkT00`000000oooo0?ooo`0[0?ooo`07
@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000003ooom000000080oooo00=00000
0?oood0000000P3oool00`000000oooo0?ooo`0;0?ooo`80`;OA1`3Gjn850:6@``D0d/791@2Y_NP3
09n:_Ch0ZKgX0P00ALD60=:`]`@000001P2MO[440>c>]P030000002PQkT0X8Ni00H0X8Ni00<00000
0?ooo`3oool06`3oool00140oooo0T0000040?ooo`03@000003oool0oooo0080oooo00=000000?oo
o`3oool00P3oool01T000000oooo0?ooo`3oool00000@00000d0oooo203Gjn840:6@``L0d/79202O
R[dm0:Vmj0030000Q@00ALD004G500D0d[2g1@00000409en/@D0k<jf0P0000070:27^@03@0000000
0000oooo02X0oooo0T0000040?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3o
ool01T000000oooo0?ooo`3oool00000@00000d0oooo203Gjn840:6@``L0d/79202OR[dm0:Vmj003
0000Q@00ALD004G500D0d[2g1@00000409en/@D0k<jf0P0000070:27^@03@00000000000oooo01/0
oooo000U0?ooo`030000003oool0oooo0100oooo103Gjn830:6@``L0d/7900<0h_[C09n:_@2OR[d0
1`2OR[dn0:Vmj0030015a@3B/;L0d[2g0080d[2g0P2Y_NP4000000@0WGja103/c[H3000000H0X8Ni
0P3Xe/<00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0100oooo103Gjn830:6@``L0d/79
00<0h_[C09n:_@2OR[d01`2OR[dn0:Vmj0030015a@3B/;L0d[2g0080d[2g0P2Y_NP4000000@0WGja
103/c[H3000000H0X8Ni0P3Xe/<00`000000oooo0?ooo`0J0?ooo`009@3oool00d000000oooo0?oo
o`0A0?ooo`05001Od`3Gjn80en_R0=O[hP2QT<<01`3B`LT30>;jd`T0WhZm?@2Y_NP20015a@<0d[2g
0P2Y_NP010005j40000000000000000309en/@D0k<jf0`0000060:27^@<0j=K300<000000?ooo`3o
ool00P3oool5@0000080oooo00=000000?ooo`3oool0<03oool00d000000oooo0?ooo`0A0?ooo`05
001Od`3Gjn80en_R0=O[hP2QT<<01`3B`LT30>;jd`T0WhZm?@2Y_NP20015a@<0d[2g0P2Y_NP01000
5j40000000000000000309en/@D0k<jf0`0000060:27^@<0j=K300<000000?ooo`3oool00P3oool5
@0000080oooo00=000000?ooo`3oool03@3oool002D0oooo00=000000?ooo`3oool04`3oool2001O
d`L0d/79103Rn]<809n:_@80e[o3302Y_NP309ao/bh0ZKgX00<004G50=:`]`3B/;L0102Y_NP00`00
5j4000000000000309en/@@0k<jf100000050:27^@@0j=K300=000000000003oool0103oool01d00
0000oooo0?ooo`3ooom000000?oood000000<@3oool00d000000oooo0?ooo`0C0?ooo`8005oC1`3B
`LT40>;jd`P0WhZm0P3F_l<<0:Vmj0<0W7nc;P2Y_NP00`00ALD0d[2g0=:`]`040:Vmj003000GX@00
0000000000<0WGja103/c[H4000000D0X8Ni103Xe/<00d00000000000?ooo`040?ooo`07@000003o
ool0oooo0?oood000000oooo@000000>0?ooo`00903oool2000001H0oooo0P00Gm<60=;1b@D0h_[C
1`2OR[d30=Jo``L0ZKgX202LOk<^0:Vmj0030015a@3B/;L0ZKgX00@0ZKgX00@001NQ000000000000
WGja1@3/c[H5000000@0X8Ni1@3Xe/<00`000000oooo0?ooo`030?ooo`03@000003oool0oooo00<0
oooo00=000000?ooo`3oool0;P3oool2000001H0oooo0P00Gm<60=;1b@D0h_[C1`2OR[d30=Jo``L0
ZKgX202LOk<^0:Vmj0030015a@3B/;L0ZKgX00@0ZKgX00@001NQ000000000000WGja1@3/c[H50000
00@0X8Ni1@3Xe/<00`000000oooo0?ooo`030?ooo`03@000003oool0oooo00<0oooo00=000000?oo
o`3oool0303oool00100oooo0d0000030?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3o
ool00P3oool01T000000oooo0?ooo`3oool00000@00001L0oooo0P00Gm<40=;1b@H0h_[C1P2OR[d4
0=Jo``L0ZKgX2@2LOk<e0:Vmj003000GX@000000WGja00@0k<jf00<0ZKgX0000000000000`000003
0:27^@D0j=K300<0TliY0?ooo`000000103oool014000000oooo0?ooo`3oool2@00001d0oooo0d00
00030?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool01T000000oooo0?oo
o`3oool00000@00001L0oooo0P00Gm<40=;1b@H0h_[C1P2OR[d40=Jo``L0ZKgX2@2LOk<e0:Vmj003
000GX@000000WGja00@0k<jf00<0ZKgX0000000000000`0000030:27^@D0j=K300<0TliY0?ooo`00
0000103oool014000000oooo0?ooo`3oool2@00000l0oooo000@0?ooo`03@000003oool0oooo0080
oooo00=000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom000000080
oooo00<000000?ooo`3oool05`3oool01000Eld005oC0=;1b@3B`LT70>;jd`D0WhZm1P3F_l<70:Vm
j0L0W7nc0P3Q`kXe0:Vmj003000GX@3/c[H0k<jf00<0k<jf00<0ZKgX001Fd@00E]400`0000030:27
^@D0j=K30P2CcVT00`000000oooo0?ooo`020?ooo`05@000003oool0oooo0?oood0000007P3oool0
0d000000oooo0?ooo`020?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool0
0d000000oooo@00000020?ooo`030000003oool0oooo01L0oooo00@005O=001Od`3B`LT0d/791`3R
n]<509n:_@H0e[o31`2Y_NP709ao/`80hL>j=@2Y_NP00`005j40k<jf0>c>]P030>c>]P030:Vmj000
E]4005KA00<000000`2PQkT50>SF``80TliY00<000000?ooo`3oool00P3oool01D000000oooo0?oo
o`3ooom000000100oooo000A0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03
@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo0?ooo`0H0?ooo`@0
05O=0`2Y_NP40>;jd`<0WhZm1P3F_l<20>7m^`H0ZKgX1`2LOk<30>73^SH0ZKgX0`3/c[H30:Vmj080
05KA0P0000020:27^@D0j=K30`2CcVT01400000000000?ooo`3oool2@00000<0oooo0d00000M0?oo
o`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000003ooom000000080oooo00=0
00000?oood0000000P3oool00d000000oooo0?ooo`0H0?ooo`@005O=0`2Y_NP40>;jd`<0WhZm1P3F
_l<20>7m^`H0ZKgX1`2LOk<30>73^SH0ZKgX0`3/c[H30:Vmj08005KA0P0000020:27^@D0j=K30`2C
cVT01400000000000?ooo`3oool2@00000<0oooo0d00000>0?ooo`004@3oool01d000000oooo0?oo
o`3ooom000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom000000080
oooo00<000000?ooo`3oool06@3oool80:Vmj080h_[C0`2OR[d60=Jo``@0hOfk102Y_NP609ao/`@0
hL>j1@2Y_NP309n6^2l0ZKgX0P3/c[H30:Vmj0<005KA0P0000000`2PQkT0j=K30>SF``020>SF``@0
TliY0P3oool00`000000oooo0?ooo`0T0?ooo`07@000003oool0oooo0?oood000000oooo@0000002
0?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool00`000000oooo0?ooo`0I
0?ooo`P0ZKgX0P3Rn]<309n:_@H0e[o3103QoK/40:Vmj0H0W7nc103Q`kX50:Vmj0<0WhJh;`2Y_NP2
0>c>]P<0ZKgX0`00E]42000000030:27^@3Xe/<0j=K30080j=K3102CcVT20?ooo`030000003oool0
oooo01D0oooo000@0?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool00d00
0000oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?ooo`3oool06P3oool80:Vm
j080h_[C00<0WhZm0=Jo``3F_l<0103F_l<60>7m^`<0ZKgX1P2LOk<50>73^PP0WhJh=02Y_NP4001F
d@@0j=K31@2CcVT20?ooo`030000003oool0oooo02<0oooo00=000000?oood0000000P3oool00d00
0000oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool00d00
0000oooo0?ooo`0J0?ooo`P0ZKgX0P3Rn]<00`2OR[d0e[o30=Jo``040=Jo``H0hOfk0`2Y_NP609ao
/`D0hL>j202OQ[Pd0:Vmj0@005KA103Xe/<509?>J@80oooo00<000000?ooo`3oool05@3oool00140
oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080
oooo00=000000?ooo`3oool00P00000N0?ooo`L0ZKgX00<002n]0=Jo``3F_l<0103F_l<50>7m^`H0
ZKgX102LOk<50>73^P030<?UO`2OQ[P0WhJh00L0WhJh=02Y_NP0100AIMX005KA001Fd@00E]430>SF
``030:Vmj02CcVT0TliY00<0TliY0P3oool00d000000oooo0?ooo`0S0?ooo`03@000003oool0oooo
0080oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo
008000007P3oool70:Vmj003000_[@3F_l<0e[o300@0e[o31@3QoK/60:Vmj0@0W7nc1@3Q`kX00`33
iGl0WhJh09n6^00709n6^3@0ZKgX00@04FGJ001Fd@00E]4005KA0`3Xe/<00`2Y_NP0TliY09?>J@03
09?>J@80oooo00=000000?ooo`3oool0503oool002<0oooo00<00000@000003oool07P3oool70:Vm
j003000_[@3F_l<0e[o30080e[o30P3QoK/:0:Vmj0@0W7nc1@3Q`kX20<?UO`L0WhJh0P3:Y[@f0:Vm
j003001Fd@3Xe/<0j=K30080ZKgX00<0002=09?>J@2CcVT00P2CcVTj0?ooo`03000004000000oooo
01h0oooo1`2Y_NP00`00;jd0e[o30=Jo``020=Jo``80hOfk2P2Y_NP409ao/`D0hL>j0P33iGl709n6
^080bZJd=P2Y_NP00`00E]40j=K30>SF``020:Vmj0030000S@2CcVT0TliY0080TliY6@3oool002<0
oooo00<000000?ooo`3oool07`3oool70:Vmj005000_[@3F_l<0e[o30=Jo``3QoK/02`2Y_NP309ao
/`D0hL>j0`33iGl709n6^0<0bZJd>`2Y_NP0100008d0TliY09?>J@2CcVTj0?ooo`030000003oool0
oooo01l0oooo1`2Y_NP01@00;jd0e[o30=Jo``3F_l<0hOfk00/0ZKgX0`2LOk<50>73^P<0`nEo1`2O
Q[P30<ZV]3/0ZKgX00@0002=09?>J@2CcVT0TliY6@3oool002<0oooo00<00000@000003oool0803o
ool70:Vmj080e[o33@2Y_NP309ao/`D0hL>j1033iGl509n6^0@0bZJd1@2Y_NP309aj[C<0ZKgX0P3o
ool309?>J@80002==`3oool00`00001000000?ooo`0P0?ooo`L0ZKgX0P3F_l<=0:Vmj0<0W7nc1@3Q
`kX40<?UO`D0WhJh103:Y[@50:Vmj0<0W7Z]<`2Y_NP20?ooo`<0TliY0P0008dF0?ooo`003P3oool2
@00000@0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0
oooo0080oooo00<000000?ooo`3oool0803ooolG0:Vmj00309ao/`3Q`kX0hL>j00<0hL>j1@33iGl5
09n6^0D0bZJd202LNZd`0:Vmj0@0oooo0`2CcVT20000SB80oooo0T0000040?ooo`03@000003oool0
oooo0080oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`030000003oool0
oooo0200oooo5`2Y_NP00`2LOk<0hL>j0>73^P030>73^PD0`nEo1@2OQ[P50<ZV]0P0W7Z]<02Y_NP4
0?ooo`<0TliY0P0008dF0?ooo`00403oool01T000000oooo0?oood000000oooo@0000080oooo00=0
00000?oood0000000P3oool00d000000oooo@00000030?ooo`03@000003oool0oooo0240oooo5P2Y
_NP00`2LOk<0hL>j0>73^P020>73^P030<?UO`2Y_NP0ZKgX00<0`nEo102OQ[P60<ZV]0T0W7Z]:`2Y
_NP90?ooo`80TliY0P0008dT0?ooo`06@000003oool0oooo@000003ooom000000P3oool00d000000
oooo@00000020?ooo`03@000003ooom0000000<0oooo00=000000?ooo`3oool08@3ooolF0:Vmj003
09ao/`3Q`kX0hL>j0080hL>j00<0`nEo0:Vmj02Y_NP00`33iGl409n6^0H0bZJd2@2LNZd[0:Vmj0T0
oooo0P2CcVT20000SAH0oooo000?0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?oo
o`03@000003ooom000000080oooo00=000000?oood0000000`3oool00`000000oooo0?ooo`0R0?oo
oaD0ZKgX1@3Q`kX40:Vmj0<0`nEo0`2OQ[P50<ZV]0800000202LNZd00`3be;40ZKgX0:Vmj00R0:Vm
j100oooo00<0TliY0000S@3oool08`3oool01d000000oooo0?ooo`3ooom000000?oood0000000P3o
ool00d000000oooo@00000020?ooo`03@000003ooom0000000<0oooo00<000000?ooo`3oool08P3o
oolE0:Vmj0D0hL>j102Y_NP30<?UO`<0WhJh1@3:Y[@2000000P0W7Z]00<0l]Ba0:Vmj02Y_NP08P2Y
_NP@0?ooo`0309?>J@0008d0oooo01H0oooo000@0?ooo`06@000003oool0oooo@000003ooom00000
0P3oool00d000000oooo@00000020?ooo`03@000003ooom000000080oooo00<000000?ooo`3oool0
9@3ooolD0:Vmj0<0hL>j00<0`nEo0:Vmj02Y_NP00`2Y_NP010006IX0`nEo09n6^02OQ[P60<ZV]080
00001`2LNZd30?;D/B40ZKgX4`3oool00`2CcVT0oooo0?ooo`0S0?ooo`06@000003oool0oooo@000
003ooom000000P3oool00d000000oooo@00000020?ooo`03@000003ooom000000080oooo00<00000
0?ooo`3oool09@3ooolD0:Vmj0<0hL>j00<0`nEo0:Vmj02Y_NP00`2Y_NP010006IX0`nEo09n6^02O
Q[P60<ZV]08000001`2LNZd30?;D/B40ZKgX4`3oool00`2CcVT0oooo0?ooo`0E0?ooo`003P3oool0
0d000000oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool0
0d000000oooo@00000020?ooo`03000004000000oooo02H0oooo502Y_NP20>73^PL0ZKgX00<001VJ
0<?UO`2OQ[P01@3:Y[@3000000L0W7Z]0`3be;450:Vmj0<0WhBf5@2Y_NPk0?ooo`03@000003ooom0
00000080oooo00=000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom0
00000080oooo00<00000@000003oool09P3ooolD0:Vmj080hL>j1`2Y_NP00`006IX0`nEo09n6^005
0<ZV]0<000001`2LNZd30?;D/@D0ZKgX0`2OQ;HE0:Vmj2l0oooo000?0?ooo`03@000003oool0oooo
0080oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo
0?oood000000:@3ooolL0:Vmj08001VJ1P3:Y[@3000000H0W7Z]1@3be;4709n4]Q<0ZKgX?P3oool0
0d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool0
1D000000oooo0?ooo`3ooom0000002T0oooo702Y_NP2000IVPH0bZJd0`00000609aj[@D0l]Ba1`2O
Q;HC0:Vmj340oooo001=0?oooa`0ZKgX00<001VJ0<ZV]03:Y[@0103:Y[@0102Y_NP0000000000000
000509aj[@@0l]Ba00<0000009n4]P2OQ;H01P2OQ;H?0:Vmj7l0oooo702Y_NP00`006IX0bZJd0<ZV
]0040<ZV]0040:Vmj00000000000000000D0W7Z]103be;400`000000WhBf09n4]P0609n4]Pl0ZKgX
=03oool004h0oooo6`2Y_NP2000IVP@0bZJd0P2Y_NP3000000D0W7Z]103be;42000000H0WhBf0P2Z
NYl<0:Vmj880oooo6`2Y_NP2000IVP@0bZJd0P2Y_NP3000000D0W7Z]103be;42000000H0WhBf0P2Z
NYl<0:Vmj3H0oooo001?0?oooa/0ZKgX00<001VJ0<ZV]03:Y[@00P3:Y[@30:Vmj0800000102LNZd4
0?;D/@<000001P2OQ;H30:YjW`L0ZKgXQ`3ooolK0:Vmj003000IVP3:Y[@0bZJd0080bZJd0`2Y_NP2
000000@0W7Z]103be;43000000H0WhBf0`2ZNYl70:Vmj3X0oooo001A0?oooaX0ZKgX00@001VJ0<ZV
]03:Y[@0bZJd102Y_NP2000000<0W7Z]103be;43000000D0WhBf1@2ZNYn?0?oooaX0ZKgX00@001VJ
0<ZV]03:Y[@0bZJd102Y_NP2000000<0W7Z]103be;43000000D0WhBf1@2ZNYm00?ooo`00DP3ooolI
0:Vmj003000IVP3:Y[@0bZJd00D0ZKgX0P00000309aj[@<0l]Ba1@00000409n4]PD0ZWZOT03ooolI
0:Vmj003000IVP3:Y[@0bZJd00D0ZKgX0P00000309aj[@<0l]Ba1@00000409n4]PD0ZWZO@03oool0
05<0oooo6@2Y_NP20<ZV]0H0ZKgX00<0000009aj[@2LNZd00`3be;420:Vmj0@000000`2OQ;H60:Yj
Wi40oooo6@2Y_NP20<ZV]0H0ZKgX00<0000009aj[@2LNZd00`3be;420:Vmj0@000000`2OQ;H60:Yj
Wd00oooo001D0?oooaP0ZKgX00<001VJ0:Vmj02Y_NP01P2Y_NP209aj[@<0l]Ba0`2Y_NP3000000<0
WhBf1P2ZNYnB0?oooaP0ZKgX00<001VJ0:Vmj02Y_NP01P2Y_NP209aj[@<0l]Ba0`2Y_NP3000000<0
WhBf1P2ZNYm00?ooo`00E@3ooolP0:Vmj0040000003be;40l]Ba0?;D/@D0ZKgX00@000jB0000002O
Q;H0WhBf1`2ZNYnC0?ooob00ZKgX00@000000?;D/@3be;40l]Ba1@2Y_NP010003Y80000009n4]P2O
Q;H70:YjWd00oooo001F0?ooob00ZKgX0`3be;450?ooo`8000jB00<0000009n4]P2ZNYl01@2ZNYnE
0?ooob00ZKgX0`3be;450?ooo`8000jB00<0000009n4]P2ZNYl01@2ZNYm10?ooo`00E`3ooolP0:Vm
j0L0oooo0`003Y870:YjWiH0oooo802Y_NP70?ooo`<000jB1`2ZNYm10?ooo`00F03ooolK0:Vmj0`0
oooo0P003Y870:YjWiL0oooo6`2Y_NP<0?ooo`8000jB1`2ZNYm10?ooo`00F@3ooolE0:Vmj140oooo
0P003Y870:YjWiP0oooo5@2Y_NPA0?ooo`8000jB1`2ZNYm10?ooo`00FP3ooolB0:Vmj1<0oooo0P00
3Y870:YjWiT0oooo4P2Y_NPC0?ooo`8000jB1`2ZNYm10?ooo`00F`3oool>0:Vmj1H0oooo0`003Y86
0:YjWiX0oooo3P2Y_NPF0?ooo`<000jB1P2ZNYm10?ooo`00G03oool;0:Vmj1T0oooo0P003Y860:Yj
Wi/0oooo2`2Y_NPI0?ooo`8000jB1P2ZNYm10?ooo`00G@3oool60:Vmj1d0oooo0P003Y860:YjWi`0
oooo1P2Y_NPM0?ooo`8000jB1P2ZNYm10?ooo`00P03oool2000>TPD0ZWZO`03oool2000>TPD0ZWZO
@P3oool00800oooo0P003Y850:YjWl00oooo0P003Y850:YjWd80oooo00210?ooo`03000>TP2ZNYl0
ZWZO00<0ZWZO`@3oool00`003Y80ZWZO0:YjW`030:YjWd80oooo00210?ooo`03000>TP2ZNYl0ZWZO
00<0ZWZO`@3oool00`003Y80ZWZO0:YjW`030:YjWd80oooo00210?ooo`8000jB102ZNYo10?ooo`80
00jB102ZNYm20?ooo`00P@3oool2000>TP@0ZWZO`@3oool2000>TP@0ZWZO@P3oool00880oooo00<0
00jB0:YjW`2ZNYl00P2ZNYo20?ooo`03000>TP2ZNYl0ZWZO0080ZWZO@P3oool00880oooo00<000jB
0:YjW`2ZNYl00P2ZNYo20?ooo`03000>TP2ZNYl0ZWZO0080ZWZO@P3oool00880oooo00@000jB0:Yj
W`2ZNYl0ZWZO``3oool010003Y80ZWZO0:YjW`2ZNYm30?ooo`00PP3oool010003Y80ZWZO0:YjW`2Z
NYo30?ooo`04000>TP2ZNYl0ZWZO0:YjWd<0oooo00230?ooo`03000>TP2ZNYl0ZWZO0<@0oooo00<0
00jB0:YjW`2ZNYl0@`3oool008<0oooo00<000jB0:YjW`2ZNYl0a03oool00`003Y80ZWZO0:YjW`13
0?ooo`00P`3oool00`003Y80ZWZO0:YjW`340?ooo`03000>TP2ZNYl0ZWZO04<0oooo00230?ooo`03
000>TP2ZNYl0ZWZO0<@0oooo00<000jB0:YjW`2ZNYl0@`3oool008@0oooo0P2ZNYo50?ooo`80ZWZO
@`3oool008@0oooo0P2ZNYo50?ooo`80ZWZO@`3oool008@0oooo00<0ZWZO0?ooo`3oool0a03oool0
0`2ZNYl0oooo0?ooo`120?ooo`00Q03oool00`003Y80oooo0?ooo`340?ooo`03000>TP3oool0oooo
0480oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo001W0?ooo`03@000003oool0
oooo00H0oooo00=000000?ooo`3oool0^`3oool00d000000oooo0?ooo`060?ooo`03@000003oool0
oooo05H0oooo001V0?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool0^@3oool00d00
0000oooo0?ooo`080?ooo`03@000003oool0oooo05D0oooo001U0?ooo`03@000003oool0oooo0080
oooo140000040?ooo`03@000003oool0oooo0;L0oooo00A000000?ooo`3oool0oooo140000050?oo
o`03@000003oool0oooo05@0oooo001U0?ooo`03@000003oool0oooo0080oooo0d0000050?ooo`03
@000003oool0oooo0;L0oooo00=000000?ooo`3oool00P3oool014000000oooo0?oood0000040?oo
o`03@000003oool0oooo05@0oooo001U0?ooo`03@000003oool0oooo00@0oooo00=000000?ooo`3o
ool00`3oool00d000000oooo0?ooo`2g0?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3o
oom00000103oool00d000000oooo0?ooo`1D0?ooo`00I@3oool00d000000oooo0?ooo`030?ooo`90
00001@3oool00d000000oooo0?ooo`2g0?ooo`03@000003oool0oooo0080oooo0d0000050?ooo`03
@000003oool0oooo05@0oooo001V0?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool0
^@3oool01D000000oooo0?ooo`3ooom0000000H0oooo00=000000?ooo`3oool0E@3oool006L0oooo
00=000000?ooo`3oool01P3oool00d000000oooo0?ooo`2k0?ooo`04@000003ooom00000@00000D0
oooo00=000000?ooo`3oool0EP3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00940oooo0T00000^0?ooo`9000005P3oool3@0000;@0oooo002C0?ooo`03@000
003oool0oooo02d0oooo00=000000?ooo`3oool0503oool00d000000oooo0?ooo`2c0?ooo`00Q@3o
ool3@00000<0oooo0d0000030?ooo`=000001@3oool00d000000oooo0?ooo`05@0000080oooo00=0
00000?ooo`3oool01@3oool00d000000oooo0?ooo`070?ooo`E0000000@0oooo@000040000100000
0`3oool3@0000080oooo0T0000000`3ooom00000@00000020?ooo`03@000003oool0oooo00X0oooo
0d0000020?ooo`A000000P3oool2@00000<0oooo0T0000030?ooo`9000000P3oool3@00000030?oo
od00001000000080oooo00A000000?oood0000100000T@3oool008H0oooo00=000000?ooo`3oool0
0`3oool01D000000oooo0?ooo`3ooom000000080oooo00=000000?ooo`3oool0203oool01d000000
oooo0?ooo`3ooom000000?oood0000004@3oool014000000oooo0?oood0000020?ooo`05@000003o
ool0oooo0?oood0000000P3oool00d000000oooo@00000040?ooo`04@000003oool0oooo@00000`0
oooo00E000000?ooo`3ooom000000?ooo`03@0000080oooo00I000000?ooo`3ooom000000?oood00
00020?ooo`03@000003ooom0000000D0oooo00E000000?ooo`3oool0oooo@00000020?ooo`05@000
003oool0oooo0?oood000000T03oool008H0oooo00=000000?ooo`3oool00`3oool01D000000oooo
0?ooo`3ooom000000080oooo00=000000?ooo`3oool0203oool01d000000oooo0?ooo`3ooom00000
0?oood0000004@3oool00d000000oooo0?ooo`030?ooo`05@000003oool0oooo0?oood0000000P3o
ool00d000000oooo@0000002@0000080oooo00A000000?ooo`3ooom00000303oool014000000oooo
0?oood0000030?ooo`04@000003oool0oooo@00000@0oooo00=000000?ooo`3oool00P3oool3@000
00<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`04@000003oool0oooo@0000940oooo0026
0?ooo`9000000`3oool2@00000@0oooo0d00000:0?ooo`07@000003oool0oooo0?oood000000oooo
@000000A0?ooo`9000000`3oool2@00000@0oooo0d0000001@3ooom00000@00004000000oooo00A0
0000303oool4@00000<0oooo0T0000000`3ooom00000@0000002@00000030?oood00001000000090
00000P3oool3@0000080oooo240000030?ooo`900000T03oool008H0oooo00A000000?ooo`3ooom0
0000503oool01d000000oooo0?ooo`3ooom000000?oood0000004@3oool014000000oooo0?oood00
000Z0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool0Y03oool008D0oooo1D000002
0?ooo`03@000003oool0oooo00h0oooo0T0000040?ooo`03@000003oool0oooo00l0oooo1D000002
0?ooo`03@000003oool0oooo0=40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.192686, 
  0.00526322, 0.00526322}, {{9.5, 190.438}, {362.375, 
  215.563}} -> {-0.220102, -0.231184, 0.00639378, 0.00639378}, {{208.5, 
  389.438}, {362.375, 215.563}} -> {-1.49311, -0.231369, 0.00639549, 
  0.00639549}, {{9.5, 190.438}, {200.938, 54.125}} -> {-0.220454, -1.26391, 
  0.00639575, 0.00639575}, {{208.5, 389.438}, {200.938, 
  54.125}} -> {-1.49321, -1.26391, 0.00639575, 0.00639575}}]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "Similar to that of monochrome images, the sample images having the same \
resolution take the same eigen pattern even if they are angled. The lower \
resolution sample images take the eigen patterns having smaller maximum \
amplitude. However, computation of the correlation coefficients between them \
reveals that all of the sample images in Fig. 9 are the same ones.\n",
    FormatType->InputForm,
    FontFamily->"Times New Roman"],
  StyleBox["\t",
    FormatType->InputForm],
  StyleBox[
  "Before to move on the next computations, we remove the needless variables \
and check the used memories.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["Table[corRelation[eigen3D[[1]],eigen3D[[i]]],{i,2,4,1}]", "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \({0.999999999999999822`, 0.999643965924329513`, 0.999781501988822363`}
      \)], "Output",
  CellLabel->"Out[78]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Remove[\"eigen3DG\",\"win128\"];
memoryUsed\
\>", "Input",
  CellLabel->"In[79]:="],

Cell[BoxData[
    InterpretationBox[\(2462\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ 2462, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Inverse transform",
  FormatType->InputForm,
  FontFamily->"Times New Roman"]], "Subsubsection",
  FormatType->InputForm],

Cell[TextData[{
  "\t",
  StyleBox[
  "We generate or recover the color images from the color image eigen \
patterns in Fig.10. Similar to the one-dimensional and monochrome image \
recovery, the recovered images are depended on the base image data. Also \
described in the monochrome image recovery from their eigen patterns, the \
base image data work as a guideline for which type image will be recovered \
from the same eigen pattern. We select the data representing a sample image \
of Fig. 9(a) as the base image data. And then we recover the color images \
from the eigen patterns in Fig. 10(b)-(d). Figure 11 shows the recovered \
color images formatted by the base image in Fig. 9(a). ",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell["\<\
recover3D=Table[inverseEigenPattern[eigen3D[[i]],
\tFlatten[sampleWD[[1]]],resolution],{i,2,4,1}];\
\>", "Input",
  CellLabel->"In[81]:="],

Cell["\<\
k=dim[[2]]*dim[[3]];
recoverC=Table[Take[recover3D[[i]],{k*(j-1)+1,k*j}],
\t{i,3},{j,dim[[1]]}];
color2D=Table[convert2D[recoverC[[i,j]],dim[[2]],dim[[3]]],
\t{i,3},{j,dim[[1]]}];\
\>", "Input",
  CellLabel->"In[82]:=",
  FormatType->InputForm],

Cell["\<\
recover3DG=Table[Show[convertRGB[color2D[[i]]],
\tPlotLabel->StringForm[\"`1`\",label[[i+1]]],
\tAspectRatio->dim[[2]]/dim[[3]],
\tDisplayFunction->Identity],{i,3}];\
\>", "Input",
  CellLabel->"In[85]:=",
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[recover3DG],PlotLabel->\"Fig.11. Recovered images\",
\tImageSize->{450,150}];\
\>", "Input",
  CellLabel->"In[86]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
%%ImageSize: 450 150 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[.5 .325 -74 0 ]
[.5 .325 74 12.5625 ]
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .325 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.11) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Recovered) show
171.000000 12.812500 moveto
(images) show
207.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F0BE9D000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000F0C7A6F0C7A6F0C7A6F0C7A6F0C7A6F0C7A6F0C7A6F0BE9D\
F0C7A6F0BE9DF0BE9DF0BE9DF0C7A6F0C7A6F0C7A6F0C7A6F0B695F0B695F0BE9D
F0BE9DF0BE9D000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000F0C7A6F0C7A6F0C7A6F0C7A6F0BE9DF0BE9DF0C7A6F0C7A6F0BE9DF0BE9DF0BE9DF0BE9D\
F0B695E8BE9DF0BE9DF0C7A6F0C7A6F0C7A6F0BE9DF0BE9DF0BE9DE8BE9DF0B695
E8BE95E8B695F0BE9DF0BE9DF0BE9DF0B695000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000E8BE95F0BE9D
F0C7A6F0BE9DF0BE9DF0BE9DF0BE9DF0C7A6F0BE9DF0BE9DF0C7A6F0BE9DF0BE9DF0C7A6F0BE9D\
F0BE9DF0B695E8BE95F0BE9DF0BE9DE8BE9DF0C7A6F0BE9DF0B695E8B695F0B695
E8B695E8B695E8B695E8B695E8BE95E8B695E8B695E8AE8DE8AE8D000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000DFAE9DDFAE95E8B695E8B695E8BEA6
E8BE9DF0BE9DF0BE9DF0BE9DF0BE9DF0C7A6F0BE9DF0C7A6F0BE9DF0BE9DF0BE9DF0BE9DE8BE9D\
F0BE9DF0BE9DF0B695F0B695E8BE95F0B695F0BE9DF0BE9DE8BE9DE8BE95F0B695
E8B695F0B695E8AE8DDFAE85E8AE8DF0B695E8AE8DE8AE8DF0B695E8AE8DE8BE95E8B695000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000006329104A1808DFAE95DFAE95E8BE9DE8B69DE8BE9D
E8BE9DF0BE9DF0BE9DF0BE9DF0BE9DF0BE9DF0C7A6F0C7A6F0BE9DF0BE9DF0BE9DF0BE9DF0BE9D\
F0BE9DF0BE9DE8BE95E8BE95F0BE9DF0B695E8BE9DF0B695F0B69DE8B695E8B695
E8B695E8B695E8AE8DE8AE8DE8AE8DE8AE8DDFAE85DFA67BDFAE85E8AE8DDFAE85E8BE9DDFA67B\
DFAE8D000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000007B39186329105221106B3118DFAE95DFAE95E8B695E8BE9DE8BE9D
E8BEA6E8BE9DF0C7A6F0BE9DF0C7A6F0BE9DF0BE9DF0BE9DF0BE9DF0BE9DF0B695F0BE9DF0BE9D\
E8BE95F0BE9DF0B695E8BE9DF0B695E8B695E8B695E8AE8DE8B695E8B695E8B695
E8B695E8AE8DE8AE8DDFAE85DFA685DFA67BDFA67BDFA67BDFAE85E8BE9DDFAE85D79D7BD79D73\
D79D7BDF9D73DF9D73000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
B66B399552298D4A296B31186B31187B42217B4A29DFAE9DE8BE95E8BE9DF0C7A6
E8BE9DE8BE9DF0C7A6F0BE9DF0BE9DF0BE9DF0BE9DF0BE9DF0BE9DE8BE9DF0BE9DE8BE9DE8B695\
F0B69DF0BE9DE8BE95F0B695F0B695E8BE95E8AE8DE8BE95DFAE85E8B695E8BE95
E8B695E8AE8DE8AE8DDFA685DFA685CF956BD79D73DFAE8DE8BE9DDFAE8DCF8D63CF956BD79D73\
CF956BD79D73CF956BC77B4AC77B42000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000B6734A\
AE6B398D4A298D4A297B39188542218D4221632910DFAE95E8BE9DE8BEA6F0C7A6
E8BE9DE8BE9DF0BE9DF0B695E8BE95F0BE9DF0B695E8BE95F0BE9DF0BE9DE8BE95F0B695E8BE95\
F0B695F0B695F0BE9DE8B695E8B695E8B695E8BE95DFAE85F0B695DFAE85E8AE8D
DFAE8DDFAE85DFA685DF9D7BCF956BD79D73D79D73E8BE95E8BE9DCF8D63CF956BD79D73D79D73\
CF8D63B67B5AB66B529D6339C77B42B66B39000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000B6734AAE6B429D6339\
9D63398D42218D4A299552299552297B39184A1808E8BE9DE8B695E8BEA6E8BE9D
F0BE9DE8BE9DF0BE9DF0B695F0B695F0BE9DF0B695F0B695F0B695F0B695F0B695F0B695E8BE95\
E8BE95F0B695E8B695E8BE95E8B695E8B695DFAE85DFAE85DFAE85E8AE8DDFAE85
DFAE8DDFAE8DDF9D7BD79D73CF8D63CF8D63DFAE85DFAE95CF8D63C78563C78563C78D63C78563\
B67B5AAE73528D5A42AE6B42C77B42B66B39B66B39B66B39000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000BE8D63B67B5AB66B42AE6B42\
8D4A29854221955229955A318D4A296B39216B3118E8BEA6E8B69DF0C7A6E8BEA6
E8B695F0BE9DE8BE9DE8BE9DF0BE9DF0B695F0B69DE8BE95F0B695E8AE8DF0B695F0B695E8AE8D\
E8AE8DE8AE8DE8AE8DF0B695DFAE85E8AE8DDFAE8DDFAE85E8AE8DDFA67BDFA685
DFA67BD79D7BD79D73C7856BCF8D63CF9563D79D73CF956BC7855AC78563C7855AC7855AB67B5A\
9D63399D6B4A9D6B4AAE6B39CF8D5AC77B4AC77B42B66B39AE6B39000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000CF956BC7855AB6734AAE6B42AE6B39\
955A31955229AE6B399552296B31186B3118632910E8BEA6E8B69DE8BE9DDFAE95
E8BE9DF0BE9DF0BE9DE8AE8DE8AE8DF0B695E8B695E8AE8DE8AE8DE8AE8DDFAE85E8AE8DE8AE8D\
DFAE85DFAE85E8AE8DDFA685E8AE8DDFA685DFA685DFA685DFA685DFA67BDFA67B
D79D73D79D73CF956BCF8D5AC78563D79D7BC78D63B67B5AB66B52C77B4AB6734AB67B5A956342\
B6734A9D7352AE6B39AE6B42C77B4ACF8D5AC7855AB6734AC77B4AB67B5A000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000D79D73D79D73BE8D63B6734AAE6B42AE6B42\
8D4A299D63399552298542216329106B3921632910E8BE9DE8BE9DE8BE9DE8BE9D
E8BE9DE8B695F0BE9DE8BE95E8AE8DF0B695E8AE8DDFAE85E8AE8DDFAE85DFA685DFAE85DFA685\
DFAE85DFA685DFA685DFA685DFAE8DDFAE85DFA67BDF9D7BD79D7BDFA67BD79D7B
D79D7BD79D73CF956BC7855ACF956BCF8D63B67B5AB66B52B6734AAE6B42AE6B42955A319D6B4A\
9D6B4A9552299D6339B66B42CF8D5ACF8D5ACF8D5ACF956BC77B4AC77B4AB6734A
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000F8F0E8CFAE95D79D73C78D63C7855A9D63399D6B4A955A31\
9D4A319D63399D4A317B42216B39217B42216B3118E8BEA6DFAE9DE8BE9DE8B695
E8BE9DE8B695E8AE8DE8BE95E8AE8DE8AE8DE8AE8DDFAE85DFA685DFA685DFA685DF9D73DF9D7B\
DFA67BDF9D7BDF9D7BDFA685DFA67BDFA67BD79D73DF9D73D79D73D79D73D79D73
D79D73CF8D63CF8D63C7855ACF956BC7855AB6734AAE6B42AE6342AE6342956342AE6B429D6B4A\
955A31955A319D6339B66B39C77B42CF8D5AC7855ACF8D5AC7855ABE8D63B6734A
B6734AB66B42000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000F8F0E8E8D7C7D7AE8DD79D73C7855AB67B5AAE6B42B6734A955229\
9D63399D6339955A315A31216329106B31186B3921E8BE9DDFAE95E8B69DDFAE95
E8B695E8B695E8AE8DE8AE8DE8AE8DDFA685DFAE85DFA67BDF9D7BDFA67BDF9D7BDF9D7BDF9D73\
CF956BCF956BCF956BD79D73D79D73DF9D7BD79D73D79D73CF956BCF956BCF956B
CF8D63CF8D63C78563BE8D63B6734AAE6B42AE6B399D6339AE6342AE6B42AE6B429D63399D6339\
9D6339AE6331B66B39B66B42C77B42CF8D5ADFA673D79D73DFAE85C78D63AE6B39
AE6B39B6734AC78D63000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000F8F0E8F8F0E8E8BEA6D7AE85C7956BBE8D63B6734A9D63399D6B4A955A31\
AE6B398D4A298542215229185229186B31186B3118E8BE9DDFAE95E8B695E8B69D
E8B695E8AE8DE8AE8DDFA685DFA67BDFA67BDFA67BDFA67BDF9D73D79D7BD79D73DF9D73D79D73\
D79D73CF956BCF956BCF956BCF956BD79D73D79D73CF956BCF956BCF956BC78563
C78563C7855AB67B5AC7855AB66B429D6339955A31AE6B429D6339AE6B42AE6B427B42217B4221\
8D4A29B66331C77B42C77B42C77B42C7855ACF9563D79D73CF956BD7AE85BE8D63
B6734AC7855AC7855ACF956B000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000F0F0E8F8F0F8E8DFD7D7B6A6D7AE85BE8D63B67B5AAE6B429D6B4A955A31955A31\
9D63398D4A297B39186B31186B39216B39217B3918DFAE95DFAE95DFAE8DDFAE8D
E8AE8DDFAE8DDFA685DFAE8DDFA685DFA685D79D7BDF9D73DF9D73CF956BCF956BCF956BC7856B\
CF8D63CF8D63C7856BCF956BCF956BC7856BCF956BCF956BCF956BC78563C7855A
C78563C7855AB6734ACF8D5AAE6B428D4A299D6B4A9D6B4A9D6339955A318542217B4221632910\
AE6331C77B42B66331C77B42B66B42C77B4ACF9563DFA673D79D7BDFAE85BE8D63
BE8D63CF9563BE8D63CF956BC7956B000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000F0F0F8F8F0F8F0F0E8E8C7B6D7AE8DC79D85B67B5AB67B5A9D6B4AAE63429D6339955A31\
955A316B39216B39216B31186B39216B39216B3921DFAE95DFAE8DDFAE95E8BEA6
E8AE95E8AE95E8A695E8AE95E8A695E8A695DFAE8DDFA685DFA685D79D7BCF8D63C7855ACF8D63\
C77B5AC7855AC7855AC7855AC7855ACF8D63CF8D63C7855AC7855AC7855AB67B5A
B67B5AB66B52B6734AC7855A9D63397B4A299D6339AE6B428D4A297B42217B39187B4A29955229\
AE5A31C77B42C77B42B6734AC77B42AE6B39CF9563D79D73D7AE85CF956BC7956B
C7855AC78D63C78D63BE8D63D7AE85D7AE85000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000F0F0F8F0F0F8F0E8DFDFC7B6D7AE85C7956BB67B5AB6734AAE6B429D6339B6734A9D4A31\
955A315221107342296B39216B39216B3118855231DFAE95E8C7AEF0C7AEF0C7AE
F0C7AEF0C7A6F0C7A6F0B69DF0B69DF0B69DE8AE9DE8AE95E8AE95DFAE8DDFA685D79D7BC77B5A\
C77B5AC77B4AC77B5AC77B5AB67B5AB67B5AB67B5AC7855AC77B5AB67B5AC77B4A
B6734AAE6B42AE6B42C77B4A8D4A298D4A319D63398D5A428542216B31186B3921AE6331854221\
9D6339C77B4AC77B42B6734AAE6B39B6734ACF8D5AD79D7BDFAE85DFAE8DD7AE85
C7956BC7956BB67B5AB66B42D7AE85D7AE85000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
F0F0F8F8F0F8F8F0F8E8CFBED7B6A6D79D73C78D63B67B5AAE7352955A319D6339955A319D6339\
8542216329107B42217342296B39216B3118B68563F0C7AEF0C7B6F8D7BEF8C7B6
F8C7B6F0C7AEF0C7AEF8C7B6F0C7AEF0C7AEF0B69DF0B69DE8B69DE8AE95DFAE8DDFA685DF9D7B\
CF956BC77B4AB6734AB67B5AC77B4AC77B4AC77B5AB66B52B67B5AC77B4AB67B5A
B6734AAE6B42956342B6734A955A319D6339B6734A8542217B39186B3118734A31B66B398D4221\
9D6339B66B42C77B4AB66B39AE6B39B6734AC7855ACF8D5ADFAE85DFAE8DD7AE85
D79D73C7956BB6734ABE8D63D79D73D79D73D79D73000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000F0F0F8
F8F0E8F8F0F8F8F0F8E8CFBECFAE95C7956BBE8D63AE7352AE6B42AE6B429D6339955A319D6339\
6329106B39217B4A296B39216B3921B68D73F0C7B6F8CFB6F8D7BEF8CFB6F8D7BE
F8C7B6F8D7BEF8C7B6F8CFB6F8C7B6F0C7AEF0C7A6F0C7AEF0B69DF0B69DE8AE95E8AE8DDFA685\
DFA67BD79D73CF956BB6734AB6734AB6734AB6734AC77B4AB6734AB67B5AB6734A
AE63429D6B4A855239854221B6734A955A31C7855A7B39186B3118522110632910AE6B39B66B42\
955229B66B42CF8D5AAE6B39BE8D63B6734AC7855AD79D73DFAE85E8BE95E8BEA6
D7AE8DB66B42BE8D63BE8D63CF956BC78D63D79D73D7AE8D000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000F8F8F8F8F8F8
F0F0F8F0E8E8E8D7C7E8C7AEC79D85C7956BB67B5A9D6B4A955A319D63399D6339955A31854A29\
6329107B4A297B4A296B3921E8C7B6F8CFB6F0CFAEF8CFB6F8D7BEF8D7BEF0D7C7
F8D7BEF0D7C7F8C7B6F8C7B6F8C7B6F8CFB6F0C7AEF0C7A6F0C7A6F0C7A6E8BE9DDFAE95DFAE8D\
E8AE8DDFA685D79D7BCF956BB66B52AE6B42AE6B42B6734AAE6B42B66B52AE6B42
AE63429D63398542217B4221C7855A854221CF8D639D63396B3921734A31522110854221C77B4A\
8D4221B66B42C77B4AB66B39C7855AC7855AC7855ACF9563D79D73E8BE9DE8BEA6
D7AE85C78D63B67B5ABE8D63C7956BC7956BD7AE85D7AE8DD7AE85000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000F8F8F8F8F0F8
F0F0E8F0E8E8DFCFBED7BEAEBE957BBE8D63B67B5AAE6B429563429D6339955A31955A316B3921\
6B31187B42216B3921A6856BF0CFB6F8CFB6F0C7AEF8CFB6F8CFB6F8D7BEF8D7BE
F8D7BEF8D7BEF0D7C7F8D7BEF8C7B6F8C7B6F0C7AEF0C7AEF0C7AEE8BEA6E8B69DE8BE9DE8B695\
E8AE8DDFAE95DFA685D79D7BC7856BCF956BAE6342AE6342AE6B429D6B4AAE6342
9563429D4A31854A31734229C77B4AAE7352B67B5AB6734A6B31185221107B42219D6339C77B4A\
C7855AC77B4AC77B4AC7855AAE6B42C78D63BE8D63C7956BD79D73D7AE85E8BE9D
E8BE95BE8D63B6734ABE8D63C77B4AC7956BD7B6A6E8BE95CFB6A6000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000F0F0E8F8F8F8F0F0F8
F0F0E8E8DFD7DFCFBECFAE95BE957BBE8D63B6734A9D6B4A855239955A318D4A29955A31522918\
6B39217342298D5A42F0C7AEF0C7B6F8CFB6F8CFB6F8CFB6F8CFB6F8D7BEF8C7B6
F8D7BEF8C7B6F8C7B6F8D7BEF8C7B6F8C7B6F0C7AEF0C7A6F0C7AEF0C7AEF0C7A6E8B69DE8B69D\
E8B695DFAE95DFAE8DDFA685D79D7BCF956BC7856B9D6339AE6342AE6342955A42
9D6339854A297B4A296329109D6B4AD79D7B8D4A29CF956B956342AE6B426B3118AE63318D4A31\
BE8D63AE6331C77B42C77B4ABE8D63B68563C7956BB67B5AD7AE85CF9563E8BEA6
F0CFB6BE8D63B6734ABE8D63C78D63C79D85D79D73D7AE85D7AE8DE8BE95000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000F8F8F8F8F8F8F8F0F8F0E8E8
F0E8E8E8CFBEDFCFBEC79D85C78D63AE7352B6734A956342955A31955A318552316B39216B3118\
854A29855A42F0C7B6F0C7AEF0CFAEF8CFB6F8CFB6F8CFB6F8C7B6F0CFAEF0C7AE
F0C7AEF0C7AEF0C7AEF0C7AEF0C7A6F0B69DF0B69DE8BEA6F0C7A6E8BE9DF0BE9DE8B69DE8B69D\
DFAE8DE8AE8DDFAE95DFAE8DDFA685D79D73CF956BCF8D639D63399D4A319D6339
8D4A318D4A296B39216B3921855239BE8D63B67B5A9D6B4AC79D858D4221B67B5A955A31AE6342\
B66B42C77B4AAE6B39C77B4ABE8D639D6339BE8D63BE8D63D79D73D79D73CFAE95
DFAE8DE8BE95BE8D63B66B42BE8D63C79D85C7956BD7AE85E8BE95E8D7CFF0F0E8000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000F8F0F8F8F8F8F8F8F8F0E8E8
E8D7CFE8CFBECFB6A6BE957BB67B5AAE7352956342955A31955A31955A315A31216B39216B3118\
6B3118F0C7B6F0C7B6F8CFB6F0CFAEF0C7AEF0C7AEF8C7B6F0C7AEF0BE9DE8B69D
E8AE95E8AE95DFAE8DDFAE8DDFAE8DDFA685DFAE8DDFAE8DDFAE8DDFAE8DE8B695E8B695E8B695\
E8B69DE8B695DFAE8DDFAE8DDFA685DF9D7BD79D7BD79D73CF8D63B66B52955A31
855231854A317342296B3921734A31956342CF956BBE8D63A67B5AD79D73C77B4AB67B5A854221\
AE6B39C7855AC77B42C77B4AAE6B39B67B5AB67B5AD79D7BC7956BD79D73D7AE85
E8BEA6E8C7B6BE8D63C7956BD79D7BC7956BC78D63CFAE95E8BE9DF8F0E8E8DFD7000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000F8F8F8F8F8F8F8F0F8F8F0F8F0E8E8
E8D7C7DFCFBED7AE8DC7956BB6734AB6734AAE63428D4A31955A318552316B31186B3921854A29\
E8C7B6F0CFB6F0CFB6F8CFB6F0CFAEF0C7AEF0C7AEF0C7A6E8BEA6E8AE95E8AE8D
DFA685DF9D7BE88D7BE88D7BE88D7BE88D7BE88D7BDFA685DF9D7BDFA685DFAE8DDFA685E8B695\
E8B695E8B69DDFAE95DFAE8DDFA685D7A685D79D7BCF956BCF956BC785638D5A42
8542297B4A296B39215229186B39218D634ACF956BAE7352955A31D7A685C77B4ACF9563B67B5A\
9D6339AE6B42CF8D5AC77B4AB6734ABE8D63B67B5AD79D73C7956BD7AE85D79D73
D7AE85E8C7AED7AE85D79D73C79D85C79D85D79D73D7AE8DE8BEA6F0E8DFF0E8DFF8F0E8000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000F8F0E8F8F8F8F8F0F8F0F0E8E8D7CF
E8CFBEDFCFC7C79D85B67B5AAE73529D6339AE6342855239854A296B39216B39217B39187B4A29\
F0C7B6F0C7B6F0C7AEF0C7AEF0C7AEF0C7AEF0C7A6F0B69DDF7363CF6B5ADF7B6B
DF7B6BDF8573DF8573DF8573DF8573DF8573CF6B5ACF6B5ACF6B5ACF6B5AD79D7BDFAE8DDFAE8D\
E8B695E8B695E8B695DFAE95DFAE8DDFA685D79D7BD79D7BCF956BC7856BC7855A
7B4A296B39216B31185221106B3118855239AE7352D79D7BB68563C7856BD7AE85CF9563D79D73\
C7956BC77B4AB6734AC7855ABE8D63AE6B39B6734ABE8D63D79D73BE8D63DFAE85
D7AE8DE8BE95E8BEA6C79D85D7AE85C7956BD79D73E8BE95DFCFBEE8D7CFF0E8E8F0F0E8000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000F8F8F8F8F8F8F8F0E8F8F8F8F0E8E8E8DFD7
E8D7C7D7AE8DC7956BA67B5A9D6B4A9D6339955A317B4A298552397342296B39217B4A29F0CFBE\
F0C7B6F0C7AEF0C7AEF0C7A6F0CFAEF0C7AEE88D7BDF8573DF8573DF8573F0C7B6
F0B69DE88D7BE88D7BE8A695F0B69DDF8573DF8573DF7B6BC7856BCF7363CF6B5AD79D7BDFAE8D\
DFAE95E8B695E8B69DDFAE95DFAE8DDFAE8DD7A685D79D7BCF956BDF8573C78563
B67B5A734A31522918522918522110855239522918D7A685DFAE8D9D6339D7AE8DB67B5ADFA67B\
D7AE85BE8D63C7855ACF9563AE6331C7855AB67B5ABE8D63C7956BCF956BD79D7B
D7AE8DE8BEA6E8C7B6BE957BB68563C7956BD79D73CFAE95F0E8DFF0E8DFF0F0E8F0F0E8F0E8DF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000F8F8F8F8F8F8F0F0F8F8F8F8E8D7D7DFCFBE
CFAE95C7956BB68563A67B5A855239955A318D4A31955A316329106B39216B3921A6856BF0CFB6\
F0CFB6F0CFB6F0C7AEF0C7A6F0C7A6F0C7A6DF7B6BDF8573DF8573DF7B6BDF7363
DF7363DF7363DF8573CF6B5ACF6B5AC75A4AC7634AC7634AE88D7BCF7363CF7363C75A4AD7A68D\
E8AE95E8B695E8B695E8B695E8B695DFAE8DD7A685D79D7BD79D7BCF956BCF956B
C7855AAE73526B39216B39213918106B31188D5A42B68563C7956BB67B5ABE8D63D7AE85C7855A\
DFAE85F0CFAEBE8D63B6734AC7855AC7855AAE6B42B67B5ACF9563C7956BD79D73
D79D73E8BEA6E8BEA6C79D85C7956BC79D85BE957BCFAE95F0E8DFF0E8E8F8F0E8F0E8E8F0E8E8\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000F8F0F8F8F8F8F8F0F8F8F0F8F8F0F8E8D7CFD7C7B6
D79D73C7956BAE73529563428D4A31955A31854A296B31187B42216B3118955A31F0CFBEF0CFBE\
F0CFB6F0C7AEF0C7AEF0C7A6E88D7BDF8573AE73529D4A31AE4A31BE5242AE7352
BE5242BE5242C75A4AB652399D4A319D31219D4229AE4A318D3121AE42319D4229854229955A42\
DF8573E8B695E8B695E8B695DFAE8DDFAE8DDFAE8DD79D7BD79D7BD79D73D79D7B
C78563B67B5A8D5A424A18083918106B3921734A31855A42BE8D63D7A685955A31D7A685B67B5A\
D79D7BE8BE9DF0CFAECF956BCF956BB66B39C7855AB67B5ABE8D63C78D63B67B5A
D7AE85E8BE95E8BEA6D7BEAED79D73D7AE85C79D85D7B6A6E8DFD7F0F0E8F0E8DFF0F0E8F8F0F8\
F0F0E8000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000F8F0F8F8F0F8F8F0E8F8F0F8F0E8E8E8D7CFD7BEAE
BE957BB67B5A9563428D4A318D5A428D4A297B4A297B4A297B4A29854229F0CFBEF0CFBEF0C7B6\
F0CFB6F8CFB6F0C7AEF0C7A6F0B69DF0C7A6E88D7BCF7363CF6B5AC7634ACF6B5A
C7634ACF6B5ADF7B6BC7634AC7634AC7634AC7634AC7634AC7634AD79D73D7A685D7A68DDFAE8D\
DFAE8DE8B695E8B695E8AE8DE8AE8DDFAE8DE8AE8DDFA685D79D7BD79D7BD79D73
CF956BC785639D73525A39293918103918105A3929855A429D7352D79D7BC7956B9D6B4AD79D73\
B67B5AE8BE9DE8BE9DF0CFB6AE7352C7855AC7855AB67B5ABE8D63BE8D63B67B5A
D7AE85D7AE85E8BEA6E8C7AEC7956BD7AE85D79D73E8D7C7F0E8E8F0E8E8F0E8DFF0E8DFF8F0F8\
F8F0F8000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000F8F0E8F8F8F8F8F0F8F0F0E8F8F0E8F0E8DFDFCFC7D7AE8D
B685639D6B4A9D6B4A8D5A428D4A29854A297342297B4A29854221855231F0CFB6F0C7AEF0CFB6\
F0CFAEF0C7AEF0CFAEF0C7A6F0CFAEF8CFB6F8CFB6F8D7BEF0D7C7F0C7B6F0C7AE
F8D7BEF0C7AEF0C7A6F8CFB6F8D7BEF0C7B6F0C7AEE8BEA6E8B69DE8BEA6E8B69DE8B695E8B695\
E8B69DE8B695E8B69DE8B695E8AE95DFAE8DDFAE8DDFA685DFA685D79D7BD79D73
CF956BCF956BB67B5A855231423129291008855A42734A31855A429D7352BE8D639D6339C7855A\
AE6B42C7855AE8BE9DE8BE9DD79D73CF956BBE8D63B6734AB6734ABE8D63CF956B
D79D73CF956BE8BEA6E8C7AEC79D85C79D85C78D63E8DFD7F0E8DFF0E8DFF0E8E8F0E8DFF8F8F8\
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000F8F0F8F8F0E8F8F0F8F8F0F8F0E8E8DFC7B6E8BE9DC79D85
AE7352956342855231855231854A316B31187B4A297B4A297B4221D7B6A6F0CFB6F0CFB6F0CFB6\
F8C7B6F8CFB6F0C7AEF8CFB6F0C7AEF8CFB6F8CFB6F8D7BEF8CFB6F8D7BEF8CFB6
F8D7BEF0C7A6F0C7AEF0C7AEF0C7AEE8B69DE8B69DE8B69DE8B69DE8BE9DE8B69DE8BE9DF0C7A6\
E8B69DE8B695E8BE9DE8B69DE8AE95E8AE95DFAE8DDFA685DFA685D79D7BDF8573
CF956BCF956BB67B5A955A42522110422118734A31855231A6856B9D7352C79D859D6339955A31\
C78D63BE8D63DFAE95E8BE9DF0C7A6D7AE85C7855AC7855AC78D63B6734AB67B5A
B67B5ACF956BE8BEA6E8C7AED79D73D7AE8DC7956BF0E8DFF0E8E8E8DFD7F0E8DFF8F0E8F8F8F8\
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000F8F0F8F8F0F8F8F0E8F8F0F8F8F0F8DFCFC7C79D85B67B5A
9D63399D6B4A854A29854A316B39217B4A297B4A297B4A297B4A29F0CFB6F0CFB6F0C7B6F0CFB6\
F8CFB6F8C7B6F8C7B6F8CFB6F0CFB6F8CFB6F8CFB6F8CFB6F8CFB6F8CFB6F8CFB6
F0CFB6F0C7AEF0C7A6F0C7A6F0C7A6E8B69DE8BE9DF0BE9DE8B69DE8BEA6E8B69DF0C7A6E8B69D\
F0C7A6E8B69DE8B69DE8AE95E8AE95E8B695DFAE8DDFA685DF9D7BDFA685D79D73
CF956BCF956BC785639D6B4A7342295A39293918107352428552399563429D6339AE73529D6339\
B67B5AA67B5ACF956BE8BE95E8BE95CF956BD79D73C7855ABE8D63B6734ABE8D63
B6734AD79D73D7AE85E8BEA6CFAE95C7956BD79D7BE8D7CFF0E8DFF0E8DFE8D7C7F8F8F8F8F0F8\
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F8F8F8F8F8F8F8F0F8F8F0F8F8F0E8DFCFC7D7C7B6BE957BB6734A
9D6B4A854A298D5A426B39217B4A296B31187B4A29854A296B3921F0CFB6F0C7B6F0C7B6F0CFB6\
F8CFB6F8CFB6F8CFB6F8C7B6F8CFB6F8CFB6F8CFB6F8CFB6F0CFB6F8CFB6F8CFB6
F0C7A6F0C7A6E8B69DF0C7A6E8B69DE8AE8DE8B695E8BE9DE8B69DF0B69DF0BE9DF0C7A6F0B69D\
F0B69DF0C7AEF0C7A6E8B69DE8B69DE8AE95E8AE8DDFA685DFA685D79D7BD79D73
DF8573C7856BC78563B6734A734A31522110522918734A318D634A956B529D7352B685639D6B4A\
8D5A42956342BE957BC78D63DFA673F0C7A6D7AE85C77B4AC78D639D6B4AC7956B
BE8D63D79D7BD79D73E8BEA6CFAE95BE8D63E8C7B6E8D7C7F0E8E8F0E8E8F0E8E8F8F0F8F8F8F8\
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F8F0F8F8F0F8F8F8F8F8F8F8F0E8E8DFC7B6C7A695BE957B9D6B4A
9D63399563428542297B4A297B4A29734A317B4A296B3921B68563E8C7B6F0C7B6F0C7B6F8CFB6\
F8CFB6F8CFB6F8CFB6F8D7BEF8CFB6F0CFB6F8CFB6F8CFB6F8CFB6F0C7AEF0C7AE
E8B69DDFAE8DDFA685E8AE95DFAE95DFA685DFAE8DE8AE95E8B695E8B69DF0BE9DE8BEA6F0C7A6\
F0C7AEF0C7AEF0B69DF0B69DE8B69DE8AE95DFAE8DDFA685DFA685D79D7BD79D7B
D79D73CF956BC77B5AB66B528D5A425A39296B39215A4239855A428552399D7352956342B6734A\
8552319D6339855239D7AE8DE8BE95D79D73DFA67BC78D63C7956BA67B5AB67B5A
BE8D63C79D85D79D73E8BE9DD7B6A6C7956BE8DFD7E8BEA6F8F0F8F0E8E8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F8F8F8F8F0E8F8F8F8F8F0F8F8F0F8E8BE9DBE957BAE7352956342
8D4A318D4A317B4A296B39216B39217B4A297B4A296B3118E8C7B6F0C7B6F0C7B6F8C7B6F8CFB6\
F8CFB6F8CFB6F8CFB6F8CFB6F8CFB6F0CFAEF8CFB6F8CFB6F8CFB6F0C7AEF0B69D
E8AE9DE8B695DF9D7BDFA685DFA685D79D7BD7A685DFAE8DDFAE8DE8B695E8B69DF0BE9DF0B69D\
F0C7A6F0C7A6F0C7A6F0B69DF0C7A6F0B695E8AE95DFAE8DDFA685D79D7BD79D7B
D79D73C7856BC78563B67B5A955A425A3929291008422921734A318552319D6B4A855239B6734A\
9D63399D63397B4A29D7A685C7855AD79D73F0CFAEC7956BC78D63C78D63B67B5A
B68D73C7855AC7956BE8BE9DD7BEAED7BEAEDFCFBEE8D7CFE8D7CFE8CFC7F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F0E8E8D7AE8DB68563956342855231
8D4A316B39217B4A297342297B4A298542296B31185A3121F0C7B6E8C7AEF0C7AEF0C7AEF8CFB6\
F8C7B6F8D7BEF8D7BEF8CFB6F8CFB6F8CFB6F8C7B6F0D7C7DF9D7BDF7B6BF0C7AE
F0C7AEF0B69DE8A695B66342B66342C7856BDF9D7BB67B5AD79D73DFAE8DE8B69DF0C7A6F0C7A6\
F0C7AEF0C7AEF0C7AEF0C7A6F0B69DE8B69DE8AE95E8AE8DDFA685DFA685D79D7B
D79D73CF956BC78563B66B52AE63427342293918104229215A3121734A31855239855A429D6B4A\
9D6B4A8552319D6B4A8D5A42BE8D63DFAE85D79D73DFAE85C7855ABE8D639D6339
B67B5AB67B5AD79D73E8BE95D7BEAEF0E8E8CFAE95F0E8E8D7B6A6F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8E8DFDFC7956BAE73529563429D6339
7B4A297B4A296B39217B42217B4A296B39215A3121855239F0C7B6F0C7AEF0CFB6F8CFB6F8D7BE\
F8CFB6F8C7B6F8D7BEF8C7B6F8CFB6F0CFAEF8CFB6F8D7BEF0CFB6F0C7B6F8C7B6
F8C7B6F0C7AEE8B695DFAE8DDFAE95E8AE8DE8B695DFA685CF8D63D79D7BE8B69DF0C7AEF0C7AE\
F0C7AEF0C7AEF0C7AEF0B69DF0C7A6F0C7A6F0B695E8AE8DDFAE8DDFA685D79D7B
CF956BCF956BC78563C77B5A9D73528D5A422910083918104229215A42397352428D5A42855239\
9D7352855231955A31522918D7AE85CF8D63CF9563E8BE9DB67B5ABE8D639D6B4A
AE7352BE8D63C7956BCFAE95DFC7B6DFC7B6C7AE9DD7B6A6F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F0F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F8F8F8F8F0E8F8F8F8F8F8F8F8F8F8E8D7CFBE8D63956342955A426B3921
734A31854A317342297B4A29854A31632910632910A67B63E8C7AEF8C7B6F8C7B6F8C7B6F0D7C7\
F8D7BEF8D7BEF8D7BEF0D7C7F8CFB6F8CFB6F8C7B6F8D7BEF0C7B6F0D7C7F0D7C7
F0D7C7F8C7B6F0C7A6E8B695E8AE9DE8AE9DDFAE95DFAE8DDFA685DFA685F0B69DF0C7AEF0C7AE\
F8C7B6F0C7AEF0C7AEF0C7AEF0B69DF0B69DF0B69DE8B695E8AE8DDFAE8DDF9D7B
DF8573DF8573C78563B67B5AAE6B42956342291008422118391810734A31855239956342734229\
9D6B4A855231955A315A3121C7956BBE8D63D7AE85E8BE9DB67B5ABE8D63AE7352
B67B5AB68563BE957BD7AE8DDFC7B6DFC7B6D7BEAEDFCFBEF8F8F8F8F8F8F8F0F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F8F8F8F8F0F8F8F0F8F8F8F8F8F0F8E8CFC7AE73528D5A42955A31855231
7B4A297B4A29854A298D4A317B42215229185A3929E8C7B6F0C7B6F8CFB6F8CFB6F8D7BEF8D7BE\
F8D7BEF0D7C7F8D7BEF0D7C7F8D7BEF8C7B6F0C7AEF8D7BEF8D7BEF0D7C7F8DFD7
F0D7C7F8C7B6F0C7AEE8BEA6E8AE95E8A695DFAE95DFAE8DDFA685E8AE95F0B69DF0C7AEF0C7AE\
F0CFAEF0C7AEF8C7B6F0C7AEF0C7A6F0C7A6F0B69DF0B69DE8AE95E8AE8DDFA685
DF9D7BCF956BC7856BB67B5AAE6B42955A315229181808084221187342295229189D6339855231\
9D6B4A7B42218552318D5A42AE7352C78D63DFA67BDFA67BD79D73B67B5ABE8D63
AE7352B67B5AB67B5ACFAE95E8C7AED7B6A6E8CFC7F8F0F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F0F8F8F0F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F8F0F8F8F8F8F8F8F8F8F8F8F8F0E8C7956B9563429563426B3921734229
7342297B4A29854A317B4A29422118632910422118F0C7AEF8C7B6F0CFBEF8C7B6F8D7BEF8D7BE\
F0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8CFB6F8CFB6F8C7B6F0D7C7F0D7C7
F0D7C7F8CFB6F0C7AEE8AE95D7A68DDFA685DFAE8DD7A68DDFAE95E8B69DF0C7AEF0C7B6F0C7B6\
F0CFB6F8CFB6F0C7AEF0C7AEF0C7A6F0C7AEF0C7A6F0B69DE8AE95E8AE8DDFAE8D
DFA685D79D73C7856BB67B5AAE7352AE6342734A312110083918105A39297B5A428552398D5A42\
9563427B4A29855231734A319D7352C7855ACF956BDFAE8DE8BEA6B6734AB67B5A
9D7352B67B5AC7956BE8BE9DE8C7AEC79D85DFCFBEF8F8F8F8F0F8F8F8F8F8F0F8F8F0F8F8F0F8\
F8F8F8F8F8F8F8F8F8F8F0F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F0F8F8F8F8F8F8F8F8F8F8F0F0F8B6856B956342854A296B3921855239
854A31854A317B4A293918105229185221105A3929F0C7AEF8CFB6F8D7BEF0D7C7F0D7C7F0D7C7\
F0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F8D7BEF8D7BEF8C7B6F0CFBEF8C7B6F8D7BE
F8C7B6F0C7B6F0B69DE8B69DD7A68DDFAE8DDFAE95DFAE95E8B69DF0C7AEF0C7AEF0C7AEF0C7B6\
F8C7B6F8CFB6F0C7B6F8C7B6F0C7AEF0C7A6F0C7AEF0B69DF0B69DE8AE95E8AE8D
D7A685DFA685CF956BC78563AE73529D6B4A8D4A31291008423129522918734229734A31855231\
8552319D6339855231855231A67B5ABE8D63CF9563DFAE8DF0CFAEB67B5AB6734A
9D6B4AA67B5AB68563CFAE95DFC7B6DFCFBEF8F0F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F0F8F8F8F8F8F0F8F8F0F8F8F0F8F8F0F8B6856B955A317B4A297B4A29855239
734A317B4A29854A31522918422118522918CFAE95F0CFB6F0CFB6F8D7BEF0D7C7F0D7C7F0D7C7\
F0D7C7F8DFCFF8DFCFF8DFCFF0D7C7F8D7BEF8D7BEF8D7BEF8CFB6F0C7B6F8D7BE
F8D7BEF0C7AEF0B69DDFAE95DFAE95DFAE8DE8B695E8B69DE8BEA6F0C7AEF0CFB6F0C7B6F8C7B6\
F8C7B6F8D7BEF0CFBEF8C7B6F0C7B6F0C7AEF0C7AEF0B69DE8B69DE8B69DDFAE95
DFA685D79D7BD79D73C78563B66B529D6B4A9563424221182110085A31215229188552398D5A42\
7B4A29955A319D63398552319D7352C79D85D79D73DFAE85F0CFAEAE7352C78D63
8D5A42B68563AE7352E8BE95E8CFBEDFCFBEF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F0F8F8F0F8F8F8F8DFC7C79D73528D5A42734229855231855231
854A317B4A29522918422118391810F0B69DF0CFBEF8C7B6F8D7BEF8DFCFF0D7C7F0D7C7F8DFCF\
F0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F8D7BEF8CFB6F8D7BE
F8D7BEF8C7B6F0C7AEE8B69DDFAE95E8B695E8B695E8B69DE8BEA6F0C7B6F0C7B6F0D7C7F8D7BE\
F8C7B6F0D7C7F8C7B6F8D7BEF0CFBEF0CFBEF0C7B6F0C7AEE8C7AEF0B69DE8B695
DFAE8DD7A685D79D7BD79D73B67B5A9D6B4A9D63397342296329106B3921734A31734A31956342\
8552319D63398D5A428D4A319D7352D7A685D79D73D7AE85E8BEA6BE8D63B6734A
855231A67B5AB67B5ADFAE8DE8D7C7F0F0E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F89D7352955A318552315A31217B5A42734A31
734A31854A315229186B39215A3929F0C7AEF0C7B6F0D7C7F8D7BEF0D7C7F0D7C7F8DFCFF8DFCF\
F0D7C7F0D7C7F8D7BEF8DFCFF0D7C7F0D7C7F0D7C7F0D7C7F8D7BEF0CFBEF8D7BE
F8D7BEF8D7BEF8C7B6E8B69DDFAE95E8B69DE8BE9DE8BEA6E8BEA6E8C7AEF0CFB6F8D7BEF0CFBE\
F8D7BEF0D7C7F8D7BEF8C7B6F0CFBEF0CFBEF0CFBEF0C7B6F0C7AEE8BEA6E8B69D
DFAE95DFAE8DD79D7BD79D73C77B5AB66B52955A42734A316B39216B39216B3921855239855231\
9D63399563428D5A4295735AB6856BD79D7BD79D73D79D73D7AE85C78D63AE6B39
854A29A67B5ABE957BD7AE8DE8DFD7F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F8F8F8F0F8F8F8F8AE73529D6339734A316B39218D5A42855239
7B4A297342296B3921522918A68573F8C7B6F0CFBEF0D7C7F0D7C7F0D7C7F8DFCFF8DFCFF0D7C7\
F8D7BEF0D7C7F8D7BEF8D7BEF0D7C7F8DFCFF8DFCFF0D7C7F0D7C7F8D7BEF8D7BE
F0D7C7F8C7B6F8C7B6E8B69DDFAE95DFAE95E8BE9DE8BEA6F0C7AEF0C7AEF0CFBEF0CFBEF0CFBE\
F0D7C7F0D7C7F8C7B6F8C7B6F8D7BEF8CFB6F0CFB6F0C7B6F0C7AEF0C7AEE8BEA6
DFAE95DFAE8DD7A685D79D73C78563B66B52955A428D4A315A31215A31216B3921734A31854A31\
9563429D6339956342955A31D79D73D79D73D79D73D79D73D7A685D7AE85AE6B42
AE6B42AE7352B68563DFAE85F0F0E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F8F8F8F8F8F8F0F89D73529D7352855239734A31734229855239
854A315A3121734229855239F0C7B6F8CFB6F0CFBEF0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F0D7C7\
F0D7C7F8D7BEF0D7C7F0CFBEF0D7C7F0D7C7F0D7C7F0D7C7F8D7BEF8D7BEF0C7B6
F0D7C7F0D7C7F8D7BEE8BEA6E8AE95DFAE95E8B69DE8BEA6E8BEA6E8C7AEF0C7B6F0CFBEF0CFBE\
F0CFBEF0D7C7F0CFBEF8D7BEF0CFBEF0C7B6F0C7B6F0C7AEF0C7B6E8C7AEE8BEA6
E8BEA6DFAE95D7A685D79D7BCF956BB67B5A9D6B4A8552397342296B31186B39216B3921855239\
955A318D634A855239854A29D7AE8DD79D73C7956BD79D7BC79D85DFAE8D955A31
AE7352AE7352A6856BD7AE85F8F0E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F0F8F8F8F8BEAEAE955A318D634A8552318D5A428552318D4A31
6B39215A3929734229E8C7AEF8D7BEF0C7B6F8D7BEF0D7C7F0D7C7F0D7C7F0D7C7F8DFCFF0D7C7\
F0D7C7F8D7BEF0CFBEF0C7B6F0C7B6F0CFBEF0CFBEF8D7BEF8D7BEF8C7B6F8CFB6
F0D7C7F0D7C7F8D7BEF0C7AEE8AE95DFAE8DDFAE95DFAE9DE8BE9DDFAE9DE8C7B6E8CFBEF0C7B6\
F0D7C7F0CFBEF0CFBEF0CFBEF0C7B6E8C7B6F0C7B6F0C7AEF0C7AEF0C7AEE8BEA6
E8BEA6DFAE9DDFAE8DD7A685DF8573C785639D6B4A955A31734A315229186B39216B3921734A31\
9D6B4A8D5A428D5A428D5A42C79D85C7956BD79D73D79D739D6B4AE8BE95854221
9D6B4ABE8D63C7956BCFAE95F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F0F8F8F8F8A67B6BB68D739D6B4A734A319D6B4A734A318D4A31
5A3121734A317B4A29E8C7AEF8C7B6E8C7AEF0D7C7F0D7C7F8DFCFF0D7C7F0D7C7F8D7BEF0D7C7\
F0CFBEF0CFBEF0B69DE8C7AEF0C7AEF0C7AEF0C7B6F0CFBEF8D7BEF0CFB6F8CFB6
F8D7BEF0D7C7F8D7BEF0C7AEE8A695DFAE8DD7A68DDFAE95DFAE95E8BEA6E8C7B6F0C7B6F0CFBE\
E8C7AEE8C7AEE8BEA6E8C7AEE8C7AEE8C7AEE8C7AEF0C7AEF0C7B6E8C7AEE8C7AE
D7B6A6E8BE9DDFAE8DD7A685D79D73C78563AE7352955A31854A315229185221106B3921734A31\
8D5A429D63398D5A428D5A42C79D85CF956BCF956BD79D73854A31DFAE85955A42
8D5A42B6856BD7A685E8C7AEF8F8F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F0F8F8F0F8F8F8F8F8F8F88D4A29B6957B8D5A42956B52855A428D5A42734A31
5229189D6339E8AE8DF0C7AEE8AE95F0C7B6F8D7BEF0D7C7F0D7C7F0D7C7F0D7C7F0CFBEE8CFBE\
F0C7B6F0C7B6F0C7AEDFAE9DDFAE95E8BEA6E8C7AEF0C7B6F0CFBEE8C7AEF0C7B6
F0D7C7F0D7C7F8D7BEF0B69DDFAE95DF9D7BD7AE8DD7A68DCFAE95D7B6A6E8C7AEE8C7B6E8BEA6\
E8BEA6D7B6A6E8AE9DDFAE8DDFAE8DD7A68DDFAE9DDFAE9DE8BEA6E8BEA6E8BEA6
E8BE9DE8BE9DDFAE95D7A685CF956BC7856BB66B529D6B4A8552397342293918106329106B3921\
8D5A428D5A429D6B4A855239BE957BD79D7BB67B5ABE8D63854A29E8BE959D6B4A
8D4A31C7956BD7AE85E8D7C7F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F8F8FFFFFF9D6B4AA67B638552398D5A42855239955A42522110
855231854A31F8C7B6CF956BDFA685F0CFB6F8D7BEF0D7C7F0D7C7F0D7C7F0CFBEE8C7B6DFAE9D\
BE957BB68D73D7A68DCFA695BE957BDFAE9DDFAE9DF0CFBEF0CFBEF0C7B6F0C7B6
F8D7BEF8D7BEF8D7BEF0C7AEDFAE95D79D7BC79D85D79D7BE8BE9DDFAE9DE8C7B6E8AE9DDFAE9D\
C7A69DBE9D8DB6856BB68D73C79D85C79D85C79D85CFA695E8BE9DE8BEA6DFAE9D
DFAE9DDFAE9DDFAE8DD7A685C79D85C7856BB67B5A955A42855239734A316B39215A31215A3121\
8552398552318D634A8D5A42B6856BBE8D63B67B5AB67B5A955A31E8BE95955A31
8D4A31C79D85D79D73E8D7CFFFFFFFF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F8F8BE9D95A67B5A9D7352734A31855239734A31955A425A3121
955A31F0B695F0B69DE88D7BD7A68DF0CFB6F0CFBEF0D7C7F0D7C7F0C7B6E8AE9DB68563BE8D63\
DFAE9DBEAEAE736B6373736BA68573C79D85DF8573DF8573F0C7B6F0C7B6E8C7AE
F8D7BEF8D7BEF8D7BEF0C7A6E8B69DD79D7BD7A685BE957BD7A6859D4A31C75A4AC7856BD7A68D\
DFC7C7957B73735A4AA67B6BA67B63A67B5AA67B63B6856BD7A68DDFAE95DFAE95
DFAE9DDFAE9DD7A68DD7A68DCF956BC7856BB66B529D6B4A8D5A42734A31855239522918522918\
8552398552398D5A429D6B4AB68563BE957BB6734AB67B5A955229E8BE9D9D6339
9D7352D7AE85D7AE85F0E8E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F8F8B6856BBE9D8D9D73528D634A5A3121855239955A426B3118
522918F8C7B6E8AE8DE8A695DFAE95F0CFBEF8D7BEF0CFBEE8C7AEE8AE9DB6856BC7856BD7BEB6\
E8D7CF7B7373736B63635A52857B73A67B6BC79D85BE957BE8AE9DDFAE95F0C7A6
F8D7BEF8D7BEF0CFB6F0C7AEE8B69DDFA685BE957BB6856BC7856BC79D85AE4231DFC7C7F0E8E8\
8D736395735A7B6B5A958D856B635ABE9D959D73528D6B52B6856BD7A685D7A685
DFAE95DFAE8DD7A68DD79D7BD79D73B6856BAE73529D6B4A855231734A315A3121291008422118\
8552398D5A427342299D6B4AB6856BB685639D6B4AA67B5AAE6342DFAE8D854A29
BE957BD7AE8DD7AE8DF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F0F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8FFFFFFF8F0F8A6856B8552317B4A295A3121855239855239855239
955A42F8C7B6DFA685E88D7BDFAE95E8C7B6F0CFB6F0C7AEDFAE9DBE957B95735A5A3929B6958D\
C7B6B6957B6BB6B6BE21181885736B5A4A4295735AB6856BBE957BE8B69DF0CFAE
F8D7BEF8D7BEF8CFB6F0C7AEE8BE9DE8B695BE957BB68D739D7352B68D73BE957B9D6B4ACFC7BE\
635A52B6BECF21181873736B635A52BE9D95423129735242A67B63B68D73BE957B
D7A685D7A68DD7A685BE957BC7956BC78563AE7352955A42855239854A31422118391810422118\
522918855239734A31AE73529D7352A67B5AA67B5AB67B5AAE6342D7AE85854A29
BE8D63D79D7BDFC7B6F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8B6957BD7C7C7A68D7395735A7B5242734A31855239855239955A42
CF7363F0B69DE88D7BD79D7BDFAE8DF0C7B6F0CFB6E8B69DCFA695C7856B734A31856352856352\
5A42394229215A39298552398D6B52856352A67B63BE957BE8AE95F0BE9DF8CFB6
F8CFB6F8D7BEF8CFB6F0C7AEF0BE9DE8B69DDFA685BE957BC7856BAE735295735AA68D85A68D85\
5A39295229185A39295A3929734A315A4239735A4A7B5242A67B63B68563B6856B
CF956BD79D7BD79D7BBE957BB6856BB67B5A955A428D5A428D5A42734A316B39214221185A3929\
6B39216B3921734A319D6B4AAE73529D6B4A9D6339B67B5AAE7352D7AE85956342
BE8D63D79D73F0E8DFF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8AE7352BE9D95B69D8D8D5A42734A318D634A855239734A318D4A31
C78563E8A695D79D7BD79D7BDFAE8DF0C7B6E8C7B6E8C7AEE8BEA6DFAE95BE957BB66B528D634A\
7B52427B52427B524285523995735AC7856BD7A685E8B69DF0C7AEF0C7AEF8CFB6
F8D7BEF8D7BEF8CFB6F0C7AEF0C7AEF0C7A6E8B695DFA685D79D7BBE957BB6856B85634AA67B63\
A685739D7B6B856352634A425A4239734A319D7352BE8D63B68D73C7856BCF956B
D79D7BD79D7BBE957BCF956BBE8D63B66B52955A428D5A428552398552397342295229185A3929\
5A31215A31217342299D7352B67B5A9D73529D6339B67B5ABE8D63D7AE859D6B4A
BE8D63D7A685F0F0E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F8F8F8F0E8DFA68D7B956B52734A31734229734A31734A316B39219D6B4A
C78563CF956BC79D85BE957BD7A68DE8C7B6F0CFB6F0CFB6F8D7BEF0CFBEF0C7AEF0C7B6E8BEA6\
E8B69DE8AE9DE8B69DE8BEA6E8B69DD79D7BDFA685E8AE95F0C7A6F8D7BEF8CFB6
F0D7C7F0D7C7F8D7BEF8CFB6F0CFAEF0C7AEE8B695D79D73DF9D7BBE957BD7A685D7A68DD7A685\
BE957BBE957BBE957BCF956BD79D7BD7A685D7A685DFAE8DE8AE8DDFAE95D7A68D
D7A685D79D7BCF956BC7856BBE8D63B67B5A955A428D634A8552396B39216B39215229185A3929\
734A317342296B39219D6B4ABE8D639D6B4A9D6339C7855ABE957BDFAE959D7352
BE957BF0DFCFFFFFFFF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000FFFFFFFFFFFF7342298D5A425A31216B39216B39219563425A31219D4A31
B66B52DF8573CF956BB68D73D7A685F0CFB6E8BEA6F8CFB6F8D7BEF8D7BEF0D7C7F8D7BEF8D7BE\
F0D7C7E8A695C7856BA67B639D7352B66B52E8B69DF0C7A6F8D7BEF8D7BEF8D7BE
F8DFCFF0D7C7F8D7BEF0D7C7F8CFB6F8D7BEF0BE9DE8AE95C7856BAE63429D7352B66B52B68D73\
E8BEA6E8C7AEF0C7AEE8C7AEE8BEA6E8BEA6E8B69DE8B69DE8B69DDFAE95D7A685
C7956BB68563CF956BBE8D63B67B5AAE73529D6B4A8D5A42855231855239632910522918522918\
5A3929522110734A318D5A42AE73529D6B4A956342C78D63C7956BE8BE9DA67B5A
C79D85F0E8E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F0E8E8FFFFFF6B39217B4A295A31216B3921734A31855239734A319D6339
B66342B67B5ABE8D63C7856BC79D85F0C7AEDFC7B6E8BE9DF0C7B6F8D7BEF0D7C7F0D7C7F8C7B6\
B6856BA67B6395735AB66B52D7A685F0C7A6F8CFB6F8CFB6F8D7BEF8DFCFF8D7BE
F8DFCFF0D7C7F8D7BEF8D7BEF8D7BEF8CFB6F8CFB6F0C7A6E8AE95BE8D63955A42855239955A42\
B66B52DFA685E8AE9DE8C7AEF0C7AEF0C7AEF0B69DE8BEA6DFAE95DFA685BE957B
A67B5ACF956BB68D73B6856BAE73529D6B4A9D6B4A8D5A426B39216B39215229185A3121522918\
522110735242855A42956B52A67B5A9D7352955A31BE8D63BE8D63D7AE8DBE957B
C79D85F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000BEAEAEFFFFFF855231734229734A31734A315A31218552397B4A29955A31
955A42955A42A67B63B6856BC79D85E8C7B6F0CFBEBE957BC79D85D7A685D79D7BDF8573B66B52\
AE7352D79D7BF8CFB6F8D7BEF8D7BEF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCF
F0D7C7F0D7C7F0D7C7F0D7C7F8D7BEF0D7C7F8CFB6F8CFB6F8CFB6F0CFAEE8B69DD7A685B68D73\
95735A8D5A429D7352AE6342CF6B5AB68D73C7856BB68563A67B63A67B5AB6856B
BE957BBE957BDF8573BE8D63AE73529D6B4A9D6B4A8552399D6B4A4221187342297342296B3921\
52291842292185634A9D6B4AAE73529D6B4A956342BE8D63D79D73B6856BAE6B42
DFCFBEF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000C7A6959D7352734A31734A3185634A855239734A31734A31734A31855239
955A318D634A9D7352A67B5AD7A685E8C7B6F0CFB6F0CFB6F0C7AED7A685BE9D8DDF8573DFAE9D\
F0D7C7F8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFD7
F0D7C7F0D7C7F8DFCFF8DFCFF8DFCFF8D7BEF8D7BEF0D7C7F8D7BEF8CFB6F8C7B6F0C7AEF0C7AE\
F0C7AEE8C7AEE8C7AEC79D85A67B63AE7352A67B63A67B63BE957BC79D85BE957B
CF956BD79D73CF956BBE8D63AE73529D7352AE73528552396B3921734A316B39215A3121391810\
3918104221188D634A95735A8D5A42A67B5AAE6342C7956BC79D859D6B4ABE8D63
F0E8E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000009D6B4A7B5A42734A319D7B6B8D6B527B5A42855239734A318D5A42
8D5A428D634AAE7352AE7352D79D7BF0C7AEF0C7B6F0CFB6F0CFB6F8D7BEF8D7BEF0D7C7F0D7C7\
F0D7C7F8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFD7F8DFCFF8DFCF
F0D7C7F8DFCFF8DFCFF8DFCFF0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F8D7BEF0CFB6F0CFB6F8CFB6\
F0C7AEF0C7AEF0C7AEE8BEA6E8C7AEE8C7AEE8B69DDFAE95DFAE8DD7A68DD79D7B
D7A685BE957BB68D73B67B5AAE7352A67B5AAE73529D6B4A734A316B3921522110391810391810\
391810422118B68D738D634A8D5A42D79D739D6B4AB67B5AD7AE859D6B4AC79D85
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000854A29735242855A42A68D73956B52855239855A427B5A42855A42
855A428D5A42A67B5A9D7352D79D7BE8C7AEF0CFB6F0CFB6F0CFBEF8D7BEF8D7BEF0D7C7F8DFCF\
F8DFCFF0D7C7F8D7BEF8DFCFF8DFCFF8DFCFF8D7BEF8DFCFF8DFCFF8DFCFF8DFCF
F8D7BEF0D7C7F8DFCFF0D7C7F0D7C7F8DFCFF0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF8C7B6F8CFB6\
F0C7B6F0C7AEE8C7AEE8BEA6F0C7AEE8B69DE8B69DDFAE95D7A685D7A685D79D7B
D79D7BBE957BC7956BBE8D63B66B52AE7352AE73528D5A429D6B4A734229522918522918422118\
5A3121522110BE957BA67B5A8D5A42BE957BAE73529D6B4AD7AE8D9D6B4AD7BEAE
FFFFFFF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000008552398D6B528D634A9D73528D634A8D6B528D634A855A42855239
8552318552319D6B4A9D7352C7856BE8BE9DF0C7B6F0CFB6F0CFB6F0CFBEF8D7BEF8D7BEF0D7C7\
F8DFCFF8DFCFF8D7BEF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCF
F8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF0D7C7F0D7C7F0D7C7F8CFB6F8CFB6F8CFB6F8CFB6F8CFB6\
F0C7AEF0C7A6E8C7AEF0C7AEE8BEA6E8BE9DE8B695DFAE95DFAE8DD7A68DD7A685
D79D7BD79D73CF956BB67B5AAE7352B67B5A9D73529D6B4A734A315A31216B39215A3121391810\
391810422118C7956BA67B639D6B4AD79D73B6734A8D634ABE957B9D6B4AF8F0F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000085523985523985523985634A8D634A855239855A42855239
855A42855239A67B5AB67B5AC7956BE8B69DE8BEA6F0CFAEF0CFBEF8CFB6F8D7BEF8D7BEF0D7C7\
F0D7C7F8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8D7BEF8D7BEF8DFCFF8DFCFF8DFCF
F8DFCFF8DFCFF0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F8C7B6F8CFB6F8CFB6F8CFB6F0CFAEF0C7AE\
F0C7AEF0C7AEF0B69DE8BEA6E8BE9DE8BEA6E8B69DDFAE8DDFAE95DFA685D7A685
BE957BCF956BC7856BBE8D63B67B5AAE73529D6B4A855239734A315A3929734229422118391810\
3918105A31219D7352D79D73B68563D79D7BB67B5A9D7352956342CFAE95F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000008D6B528552398D634A8D6B52956B528D634A855A42855A42
8552398D634A9D7352BE8D63BE957BDFAE8DE8BEA6F0CFB6F0CFBEF8D7BEF8D7BEF8D7BEF8D7BE\
F8DFCFF8DFCFF8D7BEF8D7BEF8DFCFF8DFCFF8D7BEF8DFCFF8DFCFF0D7C7F8DFCF
F8DFCFF8DFCFF0D7C7F0D7C7F0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF8CFB6F8CFB6F0CFAEF0C7AE\
F0C7AEF0C7AEF0B69DE8B69DE8B69DE8B69DE8B69DE8AE95DFAE8DD7A68DD7A685
D79D7BCF956BB68D73B68563B68563A67B639D6B4A8D5A426B3921734A31522110422118422118\
39181042292195735ABE957B9D7352C7956BBE8D63A6856B956342E8CFC7F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000007352428D5A42956B52956B52855A428D634A8552397B5A42
956B528D634A9D7352B6856BC7956BD7A68DE8BEA6F0C7AEF8CFB6F8CFB6F8CFB6F8D7BEF8D7BE\
F8D7BEF8DFCFF8DFCFF0D7C7F8D7BEF8DFCFF8DFCFF0D7C7F8D7BEF8DFCFF8D7BE
F0D7C7F0D7C7F8D7BEF0D7C7F8D7BEF8D7BEF8D7BEF8CFB6F8D7BEF8CFB6F8CFB6F0C7AEF8CFB6\
F0C7AEF0C7A6F0C7A6E8BEA6E8BE9DE8BEA6E8B695DFAE95DFAE8DD7A68DD7A685
BE957BCF956BC7856BB68563B685639D6B4A9D6B4A8D5A42734A316B3921522110391810291008\
2910087B52428D634AA67B5AAE7352C79D85C7956BD7AE8DC7956BF8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000A67B5A8D5A428D634A85634A8D5A42855A429D6339
7342298D634AA67B63BE8D63B68D73D7A685E8BE9DF0C7AEF0CFB6F8CFB6F8D7BEF8D7BEF8D7BE\
F8DFCFF8DFCFF0D7C7F8DFCFF8DFCFF8DFCFF8D7BEF8DFCFF8D7BEF0D7C7F8DFCF
F8D7BEF0D7C7F0D7C7F8D7BEF0D7C7F0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF0C7AEF8C7B6F0CFAE\
F0C7AEF0C7AEF0B69DF0C7A6E8B69DE8B69DDFAE95DFAE95DFAE8DD7A68DD7A685
BE957BD79D73B68D73B6856B9D7352956B52855A42734A318552395A3121391810291008422921\
29100885634A956B529D6B4A956342C7956BC7956BC79D85E8DFD7F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000007B5A427B5A42855239855239855231855A42855239
8D634A8D634AA67B5AB68D73C79D85D7A68DE8BE9DF0C7AEF0CFB6F8D7BEF8D7BEF0D7C7F8D7BE\
F8DFCFF8DFCFF8D7BEF8DFCFF8D7BEF8DFCFF8D7BEF0D7C7F8D7BEF8DFCFF8D7BE
F0D7C7F0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF0D7C7F8D7BEF8D7BEF8C7B6F8CFB6F8CFB6F0C7AE\
F0C7AEF0C7AEF0B69DF0C7A6E8B69DE8B69DDFAE95DFAE8DDFAE8DDFAE8DD7A685
C79D85D79D7BB6856BA67B639D73529D73529D6B4A7B5A426B39215A3121391810391810422921\
391810956B52956B529D73529D6339C7956BC79D85D7A68DF8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000855239734A31855231735242734A317B5A42
8D634A9D6B4AB68563B68D73D79D7BD7AE8DE8BE9DF0C7AEF8CFB6F8C7B6F8D7BEF0D7C7F8D7BE\
F8D7BEF8D7BEF8D7BEF0D7C7F8DFCFF8DFCFF8DFCFF8DFCFF0D7C7F0D7C7F8DFCF
F8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8C7B6F8CFB6F8CFB6F8CFB6F0C7AE\
F8CFB6F0C7AEF0C7A6F0C7A6F0BE9DE8B69DDFAE95DFAE8DD7A68DDFAE8DD7A685
D7A685BE957BB6856BB6856BA67B638D634A8D5A426B39215A3121422118422118291008392118\
3918109D7B63956B529D6339956342C79D85CFB6A6DFCFC7F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000855239855239855231855239855239735242
8552399D6B4AA67B63B68D73C79D85DFAE9DE8BEA6F0C7AEF8CFB6F8CFB6F8D7BEF0D7C7F0D7C7\
F8DFCFF0D7C7F8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF0D7C7F8DFCFF8D7BEF0D7C7
F8DFCFF0D7C7F8D7BEF0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF8CFB6F8D7BEF8CFB6F8C7B6F0CFAE\
F0C7AEF0C7AEF0C7A6F0C7A6E8B69DE8B69DDFAE9DDFAE8DDFAE8DD7A685D7A68D
CF956BCF956BBE8D63A67B63A67B5A9D73528D5A425A39295A3121422118422921311818422118\
422118A67B63B6856B8D5A42AE7352C7956BE8BE9DF8F8F8F8F8F8F8F0F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000734A317352427352428552397B5A42
735242956B52B68563BE957BD7A685DFAE95F0C7A6F0C7AEF0C7B6F0CFB6F8CFB6F8D7BEF8D7BE\
F8D7BEF8D7BEF8D7BEF8DFCFF8D7BEF8DFCFF0D7C7F8D7BEF8D7BEF0D7C7F8D7BE
F0D7C7F0D7C7F8D7BEF8D7BEF8D7BEF0D7C7F8D7BEF8D7BEF8CFB6F8CFB6F0CFAEF8CFB6F8C7B6\
F0C7AEF0C7AEF0C7AEE8BEA6E8BEA6E8BE9DE8B695DFAE8DDFAE8DD7A68DD79D7B
D79D7BB68D73BE8D63A67B639D73528D634A8552395A39295A3121422921422118522918522918\
3918109D6B4AB685639D6B4AC7855AD7A685DFCFCFF8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000735242855A427B5A427352427B5A42
855A42956B529D7352C7956BD7AE8DE8BEA6E8BEA6F0C7AEF8CFB6F8CFB6F8D7BEF8D7BEF8D7BE\
F0D7C7F0D7C7F8DFCFF8DFCFF0D7C7F8D7BEF8D7BEF0D7C7F0D7C7F0D7C7F0D7C7
F8D7BEF8D7BEF0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF8CFB6F8CFB6F8CFB6F0CFAEF0CFAEF0C7AE\
F0C7A6F0C7A6F0C7AEE8BEA6E8BE9DE8B695E8AE95DFAE8DDFAE8DDFA685DFA685
CF956BB68D73B6856BAE73529D6B4A8D5A42734A315A39295A3929522918422118522918391810\
291008956B529D73529D6B4ABE8D63DFAE8DF0F0E8F8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000956B52956B52956B527B5A42
7B5A42956B52A6856BB68D73D79D7BE8B69DF0C7A6F0C7AEF0C7AEF8CFB6F0CFB6F8CFB6F0D7C7\
F0D7C7F0D7C7F0D7C7F8D7BEF8D7BEF0D7C7F8DFCFF8D7BEF0D7C7F8D7BEF8D7BE
F8D7BEF8D7BEF8CFB6F8D7BEF8CFB6F8CFB6F8CFB6F8CFB6F8D7BEF8C7B6F8CFB6F0C7A6F0C7A6\
F0C7A6F0C7A6F0B69DE8BEA6E8BE9DE8B695DFAE95E8B695D7A685D7A685D7A685
B68D73B68D73A67B63A67B5A8D634A855239734229734A315A31215A3121422118391810211008\
5A3929B6856B9D7352B6734ACF956BCFAE95F8F8F8F8F0F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000095735A956B52855A428D634A
85634A8D634AAE7352BE957BC79D85DFAE95F0C7A6F0C7AEF0C7AEF8CFB6F8CFB6F8D7BEF8D7BE\
F8CFB6F0D7C7F0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF0D7C7F8D7BE
F8D7BEF8D7BEF8D7BEF8D7BEF8CFB6F8CFB6F8CFB6F8D7BEF8CFB6F0C7AEF0C7AEF0C7AEF0C7AE\
F0C7A6F0C7AEF0BE9DE8B69DE8B69DE8B69DE8B695DFAE8DD79D7BD7A68DBE957B
BE957BBE8D63AE7352955A42855239855A427342295A39295A3929422921522918211818211008\
A67B5AA67B63956342B67B5AC78D63E8CFBEF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000085523985634A735242
8D634A8D634AA67B5ABE8D63D79D7BDFAE9DE8BEA6F0B69DF0C7AEF0C7AEF8CFB6F0CFAEF0CFAE\
F8CFB6F8CFB6F8D7BEF8D7BEF8D7BEF8CFB6F8D7BEF8D7BEF8D7BEF8CFB6F8D7BE
F0CFB6F8CFB6F0CFBEF8CFB6F8CFB6F8CFB6F0CFAEF0C7AEF0C7AEF0C7AEF0C7AEF0C7A6F0C7AE\
F0C7A6F0C7A6F0B69DE8B69DE8B69DE8B69DDFAE95DFAE95D7A68DD79D7BD7A685
B68D73A67B639D6B4A9563428D5A42855A42855A425A31215A3121522918391810291008B6856B\
9D7B639D6B4A956342BE8D63D7B6A6F0E8E8F8F8F8F8F0F8F8F0F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000855A42A67B5A
7B5A42A67B5AA67B5ABE8D63C79D85DFAE95E8BE9DE8C7AEF0C7AEF0C7A6F0C7AEF8CFB6F8CFB6\
F8D7BEF8CFB6F0CFBEF8D7BEF8CFB6F8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8CFB6
F8CFB6F8D7BEF8CFB6F0C7AEF8CFB6F0C7AEF8CFB6F0C7AEF0C7AEF0C7A6F0C7AEF0C7AEF0C7A6\
F0C7A6E8BE9DF0BE9DE8B695E8B695DFAE9DDFAE8DCFAE95BE957BD79D7BCF956B
B6856BA67B639D73529D6B4A855A42734A31735242956B524221183918103921187B5A42855239\
A67B5A9D6B4AAE7352C7956BE8BEA6F8F0F8F8F8F8F8F0F8FFFFFFF8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000855239855239
85634AA67B63A67B5ABE8D63D79D7BDFAE95DFAE9DE8BEA6F0C7AEF0C7A6F0C7AEF8C7B6F0C7AE\
F8D7BEF0CFAEF8CFB6F8CFB6F8CFB6F8CFB6F8CFB6F8CFB6F8CFB6F8D7BEF8C7B6
F8C7B6F0C7AEF0C7AEF0C7AEF0B69DF0C7AEF0C7A6F0C7A6F0C7A6F0C7A6F0C7A6F0C7AEF0C7A6\
F0C7A6E8B695E8B695E8B69DDFAE95DFAE95DFAE8DD7A685BE957BBE957BB6856B
AE73529D7352956342855A42855A428552398552395A3929734A315A3929734A31734229A67B63\
9D7352B68563BE8D63D7AE8DD7BEAEF8F8F8FFFFFFF8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000855231
7B5A428D5A429D7352B68563BE957BC79D85D7B6A6E8B69DE8BEA6F0C7A6F0B69DF8C7B6F8C7B6\
F0CFB6F0CFB6F0C7B6F0C7AEF8C7B6F8CFB6F8CFB6F8D7BEF0C7B6F0CFB6F0C7AE
F0C7AEF0C7A6F0B69DE8B69DE8B69DF0B695F0C7A6F0C7A6F0BE9DF0B69DF0BE9DF0B695E8B69D\
E8B69DDFAE8DE8AE95DFAE95D7A68DD7A68DD79D7BBE957BBE957BB68D73B6856B
AE7352A67B5A9D6B4A735242735242734A31734A315A42397342295A3121A6856B956B529D7352\
9D6B4AD79D7BC7956BE8BE9DF8F8F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8FFFFFF
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
9D6B4A8552399D7352A6856BB68D73D7A68DDFAE95DFAE9DE8B69DF0B69DF0B69DF0C7A6F0C7AE\
E8C7AEF0C7AEF0CFB6F0C7AEF0C7AEF0C7AEF0C7B6F0C7AEF0C7A6F0C7AEF0C7AE
F0BE9DE8B69DE8AE8DE8AE95E8AE95E8B695F0B695E8AE8DE8AE8DE8AE8DE8AE8DDFA685DFAE8D\
E8AE95D7A685DFAE8DD7A685D7A685C79D85D79D73BE957BB6856BB68563B68563
A67B5A9D73528D5A42855A427B5A427352428D6B527B5A42734A318D6B52B6856B95735AA67B63\
BE8D63D7A685E8BE9DD7BEAEF8F0F8F8F8F8F8F8F8F8F8F8FFFFFFF8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000956B528D634A9D7352A67B63BE957BD7A68DE8BE9DDFAE9DD7B6A6E8B69DE8B69DF0C7AE\
F0C7AEF0C7AEF0C7AEE8C7AEE8BEA6E8BEA6E8BEA6E8BEA6E8B69DDFAE9DDFAE8D
DFAE95DFAE95D7A685D7A685D79D7BD79D7BD79D7BD79D73DF9D7BD79D7BD79D73D79D73BE957B\
CF956BCF956BCF956BCF956BC7856BB68D73BE957BB68D73B6856BB67B5A9D6B4A
8D634A95735A956B52735A4A956B52956B52734A318D634A9D6B4A9D6B4A9D73529D6B4ABE8D63\
B68563DFAE95E8BE9DF8F0E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000008D634A956B52A67B5AB6856BA67B6BB68D73BE957BDFAE95D7B6A6E8BEA6F0C7A6E8C7AE\
E8BEA6E8BEA6E8BEA6E8BE9DDFAE95DFAE95D7A685DFAE95E8BE9DD7A68DDFA685
D7A685D7A68DBE957BC79D85C7856BCF956BBE8D63D79D7BCF7363CF956BB67B5AB68D73B67B5A\
B67B5ABE8D63B68563B68563B6856BB6856BA67B63B68D73BE957BA6856BA68D73
A67B5AA67B638D634A8D634A95735AA67B63855A426B3921855239B67B5AB68563B67B5ABE8D63\
CFAE95D7B6A6D7BEAEF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000007B5A429D7352A67B5A8D634AB68D73C79D85D7BEAEE8C7B6E8C7B6E8C7B6E8BEA6\
E8BEA6D7B6A6DFAE9DD7A685CFAE95D7A68DD7A68DD7A685D7A68DD7A685D7A685
C7956BC7956BB68D73B68D73B6856BB68D73B6856BAE7352B6856BB685639D73529D6B4AB6856B\
9D7352B685639D7352AE7352A67B63A67B5AA67B638D634A956B5295735AAE7352
95735A9D735295735A9D7352855239855A428D6B529D6B4A9D7352A67B5AA67B5AC7956BD7B6A6\
D7B6A6C79D85F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000009D7363A68D73C7A695CFA695BE9D8DDFAE9DCFA695DFAE9DD7BEAED7BEAE\
DFAE9DDFAE95D7A68DD7A685D7A68DBE957BC79D85D7A685C79D85C7956BC79D85
BE957BC7856BB68563B6856B9D7352BE957BA67B63BE957BB68563A67B63BE8D63A67B5A9D6B4A\
BE957BA67B5AB6856BA67B63A67B5AA6856BA68D7385634A956B52A67B5A9D7B63
8D6B5295735AA67B639563429D6B4A9563429D6B4A9563429D7352B68563D7AE85CFB6A6CFAE95\
D7AE8DE8CFC7F8F8F8F8F8F8F8F8F8F8F8F8FFFFFFF8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000956B52A6856BB68D73B68D73BE9D8DDFAE9DD7B6A6DFAE95CFAE95\
D7A68DD7AE8DC79D85C79D85C79D85B68D73BE957BB68D73BE957BB68D73BE957B
B6856BBE957BA67B5A9D7352A67B6B956342A6856BA67B5AB68D739D7352A67B63A67B5AA67B63\
C7956B8D634A9D73529D7352B6856BA67B5A956B52956B52855A427B5A42734A31
7352428D634A8552398552397B5A427B5A42956342B6734AC7956BD7AE85E8C7AEBE9D8DD7AE8D\
B68563F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000BE9D95C79D85C7A695D7B6A6D7B6A6D7B6A6D7B6A6C79D85\
C79D85C79D85C79D85BE957BC79D85BE957BBE957BB6856BB6856BBE957BB68563
A67B5AA67B63956342A6856BA6856B8D634A734A31A67B63855A42B68563A67B5AA67B63A67B63\
8D5A429D6B4AA67B5A734229734A319D63398D5A42855A428D5A429D6339956342
9D6B4A9563429563428552399D63399D6B4ACFAE95BE957BD7AE8DD7BEAE8D634ABE9D8DA6856B\
DFCFCFFFFFFFF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8F8F8F8
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000A6856BC7A69DCFB6A6DFAE9DD7B6A6C7A695\
BE957BBE957BB68D73BE957BBE957BB68D73A6856BA68D73B68D73A67B63B68563
B685638D634AC7956BA67B5A8D634ABE957B8D634A855A42A67B638D634A8D634A956B52855A42\
8D5A428552317342298552398552399D63398552397B5A429563428D5A42855239
854A318D5A429D7352B68563B68563C79D85BE957BE8BE9DD7B6A6A6856BA67B5ABE9D8DA6856B\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000B6957BC7AE9DCFB6A6D7A68DC7A695\
A67B63B6856BA6856BBE957BBE957BB6856B9D7363B6856BB68563A67B63B68D73
A67B63B68563855A429D735295735A8D634AA67B5A855A428D634A956342855A4285634A855A42\
735242855239855239855239734A317342298552397B5A42855239855231855231
8D634AA67B5AA67B5AA67B5AA67B5AC79D85CFB6A69D7B639D7B63A6856BC7A695BE957BF0E8E8\
F8F0F8F8F0F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000B6957BD7B6A6D7B6A6C7AE9D\
A67B5AB68D73A67B63A67B63B68563A67B5A95735AA6856BA6856B95735AA67B63
95735AA67B63855A42A67B5A9D6B4A956B52735242734A31A67B5A7352427B5A42855A427B5A42\
855231734A31734A316B39215A39297342297342297342298552319D6B4A855A42
8D634AA6856BC79D85BE957BE8BEA6CFB6A6BE9D8DA68D73956B52C79D85956B52F0E8E8FFFFFF\
FFFFFFF8F0F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000CFB6A6D7BEAEC7AE9D\
A67B5A956B52B6957BA67B63B68D73B6957BB68563956B52A6856BA67B5A8D634A
A67B63A67B638D634A9D7352A67B5A95735A8D6B525A3121734A317B5A42A67B5A855239855239\
6B39218552397342296B39215A31215A39295A31215A3121734A318D5A42A6856B
BE957BB6856BBE957BCFB6A6B6957B85634A957B6BB68563A6856B9D6B4AC7A69DF8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8F8F8F8FFFFFFF8F8F8000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000D7B6A6\
A6856B956B52A67B5AB68D7395735A95735AA67B638D6B528D634A9D736395735A
8D6B52956B52A67B6395735A8D634AA67B5A9D73528D6B528D634A734A31734A3185634A855239\
8552398D5A428552319D6B4A855231855231955A319D6B4AAE7352A67B63BE8D63
C79D85DFC7B6B6957BBE9D8D9D7B6B734A3195735AA6856BB6957BB6957BF8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8FFFFFFF8F8F8F8F0F8000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
D7B6A68D634A8D6B529D7B63B6856395735A956B52855A427B5A427B5A428D634A
8D634A956B5295735A8D634A8D634AA67B5AA6856B9D735295735A7B5A42A67B5A855239855231\
95735A956B528D634A9563429D6B4AA67B5AB68563C79D85B68D73BE957BD7B6A6
BE9D8DB69D8DA68D73A68D737B5A429D7363A68D73A6856BA67B6BFFFFFFF8F8F8FFFFFFFFFFFF\
F8F8F8F8F0F8FFFFFFF8F0F8FFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000008D6B528D6B52A6856BA6856B956B52A6856B855239855A42855A42
9D6B4A956B529D7352855239A67B6B9D7352B68D73A67B63B6856BB6957B956B528D5A428D5A42\
9D73529D7352B68563B68563BE8D63BE8D63D7A685D7A685C7A695A67B639D7B6B
9D7B6B8D5A42734229855239A67B63A6856B9D7B63BE957BFFFFFFF8F8F8F8F8F8F8F8F8FFFFFF\
FFFFFFF8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000A6856B8D634AA6857395735AA67B63956B52855239
7B5242734A318D634A7B5A429D73639D7352BE957BB68D73DFC7B6E8C7B6D7B6A6C79D85DFAE9D\
D7A68DD7A68DD7A68DE8C7AEE8C7AEDFAE95CFB6A6A68D738D6B529D7B63956B52
855A427B5A428D634AB68563B6957BA67B63A67B6BFFFFFFF8F8F8F8F8F8FFFFFFF8F8F8F8F8F8\
F8F8F8000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000A68573A68D7BA67B6BBE957BC7A695
9D7B6B7B52428D6B527B524295735AB6957BC7A695BE9D8DA68D7BD7BEAED7BEB6D7BEAEDFC7B6\
E8D7C7E8CFC7D7BEAEC79D85B6957BB6957BA6857395736395735A956B52735242
85523995735A9D7B63BE957BA67B63B6957BF8F8F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000D7BEB6C7A69D
E8CFC7F0D7C7F8F0E8F0E8DFF0D7C7E8CFC7E8CFBED7BEAEDFCFBEDFC7B6DFC7B6DFC7B6E8CFBE\
CFB6A6A68D73C7A695A68D739D7B639D7B6B9D7B6B8D634A8D6B52735A4AA67B63
A68D73A6856BA6856BA67B63FFFFFFF8F8F8F8F8F8FFFFFFF8F0F8000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000DFC7B6E8C7B6E8CFBEE8C7B6F0D7C7F0DFCFE8D7CFDFCFBEE8CFC7CFB6A6BE9D95D7BEAE\
BE9D8DB69D8DBE9D958D735AA67B5A8D634A8D6B529D7B6BA68573BE9D8DC79D85
B68D73A6856BC7A69DF8F8F8F8F8F8F8F0F8000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000E8D7CFF0DFCFE8CFC7DFCFBED7BEB6CFC7BEB69D8DA68D85\
BE9D959D7B639D7B6B95735AA68D73856352A68D7BBE9D8DC79D85B69D8DA68D7B
C79D85E8DFDF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000B69D8D000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F0BE9D000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000F0C7A6F0C7A6F0C7A6F0C7A6F0C7A6F0C7A6F0C7A6F0BE9D\
F0C7A6F0BE9DF0BE9DF0BE9DF0C7A6F0C7A6F0C7A6F0C7A6F0B695F0B695F0BE9D
F0BE9DF0BE9D000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000F0C7A6F0C7A6F0C7A6F0C7A6F0BE9DF0BE9DF0C7A6F0C7A6F0BE9DF0BE9DF0BE9DF0BE9D\
F0B695E8BE9DF0BE9DF0C7A6F0C7A6F0C7A6F0BE9DF0BE9DF0BE9DE8BE9DF0B695
E8BE95E8B695F0BE9DF0BE9DF0BE9DF0B695000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000E8BE95F0BE9D
F0C7A6F0BE9DF0BE9DF0BE9DF0BE9DF0C7A6F0BE9DF0BE9DF0C7A6F0BE9DF0BE9DF0C7A6F0BE9D\
F0BE9DF0B695E8BE95F0BE9DF0BE9DE8BE9DF0C7A6F0BE9DF0B695E8B695F0B695
E8B695E8B695E8B695E8B695E8BE95E8B695E8B695E8AE8DE8AE8D000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000DFAE9DDFAE95E8B695E8B695E8BEA6
E8BE9DF0BE9DF0BE9DF0BE9DF0BE9DF0C7A6F0BE9DF0C7A6F0BE9DF0BE9DF0BE9DF0BE9DE8BE9D\
F0BE9DF0BE9DF0B695F0B695E8BE95F0B695F0BE9DF0BE9DE8BE9DE8BE95F0B695
E8B695F0B695E8AE8DDFAE85E8AE8DF0B695E8AE8DE8AE8DF0B695E8AE8DE8BE95E8B695000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000006329104A1808DFAE95DFAE95E8BE9DE8B69DE8BE9D
E8BE9DF0BE9DF0BE9DF0BE9DF0BE9DF0BE9DF0C7A6F0C7A6F0BE9DF0BE9DF0BE9DF0BE9DF0BE9D\
F0BE9DF0BE9DE8BE95E8BE95F0BE9DF0B695E8BE9DF0B695F0B69DE8B695E8B695
E8B695E8B695E8AE8DE8AE8DE8AE8DE8AE8DDFAE85DFA67BDFAE85E8AE8DDFAE85E8BE9DDFA67B\
DFAE8D000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000007B39186329105221106B3118DFAE95DFAE95E8B695E8BE9DE8BE9D
E8BEA6E8BE9DF0C7A6F0BE9DF0C7A6F0BE9DF0BE9DF0BE9DF0BE9DF0BE9DF0B695F0BE9DF0BE9D\
E8BE95F0BE9DF0B695E8BE9DF0B695E8B695E8B695E8AE8DE8B695E8B695E8B695
E8B695E8AE8DE8AE8DDFAE85DFA685DFA67BDFA67BDFA67BDFAE85E8BE9DDFAE85D79D7BD79D73\
D79D7BDF9D73DF9D73000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
B66B399552298D4A296B31186B31187B42217B4A29DFAE9DE8BE95E8BE9DF0C7A6
E8BE9DE8BE9DF0C7A6F0BE9DF0BE9DF0BE9DF0BE9DF0BE9DF0BE9DE8BE9DF0BE9DE8BE9DE8B695\
F0B69DF0BE9DE8BE95F0B695F0B695E8BE95E8AE8DE8BE95DFAE85E8B695E8BE95
E8B695E8AE8DE8AE8DDFA685DFA685CF956BD79D73DFAE8DE8BE9DDFAE8DCF8D63CF956BD79D73\
CF956BD79D73CF956BC77B4AC77B42000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000B6734A\
AE6B398D4A298D4A297B39188542218D4221632910DFAE95E8BE9DE8BEA6F0C7A6
E8BE9DE8BE9DF0BE9DF0B695E8BE95F0BE9DF0B695E8BE95F0BE9DF0BE9DE8BE95F0B695E8BE95\
F0B695F0B695F0BE9DE8B695E8B695E8B695E8BE95DFAE85F0B695DFAE85E8AE8D
DFAE8DDFAE85DFA685DF9D7BCF956BD79D73D79D73E8BE95E8BE9DCF8D63CF956BD79D73D79D73\
CF8D63B67B5AB66B529D6339C77B42B66B39000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000B6734AAE6B429D6339\
9D63398D42218D4A299552299552297B39184A1808E8BE9DE8B695E8BEA6E8BE9D
F0BE9DE8BE9DF0BE9DF0B695F0B695F0BE9DF0B695F0B695F0B695F0B695F0B695F0B695E8BE95\
E8BE95F0B695E8B695E8BE95E8B695E8B695DFAE85DFAE85DFAE85E8AE8DDFAE85
DFAE8DDFAE8DDF9D7BD79D73CF8D63CF8D63DFAE85DFAE95CF8D63C78563C78563C78D63C78563\
B67B5AAE73528D5A42AE6B42C77B42B66B39B66B39B66B39000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000BE8D63B67B5AB66B42AE6B42\
8D4A29854221955229955A318D4A296B39216B3118E8BEA6E8B69DF0C7A6E8BEA6
E8B695F0BE9DE8BE9DE8BE9DF0BE9DF0B695F0B69DE8BE95F0B695E8AE8DF0B695F0B695E8AE8D\
E8AE8DE8AE8DE8AE8DF0B695DFAE85E8AE8DDFAE8DDFAE85E8AE8DDFA67BDFA685
DFA67BD79D7BD79D73C7856BCF8D63CF9563D79D73CF956BC7855AC78563C7855AC7855AB67B5A\
9D63399D6B4A9D6B4AAE6B39CF8D5AC77B4AC77B42B66B39AE6B39000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000CF956BC7855AB6734AAE6B42AE6B39\
955A31955229AE6B399552296B31186B3118632910E8BEA6E8B69DE8BE9DDFAE95
E8BE9DF0BE9DF0BE9DE8AE8DE8AE8DF0B695E8B695E8AE8DE8AE8DE8AE8DDFAE85E8AE8DE8AE8D\
DFAE85DFAE85E8AE8DDFA685E8AE8DDFA685DFA685DFA685DFA685DFA67BDFA67B
D79D73D79D73CF956BCF8D5AC78563D79D7BC78D63B67B5AB66B52C77B4AB6734AB67B5A956342\
B6734A9D7352AE6B39AE6B42C77B4ACF8D5AC7855AB6734AC77B4AB67B5A000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000D79D73D79D73BE8D63B6734AAE6B42AE6B42\
8D4A299D63399552298542216329106B3921632910E8BE9DE8BE9DE8BE9DE8BE9D
E8BE9DE8B695F0BE9DE8BE95E8AE8DF0B695E8AE8DDFAE85E8AE8DDFAE85DFA685DFAE85DFA685\
DFAE85DFA685DFA685DFA685DFAE8DDFAE85DFA67BDF9D7BD79D7BDFA67BD79D7B
D79D7BD79D73CF956BC7855ACF956BCF8D63B67B5AB66B52B6734AAE6B42AE6B42955A319D6B4A\
9D6B4A9552299D6339B66B42CF8D5ACF8D5ACF8D5ACF956BC77B4AC77B4AB6734A
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000F8F0E8CFAE95D79D73C78D63C7855A9D63399D6B4A955A31\
9D4A319D63399D4A317B42216B39217B42216B3118E8BEA6DFAE9DE8BE9DE8B695
E8BE9DE8B695E8AE8DE8BE95E8AE8DE8AE8DE8AE8DDFAE85DFA685DFA685DFA685DF9D73DF9D7B\
DFA67BDF9D7BDF9D7BDFA685DFA67BDFA67BD79D73DF9D73D79D73D79D73D79D73
D79D73CF8D63CF8D63C7855ACF956BC7855AB6734AAE6B42AE6342AE6342956342AE6B429D6B4A\
955A31955A319D6339B66B39C77B42CF8D5AC7855ACF8D5AC7855ABE8D63B6734A
B6734AB66B42000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000F8F0E8E8D7C7D7AE8DD79D73C7855AB67B5AAE6B42B6734A955229\
9D63399D6339955A315A31216329106B31186B3921E8BE9DDFAE95E8B69DDFAE95
E8B695E8B695E8AE8DE8AE8DE8AE8DDFA685DFAE85DFA67BDF9D7BDFA67BDF9D7BDF9D7BDF9D73\
CF956BCF956BCF956BD79D73D79D73DF9D7BD79D73D79D73CF956BCF956BCF956B
CF8D63CF8D63C78563BE8D63B6734AAE6B42AE6B399D6339AE6342AE6B42AE6B429D63399D6339\
9D6339AE6331B66B39B66B42C77B42CF8D5ADFA673D79D73DFAE85C78D63AE6B39
AE6B39B6734AC78D63000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000F8F0E8F8F0E8E8BEA6D7AE85C7956BBE8D63B6734A9D63399D6B4A955A31\
AE6B398D4A298542215229185229186B31186B3118E8BE9DDFAE95E8B695E8B69D
E8B695E8AE8DE8AE8DDFA685DFA67BDFA67BDFA67BDFA67BDF9D73D79D7BD79D73DF9D73D79D73\
D79D73CF956BCF956BCF956BCF956BD79D73D79D73CF956BCF956BCF956BC78563
C78563C7855AB67B5AC7855AB66B429D6339955A31AE6B429D6339AE6B42AE6B427B42217B4221\
8D4A29B66331C77B42C77B42C77B42C7855ACF9563D79D73CF956BD7AE85BE8D63
B6734AC7855AC7855ACF956B000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000F0F0E8F8F0F8E8DFD7D7B6A6D7AE85BE8D63B67B5AAE6B429D6B4A955A31955A31\
9D63398D4A297B39186B31186B39216B39217B3918DFAE95DFAE95DFAE8DDFAE8D
E8AE8DDFAE8DDFA685DFAE8DDFA685DFA685D79D7BDF9D73DF9D73CF956BCF956BCF956BC7856B\
CF8D63CF8D63C7856BCF956BCF956BC7856BCF956BCF956BCF956BC78563C7855A
C78563C7855AB6734ACF8D5AAE6B428D4A299D6B4A9D6B4A9D6339955A318542217B4221632910\
AE6331C77B42B66331C77B42B66B42C77B4ACF9563DFA673D79D7BDFAE85BE8D63
BE8D63CF9563BE8D63CF956BC7956B000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000F0F0F8F8F0F8F0F0E8E8C7B6D7AE8DC79D85B67B5AB67B5A9D6B4AAE63429D6339955A31\
955A316B39216B39216B31186B39216B39216B3921DFAE95DFAE8DDFAE95E8BEA6
E8AE95E8AE95E8A695E8AE95E8A695E8A695DFAE8DDFA685DFA685D79D7BCF8D63C7855ACF8D63\
C77B5AC7855AC7855AC7855AC7855ACF8D63CF8D63C7855AC7855AC7855AB67B5A
B67B5AB66B52B6734AC7855A9D63397B4A299D6339AE6B428D4A297B42217B39187B4A29955229\
AE5A31C77B42C77B42B6734AC77B42AE6B39CF9563D79D73D7AE85CF956BC7956B
C7855AC78D63C78D63BE8D63D7AE85D7AE85000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000F0F0F8F0F0F8F0E8DFDFC7B6D7AE85C7956BB67B5AB6734AAE6B429D6339B6734A9D4A31\
955A315221107342296B39216B39216B3118855231DFAE95E8C7AEF0C7AEF0C7AE
F0C7AEF0C7A6F0C7A6F0B69DF0B69DF0B69DE8AE9DE8AE95E8AE95DFAE8DDFA685D79D7BC77B5A\
C77B5AC77B4AC77B5AC77B5AB67B5AB67B5AB67B5AC7855AC77B5AB67B5AC77B4A
B6734AAE6B42AE6B42C77B4A8D4A298D4A319D63398D5A428542216B31186B3921AE6331854221\
9D6339C77B4AC77B42B6734AAE6B39B6734ACF8D5AD79D7BDFAE85DFAE8DD7AE85
C7956BC7956BB67B5AB66B42D7AE85D7AE85000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
F0F0F8F8F0F8F8F0F8E8CFBED7B6A6D79D73C78D63B67B5AAE7352955A319D6339955A319D6339\
8542216329107B42217342296B39216B3118B68563F0C7AEF0C7B6F8D7BEF8C7B6
F8C7B6F0C7AEF0C7AEF8C7B6F0C7AEF0C7AEF0B69DF0B69DE8B69DE8AE95DFAE8DDFA685DF9D7B\
CF956BC77B4AB6734AB67B5AC77B4AC77B4AC77B5AB66B52B67B5AC77B4AB67B5A
B6734AAE6B42956342B6734A955A319D6339B6734A8542217B39186B3118734A31B66B398D4221\
9D6339B66B42C77B4AB66B39AE6B39B6734AC7855ACF8D5ADFAE85DFAE8DD7AE85
D79D73C7956BB6734ABE8D63D79D73D79D73D79D73000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000F0F0F8
F8F0E8F8F0F8F8F0F8E8CFBECFAE95C7956BBE8D63AE7352AE6B42AE6B429D6339955A319D6339\
6329106B39217B4A296B39216B3921B68D73F0C7B6F8CFB6F8D7BEF8CFB6F8D7BE
F8C7B6F8D7BEF8C7B6F8CFB6F8C7B6F0C7AEF0C7A6F0C7AEF0B69DF0B69DE8AE95E8AE8DDFA685\
DFA67BD79D73CF956BB6734AB6734AB6734AB6734AC77B4AB6734AB67B5AB6734A
AE63429D6B4A855239854221B6734A955A31C7855A7B39186B3118522110632910AE6B39B66B42\
955229B66B42CF8D5AAE6B39BE8D63B6734AC7855AD79D73DFAE85E8BE95E8BEA6
D7AE8DB66B42BE8D63BE8D63CF956BC78D63D79D73D7AE8D000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000F8F8F8F8F8F8
F0F0F8F0E8E8E8D7C7E8C7AEC79D85C7956BB67B5A9D6B4A955A319D63399D6339955A31854A29\
6329107B4A297B4A296B3921E8C7B6F8CFB6F0CFAEF8CFB6F8D7BEF8D7BEF0D7C7
F8D7BEF0D7C7F8C7B6F8C7B6F8C7B6F8CFB6F0C7AEF0C7A6F0C7A6F0C7A6E8BE9DDFAE95DFAE8D\
E8AE8DDFA685D79D7BCF956BB66B52AE6B42AE6B42B6734AAE6B42B66B52AE6B42
AE63429D63398542217B4221C7855A854221CF8D639D63396B3921734A31522110854221C77B4A\
8D4221B66B42C77B4AB66B39C7855AC7855AC7855ACF9563D79D73E8BE9DE8BEA6
D7AE85C78D63B67B5ABE8D63C7956BC7956BD7AE85D7AE8DD7AE85000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000F8F8F8F8F0F8
F0F0E8F0E8E8DFCFBED7BEAEBE957BBE8D63B67B5AAE6B429563429D6339955A31955A316B3921\
6B31187B42216B3921A6856BF0CFB6F8CFB6F0C7AEF8CFB6F8CFB6F8D7BEF8D7BE
F8D7BEF8D7BEF0D7C7F8D7BEF8C7B6F8C7B6F0C7AEF0C7AEF0C7AEE8BEA6E8B69DE8BE9DE8B695\
E8AE8DDFAE95DFA685D79D7BC7856BCF956BAE6342AE6342AE6B429D6B4AAE6342
9563429D4A31854A31734229C77B4AAE7352B67B5AB6734A6B31185221107B42219D6339C77B4A\
C7855AC77B4AC77B4AC7855AAE6B42C78D63BE8D63C7956BD79D73D7AE85E8BE9D
E8BE95BE8D63B6734ABE8D63C77B4AC7956BD7B6A6E8BE95CFB6A6000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000F0F0E8F8F8F8F0F0F8
F0F0E8E8DFD7DFCFBECFAE95BE957BBE8D63B6734A9D6B4A855239955A318D4A29955A31522918\
6B39217342298D5A42F0C7AEF0C7B6F8CFB6F8CFB6F8CFB6F8CFB6F8D7BEF8C7B6
F8D7BEF8C7B6F8C7B6F8D7BEF8C7B6F8C7B6F0C7AEF0C7A6F0C7AEF0C7AEF0C7A6E8B69DE8B69D\
E8B695DFAE95DFAE8DDFA685D79D7BCF956BC7856B9D6339AE6342AE6342955A42
9D6339854A297B4A296329109D6B4AD79D7B8D4A29CF956B956342AE6B426B3118AE63318D4A31\
BE8D63AE6331C77B42C77B4ABE8D63B68563C7956BB67B5AD7AE85CF9563E8BEA6
F0CFB6BE8D63B6734ABE8D63C78D63C79D85D79D73D7AE85D7AE8DE8BE95000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000F8F8F8F8F8F8F8F0F8F0E8E8
F0E8E8E8CFBEDFCFBEC79D85C78D63AE7352B6734A956342955A31955A318552316B39216B3118\
854A29855A42F0C7B6F0C7AEF0CFAEF8CFB6F8CFB6F8CFB6F8C7B6F0CFAEF0C7AE
F0C7AEF0C7AEF0C7AEF0C7AEF0C7A6F0B69DF0B69DE8BEA6F0C7A6E8BE9DF0BE9DE8B69DE8B69D\
DFAE8DE8AE8DDFAE95DFAE8DDFA685D79D73CF956BCF8D639D63399D4A319D6339
8D4A318D4A296B39216B3921855239BE8D63B67B5A9D6B4AC79D858D4221B67B5A955A31AE6342\
B66B42C77B4AAE6B39C77B4ABE8D639D6339BE8D63BE8D63D79D73D79D73CFAE95
DFAE8DE8BE95BE8D63B66B42BE8D63C79D85C7956BD7AE85E8BE95E8D7CFF0F0E8000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000F8F0F8F8F8F8F8F8F8F0E8E8
E8D7CFE8CFBECFB6A6BE957BB67B5AAE7352956342955A31955A31955A315A31216B39216B3118\
6B3118F0C7B6F0C7B6F8CFB6F0CFAEF0C7AEF0C7AEF8C7B6F0C7AEF0BE9DE8B69D
E8AE95E8AE95DFAE8DDFAE8DDFAE8DDFA685DFAE8DDFAE8DDFAE8DDFAE8DE8B695E8B695E8B695\
E8B69DE8B695DFAE8DDFAE8DDFA685DF9D7BD79D7BD79D73CF8D63B66B52955A31
855231854A317342296B3921734A31956342CF956BBE8D63A67B5AD79D73C77B4AB67B5A854221\
AE6B39C7855AC77B42C77B4AAE6B39B67B5AB67B5AD79D7BC7956BD79D73D7AE85
E8BEA6E8C7B6BE8D63C7956BD79D7BC7956BC78D63CFAE95E8BE9DF8F0E8E8DFD7000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000F8F8F8F8F8F8F8F0F8F8F0F8F0E8E8
E8D7C7DFCFBED7AE8DC7956BB6734AB6734AAE63428D4A31955A318552316B31186B3921854A29\
E8C7B6F0CFB6F0CFB6F8CFB6F0CFAEF0C7AEF0C7AEF0C7A6E8BEA6E8AE95E8AE8D
DFA685DF9D7BE88D7BE88D7BE88D7BE88D7BE88D7BDFA685DF9D7BDFA685DFAE8DDFA685E8B695\
E8B695E8B69DDFAE95DFAE8DDFA685D7A685D79D7BCF956BCF956BC785638D5A42
8542297B4A296B39215229186B39218D634ACF956BAE7352955A31D7A685C77B4ACF9563B67B5A\
9D6339AE6B42CF8D5AC77B4AB6734ABE8D63B67B5AD79D73C7956BD7AE85D79D73
D7AE85E8C7AED7AE85D79D73C79D85C79D85D79D73D7AE8DE8BEA6F0E8DFF0E8DFF8F0E8000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000F8F0E8F8F8F8F8F0F8F0F0E8E8D7CF
E8CFBEDFCFC7C79D85B67B5AAE73529D6339AE6342855239854A296B39216B39217B39187B4A29\
F0C7B6F0C7B6F0C7AEF0C7AEF0C7AEF0C7AEF0C7A6F0B69DDF7363CF6B5ADF7B6B
DF7B6BDF8573DF8573DF8573DF8573DF8573CF6B5ACF6B5ACF6B5ACF6B5AD79D7BDFAE8DDFAE8D\
E8B695E8B695E8B695DFAE95DFAE8DDFA685D79D7BD79D7BCF956BC7856BC7855A
7B4A296B39216B31185221106B3118855239AE7352D79D7BB68563C7856BD7AE85CF9563D79D73\
C7956BC77B4AB6734AC7855ABE8D63AE6B39B6734ABE8D63D79D73BE8D63DFAE85
D7AE8DE8BE95E8BEA6C79D85D7AE85C7956BD79D73E8BE95DFCFBEE8D7CFF0E8E8F0F0E8000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000F8F8F8F8F8F8F8F0E8F8F8F8F0E8E8E8DFD7
E8D7C7D7AE8DC7956BA67B5A9D6B4A9D6339955A317B4A298552397342296B39217B4A29F0CFBE\
F0C7B6F0C7AEF0C7AEF0C7A6F0CFAEF0C7AEE88D7BDF8573DF8573DF8573F0C7B6
F0B69DE88D7BE88D7BE8A695F0B69DDF8573DF8573DF7B6BC7856BCF7363CF6B5AD79D7BDFAE8D\
DFAE95E8B695E8B69DDFAE95DFAE8DDFAE8DD7A685D79D7BCF956BDF8573C78563
B67B5A734A31522918522918522110855239522918D7A685DFAE8D9D6339D7AE8DB67B5ADFA67B\
D7AE85BE8D63C7855ACF9563AE6331C7855AB67B5ABE8D63C7956BCF956BD79D7B
D7AE8DE8BEA6E8C7B6BE957BB68563C7956BD79D73CFAE95F0E8DFF0E8DFF0F0E8F0F0E8F0E8DF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000F8F8F8F8F8F8F0F0F8F8F8F8E8D7D7DFCFBE
CFAE95C7956BB68563A67B5A855239955A318D4A31955A316329106B39216B3921A6856BF0CFB6\
F0CFB6F0CFB6F0C7AEF0C7A6F0C7A6F0C7A6DF7B6BDF8573DF8573DF7B6BDF7363
DF7363DF7363DF8573CF6B5ACF6B5AC75A4AC7634AC7634AE88D7BCF7363CF7363C75A4AD7A68D\
E8AE95E8B695E8B695E8B695E8B695DFAE8DD7A685D79D7BD79D7BCF956BCF956B
C7855AAE73526B39216B39213918106B31188D5A42B68563C7956BB67B5ABE8D63D7AE85C7855A\
DFAE85F0CFAEBE8D63B6734AC7855AC7855AAE6B42B67B5ACF9563C7956BD79D73
D79D73E8BEA6E8BEA6C79D85C7956BC79D85BE957BCFAE95F0E8DFF0E8E8F8F0E8F0E8E8F0E8E8\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000F8F0F8F8F8F8F8F0F8F8F0F8F8F0F8E8D7CFD7C7B6
D79D73C7956BAE73529563428D4A31955A31854A296B31187B42216B3118955A31F0CFBEF0CFBE\
F0CFB6F0C7AEF0C7AEF0C7A6E88D7BDF8573AE73529D4A31AE4A31BE5242AE7352
BE5242BE5242C75A4AB652399D4A319D31219D4229AE4A318D3121AE42319D4229854229955A42\
DF8573E8B695E8B695E8B695DFAE8DDFAE8DDFAE8DD79D7BD79D7BD79D73D79D7B
C78563B67B5A8D5A424A18083918106B3921734A31855A42BE8D63D7A685955A31D7A685B67B5A\
D79D7BE8BE9DF0CFAECF956BCF956BB66B39C7855AB67B5ABE8D63C78D63B67B5A
D7AE85E8BE95E8BEA6D7BEAED79D73D7AE85C79D85D7B6A6E8DFD7F0F0E8F0E8DFF0F0E8F8F0F8\
F0F0E8000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000F8F0F8F8F0F8F8F0E8F8F0F8F0E8E8E8D7CFD7BEAE
BE957BB67B5A9563428D4A318D5A428D4A297B4A297B4A297B4A29854229F0CFBEF0CFBEF0C7B6\
F0CFB6F8CFB6F0C7AEF0C7A6F0B69DF0C7A6E88D7BCF7363CF6B5AC7634ACF6B5A
C7634ACF6B5ADF7B6BC7634AC7634AC7634AC7634AC7634AC7634AD79D73D7A685D7A68DDFAE8D\
DFAE8DE8B695E8B695E8AE8DE8AE8DDFAE8DE8AE8DDFA685D79D7BD79D7BD79D73
CF956BC785639D73525A39293918103918105A3929855A429D7352D79D7BC7956B9D6B4AD79D73\
B67B5AE8BE9DE8BE9DF0CFB6AE7352C7855AC7855AB67B5ABE8D63BE8D63B67B5A
D7AE85D7AE85E8BEA6E8C7AEC7956BD7AE85D79D73E8D7C7F0E8E8F0E8E8F0E8DFF0E8DFF8F0F8\
F8F0F8000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000F8F0E8F8F8F8F8F0F8F0F0E8F8F0E8F0E8DFDFCFC7D7AE8D
B685639D6B4A9D6B4A8D5A428D4A29854A297342297B4A29854221855231F0CFB6F0C7AEF0CFB6\
F0CFAEF0C7AEF0CFAEF0C7A6F0CFAEF8CFB6F8CFB6F8D7BEF0D7C7F0C7B6F0C7AE
F8D7BEF0C7AEF0C7A6F8CFB6F8D7BEF0C7B6F0C7AEE8BEA6E8B69DE8BEA6E8B69DE8B695E8B695\
E8B69DE8B695E8B69DE8B695E8AE95DFAE8DDFAE8DDFA685DFA685D79D7BD79D73
CF956BCF956BB67B5A855231423129291008855A42734A31855A429D7352BE8D639D6339C7855A\
AE6B42C7855AE8BE9DE8BE9DD79D73CF956BBE8D63B6734AB6734ABE8D63CF956B
D79D73CF956BE8BEA6E8C7AEC79D85C79D85C78D63E8DFD7F0E8DFF0E8DFF0E8E8F0E8DFF8F8F8\
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000F8F0F8F8F0E8F8F0F8F8F0F8F0E8E8DFC7B6E8BE9DC79D85
AE7352956342855231855231854A316B31187B4A297B4A297B4221D7B6A6F0CFB6F0CFB6F0CFB6\
F8C7B6F8CFB6F0C7AEF8CFB6F0C7AEF8CFB6F8CFB6F8D7BEF8CFB6F8D7BEF8CFB6
F8D7BEF0C7A6F0C7AEF0C7AEF0C7AEE8B69DE8B69DE8B69DE8B69DE8BE9DE8B69DE8BE9DF0C7A6\
E8B69DE8B695E8BE9DE8B69DE8AE95E8AE95DFAE8DDFA685DFA685D79D7BDF8573
CF956BCF956BB67B5A955A42522110422118734A31855231A6856B9D7352C79D859D6339955A31\
C78D63BE8D63DFAE95E8BE9DF0C7A6D7AE85C7855AC7855AC78D63B6734AB67B5A
B67B5ACF956BE8BEA6E8C7AED79D73D7AE8DC7956BF0E8DFF0E8E8E8DFD7F0E8DFF8F0E8F8F8F8\
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000F8F0F8F8F0F8F8F0E8F8F0F8F8F0F8DFCFC7C79D85B67B5A
9D63399D6B4A854A29854A316B39217B4A297B4A297B4A297B4A29F0CFB6F0CFB6F0C7B6F0CFB6\
F8CFB6F8C7B6F8C7B6F8CFB6F0CFB6F8CFB6F8CFB6F8CFB6F8CFB6F8CFB6F8CFB6
F0CFB6F0C7AEF0C7A6F0C7A6F0C7A6E8B69DE8BE9DF0BE9DE8B69DE8BEA6E8B69DF0C7A6E8B69D\
F0C7A6E8B69DE8B69DE8AE95E8AE95E8B695DFAE8DDFA685DF9D7BDFA685D79D73
CF956BCF956BC785639D6B4A7342295A39293918107352428552399563429D6339AE73529D6339\
B67B5AA67B5ACF956BE8BE95E8BE95CF956BD79D73C7855ABE8D63B6734ABE8D63
B6734AD79D73D7AE85E8BEA6CFAE95C7956BD79D7BE8D7CFF0E8DFF0E8DFE8D7C7F8F8F8F8F0F8\
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F8F8F8F8F8F8F8F0F8F8F0F8F8F0E8DFCFC7D7C7B6BE957BB6734A
9D6B4A854A298D5A426B39217B4A296B31187B4A29854A296B3921F0CFB6F0C7B6F0C7B6F0CFB6\
F8CFB6F8CFB6F8CFB6F8C7B6F8CFB6F8CFB6F8CFB6F8CFB6F0CFB6F8CFB6F8CFB6
F0C7A6F0C7A6E8B69DF0C7A6E8B69DE8AE8DE8B695E8BE9DE8B69DF0B69DF0BE9DF0C7A6F0B69D\
F0B69DF0C7AEF0C7A6E8B69DE8B69DE8AE95E8AE8DDFA685DFA685D79D7BD79D73
DF8573C7856BC78563B6734A734A31522110522918734A318D634A956B529D7352B685639D6B4A\
8D5A42956342BE957BC78D63DFA673F0C7A6D7AE85C77B4AC78D639D6B4AC7956B
BE8D63D79D7BD79D73E8BEA6CFAE95BE8D63E8C7B6E8D7C7F0E8E8F0E8E8F0E8E8F8F0F8F8F8F8\
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F8F0F8F8F0F8F8F8F8F8F8F8F0E8E8DFC7B6C7A695BE957B9D6B4A
9D63399563428542297B4A297B4A29734A317B4A296B3921B68563E8C7B6F0C7B6F0C7B6F8CFB6\
F8CFB6F8CFB6F8CFB6F8D7BEF8CFB6F0CFB6F8CFB6F8CFB6F8CFB6F0C7AEF0C7AE
E8B69DDFAE8DDFA685E8AE95DFAE95DFA685DFAE8DE8AE95E8B695E8B69DF0BE9DE8BEA6F0C7A6\
F0C7AEF0C7AEF0B69DF0B69DE8B69DE8AE95DFAE8DDFA685DFA685D79D7BD79D7B
D79D73CF956BC77B5AB66B528D5A425A39296B39215A4239855A428552399D7352956342B6734A\
8552319D6339855239D7AE8DE8BE95D79D73DFA67BC78D63C7956BA67B5AB67B5A
BE8D63C79D85D79D73E8BE9DD7B6A6C7956BE8DFD7E8BEA6F8F0F8F0E8E8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F8F8F8F8F0E8F8F8F8F8F0F8F8F0F8E8BE9DBE957BAE7352956342
8D4A318D4A317B4A296B39216B39217B4A297B4A296B3118E8C7B6F0C7B6F0C7B6F8C7B6F8CFB6\
F8CFB6F8CFB6F8CFB6F8CFB6F8CFB6F0CFAEF8CFB6F8CFB6F8CFB6F0C7AEF0B69D
E8AE9DE8B695DF9D7BDFA685DFA685D79D7BD7A685DFAE8DDFAE8DE8B695E8B69DF0BE9DF0B69D\
F0C7A6F0C7A6F0C7A6F0B69DF0C7A6F0B695E8AE95DFAE8DDFA685D79D7BD79D7B
D79D73C7856BC78563B67B5A955A425A3929291008422921734A318552319D6B4A855239B6734A\
9D63399D63397B4A29D7A685C7855AD79D73F0CFAEC7956BC78D63C78D63B67B5A
B68D73C7855AC7956BE8BE9DD7BEAED7BEAEDFCFBEE8D7CFE8D7CFE8CFC7F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F0E8E8D7AE8DB68563956342855231
8D4A316B39217B4A297342297B4A298542296B31185A3121F0C7B6E8C7AEF0C7AEF0C7AEF8CFB6\
F8C7B6F8D7BEF8D7BEF8CFB6F8CFB6F8CFB6F8C7B6F0D7C7DF9D7BDF7B6BF0C7AE
F0C7AEF0B69DE8A695B66342B66342C7856BDF9D7BB67B5AD79D73DFAE8DE8B69DF0C7A6F0C7A6\
F0C7AEF0C7AEF0C7AEF0C7A6F0B69DE8B69DE8AE95E8AE8DDFA685DFA685D79D7B
D79D73CF956BC78563B66B52AE63427342293918104229215A3121734A31855239855A429D6B4A\
9D6B4A8552319D6B4A8D5A42BE8D63DFAE85D79D73DFAE85C7855ABE8D639D6339
B67B5AB67B5AD79D73E8BE95D7BEAEF0E8E8CFAE95F0E8E8D7B6A6F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8E8DFDFC7956BAE73529563429D6339
7B4A297B4A296B39217B42217B4A296B39215A3121855239F0C7B6F0C7AEF0CFB6F8CFB6F8D7BE\
F8CFB6F8C7B6F8D7BEF8C7B6F8CFB6F0CFAEF8CFB6F8D7BEF0CFB6F0C7B6F8C7B6
F8C7B6F0C7AEE8B695DFAE8DDFAE95E8AE8DE8B695DFA685CF8D63D79D7BE8B69DF0C7AEF0C7AE\
F0C7AEF0C7AEF0C7AEF0B69DF0C7A6F0C7A6F0B695E8AE8DDFAE8DDFA685D79D7B
CF956BCF956BC78563C77B5A9D73528D5A422910083918104229215A42397352428D5A42855239\
9D7352855231955A31522918D7AE85CF8D63CF9563E8BE9DB67B5ABE8D639D6B4A
AE7352BE8D63C7956BCFAE95DFC7B6DFC7B6C7AE9DD7B6A6F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F0F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F8F8F8F8F0E8F8F8F8F8F8F8F8F8F8E8D7CFBE8D63956342955A426B3921
734A31854A317342297B4A29854A31632910632910A67B63E8C7AEF8C7B6F8C7B6F8C7B6F0D7C7\
F8D7BEF8D7BEF8D7BEF0D7C7F8CFB6F8CFB6F8C7B6F8D7BEF0C7B6F0D7C7F0D7C7
F0D7C7F8C7B6F0C7A6E8B695E8AE9DE8AE9DDFAE95DFAE8DDFA685DFA685F0B69DF0C7AEF0C7AE\
F8C7B6F0C7AEF0C7AEF0C7AEF0B69DF0B69DF0B69DE8B695E8AE8DDFAE8DDF9D7B
DF8573DF8573C78563B67B5AAE6B42956342291008422118391810734A31855239956342734229\
9D6B4A855231955A315A3121C7956BBE8D63D7AE85E8BE9DB67B5ABE8D63AE7352
B67B5AB68563BE957BD7AE8DDFC7B6DFC7B6D7BEAEDFCFBEF8F8F8F8F8F8F8F0F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F8F8F8F8F0F8F8F0F8F8F8F8F8F0F8E8CFC7AE73528D5A42955A31855231
7B4A297B4A29854A298D4A317B42215229185A3929E8C7B6F0C7B6F8CFB6F8CFB6F8D7BEF8D7BE\
F8D7BEF0D7C7F8D7BEF0D7C7F8D7BEF8C7B6F0C7AEF8D7BEF8D7BEF0D7C7F8DFD7
F0D7C7F8C7B6F0C7AEE8BEA6E8AE95E8A695DFAE95DFAE8DDFA685E8AE95F0B69DF0C7AEF0C7AE\
F0CFAEF0C7AEF8C7B6F0C7AEF0C7A6F0C7A6F0B69DF0B69DE8AE95E8AE8DDFA685
DF9D7BCF956BC7856BB67B5AAE6B42955A315229181808084221187342295229189D6339855231\
9D6B4A7B42218552318D5A42AE7352C78D63DFA67BDFA67BD79D73B67B5ABE8D63
AE7352B67B5AB67B5ACFAE95E8C7AED7B6A6E8CFC7F8F0F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F0F8F8F0F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F8F0F8F8F8F8F8F8F8F8F8F8F8F0E8C7956B9563429563426B3921734229
7342297B4A29854A317B4A29422118632910422118F0C7AEF8C7B6F0CFBEF8C7B6F8D7BEF8D7BE\
F0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8CFB6F8CFB6F8C7B6F0D7C7F0D7C7
F0D7C7F8CFB6F0C7AEE8AE95D7A68DDFA685DFAE8DD7A68DDFAE95E8B69DF0C7AEF0C7B6F0C7B6\
F0CFB6F8CFB6F0C7AEF0C7AEF0C7A6F0C7AEF0C7A6F0B69DE8AE95E8AE8DDFAE8D
DFA685D79D73C7856BB67B5AAE7352AE6342734A312110083918105A39297B5A428552398D5A42\
9563427B4A29855231734A319D7352C7855ACF956BDFAE8DE8BEA6B6734AB67B5A
9D7352B67B5AC7956BE8BE9DE8C7AEC79D85DFCFBEF8F8F8F8F0F8F8F8F8F8F0F8F8F0F8F8F0F8\
F8F8F8F8F8F8F8F8F8F8F0F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F0F8F8F8F8F8F8F8F8F8F8F0F0F8B6856B956342854A296B3921855239
854A31854A317B4A293918105229185221105A3929F0C7AEF8CFB6F8D7BEF0D7C7F0D7C7F0D7C7\
F0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F8D7BEF8D7BEF8C7B6F0CFBEF8C7B6F8D7BE
F8C7B6F0C7B6F0B69DE8B69DD7A68DDFAE8DDFAE95DFAE95E8B69DF0C7AEF0C7AEF0C7AEF0C7B6\
F8C7B6F8CFB6F0C7B6F8C7B6F0C7AEF0C7A6F0C7AEF0B69DF0B69DE8AE95E8AE8D
D7A685DFA685CF956BC78563AE73529D6B4A8D4A31291008423129522918734229734A31855231\
8552319D6339855231855231A67B5ABE8D63CF9563DFAE8DF0CFAEB67B5AB6734A
9D6B4AA67B5AB68563CFAE95DFC7B6DFCFBEF8F0F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F0F8F8F8F8F8F0F8F8F0F8F8F0F8F8F0F8B6856B955A317B4A297B4A29855239
734A317B4A29854A31522918422118522918CFAE95F0CFB6F0CFB6F8D7BEF0D7C7F0D7C7F0D7C7\
F0D7C7F8DFCFF8DFCFF8DFCFF0D7C7F8D7BEF8D7BEF8D7BEF8CFB6F0C7B6F8D7BE
F8D7BEF0C7AEF0B69DDFAE95DFAE95DFAE8DE8B695E8B69DE8BEA6F0C7AEF0CFB6F0C7B6F8C7B6\
F8C7B6F8D7BEF0CFBEF8C7B6F0C7B6F0C7AEF0C7AEF0B69DE8B69DE8B69DDFAE95
DFA685D79D7BD79D73C78563B66B529D6B4A9563424221182110085A31215229188552398D5A42\
7B4A29955A319D63398552319D7352C79D85D79D73DFAE85F0CFAEAE7352C78D63
8D5A42B68563AE7352E8BE95E8CFBEDFCFBEF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F0F8F8F0F8F8F8F8DFC7C79D73528D5A42734229855231855231
854A317B4A29522918422118391810F0B69DF0CFBEF8C7B6F8D7BEF8DFCFF0D7C7F0D7C7F8DFCF\
F0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F8D7BEF8CFB6F8D7BE
F8D7BEF8C7B6F0C7AEE8B69DDFAE95E8B695E8B695E8B69DE8BEA6F0C7B6F0C7B6F0D7C7F8D7BE\
F8C7B6F0D7C7F8C7B6F8D7BEF0CFBEF0CFBEF0C7B6F0C7AEE8C7AEF0B69DE8B695
DFAE8DD7A685D79D7BD79D73B67B5A9D6B4A9D63397342296329106B3921734A31734A31956342\
8552319D63398D5A428D4A319D7352D7A685D79D73D7AE85E8BEA6BE8D63B6734A
855231A67B5AB67B5ADFAE8DE8D7C7F0F0E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F89D7352955A318552315A31217B5A42734A31
734A31854A315229186B39215A3929F0C7AEF0C7B6F0D7C7F8D7BEF0D7C7F0D7C7F8DFCFF8DFCF\
F0D7C7F0D7C7F8D7BEF8DFCFF0D7C7F0D7C7F0D7C7F0D7C7F8D7BEF0CFBEF8D7BE
F8D7BEF8D7BEF8C7B6E8B69DDFAE95E8B69DE8BE9DE8BEA6E8BEA6E8C7AEF0CFB6F8D7BEF0CFBE\
F8D7BEF0D7C7F8D7BEF8C7B6F0CFBEF0CFBEF0CFBEF0C7B6F0C7AEE8BEA6E8B69D
DFAE95DFAE8DD79D7BD79D73C77B5AB66B52955A42734A316B39216B39216B3921855239855231\
9D63399563428D5A4295735AB6856BD79D7BD79D73D79D73D7AE85C78D63AE6B39
854A29A67B5ABE957BD7AE8DE8DFD7F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F8F8F8F0F8F8F8F8AE73529D6339734A316B39218D5A42855239
7B4A297342296B3921522918A68573F8C7B6F0CFBEF0D7C7F0D7C7F0D7C7F8DFCFF8DFCFF0D7C7\
F8D7BEF0D7C7F8D7BEF8D7BEF0D7C7F8DFCFF8DFCFF0D7C7F0D7C7F8D7BEF8D7BE
F0D7C7F8C7B6F8C7B6E8B69DDFAE95DFAE95E8BE9DE8BEA6F0C7AEF0C7AEF0CFBEF0CFBEF0CFBE\
F0D7C7F0D7C7F8C7B6F8C7B6F8D7BEF8CFB6F0CFB6F0C7B6F0C7AEF0C7AEE8BEA6
DFAE95DFAE8DD7A685D79D73C78563B66B52955A428D4A315A31215A31216B3921734A31854A31\
9563429D6339956342955A31D79D73D79D73D79D73D79D73D7A685D7AE85AE6B42
AE6B42AE7352B68563DFAE85F0F0E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F8F8F8F8F8F8F0F89D73529D7352855239734A31734229855239
854A315A3121734229855239F0C7B6F8CFB6F0CFBEF0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F0D7C7\
F0D7C7F8D7BEF0D7C7F0CFBEF0D7C7F0D7C7F0D7C7F0D7C7F8D7BEF8D7BEF0C7B6
F0D7C7F0D7C7F8D7BEE8BEA6E8AE95DFAE95E8B69DE8BEA6E8BEA6E8C7AEF0C7B6F0CFBEF0CFBE\
F0CFBEF0D7C7F0CFBEF8D7BEF0CFBEF0C7B6F0C7B6F0C7AEF0C7B6E8C7AEE8BEA6
E8BEA6DFAE95D7A685D79D7BCF956BB67B5A9D6B4A8552397342296B31186B39216B3921855239\
955A318D634A855239854A29D7AE8DD79D73C7956BD79D7BC79D85DFAE8D955A31
AE7352AE7352A6856BD7AE85F8F0E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F0F8F8F8F8BEAEAE955A318D634A8552318D5A428552318D4A31
6B39215A3929734229E8C7AEF8D7BEF0C7B6F8D7BEF0D7C7F0D7C7F0D7C7F0D7C7F8DFCFF0D7C7\
F0D7C7F8D7BEF0CFBEF0C7B6F0C7B6F0CFBEF0CFBEF8D7BEF8D7BEF8C7B6F8CFB6
F0D7C7F0D7C7F8D7BEF0C7AEE8AE95DFAE8DDFAE95DFAE9DE8BE9DDFAE9DE8C7B6E8CFBEF0C7B6\
F0D7C7F0CFBEF0CFBEF0CFBEF0C7B6E8C7B6F0C7B6F0C7AEF0C7AEF0C7AEE8BEA6
E8BEA6DFAE9DDFAE8DD7A685DF8573C785639D6B4A955A31734A315229186B39216B3921734A31\
9D6B4A8D5A428D5A428D5A42C79D85C7956BD79D73D79D739D6B4AE8BE95854221
9D6B4ABE8D63C7956BCFAE95F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F0F8F8F8F8A67B6BB68D739D6B4A734A319D6B4A734A318D4A31
5A3121734A317B4A29E8C7AEF8C7B6E8C7AEF0D7C7F0D7C7F8DFCFF0D7C7F0D7C7F8D7BEF0D7C7\
F0CFBEF0CFBEF0B69DE8C7AEF0C7AEF0C7AEF0C7B6F0CFBEF8D7BEF0CFB6F8CFB6
F8D7BEF0D7C7F8D7BEF0C7AEE8A695DFAE8DD7A68DDFAE95DFAE95E8BEA6E8C7B6F0C7B6F0CFBE\
E8C7AEE8C7AEE8BEA6E8C7AEE8C7AEE8C7AEE8C7AEF0C7AEF0C7B6E8C7AEE8C7AE
D7B6A6E8BE9DDFAE8DD7A685D79D73C78563AE7352955A31854A315229185221106B3921734A31\
8D5A429D63398D5A428D5A42C79D85CF956BCF956BD79D73854A31DFAE85955A42
8D5A42B6856BD7A685E8C7AEF8F8F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F0F8F8F0F8F8F8F8F8F8F88D4A29B6957B8D5A42956B52855A428D5A42734A31
5229189D6339E8AE8DF0C7AEE8AE95F0C7B6F8D7BEF0D7C7F0D7C7F0D7C7F0D7C7F0CFBEE8CFBE\
F0C7B6F0C7B6F0C7AEDFAE9DDFAE95E8BEA6E8C7AEF0C7B6F0CFBEE8C7AEF0C7B6
F0D7C7F0D7C7F8D7BEF0B69DDFAE95DF9D7BD7AE8DD7A68DCFAE95D7B6A6E8C7AEE8C7B6E8BEA6\
E8BEA6D7B6A6E8AE9DDFAE8DDFAE8DD7A68DDFAE9DDFAE9DE8BEA6E8BEA6E8BEA6
E8BE9DE8BE9DDFAE95D7A685CF956BC7856BB66B529D6B4A8552397342293918106329106B3921\
8D5A428D5A429D6B4A855239BE957BD79D7BB67B5ABE8D63854A29E8BE959D6B4A
8D4A31C7956BD7AE85E8D7C7F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F8F8FFFFFF9D6B4AA67B638552398D5A42855239955A42522110
855231854A31F8C7B6CF956BDFA685F0CFB6F8D7BEF0D7C7F0D7C7F0D7C7F0CFBEE8C7B6DFAE9D\
BE957BB68D73D7A68DCFA695BE957BDFAE9DDFAE9DF0CFBEF0CFBEF0C7B6F0C7B6
F8D7BEF8D7BEF8D7BEF0C7AEDFAE95D79D7BC79D85D79D7BE8BE9DDFAE9DE8C7B6E8AE9DDFAE9D\
C7A69DBE9D8DB6856BB68D73C79D85C79D85C79D85CFA695E8BE9DE8BEA6DFAE9D
DFAE9DDFAE9DDFAE8DD7A685C79D85C7856BB67B5A955A42855239734A316B39215A31215A3121\
8552398552318D634A8D5A42B6856BBE8D63B67B5AB67B5A955A31E8BE95955A31
8D4A31C79D85D79D73E8D7CFFFFFFFF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F8F8BE9D95A67B5A9D7352734A31855239734A31955A425A3121
955A31F0B695F0B69DE88D7BD7A68DF0CFB6F0CFBEF0D7C7F0D7C7F0C7B6E8AE9DB68563BE8D63\
DFAE9DBEAEAE736B6373736BA68573C79D85DF8573DF8573F0C7B6F0C7B6E8C7AE
F8D7BEF8D7BEF8D7BEF0C7A6E8B69DD79D7BD7A685BE957BD7A6859D4A31C75A4AC7856BD7A68D\
DFC7C7957B73735A4AA67B6BA67B63A67B5AA67B63B6856BD7A68DDFAE95DFAE95
DFAE9DDFAE9DD7A68DD7A68DCF956BC7856BB66B529D6B4A8D5A42734A31855239522918522918\
8552398552398D5A429D6B4AB68563BE957BB6734AB67B5A955229E8BE9D9D6339
9D7352D7AE85D7AE85F0E8E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F8F8B6856BBE9D8D9D73528D634A5A3121855239955A426B3118
522918F8C7B6E8AE8DE8A695DFAE95F0CFBEF8D7BEF0CFBEE8C7AEE8AE9DB6856BC7856BD7BEB6\
E8D7CF7B7373736B63635A52857B73A67B6BC79D85BE957BE8AE9DDFAE95F0C7A6
F8D7BEF8D7BEF0CFB6F0C7AEE8B69DDFA685BE957BB6856BC7856BC79D85AE4231DFC7C7F0E8E8\
8D736395735A7B6B5A958D856B635ABE9D959D73528D6B52B6856BD7A685D7A685
DFAE95DFAE8DD7A68DD79D7BD79D73B6856BAE73529D6B4A855231734A315A3121291008422118\
8552398D5A427342299D6B4AB6856BB685639D6B4AA67B5AAE6342DFAE8D854A29
BE957BD7AE8DD7AE8DF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F0F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8FFFFFFF8F0F8A6856B8552317B4A295A3121855239855239855239
955A42F8C7B6DFA685E88D7BDFAE95E8C7B6F0CFB6F0C7AEDFAE9DBE957B95735A5A3929B6958D\
C7B6B6957B6BB6B6BE21181885736B5A4A4295735AB6856BBE957BE8B69DF0CFAE
F8D7BEF8D7BEF8CFB6F0C7AEE8BE9DE8B695BE957BB68D739D7352B68D73BE957B9D6B4ACFC7BE\
635A52B6BECF21181873736B635A52BE9D95423129735242A67B63B68D73BE957B
D7A685D7A68DD7A685BE957BC7956BC78563AE7352955A42855239854A31422118391810422118\
522918855239734A31AE73529D7352A67B5AA67B5AB67B5AAE6342D7AE85854A29
BE8D63D79D7BDFC7B6F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8B6957BD7C7C7A68D7395735A7B5242734A31855239855239955A42
CF7363F0B69DE88D7BD79D7BDFAE8DF0C7B6F0CFB6E8B69DCFA695C7856B734A31856352856352\
5A42394229215A39298552398D6B52856352A67B63BE957BE8AE95F0BE9DF8CFB6
F8CFB6F8D7BEF8CFB6F0C7AEF0BE9DE8B69DDFA685BE957BC7856BAE735295735AA68D85A68D85\
5A39295229185A39295A3929734A315A4239735A4A7B5242A67B63B68563B6856B
CF956BD79D7BD79D7BBE957BB6856BB67B5A955A428D5A428D5A42734A316B39214221185A3929\
6B39216B3921734A319D6B4AAE73529D6B4A9D6339B67B5AAE7352D7AE85956342
BE8D63D79D73F0E8DFF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8AE7352BE9D95B69D8D8D5A42734A318D634A855239734A318D4A31
C78563E8A695D79D7BD79D7BDFAE8DF0C7B6E8C7B6E8C7AEE8BEA6DFAE95BE957BB66B528D634A\
7B52427B52427B524285523995735AC7856BD7A685E8B69DF0C7AEF0C7AEF8CFB6
F8D7BEF8D7BEF8CFB6F0C7AEF0C7AEF0C7A6E8B695DFA685D79D7BBE957BB6856B85634AA67B63\
A685739D7B6B856352634A425A4239734A319D7352BE8D63B68D73C7856BCF956B
D79D7BD79D7BBE957BCF956BBE8D63B66B52955A428D5A428552398552397342295229185A3929\
5A31215A31217342299D7352B67B5A9D73529D6339B67B5ABE8D63D7AE859D6B4A
BE8D63D7A685F0F0E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F8F8F8F0E8DFA68D7B956B52734A31734229734A31734A316B39219D6B4A
C78563CF956BC79D85BE957BD7A68DE8C7B6F0CFB6F0CFB6F8D7BEF0CFBEF0C7AEF0C7B6E8BEA6\
E8B69DE8AE9DE8B69DE8BEA6E8B69DD79D7BDFA685E8AE95F0C7A6F8D7BEF8CFB6
F0D7C7F0D7C7F8D7BEF8CFB6F0CFAEF0C7AEE8B695D79D73DF9D7BBE957BD7A685D7A68DD7A685\
BE957BBE957BBE957BCF956BD79D7BD7A685D7A685DFAE8DE8AE8DDFAE95D7A68D
D7A685D79D7BCF956BC7856BBE8D63B67B5A955A428D634A8552396B39216B39215229185A3929\
734A317342296B39219D6B4ABE8D639D6B4A9D6339C7855ABE957BDFAE959D7352
BE957BF0DFCFFFFFFFF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000FFFFFFFFFFFF7342298D5A425A31216B39216B39219563425A31219D4A31
B66B52DF8573CF956BB68D73D7A685F0CFB6E8BEA6F8CFB6F8D7BEF8D7BEF0D7C7F8D7BEF8D7BE\
F0D7C7E8A695C7856BA67B639D7352B66B52E8B69DF0C7A6F8D7BEF8D7BEF8D7BE
F8DFCFF0D7C7F8D7BEF0D7C7F8CFB6F8D7BEF0BE9DE8AE95C7856BAE63429D7352B66B52B68D73\
E8BEA6E8C7AEF0C7AEE8C7AEE8BEA6E8BEA6E8B69DE8B69DE8B69DDFAE95D7A685
C7956BB68563CF956BBE8D63B67B5AAE73529D6B4A8D5A42855231855239632910522918522918\
5A3929522110734A318D5A42AE73529D6B4A956342C78D63C7956BE8BE9DA67B5A
C79D85F0E8E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F0E8E8FFFFFF6B39217B4A295A31216B3921734A31855239734A319D6339
B66342B67B5ABE8D63C7856BC79D85F0C7AEDFC7B6E8BE9DF0C7B6F8D7BEF0D7C7F0D7C7F8C7B6\
B6856BA67B6395735AB66B52D7A685F0C7A6F8CFB6F8CFB6F8D7BEF8DFCFF8D7BE
F8DFCFF0D7C7F8D7BEF8D7BEF8D7BEF8CFB6F8CFB6F0C7A6E8AE95BE8D63955A42855239955A42\
B66B52DFA685E8AE9DE8C7AEF0C7AEF0C7AEF0B69DE8BEA6DFAE95DFA685BE957B
A67B5ACF956BB68D73B6856BAE73529D6B4A9D6B4A8D5A426B39216B39215229185A3121522918\
522110735242855A42956B52A67B5A9D7352955A31BE8D63BE8D63D7AE8DBE957B
C79D85F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000BEAEAEFFFFFF855231734229734A31734A315A31218552397B4A29955A31
955A42955A42A67B63B6856BC79D85E8C7B6F0CFBEBE957BC79D85D7A685D79D7BDF8573B66B52\
AE7352D79D7BF8CFB6F8D7BEF8D7BEF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCF
F0D7C7F0D7C7F0D7C7F0D7C7F8D7BEF0D7C7F8CFB6F8CFB6F8CFB6F0CFAEE8B69DD7A685B68D73\
95735A8D5A429D7352AE6342CF6B5AB68D73C7856BB68563A67B63A67B5AB6856B
BE957BBE957BDF8573BE8D63AE73529D6B4A9D6B4A8552399D6B4A4221187342297342296B3921\
52291842292185634A9D6B4AAE73529D6B4A956342BE8D63D79D73B6856BAE6B42
DFCFBEF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000C7A6959D7352734A31734A3185634A855239734A31734A31734A31855239
955A318D634A9D7352A67B5AD7A685E8C7B6F0CFB6F0CFB6F0C7AED7A685BE9D8DDF8573DFAE9D\
F0D7C7F8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFD7
F0D7C7F0D7C7F8DFCFF8DFCFF8DFCFF8D7BEF8D7BEF0D7C7F8D7BEF8CFB6F8C7B6F0C7AEF0C7AE\
F0C7AEE8C7AEE8C7AEC79D85A67B63AE7352A67B63A67B63BE957BC79D85BE957B
CF956BD79D73CF956BBE8D63AE73529D7352AE73528552396B3921734A316B39215A3121391810\
3918104221188D634A95735A8D5A42A67B5AAE6342C7956BC79D859D6B4ABE8D63
F0E8E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000009D6B4A7B5A42734A319D7B6B8D6B527B5A42855239734A318D5A42
8D5A428D634AAE7352AE7352D79D7BF0C7AEF0C7B6F0CFB6F0CFB6F8D7BEF8D7BEF0D7C7F0D7C7\
F0D7C7F8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFD7F8DFCFF8DFCF
F0D7C7F8DFCFF8DFCFF8DFCFF0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F8D7BEF0CFB6F0CFB6F8CFB6\
F0C7AEF0C7AEF0C7AEE8BEA6E8C7AEE8C7AEE8B69DDFAE95DFAE8DD7A68DD79D7B
D7A685BE957BB68D73B67B5AAE7352A67B5AAE73529D6B4A734A316B3921522110391810391810\
391810422118B68D738D634A8D5A42D79D739D6B4AB67B5AD7AE859D6B4AC79D85
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000854A29735242855A42A68D73956B52855239855A427B5A42855A42
855A428D5A42A67B5A9D7352D79D7BE8C7AEF0CFB6F0CFB6F0CFBEF8D7BEF8D7BEF0D7C7F8DFCF\
F8DFCFF0D7C7F8D7BEF8DFCFF8DFCFF8DFCFF8D7BEF8DFCFF8DFCFF8DFCFF8DFCF
F8D7BEF0D7C7F8DFCFF0D7C7F0D7C7F8DFCFF0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF8C7B6F8CFB6\
F0C7B6F0C7AEE8C7AEE8BEA6F0C7AEE8B69DE8B69DDFAE95D7A685D7A685D79D7B
D79D7BBE957BC7956BBE8D63B66B52AE7352AE73528D5A429D6B4A734229522918522918422118\
5A3121522110BE957BA67B5A8D5A42BE957BAE73529D6B4AD7AE8D9D6B4AD7BEAE
FFFFFFF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000008552398D6B528D634A9D73528D634A8D6B528D634A855A42855239
8552318552319D6B4A9D7352C7856BE8BE9DF0C7B6F0CFB6F0CFB6F0CFBEF8D7BEF8D7BEF0D7C7\
F8DFCFF8DFCFF8D7BEF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCF
F8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF0D7C7F0D7C7F0D7C7F8CFB6F8CFB6F8CFB6F8CFB6F8CFB6\
F0C7AEF0C7A6E8C7AEF0C7AEE8BEA6E8BE9DE8B695DFAE95DFAE8DD7A68DD7A685
D79D7BD79D73CF956BB67B5AAE7352B67B5A9D73529D6B4A734A315A31216B39215A3121391810\
391810422118C7956BA67B639D6B4AD79D73B6734A8D634ABE957B9D6B4AF8F0F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000085523985523985523985634A8D634A855239855A42855239
855A42855239A67B5AB67B5AC7956BE8B69DE8BEA6F0CFAEF0CFBEF8CFB6F8D7BEF8D7BEF0D7C7\
F0D7C7F8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8D7BEF8D7BEF8DFCFF8DFCFF8DFCF
F8DFCFF8DFCFF0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F8C7B6F8CFB6F8CFB6F8CFB6F0CFAEF0C7AE\
F0C7AEF0C7AEF0B69DE8BEA6E8BE9DE8BEA6E8B69DDFAE8DDFAE95DFA685D7A685
BE957BCF956BC7856BBE8D63B67B5AAE73529D6B4A855239734A315A3929734229422118391810\
3918105A31219D7352D79D73B68563D79D7BB67B5A9D7352956342CFAE95F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000008D6B528552398D634A8D6B52956B528D634A855A42855A42
8552398D634A9D7352BE8D63BE957BDFAE8DE8BEA6F0CFB6F0CFBEF8D7BEF8D7BEF8D7BEF8D7BE\
F8DFCFF8DFCFF8D7BEF8D7BEF8DFCFF8DFCFF8D7BEF8DFCFF8DFCFF0D7C7F8DFCF
F8DFCFF8DFCFF0D7C7F0D7C7F0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF8CFB6F8CFB6F0CFAEF0C7AE\
F0C7AEF0C7AEF0B69DE8B69DE8B69DE8B69DE8B69DE8AE95DFAE8DD7A68DD7A685
D79D7BCF956BB68D73B68563B68563A67B639D6B4A8D5A426B3921734A31522110422118422118\
39181042292195735ABE957B9D7352C7956BBE8D63A6856B956342E8CFC7F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000007352428D5A42956B52956B52855A428D634A8552397B5A42
956B528D634A9D7352B6856BC7956BD7A68DE8BEA6F0C7AEF8CFB6F8CFB6F8CFB6F8D7BEF8D7BE\
F8D7BEF8DFCFF8DFCFF0D7C7F8D7BEF8DFCFF8DFCFF0D7C7F8D7BEF8DFCFF8D7BE
F0D7C7F0D7C7F8D7BEF0D7C7F8D7BEF8D7BEF8D7BEF8CFB6F8D7BEF8CFB6F8CFB6F0C7AEF8CFB6\
F0C7AEF0C7A6F0C7A6E8BEA6E8BE9DE8BEA6E8B695DFAE95DFAE8DD7A68DD7A685
BE957BCF956BC7856BB68563B685639D6B4A9D6B4A8D5A42734A316B3921522110391810291008\
2910087B52428D634AA67B5AAE7352C79D85C7956BD7AE8DC7956BF8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000A67B5A8D5A428D634A85634A8D5A42855A429D6339
7342298D634AA67B63BE8D63B68D73D7A685E8BE9DF0C7AEF0CFB6F8CFB6F8D7BEF8D7BEF8D7BE\
F8DFCFF8DFCFF0D7C7F8DFCFF8DFCFF8DFCFF8D7BEF8DFCFF8D7BEF0D7C7F8DFCF
F8D7BEF0D7C7F0D7C7F8D7BEF0D7C7F0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF0C7AEF8C7B6F0CFAE\
F0C7AEF0C7AEF0B69DF0C7A6E8B69DE8B69DDFAE95DFAE95DFAE8DD7A68DD7A685
BE957BD79D73B68D73B6856B9D7352956B52855A42734A318552395A3121391810291008422921\
29100885634A956B529D6B4A956342C7956BC7956BC79D85E8DFD7F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000007B5A427B5A42855239855239855231855A42855239
8D634A8D634AA67B5AB68D73C79D85D7A68DE8BE9DF0C7AEF0CFB6F8D7BEF8D7BEF0D7C7F8D7BE\
F8DFCFF8DFCFF8D7BEF8DFCFF8D7BEF8DFCFF8D7BEF0D7C7F8D7BEF8DFCFF8D7BE
F0D7C7F0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF0D7C7F8D7BEF8D7BEF8C7B6F8CFB6F8CFB6F0C7AE\
F0C7AEF0C7AEF0B69DF0C7A6E8B69DE8B69DDFAE95DFAE8DDFAE8DDFAE8DD7A685
C79D85D79D7BB6856BA67B639D73529D73529D6B4A7B5A426B39215A3121391810391810422921\
391810956B52956B529D73529D6339C7956BC79D85D7A68DF8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000855239734A31855231735242734A317B5A42
8D634A9D6B4AB68563B68D73D79D7BD7AE8DE8BE9DF0C7AEF8CFB6F8C7B6F8D7BEF0D7C7F8D7BE\
F8D7BEF8D7BEF8D7BEF0D7C7F8DFCFF8DFCFF8DFCFF8DFCFF0D7C7F0D7C7F8DFCF
F8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8C7B6F8CFB6F8CFB6F8CFB6F0C7AE\
F8CFB6F0C7AEF0C7A6F0C7A6F0BE9DE8B69DDFAE95DFAE8DD7A68DDFAE8DD7A685
D7A685BE957BB6856BB6856BA67B638D634A8D5A426B39215A3121422118422118291008392118\
3918109D7B63956B529D6339956342C79D85CFB6A6DFCFC7F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000855239855239855231855239855239735242
8552399D6B4AA67B63B68D73C79D85DFAE9DE8BEA6F0C7AEF8CFB6F8CFB6F8D7BEF0D7C7F0D7C7\
F8DFCFF0D7C7F8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF0D7C7F8DFCFF8D7BEF0D7C7
F8DFCFF0D7C7F8D7BEF0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF8CFB6F8D7BEF8CFB6F8C7B6F0CFAE\
F0C7AEF0C7AEF0C7A6F0C7A6E8B69DE8B69DDFAE9DDFAE8DDFAE8DD7A685D7A68D
CF956BCF956BBE8D63A67B63A67B5A9D73528D5A425A39295A3121422118422921311818422118\
422118A67B63B6856B8D5A42AE7352C7956BE8BE9DF8F8F8F8F8F8F8F0F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000734A317352427352428552397B5A42
735242956B52B68563BE957BD7A685DFAE95F0C7A6F0C7AEF0C7B6F0CFB6F8CFB6F8D7BEF8D7BE\
F8D7BEF8D7BEF8D7BEF8DFCFF8D7BEF8DFCFF0D7C7F8D7BEF8D7BEF0D7C7F8D7BE
F0D7C7F0D7C7F8D7BEF8D7BEF8D7BEF0D7C7F8D7BEF8D7BEF8CFB6F8CFB6F0CFAEF8CFB6F8C7B6\
F0C7AEF0C7AEF0C7AEE8BEA6E8BEA6E8BE9DE8B695DFAE8DDFAE8DD7A68DD79D7B
D79D7BB68D73BE8D63A67B639D73528D634A8552395A39295A3121422921422118522918522918\
3918109D6B4AB685639D6B4AC7855AD7A685DFCFCFF8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000735242855A427B5A427352427B5A42
855A42956B529D7352C7956BD7AE8DE8BEA6E8BEA6F0C7AEF8CFB6F8CFB6F8D7BEF8D7BEF8D7BE\
F0D7C7F0D7C7F8DFCFF8DFCFF0D7C7F8D7BEF8D7BEF0D7C7F0D7C7F0D7C7F0D7C7
F8D7BEF8D7BEF0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF8CFB6F8CFB6F8CFB6F0CFAEF0CFAEF0C7AE\
F0C7A6F0C7A6F0C7AEE8BEA6E8BE9DE8B695E8AE95DFAE8DDFAE8DDFA685DFA685
CF956BB68D73B6856BAE73529D6B4A8D5A42734A315A39295A3929522918422118522918391810\
291008956B529D73529D6B4ABE8D63DFAE8DF0F0E8F8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000956B52956B52956B527B5A42
7B5A42956B52A6856BB68D73D79D7BE8B69DF0C7A6F0C7AEF0C7AEF8CFB6F0CFB6F8CFB6F0D7C7\
F0D7C7F0D7C7F0D7C7F8D7BEF8D7BEF0D7C7F8DFCFF8D7BEF0D7C7F8D7BEF8D7BE
F8D7BEF8D7BEF8CFB6F8D7BEF8CFB6F8CFB6F8CFB6F8CFB6F8D7BEF8C7B6F8CFB6F0C7A6F0C7A6\
F0C7A6F0C7A6F0B69DE8BEA6E8BE9DE8B695DFAE95E8B695D7A685D7A685D7A685
B68D73B68D73A67B63A67B5A8D634A855239734229734A315A31215A3121422118391810211008\
5A3929B6856B9D7352B6734ACF956BCFAE95F8F8F8F8F0F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000095735A956B52855A428D634A
85634A8D634AAE7352BE957BC79D85DFAE95F0C7A6F0C7AEF0C7AEF8CFB6F8CFB6F8D7BEF8D7BE\
F8CFB6F0D7C7F0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF0D7C7F8D7BE
F8D7BEF8D7BEF8D7BEF8D7BEF8CFB6F8CFB6F8CFB6F8D7BEF8CFB6F0C7AEF0C7AEF0C7AEF0C7AE\
F0C7A6F0C7AEF0BE9DE8B69DE8B69DE8B69DE8B695DFAE8DD79D7BD7A68DBE957B
BE957BBE8D63AE7352955A42855239855A427342295A39295A3929422921522918211818211008\
A67B5AA67B63956342B67B5AC78D63E8CFBEF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000085523985634A735242
8D634A8D634AA67B5ABE8D63D79D7BDFAE9DE8BEA6F0B69DF0C7AEF0C7AEF8CFB6F0CFAEF0CFAE\
F8CFB6F8CFB6F8D7BEF8D7BEF8D7BEF8CFB6F8D7BEF8D7BEF8D7BEF8CFB6F8D7BE
F0CFB6F8CFB6F0CFBEF8CFB6F8CFB6F8CFB6F0CFAEF0C7AEF0C7AEF0C7AEF0C7AEF0C7A6F0C7AE\
F0C7A6F0C7A6F0B69DE8B69DE8B69DE8B69DDFAE95DFAE95D7A68DD79D7BD7A685
B68D73A67B639D6B4A9563428D5A42855A42855A425A31215A3121522918391810291008B6856B\
9D7B639D6B4A956342BE8D63D7B6A6F0E8E8F8F8F8F8F0F8F8F0F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000855A42A67B5A
7B5A42A67B5AA67B5ABE8D63C79D85DFAE95E8BE9DE8C7AEF0C7AEF0C7A6F0C7AEF8CFB6F8CFB6\
F8D7BEF8CFB6F0CFBEF8D7BEF8CFB6F8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8CFB6
F8CFB6F8D7BEF8CFB6F0C7AEF8CFB6F0C7AEF8CFB6F0C7AEF0C7AEF0C7A6F0C7AEF0C7AEF0C7A6\
F0C7A6E8BE9DF0BE9DE8B695E8B695DFAE9DDFAE8DCFAE95BE957BD79D7BCF956B
B6856BA67B639D73529D6B4A855A42734A31735242956B524221183918103921187B5A42855239\
A67B5A9D6B4AAE7352C7956BE8BEA6F8F0F8F8F8F8F8F0F8FFFFFFF8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000855239855239
85634AA67B63A67B5ABE8D63D79D7BDFAE95DFAE9DE8BEA6F0C7AEF0C7A6F0C7AEF8C7B6F0C7AE\
F8D7BEF0CFAEF8CFB6F8CFB6F8CFB6F8CFB6F8CFB6F8CFB6F8CFB6F8D7BEF8C7B6
F8C7B6F0C7AEF0C7AEF0C7AEF0B69DF0C7AEF0C7A6F0C7A6F0C7A6F0C7A6F0C7A6F0C7AEF0C7A6\
F0C7A6E8B695E8B695E8B69DDFAE95DFAE95DFAE8DD7A685BE957BBE957BB6856B
AE73529D7352956342855A42855A428552398552395A3929734A315A3929734A31734229A67B63\
9D7352B68563BE8D63D7AE8DD7BEAEF8F8F8FFFFFFF8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000855231
7B5A428D5A429D7352B68563BE957BC79D85D7B6A6E8B69DE8BEA6F0C7A6F0B69DF8C7B6F8C7B6\
F0CFB6F0CFB6F0C7B6F0C7AEF8C7B6F8CFB6F8CFB6F8D7BEF0C7B6F0CFB6F0C7AE
F0C7AEF0C7A6F0B69DE8B69DE8B69DF0B695F0C7A6F0C7A6F0BE9DF0B69DF0BE9DF0B695E8B69D\
E8B69DDFAE8DE8AE95DFAE95D7A68DD7A68DD79D7BBE957BBE957BB68D73B6856B
AE7352A67B5A9D6B4A735242735242734A31734A315A42397342295A3121A6856B956B529D7352\
9D6B4AD79D7BC7956BE8BE9DF8F8F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8FFFFFF
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
9D6B4A8552399D7352A6856BB68D73D7A68DDFAE95DFAE9DE8B69DF0B69DF0B69DF0C7A6F0C7AE\
E8C7AEF0C7AEF0CFB6F0C7AEF0C7AEF0C7AEF0C7B6F0C7AEF0C7A6F0C7AEF0C7AE
F0BE9DE8B69DE8AE8DE8AE95E8AE95E8B695F0B695E8AE8DE8AE8DE8AE8DE8AE8DDFA685DFAE8D\
E8AE95D7A685DFAE8DD7A685D7A685C79D85D79D73BE957BB6856BB68563B68563
A67B5A9D73528D5A42855A427B5A427352428D6B527B5A42734A318D6B52B6856B95735AA67B63\
BE8D63D7A685E8BE9DD7BEAEF8F0F8F8F8F8F8F8F8F8F8F8FFFFFFF8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000956B528D634A9D7352A67B63BE957BD7A68DE8BE9DDFAE9DD7B6A6E8B69DE8B69DF0C7AE\
F0C7AEF0C7AEF0C7AEE8C7AEE8BEA6E8BEA6E8BEA6E8BEA6E8B69DDFAE9DDFAE8D
DFAE95DFAE95D7A685D7A685D79D7BD79D7BD79D7BD79D73DF9D7BD79D7BD79D73D79D73BE957B\
CF956BCF956BCF956BCF956BC7856BB68D73BE957BB68D73B6856BB67B5A9D6B4A
8D634A95735A956B52735A4A956B52956B52734A318D634A9D6B4A9D6B4A9D73529D6B4ABE8D63\
B68563DFAE95E8BE9DF8F0E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000008D634A956B52A67B5AB6856BA67B6BB68D73BE957BDFAE95D7B6A6E8BEA6F0C7A6E8C7AE\
E8BEA6E8BEA6E8BEA6E8BE9DDFAE95DFAE95D7A685DFAE95E8BE9DD7A68DDFA685
D7A685D7A68DBE957BC79D85C7856BCF956BBE8D63D79D7BCF7363CF956BB67B5AB68D73B67B5A\
B67B5ABE8D63B68563B68563B6856BB6856BA67B63B68D73BE957BA6856BA68D73
A67B5AA67B638D634A8D634A95735AA67B63855A426B3921855239B67B5AB68563B67B5ABE8D63\
CFAE95D7B6A6D7BEAEF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000007B5A429D7352A67B5A8D634AB68D73C79D85D7BEAEE8C7B6E8C7B6E8C7B6E8BEA6\
E8BEA6D7B6A6DFAE9DD7A685CFAE95D7A68DD7A68DD7A685D7A68DD7A685D7A685
C7956BC7956BB68D73B68D73B6856BB68D73B6856BAE7352B6856BB685639D73529D6B4AB6856B\
9D7352B685639D7352AE7352A67B63A67B5AA67B638D634A956B5295735AAE7352
95735A9D735295735A9D7352855239855A428D6B529D6B4A9D7352A67B5AA67B5AC7956BD7B6A6\
D7B6A6C79D85F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000009D7363A68D73C7A695CFA695BE9D8DDFAE9DCFA695DFAE9DD7BEAED7BEAE\
DFAE9DDFAE95D7A68DD7A685D7A68DBE957BC79D85D7A685C79D85C7956BC79D85
BE957BC7856BB68563B6856B9D7352BE957BA67B63BE957BB68563A67B63BE8D63A67B5A9D6B4A\
BE957BA67B5AB6856BA67B63A67B5AA6856BA68D7385634A956B52A67B5A9D7B63
8D6B5295735AA67B639563429D6B4A9563429D6B4A9563429D7352B68563D7AE85CFB6A6CFAE95\
D7AE8DE8CFC7F8F8F8F8F8F8F8F8F8F8F8F8FFFFFFF8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000956B52A6856BB68D73B68D73BE9D8DDFAE9DD7B6A6DFAE95CFAE95\
D7A68DD7AE8DC79D85C79D85C79D85B68D73BE957BB68D73BE957BB68D73BE957B
B6856BBE957BA67B5A9D7352A67B6B956342A6856BA67B5AB68D739D7352A67B63A67B5AA67B63\
C7956B8D634A9D73529D7352B6856BA67B5A956B52956B52855A427B5A42734A31
7352428D634A8552398552397B5A427B5A42956342B6734AC7956BD7AE85E8C7AEBE9D8DD7AE8D\
B68563F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000BE9D95C79D85C7A695D7B6A6D7B6A6D7B6A6D7B6A6C79D85\
C79D85C79D85C79D85BE957BC79D85BE957BBE957BB6856BB6856BBE957BB68563
A67B5AA67B63956342A6856BA6856B8D634A734A31A67B63855A42B68563A67B5AA67B63A67B63\
8D5A429D6B4AA67B5A734229734A319D63398D5A42855A428D5A429D6339956342
9D6B4A9563429563428552399D63399D6B4ACFAE95BE957BD7AE8DD7BEAE8D634ABE9D8DA6856B\
DFCFCFFFFFFFF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8F8F8F8
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000A6856BC7A69DCFB6A6DFAE9DD7B6A6C7A695\
BE957BBE957BB68D73BE957BBE957BB68D73A6856BA68D73B68D73A67B63B68563
B685638D634AC7956BA67B5A8D634ABE957B8D634A855A42A67B638D634A8D634A956B52855A42\
8D5A428552317342298552398552399D63398552397B5A429563428D5A42855239
854A318D5A429D7352B68563B68563C79D85BE957BE8BE9DD7B6A6A6856BA67B5ABE9D8DA6856B\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000B6957BC7AE9DCFB6A6D7A68DC7A695\
A67B63B6856BA6856BBE957BBE957BB6856B9D7363B6856BB68563A67B63B68D73
A67B63B68563855A429D735295735A8D634AA67B5A855A428D634A956342855A4285634A855A42\
735242855239855239855239734A317342298552397B5A42855239855231855231
8D634AA67B5AA67B5AA67B5AA67B5AC79D85CFB6A69D7B639D7B63A6856BC7A695BE957BF0E8E8\
F8F0F8F8F0F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000B6957BD7B6A6D7B6A6C7AE9D\
A67B5AB68D73A67B63A67B63B68563A67B5A95735AA6856BA6856B95735AA67B63
95735AA67B63855A42A67B5A9D6B4A956B52735242734A31A67B5A7352427B5A42855A427B5A42\
855231734A31734A316B39215A39297342297342297342298552319D6B4A855A42
8D634AA6856BC79D85BE957BE8BEA6CFB6A6BE9D8DA68D73956B52C79D85956B52F0E8E8FFFFFF\
FFFFFFF8F0F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000CFB6A6D7BEAEC7AE9D\
A67B5A956B52B6957BA67B63B68D73B6957BB68563956B52A6856BA67B5A8D634A
A67B63A67B638D634A9D7352A67B5A95735A8D6B525A3121734A317B5A42A67B5A855239855239\
6B39218552397342296B39215A31215A39295A31215A3121734A318D5A42A6856B
BE957BB6856BBE957BCFB6A6B6957B85634A957B6BB68563A6856B9D6B4AC7A69DF8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8F8F8F8FFFFFFF8F8F8000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000D7B6A6\
A6856B956B52A67B5AB68D7395735A95735AA67B638D6B528D634A9D736395735A
8D6B52956B52A67B6395735A8D634AA67B5A9D73528D6B528D634A734A31734A3185634A855239\
8552398D5A428552319D6B4A855231855231955A319D6B4AAE7352A67B63BE8D63
C79D85DFC7B6B6957BBE9D8D9D7B6B734A3195735AA6856BB6957BB6957BF8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8FFFFFFF8F8F8F8F0F8000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
D7B6A68D634A8D6B529D7B63B6856395735A956B52855A427B5A427B5A428D634A
8D634A956B5295735A8D634A8D634AA67B5AA6856B9D735295735A7B5A42A67B5A855239855231\
95735A956B528D634A9563429D6B4AA67B5AB68563C79D85B68D73BE957BD7B6A6
BE9D8DB69D8DA68D73A68D737B5A429D7363A68D73A6856BA67B6BFFFFFFF8F8F8FFFFFFFFFFFF\
F8F8F8F8F0F8FFFFFFF8F0F8FFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000008D6B528D6B52A6856BA6856B956B52A6856B855239855A42855A42
9D6B4A956B529D7352855239A67B6B9D7352B68D73A67B63B6856BB6957B956B528D5A428D5A42\
9D73529D7352B68563B68563BE8D63BE8D63D7A685D7A685C7A695A67B639D7B6B
9D7B6B8D5A42734229855239A67B63A6856B9D7B63BE957BFFFFFFF8F8F8F8F8F8F8F8F8FFFFFF\
FFFFFFF8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000A6856B8D634AA6857395735AA67B63956B52855239
7B5242734A318D634A7B5A429D73639D7352BE957BB68D73DFC7B6E8C7B6D7B6A6C79D85DFAE9D\
D7A68DD7A68DD7A68DE8C7AEE8C7AEDFAE95CFB6A6A68D738D6B529D7B63956B52
855A427B5A428D634AB68563B6957BA67B63A67B6BFFFFFFF8F8F8F8F8F8FFFFFFF8F8F8F8F8F8\
F8F8F8000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000A68573A68D7BA67B6BBE957BC7A695
9D7B6B7B52428D6B527B524295735AB6957BC7A695BE9D8DA68D7BD7BEAED7BEB6D7BEAEDFC7B6\
E8D7C7E8CFC7D7BEAEC79D85B6957BB6957BA6857395736395735A956B52735242
85523995735A9D7B63BE957BA67B63B6957BF8F8F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000D7BEB6C7A69D
E8CFC7F0D7C7F8F0E8F0E8DFF0D7C7E8CFC7E8CFBED7BEAEDFCFBEDFC7B6DFC7B6DFC7B6E8CFBE\
CFB6A6A68D73C7A695A68D739D7B639D7B6B9D7B6B8D634A8D6B52735A4AA67B63
A68D73A6856BA6856BA67B63FFFFFFF8F8F8F8F8F8FFFFFFF8F0F8000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000DFC7B6E8C7B6E8CFBEE8C7B6F0D7C7F0DFCFE8D7CFDFCFBEE8CFC7CFB6A6BE9D95D7BEAE\
BE9D8DB69D8DBE9D958D735AA67B5A8D634A8D6B529D7B6BA68573BE9D8DC79D85
B68D73A6856BC7A69DF8F8F8F8F8F8F8F0F8000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000E8D7CFF0DFCFE8CFC7DFCFBED7BEB6CFC7BEB69D8DA68D85\
BE9D959D7B639D7B6B95735AA68D73856352A68D7BBE9D8DC79D85B69D8DA68D7B
C79D85E8DFDF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000B69D8D000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 12.812500 moveto
(H) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 12.812500 moveto
(L) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F0BE9D000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000F0C7A6F0C7A6F0C7A6F0C7A6F0C7A6F0C7A6F0C7A6F0BE9D\
F0C7A6F0BE9DF0BE9DF0BE9DF0C7A6F0C7A6F0C7A6F0C7A6F0B695F0B695F0BE9D
F0BE9DF0BE9D000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000F0C7A6F0C7A6F0C7A6F0C7A6F0BE9DF0BE9DF0C7A6F0C7A6F0BE9DF0BE9DF0BE9DF0BE9D\
F0B695E8BE9DF0BE9DF0C7A6F0C7A6F0C7A6F0BE9DF0BE9DF0BE9DE8BE9DF0B695
E8BE95E8B695F0BE9DF0BE9DF0BE9DF0B695000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000E8BE95F0BE9D
F0C7A6F0BE9DF0BE9DF0BE9DF0BE9DF0C7A6F0BE9DF0BE9DF0C7A6F0BE9DF0BE9DF0C7A6F0BE9D\
F0BE9DF0B695E8BE95F0BE9DF0BE9DE8BE9DF0C7A6F0BE9DF0B695E8B695F0B695
E8B695E8B695E8B695E8B695E8BE95E8B695E8B695E8AE8DE8AE8D000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000DFAE9DDFAE95E8B695E8B695E8BEA6
E8BE9DF0BE9DF0BE9DF0BE9DF0BE9DF0C7A6F0BE9DF0C7A6F0BE9DF0BE9DF0BE9DF0BE9DE8BE9D\
F0BE9DF0BE9DF0B695F0B695E8BE95F0B695F0BE9DF0BE9DE8BE9DE8BE95F0B695
E8B695F0B695E8AE8DDFAE85E8AE8DF0B695E8AE8DE8AE8DF0B695E8AE8DE8BE95E8B695000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000006329104A1808DFAE95DFAE95E8BE9DE8B69DE8BE9D
E8BE9DF0BE9DF0BE9DF0BE9DF0BE9DF0BE9DF0C7A6F0C7A6F0BE9DF0BE9DF0BE9DF0BE9DF0BE9D\
F0BE9DF0BE9DE8BE95E8BE95F0BE9DF0B695E8BE9DF0B695F0B69DE8B695E8B695
E8B695E8B695E8AE8DE8AE8DE8AE8DE8AE8DDFAE85DFA67BDFAE85E8AE8DDFAE85E8BE9DDFA67B\
DFAE8D000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000007B39186329105221106B3118DFAE95DFAE95E8B695E8BE9DE8BE9D
E8BEA6E8BE9DF0C7A6F0BE9DF0C7A6F0BE9DF0BE9DF0BE9DF0BE9DF0BE9DF0B695F0BE9DF0BE9D\
E8BE95F0BE9DF0B695E8BE9DF0B695E8B695E8B695E8AE8DE8B695E8B695E8B695
E8B695E8AE8DE8AE8DDFAE85DFA685DFA67BDFA67BDFA67BDFAE85E8BE9DDFAE85D79D7BD79D73\
D79D7BDF9D73DF9D73000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
B66B399552298D4A296B31186B31187B42217B4A29DFAE9DE8BE95E8BE9DF0C7A6
E8BE9DE8BE9DF0C7A6F0BE9DF0BE9DF0BE9DF0BE9DF0BE9DF0BE9DE8BE9DF0BE9DE8BE9DE8B695\
F0B69DF0BE9DE8BE95F0B695F0B695E8BE95E8AE8DE8BE95DFAE85E8B695E8BE95
E8B695E8AE8DE8AE8DDFA685DFA685CF956BD79D73DFAE8DE8BE9DDFAE8DCF8D63CF956BD79D73\
CF956BD79D73CF956BC77B4AC77B42000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000B6734A\
AE6B398D4A298D4A297B39188542218D4221632910DFAE95E8BE9DE8BEA6F0C7A6
E8BE9DE8BE9DF0BE9DF0B695E8BE95F0BE9DF0B695E8BE95F0BE9DF0BE9DE8BE95F0B695E8BE95\
F0B695F0B695F0BE9DE8B695E8B695E8B695E8BE95DFAE85F0B695DFAE85E8AE8D
DFAE8DDFAE85DFA685DF9D7BCF956BD79D73D79D73E8BE95E8BE9DCF8D63CF956BD79D73D79D73\
CF8D63B67B5AB66B529D6339C77B42B66B39000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000B6734AAE6B429D6339\
9D63398D42218D4A299552299552297B39184A1808E8BE9DE8B695E8BEA6E8BE9D
F0BE9DE8BE9DF0BE9DF0B695F0B695F0BE9DF0B695F0B695F0B695F0B695F0B695F0B695E8BE95\
E8BE95F0B695E8B695E8BE95E8B695E8B695DFAE85DFAE85DFAE85E8AE8DDFAE85
DFAE8DDFAE8DDF9D7BD79D73CF8D63CF8D63DFAE85DFAE95CF8D63C78563C78563C78D63C78563\
B67B5AAE73528D5A42AE6B42C77B42B66B39B66B39B66B39000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000BE8D63B67B5AB66B42AE6B42\
8D4A29854221955229955A318D4A296B39216B3118E8BEA6E8B69DF0C7A6E8BEA6
E8B695F0BE9DE8BE9DE8BE9DF0BE9DF0B695F0B69DE8BE95F0B695E8AE8DF0B695F0B695E8AE8D\
E8AE8DE8AE8DE8AE8DF0B695DFAE85E8AE8DDFAE8DDFAE85E8AE8DDFA67BDFA685
DFA67BD79D7BD79D73C7856BCF8D63CF9563D79D73CF956BC7855AC78563C7855AC7855AB67B5A\
9D63399D6B4A9D6B4AAE6B39CF8D5AC77B4AC77B42B66B39AE6B39000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000CF956BC7855AB6734AAE6B42AE6B39\
955A31955229AE6B399552296B31186B3118632910E8BEA6E8B69DE8BE9DDFAE95
E8BE9DF0BE9DF0BE9DE8AE8DE8AE8DF0B695E8B695E8AE8DE8AE8DE8AE8DDFAE85E8AE8DE8AE8D\
DFAE85DFAE85E8AE8DDFA685E8AE8DDFA685DFA685DFA685DFA685DFA67BDFA67B
D79D73D79D73CF956BCF8D5AC78563D79D7BC78D63B67B5AB66B52C77B4AB6734AB67B5A956342\
B6734A9D7352AE6B39AE6B42C77B4ACF8D5AC7855AB6734AC77B4AB67B5A000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000D79D73D79D73BE8D63B6734AAE6B42AE6B42\
8D4A299D63399552298542216329106B3921632910E8BE9DE8BE9DE8BE9DE8BE9D
E8BE9DE8B695F0BE9DE8BE95E8AE8DF0B695E8AE8DDFAE85E8AE8DDFAE85DFA685DFAE85DFA685\
DFAE85DFA685DFA685DFA685DFAE8DDFAE85DFA67BDF9D7BD79D7BDFA67BD79D7B
D79D7BD79D73CF956BC7855ACF956BCF8D63B67B5AB66B52B6734AAE6B42AE6B42955A319D6B4A\
9D6B4A9552299D6339B66B42CF8D5ACF8D5ACF8D5ACF956BC77B4AC77B4AB6734A
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000F8F0E8CFAE95D79D73C78D63C7855A9D63399D6B4A955A31\
9D4A319D63399D4A317B42216B39217B42216B3118E8BEA6DFAE9DE8BE9DE8B695
E8BE9DE8B695E8AE8DE8BE95E8AE8DE8AE8DE8AE8DDFAE85DFA685DFA685DFA685DF9D73DF9D7B\
DFA67BDF9D7BDF9D7BDFA685DFA67BDFA67BD79D73DF9D73D79D73D79D73D79D73
D79D73CF8D63CF8D63C7855ACF956BC7855AB6734AAE6B42AE6342AE6342956342AE6B429D6B4A\
955A31955A319D6339B66B39C77B42CF8D5AC7855ACF8D5AC7855ABE8D63B6734A
B6734AB66B42000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000F8F0E8E8D7C7D7AE8DD79D73C7855AB67B5AAE6B42B6734A955229\
9D63399D6339955A315A31216329106B31186B3921E8BE9DDFAE95E8B69DDFAE95
E8B695E8B695E8AE8DE8AE8DE8AE8DDFA685DFAE85DFA67BDF9D7BDFA67BDF9D7BDF9D7BDF9D73\
CF956BCF956BCF956BD79D73D79D73DF9D7BD79D73D79D73CF956BCF956BCF956B
CF8D63CF8D63C78563BE8D63B6734AAE6B42AE6B399D6339AE6342AE6B42AE6B429D63399D6339\
9D6339AE6331B66B39B66B42C77B42CF8D5ADFA673D79D73DFAE85C78D63AE6B39
AE6B39B6734AC78D63000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000F8F0E8F8F0E8E8BEA6D7AE85C7956BBE8D63B6734A9D63399D6B4A955A31\
AE6B398D4A298542215229185229186B31186B3118E8BE9DDFAE95E8B695E8B69D
E8B695E8AE8DE8AE8DDFA685DFA67BDFA67BDFA67BDFA67BDF9D73D79D7BD79D73DF9D73D79D73\
D79D73CF956BCF956BCF956BCF956BD79D73D79D73CF956BCF956BCF956BC78563
C78563C7855AB67B5AC7855AB66B429D6339955A31AE6B429D6339AE6B42AE6B427B42217B4221\
8D4A29B66331C77B42C77B42C77B42C7855ACF9563D79D73CF956BD7AE85BE8D63
B6734AC7855AC7855ACF956B000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000F0F0E8F8F0F8E8DFD7D7B6A6D7AE85BE8D63B67B5AAE6B429D6B4A955A31955A31\
9D63398D4A297B39186B31186B39216B39217B3918DFAE95DFAE95DFAE8DDFAE8D
E8AE8DDFAE8DDFA685DFAE8DDFA685DFA685D79D7BDF9D73DF9D73CF956BCF956BCF956BC7856B\
CF8D63CF8D63C7856BCF956BCF956BC7856BCF956BCF956BCF956BC78563C7855A
C78563C7855AB6734ACF8D5AAE6B428D4A299D6B4A9D6B4A9D6339955A318542217B4221632910\
AE6331C77B42B66331C77B42B66B42C77B4ACF9563DFA673D79D7BDFAE85BE8D63
BE8D63CF9563BE8D63CF956BC7956B000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000F0F0F8F8F0F8F0F0E8E8C7B6D7AE8DC79D85B67B5AB67B5A9D6B4AAE63429D6339955A31\
955A316B39216B39216B31186B39216B39216B3921DFAE95DFAE8DDFAE95E8BEA6
E8AE95E8AE95E8A695E8AE95E8A695E8A695DFAE8DDFA685DFA685D79D7BCF8D63C7855ACF8D63\
C77B5AC7855AC7855AC7855AC7855ACF8D63CF8D63C7855AC7855AC7855AB67B5A
B67B5AB66B52B6734AC7855A9D63397B4A299D6339AE6B428D4A297B42217B39187B4A29955229\
AE5A31C77B42C77B42B6734AC77B42AE6B39CF9563D79D73D7AE85CF956BC7956B
C7855AC78D63C78D63BE8D63D7AE85D7AE85000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000F0F0F8F0F0F8F0E8DFDFC7B6D7AE85C7956BB67B5AB6734AAE6B429D6339B6734A9D4A31\
955A315221107342296B39216B39216B3118855231DFAE95E8C7AEF0C7AEF0C7AE
F0C7AEF0C7A6F0C7A6F0B69DF0B69DF0B69DE8AE9DE8AE95E8AE95DFAE8DDFA685D79D7BC77B5A\
C77B5AC77B4AC77B5AC77B5AB67B5AB67B5AB67B5AC7855AC77B5AB67B5AC77B4A
B6734AAE6B42AE6B42C77B4A8D4A298D4A319D63398D5A428542216B31186B3921AE6331854221\
9D6339C77B4AC77B42B6734AAE6B39B6734ACF8D5AD79D7BDFAE85DFAE8DD7AE85
C7956BC7956BB67B5AB66B42D7AE85D7AE85000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
F0F0F8F8F0F8F8F0F8E8CFBED7B6A6D79D73C78D63B67B5AAE7352955A319D6339955A319D6339\
8542216329107B42217342296B39216B3118B68563F0C7AEF0C7B6F8D7BEF8C7B6
F8C7B6F0C7AEF0C7AEF8C7B6F0C7AEF0C7AEF0B69DF0B69DE8B69DE8AE95DFAE8DDFA685DF9D7B\
CF956BC77B4AB6734AB67B5AC77B4AC77B4AC77B5AB66B52B67B5AC77B4AB67B5A
B6734AAE6B42956342B6734A955A319D6339B6734A8542217B39186B3118734A31B66B398D4221\
9D6339B66B42C77B4AB66B39AE6B39B6734AC7855ACF8D5ADFAE85DFAE8DD7AE85
D79D73C7956BB6734ABE8D63D79D73D79D73D79D73000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000F0F0F8
F8F0E8F8F0F8F8F0F8E8CFBECFAE95C7956BBE8D63AE7352AE6B42AE6B429D6339955A319D6339\
6329106B39217B4A296B39216B3921B68D73F0C7B6F8CFB6F8D7BEF8CFB6F8D7BE
F8C7B6F8D7BEF8C7B6F8CFB6F8C7B6F0C7AEF0C7A6F0C7AEF0B69DF0B69DE8AE95E8AE8DDFA685\
DFA67BD79D73CF956BB6734AB6734AB6734AB6734AC77B4AB6734AB67B5AB6734A
AE63429D6B4A855239854221B6734A955A31C7855A7B39186B3118522110632910AE6B39B66B42\
955229B66B42CF8D5AAE6B39BE8D63B6734AC7855AD79D73DFAE85E8BE95E8BEA6
D7AE8DB66B42BE8D63BE8D63CF956BC78D63D79D73D7AE8D000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000F8F8F8F8F8F8
F0F0F8F0E8E8E8D7C7E8C7AEC79D85C7956BB67B5A9D6B4A955A319D63399D6339955A31854A29\
6329107B4A297B4A296B3921E8C7B6F8CFB6F0CFAEF8CFB6F8D7BEF8D7BEF0D7C7
F8D7BEF0D7C7F8C7B6F8C7B6F8C7B6F8CFB6F0C7AEF0C7A6F0C7A6F0C7A6E8BE9DDFAE95DFAE8D\
E8AE8DDFA685D79D7BCF956BB66B52AE6B42AE6B42B6734AAE6B42B66B52AE6B42
AE63429D63398542217B4221C7855A854221CF8D639D63396B3921734A31522110854221C77B4A\
8D4221B66B42C77B4AB66B39C7855AC7855AC7855ACF9563D79D73E8BE9DE8BEA6
D7AE85C78D63B67B5ABE8D63C7956BC7956BD7AE85D7AE8DD7AE85000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000F8F8F8F8F0F8
F0F0E8F0E8E8DFCFBED7BEAEBE957BBE8D63B67B5AAE6B429563429D6339955A31955A316B3921\
6B31187B42216B3921A6856BF0CFB6F8CFB6F0C7AEF8CFB6F8CFB6F8D7BEF8D7BE
F8D7BEF8D7BEF0D7C7F8D7BEF8C7B6F8C7B6F0C7AEF0C7AEF0C7AEE8BEA6E8B69DE8BE9DE8B695\
E8AE8DDFAE95DFA685D79D7BC7856BCF956BAE6342AE6342AE6B429D6B4AAE6342
9563429D4A31854A31734229C77B4AAE7352B67B5AB6734A6B31185221107B42219D6339C77B4A\
C7855AC77B4AC77B4AC7855AAE6B42C78D63BE8D63C7956BD79D73D7AE85E8BE9D
E8BE95BE8D63B6734ABE8D63C77B4AC7956BD7B6A6E8BE95CFB6A6000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000F0F0E8F8F8F8F0F0F8
F0F0E8E8DFD7DFCFBECFAE95BE957BBE8D63B6734A9D6B4A855239955A318D4A29955A31522918\
6B39217342298D5A42F0C7AEF0C7B6F8CFB6F8CFB6F8CFB6F8CFB6F8D7BEF8C7B6
F8D7BEF8C7B6F8C7B6F8D7BEF8C7B6F8C7B6F0C7AEF0C7A6F0C7AEF0C7AEF0C7A6E8B69DE8B69D\
E8B695DFAE95DFAE8DDFA685D79D7BCF956BC7856B9D6339AE6342AE6342955A42
9D6339854A297B4A296329109D6B4AD79D7B8D4A29CF956B956342AE6B426B3118AE63318D4A31\
BE8D63AE6331C77B42C77B4ABE8D63B68563C7956BB67B5AD7AE85CF9563E8BEA6
F0CFB6BE8D63B6734ABE8D63C78D63C79D85D79D73D7AE85D7AE8DE8BE95000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000F8F8F8F8F8F8F8F0F8F0E8E8
F0E8E8E8CFBEDFCFBEC79D85C78D63AE7352B6734A956342955A31955A318552316B39216B3118\
854A29855A42F0C7B6F0C7AEF0CFAEF8CFB6F8CFB6F8CFB6F8C7B6F0CFAEF0C7AE
F0C7AEF0C7AEF0C7AEF0C7AEF0C7A6F0B69DF0B69DE8BEA6F0C7A6E8BE9DF0BE9DE8B69DE8B69D\
DFAE8DE8AE8DDFAE95DFAE8DDFA685D79D73CF956BCF8D639D63399D4A319D6339
8D4A318D4A296B39216B3921855239BE8D63B67B5A9D6B4AC79D858D4221B67B5A955A31AE6342\
B66B42C77B4AAE6B39C77B4ABE8D639D6339BE8D63BE8D63D79D73D79D73CFAE95
DFAE8DE8BE95BE8D63B66B42BE8D63C79D85C7956BD7AE85E8BE95E8D7CFF0F0E8000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000F8F0F8F8F8F8F8F8F8F0E8E8
E8D7CFE8CFBECFB6A6BE957BB67B5AAE7352956342955A31955A31955A315A31216B39216B3118\
6B3118F0C7B6F0C7B6F8CFB6F0CFAEF0C7AEF0C7AEF8C7B6F0C7AEF0BE9DE8B69D
E8AE95E8AE95DFAE8DDFAE8DDFAE8DDFA685DFAE8DDFAE8DDFAE8DDFAE8DE8B695E8B695E8B695\
E8B69DE8B695DFAE8DDFAE8DDFA685DF9D7BD79D7BD79D73CF8D63B66B52955A31
855231854A317342296B3921734A31956342CF956BBE8D63A67B5AD79D73C77B4AB67B5A854221\
AE6B39C7855AC77B42C77B4AAE6B39B67B5AB67B5AD79D7BC7956BD79D73D7AE85
E8BEA6E8C7B6BE8D63C7956BD79D7BC7956BC78D63CFAE95E8BE9DF8F0E8E8DFD7000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000F8F8F8F8F8F8F8F0F8F8F0F8F0E8E8
E8D7C7DFCFBED7AE8DC7956BB6734AB6734AAE63428D4A31955A318552316B31186B3921854A29\
E8C7B6F0CFB6F0CFB6F8CFB6F0CFAEF0C7AEF0C7AEF0C7A6E8BEA6E8AE95E8AE8D
DFA685DF9D7BE88D7BE88D7BE88D7BE88D7BE88D7BDFA685DF9D7BDFA685DFAE8DDFA685E8B695\
E8B695E8B69DDFAE95DFAE8DDFA685D7A685D79D7BCF956BCF956BC785638D5A42
8542297B4A296B39215229186B39218D634ACF956BAE7352955A31D7A685C77B4ACF9563B67B5A\
9D6339AE6B42CF8D5AC77B4AB6734ABE8D63B67B5AD79D73C7956BD7AE85D79D73
D7AE85E8C7AED7AE85D79D73C79D85C79D85D79D73D7AE8DE8BEA6F0E8DFF0E8DFF8F0E8000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000F8F0E8F8F8F8F8F0F8F0F0E8E8D7CF
E8CFBEDFCFC7C79D85B67B5AAE73529D6339AE6342855239854A296B39216B39217B39187B4A29\
F0C7B6F0C7B6F0C7AEF0C7AEF0C7AEF0C7AEF0C7A6F0B69DDF7363CF6B5ADF7B6B
DF7B6BDF8573DF8573DF8573DF8573DF8573CF6B5ACF6B5ACF6B5ACF6B5AD79D7BDFAE8DDFAE8D\
E8B695E8B695E8B695DFAE95DFAE8DDFA685D79D7BD79D7BCF956BC7856BC7855A
7B4A296B39216B31185221106B3118855239AE7352D79D7BB68563C7856BD7AE85CF9563D79D73\
C7956BC77B4AB6734AC7855ABE8D63AE6B39B6734ABE8D63D79D73BE8D63DFAE85
D7AE8DE8BE95E8BEA6C79D85D7AE85C7956BD79D73E8BE95DFCFBEE8D7CFF0E8E8F0F0E8000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000F8F8F8F8F8F8F8F0E8F8F8F8F0E8E8E8DFD7
E8D7C7D7AE8DC7956BA67B5A9D6B4A9D6339955A317B4A298552397342296B39217B4A29F0CFBE\
F0C7B6F0C7AEF0C7AEF0C7A6F0CFAEF0C7AEE88D7BDF8573DF8573DF8573F0C7B6
F0B69DE88D7BE88D7BE8A695F0B69DDF8573DF8573DF7B6BC7856BCF7363CF6B5AD79D7BDFAE8D\
DFAE95E8B695E8B69DDFAE95DFAE8DDFAE8DD7A685D79D7BCF956BDF8573C78563
B67B5A734A31522918522918522110855239522918D7A685DFAE8D9D6339D7AE8DB67B5ADFA67B\
D7AE85BE8D63C7855ACF9563AE6331C7855AB67B5ABE8D63C7956BCF956BD79D7B
D7AE8DE8BEA6E8C7B6BE957BB68563C7956BD79D73CFAE95F0E8DFF0E8DFF0F0E8F0F0E8F0E8DF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000F8F8F8F8F8F8F0F0F8F8F8F8E8D7D7DFCFBE
CFAE95C7956BB68563A67B5A855239955A318D4A31955A316329106B39216B3921A6856BF0CFB6\
F0CFB6F0CFB6F0C7AEF0C7A6F0C7A6F0C7A6DF7B6BDF8573DF8573DF7B6BDF7363
DF7363DF7363DF8573CF6B5ACF6B5AC75A4AC7634AC7634AE88D7BCF7363CF7363C75A4AD7A68D\
E8AE95E8B695E8B695E8B695E8B695DFAE8DD7A685D79D7BD79D7BCF956BCF956B
C7855AAE73526B39216B39213918106B31188D5A42B68563C7956BB67B5ABE8D63D7AE85C7855A\
DFAE85F0CFAEBE8D63B6734AC7855AC7855AAE6B42B67B5ACF9563C7956BD79D73
D79D73E8BEA6E8BEA6C79D85C7956BC79D85BE957BCFAE95F0E8DFF0E8E8F8F0E8F0E8E8F0E8E8\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000F8F0F8F8F8F8F8F0F8F8F0F8F8F0F8E8D7CFD7C7B6
D79D73C7956BAE73529563428D4A31955A31854A296B31187B42216B3118955A31F0CFBEF0CFBE\
F0CFB6F0C7AEF0C7AEF0C7A6E88D7BDF8573AE73529D4A31AE4A31BE5242AE7352
BE5242BE5242C75A4AB652399D4A319D31219D4229AE4A318D3121AE42319D4229854229955A42\
DF8573E8B695E8B695E8B695DFAE8DDFAE8DDFAE8DD79D7BD79D7BD79D73D79D7B
C78563B67B5A8D5A424A18083918106B3921734A31855A42BE8D63D7A685955A31D7A685B67B5A\
D79D7BE8BE9DF0CFAECF956BCF956BB66B39C7855AB67B5ABE8D63C78D63B67B5A
D7AE85E8BE95E8BEA6D7BEAED79D73D7AE85C79D85D7B6A6E8DFD7F0F0E8F0E8DFF0F0E8F8F0F8\
F0F0E8000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000F8F0F8F8F0F8F8F0E8F8F0F8F0E8E8E8D7CFD7BEAE
BE957BB67B5A9563428D4A318D5A428D4A297B4A297B4A297B4A29854229F0CFBEF0CFBEF0C7B6\
F0CFB6F8CFB6F0C7AEF0C7A6F0B69DF0C7A6E88D7BCF7363CF6B5AC7634ACF6B5A
C7634ACF6B5ADF7B6BC7634AC7634AC7634AC7634AC7634AC7634AD79D73D7A685D7A68DDFAE8D\
DFAE8DE8B695E8B695E8AE8DE8AE8DDFAE8DE8AE8DDFA685D79D7BD79D7BD79D73
CF956BC785639D73525A39293918103918105A3929855A429D7352D79D7BC7956B9D6B4AD79D73\
B67B5AE8BE9DE8BE9DF0CFB6AE7352C7855AC7855AB67B5ABE8D63BE8D63B67B5A
D7AE85D7AE85E8BEA6E8C7AEC7956BD7AE85D79D73E8D7C7F0E8E8F0E8E8F0E8DFF0E8DFF8F0F8\
F8F0F8000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000F8F0E8F8F8F8F8F0F8F0F0E8F8F0E8F0E8DFDFCFC7D7AE8D
B685639D6B4A9D6B4A8D5A428D4A29854A297342297B4A29854221855231F0CFB6F0C7AEF0CFB6\
F0CFAEF0C7AEF0CFAEF0C7A6F0CFAEF8CFB6F8CFB6F8D7BEF0D7C7F0C7B6F0C7AE
F8D7BEF0C7AEF0C7A6F8CFB6F8D7BEF0C7B6F0C7AEE8BEA6E8B69DE8BEA6E8B69DE8B695E8B695\
E8B69DE8B695E8B69DE8B695E8AE95DFAE8DDFAE8DDFA685DFA685D79D7BD79D73
CF956BCF956BB67B5A855231423129291008855A42734A31855A429D7352BE8D639D6339C7855A\
AE6B42C7855AE8BE9DE8BE9DD79D73CF956BBE8D63B6734AB6734ABE8D63CF956B
D79D73CF956BE8BEA6E8C7AEC79D85C79D85C78D63E8DFD7F0E8DFF0E8DFF0E8E8F0E8DFF8F8F8\
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000F8F0F8F8F0E8F8F0F8F8F0F8F0E8E8DFC7B6E8BE9DC79D85
AE7352956342855231855231854A316B31187B4A297B4A297B4221D7B6A6F0CFB6F0CFB6F0CFB6\
F8C7B6F8CFB6F0C7AEF8CFB6F0C7AEF8CFB6F8CFB6F8D7BEF8CFB6F8D7BEF8CFB6
F8D7BEF0C7A6F0C7AEF0C7AEF0C7AEE8B69DE8B69DE8B69DE8B69DE8BE9DE8B69DE8BE9DF0C7A6\
E8B69DE8B695E8BE9DE8B69DE8AE95E8AE95DFAE8DDFA685DFA685D79D7BDF8573
CF956BCF956BB67B5A955A42522110422118734A31855231A6856B9D7352C79D859D6339955A31\
C78D63BE8D63DFAE95E8BE9DF0C7A6D7AE85C7855AC7855AC78D63B6734AB67B5A
B67B5ACF956BE8BEA6E8C7AED79D73D7AE8DC7956BF0E8DFF0E8E8E8DFD7F0E8DFF8F0E8F8F8F8\
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000F8F0F8F8F0F8F8F0E8F8F0F8F8F0F8DFCFC7C79D85B67B5A
9D63399D6B4A854A29854A316B39217B4A297B4A297B4A297B4A29F0CFB6F0CFB6F0C7B6F0CFB6\
F8CFB6F8C7B6F8C7B6F8CFB6F0CFB6F8CFB6F8CFB6F8CFB6F8CFB6F8CFB6F8CFB6
F0CFB6F0C7AEF0C7A6F0C7A6F0C7A6E8B69DE8BE9DF0BE9DE8B69DE8BEA6E8B69DF0C7A6E8B69D\
F0C7A6E8B69DE8B69DE8AE95E8AE95E8B695DFAE8DDFA685DF9D7BDFA685D79D73
CF956BCF956BC785639D6B4A7342295A39293918107352428552399563429D6339AE73529D6339\
B67B5AA67B5ACF956BE8BE95E8BE95CF956BD79D73C7855ABE8D63B6734ABE8D63
B6734AD79D73D7AE85E8BEA6CFAE95C7956BD79D7BE8D7CFF0E8DFF0E8DFE8D7C7F8F8F8F8F0F8\
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F8F8F8F8F8F8F8F0F8F8F0F8F8F0E8DFCFC7D7C7B6BE957BB6734A
9D6B4A854A298D5A426B39217B4A296B31187B4A29854A296B3921F0CFB6F0C7B6F0C7B6F0CFB6\
F8CFB6F8CFB6F8CFB6F8C7B6F8CFB6F8CFB6F8CFB6F8CFB6F0CFB6F8CFB6F8CFB6
F0C7A6F0C7A6E8B69DF0C7A6E8B69DE8AE8DE8B695E8BE9DE8B69DF0B69DF0BE9DF0C7A6F0B69D\
F0B69DF0C7AEF0C7A6E8B69DE8B69DE8AE95E8AE8DDFA685DFA685D79D7BD79D73
DF8573C7856BC78563B6734A734A31522110522918734A318D634A956B529D7352B685639D6B4A\
8D5A42956342BE957BC78D63DFA673F0C7A6D7AE85C77B4AC78D639D6B4AC7956B
BE8D63D79D7BD79D73E8BEA6CFAE95BE8D63E8C7B6E8D7C7F0E8E8F0E8E8F0E8E8F8F0F8F8F8F8\
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F8F0F8F8F0F8F8F8F8F8F8F8F0E8E8DFC7B6C7A695BE957B9D6B4A
9D63399563428542297B4A297B4A29734A317B4A296B3921B68563E8C7B6F0C7B6F0C7B6F8CFB6\
F8CFB6F8CFB6F8CFB6F8D7BEF8CFB6F0CFB6F8CFB6F8CFB6F8CFB6F0C7AEF0C7AE
E8B69DDFAE8DDFA685E8AE95DFAE95DFA685DFAE8DE8AE95E8B695E8B69DF0BE9DE8BEA6F0C7A6\
F0C7AEF0C7AEF0B69DF0B69DE8B69DE8AE95DFAE8DDFA685DFA685D79D7BD79D7B
D79D73CF956BC77B5AB66B528D5A425A39296B39215A4239855A428552399D7352956342B6734A\
8552319D6339855239D7AE8DE8BE95D79D73DFA67BC78D63C7956BA67B5AB67B5A
BE8D63C79D85D79D73E8BE9DD7B6A6C7956BE8DFD7E8BEA6F8F0F8F0E8E8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F8F8F8F8F0E8F8F8F8F8F0F8F8F0F8E8BE9DBE957BAE7352956342
8D4A318D4A317B4A296B39216B39217B4A297B4A296B3118E8C7B6F0C7B6F0C7B6F8C7B6F8CFB6\
F8CFB6F8CFB6F8CFB6F8CFB6F8CFB6F0CFAEF8CFB6F8CFB6F8CFB6F0C7AEF0B69D
E8AE9DE8B695DF9D7BDFA685DFA685D79D7BD7A685DFAE8DDFAE8DE8B695E8B69DF0BE9DF0B69D\
F0C7A6F0C7A6F0C7A6F0B69DF0C7A6F0B695E8AE95DFAE8DDFA685D79D7BD79D7B
D79D73C7856BC78563B67B5A955A425A3929291008422921734A318552319D6B4A855239B6734A\
9D63399D63397B4A29D7A685C7855AD79D73F0CFAEC7956BC78D63C78D63B67B5A
B68D73C7855AC7956BE8BE9DD7BEAED7BEAEDFCFBEE8D7CFE8D7CFE8CFC7F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F0E8E8D7AE8DB68563956342855231
8D4A316B39217B4A297342297B4A298542296B31185A3121F0C7B6E8C7AEF0C7AEF0C7AEF8CFB6\
F8C7B6F8D7BEF8D7BEF8CFB6F8CFB6F8CFB6F8C7B6F0D7C7DF9D7BDF7B6BF0C7AE
F0C7AEF0B69DE8A695B66342B66342C7856BDF9D7BB67B5AD79D73DFAE8DE8B69DF0C7A6F0C7A6\
F0C7AEF0C7AEF0C7AEF0C7A6F0B69DE8B69DE8AE95E8AE8DDFA685DFA685D79D7B
D79D73CF956BC78563B66B52AE63427342293918104229215A3121734A31855239855A429D6B4A\
9D6B4A8552319D6B4A8D5A42BE8D63DFAE85D79D73DFAE85C7855ABE8D639D6339
B67B5AB67B5AD79D73E8BE95D7BEAEF0E8E8CFAE95F0E8E8D7B6A6F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8E8DFDFC7956BAE73529563429D6339
7B4A297B4A296B39217B42217B4A296B39215A3121855239F0C7B6F0C7AEF0CFB6F8CFB6F8D7BE\
F8CFB6F8C7B6F8D7BEF8C7B6F8CFB6F0CFAEF8CFB6F8D7BEF0CFB6F0C7B6F8C7B6
F8C7B6F0C7AEE8B695DFAE8DDFAE95E8AE8DE8B695DFA685CF8D63D79D7BE8B69DF0C7AEF0C7AE\
F0C7AEF0C7AEF0C7AEF0B69DF0C7A6F0C7A6F0B695E8AE8DDFAE8DDFA685D79D7B
CF956BCF956BC78563C77B5A9D73528D5A422910083918104229215A42397352428D5A42855239\
9D7352855231955A31522918D7AE85CF8D63CF9563E8BE9DB67B5ABE8D639D6B4A
AE7352BE8D63C7956BCFAE95DFC7B6DFC7B6C7AE9DD7B6A6F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F0F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F8F8F8F8F0E8F8F8F8F8F8F8F8F8F8E8D7CFBE8D63956342955A426B3921
734A31854A317342297B4A29854A31632910632910A67B63E8C7AEF8C7B6F8C7B6F8C7B6F0D7C7\
F8D7BEF8D7BEF8D7BEF0D7C7F8CFB6F8CFB6F8C7B6F8D7BEF0C7B6F0D7C7F0D7C7
F0D7C7F8C7B6F0C7A6E8B695E8AE9DE8AE9DDFAE95DFAE8DDFA685DFA685F0B69DF0C7AEF0C7AE\
F8C7B6F0C7AEF0C7AEF0C7AEF0B69DF0B69DF0B69DE8B695E8AE8DDFAE8DDF9D7B
DF8573DF8573C78563B67B5AAE6B42956342291008422118391810734A31855239956342734229\
9D6B4A855231955A315A3121C7956BBE8D63D7AE85E8BE9DB67B5ABE8D63AE7352
B67B5AB68563BE957BD7AE8DDFC7B6DFC7B6D7BEAEDFCFBEF8F8F8F8F8F8F8F0F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F8F8F8F8F0F8F8F0F8F8F8F8F8F0F8E8CFC7AE73528D5A42955A31855231
7B4A297B4A29854A298D4A317B42215229185A3929E8C7B6F0C7B6F8CFB6F8CFB6F8D7BEF8D7BE\
F8D7BEF0D7C7F8D7BEF0D7C7F8D7BEF8C7B6F0C7AEF8D7BEF8D7BEF0D7C7F8DFD7
F0D7C7F8C7B6F0C7AEE8BEA6E8AE95E8A695DFAE95DFAE8DDFA685E8AE95F0B69DF0C7AEF0C7AE\
F0CFAEF0C7AEF8C7B6F0C7AEF0C7A6F0C7A6F0B69DF0B69DE8AE95E8AE8DDFA685
DF9D7BCF956BC7856BB67B5AAE6B42955A315229181808084221187342295229189D6339855231\
9D6B4A7B42218552318D5A42AE7352C78D63DFA67BDFA67BD79D73B67B5ABE8D63
AE7352B67B5AB67B5ACFAE95E8C7AED7B6A6E8CFC7F8F0F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F0F8F8F0F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F8F0F8F8F8F8F8F8F8F8F8F8F8F0E8C7956B9563429563426B3921734229
7342297B4A29854A317B4A29422118632910422118F0C7AEF8C7B6F0CFBEF8C7B6F8D7BEF8D7BE\
F0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8CFB6F8CFB6F8C7B6F0D7C7F0D7C7
F0D7C7F8CFB6F0C7AEE8AE95D7A68DDFA685DFAE8DD7A68DDFAE95E8B69DF0C7AEF0C7B6F0C7B6\
F0CFB6F8CFB6F0C7AEF0C7AEF0C7A6F0C7AEF0C7A6F0B69DE8AE95E8AE8DDFAE8D
DFA685D79D73C7856BB67B5AAE7352AE6342734A312110083918105A39297B5A428552398D5A42\
9563427B4A29855231734A319D7352C7855ACF956BDFAE8DE8BEA6B6734AB67B5A
9D7352B67B5AC7956BE8BE9DE8C7AEC79D85DFCFBEF8F8F8F8F0F8F8F8F8F8F0F8F8F0F8F8F0F8\
F8F8F8F8F8F8F8F8F8F8F0F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F0F8F8F8F8F8F8F8F8F8F8F0F0F8B6856B956342854A296B3921855239
854A31854A317B4A293918105229185221105A3929F0C7AEF8CFB6F8D7BEF0D7C7F0D7C7F0D7C7\
F0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F8D7BEF8D7BEF8C7B6F0CFBEF8C7B6F8D7BE
F8C7B6F0C7B6F0B69DE8B69DD7A68DDFAE8DDFAE95DFAE95E8B69DF0C7AEF0C7AEF0C7AEF0C7B6\
F8C7B6F8CFB6F0C7B6F8C7B6F0C7AEF0C7A6F0C7AEF0B69DF0B69DE8AE95E8AE8D
D7A685DFA685CF956BC78563AE73529D6B4A8D4A31291008423129522918734229734A31855231\
8552319D6339855231855231A67B5ABE8D63CF9563DFAE8DF0CFAEB67B5AB6734A
9D6B4AA67B5AB68563CFAE95DFC7B6DFCFBEF8F0F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F0F8F8F8F8F8F0F8F8F0F8F8F0F8F8F0F8B6856B955A317B4A297B4A29855239
734A317B4A29854A31522918422118522918CFAE95F0CFB6F0CFB6F8D7BEF0D7C7F0D7C7F0D7C7\
F0D7C7F8DFCFF8DFCFF8DFCFF0D7C7F8D7BEF8D7BEF8D7BEF8CFB6F0C7B6F8D7BE
F8D7BEF0C7AEF0B69DDFAE95DFAE95DFAE8DE8B695E8B69DE8BEA6F0C7AEF0CFB6F0C7B6F8C7B6\
F8C7B6F8D7BEF0CFBEF8C7B6F0C7B6F0C7AEF0C7AEF0B69DE8B69DE8B69DDFAE95
DFA685D79D7BD79D73C78563B66B529D6B4A9563424221182110085A31215229188552398D5A42\
7B4A29955A319D63398552319D7352C79D85D79D73DFAE85F0CFAEAE7352C78D63
8D5A42B68563AE7352E8BE95E8CFBEDFCFBEF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F0F8F8F0F8F8F8F8DFC7C79D73528D5A42734229855231855231
854A317B4A29522918422118391810F0B69DF0CFBEF8C7B6F8D7BEF8DFCFF0D7C7F0D7C7F8DFCF\
F0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F8D7BEF8CFB6F8D7BE
F8D7BEF8C7B6F0C7AEE8B69DDFAE95E8B695E8B695E8B69DE8BEA6F0C7B6F0C7B6F0D7C7F8D7BE\
F8C7B6F0D7C7F8C7B6F8D7BEF0CFBEF0CFBEF0C7B6F0C7AEE8C7AEF0B69DE8B695
DFAE8DD7A685D79D7BD79D73B67B5A9D6B4A9D63397342296329106B3921734A31734A31956342\
8552319D63398D5A428D4A319D7352D7A685D79D73D7AE85E8BEA6BE8D63B6734A
855231A67B5AB67B5ADFAE8DE8D7C7F0F0E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F89D7352955A318552315A31217B5A42734A31
734A31854A315229186B39215A3929F0C7AEF0C7B6F0D7C7F8D7BEF0D7C7F0D7C7F8DFCFF8DFCF\
F0D7C7F0D7C7F8D7BEF8DFCFF0D7C7F0D7C7F0D7C7F0D7C7F8D7BEF0CFBEF8D7BE
F8D7BEF8D7BEF8C7B6E8B69DDFAE95E8B69DE8BE9DE8BEA6E8BEA6E8C7AEF0CFB6F8D7BEF0CFBE\
F8D7BEF0D7C7F8D7BEF8C7B6F0CFBEF0CFBEF0CFBEF0C7B6F0C7AEE8BEA6E8B69D
DFAE95DFAE8DD79D7BD79D73C77B5AB66B52955A42734A316B39216B39216B3921855239855231\
9D63399563428D5A4295735AB6856BD79D7BD79D73D79D73D7AE85C78D63AE6B39
854A29A67B5ABE957BD7AE8DE8DFD7F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F8F8F8F0F8F8F8F8AE73529D6339734A316B39218D5A42855239
7B4A297342296B3921522918A68573F8C7B6F0CFBEF0D7C7F0D7C7F0D7C7F8DFCFF8DFCFF0D7C7\
F8D7BEF0D7C7F8D7BEF8D7BEF0D7C7F8DFCFF8DFCFF0D7C7F0D7C7F8D7BEF8D7BE
F0D7C7F8C7B6F8C7B6E8B69DDFAE95DFAE95E8BE9DE8BEA6F0C7AEF0C7AEF0CFBEF0CFBEF0CFBE\
F0D7C7F0D7C7F8C7B6F8C7B6F8D7BEF8CFB6F0CFB6F0C7B6F0C7AEF0C7AEE8BEA6
DFAE95DFAE8DD7A685D79D73C78563B66B52955A428D4A315A31215A31216B3921734A31854A31\
9563429D6339956342955A31D79D73D79D73D79D73D79D73D7A685D7AE85AE6B42
AE6B42AE7352B68563DFAE85F0F0E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F8F8F8F8F8F8F0F89D73529D7352855239734A31734229855239
854A315A3121734229855239F0C7B6F8CFB6F0CFBEF0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F0D7C7\
F0D7C7F8D7BEF0D7C7F0CFBEF0D7C7F0D7C7F0D7C7F0D7C7F8D7BEF8D7BEF0C7B6
F0D7C7F0D7C7F8D7BEE8BEA6E8AE95DFAE95E8B69DE8BEA6E8BEA6E8C7AEF0C7B6F0CFBEF0CFBE\
F0CFBEF0D7C7F0CFBEF8D7BEF0CFBEF0C7B6F0C7B6F0C7AEF0C7B6E8C7AEE8BEA6
E8BEA6DFAE95D7A685D79D7BCF956BB67B5A9D6B4A8552397342296B31186B39216B3921855239\
955A318D634A855239854A29D7AE8DD79D73C7956BD79D7BC79D85DFAE8D955A31
AE7352AE7352A6856BD7AE85F8F0E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F0F8F8F8F8BEAEAE955A318D634A8552318D5A428552318D4A31
6B39215A3929734229E8C7AEF8D7BEF0C7B6F8D7BEF0D7C7F0D7C7F0D7C7F0D7C7F8DFCFF0D7C7\
F0D7C7F8D7BEF0CFBEF0C7B6F0C7B6F0CFBEF0CFBEF8D7BEF8D7BEF8C7B6F8CFB6
F0D7C7F0D7C7F8D7BEF0C7AEE8AE95DFAE8DDFAE95DFAE9DE8BE9DDFAE9DE8C7B6E8CFBEF0C7B6\
F0D7C7F0CFBEF0CFBEF0CFBEF0C7B6E8C7B6F0C7B6F0C7AEF0C7AEF0C7AEE8BEA6
E8BEA6DFAE9DDFAE8DD7A685DF8573C785639D6B4A955A31734A315229186B39216B3921734A31\
9D6B4A8D5A428D5A428D5A42C79D85C7956BD79D73D79D739D6B4AE8BE95854221
9D6B4ABE8D63C7956BCFAE95F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F0F8F8F8F8A67B6BB68D739D6B4A734A319D6B4A734A318D4A31
5A3121734A317B4A29E8C7AEF8C7B6E8C7AEF0D7C7F0D7C7F8DFCFF0D7C7F0D7C7F8D7BEF0D7C7\
F0CFBEF0CFBEF0B69DE8C7AEF0C7AEF0C7AEF0C7B6F0CFBEF8D7BEF0CFB6F8CFB6
F8D7BEF0D7C7F8D7BEF0C7AEE8A695DFAE8DD7A68DDFAE95DFAE95E8BEA6E8C7B6F0C7B6F0CFBE\
E8C7AEE8C7AEE8BEA6E8C7AEE8C7AEE8C7AEE8C7AEF0C7AEF0C7B6E8C7AEE8C7AE
D7B6A6E8BE9DDFAE8DD7A685D79D73C78563AE7352955A31854A315229185221106B3921734A31\
8D5A429D63398D5A428D5A42C79D85CF956BCF956BD79D73854A31DFAE85955A42
8D5A42B6856BD7A685E8C7AEF8F8F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F0F8F8F0F8F8F8F8F8F8F88D4A29B6957B8D5A42956B52855A428D5A42734A31
5229189D6339E8AE8DF0C7AEE8AE95F0C7B6F8D7BEF0D7C7F0D7C7F0D7C7F0D7C7F0CFBEE8CFBE\
F0C7B6F0C7B6F0C7AEDFAE9DDFAE95E8BEA6E8C7AEF0C7B6F0CFBEE8C7AEF0C7B6
F0D7C7F0D7C7F8D7BEF0B69DDFAE95DF9D7BD7AE8DD7A68DCFAE95D7B6A6E8C7AEE8C7B6E8BEA6\
E8BEA6D7B6A6E8AE9DDFAE8DDFAE8DD7A68DDFAE9DDFAE9DE8BEA6E8BEA6E8BEA6
E8BE9DE8BE9DDFAE95D7A685CF956BC7856BB66B529D6B4A8552397342293918106329106B3921\
8D5A428D5A429D6B4A855239BE957BD79D7BB67B5ABE8D63854A29E8BE959D6B4A
8D4A31C7956BD7AE85E8D7C7F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F8F8FFFFFF9D6B4AA67B638552398D5A42855239955A42522110
855231854A31F8C7B6CF956BDFA685F0CFB6F8D7BEF0D7C7F0D7C7F0D7C7F0CFBEE8C7B6DFAE9D\
BE957BB68D73D7A68DCFA695BE957BDFAE9DDFAE9DF0CFBEF0CFBEF0C7B6F0C7B6
F8D7BEF8D7BEF8D7BEF0C7AEDFAE95D79D7BC79D85D79D7BE8BE9DDFAE9DE8C7B6E8AE9DDFAE9D\
C7A69DBE9D8DB6856BB68D73C79D85C79D85C79D85CFA695E8BE9DE8BEA6DFAE9D
DFAE9DDFAE9DDFAE8DD7A685C79D85C7856BB67B5A955A42855239734A316B39215A31215A3121\
8552398552318D634A8D5A42B6856BBE8D63B67B5AB67B5A955A31E8BE95955A31
8D4A31C79D85D79D73E8D7CFFFFFFFF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F8F8BE9D95A67B5A9D7352734A31855239734A31955A425A3121
955A31F0B695F0B69DE88D7BD7A68DF0CFB6F0CFBEF0D7C7F0D7C7F0C7B6E8AE9DB68563BE8D63\
DFAE9DBEAEAE736B6373736BA68573C79D85DF8573DF8573F0C7B6F0C7B6E8C7AE
F8D7BEF8D7BEF8D7BEF0C7A6E8B69DD79D7BD7A685BE957BD7A6859D4A31C75A4AC7856BD7A68D\
DFC7C7957B73735A4AA67B6BA67B63A67B5AA67B63B6856BD7A68DDFAE95DFAE95
DFAE9DDFAE9DD7A68DD7A68DCF956BC7856BB66B529D6B4A8D5A42734A31855239522918522918\
8552398552398D5A429D6B4AB68563BE957BB6734AB67B5A955229E8BE9D9D6339
9D7352D7AE85D7AE85F0E8E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8F8F8F8B6856BBE9D8D9D73528D634A5A3121855239955A426B3118
522918F8C7B6E8AE8DE8A695DFAE95F0CFBEF8D7BEF0CFBEE8C7AEE8AE9DB6856BC7856BD7BEB6\
E8D7CF7B7373736B63635A52857B73A67B6BC79D85BE957BE8AE9DDFAE95F0C7A6
F8D7BEF8D7BEF0CFB6F0C7AEE8B69DDFA685BE957BB6856BC7856BC79D85AE4231DFC7C7F0E8E8\
8D736395735A7B6B5A958D856B635ABE9D959D73528D6B52B6856BD7A685D7A685
DFAE95DFAE8DD7A68DD79D7BD79D73B6856BAE73529D6B4A855231734A315A3121291008422118\
8552398D5A427342299D6B4AB6856BB685639D6B4AA67B5AAE6342DFAE8D854A29
BE957BD7AE8DD7AE8DF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F0F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8FFFFFFF8F0F8A6856B8552317B4A295A3121855239855239855239
955A42F8C7B6DFA685E88D7BDFAE95E8C7B6F0CFB6F0C7AEDFAE9DBE957B95735A5A3929B6958D\
C7B6B6957B6BB6B6BE21181885736B5A4A4295735AB6856BBE957BE8B69DF0CFAE
F8D7BEF8D7BEF8CFB6F0C7AEE8BE9DE8B695BE957BB68D739D7352B68D73BE957B9D6B4ACFC7BE\
635A52B6BECF21181873736B635A52BE9D95423129735242A67B63B68D73BE957B
D7A685D7A68DD7A685BE957BC7956BC78563AE7352955A42855239854A31422118391810422118\
522918855239734A31AE73529D7352A67B5AA67B5AB67B5AAE6342D7AE85854A29
BE8D63D79D7BDFC7B6F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8B6957BD7C7C7A68D7395735A7B5242734A31855239855239955A42
CF7363F0B69DE88D7BD79D7BDFAE8DF0C7B6F0CFB6E8B69DCFA695C7856B734A31856352856352\
5A42394229215A39298552398D6B52856352A67B63BE957BE8AE95F0BE9DF8CFB6
F8CFB6F8D7BEF8CFB6F0C7AEF0BE9DE8B69DDFA685BE957BC7856BAE735295735AA68D85A68D85\
5A39295229185A39295A3929734A315A4239735A4A7B5242A67B63B68563B6856B
CF956BD79D7BD79D7BBE957BB6856BB67B5A955A428D5A428D5A42734A316B39214221185A3929\
6B39216B3921734A319D6B4AAE73529D6B4A9D6339B67B5AAE7352D7AE85956342
BE8D63D79D73F0E8DFF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F8F8F8F8F8F8AE7352BE9D95B69D8D8D5A42734A318D634A855239734A318D4A31
C78563E8A695D79D7BD79D7BDFAE8DF0C7B6E8C7B6E8C7AEE8BEA6DFAE95BE957BB66B528D634A\
7B52427B52427B524285523995735AC7856BD7A685E8B69DF0C7AEF0C7AEF8CFB6
F8D7BEF8D7BEF8CFB6F0C7AEF0C7AEF0C7A6E8B695DFA685D79D7BBE957BB6856B85634AA67B63\
A685739D7B6B856352634A425A4239734A319D7352BE8D63B68D73C7856BCF956B
D79D7BD79D7BBE957BCF956BBE8D63B66B52955A428D5A428552398552397342295229185A3929\
5A31215A31217342299D7352B67B5A9D73529D6339B67B5ABE8D63D7AE859D6B4A
BE8D63D7A685F0F0E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F8F8F8F0E8DFA68D7B956B52734A31734229734A31734A316B39219D6B4A
C78563CF956BC79D85BE957BD7A68DE8C7B6F0CFB6F0CFB6F8D7BEF0CFBEF0C7AEF0C7B6E8BEA6\
E8B69DE8AE9DE8B69DE8BEA6E8B69DD79D7BDFA685E8AE95F0C7A6F8D7BEF8CFB6
F0D7C7F0D7C7F8D7BEF8CFB6F0CFAEF0C7AEE8B695D79D73DF9D7BBE957BD7A685D7A68DD7A685\
BE957BBE957BBE957BCF956BD79D7BD7A685D7A685DFAE8DE8AE8DDFAE95D7A68D
D7A685D79D7BCF956BC7856BBE8D63B67B5A955A428D634A8552396B39216B39215229185A3929\
734A317342296B39219D6B4ABE8D639D6B4A9D6339C7855ABE957BDFAE959D7352
BE957BF0DFCFFFFFFFF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000FFFFFFFFFFFF7342298D5A425A31216B39216B39219563425A31219D4A31
B66B52DF8573CF956BB68D73D7A685F0CFB6E8BEA6F8CFB6F8D7BEF8D7BEF0D7C7F8D7BEF8D7BE\
F0D7C7E8A695C7856BA67B639D7352B66B52E8B69DF0C7A6F8D7BEF8D7BEF8D7BE
F8DFCFF0D7C7F8D7BEF0D7C7F8CFB6F8D7BEF0BE9DE8AE95C7856BAE63429D7352B66B52B68D73\
E8BEA6E8C7AEF0C7AEE8C7AEE8BEA6E8BEA6E8B69DE8B69DE8B69DDFAE95D7A685
C7956BB68563CF956BBE8D63B67B5AAE73529D6B4A8D5A42855231855239632910522918522918\
5A3929522110734A318D5A42AE73529D6B4A956342C78D63C7956BE8BE9DA67B5A
C79D85F0E8E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F0E8E8FFFFFF6B39217B4A295A31216B3921734A31855239734A319D6339
B66342B67B5ABE8D63C7856BC79D85F0C7AEDFC7B6E8BE9DF0C7B6F8D7BEF0D7C7F0D7C7F8C7B6\
B6856BA67B6395735AB66B52D7A685F0C7A6F8CFB6F8CFB6F8D7BEF8DFCFF8D7BE
F8DFCFF0D7C7F8D7BEF8D7BEF8D7BEF8CFB6F8CFB6F0C7A6E8AE95BE8D63955A42855239955A42\
B66B52DFA685E8AE9DE8C7AEF0C7AEF0C7AEF0B69DE8BEA6DFAE95DFA685BE957B
A67B5ACF956BB68D73B6856BAE73529D6B4A9D6B4A8D5A426B39216B39215229185A3121522918\
522110735242855A42956B52A67B5A9D7352955A31BE8D63BE8D63D7AE8DBE957B
C79D85F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000BEAEAEFFFFFF855231734229734A31734A315A31218552397B4A29955A31
955A42955A42A67B63B6856BC79D85E8C7B6F0CFBEBE957BC79D85D7A685D79D7BDF8573B66B52\
AE7352D79D7BF8CFB6F8D7BEF8D7BEF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCF
F0D7C7F0D7C7F0D7C7F0D7C7F8D7BEF0D7C7F8CFB6F8CFB6F8CFB6F0CFAEE8B69DD7A685B68D73\
95735A8D5A429D7352AE6342CF6B5AB68D73C7856BB68563A67B63A67B5AB6856B
BE957BBE957BDF8573BE8D63AE73529D6B4A9D6B4A8552399D6B4A4221187342297342296B3921\
52291842292185634A9D6B4AAE73529D6B4A956342BE8D63D79D73B6856BAE6B42
DFCFBEF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000C7A6959D7352734A31734A3185634A855239734A31734A31734A31855239
955A318D634A9D7352A67B5AD7A685E8C7B6F0CFB6F0CFB6F0C7AED7A685BE9D8DDF8573DFAE9D\
F0D7C7F8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFD7
F0D7C7F0D7C7F8DFCFF8DFCFF8DFCFF8D7BEF8D7BEF0D7C7F8D7BEF8CFB6F8C7B6F0C7AEF0C7AE\
F0C7AEE8C7AEE8C7AEC79D85A67B63AE7352A67B63A67B63BE957BC79D85BE957B
CF956BD79D73CF956BBE8D63AE73529D7352AE73528552396B3921734A316B39215A3121391810\
3918104221188D634A95735A8D5A42A67B5AAE6342C7956BC79D859D6B4ABE8D63
F0E8E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000009D6B4A7B5A42734A319D7B6B8D6B527B5A42855239734A318D5A42
8D5A428D634AAE7352AE7352D79D7BF0C7AEF0C7B6F0CFB6F0CFB6F8D7BEF8D7BEF0D7C7F0D7C7\
F0D7C7F8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFD7F8DFCFF8DFCF
F0D7C7F8DFCFF8DFCFF8DFCFF0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F8D7BEF0CFB6F0CFB6F8CFB6\
F0C7AEF0C7AEF0C7AEE8BEA6E8C7AEE8C7AEE8B69DDFAE95DFAE8DD7A68DD79D7B
D7A685BE957BB68D73B67B5AAE7352A67B5AAE73529D6B4A734A316B3921522110391810391810\
391810422118B68D738D634A8D5A42D79D739D6B4AB67B5AD7AE859D6B4AC79D85
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000854A29735242855A42A68D73956B52855239855A427B5A42855A42
855A428D5A42A67B5A9D7352D79D7BE8C7AEF0CFB6F0CFB6F0CFBEF8D7BEF8D7BEF0D7C7F8DFCF\
F8DFCFF0D7C7F8D7BEF8DFCFF8DFCFF8DFCFF8D7BEF8DFCFF8DFCFF8DFCFF8DFCF
F8D7BEF0D7C7F8DFCFF0D7C7F0D7C7F8DFCFF0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF8C7B6F8CFB6\
F0C7B6F0C7AEE8C7AEE8BEA6F0C7AEE8B69DE8B69DDFAE95D7A685D7A685D79D7B
D79D7BBE957BC7956BBE8D63B66B52AE7352AE73528D5A429D6B4A734229522918522918422118\
5A3121522110BE957BA67B5A8D5A42BE957BAE73529D6B4AD7AE8D9D6B4AD7BEAE
FFFFFFF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000008552398D6B528D634A9D73528D634A8D6B528D634A855A42855239
8552318552319D6B4A9D7352C7856BE8BE9DF0C7B6F0CFB6F0CFB6F0CFBEF8D7BEF8D7BEF0D7C7\
F8DFCFF8DFCFF8D7BEF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8DFCF
F8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF0D7C7F0D7C7F0D7C7F8CFB6F8CFB6F8CFB6F8CFB6F8CFB6\
F0C7AEF0C7A6E8C7AEF0C7AEE8BEA6E8BE9DE8B695DFAE95DFAE8DD7A68DD7A685
D79D7BD79D73CF956BB67B5AAE7352B67B5A9D73529D6B4A734A315A31216B39215A3121391810\
391810422118C7956BA67B639D6B4AD79D73B6734A8D634ABE957B9D6B4AF8F0F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000085523985523985523985634A8D634A855239855A42855239
855A42855239A67B5AB67B5AC7956BE8B69DE8BEA6F0CFAEF0CFBEF8CFB6F8D7BEF8D7BEF0D7C7\
F0D7C7F8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF8D7BEF8D7BEF8DFCFF8DFCFF8DFCF
F8DFCFF8DFCFF0D7C7F0D7C7F0D7C7F0D7C7F0D7C7F8C7B6F8CFB6F8CFB6F8CFB6F0CFAEF0C7AE\
F0C7AEF0C7AEF0B69DE8BEA6E8BE9DE8BEA6E8B69DDFAE8DDFAE95DFA685D7A685
BE957BCF956BC7856BBE8D63B67B5AAE73529D6B4A855239734A315A3929734229422118391810\
3918105A31219D7352D79D73B68563D79D7BB67B5A9D7352956342CFAE95F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000008D6B528552398D634A8D6B52956B528D634A855A42855A42
8552398D634A9D7352BE8D63BE957BDFAE8DE8BEA6F0CFB6F0CFBEF8D7BEF8D7BEF8D7BEF8D7BE\
F8DFCFF8DFCFF8D7BEF8D7BEF8DFCFF8DFCFF8D7BEF8DFCFF8DFCFF0D7C7F8DFCF
F8DFCFF8DFCFF0D7C7F0D7C7F0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF8CFB6F8CFB6F0CFAEF0C7AE\
F0C7AEF0C7AEF0B69DE8B69DE8B69DE8B69DE8B69DE8AE95DFAE8DD7A68DD7A685
D79D7BCF956BB68D73B68563B68563A67B639D6B4A8D5A426B3921734A31522110422118422118\
39181042292195735ABE957B9D7352C7956BBE8D63A6856B956342E8CFC7F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000007352428D5A42956B52956B52855A428D634A8552397B5A42
956B528D634A9D7352B6856BC7956BD7A68DE8BEA6F0C7AEF8CFB6F8CFB6F8CFB6F8D7BEF8D7BE\
F8D7BEF8DFCFF8DFCFF0D7C7F8D7BEF8DFCFF8DFCFF0D7C7F8D7BEF8DFCFF8D7BE
F0D7C7F0D7C7F8D7BEF0D7C7F8D7BEF8D7BEF8D7BEF8CFB6F8D7BEF8CFB6F8CFB6F0C7AEF8CFB6\
F0C7AEF0C7A6F0C7A6E8BEA6E8BE9DE8BEA6E8B695DFAE95DFAE8DD7A68DD7A685
BE957BCF956BC7856BB68563B685639D6B4A9D6B4A8D5A42734A316B3921522110391810291008\
2910087B52428D634AA67B5AAE7352C79D85C7956BD7AE8DC7956BF8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000A67B5A8D5A428D634A85634A8D5A42855A429D6339
7342298D634AA67B63BE8D63B68D73D7A685E8BE9DF0C7AEF0CFB6F8CFB6F8D7BEF8D7BEF8D7BE\
F8DFCFF8DFCFF0D7C7F8DFCFF8DFCFF8DFCFF8D7BEF8DFCFF8D7BEF0D7C7F8DFCF
F8D7BEF0D7C7F0D7C7F8D7BEF0D7C7F0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF0C7AEF8C7B6F0CFAE\
F0C7AEF0C7AEF0B69DF0C7A6E8B69DE8B69DDFAE95DFAE95DFAE8DD7A68DD7A685
BE957BD79D73B68D73B6856B9D7352956B52855A42734A318552395A3121391810291008422921\
29100885634A956B529D6B4A956342C7956BC7956BC79D85E8DFD7F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000007B5A427B5A42855239855239855231855A42855239
8D634A8D634AA67B5AB68D73C79D85D7A68DE8BE9DF0C7AEF0CFB6F8D7BEF8D7BEF0D7C7F8D7BE\
F8DFCFF8DFCFF8D7BEF8DFCFF8D7BEF8DFCFF8D7BEF0D7C7F8D7BEF8DFCFF8D7BE
F0D7C7F0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF0D7C7F8D7BEF8D7BEF8C7B6F8CFB6F8CFB6F0C7AE\
F0C7AEF0C7AEF0B69DF0C7A6E8B69DE8B69DDFAE95DFAE8DDFAE8DDFAE8DD7A685
C79D85D79D7BB6856BA67B639D73529D73529D6B4A7B5A426B39215A3121391810391810422921\
391810956B52956B529D73529D6339C7956BC79D85D7A68DF8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
F8F8F8000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000855239734A31855231735242734A317B5A42
8D634A9D6B4AB68563B68D73D79D7BD7AE8DE8BE9DF0C7AEF8CFB6F8C7B6F8D7BEF0D7C7F8D7BE\
F8D7BEF8D7BEF8D7BEF0D7C7F8DFCFF8DFCFF8DFCFF8DFCFF0D7C7F0D7C7F8DFCF
F8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8C7B6F8CFB6F8CFB6F8CFB6F0C7AE\
F8CFB6F0C7AEF0C7A6F0C7A6F0BE9DE8B69DDFAE95DFAE8DD7A68DDFAE8DD7A685
D7A685BE957BB6856BB6856BA67B638D634A8D5A426B39215A3121422118422118291008392118\
3918109D7B63956B529D6339956342C79D85CFB6A6DFCFC7F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000855239855239855231855239855239735242
8552399D6B4AA67B63B68D73C79D85DFAE9DE8BEA6F0C7AEF8CFB6F8CFB6F8D7BEF0D7C7F0D7C7\
F8DFCFF0D7C7F8DFCFF8DFCFF8DFCFF8DFCFF8DFCFF0D7C7F8DFCFF8D7BEF0D7C7
F8DFCFF0D7C7F8D7BEF0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF8CFB6F8D7BEF8CFB6F8C7B6F0CFAE\
F0C7AEF0C7AEF0C7A6F0C7A6E8B69DE8B69DDFAE9DDFAE8DDFAE8DD7A685D7A68D
CF956BCF956BBE8D63A67B63A67B5A9D73528D5A425A39295A3121422118422921311818422118\
422118A67B63B6856B8D5A42AE7352C7956BE8BE9DF8F8F8F8F8F8F8F0F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000734A317352427352428552397B5A42
735242956B52B68563BE957BD7A685DFAE95F0C7A6F0C7AEF0C7B6F0CFB6F8CFB6F8D7BEF8D7BE\
F8D7BEF8D7BEF8D7BEF8DFCFF8D7BEF8DFCFF0D7C7F8D7BEF8D7BEF0D7C7F8D7BE
F0D7C7F0D7C7F8D7BEF8D7BEF8D7BEF0D7C7F8D7BEF8D7BEF8CFB6F8CFB6F0CFAEF8CFB6F8C7B6\
F0C7AEF0C7AEF0C7AEE8BEA6E8BEA6E8BE9DE8B695DFAE8DDFAE8DD7A68DD79D7B
D79D7BB68D73BE8D63A67B639D73528D634A8552395A39295A3121422921422118522918522918\
3918109D6B4AB685639D6B4AC7855AD7A685DFCFCFF8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000735242855A427B5A427352427B5A42
855A42956B529D7352C7956BD7AE8DE8BEA6E8BEA6F0C7AEF8CFB6F8CFB6F8D7BEF8D7BEF8D7BE\
F0D7C7F0D7C7F8DFCFF8DFCFF0D7C7F8D7BEF8D7BEF0D7C7F0D7C7F0D7C7F0D7C7
F8D7BEF8D7BEF0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF8CFB6F8CFB6F8CFB6F0CFAEF0CFAEF0C7AE\
F0C7A6F0C7A6F0C7AEE8BEA6E8BE9DE8B695E8AE95DFAE8DDFAE8DDFA685DFA685
CF956BB68D73B6856BAE73529D6B4A8D5A42734A315A39295A3929522918422118522918391810\
291008956B529D73529D6B4ABE8D63DFAE8DF0F0E8F8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000956B52956B52956B527B5A42
7B5A42956B52A6856BB68D73D79D7BE8B69DF0C7A6F0C7AEF0C7AEF8CFB6F0CFB6F8CFB6F0D7C7\
F0D7C7F0D7C7F0D7C7F8D7BEF8D7BEF0D7C7F8DFCFF8D7BEF0D7C7F8D7BEF8D7BE
F8D7BEF8D7BEF8CFB6F8D7BEF8CFB6F8CFB6F8CFB6F8CFB6F8D7BEF8C7B6F8CFB6F0C7A6F0C7A6\
F0C7A6F0C7A6F0B69DE8BEA6E8BE9DE8B695DFAE95E8B695D7A685D7A685D7A685
B68D73B68D73A67B63A67B5A8D634A855239734229734A315A31215A3121422118391810211008\
5A3929B6856B9D7352B6734ACF956BCFAE95F8F8F8F8F0F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000095735A956B52855A428D634A
85634A8D634AAE7352BE957BC79D85DFAE95F0C7A6F0C7AEF0C7AEF8CFB6F8CFB6F8D7BEF8D7BE\
F8CFB6F0D7C7F0D7C7F8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF0D7C7F8D7BE
F8D7BEF8D7BEF8D7BEF8D7BEF8CFB6F8CFB6F8CFB6F8D7BEF8CFB6F0C7AEF0C7AEF0C7AEF0C7AE\
F0C7A6F0C7AEF0BE9DE8B69DE8B69DE8B69DE8B695DFAE8DD79D7BD7A68DBE957B
BE957BBE8D63AE7352955A42855239855A427342295A39295A3929422921522918211818211008\
A67B5AA67B63956342B67B5AC78D63E8CFBEF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000085523985634A735242
8D634A8D634AA67B5ABE8D63D79D7BDFAE9DE8BEA6F0B69DF0C7AEF0C7AEF8CFB6F0CFAEF0CFAE\
F8CFB6F8CFB6F8D7BEF8D7BEF8D7BEF8CFB6F8D7BEF8D7BEF8D7BEF8CFB6F8D7BE
F0CFB6F8CFB6F0CFBEF8CFB6F8CFB6F8CFB6F0CFAEF0C7AEF0C7AEF0C7AEF0C7AEF0C7A6F0C7AE\
F0C7A6F0C7A6F0B69DE8B69DE8B69DE8B69DDFAE95DFAE95D7A68DD79D7BD7A685
B68D73A67B639D6B4A9563428D5A42855A42855A425A31215A3121522918391810291008B6856B\
9D7B639D6B4A956342BE8D63D7B6A6F0E8E8F8F8F8F8F0F8F8F0F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000855A42A67B5A
7B5A42A67B5AA67B5ABE8D63C79D85DFAE95E8BE9DE8C7AEF0C7AEF0C7A6F0C7AEF8CFB6F8CFB6\
F8D7BEF8CFB6F0CFBEF8D7BEF8CFB6F8D7BEF8D7BEF8D7BEF8D7BEF8D7BEF8CFB6
F8CFB6F8D7BEF8CFB6F0C7AEF8CFB6F0C7AEF8CFB6F0C7AEF0C7AEF0C7A6F0C7AEF0C7AEF0C7A6\
F0C7A6E8BE9DF0BE9DE8B695E8B695DFAE9DDFAE8DCFAE95BE957BD79D7BCF956B
B6856BA67B639D73529D6B4A855A42734A31735242956B524221183918103921187B5A42855239\
A67B5A9D6B4AAE7352C7956BE8BEA6F8F0F8F8F8F8F8F0F8FFFFFFF8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000855239855239
85634AA67B63A67B5ABE8D63D79D7BDFAE95DFAE9DE8BEA6F0C7AEF0C7A6F0C7AEF8C7B6F0C7AE\
F8D7BEF0CFAEF8CFB6F8CFB6F8CFB6F8CFB6F8CFB6F8CFB6F8CFB6F8D7BEF8C7B6
F8C7B6F0C7AEF0C7AEF0C7AEF0B69DF0C7AEF0C7A6F0C7A6F0C7A6F0C7A6F0C7A6F0C7AEF0C7A6\
F0C7A6E8B695E8B695E8B69DDFAE95DFAE95DFAE8DD7A685BE957BBE957BB6856B
AE73529D7352956342855A42855A428552398552395A3929734A315A3929734A31734229A67B63\
9D7352B68563BE8D63D7AE8DD7BEAEF8F8F8FFFFFFF8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000855231
7B5A428D5A429D7352B68563BE957BC79D85D7B6A6E8B69DE8BEA6F0C7A6F0B69DF8C7B6F8C7B6\
F0CFB6F0CFB6F0C7B6F0C7AEF8C7B6F8CFB6F8CFB6F8D7BEF0C7B6F0CFB6F0C7AE
F0C7AEF0C7A6F0B69DE8B69DE8B69DF0B695F0C7A6F0C7A6F0BE9DF0B69DF0BE9DF0B695E8B69D\
E8B69DDFAE8DE8AE95DFAE95D7A68DD7A68DD79D7BBE957BBE957BB68D73B6856B
AE7352A67B5A9D6B4A735242735242734A31734A315A42397342295A3121A6856B956B529D7352\
9D6B4AD79D7BC7956BE8BE9DF8F8F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8FFFFFF
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
9D6B4A8552399D7352A6856BB68D73D7A68DDFAE95DFAE9DE8B69DF0B69DF0B69DF0C7A6F0C7AE\
E8C7AEF0C7AEF0CFB6F0C7AEF0C7AEF0C7AEF0C7B6F0C7AEF0C7A6F0C7AEF0C7AE
F0BE9DE8B69DE8AE8DE8AE95E8AE95E8B695F0B695E8AE8DE8AE8DE8AE8DE8AE8DDFA685DFAE8D\
E8AE95D7A685DFAE8DD7A685D7A685C79D85D79D73BE957BB6856BB68563B68563
A67B5A9D73528D5A42855A427B5A427352428D6B527B5A42734A318D6B52B6856B95735AA67B63\
BE8D63D7A685E8BE9DD7BEAEF8F0F8F8F8F8F8F8F8F8F8F8FFFFFFF8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000956B528D634A9D7352A67B63BE957BD7A68DE8BE9DDFAE9DD7B6A6E8B69DE8B69DF0C7AE\
F0C7AEF0C7AEF0C7AEE8C7AEE8BEA6E8BEA6E8BEA6E8BEA6E8B69DDFAE9DDFAE8D
DFAE95DFAE95D7A685D7A685D79D7BD79D7BD79D7BD79D73DF9D7BD79D7BD79D73D79D73BE957B\
CF956BCF956BCF956BCF956BC7856BB68D73BE957BB68D73B6856BB67B5A9D6B4A
8D634A95735A956B52735A4A956B52956B52734A318D634A9D6B4A9D6B4A9D73529D6B4ABE8D63\
B68563DFAE95E8BE9DF8F0E8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000008D634A956B52A67B5AB6856BA67B6BB68D73BE957BDFAE95D7B6A6E8BEA6F0C7A6E8C7AE\
E8BEA6E8BEA6E8BEA6E8BE9DDFAE95DFAE95D7A685DFAE95E8BE9DD7A68DDFA685
D7A685D7A68DBE957BC79D85C7856BCF956BBE8D63D79D7BCF7363CF956BB67B5AB68D73B67B5A\
B67B5ABE8D63B68563B68563B6856BB6856BA67B63B68D73BE957BA6856BA68D73
A67B5AA67B638D634A8D634A95735AA67B63855A426B3921855239B67B5AB68563B67B5ABE8D63\
CFAE95D7B6A6D7BEAEF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000007B5A429D7352A67B5A8D634AB68D73C79D85D7BEAEE8C7B6E8C7B6E8C7B6E8BEA6\
E8BEA6D7B6A6DFAE9DD7A685CFAE95D7A68DD7A68DD7A685D7A68DD7A685D7A685
C7956BC7956BB68D73B68D73B6856BB68D73B6856BAE7352B6856BB685639D73529D6B4AB6856B\
9D7352B685639D7352AE7352A67B63A67B5AA67B638D634A956B5295735AAE7352
95735A9D735295735A9D7352855239855A428D6B529D6B4A9D7352A67B5AA67B5AC7956BD7B6A6\
D7B6A6C79D85F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000009D7363A68D73C7A695CFA695BE9D8DDFAE9DCFA695DFAE9DD7BEAED7BEAE\
DFAE9DDFAE95D7A68DD7A685D7A68DBE957BC79D85D7A685C79D85C7956BC79D85
BE957BC7856BB68563B6856B9D7352BE957BA67B63BE957BB68563A67B63BE8D63A67B5A9D6B4A\
BE957BA67B5AB6856BA67B63A67B5AA6856BA68D7385634A956B52A67B5A9D7B63
8D6B5295735AA67B639563429D6B4A9563429D6B4A9563429D7352B68563D7AE85CFB6A6CFAE95\
D7AE8DE8CFC7F8F8F8F8F8F8F8F8F8F8F8F8FFFFFFF8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000956B52A6856BB68D73B68D73BE9D8DDFAE9DD7B6A6DFAE95CFAE95\
D7A68DD7AE8DC79D85C79D85C79D85B68D73BE957BB68D73BE957BB68D73BE957B
B6856BBE957BA67B5A9D7352A67B6B956342A6856BA67B5AB68D739D7352A67B63A67B5AA67B63\
C7956B8D634A9D73529D7352B6856BA67B5A956B52956B52855A427B5A42734A31
7352428D634A8552398552397B5A427B5A42956342B6734AC7956BD7AE85E8C7AEBE9D8DD7AE8D\
B68563F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8
F8F8F8F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000BE9D95C79D85C7A695D7B6A6D7B6A6D7B6A6D7B6A6C79D85\
C79D85C79D85C79D85BE957BC79D85BE957BBE957BB6856BB6856BBE957BB68563
A67B5AA67B63956342A6856BA6856B8D634A734A31A67B63855A42B68563A67B5AA67B63A67B63\
8D5A429D6B4AA67B5A734229734A319D63398D5A42855A428D5A429D6339956342
9D6B4A9563429563428552399D63399D6B4ACFAE95BE957BD7AE8DD7BEAE8D634ABE9D8DA6856B\
DFCFCFFFFFFFF8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8F8F8F8
F8F8F8F8F8F8000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000A6856BC7A69DCFB6A6DFAE9DD7B6A6C7A695\
BE957BBE957BB68D73BE957BBE957BB68D73A6856BA68D73B68D73A67B63B68563
B685638D634AC7956BA67B5A8D634ABE957B8D634A855A42A67B638D634A8D634A956B52855A42\
8D5A428552317342298552398552399D63398552397B5A429563428D5A42855239
854A318D5A429D7352B68563B68563C79D85BE957BE8BE9DD7B6A6A6856BA67B5ABE9D8DA6856B\
F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000B6957BC7AE9DCFB6A6D7A68DC7A695\
A67B63B6856BA6856BBE957BBE957BB6856B9D7363B6856BB68563A67B63B68D73
A67B63B68563855A429D735295735A8D634AA67B5A855A428D634A956342855A4285634A855A42\
735242855239855239855239734A317342298552397B5A42855239855231855231
8D634AA67B5AA67B5AA67B5AA67B5AC79D85CFB6A69D7B639D7B63A6856BC7A695BE957BF0E8E8\
F8F0F8F8F0F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000B6957BD7B6A6D7B6A6C7AE9D\
A67B5AB68D73A67B63A67B63B68563A67B5A95735AA6856BA6856B95735AA67B63
95735AA67B63855A42A67B5A9D6B4A956B52735242734A31A67B5A7352427B5A42855A427B5A42\
855231734A31734A316B39215A39297342297342297342298552319D6B4A855A42
8D634AA6856BC79D85BE957BE8BEA6CFB6A6BE9D8DA68D73956B52C79D85956B52F0E8E8FFFFFF\
FFFFFFF8F0F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000CFB6A6D7BEAEC7AE9D\
A67B5A956B52B6957BA67B63B68D73B6957BB68563956B52A6856BA67B5A8D634A
A67B63A67B638D634A9D7352A67B5A95735A8D6B525A3121734A317B5A42A67B5A855239855239\
6B39218552397342296B39215A31215A39295A31215A3121734A318D5A42A6856B
BE957BB6856BBE957BCFB6A6B6957B85634A957B6BB68563A6856B9D6B4AC7A69DF8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8F8F8F8F8F0F8F8F8F8FFFFFFF8F8F8000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000D7B6A6\
A6856B956B52A67B5AB68D7395735A95735AA67B638D6B528D634A9D736395735A
8D6B52956B52A67B6395735A8D634AA67B5A9D73528D6B528D634A734A31734A3185634A855239\
8552398D5A428552319D6B4A855231855231955A319D6B4AAE7352A67B63BE8D63
C79D85DFC7B6B6957BBE9D8D9D7B6B734A3195735AA6856BB6957BB6957BF8F8F8F8F8F8F8F8F8\
F8F8F8F8F8F8F8F8F8FFFFFFF8F8F8F8F0F8000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
D7B6A68D634A8D6B529D7B63B6856395735A956B52855A427B5A427B5A428D634A
8D634A956B5295735A8D634A8D634AA67B5AA6856B9D735295735A7B5A42A67B5A855239855231\
95735A956B528D634A9563429D6B4AA67B5AB68563C79D85B68D73BE957BD7B6A6
BE9D8DB69D8DA68D73A68D737B5A429D7363A68D73A6856BA67B6BFFFFFFF8F8F8FFFFFFFFFFFF\
F8F8F8F8F0F8FFFFFFF8F0F8FFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000008D6B528D6B52A6856BA6856B956B52A6856B855239855A42855A42
9D6B4A956B529D7352855239A67B6B9D7352B68D73A67B63B6856BB6957B956B528D5A428D5A42\
9D73529D7352B68563B68563BE8D63BE8D63D7A685D7A685C7A695A67B639D7B6B
9D7B6B8D5A42734229855239A67B63A6856B9D7B63BE957BFFFFFFF8F8F8F8F8F8F8F8F8FFFFFF\
FFFFFFF8F8F8F8F8F8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000A6856B8D634AA6857395735AA67B63956B52855239
7B5242734A318D634A7B5A429D73639D7352BE957BB68D73DFC7B6E8C7B6D7B6A6C79D85DFAE9D\
D7A68DD7A68DD7A68DE8C7AEE8C7AEDFAE95CFB6A6A68D738D6B529D7B63956B52
855A427B5A428D634AB68563B6957BA67B63A67B6BFFFFFFF8F8F8F8F8F8FFFFFFF8F8F8F8F8F8\
F8F8F8000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000A68573A68D7BA67B6BBE957BC7A695
9D7B6B7B52428D6B527B524295735AB6957BC7A695BE9D8DA68D7BD7BEAED7BEB6D7BEAEDFC7B6\
E8D7C7E8CFC7D7BEAEC79D85B6957BB6957BA6857395736395735A956B52735242
85523995735A9D7B63BE957BA67B63B6957BF8F8F8F8F8F8F8F8F8F8F0F8F8F8F8F8F8F8000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000D7BEB6C7A69D
E8CFC7F0D7C7F8F0E8F0E8DFF0D7C7E8CFC7E8CFBED7BEAEDFCFBEDFC7B6DFC7B6DFC7B6E8CFBE\
CFB6A6A68D73C7A695A68D739D7B639D7B6B9D7B6B8D634A8D6B52735A4AA67B63
A68D73A6856BA6856BA67B63FFFFFFF8F8F8F8F8F8FFFFFFF8F0F8000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000DFC7B6E8C7B6E8CFBEE8C7B6F0D7C7F0DFCFE8D7CFDFCFBEE8CFC7CFB6A6BE9D95D7BEAE\
BE9D8DB69D8DBE9D958D735AA67B5A8D634A8D6B529D7B6BA68573BE9D8DC79D85
B68D73A6856BC7A69DF8F8F8F8F8F8F8F0F8000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000E8D7CFF0DFCFE8CFC7DFCFBED7BEB6CFC7BEB69D8DA68D85\
BE9D959D7B639D7B6B95735AA68D73856352A68D7BBE9D8DC79D85B69D8DA68D7B
C79D85E8DFDF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000B69D8D000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[86]:=",
  ImageSize->{450, 150},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000720000UR000`400?l00000o`00003oo`3oooo3
0?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo3
0?ooo`00o`3oooo30?ooo`008P3ooomY00000200ooooJP00000P0?ooofT00000903oool00280oooo
J@00000P0?ooofX00000803ooomY000002@0oooo000R0?ooofT00000803ooomZ00000200ooooJ@00
000T0?ooo`008P3ooomY00000200ooooJP00000P0?ooofT00000903oool00280ooooJ@00000P0?oo
ofX00000803ooomY000002@0oooo000R0?ooofT00000803ooomZ00000200ooooJ@00000T0?ooo`00
8P3ooomY00000200ooooJP00000P0?ooofT00000903oool00280ooooJ@00000P0?ooofX00000803o
oomY000002@0oooo000R0?ooofT00000803ooomZ00000200ooooJ@00000T0?ooo`008P3ooomY0000
0200ooooJP00000P0?ooofT00000903oool00280ooooJ@00000P0?ooofX00000803ooomY000002@0
oooo000R0?ooofT00000803ooold000000030?2nW@000000000003<00000803ooomY000002@0oooo
000R0?ooob/000001P3`ajH0103`_Yd0l<NV0?2nW@3`_Yd40?37YP040?2fU@3`_Yd0l;jM0?2nWB`0
0000803oool/000000L0l<NV0`3`_Yd30?37YP80l;JE0P3`_Yd]00000200oooo:`0000060?37YP04
0?2nW@3`ajH0l;jM0?2nW@@0l<NV00@0l;JE0?2nW@3`_Yd0l;jM;000000T0?ooo`008P3ooolV0000
00030?2nW@3`ajH0l;jM0080l;jM00H0l<NV0?2nW@3`_Yd0l<NV0?2nW@3`ajH20?2nW@080?2fU@3`
_Yd0l;jM0>RnW@3`ajH0l;jM0>RfU@3`]YD30>RfU@040>RnU@3X]YD0j;JE0>R^SBL00000803ooolV
000000030>RnU@3`_Yd0l;jM00<0l;jM00<0l<NV0?2nW@3`ajH00P3`_Yd0103`ajH0l;jM0?2fU@3X
_YD20?2nW@050?37YP3`_Yd0l;JE0>RfU@3`]YD00`3X]YD0103X_YD0j;JE0>R^S@3X[XdW00000200
oooo9P0000000`3`_Yd0l<NV0?2nW@020?2nW@060?37YP3`_Yd0l;jM0?37YP3`_Yd0l<NV0P3`_Yd0
203`]YD0l;jM0?2nW@3X_Yd0l<NV0?2nW@3X]YD0l;JE0`3X]YD0103X_YD0j;JE0>RfU@3X[XdW0000
02@0oooo000R0?ooob<0000000D0gjjM0=n^U@3X]YD0j;jV0>RnW@030?2nW@030?37YP3`_Yd0l<NV
00<0l;jM00H0j;jM0?2nW@3`_Yd0l;JE0>RnU@3`]YD20?2nW@070>RnU@3`]YD0j;JE0?2fU@3O[XD0
j:j=0?2fU@030>R^S@030>RnU@3X]YD0000002<00000803ooolT000000040=n^U@3X]YD0j;JE0>Rn
YP@0l;jM0P3`ajH60?2nW@80l;JE00D0j;jE0?2nW@3`_Yd0j;jM0>RnU@020?2fU@080>R^S@3O[XD0
j:j=0?2fU@3X[Xd0l;JE0>R^S@3X_YDU00000200oooo8`0000001@3O[Yd0gjjE0>RfU@3X_ZH0j;jM
00<0l;jM00<0l<NV0?2nW@3`ajH00`3`_Yd01P3X_Yd0l;jM0?2nW@3`]YD0j;jE0?2fU@80l;jM00L0
j;jE0?2fU@3X]YD0l;JE0=n^Q@3X[Xd0l;JE00<0j:j=00<0j;jE0>RfU@0000008`00000T0?ooo`00
8P3ooolR0000000304XH203O[YD0gjjE00<0j;jM103`_Yd20?37YPH0l;jM00D0j;jE0?2nW@3`]YD0
j;jM0?2fU@040>RfU@<0j:j=00H0gjj50=nVN`3X[Xd0gjj50>RnW@3OYW/S00000200oooo8P000000
1P1S:A00BQP80=n^U@3X_Yd0j;JM0>RnW@D0l;jM00<0l<NV0?2nW@3`_Yd0103`_Yd20>RnU@040?2n
W@3X_Yd0l;JE0?2fW@<0j;JE103X[Xd01P3OYW/0gjj50>R^S@3O[XD0gjIk0=n^SB<00000803ooolR
0000000304XH203O[YD0gjjE00<0j;jM103`_Yd20?37YPH0l;jM00D0j;jE0?2nW@3`]YD0j;jM0?2f
U@040>RfU@<0j:j=00H0gjj50=nVN`3X[Xd0gjj50>RnW@3OYW/S000002@0oooo000R0?ooob000000
00<0NcTH06<Y401[<AP00P3O[YD01@3X]YD0j;jM0>RnYP3X_Yd0l<NV00D0l;jM00L0l;JE0?2nW@3`
_Yd0j;jE0?2nW@3X_Yd0l;JE0080j;JE00L0j:j=0>RfU@3X]YD0j;JE0>R^S@3O[XD0gjJ500<0gjIk
00@0j;jM0=n^Q@3GWG/0eiec0P3OWG<Q00000200oooo800000001P1k>AP0HbT@058Q401[<AP0gjjE
0>RfU@<0j;jM00<0l<NV0?2nW@3`ajH0103`_Yd02@3`]YD0l;jM0>RnU@3`_Yd0l;JE0>RnW@3`]YD0
j;JE0>R^S@030>RfU@80j:j=00T0gjj50=nVQ@3OYW/0gjIk0=n^Q@3X_Yd0gjj50=NML`3GWG/00P3O
WG<Q00000200oooo800000000`1k>AP0HbT@06/a60020=n^U@050>RfU@3X_Yd0j;jV0>RnW@3`ajH0
1@3`_Yd01`3`]YD0l;jM0?2nW@3X_YD0l;jM0>RnW@3`]YD00P3X]YD01`3X[Xd0j;JE0>RfU@3X]YD0
j:j=0=n^Q@3OYXD00`3OYW/0103X_Yd0gjj50=NMN`3GWG<20=nMLb400000903oool00280oooo7@00
00002P2fLdX0[V/i08e::@2=BRT0NcTH08e28@1S:A00gjjE0>RnW@3`ajH20>RnW@090?2nW@3`]YD0
l;jM0?2fU@3X_YD0l;jM0>RnU@3`]YD0j;jE0080l;JE0`3X]YD0203X_YD0gjj50=n^Q@3X[Xd0gjj=
0=n^Q@3OWG/0ciE[0P3GWG<00`3X_YD0cheS0<nEJ`020=NML`050;IkFP2fJe80WF<i0<Mk@P2fJcT0
7P00000P0?oooah000000100]W=:08e::@2=BRT0NcTH08E28@2=@R40gjjE0>RnW@3X_ZH0l<NV0>Rn
W@3`_Yd0l;JE0>RnU@3`_Yd0j;jE0P3`_Yd01@3X_YD0l;JE0?2fU@3`]YD0l;jM0080j;JE01@0j;jE
0=n^Q@3`]YD0gjj50>R^S@3O[XD0gjJ50=nMN`3?UF/0eiec0>RnU@3X_Yd0cheS0<nEJ`3GWG<0cheS
0;IkFP2fJe80WF<i0;I[>Al00000803ooolM0000000:0;IcBP2^JcT0SDXY08e::@1k>AP0SD8Q06<Y
403O[YD0j;jM0?37YP80j;jM00T0l;jM0?2fU@3`_Yd0l;JE0>RnU@3`_Yd0j;jE0?2fU@3X_YD00P3`
]YD30>RfU@080>RnU@3O[XD0gjj50>R^S@3O[Xd0gjj50=nMN`3?UF/20=NML`030>RnU@3?SF<0ciE[
0080eiec00D0]W]J0;I[DP2MHcT0ag]20;I[>@0N000002@0oooo000R0?oooa`000000100]W=:09eS
>@2MHcT0SD8Q08e::@2EDRT0NcTH04XH203X_Yd0j;JE0>RnW@3`_Yd0j;jM0?2nW@3`]YD0l;jM1@3`
]YD20>RnU@040?2fU@3X_YD0j;JE0>RfU@80gjj500D0j:j=0=n^Q@3O[Xd0gjj=0=NML`020<n=H`0:
0=n^Q@3O[YD0ahES0<N5H`37SF<0ahES0:icDP2=FT80[V]20<Mk@P80]V/i7@00000P0?oooa`00000
00D0]W=:0:i[@P2MHcT0SD8Q08e::@0209EB:@0407/i603X_Yd0j;JE0>RnYP80j;jM00@0l;jM0?2f
U@3`]YD0l;jM1@3`]YD01@3X_YD0l;JE0>RfU@3X_YD0j;JE00<0gjj500D0j:j=0=n^Q@3O[Xd0giek
0=NML`020<n=H`030=n^U@3?SF<0ahES0080ahES00@0]W]J0:icDP2=FT80[V]20`2fJcTM00000200
oooo70000000402fLdX0WF<i09eS>@2=@R40SDXY09EB:@1k>AP0BQP80>RnW@3X]YD0j;jM0?2nW@3X
_Yd0l;jM0?2fU@3`_Yd50?2fU@80j;jE00@0l;JE0>RnU@3X]YD0j;JE0P3O[XD01@3X[Xd0gjj50=n^
S@3O[Xd0eiec0080cheS00X0gjj50=n^U@37QF<0ahES0<N=H`37QF<0[W=B08eJ@P2^Jd80ag]20P2f
JcTM000002@0oooo000R0?oooa/0000000h0_XeS0;IkFP2^Jd80SDXY08E28@2EDRT0UEXa06/i8@1[
<AP0j;jV0>RfW@3X_ZH0j;JE0?2nW@80j;jM00<0l;JE0?2fW@3X_YD00`3`]YD30>R^S@0?0?2fU@3O
[XD0j:j=0=n^S@3O[XD0gjIk0=nVQ@3OYW/0eiek0<N5J`3?SF<0ciES0=NML`3?UF/0ahES0080ahEJ
00P0]W]J09e[BP2MJdX0[V/i0<n=FP37NdX0]V/i0:i[>A`00000803ooolK0000000>0;j=H`2fNeX0
]V]20:i[@P25@R40UE8Y09EJ<@2=BRT0JcTQ0>RnYP3X]Yd0l<NV0>RnYP3`_Yd20>RnW@050?2nW@3`
]YD0j;jE0?2fU@3X[Xd00P3`]YD30>R^S@0B0?2fU@3O[XD0gjj=0=n^Q@3X[Xd0gjIk0=nVQ@3GWG/0
eiec0<N5J`3?SF<0ciES0<nEJ`37QEX0ahES0<N5FP2fNeX0WF<i0P2MJdX01@2^JcT0ag]:0<Mk@P2f
JcT0[V/i01`00000803ooolK0000000>0;j=H`2fNeX0[V]208e::@25@R40UE8Y09EJ<@1[>B40Jc4H
0>RnYP3X]Yd0j;jV0>RfU@3`_Yd20>RnW@030?2fU@3`]Yd0j;jE00<0l;JE0`3X[Xd03`3`]YD0gjj5
0>R^S@3O[Xd0gjj50=nVN`3OYXD0gjIk0=NMN`37QF/0cheS0<nEH`3GWG<0ciE[0<N5H`020<N5FP08
0;IkFP2MJdX0WF]:0:i[>@3?SEX0ag]:0;I[>@2^JcTL000002@0oooo000R0?oooaX0000000h0ciE[
0<N5FP2fLdX0[V/i09EJ<@2EDRT0[V/i09EB:@1[<AP0HbT@0>RnYP3X]Yd0gjjE0>RnW@80l;jM00<0
j:j=0?2fU@3X]YD00P3X[Xd00`3O[XD0j:j=0>R^S@020=n^Q@030=nVQ@3X[Xd0gjJ50080gjJ50P3O
YW/20=NML`0A0<n=FP37QF<0eiek0<N=H`2fNeX0ag]:0;IcBP2fNeX0UF=209ecDP2^JcT0[V]20<Mk
BP3?SEX0]W=:0<MkBP2fNeX06`00000P0?oooaX0000000P0ciE[0<N5FP2fLdX0[V]20:i[>@2EDRT0
[V/i09EB:@80Jc4H00@0j;jV0>RfW@3X_Yd0gjjE0P3`_Yd20>R^S@060?2fU@3X[Xd0j:j=0>R^S@3O
[XD0j:j=0P3O[XD00`3X[Xd0gjJ50>R^S@030=nVQ@80gjIk01<0eiec0<nEJ`3?SEX0ahES0=NMN`2f
NeX0]V]B0<MkBP2fLdX0UF=20;IcBP2MLe80[V/i0:i[@P3?SEX0ahEJ0;IcBP37NdX0]W]J01/00000
803ooolJ0000000>0<nEJ`37QEX0]W=:0:i[>@2EFS40UE8Y0:i[>@2EDRT0Jc4H06<Y403X_ZH0j;JM
0=n^U@3X_Yd20?2nW@030>R^S@3`]YD0j;JE0080j:j=00<0gjj50>R^S@3X[Xd00P3O[XD00`3OYXD0
j:j=0=nVQ@020=nVQ@80gjIk0P3GWG<04@3?SEX0ahES0=NMN`37SF<0]W]J0<MkBP2fLdX0]W]J09ES
@P2MLe80[V/i0:i[@P37NdX0cheJ0;IcBP37NdX0]W]J01/00000903oool00280oooo6@0000020=NM
L`090;j=H`2fLdX0[V]208e::@2MHcT0UE8Y08E28@1[>B40HbT@00@0j;jM00/0j;JE0?2nW@3X_YD0
l;JE0>R^S@3O[XD0j:j=0=nVQ@3O[XD0gjJ50=n^Q@020=nVQ@050=n^S@3O[XD0gjIk0=nMN`3OYW/0
0P3GWG/01P3GWG<0ahEJ0<nEJ`3?SF<0]W]J0;I[DP80[V]200D0UEXa09e[BP2EDRT0WF<i0;I[@P02
0<n=FP040<nEJ`37NdX0ag]:0;IcBQX00000803ooolJ000000030=NML`2nSF<0]W=:0080[V]200D0
WF<i09EB:@25@R40HbT@06/i8@040>RnW@090>RfU@3`_Yd0j;jE0>R^S@3`]YD0gjj50>R^S@3O[XD0
gjJ50080gjj50`3OYXD03@3O[Xd0gjIk0=nMN`3GWG/0gjIk0=NMN`3GWG<0ciE[0<N5FP3?UF/0cheS
0;I[DP2fLdX00P2^Jd8209e[BP0309EB:@2MHcT0]V]20080cheJ00<0ciE[0<MkBP37NdX06`00000P
0?oooaT000000P3GWG<02@2nSF<0]W=:0:i[@P2=BRT0WF<i09EB:@25@R40JcTQ06<Y40040>RnW@0;
0>RfU@3`_Yd0j;jE0?2fU@3X[Xd0gjj50>R^S@3OYXD0gjj50=nVQ@3O[XD00P3OYXD01@3O[Xd0gjj5
0=nVN`3OWG/0gjIk0080eiek00H0eiec0<N5FP3?UF/0cheS0;IkFP2fJe820:i[@P0509EJ<@2MJdX0
UE8Y09eS>@2fJd800P3?SEX0103?UF/0ag]:0<MkBP2fLdXJ000002@0oooo000R0?oooaL0000000L0
n?3X0>SGa`3GWG<0ahEJ0;IkFP2^Jd80UE8Y0080WF<i00D0UEXa05Xa8@1[<AP0JcTQ0>RnW@020=n^
U@80j;JE0P3X[Xd00`3OYXD0gjj50=nVN`030=nMN`030=nML`3?UF/0ciE[0080eiec00<0giek0=NM
L`3GWG<00P3?UF/20<n=H`050;j=H`2fLdX0[V]20:i[>@2MHcT00P2^Jd8209eS>@0;0:iS<@2fJcT0
]V]20<Mk@P3?SEX0eiec0=n^Q@37SF<0[V/i0;IcBP37SF<06000000P0?oooaL000000180n?3X0>SG
a`3G[Xd0ahEJ0;IkFP2^Jd80]W=:09EB:@2MHcT0UEXa05Xa8@1S:A00Jc4H0>RnW@3O[YD0j;JM0=n^
U@3X]YD30>R^S@040=nVQ@3OYW/0giek0=nVN`80giek0`3?UF/40=NML`<0ciE[00L0cheS0<N5H`2n
SF<0]W=:0:i[@P2MHcT0[V=20080[V]20P2MHcT02`2^Hc40]V/i0;I[@P3?SEX0gjIc0=NML`3O[XD0
aheS0:i[>@2fLdX0aheS01P00000803ooolG000000070?S`j03XelL0eiec0<N5FP2fNeX0[V]209EB
:@0209eS>@0509EJ<@1J<B40Jc4H06/i8@3X_Yd00P3O[YD20>RfU@80j:j=00<0gjJ50=n^Q@3OYW/0
0`3OWG/00`3OWG<0ciE[0<nEJ`020=NML`030=nMN`3GWG<0eiec0080ciE[0P3?SF<01@2nSF<0]W=:
0:i[@P2^JcT0WF<i0080[V]20P2MHcT02`2^Hc40]V/i0;I[@P37Nd80cheJ0=NML`3O[XD0aheS0:i[
>@2fLdX0aheS01P00000903oool00280oooo5P0000020?S`j00:0>RnYP37UF/0_XeS0;IcBP2MHcT0
UEXa0:i[>@2=BRT0QD8Q058Y6080Jc4H00@0j;jM0=n^U@3X]Yd0j;JE0P3X[Xd01`3OYXD0gjIk0=nV
N`3OYW/0giec0=NML`3OWG<00P3GWG<30<nEJ`80eiec0P3?UF/20<N5H`80ahEJ00<0]V]209eS>@2E
FS400`2^Jd8207]28@090;IS<@37Nd80ag]20<Mk@P37QEX0eiec0<nEJ`3G[XD0_XeS0080ahEJ00<0
ciE[0000000000005@00000P0?oooaH000000P3hl>P02@3X_ZH0ejj50;j=H`2fLdX0WF<i09e[BP2E
FS40SDXY08E28@02058Y600506/a603X_Yd0gjjE0>RfU@3X]Yd00P3X[Xd02@3OYXD0gjIk0=nVN`3O
YW/0giec0=NMN`3GWG<0giec0=NML`040<nEJ`0<0=NML`3?UF/0ciE[0<nEJ`37QF<0ahEJ0;IkFP37
QEX0]V]209eS>@2^Jd80WF<i0P2^Jd800`1k@R40SDXY0;IS<@020<Mk@P060<N5FP3?UF<0eiec0<nE
J`3G[XD0]W=:0P37QEX00`3?UF/000000000000E00000200oooo5P0000020?S`j00:0>RnYP37UF/0
_XeS0;IcBP2MHcT0UEXa0:i[>@2=BRT0QD8Q058Y6080Jc4H00@0j;jM0=n^U@3X]Yd0j;JE0P3X[Xd0
1`3OYXD0gjIk0=nVN`3OYW/0giec0=NML`3OWG<00P3GWG<30<nEJ`80eiec0P3?UF/20<N5H`80ahEJ
00<0]V]209eS>@2EFS400`2^Jd8207]28@090;IS<@37Nd80ag]20<Mk@P37QEX0eiec0<nEJ`3G[XD0
_XeS0080ahEJ00<0ciE[0000000000005@00000T0?ooo`008P3ooolE0000000?0?3`j03hl?P0j=oG
0=NfYP2nSF<0]W]J0:i[@P2MJdX0UEXa09eS>@2=BRT0NcTH06/a601[>B40NcTH0080gjjE00L0gjj=
0>R^S@3O[Xd0gjJ50=n^S@3OYXD0eiek0080giec0P3?UF/00`37QF/0cheS0<n=H`020<nEJ`0:0<N5
J`3?UF/0ciE[0<N5H`37QEX0ahES0<N5FP3?SEX0[V]208e::@80WF]:0140UEXa08E28@1k@R40HbT@
0<Mk@P2fHc40ag]20;I[@P37NdX0gjIc0=NMN`3O[XD0_XeS0<nEH`2nSF<0ciE[0<NEJ`0F00000200
oooo5@000000203`l>P0n?3h0>SOe`3G]ZH0ejj50;IkFP2^Jd80WF]:0P2EFS400`2=BRT0NcTH06/a
600206/i8@80gjjE0`3O[Xd0103OYXD0gjj=0=nVQ@3OYXD20=nML`<0ciE[0P3?SF<00`37QF/0ciE[
0<nEJ`030<nEJ`0J0<N5H`37QEX0ahEJ0;IcBP3?SEX0[V]208e::@2MJdX0WF<i09EJ<@25@R40HbT@
0:iS<@37Nd80]V<a0<Mk@P37NdX0ciES0=nVL`3GWG/0gjj50;j=H`3?UF<0_XeS0<nEJ`37UF/F0000
0200oooo5@0000003`3`l>P0n?3h0>SOe`3G]ZH0_XeS0;IkFP2^Jd80WF]:09EJ<@2MHcT0SDXY07/i
601[<AP0JcTQ07/i60020=n^U@070=n^S@3X[Xd0gjj=0=nVQ@3O[Xd0gjJ50=NMN`020=nML`80ciE[
00<0ahE[0<n=H`3?SF<00P3?UF/02P37QF/0ciE[0<nEJ`37QF<0ahEJ0<N5H`37QEX0cheJ0:i[@P2=
BRT209e[BP0A09EJ<@25@R40Nd8Q06<Y4037Nd80]V<a0<Mk@P2fJd80ag]:0=nVL`3GWG/0gjj50;j=
H`3?UF<0_XeS0<nEJ`37UF/05P00000T0?ooo`008P3ooolD000000050?3`n03hl?P0l?3X0>S7]P3G
[Xd00P2fNeX0102MJdX0[V=209EJ<@2EFS4206/i8@0606/a601[>B40JcTQ0=n^U@3O[Xd0j;jV0P3X
[YD0103XYYD0j:jE0>RVU@3O[Xd20=nVQ@040<n=H`37QEX0cheS0<MkFP<0ahEJ0P3?SF<20<N5FP80
]W]J00X0]V]B0<N5FP2MHcT0NdXY09eS>@2^Jd80Nd8Q07/i601kBRT0UE8Y0P37Nd801`2fLdX0ag]2
0:i[>@3GWG<0ejj50<nEJ`37UF/00P37SF<00`2nSF<0ejj50=N^Q@0E00000200oooo5@0000002P3h
l?P0l?3X0>S7]P3G[Xd0aif50;IkFP2MJdX0[V=209eS>@2EFS4206/i8@0:06/a601[>B40JcTQ0=n^
U@3O[Xd0gjjE0>RnYP3X[YD0j:JE0>R^U@80j:JE0P3OYXD0103GWG/0cheS0<N5FP37NeX40<N5FP0@
0<n=H`37QEX0ahEJ0<N5FP2fNeX0]V]B0;IcBP37QEX0WF<i07]::@2^Jd80SDXY07]28@1k>AP0UE8Y
0:iJ<@80ag]200L0]W=:0:i[>@3?UF<0eiec0=N^Q@3?UF/0ahEJ0080aheS00<0_XeS0=N^Q@000000
5@00000P0?oooa@0000000D0l?3h0?S`n03`l>P0j<Nf0=N^S@020;IkFP0409e[BP2^Hd80UEXa09EJ
<@80JcTQ00H0Jc4H06/i8@1[>B40gjjE0=n^S@3X_ZH20>R^U@040>RVU@3X[YD0j:JE0=n^S@80gjJ5
00@0cheS0<N5FP3?SF<0ag]J0`37QEX20<n=H`80ahEJ0P2fNeX02P2fJe80ahEJ09eS>@1kBRT0WF<i
0:i[@P1k@R40NcTH07]::@2EDRT20<Mk@P070;IcBP37Nd80[V/i0=NML`3G[XD0ciE[0<NEJ`020<N=
H`030;j=H`3G[XD0ejj501D00000903oool00280oooo500000020?3`n00@0?3Xg`3OakH0ejj50;Ik
FP2fLdX0[V]209eS>@2MBS40UEXa058Q401c@RT0JcTQ06/a6025DS40gjjE0>S7[P80l<N^0P3`ajH2
0?2fW@050>R^W@3X[YD0j:jE0=nVQ@3GWG/00P37NeX00`37NdX0ag]J0;IkFP020;IkFP0J0<N5FP2f
NeX0ag]:0;IcBP2^Jd80ag]:08e::@2=BS40WF<i08eJ@P1[<AP0JcTQ0:iS<@25@R40ag]:0<Mk@P2f
LdX0[V/i0;IcBP3GWG/0gjj50=n^S@3G[XD0aiE[0;IkFP2fJd820=N^QAD00000803ooolE0000000<
0?3`n03`j=l0glNf0=N^Q@37UF/0]W=:0:i[@P2MHcT0]W=:09e:<@1B8A00Ld8Y0P1[>B400`1[<AP0
gjjE0>S7[P020?37[P80l<NV0`3`]Yd20>R^U@050=n^S@3OYXD0eiek0<MkFP37NdX00P37NeX20;Ik
FP040<N5FP37NeX0]W]J0<MkBP80[V]200/0ag]:08e::@2=BS40SEY208E28@1[<AP0JcTQ08E28@2M
HcT0ag]:0<Mk@P020;IcBP040<n=FP3GWG/0gjj50=n^S@80aiE[00<0]W]J0;I[@P3G[XD05P00000P
0?oooa@000000P3`l?P0403`j=l0glNf0=N^Q@2fNeX0]W=:0:i[@P2MHcT0WDXa09EJ<@1B8A00Ld8Y
06/i8@1[<AP0QE8a0=n^U@3Xajh20?37[P80l<NV0P3`]Yd01@3X[Yd0j:jE0>R^U@3OYXD0eiek0080
ag]J00<0ag]:0<MkFP2fNeX00P2fNeX06P37QEX0]W]J0<MkBP2fLdX0[V]20<MkBP2=BRT0SDXa09eS
>@2=FT80Jc4H06/i8@2^Hc40QD8Q0<MkBP37Nd80]W=:0:i[>@2fLdX0eiek0=n^Q@3O[Xd0ejj50<NE
J`2fNeX0]V]20P3G[XDE000002@0oooo000R0?oooa<0000000L0l?3h0?S`n03hl?P0j<nn0<n^U@37
UF/0[W=B0080[V]20P2MHcT01`1S:A00JcTQ07]::@1[>B40]Xec0?37]P3hckH00P3hekh03@3hakH0
n=Nn0?S7]P3hckH0l<N^0?37YP3`ajh0l;JM0>R^U@3X[Xd0gjJ50=nVN`3GWG<0102fLdX03@37NdX0
]W]J0;IcBP2^Hd80WF]:08E28@2fLdX0UEXa0<N5FP1k>AP0DR4@06<Y402^JcT00P2fJd802@3?SEX0
[V/i0;j=H`2fLdX0eiec0=n^Q@3X_YD0j;jV0;I[@P020;j=H`030<nEJ`37SF<0ejj=01@00000803o
oolC000000070?3`n03hl>P0n?3h0>S?_P3?[YD0aiE[0;j=H`020:i[@P0509eS>@2EFS40WF<i06/i
8@1kBRT00P1[>B40102fSG<0n<nf0?SG_P3hckH20?SG_P030?S7]P3hckH0n<Nf0080l<N^0P3`]Yd0
1@3X[YD0j:j=0=nVN`3GWG<0ciE[00<0]W=:01T0ag]:0;IcBP2fNeX0]W=:09e[BP25DST0QD8Q0;Ic
BP2EFS40NcTH06/a601B8A00HbT@0;I[@P2EDRT0]V]20<n=FP2^JcT0]W=:0<N5FP3GWG<0gjj50>Rn
U@3G[Xd0]V]20080_XeS00<0ciE[0=NML`3G[Xd05000000P0?oooa<0000000L0l?3h0?S`n03hl?P0
j<nn0<n^U@37UF/0[W=B0080[V]20P2MHcT01`1S:A00JcTQ07]::@1[>B40]Xec0?37]P3hckH00P3h
ekh03@3hakH0n=Nn0?S7]P3hckH0l<N^0?37YP3`ajh0l;JM0>R^U@3X[Xd0gjJ50=nVN`3GWG<0102f
LdX03@37NdX0]W]J0;IcBP2^Hd80WF]:08E28@2fLdX0UEXa0<N5FP1k>AP0DR4@06<Y402^JcT00P2f
Jd802@3?SEX0[V/i0;j=H`2fLdX0eiec0=n^Q@3X_YD0j;jV0;I[@P020;j=H`030<nEJ`37SF<0ejj=
01@00000903oool00280oooo4P0000020?Shn0070?3Xj03XelL0j<N^0<NMQ@37UF/0WF]:09EJ<@02
09eS>@0<08E::@1S:A00NdXY07]::@1[>B40n<nf0?3?[P3hckH0n=Nn0?3Ga`3hekh0l=O70P3hakH0
2`3hckH0l<N^0?37YP3`ajH0j;jM0=n^U@3O[Xd0j:j=0=nVQ@3?UF/0]V]B0080[V]20140]W=:0;I[
DP2^Jd80[V=209eS>@1k@R40ahEJ08E28@3?SF<0WF<i07=:<@1B8A00QD8Q0<MkBP2fJd80ag]:0;I[
>@020<N5FP070<nEH`3GWG<0j;jM0>RnYP37SF<0]W]J0;j=H`020<NEJ`030=N^S@3G[XD000000180
0000803ooolB00000080n?Sh00L0l?3h0>SGa`3Xajh0aif50<NEJ`2fNeX0UEXa0080WF<i00H0UEXa
08E::@1kBRT0NdXY06/i8@3XakH20?S?]P80n=Nn0P3`elL30?S7]P0N0?S?]P3`ajH0l<NV0?37YP3X
_Yd0gjjE0>R^S@3OYXD0eiek0<nEJ`2fJe80[V]20;IcBP2^Jd80]V]B0:i[@P2MHcT0QD8Q07]28@37
QEX0QD8Q09eS>@1[>B40LdXa058Q4037NdX0SD8Q0;I[@P37NdX0]V/i0P37QEX02`3?UF<0eiec0>Rn
W@3G[XD0aheS0;IkFP2nSF<0aiE[0=N^Q@3G[Xd0ejj501<00000803ooolB00000080n?Sh00L0l>SX
0>SGa`3Xajh0aif50<NEJ`2MJdX0UEXa0080WF<i00`0QDXY06<Y401kBRT0NdXY06/i8@3hckH0l<n^
0?S?]P3hekh0l=O70?SG_P3`elL20?S7]P0;0?S?]P3`ajh0l<NV0?37YP3X_Yd0gjjE0=n^S@3X[Xd0
gjJ50<nEJ`2fJe800P2^Jd804@2fLdX0]V]B0:i[@P2^Hd80WF<i07]28@37QEX0QD8Q0<n=H`2MHcT0
LdXa058Q4025@R40ag]:0;I[@P37NdX0]V/i0080ahEJ00L0ciES0=NML`3X_Yd0j;jV0<N=H`2fNeX0
_XeS0080aiE[00<0ejj=0=N^Q@0000004P00000T0?ooo`008P3ooolB0000000B0?Shn03hl?P0l>SX
0=o?_P3G_Zh0_YEk0;j=H`2^Jd80UF=209eS>@2EFS40JcTQ06/a601k@R40JcTQ0:J5J`3hckH0l<N^
0P3hckH30?SG_P030?3Ga`3hekh0n<Nf00<0l<N^00P0j;JM0>RnW@3X]YD0j:j=0=n^U@3GWG/0ahE[
0<nEJ`80[V=200`0WF]:0:iS@P2EHd80WDXa07=2:@37NdX0[W=B0;IkFP2fLdX0DR4@07]28@2MHcT3
0<MkBP0>0<N5FP2^Jd80aheS0<NEJ`3GWG<0ejj50>RnW@2nSF<0]W=:0;j=H`37NdX0aiE[0>RnU@3?
]ZHC00000200oooo4P0000002P3hn?P0n?3h0?3`j03Ockh0ekj^0;jEN`2nSF<0]W]J09ES@P2MHcT2
09EJ<@0506/i8@1k@R40JcTQ0:J5J`3`ckH00`3hckH30?SG_P040?3Ga`3hekh0n<Nf0?S7]P80l<N^
00P0j;jV0>RfW@3X_Yd0j:j=0=n^U@3OYXD0eiek0<N5J`80[V=200h0[V]209e[BP2^Hd80WDXa08E:
<@1c@RT0ag]:0:icDP2fLdX0Jc4H058Q401k@R40ag]:0<N5FP80ag]:00h0ahEJ0<N=H`2nSF<0aiE[
0=NML`3G[XD0j;jE0;j=H`2fLdX0_XeS0<MkBP3G]ZH0j;jE0<nfYQ<00000803ooolB0000000B0?Sh
n03hl?P0l>SX0=o?_P3G_Zh0_YEk0;j=H`2^Jd80UF=209eS>@2EFS40JcTQ06/a601k@R40JcTQ0:J5
J`3hckH0l<N^0P3hckH30?SG_P030?3Ga`3hekh0n<Nf00<0l<N^00P0j;JM0>RnW@3X]YD0j:j=0=n^
U@3GWG/0ahE[0<nEJ`80[V=200`0WF]:0:iS@P2EHd80WDXa07=2:@37NdX0[W=B0;IkFP2fLdX0DR4@
07]28@2MHcT30<MkBP0>0<N5FP2^Jd80aheS0<NEJ`3GWG<0ejj50>RnW@2nSF<0]W=:0;j=H`37NdX0
aiE[0>RnU@3?]ZHC000002@0oooo000R0?oooa4000000140l?3X0?Shn03`l?P0j=oG0=o?_P3?[YD0
_YEk0;j=H`2MJdX0QE8i09EJ<@2=BRT0DRTH06/i8@1c@RT0SEY20?37[P040?S?]P0:0?S7]P3hekh0
n<Nf0?S7]P3hekh0n<Nf0?37[P3`ajH0l<N^0?37YP80j;JM02D0j;JE0=n^U@3OYXD0eiek0<nEJ`37
QF/0WF<i0:iS@P2EFT80WF<i08E::@1S:A00WF]:0=NMN`2=BRT0ciE[0:i[@P1[<AP0[V<a08e:<@2^
Hc40ag]20<MkBP2nSF<0]XES0;IkFP3G[XD0ciES0>RnYP2nSF<0]W=:0;j=H`37SF<0aif50=N^Q@3G
[Xd0j;jE01800000803ooolA0000000B0?3`j03hn?P0l?3h0?3`j03Ockh0cjjE0;jEN`2nSF<0]W=:
08EB>@2EFS40SDXY09EJ<@1B:AP0Ld8Y08eJ@P3`ajh0l<Nf0`3hckH01@3hekh0n<Nf0?S7]P3hakH0
n=Nn0080n<Nf00`0l<NV0?37[P3`ajh0l<NV0>RfW@3X]YD0gjjE0=n^S@3OYXD0eiek0<N5J`2MHcT2
0:iS@P0M09EJ@P25BRT0NdXY06<Y402MJdX0eiek0<nEJ`2EHd80[V]206/a602=BS40_XeS0:iS<@37
Nd80ag]:0;J5H`37UF/0]W]J0=N^Q@3?UF<0l<nf0;j=H`2fLdX0_XeS0<N=H`3GWG<0ejj50=N^S@3X
_YD04P00000P0?oooa4000000140l?3X0?Shn03`l?P0j=oG0=o?_P3?[YD0_YEk0;j=H`2MJdX0QE8i
09EJ<@2=BRT0DRTH06/i8@1c@RT0SEY20?37[P040?S?]P0:0?S7]P3hekh0n<Nf0?S7]P3hekh0n<Nf
0?37[P3`ajH0l<N^0?37YP80j;JM02D0j;JE0=n^U@3OYXD0eiek0<nEJ`37QF/0WF<i0:iS@P2EFT80
WF<i08E::@1S:A00WF]:0=NMN`2=BRT0ciE[0:i[@P1[<AP0[V<a08e:<@2^Hc40ag]20<MkBP2nSF<0
]XES0;IkFP3G[XD0ciES0>RnYP2nSF<0]W=:0;j=H`37SF<0aif50=N^Q@3G[Xd0j;jE01800000903o
ool00280oooo400000020?Shn0080?S`n03`j>P0j<nn0=o?_P37WHD0aheS0:icDP2EHd8209EJ<@06
08EB<@1[<AP0QDXY08EJ@P3`akH0l<N^0`3hckH00`3hakH0l<N^0?37[P030?37[P80l;JM00<0j;jV
0?37YP3`_Yd00P3X]Yd06P3O[Xd0j:j=0=n^S@3OYXD0eiec0<nEJ`3?SF<0WDXa09eS>@2=BS40SDXY
06/i8@25DST0_XeS0;IkFP2MJdX0SD8Q0;IkFP2EFS40[V=20<MkBP2^JcT0ag]:0;j=H`2MHcT0_XeS
0P3GWG<02P3?[YD0j;jE0;j=H`2fJd80_XeS0<NMQ@3G[XD0j;jE0>SGc`3`l>PA00000200oooo4000
00020?Shn0080?S`n03`j>P0l>SX0=o?_P37WHD0aheS0:icDP2fLdX209EJ<@0708EB<@1[>B40Jc4H
08EJ@P3`akH0l<N^0?3?[P020?S?]P030?S7]P3`cjh0l<N^00<0l<N^0180l<NV0?2fW@3X_ZH0l<NV
0>RnW@3`_Yd0j;JM0=n^S@3X[Xd0gjjE0=n^S@3OYXD0ciE[0<n=H`2MHcT0WDXa09eS>@2=BRT206/i
8@0<08EB>@2nSF<0WF]:0<NMQ@2=@R40]W]J0:iS@P2fJd80ag]:0:i[>@37NdX0WF<i0P2nSF<20=NM
L`0:0=n^S@3X_YD0_XeS0;I[@P2nSF<0aiE[0=N^Q@3X_YD0j=O?0?3`j1400000803oool@00000080
n?Sh00P0n?3h0?3Xj03Xckh0glnn0<NMQ@37SF<0[W=B09ES@P80UEXa00H0QE8a06/a6025BRT0QEY2
0?37]P3`ajh30?S?]P030?S7]P3`ajh0l<N^00<0l<N^0P3`]Yd00`3X_ZH0l<NV0?2nW@020>RfW@0J
0=n^S@3X[Xd0gjj=0=nVQ@3GWG<0ciE[0<n=H`2MBS40WF<i08e:<@2=BRT0JcTQ08EB>@2nSF<0]W]J
09e[BP2=@R40]W]J09EJ<@2^Hd80ag]:0:i[>@37NdX0_XeS09eS>@2nSF<20=NML`0:0<n^U@3X_YD0
_XeS0;I[@P2nSF<0aif50=N^Q@3X_YD0j=O?0?3`j1400000903oool00280oooo3`0000020?Shn080
n?3h00@0l>SX0=o?_P3G[Xd0aiE[0P2fLdX01P2=BS40UEXa08EB<@1[<AP0QDXY0>S7]P80l<nf00P0
n<nf0?37[P3`ajh0l<NV0>RnYP3X[Xd0gjJ50=nMN`@0j8ek00@0gjJ50=nMN`3O[Xd0gjJ50P3X]YD0
7`3X]Yd0gjj=0=nVQ@3GYXD0eiek0<nEJ`37QF<0SEY208E2:@1kBRT0DRTH06/i8@2=HdX0ciE[0:ic
DP3GYXD0ag]:0<nEH`2fNeX0[V]20<n=FP37NdX0]W=:0;j=H`3GWG<0aiE[0=N^Q@3GWG<0j<N^0=N^
Q@3GWG<00P37WHD0103G[Xd0j;jV0?3Xg`3`j=lA00000200oooo400000001`3hn?P0n?3h0?S`n03`
j>P0j=O70=N^S@37UF/00P2fLdX01P2^Hd80UEXa08EB<@1[<AP0JcTQ08E::@80l<nf00P0n<nf0?3?
[P3`ajh0l<NV0>RnYP3X[YD0j:j=0=nMN`@0j8ek00/0gjJ50=nMN`3OYXD0gjj=0=nVQ@3X]YD0j;JM
0=n^U@3O[Xd0gjJ50=NMN`020<nEJ`0D0<N5H`2=FT80NdXY06/i8@1B:AP0JcTQ08eSBP2^Le80UEXa
0=NVQ@37NdX0]W]J09eS>@2^Jd80cheJ0<MkBP2nSF<0]W]J0=NML`37UF/20=N^Q@070>S7[P3G[XD0
eiec0<NMQ@3GWG<0ejj=0>RnYP020?3Xga400000803oool?00000080n?Sh0P3hl?P0103`j>P0glnn
0=N^S@37UF/20;IcBP0608e:<@2EFS40QE8a06/a6025BRT0j<Nf0P3`ckH0203hckH0l<N^0?37[P3`
ajH0j;jV0>R^S@3OYXD0giek103XSG/0103OYXD0giek0=n^S@3OYXD20>RfU@0O0>RfW@3O[Xd0gjJ5
0=NVQ@3GWG/0ciE[0<N5H`2=FT80QD8Y07]::@1B:AP0JcTQ08eSBP3?UF/0[W=B0=NVQ@37NdX0ciES
0;IkFP2^Jd80cheJ0<MkBP2fLdX0_XeS0=NML`37UF/0ejj50=NML`3Xajh0ejj50=NML`020<NMQ@04
0=N^S@3X_ZH0l>SO0?3Xga400000903oool00280oooo3`000000303hl>P0n?Sh0?S`n03`l>P0j=O?
0=o?a`37WHD0]W]J0:icDP2MHcT0QE8i08E::@80JcTQ00<0NdXY0?37]P3`akH00`3`ajh00`3`ajH0
l;JM0=mcH`020=mkJ`@0ghEc0`3?JeX00`3GWG/0gjj=0=n^S@020>RfU@030=n^U@3O[Xd0gjJ50080
eiek01l0ahE[0<N5FP1kBRT0JcTQ058Q401[<AP0QE8i0:icDP3GWG/0ahE[0=N^Q@3?UF<0eiec0<Mk
BP2fLdX0ahEJ0;j=H`2^JcT0_XeS0=NML`2nSF<0gjj50>RnU@3X_ZH0aif50=N^Q@37UF/0j;jE0=o?
_P3Xell0l>SX01400000803oool@0000000;0?Shn03hl?P0l?3X0>SGc`3Xckh0aif50;IkFP2^Le80
WF<i0:iS@P25BRT00P1[>B400`1k>AP0NdXY0?37]P040?37[P040?2fW@3OLf<0cf]J0=mkJ`D0ghEc
0`3?JeX00`3GWG/0gjj=0>RfU@020>RfU@0T0=n^U@3O[Xd0eiek0=NMN`3?UF/0ahE[0<N5FP1[>B40
Jc4H058Q401[<AP0QE8i0=NMN`2fQF<0ahE[0=N^Q@3GWG<0aiE[0<MkBP2fLdX0ahEJ0:i[>@2fLdX0
_XeS0=NML`2nSF<0ejj=0>RnU@3X_ZH0aif50=N^Q@3GWG<0j;jE0=o?_P3Xell0l>SX4@00000P0?oo
o`l0000000`0n?3X0?Shn03hl?P0l?3X0>SGc`3OclL0aif50;IkFP2^Le80WF<i08EB>@25BRT206/i
8@0307]::@3`akH0l<Nf00<0l<N^00<0l<NV0?2fW@3OLf<00P3ONf/40=n5L`<0cf]J00<0eiek0=n^
S@3O[Xd00P3X]YD00`3O[YD0gjj=0=nVQ@020=NMN`0O0<N5J`37QEX0NdXY06/i8@1B8A00Jc4H08EB
>@2^Le80eiek0<N5J`3G[XD0ciES0=NML`37NdX0]W=:0<N5FP2nSF<0[V/i0;j=H`3GWG<0_XeS0=n^
Q@3X_YD0j;jV0<NMQ@3G[XD0aiE[0>RnU@3Ockh0j=O?0?3Xj00A000002@0oooo000R0?ooo`l00000
0100n?Sh0?S`j03hn?P0l>SX0>SOe`3G[Xd0aiE[0:IkFP2MJdX0WF<i07]::@25DST0Ld8Y06/i8@3`
ckh0l<Nf0P3`ajh00`3`ajH0l<N^0>R=N`020=n5L`050?37]P3`]Yd0j8ek0>R=N`3XYYD00P3OQG<0
203ONf/0ahE[0<m[FP3GWG/0gjj=0=n^U@3X]YD0gjjE0P3O[Xd07P3GYXD0eiek0=n5L`37QF<0]W]J
07=:<@1B:AP0DR4@08EB>@1B:AP0ejJ509eS>@3G[Xd0]W]J0=nVN`2nSF<0ahEJ0<nEH`2^Hc40ahEJ
0;j=H`37UF/0ciE[0=NMN`3X_ZH0j<Nf0;jEN`2fQF<0aiE[0<n^U@80l>SO00<0l?3X0?3Xg`000000
3`00000P0?ooo`l000000100n?Sh0?S`j03hn?P0l>SX0>SOe`3XelL0aiE[0:IkFP2MJdX0WF<i09EJ
<@25DST0Ld8Y06/i8@1kBRT0l<nn0P3`ajh00`3`ajH0l<n^0?37[P030=n5L`0F0?37]P3XSG/0j8ek
0>RVU@3`]Yd0ghEc0=mkJ`37QF/0cg=S0<m[FP3GWG/0gjjE0>RfU@3X]Yd0gjjE0=n^S@3GYXD0eiek
0<nEJ`3OQG<0ahES07=:<@80DRTH01L0DR4@08EB>@3GYXD0gjj=09eS>@3G[Xd0gjIk0=N^Q@2nSF<0
ahEJ0<nEH`37QEX0]W]J0;j=H`37UF/0ciE[0=N^S@3X_ZH0j<Nf0;jEN`2fQF<0eiec0<n^U@020?3X
g`030?3`j03`j=l0000000l00000803oool?0000000@0?Shn03hl>P0n?Sh0?3Xj03XgmL0ejj=0<NE
J`2VNeX0WF]:09eS>@1kBRT0QE8i07=2:@1[>B40l<nn0?37]P80l<N^00<0l<NV0?37[P3XSG/00P3O
QG<01@3`akH0l;JM0>R=N`3XSG/0j:JE0080ghEc00P0gg][0<N5J`3?JeX0eiek0=n^S@3O[YD0j;JE
0=n^U@80gjj=01h0ejJ50=NMN`3OQG<0ahES0;IkFP1cBS40DRTH058Q4025DST0DRTH0=NVQ@2MHcT0
ejj=0;IkFP3OYW/0_XeS0<N5FP3?UF<0[V<a0<N5FP2nSF<0aiE[0<nEJ`3GWG/0j;jV0>S7]P2nUG/0
]XES0<NEJ`3?[YD20?3Xg`030?3`j03`j=l0000000l00000903oool00280oooo3`0000002@3hn?P0
l?3h0?Shn03XemL0glnn0<NEJ`2fQF<0YW]J08EB>@0209EJ<@0306<Y401[>B40JcTQ00<0l<nf00@0
l<N^0?37YP3`ajH0gg][0P3OQG<30=mcH`030=n5L`3?JeX0aeY:0080af=:00D0j8ek0<mcH`37FTX0
ejJ=0>R^U@030>RfU@030=n^S@3GYXD0eiek0080ciE[00h0ahEJ0:icDP1[>B40>AP@06/a602=FT80
]XES0;IkFP2nSF<0ejj50<N5FP3`cjh0_XeS0;IcBP80ahEJ00@0]W]J0<nEH`37UF/0eiec0P3X_ZH0
2037WHD0aiE[0<NMQ@3?[YD0l>SO0?3Xj03hl>P0l>SX4000000P0?ooo`l0000000`0n?Sh0?3`n03h
n?P0j=OG0=o?_P3?[YD0]XES0:IkFP25DST0UEXa08e:<@1S:A0206/i8@040:J5J`3`ckH0l<nf0?37
[P<0l<NV0P3OQG<0103ONf/0gg=S0=mcH`3OQG<20<m[FP030<MJBP37HdX0j8ek0080cg=S00<0aeY:
0>R^U@3X]YD00`3X]YD00`3GYXD0eiek0=NMN`020<nEJ`0D0:icDP1[>B40JcTQ03TH401[<AP0]XES
0<NEJ`2fNeX0_XeS0<N5FP3O[XD0l<n^0;j=H`2fLdX0ahEJ0:i[@P2fNeX0ciES0<NEJ`3GWG<20>Rn
YP080<NMQ@37UF/0_YEk0<n^U@3`j=l0l>SX0?S`j03`j>P@00000200oooo3`0000002@3hn?P0l?3h
0?Shn03XemL0glnn0<NEJ`2fQF<0YW]J08EB>@0209EJ<@0306<Y401[>B40JcTQ00<0l<nf00@0l<N^
0?37YP3`ajH0gg][0P3OQG<30=mcH`030=n5L`3?JeX0aeY:0080af=:00D0j8ek0<mcH`37FTX0ejJ=
0>R^U@030>RfU@030=n^S@3GYXD0eiek0080ciE[00h0ahEJ0:icDP1[>B40>AP@06/a602=FT80]XES
0;IkFP2nSF<0ejj50<N5FP3`cjh0_XeS0;IcBP80ahEJ00@0]W]J0<nEH`37UF/0eiec0P3X_ZH02037
WHD0aiE[0<NMQ@3?[YD0l>SO0?3Xj03hl>P0l>SX4000000T0?ooo`008P3oool>000000@0n?3h00d0
j=O?0=O7]P37UF/0[W=B09ES@P2=BS40UEXa06/a601k@R40Jc4H09EJ<@3`ckh0l<nf0080l<N^00H0
l<NV0=n5L`2^Le80WDXa0:i:<@2^Le820;iB@P0:0<MJBP2fDST0WC4Q09e2:@2^BS40SC4Q09e2:@25
@RT0UEY20=n5L`80j;JE0`3O[Xd0403GWG/0eiec0=NMN`37QF<0]W]J04XH200i6100JcTQ07=:<@25
FT80ejJ509EJ<@3GYXD0]W]J0>RnW@3`cjh20<nEJ`0@0;I[>@2fNeX0_XeS0<N=H`2fNeX0j;jE0>Rn
YP3G_Zh0eiec0=N^Q@3G]ZH0j=oG0?3`j03`j=l0n?3h0?3`j0l00000803oool>0000000?0?S`n03h
n?P0n?3h0?S`n03Xell0elNf0=NML`2^Le80UF=208e:<@2EFS40QDXY07]28@1[<AP0UEXa0080l<nn
0P3`ajh04P3`ajH0j8ek0=n5L`2MBS40[TXa0;iB@P2^Le80_U920<MJBP2fDST0WDXa09da8@2^BS40
SC4Q0:i2<@2M@RT0QD8Y0=n5L`<0j;JE0P3O[Xd20=NMN`0Q0=NML`3GWG/0]W]J08eJ@P1:60P0>AP@
06/i8@25FT80_XeS0=NVQ@2EFS40]W]J0=NMN`3X_Yd0l<n^0<nEJ`2fJcT0ahEJ0;IkFP2nSF<0aheS
0=N^Q@3X_YD0j;jV0=Nn[P3GWG<0aif50=NfYP3XgmL0l?3X0?3Xg`3hl?P0l?3X00l00000803oool>
000000@0n?3h00d0j=O?0=O7]P37UF/0[W=B09ES@P2=BS40UEXa06/a601k@R40Jc4H09EJ<@3`ckh0
l<nf0080l<N^00H0l<NV0=n5L`2^Le80WDXa0:i:<@2^Le820;iB@P0:0<MJBP2fDST0WC4Q09e2:@2^
BS40SC4Q09e2:@25@RT0UEY20=n5L`80j;JE0`3O[Xd0403GWG/0eiec0=NMN`37QF<0]W]J04XH200i
6100JcTQ07=:<@25FT80ejJ509EJ<@3GYXD0]W]J0>RnW@3`cjh20<nEJ`0@0;I[>@2fNeX0_XeS0<N=
H`2fNeX0j;jE0>RnYP3G_Zh0eiec0=N^Q@3G]ZH0j=oG0?3`j03`j=l0n?3h0?3`j0l00000903oool0
0280oooo3@0000001`3hl>P0n?Sh0?3`j03hl>P0l>SO0=o?a`3G[Xd00P2MJdX01P2=FT80SDXY08E:
:@1kBRT0QD8Q08EB<@80l<nf00@0l<n^0?37[P3`cjh0l<NV0P3hckH02P3hekh0l=O70?37[P3hekh0
l<N^0?37YP3hckH0l<Nf0?37[P3X_ZH20>RfW@80j;JE00@0j;JM0>RfU@3X]YD0j:jE0P3O[Xd00`3O
YXD0eiek0=NML`020<nEJ`0808EB<@12<BT0:A0808EJ@P1cBS40WG=B0;j=H`2MHcT20<N5FP80j;jM
00D0eiec0<nEJ`2fLdX0]W=:0;j=H`020<nEJ`050>RnYP3Xajh0aif50<NMQ@3XgmL00P3`j=l0103`
j>P0n?Sh0?Shn03hn?P>00000200oooo3@0000006P3hl>P0n?Sh0?S`n03hl>P0l>SO0=o?a`3G[Xd0
]XES09e[BP2=FT80SDXY08E::@1c@RT0QD8Q08EB<@3`ckH0l<N^0?3?]P3`ajh0l<n^0?37YP3`cjh0
n<nf0?SG_P3`elL0l<Nf0P3`ajh03`3`ajH0n<nf0?SG_P3`akH0j;jV0>RfW@3X_ZH0j;JM0>RfU@3X
]Yd0j;JE0>RfW@3X]YD0j:jE0=n^S@020=nVQ@0>0=NMN`3GWG<0ciE[0;IkFP25DS40@S4Y02T@201c
BS40QEY209ecDP2nSF<0ahEJ0:i[@P37QEX20>RnW@0<0<nEJ`2nSF<0]W=:0;IcBP2nSF<0eiec0<nE
J`3X_ZH0j<N^0<NMQ@37SF<0j=oG0P3`j=l0103`j>P0n?Sh0?Shn03hn?P>00000200oooo3@000000
1`3hl>P0n?Sh0?3`j03hl>P0l>SO0=o?a`3G[Xd00P2MJdX01P2=FT80SDXY08E::@1kBRT0QD8Q08EB
<@80l<nf00@0l<n^0?37[P3`cjh0l<NV0P3hckH02P3hekh0l=O70?37[P3hekh0l<N^0?37YP3hckH0
l<Nf0?37[P3X_ZH20>RfW@80j;JE00@0j;JM0>RfU@3X]YD0j:jE0P3O[Xd00`3OYXD0eiek0=NML`02
0<nEJ`0808EB<@12<BT0:A0808EJ@P1cBS40WG=B0;j=H`2MHcT20<N5FP80j;jM00D0eiec0<nEJ`2f
LdX0]W=:0;j=H`020<nEJ`050>RnYP3Xajh0aif50<NMQ@3XgmL00P3`j=l0103`j>P0n?Sh0?Shn03h
n?P>000002@0oooo000R0?ooo`d0000000P0n?3h0?S`j03hl?P0l>SX0=o7]P3X_Yd0aif509ES@P80
QE8a00D0QDXa06/a601kBRT0Nd8Q0=NfYP020?3?]P030?S7]P3hckH0l<N^00<0n<nf00D0n=Nn0?S?
]P3hckH0n=Nn0?37YP020?37[PD0j;JM00D0j;jM0?37YP3X]Yd0j;JE0>RfW@020>R^U@040=n^S@3O
YXD0eiek0=n5L`80ciE[01/0UEY2058Q40128AP0LdXa08EB<@2MLe80aif509eS>@2EFS40_XeS0=n^
U@3X_Yd0l<NV0=N^Q@37QEX0aheS0;IcBP2fNeX0ciE[0>RnYP3Xajh0eiec0=N^S@3`j=l0l>SX0>SO
e`3`j=l00`3hn?P>00000200oooo3@000000203hl?P0n?3X0?S`n03`j>P0glNf0>RnW@37WHD0[W=B
0P25DS401@25BS40Jc4H07]::@1k@R40ekJV00<0l<nf00X0n<nf0?37[P3hckH0l<N^0?S?]P3hekh0
n<nf0?SG_P3hckH0l<NV0`3`ajh30>RfW@090>RnW@3X]Yd0j;jM0>RfW@3X]YD0j;jM0>RfW@3X[YD0
gjj=0080gjJ50140eiek0=n5L`3?UF/0]W]J09EJ@P1B8A00@R4H08EB<@2VQF/0WG=B0<NMQ@2EFS40
aheS0;j=H`3O[YD0j;jM0=N^Q@020<N5FP0<0<N=H`2fLdX0]W]J0<nEJ`3X_ZH0j<N^0=NML`37UF/0
l>SO0?3Xj03XgmL0l>SO0`3hn?P>00000200oooo3@000000203hl?P0n?3X0?S`n03`j>P0glNf0>Rn
W@37WHD0UF=20P25DS401@25BS40Jc4H07]::@1k@R40ekJV0080l<nf00<0n<Nf0?S?]P3`ajh00`3h
ckH01@3hekh0n<nf0?S?]P3hekh0l<NV0080l<N^1@3X]Yd01@3X_Yd0l<NV0>RfW@3X]YD0j;JM0080
j:jE00@0gjj=0=nVQ@3GWG/0ghEc0P3?UF/06`2EFT80DR4@048Q601cBS40QE8a09ecDP37WHD0WF<i
09EJ<@2nSF<0gjjE0>RnW@3`ajH0ejj50<N5FP37SF<0]W=:0;IkFP3?UF/0j;jV0>S7[P3GWG<0ejj=
0?3Xg`3`j>P0j=oG0?3Xg`030?Shn0h00000903oool00280oooo3@0000040?S`n0070=o?a`37WHD0
]W]J09e[BP25BRT0QDXa06/i8@0307]::@<0l<nf00<0n<nf0?S7]P3hakH01P3hckH01`3`ckH0l<N^
0?37YP3`ajH0j;JM0>RnW@3`_Yd00P3X]Yd0103`ajH0j;JM0?37YP3X]Yd20>R^U@050>RfU@3O[Xd0
gjJ50=nVQ@3GWG<00P3?UF/02`2MJdX0Ld8Y05Xi:@0i6100Le9209ES@P2MHcT0[W=B09eS>@2VNeX0
ciE[0080j;jE00/0ciE[0<N5FP2nSF<0]W=:0;j=H`3GWG<0ejj50>RnYP3?[YD0aiE[0>SGc`020?3X
g`040>SGa`3hl?P0n?Sh0?Shn0h00000803oool=00000080n?3h00T0n?3X0?S`n03OclL0aif50;Ik
FP2MHcT0QDXY08E:<@1[>B400`1kBRT20?3?]P060?37]P3`ckH0n<Nf0?S7]P3hckH0l<nf1@3hckH0
2@3`ajh0l<NV0?37YP3`ajH0j;JM0?2nW@3X]Yd0j;jV0>RfW@020?37YP80j;JM0P3X[YD03@3O[Xd0
gjJ50=nMN`3OYXD0eiec0<nEJ`37QF<0WF]:07=2:@1J>BT0Le9208EB>@2EHd800P2MHcT0202fNeX0
YW]J0<nEJ`3X_YD0ciE[0=NML`37QEX0_XeS0P2fLdX01P3GWG<0ejj50>RnYP3?[YD0eiek0>SGc`80
l>SO00@0j=O70?S`n03hn?P0n?Sh3P00000P0?ooo`d00000103hl?P01`3OclL0aif50;IkFP2MJdX0
QDXY08E:<@1[>B400`1kBRT30?3?]P030?S?]P3hakH0n<Nf00H0n<nf00L0l<nf0?37[P3`ajH0l<NV
0>RfW@3X_Yd0l;jM0080j;JM00@0l<NV0>RfW@3`ajH0j;JM0P3X[YD01@3X]YD0gjj=0=nVQ@3OYXD0
eiec0080ciE[00/0WF]:07=2:@1J>BT0>AP@07=B@P2EHd80WF<i0:icDP2MHcT0YW]J0<nEJ`020>Rn
U@0;0<nEJ`37QEX0_XeS0;IcBP2nSF<0eiec0=N^Q@3X_ZH0cjjE0<NEJ`3Xell00P3`j=l0103XelL0
n?3h0?Shn03hn?P>000002@0oooo000R0?ooo``000000P3hn?P0403hl?P0n?3X0=o?a`3GakH0_YEk
0;IcBP25BRT0SEY206/i8@1kBRT0Jc4H08E::@1[>B40l<nf0?37]P3`ckH30?S?]P060?S7]P3hckH0
n<nf0?S?]P3`ckH0n<nf0P3`ajH0203X]Yd0l<NV0>R^S@3X]YD0j;jM0>RfW@3`_Yd0l<NV0P3`]Yd0
8P3`ajh0j;JM0>RfW@3X[YD0j:j=0=nVQ@3GWG/0eiec0=n5L`37QF/0]W=:07=:<@1B8A00DRTH07=:
<@2EJe80WG=B0;J5H`2MJdX0UF=20;jEN`37SF<0gjIc0?37YP37NdX0aheS09e[BP37UF/0eiek0=NM
L`3X_ZH0cjjE0;j=H`3XelL30?3Xj0@0n?Sh3@00000P0?ooo``000000P3hn?P20?S`n00<0=o?a`3G
akH0_YEk0;IcBP2MJdX0SEY206/i8@1kBRT0Jc4H07]::@1[>B40l<nf0P3`akH0103`ckH0n<nf0?S?
]P3hakH30?S?]P0@0?3?]P3hckH0n<nf0?37YP3X]Yd0l<NV0>RfW@3X[Xd0j;jM0>RfW@3`]Yd0l;jM
0?37YP3`]Yd0l<N^0?37YP80j;JM01l0j:j=0=nVQ@3OYXD0eiek0=NML`37QF/0ahES0;IcBP1cBS40
DR4@07=:<@2=HdX0UF]B09ecDP2MJdX0SEY209ES@P2nUG/0aheS0?37YP3G[XD0ag]:0<N=H`2MJdX0
_XeS0=NMN`3GWG<0j;jV0<n^U@3XakH0j=O700<0l>SX103hn?P=00000200oooo300000020?Shn00@
0?S`n03hl>P0glo70=O7]P2nUG/0]W=:08E::@2=FT80JcTQ07]::@1[<AP0QDXY06/i8@3`ckH0l<Nf
0?3?]P<0n<nf00H0n<Nf0?S?]P3hckH0n<nf0?3?]P3hckH20?37YP080>RfW@3`ajH0j:j=0>RfU@3X
_Yd0j;JM0?2nW@3`ajH20?2fW@0R0?37[P3X]Yd0j;JM0>R^U@3X[Xd0gjJ50=NMN`3GWG<0ghEc0<N5
J`2fLdX0LdXa058Q401B:AP0LdXa09E[DP2MLe80]XES09e[BP2EHd80_YEk0<N=H`3OYW<0l<NV0<Mk
BP37SF<0WF]:0<NEJ`3GWG/0eiec0>RnYP3?[YD0_XeS0>SGa`<0l>SX103hn?P=000002@0oooo000R
0?ooo``0000000X0n?Sh0?S`j03hn?P0n?3h0>RnW@2nUG/0[W=B09ES@P2=BS40NdXY0P1[>B400`1k
BRT0Jc4H0>S7]P020?37]PD0n<nf00/0l<n^0?S?]P3hckH0n<nf0?2fW@3X[Yd0j;JE0=nMN`3OYXD0
eiek0=NVQ@020=n^S@030>RfW@3`_Yd0l;JM0080l<NV00D0l;JM0?37YP3`]YD0j:jE0=n^S@020=NM
N`0A0=NML`37QF/0]W]J09EJ@P1J>BT0:A08048Y8@25DS40WF]:08EB>@2fLdX0WF<i07]::@3GYXD0
ahEJ0=NML`37UF/00P37SF<0102fNeX0ahEJ0<NEJ`3X_Yd20=Nn[P80j=O?00<0j<o70?Shn03hn?P0
0`3hn?P=00000200oooo300000002P3hn?P0n?3X0?Shn03hl?P0j;jM0;jEN`2^Le80UF=208e:<@1k
BRT206/i8@80NdXY00@0j<Nf0?37]P3`akH0n<Nf1@3hckH01`3`cjh0n<nf0?S?]P3`ajh0l;JM0>Rf
U@3OWG/00P3OYXD01P3GWG/0gjj=0=n^S@3X]YD0j;JM0?2nW@<0l<NV00D0l;JM0?37YP3X[YD0gjj=
0=nVQ@020=NMN`0:0<N5J`37QF<0]W]J09EJ@P1J>BT0@RTQ07=:<@25DS40WF]:0;IcBP80WF<i00D0
NdXY0=NVQ@3GWG<0l<n^0<NEJ`020<N=H`060;J=L`37QEX0aiE[0>RnW@3G_Zh0glnn0P3Xell00`3X
clL0n?Sh0?Shn0030?Shn0d00000803oool<0000000:0?Shn03hl>P0n?Sh0?S`n03X_Yd0_YEk0:ic
DP2EHd80SDXa07]::@80JcTQ00<0NdXY06/a603XakH00P3`akH50?S?]P0;0?3?[P3hckH0n<nf0?S?
]P3`]Yd0j:jM0>RfU@3OWG/0gjJ50=NMN`3GYXD00P3O[Xd00`3X]Yd0l;jM0?2fW@020?37YP050?2f
W@3`ajH0l;JE0>R^U@3O[Xd00P3GWG/04@3GWG<0ahE[0;IkFP2EFT80FSTY02T@2012:B40QE8a09e[
BP25DST0]W=:09eS>@1kBRT0ejJ50<N5FP3GWG<0aiE[0080aheS00@0]W]J0<N5FP37UF/0j;jM0P3G
_Zh20>SGc`030>S?a`3hn?P0n?Sh00<0n?Sh3@00000T0?ooo`008P3oool;000000@0n?Sh0100l>SX
0=N^S@2fQF<0UF=208EB<@1[>B40NdXY07=2:@1kBRT0QD8Y05Xa8@3`akH0j<N^0?37[P3hckH0n<Nf
0P3hekh20?S?]P030?S7]P3`elL0giek0080l<N^00P0l;JM0>RVU@2fHd80ahE[0=nMN`2fNeX0eiec
0>RfW@80l<NV0P3`ajh05P3`ajH0l;JM0>RfW@3X[YD0j:j=0=nVQ@3GWG/0eiec0<nEJ`2fJe80[V=2
07=2:@0i6100@RTQ07=:<@25DST0QEY209e[BP25DS40WF]:08eJ@P2nSF<20=n^Q@070<N5FP2nSF<0
WF<i0;IkFP3GWG<0j;jE0=Nn[P020?3Xj0030=NfYP3hn?P0n?Sh00D0n?Sh3000000P0?ooo``00000
103hn?P0303G[Xd0]XES09ES@P25DS40SDXa07]::@1c@RT0NdXY08E2:@1[<AP0l<Nf0>S7[P80l<N^
00<0n<nf0?SG_P3hekh00`3hckH01P3`elL0giek0=mkJ`3`ajh0l;JM0>RVU@80]V=200H0ahE[0;Ik
FP3GWG<0gjj=0>RfW@3`ajH30?37[P040?37YP3`]Yd0j:jE0>R^S@80gjJ500X0eiek0<nEJ`37QF<0
]V]B0:iS@P1c@RT0@RTQ05Xa8@1cBS40QE8i0P2MJdX02025DS40WF]:08eJ@P3O[XD0eiec0=n^Q@37
QEX0_XeS0P2fNeX01P3GWG<0j;jE0=Nn[P3?[YD0l>SX0=NfYPH0n?Sh3@00000P0?ooo`/00000103h
n?P0403`j>P0ejj=0;J5H`2EHd80QE8a06/i8@1kBRT0Ld8Y07]::@25@RT0FS4Q0?37]P3Xajh0l<N^
0?S?]P3hakH20?SG_P80n<nf00<0n<Nf0?3Ga`3OWG/00P3`ajh0203`]Yd0j:JE0;IS@P37QF/0giek
0;IkFP3GWG<0j;JM0P3`ajH20?37[P0F0?37YP3`]Yd0j;JM0>R^U@3X[Xd0gjJ50=NMN`3GWG<0ciE[
0;I[DP2^Hd80Ld8Y03TH4012:B40LdXa08EB>@25FT80WF]:08EB<@2MJdX0SEY20;j=H`80gjj500L0
ahEJ0;j=H`2MHcT0]W]J0=NML`3X_YD0ekj^0080l>SX00<0ekJV0?Shn03hn?P01@3hn?P<000002@0
oooo000R0?ooo`/00000103hn?P05`3Xgml0aiE[0:icDP2EHd80WF<i07]::@1[>B40Nd8Q07]::@1[
>B40QE8i0?37]P3`ajh0l<nf0?SG_P3hckH0n<Nf0?SG_P3hakH0l<n^0?S?]P3hekh0l<nf0080n<Nf
00P0l<N^0>RfU@3O[Xd0j:j=0>RfU@3OYXD0cheS0>RfW@@0l<N^00L0l;JM0?37YP3`ajH0l;JE0>R^
S@3OYXD0eiek0080ciE[01D0ag]J09ecDP2=FT80:A0803TH401J@ST0Le9208eJ@P25DST0QE8a09EJ
<@1B:AP0ejj50<n=H`3X_Yd0]W]J0;j=H`2MJdX0_XeS0<NEJ`3?[YD00P3OakH0103G]ZH0n?Sh0?Sh
n03hl?P40?Shn0030?S`n0000000000000X00000803oool<000000<0n?Sh0280n?3h0<NEJ`2^Le80
UF=209eS>@1kBRT0JcTQ07]28@1kBRT0JcTQ05Xa8@3`akH0l<N^0?3?]P3hckH0n=Nn0?S7]P3hekh0
n<Nf0?S?]P3`cjh0n=Nn0?3?]P3`akH0n<Nf0?37[P3X]YD0gjj=0=n^U@3X[Xd0gjJ50<n=H`3GWG/0
j;JM103`ajh08@3`]Yd0l<NV0?2fU@3X[Xd0gjj=0=nVQ@3GWG/0ciE[0<N5H`37NeX0WG=B08eJ@P0i
6100@RTQ05Y2>@1cDT80QE8i09ecDP25DS40UEXa058Y603?SF<0ciES0>RnW@2fNeX0_XeS0:icDP2n
SF<0aiE[0<n^U@3OakH0ajjM0=NfYP020?Shn0030?S`n03hn?P0n?Sh0080n?Sh3@00000P0?ooo`/0
0000103hn?P05`3Xgml0aiE[0:icDP2EHd80WF<i07]::@1[>B40Nd8Q07]::@1[>B40QE8i0?37]P3`
ajh0l<nf0?SG_P3hckH0n<Nf0?SG_P3hakH0l<n^0?S?]P3hekh0l<nf0080n<Nf00P0l<N^0>RfU@3O
[Xd0j:j=0>RfU@3OYXD0cheS0>RfW@@0l<N^00L0l;JM0?37YP3`ajH0l;JE0>R^S@3OYXD0eiek0080
ciE[01D0ag]J09ecDP2=FT80:A0803TH401J@ST0Le9208eJ@P25DST0QE8a09EJ<@1B:AP0ejj50<n=
H`3X_Yd0]W]J0;j=H`2MJdX0_XeS0<NEJ`3?[YD00P3OakH0103G]ZH0n?Sh0?Shn03hl?P40?Shn003
0?S`n0000000000000X00000903oool00280oooo2`000000403hn?P0n?3X0?Shn03hn?P0j=O?0;j=
H`2EHd80UEY206/i8@25BS40Ld8Y07]::@25BS40HbT@0:IkH`3Xajh20?S7]P090?3Ga`3hekh0n=Nn
0?SG_P3`elL0n<nf0?S7]P3hekh0l<Nf0080l=O700P0n<Nf0?37YP3X]YD0j:jM0=n^U@3O[Xd0gjJ5
0?2fW@80l<N^00<0n<Nf0?37[P3`ajh00`3`]Yd00`3X]YD0gjj=0=nMN`020=n5L`0E0;IkFP2^Jd80
UF=202T@20128AP0LdXa08EB>@2EHd80Ld8Y08EB<@2EFS40FS4Q0<NEJ`2nSF<0j;jM0;IkFP2nSF<0
[W=B0;J5H`2nUG/0ejj=0080glNf00@0glnn0?Shn03hn?P0n?3h1@3hn?P<00000200oooo30000000
303hl>P0n?Sh0?Shn03hn?P0_XeS09ES@P2EFT80JcTQ07=:<@1c@RT0NdXY08E:<@80HbT@00D0j<N^
0?S7]P3hakH0n<Nf0?3Ga`020?SG_P050?3Ga`3hckH0n<nf0?SG_P3`akH00P3`elL00`3hakH0l<NV
0>RfU@020>R^W@060=n^S@3OYXD0gjJ50?2fW@3`ajh0n<Nf0`3`ajh20?2fW@0N0>RfU@3X[Xd0gjj=
0=nMN`3OQG<0ahES0;IkFP2^Jd80UF=2048Q600i6100LdXa08EB>@1c@RT0WF]:08EB<@2EFS40FS4Q
0;j=H`3G[XD0j;jM0;IkFP2nSF<0]W]J0;J5H`2nUG/0ejj=0=o7]P3G_Zh0glnn0P3hn?P00`3hl?P0
n?Sh0?Shn0020?Shn0d00000803oool;0000000@0?Shn03hl>P0n?Sh0?Shn03Xell0_XeS09ES@P2E
FT80JcTQ08E:<@1c@RT0NdXY08E:<@1S:A00YW]S0>S7[P80n<Nf00T0l=O70?SG_P3hekh0n=Nn0?3G
a`3hckH0n<Nf0?SG_P3`akH00P3`elL0203hakH0l<NV0>RfU@3X[Yd0gjjE0=n^S@3OYXD0l;JM0P3`
ajh00`3hakH0l<N^0?37[P030?2fW@030>RfU@3O[Xd0giek0080ghEc01D0]W]J0:i[@P2EHd80:A08
048Q601cBS40QE8i09ES@P1c@RT0QE8a09EJ<@1J<B40aiE[0;j=H`3X_Yd0]W]J0;j=H`2^Le80]XES
0;jEN`3G[Xd00P3OakH0103Ockh0n?Sh0?Shn03hl?P50?Shn0`00000903oool00280oooo2`000000
403hn?P0n?3h0?S`n03hn?P0j<o70:icDP2=FT80UEXa08EB<@1kBRT0QDXY08e:<@1k@R40DRTH0>S7
]P3`akH20?S?]P80n=Nn00D0l=O70?SG_P3`elL0n<Nf0?37[P020?SG_P0:0?SOe`3`elL0n<Nf0?37
[P3X_ZH0j:JE0=n^U@3O[Xd0gjJ50?2fW@80l<N^00<0l<n^0?37[P3`ajh00P3`ajH20?2fW@0F0>R^
S@3OYXD0giek0<nEJ`2fNeX0[V]209EJ<@1B:AP060P807=2:@1B:AP0WF<i08EB<@1k@R40QE8a08eJ
@P2^Le80aheS0=nVN`3GWG<0]W]J0;j=H`80]W]J00@0cjjE0>S7[P3G]ZH0n?3h1P3hn?P20?S`n0`0
0000803oool<00000080n?3h00d0n?Sh0?S`n02^Le80SEY209EJ<@25DS40NdXY08E::@2=BS40Nd8Q
058Y601J>BT0l<Nf0080n<nf0P3hekh01@3`elL0n=Nn0?3Ga`3hekh0n<Nf0080n=Nn0140l=O70?SO
e`3hakH0l<N^0>RnYP3X[YD0j:JE0=n^S@3OYXD0j:jE0?2fW@3`ajh0l<n^0?37[P3hakH0l<N^0?37
YP020?2fW@0B0>R^U@3X[Xd0gjJ50<nEJ`37QF/0]W]J0:i[@P2EFS4060P8048Q601c@RT0DRTH08EB
<@2MJdX0Nd8Q08EB<@2=FT80aheS0P3OYW/00`3GWG<0]W]J0:icDP020;IkFP040<n^U@3Xajh0j<o7
0?S`n0H0n?Sh00<0n?3h0000000000002`00000P0?ooo`/000000100n?Sh0?S`n03hl?P0n?Sh0>S?
a`2^Le80SEY209EJ<@25DS40NdXY08E::@2=BS40Nd8Q058Y603XakH0l<Nf0P3hckH20?SG_P050?3G
a`3hekh0l=O70?S7]P3`ajh00P3hekh02P3hgmL0l=O70?S7]P3`ajh0j;jV0>RVU@3O[YD0gjj=0=nV
Q@3`]Yd20?37[P030?3?[P3`ajh0l<N^0080l<NV0P3`]Yd05P3X[Xd0gjJ50=nMN`3?UF/0]W]J0:i[
@P2EFS40DRTH01P8201c@RT0DRTH09eS>@25DS40Nd8Q08EB<@2=FT80[W=B0<N=H`3OYW/0eiec0;Ik
FP2nSF<20;IkFP040<n^U@3Xajh0ekJV0?S`n0H0n?Sh0P3hl?P<000002@0oooo000R0?ooo`/00000
0140n?3h0?Shn03hn?P0n?Sh0;J5J`2EHd80QDXY06/i8@25DST0QDXa07]::@0i6100DRTH058Q403`
ajh0n<nf0?SG_P060?3Ga`80n=Nn00P0n<Nf0?3?_P3hekh0n<Nf0?37]P3`]Yd0j;JM0=n^S@80gjjE
01T0j;JM0?37[P3`ajh0l<Nf0?S7]P3hckH0n<Nf0?37[P3`ajH0l<N^0?2fW@3X[YD0j:j=0=NVQ@3O
YXD0ahES0:icDP2MJdX0SDXa02T@201B:AP0Ld8Y07=:<@25DS40WF<i0080QE8a00/0YW]J0;j=H`3O
[Xd0l<n^0;IkFP2fLdX0YW]J0;J5H`3?[YD0glNf0=o?_P090?Shn0`00000803oool;000000@0n?Sh
00d0l?3h09ES@P25BRT0JcTQ08EB>@25BS40NdXY03TH401B:AP0DR4@05Xi:@3hckH0n=Nn00L0l=O7
00`0n=Nn0?S7]P3`ckh0n<Nf0?SG_P3`akH0l;JM0>RfW@3GYXd0gjj=0=n^U@3X]Yd30?37[P040?S7
]P3hckH0l<Nf0?S7]P80l<N^0P3`]Yd02`3X[YD0j:j=0=nVQ@3?UF/0ahES0:icDP2MJdX0:A08048a
:@1B:AP0Ld8Y0080QE8a00h0WF<i08EB<@25DS40_XeS0<nEH`3O[Xd0l<n^0;IkFP2MJdX0YW]J0;J5
H`3?[YD0glNf0?S`n0T0n?Sh3000000P0?ooo`/000000140n?3h0?Shn03hn?P0n?Sh0;J5J`2EHd80
QDXY06/i8@25DST0QDXa07]::@0i6100DRTH058Q403`ajh0n<nf0?SG_P060?3Ga`80n=Nn00P0n<Nf
0?3?_P3hekh0n<Nf0?37]P3`]Yd0j;JM0=n^S@80gjjE01T0j;JM0?37[P3`ajh0l<Nf0?S7]P3hckH0
n<Nf0?37[P3`ajH0l<N^0?2fW@3X[YD0j:j=0=NVQ@3OYXD0ahES0:icDP2MJdX0SDXa02T@201B:AP0
Ld8Y07=:<@25DS40WF<i0080QE8a00/0YW]J0;j=H`3O[Xd0l<n^0;IkFP2fLdX0YW]J0;J5H`3?[YD0
glNf0=o?_P090?Shn0`00000903oool00280oooo2`0000001P3hn?P0n?3h0?S`n03hl?P0]XE[09EJ
<@80NdXY00H0QE8i07]::@25BS40DRTH048Q601B:AP20?3?]P040?SG_P3`elL0l=O70?3Ga`<0n=o?
0`3hekh0303hckH0n=Nn0?SG_P3`ajh0l;JM0=n^U@3O[Xd0j;JE0>RfW@3X_ZH0l<nf0?37]P80n<Nf
00<0n=Nn0?S7]P3`akH00P3`ajh0703`]Yd0j;JM0=n^U@3OYXD0eiek0<N5H`2fJe80WF]:09ES@P12
8AP0FS4Q058Y6025DST0SEY209EJ<@2MHcT0QE8a09ecDP37WHD0gjj50?3?[P2^Le80aheS0;J5H`2^
Le80j;jE0>S?_P3Ockh90?Shn0`00000803oool;000000D0n?3h00`0UEXa07]::@1kBRT0QE8i07=:
<@25BS40DRTH048Q601B:AP0cjjE0?3?]P3hekh30?3Ga`<0n=o?00P0l=O70?SG_P3hekh0n<nf0?37
]P3hekh0l<N^0?2fW@80gjjE00d0gjj=0>RfW@3X_ZH0l<N^0?3?]P3`akH0n<Nf0?SG_P3`ckh0n<Nf
0?37]P3`ajh0l;JM0080j;JM01T0gjjE0=NMN`3GWG<0ahES0;I[DP2MJdX0@R4H024@201J<B40DRTH
08eJ@P1kBRT0UEXa09eS>@25DS40aif50=NML`3O[XD0l<n^0:icDP2=FT80]XES0:icDP3X_YD0j<nn
00X0n?Sh3000000P0?ooo`/0000000H0n?Sh0?S`n03hl?P0n?3h0;J5J`2EFS4207]::@0608EB>@1k
BRT0QDXa058Y60128AP0DRTH0P3`ckH0103hekh0l=O70?3Ga`3`elL30?SOc`<0n=Nn00`0n<nf0?SG
_P3hekh0l<N^0?2fW@3O[YD0gjj=0>RfU@3X]Yd0j;jV0?3?]P3`akH20?S7]P030?SG_P3hakH0l<Nf
0080l<N^01`0l;JM0>RfW@3O[YD0gjJ50=NMN`37QF<0]V]B09e[BP2EHd80@R4H05Xa8@1B:AP0QE8i
08eJ@P2EFS40WF<i08EB<@2MLe80aif50=n^Q@3`cjh0[W=B0<N=H`2fQF<0[W=B0>RnU@3Xckh0glnn
2@3hn?P<000002@0oooo000R0?ooo`/0000000L0n?Sh0?S`n03hl?P0n?Sh09ecDP2=FT80Ld8Y0080
QE8a00X0NdXY058Y60128AP0>AP@0?2fW@3hakH0n=Nn0?SOc`3`elL0n=o?1`3`elL30?SG_P030?S7
]P3`ajh0j;JM0080j;JE00P0j;JM0>RnYP3`akH0l=O70?SG_P3hakH0l=O70?SG_P80l<nn00`0l<Nf
0?37[P3`]Yd0j;JE0=n^S@3GYXD0eiec0;IkFP2MJdX0WF<i07=2:@1[>B4207=:<@0?09ES@P2MHcT0
SEY208e:<@2MLe80ejJ50=N^Q@3X_ZH0_XeS0;IcBP2VNeX0]W]J0=n^S@3XelL0l?3X00L0n?Sh00<0
n?3h0?Shn00000002`00000P0?ooo`/0000000L0n?Sh0?S`n03hl?P0n?Sh0=o7a`2=FT80Ld8Y0080
QE8a00P0QDXa058Y60128AP0>AP@0?2fW@3`ckh0n=Nn0?SOc`80l=O700<0n=o?0?3Ga`3`elL0103`
elL02P3hekh0n<nf0?SG_P3hakH0l<N^0>RfW@3O[YD0j;JE0>RfW@3X_ZH20?37]P0S0?3Ga`3hakH0
l=O70?S7]P3hekh0l<nn0?37]P3`ajh0j<N^0?2fW@3X]YD0ejJ50=NMN`3GWG<0]W]J09e[BP1c@RT0
HbT@06/i8@1cBS40UF=208EB<@2MHcT0SEY208e:<@3GYXD0eiec0=N^Q@3X_ZH0_XeS08EB<@2VNeX0
]W]J0=n^S@3XelL0203hn?P00`3hl?P0n?Sh0000000;00000200oooo2`0000001`3hn?P0n?3h0?S`
n03hn?P0WG=B08eJ@P1c@RT00P25DS402P1kBRT0DRTH048Q600i6100l;JM0?S7]P3hekh0n=o?0?3G
a`3hgll70?3Ga`<0n=Nn00<0n<Nf0?37[P3X]Yd00P3X]YD0203X]Yd0j;jV0?37]P3`elL0n=Nn0?S7
]P3`elL0n=Nn0P3`ckh0303`akH0l<N^0?2fW@3X]YD0gjj=0=NVQ@3GWG<0]W]J09e[BP2MHcT0Ld8Y
06/i8@80LdXa00l0UF=209eS>@2=FT80SDXa09ecDP3GYXD0ejj50>RnYP2nSF<0]W=:0:IkFP2fNeX0
gjj=0>SGa`3`l>P01`3hn?P00`3hl?P0n?Sh0000000;000002@0oooo000R0?ooo`/00000103hn?P0
302EFS40QE8a05Xa8@1kFT80LdXa08E:<@1B:AP0JcTQ05Xi:@3`ajh0l=O70?SG_P80l=O700D0n=o?
0?3Ga`3`elL0n=Nn0?SOc`030?3Ga`@0n=Nn00@0n<Nf0>RfW@3X]Yd0j;jM0P3X_ZH01P3`ckH0n=Nn
0?3?_P3hekh0l=O70?S7]P<0l<nn00X0l<Nf0>RnYP3X]Yd0gjjE0=n^S@3GWG<0ag]J0;I[DP2EFT80
LdXa0P1[>B403`25DST0QE8a09ES@P2=FT80UG=J0;J5J`3GWG/0eiec0=N^Q@37SF<0[V/i0:IkFP2n
UG/0ejj=0>SOe`0:0?Shn0`00000803oool;000000@0n?Sh00@0WG=B08EB<@1J<B40NeY20P1cBS40
1P1B:AP0JcTQ05Xi:@3`ajh0l<Nf0?SG_P80l=O70P3hgll00`3`elL0n=Nn0?SOc`030?3Ga`080?SG
_P3`ckh0n=Nn0?SG_P3hakH0j;JM0=n^U@3X]Yd20>RnYP070>S7[P3`ckH0n=Nn0?SG_P3`elL0n=Nn
0?S7]P020?3?_P0:0?37]P3`ajh0j;jV0>RfW@3O[Xd0eiek0=NML`37NeX0]V]B07=:<@<0JcTQ00H0
QE8a09eS>@2EHd80SEY209EcFP3GWG/20=NML`070=N^Q@37SF<0QDXY0:IkFP2nUG/0ejj=0>SOe`0:
0?Shn0`00000803oool;000000@0n?Sh00`0UEXa08EB<@1J<B40NeY207=:<@25BS40DRTH06/i8@1J
>BT0l<N^0?3Ga`3hekh20?3Ga`050?SOc`3`elL0l=O70?SG_P3hgll00`3`elL40?SG_P040?S7]P3X
]Yd0j;JM0>RnW@80j;jV00H0l<nf0?SG_P3`ckh0n=Nn0?3Ga`3hakH30?3?_P0:0?37]P3X_ZH0j;JM
0=n^U@3O[Xd0eiec0<MkFP2fJe80UEY207=:<@80JcTQ00l0QE8i08EB<@2EHd80SEY209EcFP2fQF/0
eiek0=NML`3G[XD0aheS0:i[>@2VNeX0_YEk0=N^S@3XgmL02P3hn?P<000002@0oooo000R0?ooo`/0
00000P3hn?P0303hl?P0n?Sh09eS>@1cBS40JcTQ08eJ@P25DST0Ld8Y06/i8@1B:AP0YXEc0?S7]P<0
l=O700@0n=o?0?3Ga`3hekh0l=O70P3hekh20?SOc`80l=O700T0n=Nn0?3Ga`3hakH0n<Nf0>RfW@3O
[YD0j;jM0>RnYP3`ajh00`3`ckh20?3Ga`0E0?S7]P3hekh0n<nf0?3?]P3`akH0l<N^0>RnYP3O[YD0
gjj=0=NML`37QF<0]V]B09EJ@P2=BS40FS4Q06/i8@1cBS40QDXa09eS>@2EHd80UEXa00<0eiec00L0
ejJ50=N^Q@2^Jd80[W=B0;J5H`3O[XD0l?3X00X0n?Sh3000000P0?ooo`/000000P3hn?P03@3hl?P0
n?Sh0:icDP1cBS40JcTQ08eJ@P25DST0NdXY06/i8@1B:AP0YXEc0?S7]P3`ckh00P3`elL20?SOc`80
l=O70P3hekh0103`elL0n=o?0?3Ga`3`elL20?SG_P80n<Nf00@0j;JM0=n^U@3O[YD0j;jV0P3`ajh2
0?3?_P80l=O70P3hakH00`3hekh0l<nf0?37]P020?37[P070>RnYP3O[Xd0ejJ50=NML`37QF<0]V]B
08e:<@0205Xa8@0606/i8@25BS40UF=209eS>@2EHd80UEXa0`3GWG<01`3GYXD0ejj50:i[@P2^Le80
]XES0=n^Q@3`l>P02P3hn?P<00000200oooo2`0000020?Shn00<0?S`n03hn?P0WF<i07=:<@1[>B40
SEY208EB>@1c@RT0JcTQ058Y602VQG<0n<Nf0`3`elL0103hgll0l=O70?SG_P3`elL20?SG_P80n=o?
0P3`elL02@3hekh0l=O70?S7]P3hakH0j;JM0=n^U@3X_Yd0j;jV0?37[P030?3?_P80l=O701D0n<Nf
0?SG_P3hckH0l<nf0?37]P3`ajh0j;jV0=n^U@3O[Xd0eiec0<N5H`2fJe80UEY208e:<@1J<B40JcTQ
07=:<@25BS40WF<i09ES@P2EFS400`3GWG<01`3GYXD0ejj50:i[@P2^Le80]XES0=n^Q@3`l>P02P3h
n?P<000002@0oooo000R0?ooo`/0000000h0n?Sh0?S`n03hn?P0_Zj^08eSBP25DS40SEY208EB<@2=
BS40FSTY07=2:@3Xajh0n=Nn0?37]PH0l=O700<0n=Nn0?3?_P3`akH00P3`ckh20?SG_P0=0?S?]P3`
elL0l=O70?SG_P3`ajh0gjj=0=n^U@3O[Yd0j;jM0>S7]P3Xckh0l<Nf0?3Ga`020?3?_P030?37]P3X
akH0l<Nf0080l<N^0P3X_ZH01`3O[Yd0ejJ50=n5L`37QF<0WF]:09EJ<@1B:AP00P1[>B403@1cBS40
SEY208eJ@P2=FT80aif50<NEJ`3GWG<0WF]:0>RnU@25@R40_XeS0<NEJ`3?[YD02`3hn?P<00000200
oooo2`0000003`3hn?P0n?3h0?Shn02n[Zh0UEXa08EB<@2=FT80QE8a08e:<@1[>B40Ld8Y0>S7[P3h
ekh0l<Nf0?SG_P030?3Ga`040?SOc`3`elL0n=Nn0?3?_P80l<Nf0100l<nn0?SG_P3hekh0n<Nf0?S?
]P3`elL0n=Nn0?37[P3X[YD0gjj=0=n^W@3X_Yd0gjjM0>S7]P3Xckh0l=O70`3`ckh20?37]P<0l<N^
00`0j;jV0=n^W@3O[Xd0ejJ50=n5L`37QF<0UEXa07=:<@1B:AP0JcTQ07=:<@2MJdX308eJ@P090<NE
J`3GWG<0eiec09e[BP3X_YD0WF]:0;j=H`37UF/0cjjE00/0n?Sh3000000P0?ooo`/0000000h0n?Sh
0?S`n03hn?P0_Zj^08eSBP25DS40SEY208EB<@2=BS40FSTY07=2:@3Xajh0n=Nn0?37]PH0l=O700<0
n=Nn0?3?_P3`akH00P3`ckh20?SG_P0=0?S?]P3`elL0l=O70?SG_P3`ajh0gjj=0=n^U@3O[Yd0j;jM
0>S7]P3Xckh0l<Nf0?3Ga`020?3?_P030?37]P3XakH0l<Nf0080l<N^0P3X_ZH01`3O[Yd0ejJ50=n5
L`37QF<0WF]:09EJ<@1B:AP00P1[>B403@1cBS40SEY208eJ@P2=FT80aif50<NEJ`3GWG<0WF]:0>Rn
U@25@R40_XeS0<NEJ`3?[YD02`3hn?P<000002@0oooo000R0?ooo`/000000100n?Sh0?S`n03hn?P0
YW][09e[BP1cBS40WF]:07=:<@2=BS40LdXa07]::@3Xajh0n<Nf0>S7[P3`elL0n=o?0`3`elL20?3?
_P0=0?2fW@3Xajh0l<N^0?37]P3`ckh0n=Nn0?S?]P3hekh0l=O70?SG_P3`ajh0gjj=0=NVS@020=n^
U@030>S7]P3`akH0l<nn00H0j<N^00l0l<N^0>S7[P3Xajh0ekJV0>RnW@3GYXD0eiec0<N5H`2^Le80
UEXa058Y601B8A00JcTQ07=:<@2MHcT00P2=FT802@37WHD0ciE[0=NML`25BS40gjj509EJ@P2fQF/0
ejJ50>S7[P020?Shn0030?S`n03hn?P0n?Sh00H0n?Sh3000000P0?ooo`/000000100n?Sh0?S`n03h
n?P0YW][0;J=L`1cBS40WF]:07=:<@2=BS40FS4Q07]::@3Xajh0n<Nf0>S7[P3`elL0n=o?0P3`elL0
1@3hekh0l=O70?3?_P3`]Yd0j<N^0080l<N^00T0l<nn0?SG_P3`ckH0n<nf0?3Ga`3hekh0l<N^0>RV
U@3O[Xd00P3O[YD00`3X_ZH0j<Nf0?37]P020>S7[P060>RnYP3Xajh0j<N^0>S7[P3`ajh0l<Nf0P3X
ajh0303X_Yd0gjj=0=NVQ@3GWG<0ahES09EJ<@25BS40DRTH058Q401cBS40SEY209eS>@80SEY20P3?
UF/01`3GWG<0QDXa0=n^Q@2=FT80]XE[0=NVQ@3Xajh00P3hn?P00`3hl?P0n?Sh0?Shn0060?Shn0`0
0000803oool;0000000@0?Shn03hl?P0n?Sh0:IkJ`2MJdX0LdXa09e[BP1cBS40SDXa07=:<@1kBRT0
j<N^0?S7]P3Xajh0l=O70?SOc`<0l=O70P3`ckh03@3`]Yd0j<N^0?37[P3`akH0l<nn0?SG_P3hckH0
n=Nn0?3Ga`3hekh0l<N^0=n^S@3GYXd00P3O[YD00`3XakH0l<Nf0?3?_P060>S7[P0?0?37[P3Xajh0
j<N^0=NfYP3X_Yd0ejJ50=NML`37QF<0[W=B09EJ<@1B:AP0DR4@06/i8@1cBS40WF<i0080SEY200T0
aif50<nEJ`3GWG<0QDXa0=n^Q@2EFT80]XE[0=NVQ@3Xajh00P3hn?P00`3hl?P0n?Sh0?Shn0060?Sh
n0`00000903oool00280oooo2`0000003P3hl?P0n?Sh0?Shn02=BRT0SEY209E[DP25FT80SEY207=:
<@2MHcT0j:j=0?37[P3X[YD0l<Nf103`elL02P3Xckh0l<Nf0?37]P3`ajh0gjjM0>RnYP3Xajh0l<Nf
0?3?_P3`akH20?3Ga`080?SG_P3`]Yd0giek0=N^S@3GYXd0cjjE0>S7[P3XakH20>RnYP040=NfYP3O
[Xd0gjj=0=NVS@80gjjM0P3X_ZH20>RnW@0E0=NVQ@3?UF/0ahE[0;I[DP2MJdX0Ld8Y03TH401S:A00
JcTQ08eJ@P2MJdX0QE8i0;jEN`3GWG/0_XeS08E::@3X_YD0WF]:0<NEJ`3G[XD0j=O700H0n?Sh00<0
n?3h0?Shn03hn?P00P3hn?P<00000200oooo2`0000003`3hl?P0n?Sh0?Shn02=BRT0]YEk09E[DP25
FT80SEY207=:<@1B:AP0j:j=0?37[P3X[YD0l<Nf0?SG_P030?3Ga`0H0?3?_P3Xckh0l<Nf0?37[P3O
[Yd0gjjE0>RnYP3`akH0l<nn0>S7[P3`akH0l=O70?SG_P3`]Yd0gjjE0=nMN`3GYXd0cjjE0=NfYP3X
ajh0j<Nf0>RnYP3G]ZH0j:jM0P3O[Xd20=n^W@<0j;jV00X0j;jM0=n^U@3GYXD0ciE[0<N5J`2MJdX0
QE8i07=2:@0i6100JcTQ0P2=FT802`2MJdX0QE8i0=NMN`2fNeX0_XeS08E::@3X_YD0SDXa0<NEJ`3G
[XD0j=O700H0n?Sh00<0n?3h0?Shn03hn?P00P3hn?P<00000200oooo2`0000003P3hl?P0n?Sh0?Sh
n02=BRT0SEY209E[DP25FT80SEY207=:<@2MHcT0j:j=0?37[P3X[YD0l<Nf103`elL02P3Xckh0l<Nf
0?37]P3`ajh0gjjM0>RnYP3Xajh0l<Nf0?3?_P3`akH20?3Ga`080?SG_P3`]Yd0giek0=N^S@3GYXd0
cjjE0>S7[P3XakH20>RnYP040=NfYP3O[Xd0gjj=0=NVS@80gjjM0P3X_ZH20>RnW@0E0=NVQ@3?UF/0
ahE[0;I[DP2MJdX0Ld8Y03TH401S:A00JcTQ08eJ@P2MJdX0QE8i0;jEN`3GWG/0_XeS08E::@3X_YD0
WF]:0<NEJ`3G[XD0j=O700H0n?Sh00<0n?3h0?Shn03hn?P00P3hn?P<000002@0oooo000R0?ooo`/0
00000P3hn?P0303oool0WF]:08EB>@2=FT80QE8i09EJ@P1B8A00QDXa0?S7]P3?UF/0gjJ50?3?]P<0
l=O700H0l<nn0=n^W@2nUG/0]Xec0=NVS@3?YYD20=n^W@80l<nn00l0l<Nf0?SG_P3hekh0n=Nn0?37
[P3GWG/0aif50=NMN`3X_Yd0j<Nf0>R^W@3O[Yd0ajJM0;jMS@2fSG<00`37WHD00`3?YYD0j;jV0=n^
W@020=n^W@070=NVQ@37WHD0ahE[0;IkFP2EFT80LdXa06/i8@0205Xa8@0=08EB<@2=HdX0SEY20;J5
J`2nSF<0]W]J09EJ<@3X_YD0UEXa0<NMQ@3GWG<0j=O?0?ooo`0:0?Shn0`00000803oool;00000080
n?Sh00d0oooo09e[BP2VNf<0SEY208EB>@2EFT80DR4@08EB<@3hakH0ciE[0=nVQ@3`ckH0n=Nn0080
l=O700P0l<nn0>S7]P3O[Yd0]Xec0=NVS@3?YYD0_YEk0=n^W@80l<nn0P3`akH20?SG_P0<0?37[P3O
[YD0eiek0=NMN`3X_Yd0gjjM0>S7]P3X[Yd0ajJM0;jMS@2fQF/0]Xec0P37WHD00`3?YYD0j;jM0>Rn
YP020=n^W@0>0=n^S@3GYXD0aif50<N5J`2EFT80QE8i07=:<@1[>B40FS4Q08EB>@25DS40SF=:08eJ
@P2nSF<20;IkFP0709EJ<@3X_YD0SDXa0<NMQ@3GWG<0j=O?0?ooo`0:0?Shn0`00000803oool;0000
0080n?Sh00`0oooo09e[BP25DST0SEY208EB>@2EFT80DR4@08E:<@3hakH0ciE[0=nVQ@3`ckH30?3G
a`060?3?_P3O[Yd0_YEk0;J=L`3GYXd0cjJE0P3O[Yd20?3?_P0?0?37]P3hekh0n=Nn0?SG_P3`ajh0
eiek0<NMQ@3GWG/0j;jM0>S7]P3X[Yd0gjjM0<NVW@2nWHd0]Xec00<0aif500<0cjJE0>RnYP3O[Yd0
0P3O[Yd01`3GYXD0aif50<N5J`2fNeX0UEY207=:<@1[>B400P1J<B403@25DS40SF=:08eJ@P2fQF/0
_XeS0;IkFP2EFS40j;jE09EJ<@37WHD0eiec0>SGc`3oool02P3hn?P<000002@0oooo000R0?ooo`/0
00000P3hn?P0302nWID0YW]J07=:<@25DST0LdXa09EJ@P1J<B40l;JE0?2fW@3XSG/0ejJ=0?3?]P80
l=O700P0l<Nf0>R^W@2nSF<0gjjM0;j^[P1cJf<0Lg=[0<NMQ@80ghEc00<0l<Nf0>S7[P3hekh00P3h
ekh03`3`ajH0eiek0=NVQ@2nUG/0ejJ50<MJBP37QF/0ejJ=0=o7a`2ENg<0YW][0:IkH`2VNeX0YW]S
0;J5J`020=n^U@80gjjM00L0ejJ=0<nEJ`37QF/0]V]B09e[BP1cBS40QE8i0080DRTH00T0QE8i08eJ
@P2MJdX0]XES0;jEN`2fNeX0UE8Y0>RnW@2MHcT00P3G[XD00`3`j>P0n?Sh0?Shn0090?Shn0`00000
803oool;00000080n?Sh01P0_YfE0:IkFP2MLe80QE8i07=:<@2EFT80FS4Q09EJ<@3`]Yd0j8ek0=NV
S@3`ckH0l<nn0?3Ga`3`akH0j:jM0;J5H`2nSF<0_Zj^07=[H`1cLf/0YXEc0<NMQ@3OQG<20?37]P0?
0>S7[P3hekh0n=Nn0?37YP3X]Yd0eiek0;jEN`3GYXD0WDXa0<MJBP37QF/0glO709EkL`1cFTX0YW][
0080YW]S00D0]XE[0=NVS@3O[YD0gjjE0=n^W@020=NVS@070<nEJ`37QF/0WF]:08eJ@P1cBS40QE8i
058Y600208EB>@0808eJ@P2MJdX0_YEk0;IcBP2fNeX0UE8Y0>RnW@2MLe820=N^Q@030?3Xj03hn?P0
n?Sh00T0n?Sh3000000P0?ooo`/000000P3hn?P0302nWID0YW]J07=:<@25DST0LdXa09EJ@P1J<B40
l;JE0?2fW@3XSG/0ejJ=0?3?]P80l=O700P0l<Nf0>R^W@2nSF<0gjjM0;j^[P1cJf<0Lg=[0<NMQ@80
ghEc00<0l<Nf0>S7[P3hekh00P3hekh03`3`ajH0eiek0=NVQ@2nUG/0ejJ50<MJBP37QF/0ejJ=0=o7
a`2ENg<0YW][0:IkH`2VNeX0YW]S0;J5J`020=n^U@80gjjM00L0ejJ=0<nEJ`37QF/0]V]B09e[BP1c
BS40QE8i0080DRTH00T0QE8i08eJ@P2MJdX0]XES0;jEN`2fNeX0UE8Y0>RnW@2MHcT00P3G[XD00`3`
j>P0n?Sh0?Shn0090?Shn0`00000903oool00280oooo2`0000001P3hn?P0oooo0?S`n02VQF/0NdXY
05Xa8@<0QE8i01<0n<Nf0=nVQ@3XSG/0gjjE0>S7]P3`ajh0gjjM0;jEN`2ELeX0]YF=0<Nf]P2ENf/0
][Jn024H601JBT80UG=J0;J5J`2nUG/0l<n^0080n=Nn02P0n<nf0?37[P3X]YD0_YEk0;J=L`2MLe80
_YEk09e[BP3?akh0HeYB0;Jnc`1cLf/0HeYB0;jMU@12<BT0Le920;J=L`2nUG/0ejJ50=NVS@2nUG/0
aiE[0<N5H`2^Le80UEY208E:<@128AP0>AP@048Q6025DST0LdXa0:icDP2MLe80YW]J0;IkFP2^Hd80
ejj508E::@3GWG/0glNf303hn?P<00000200oooo2`0000001P3hn?P0oooo0?S`n02VQF/0QE8a05Xa
8@<0QE8i0300UEY20=nVQ@3XSG/0gjjE0>S7]P3`ckH0gjjM0;jEN`2ELeX0FSTY0;JES@2ENf/0][Jn
024H6025Lf/0FTY20;J5J`2nUG/0j;JM0?3?[P3hekh0n<nf0?37[P3X_Yd0j;JE0;J=L`2MLe80]Xec
0;jEN`2MJdX0HeYB0;Jnc`0Q61P0Lg=[06=JDP12<BT0Le920:IkH`2fSG<0_YEk0=NVS@3GYXD0_YEk
0<NEJ`37QF<0UEY208EB>@25BS42048Q6004058Y6025DST0LdXa0:icDP80YW]J00H0]W]J0:iS@P3G
[XD0_XeS0=NMN`3OakH<0?Shn0`00000803oool;000000060?Shn03oool0n?3h0:J5J`1kBRT0FS4Q
0`25DST04`3hakH0gjJ50>R=N`3O[YD0j<Nf0?37[P3O[Yd0_YEk09EcFP2fUHd0akJf09EkJ`2f][h0
8APH05Y:@P2ELeX0]XE[0;jEN`3`cjh00P3hekh0:03hckH0l<N^0>RfU@2nUG/0]Xec09ecDP2nUG/0
WF]:0<o7_P1SFU80][k?07=cJ`1SFU80_YfE048a:@1cDT80]Xec0;jEN`3GYXD0ejJ=0;jEN`37UF/0
ahES0:icDP2EFT80QDXa048Q600i6100@R4H08EB>@1cBS40[W=B09ecDP2VNeX0]W]J0:iS@P3G[XD0
QDXY0=NMN`3OakH<0?Shn0`00000903oool00280oooo2`0000001P3hn?P0]YEk0=O7a`2VSG<0Ne92
07=:<@80QE8i01<0UEY20?2fW@3XSG/0eiek0=n^S@3`akH0j;JM0<nVU@37QF/0LdXa08ESDP1J@ST0
@RTQ05Xi:@25DST0QF=B0:IkH`2nUG/0j:jE0080n<nf00P0n=Nn0?S?]P3`ajh0j;JM0=nVQ@2nUG/0
ahE[09EcFP80YXf501l0FSTY058Y601J>BT0LdXa05Y2>@1cFTX0Ne920;J5H`2fQF/0ciE[0=NMN`2n
UG/0]XE[0;IkFP2EFT80SEY207=:<@1[>B40@R4H05Xi:@1[>B40LdXa09e[BP2^Le80WF]:0;IkFP2^
Le80ejj509ES@P3GWG<0l>SO00`0n?Sh3000000P0?ooo`/0000000H0n?Sh0;JEN`3GalL0YXec09Ec
FP1cBS4208EB>@0:09EJ@P3?Lf<0j8ek0=NMN`3O[Xd0l<Nf0?3?]P3?YYD0ahE[07=:<@80QF=B01D0
@RTQ05Xi:@25DST0SF]B08ESDP2nUG/0j:jE0?2nW@3hckH0n=Nn0?S?]P3`ajh0l;jM0>RfW@2nUG/0
ahE[0:icDP2ELeX0YXf505Xi:@1B:AP00P1J>BT01P1cBS40LeY:07]B@P2VNf<0]XES0;J5J`80eiek
00<0_YEk0;J5J`2fNeX00P2=FT800`1cBS40JcTQ05Xi:@0206/i8@0:07=:<@2MJdX0WF]:09eS>@2f
NeX0[W=B0=N^Q@2nSF<0eiec0?3Xg``0n?Sh3000000P0?ooo`/0000000H0n?Sh0;JEN`3GalL0YXec
07]B@P1cBS4208EB>@0C09EJ@P3`]Yd0j8ek0=NMN`3O[Xd0l<Nf0>RfW@3?YYD0ahE[07=:<@25He80
FT8i048Y8@1J>BT0QE8i08ESDP2VNf<0_YEk0>R^U@020?S?]P080?SG_P3hckH0l<N^0>RfW@3OYXD0
_YEk0<N5J`2ELeX20:J=Q@0O05Xi:@1B:AP0FSTY07=:<@1J@ST0LeY:07]B@P2fQF<0]XE[0<nEJ`3G
WG/0_YEk0;J5J`2fNeX0UEY208eJ@P1cBS40JcTQ048Q601J>BT0JcTQ07=:<@2MJdX0[W=B09e[BP2f
NeX0[W=B0=N^Q@2EHd80eiec0?3Xg`0<0?Shn0`00000903oool00280oooo2`0000002P3hn?P0[W=B
0;jMU@2fWHd0LdXa08eSBP25DST0LdXa08e:<@3XYYD20=NMN`070=n^S@3`akH0j<N^0>RnYP3O[YD0
_YEk08eSBP0307]B@P0608EB>@37QF/0ejJ50>RfW@3`ajh0n<nf0P3hekh04P3hckH0l<N^0?37YP3X
]YD0gjJ50=NMN`2fQF/0QF=:0:IkH`2VQG<0WG][06=:@P1J@ST0LdXa09ecDP2nSF<0ahE[0<nEJ`80
eiek01@0ciE[0;j=H`2fJe80UEY208eJ@P25DST0Ld8Y058Y601J>BT0FS4Q07=2:@2MLe80]W]J09ec
DP2fNeX0_XeS0=N^Q@2MJdX0ejJ50?3`j0`0n?Sh3000000P0?ooo`/0000000X0n?Sh0:icDP2nWID0
]Yf=08eJ@P2=HdX0QE8i07=:<@2=BS40ahES0P3GWG/0203O[Xd0l<Nf0>S7]P3X_ZH0gjjE0;jEN`2f
Je80SF=:0P1kDT801025DST0UG=J0<N5J`3X]Yd20?37[P030?S?]P3hekh0n<nf0080l<N^01H0l<NV
0=nVQ@3GWG/0_YEk0;J5J`25HdX0YXEc09ekJ`25He80HdY205Y2>@2MLe80_XeS0;J=L`37QF/0ciE[
0=NMN`2nUG/0ciE[0;j=H`2fJe80SEY20P25DST01@1c@RT0FSTY05Xa8@1J<B40Ld8Y0080WG=B00L0
WF<i0;IkFP2nSF<0ejj50;j=H`3GYXD0l?3X00`0n?Sh3000000P0?ooo`/0000000X0n?Sh0:icDP2n
WID0]Yf=07=:<@2=HdX0QE8i07=:<@2=BS40j:JE0P3GWG/01`3O[Xd0l<Nf0>S7[P3X_ZH0gjjE0;jE
N`2=HdX00`1kDT801P25DST0ahE[0=NVQ@3X]Yd0l<N^0?S?]P80n=Nn0180n<nf0?37[P3`ajH0j;JE
0=nVQ@3GWG/0]XE[08ESBP2VNf<0YXEc09ekJ`1SBT80FT8i07=:<@2MLe80_XeS0<N5J`3?UF/20=NM
N`0D0<nEJ`2nSF<0]V]B09EJ@P2=FT80QE8i07=2:@1B:AP0FSTY05Xa8@1c@RT0WG=B0;IkFP2MLe80
]W]J0;j=H`3G[XD0WF]:0=NVQ@3`l>P<0?Shn0`00000903oool00280oooo2`0000001@3hn?P0l>SO
0:J=N`2EJe80Ld8Y0080LdXa01D0JcTQ09e[BP3?UF/0aif50;jEN`3GYXd0j<Nf0?3?]P3hekh0l<nn
0?37[P3X_ZH0j;JM0>R^W@3X]Yd0j;jV0=NMN`3OYXD0j:jE0?37YP3hckH00P3`elL02@3hekh0n<nf
0?37[P3X]YD0eiec0=nMN`3GYXD0ejJ=0=NVQ@020;jEN`0>0<nEJ`3GWG/0ejJ50=NVQ@3O[Xd0gjjE
0=NVS@3GYXD0eiek0<N5J`2nSF<0]W]J09EJ@P2=HdX206/i8@0=058Y601J>BT0Ld8Y06/i8@2MJdX0
_XeS09e[BP37QEX0_YEk0=n^U@2MLe80l=o?0?ooo`0<0?Shn0`00000803oool<000000030?3Xg`2V
SG/0UF]B00<0LdXa0200JcTQ09e[BP37QF<0aif50;jEN`3GYXd0j<Nf0?3?]P3hekh0l<nn0?37[P3`
akH0j;jV0>R^W@3X]Yd0j;jV0>RfW@3GWG/0j:jE0?37YP3hekh0n<nf0?3Ga`3hekh0n<nf0?3?[P3`
ajh0eiec0=nMN`2nUG/0ejJ50=NVS@<0_YEk00h0ciE[0=NMN`3GYXD0gjj=0>R^S@3O[YD0ejJ=0=NM
N`3?UF/0ahE[0;j=H`2fNeX0SF=:08EB>@80JcTQ00@0FSTY07=:<@1c@RT0JcTQ0P2MJdX01`2MHcT0
ahEJ0;jEN`3O[YD0_YEk0?3Oc`3oool02`3hn?P=00000200oooo2`0000001@3hn?P0l>SO0:J=N`2E
Je80Ld8Y0080LdXa01D0JcTQ09e[BP3?UF/0aif50;jEN`3GYXd0j<Nf0?3?]P3hekh0l<nn0?37[P3X
_ZH0j;JM0>R^W@3X]Yd0j;jV0=NMN`3OYXD0j:jE0?37YP3hckH00P3`elL02@3hekh0n<nf0?37[P3X
]YD0eiec0=nMN`3GYXD0ejJ=0=NVQ@020;jEN`0>0<nEJ`3GWG/0ejJ50=NVQ@3O[Xd0gjjE0=NVS@3G
YXD0eiek0<N5J`2nSF<0]W]J09EJ@P2=HdX206/i8@0=058Y601J>BT0Ld8Y06/i8@2MJdX0_XeS09e[
BP37QEX0_YEk0=n^U@2MLe80l=o?0?ooo`0<0?Shn0`00000903oool00280oooo2`0000020?ooo`0=
07=2:@2=FT80JcTQ06/i8@2EHd80FS4Q09e:<@3OQG<0ciE[0;J=L`3GYXD0l<nf0?S?]P020?SG_P09
0?3Ga`3hekh0l=O70>RVU@37QF/0YW]S0;I[DP3X]Yd0l<NV0080n=Nn00`0n=o?0?3Ga`3hekh0l=O7
0?SG_P3`_Yd0j:jE0<N5J`2MLe80]V]B0;J=L`3X_ZH20>S7[P80j;jV0P3X]Yd02`3O[YD0ejJ50<NE
J`2fQF<0_XeS0;IkFP2^Le80WF]:08eJ@P25DST0HbT@0080DRTH00X0DR4@07=:<@2=FT80[W=B09e[
BP37SF<0aiE[0>RnW@2VNeX0l>SX3@3hn?P<00000200oooo300000003P3oool0Ld8Y08eJ@P1J<B40
JcTQ09ES@P1J<B40WDXa0;I[DP3?UF/0]Xec0=NVQ@3`ckH0j;jV0P3hekh02@3`elL0n=Nn0?SG_P3X
YYD0ahE[0:IkH`2MLe80]V]B0?37YP030?SG_P0?0?3Ga`3hekh0l=O70?S?]P3hekh0j:jE0<N5J`2^
Hd80WG=B0;I[DP3X_ZH0j<N^0?37[P3Xajh0j;jV00<0j;JM01L0gjjE0=NVQ@2fQF<0ciE[0;j=H`2f
NeX0[W=B08eJ@P25DS40QE8i06<Y401B:AP0FSTY058Q401cBS40SEY209e[BP2EHd80aheS0<NEJ`3X
_Yd0aif50?3Xj00<0?Shn0d00000803oool;00000080oooo00d0Ld8Y08eJ@P1[>B40JcTQ09ES@P1J
<B40WDXa0=n5L`3?UF/0]Xec0=NVQ@3`ckH0n<nf0080n=Nn00T0l=O70?SG_P3`elL0j:JE0<N5J`2V
Nf<0]V]B0>RfW@3`ajH00P3hekh0303hgll0l=O70?SG_P3`elL0n=Nn0?2nW@3X[YD0ahE[09ecDP2f
Je80]Xec0>RnYP80j<N^0P3X_ZH20>RfW@0;0=n^U@3GYXD0aiE[0;J5H`2nSF<0]W]J0:icDP2MJdX0
SEY208EB>@1S:A000P1B:AP02P1B8A00LdXa08eJ@P2^Le80WF]:0<N=H`37UF/0j;jM0:IkFP3`j>P=
0?Shn0`00000903oool00280oooo2`0000005`2n[Zh0oooo08EB<@1c@RT0LdXa05Xa8@25DST0NdXY
09EJ<@2EFT80YW]S0;J5J`37WHD0j<Nf0;jEN`37WHD0ejJ50=NMN`2fJe80[W=B0=NMN`3hckH0n=Nn
00D0n=o?1@3`elL30?S?]P0<0>RfW@3GYXD0]Xec09EcFP2=FT80[V=20<m[FP2fSG<0ahE[0;J5H`2V
NeX0]XE[0P2nUG/01P2nSF<0[W=B09e[BP2MJdX0QE8i048Q6080Ld8Y00X0JcTQ048Y8@25HdX0WF]:
0:icDP2MJdX0_XeS0=NML`2fQF/0[V]23P3hn?P<00000200oooo300000005@3oool0QE8a07=2:@1c
BS40FS4Q08EB>@1kBRT0UEXa09EJ@P2VNf<0]XE[0<NMQ@3XakH0l<nn0<NMQ@3GYXD0eiek0=n5L`2f
Je80eiek0?S?]P020?SG_PD0n=o?0`3`elL07P3hekh0l=O70?S?]P3hckH0l<n^0>RfW@3GYXD0UG=J
08eJ@P2MLe80[V=20<m[FP37QF/0]XES0:IkH`2VNeX0]XE[0;jEN`3OQG<0_XeS0:icDP2MJdX0QE8i
09e[BP128AP0Ld8Y06/i8@1B:AP0@RTQ08ESBP80WF]:00D0UF=20;j=H`3GWG<0]XE[0=o?_P0=0?Sh
n0d00000803oool;0000000G0;j^[P3oool0QE8a07=2:@1cBS40FS4Q08EB>@1kBRT0UEXa09EJ@P2V
Nf<0]XE[0<NMQ@3XakH0_YEk0<NMQ@3GYXD0eiek0;I[DP2^Le80eiek0?S?]P3hekh01@3hgll50?3G
a`<0n<nf00`0j;JM0=NVQ@2fSG<0UG=J08eJ@P2^Hd80cf]J0;J=L`37QF/0]XES0:IkFP2fQF/20;jE
N`060;j=H`2^Le80WF]:09e[BP25DST0@R4H0P1c@RT02P1[>B40@RTQ08ESBP2MJdX0[W=B09e[BP2n
SF<0eiec0;J5J`2^Jd8>0?Shn0`00000903oool00280oooo2`0000001@37YYD0WG=B07=:<@1cBS40
QE8i00<0LdXa00`0QE8i08eSBP2MLe80YW]J0=NVQ@3XakH0l<nf0?37[P3GYXD0_Yf=0=n^W@3`elL7
0?SOc`030?SOe`3`elL0l=O70080n=o?0P3hekh00`3`elL0n=Nn0?S7]P030?37[P040>S7[P37WHD0
YW]S0:icDP80YW]S01H0aif50;jEN`3?UF/0eiec0;j=H`2^Le80WG=B0:icDP25DST0LdXa06/i8@1J
<B40>AP@048Q602=HdX0UG=J08eJ@P2VNeX0aiE[0<NMQ@2MJdX0_XeS3P3hn?P<00000200oooo3000
0000102MLe80LdXa07=:<@25HdX307=:<@0<08EB>@2EFS40WG=B0:IkFP3GYXD0j<Nf0?3?]P3`ajh0
ejJ50;jMS@3OQG<0gjjM203hgll00`3hgmL0l=O70?SOc`020?SOc`050?SG_P3`elL0n=Nn0?S?]P3h
akH00P3`ajh20>S7[P0@0<NMQ@2VNf<0YW]S0:IkH`2nUG/0aif50;jEN`3GWG<0ciE[0;j=H`2^Le80
WG=B08EB>@1[>B40LdXa06/i8@80>AP@00T0@R4H08eSBP2ELeX0YW]J0:iS@P37UF/0aif509e[BP3`
j>P03@3hn?P=00000200oooo2`0000001@37YYD0WG=B07=:<@1cBS40QE8i00<0LdXa00`0QE8i08eS
BP2MLe80YW]J0=NVQ@3XakH0l<nf0?37[P3GYXD0_Yf=0=n^W@3`elL70?SOc`030?SOe`3`elL0l=O7
0080n=o?0P3hekh00`3`elL0n=Nn0?S7]P030?37[P040>S7[P37WHD0YW]S0:icDP80YW]S01H0aif5
0;jEN`3?UF/0eiec0;j=H`2^Le80WG=B0:icDP25DST0LdXa06/i8@1J<B40>AP@048Q602=HdX0UG=J
08eJ@P2VNeX0aiE[0<NMQ@2MJdX0_XeS3P3hn?P<000002@0oooo000R0?ooo``0000000T0WF]:07]J
@P1cBS40SF]B07]J@P25DST0LdXa08eJ@P2=HdX00P2^Le80103GWG/0l<N^0?3?]P3`ckH20?SG_P80
l=O71P3hgll00`3hgmL0n=o?0?3Ga`030?SOc`@0l=O70P3`ckH0103hckH0l<N^0?37[P3X_ZH20>S7
[P0=0>RfW@3O[YD0ejJ=0=NMN`3GYXD0_YEk0;IkFP2^Le80YW]J0:icDP2MJdX0JcTQ058Q400203TH
4009048Q602fSG<0SF=:08eJ@P3GWG<0]W]J0=N^Q@2MJdX0aif500d0n?Sh3@00000P0?ooo``00000
00L0WF]:07]J@P1cBS40WG][07]J@P25DST0LdXa0080SEY20P2^Le80103GWG/0l<N^0?37]P3`ckH2
0?SG_P80l=O71P3hgll00`3hgmL0n=o?0?SOc`030?SOc`@0l=O700<0n=Nn0?3?]P3`ckH00`3`ajh0
403X_ZH0j<N^0>RfW@3O[YD0gjj=0=NVS@3GWG/0_YEk0;J=L`2fNeX0[W=B0:IkFP2MJdX0LdXa06/i
8@1B8A0203TH4008048Q602fSG<0SF=:0=NML`2MJdX0]W]J0=N^Q@2MJdX>0?Shn0d00000803oool<
0000000909e[BP1kFT80LdXa08e[DP1kFT80QE8i07=:<@2=FT80SF=:0080[W=B00@0eiek0?37[P3`
ckH0l<nf0P3hekh20?3Ga`H0n=o?00<0n=oG0?SOc`3`elL00`3hgll40?3Ga`80l<nf00@0n<nf0?37
[P3`ajh0j;jV0P3Xajh03@3X]Yd0gjjE0=NVS@3GWG/0ejJ50;jEN`2fNeX0[W=B0:IkFP2^Le80WF]:
06/i8@1B8A000P0i61002@128AP0]Xec08eSBP2=FT80eiec0;IkFP3G[XD0WF]:0<NMQ@0=0?Shn0d0
0000903oool00280oooo300000003`25BRT0Le9208EJ@P2EJe80QE8i08EJ@P1kFT80QEY208eJ@P2V
NeX0WG=B0=NMN`3Xajh0l<nf0?3?_P020?SG_P80n=o?00D0l=O70?SG_P3hgll0n=o?0?SG_P030?SO
c`060?SG_P3`elL0n=o?0?3Ga`3hgll0l=O70`3hekh01P3hakH0n<nf0?37]P3`ajh0j;jV0?37[P80
j;JM00L0gjjE0=NVQ@3GWG/0eiek0;jEN`2nSF<0]V]B0080[W=B00h0SEY207=2:@1B:AP0DRTH048Q
601B8A00_YEk0:IkFP2=FT80_YEk09e[BP3G[Xd0WF]:0=Nn[Pd0n?Sh3@00000P0?ooo``0000000L0
QDXY07=B@P25FT80YXec08EB>@25FT80NeY20080QEY200H0YW]J09ecDP3GWG/0j<N^0?3?]P3`ckh2
0?SG_P040?3Ga`3hgll0l=O70?SG_PL0n=o?00D0l=O70?SOc`3`elL0l=O70?SOc`040?SG_P080?S7
]P3`akH0l<N^0>S7[P3X_ZH0l<N^0>RfW@3O[YD20=NVQ@0E0=NMN`2nUG/0aiE[0;j=H`2fJe80[W=B
08eJ@P2MJdX0Ld8Y058Y60128AP0FS4Q058Q402nUG/0YW]J0;jEN`2^Le80WF]:0=N^S@2MJdX0oooo
00d0n?Sh3@00000P0?ooo``0000000l0QDXY07=B@P25FT80UF]B08EB>@25FT80NeY208EJ@P2=FT80
YW]J09ecDP3GWG/0j<N^0?3?]P3`ckh00P3hekh20?SOc`050?3Ga`3hekh0n=o?0?SOc`3hekh00`3h
gll01P3hekh0l=O70?SOc`3`elL0n=o?0?3Ga`<0n=Nn00H0n<Nf0?S?]P3`akH0l<N^0>RnYP3`ajh2
0>RfW@070=n^U@3GYXD0eiek0=NMN`2nUG/0_XeS0;I[DP020:icDP0>08eJ@P1c@RT0DRTH058Y6012
8AP0DR4@0;jEN`2VNeX0SEY20;jEN`2MJdX0ejj=09e[BP3G_Zh=0?Shn0d00000903oool00280oooo
300000003@25DST0SF]B08eSBP2=HdX0SF]B08eSBP25FT80QE8i08EB<@2MJdX0WG=B0<N5J`3X_Yd0
0P3`ckH00`3`ckh0n=Nn0?3Ga`020?SOc`030?SG_P3hgll0n=o?00P0n=o?0`3`elL40?S?]P0M0?37
[P3`ajH0l<N^0>RnYP3X_Yd0j;JE0=n^U@3GYXd0ejJ50=NMN`3GWG<0]W]J0:icDP2fNeX0WG=B09e[
BP1J<B40JcTQ05Xa8@0i6100@R4H0<NEJ`2VNf<0WF]:0=NML`2=HdX0_YEk09e[BP3hl?P03@3hn?P=
00000200oooo300000004025DST0SF]B08eSBP2MLe80SF]B08eSBP25FT80QE8i08EB<@2MJdX0WG=B
0<N5J`3X_Yd0l<Nf0?3?]P3`ckh20?SG_P030?3Ga`3hgll0n=Nn00/0n=o?0P3`elL40?S?]P0C0?37
[P3`ajH0j<N^0?37[P3X_ZH0j;JE0=n^U@3O[Xd0ejJ=0=NVQ@3GWG<0ciE[0;IkFP2^Le80]W]J09e[
BP1cBS40FS4Q06/i8@0203TH4008048Q6037UF/0YW]S0=NML`2fLdX0SF=:0;jEN`2MJdX>0?Shn0d0
0000803oool<0000000=08EB>@2=Je80SF=:08eSBP2=Je80SF=:08EJ@P25DST0QE8a09e[BP2MLe80
ahE[0>RnW@020?3?]P030?3?_P3hekh0l=O70080n=o?00<0n=Nn0?SOc`3hgll0203hgll30?3Ga`@0
n<nf01d0l<N^0?37YP3`ajh0j;jV0>RnW@3X]YD0gjjE0=NVS@3GYXD0eiek0=NML`2fNeX0[W=B0;Ik
FP2MLe80WF]:05Xa8@1[>B40FS4Q03TH40128AP0aiE[0:IkH`2MJdX0eiec08eSBP2nUG/0WF]:0?S`
n00=0?Shn0d00000903oool00280oooo3@0000001@2=Je80QE8i08e[DP2EJe80SF=:0080QEY200L0
SF=:09ecDP2nSF<0_YEk0=n^S@3`ckH0l<nn00<0n=Nn0P3hgll20?SG_P030?SOc`3hekh0n=o?00@0
n=o?0P3`elL40?SG_P030?S?]P3`cjh0l<N^0080l<N^103X]Yd01@3X[YD0ejJ=0=NVQ@3GWG/0ciE[
0080]XES00D0YW]S09e[BP2=FT80LdXa058Q4002048Q6008048Y8@2ELeX0_YEk09ecDP37UF/0YXE[
09ES@P3XclL=0?Shn0h00000803oool=0000000508e[DP25DST0SF=:09E[DP2=HdX00P25FT801`25
DST0WG=B0;j=H`2nUG/0gjj=0>RnYP3`ckh0103hekh00`3hgll0n=Nn0?SG_P040?SOc`030?3Ga`3h
gll0n=o?00<0l=O70`3hekh20?S?]P040?3?[P3`ajh0l<N^0?2fW@<0j;JM00H0j:jE0=n^S@3GYXd0
ejJ50<nEJ`2fSG<20;J5H`0?0:IkH`2=FT80JcTQ07=:<@1B8A00@R4H03TH4012:B40UG=J0;jEN`37
UF/0_XeS0:J5J`2EHd80j<o700d0n?Sh3P00000P0?ooo`d0000000D0SF]B08EB>@2=Je80UF]B08eS
BP0208EJ@P0708eSBP2MLe80_XeS0;jEN`3O[Xd0l<nf0?3?_P030?SG_P80n=o?0P3hekh00`3hgll0
n=Nn0?SOc`040?SOc`80l=O7103hekh00`3hckH0l<n^0?37[P020?37[P@0j;JM00D0j:jE0=NVS@3G
YXD0eiek0<nEJ`020;J5H`050:IkH`2MJdX0SEY207=:<@1B8A000P128AP02012:B40UG=J0;jEN`2M
Le80aiE[0:J5J`2EHd80j<o73@3hn?P>000002@0oooo000R0?ooo`d0000000d0Le9208eJ@P2EJe80
QEY208eSBP25DST0NeY208eSBP2MLe80]XE[0<NEJ`3GYXd0l<N^00<0n<nf0P3hekh20?SOc`040?3G
a`3hgll0n=o?0?3Ga`80n=Nn0P3`elL0503hekh0l=O70?SG_P3hekh0n<nf0?SG_P3hckH0l<N^0?S?
]P3`ajh0l<NV0>RnYP3X_Yd0j;jV0>RfU@3O[YD0ejJ=0=NVQ@2nUG/0ciE[0P2fQF<209e[BP0<08eJ
@P1[>B40DR4@03TH400Y40P0Ne9208eSBP2VNeX0[W=B0<NMQ@3G[Xd0aiE[3P3hn?P>00000200oooo
3@0000003@1cDT80SEY209E[DP25FT80SF=:08EB>@1kFT80UF]B09ecDP2fQF/0aiE[0=NVS@3X_ZH0
0`3hckH20?SG_P80n=o?00X0l=O70?SG_P3hgll0l=O70?SG_P3hgll0n=Nn0?3Ga`3hekh0l=O70P3h
ekh0103hckH0n=Nn0?S?]P3hckH20?37[P80l<NV00T0j;jV0>RnW@3X]YD0gjjE0=n^S@3GYXd0ejJ5
0<nEJ`37QF/00P2fQF<01@2MJdX0SEY207=:<@1[>B40DR4@0080:A0800L0Ne9208eSBP2VNeX0aif5
0<NEJ`3G[Xd0aiE[00h0n?Sh3P00000P0?ooo`d0000000d0Le9208eJ@P2EJe80QEY208eSBP25DST0
NeY208eSBP2MLe80]XE[0<NEJ`3GYXd0l<N^00<0n<nf0P3hekh20?SOc`040?3Ga`3hgll0n=o?0?3G
a`80n=Nn0P3`elL0503hekh0l=O70?SG_P3hekh0n<nf0?SG_P3hckH0l<N^0?S?]P3`ajh0l<NV0>Rn
YP3X_Yd0j;jV0>RfU@3O[YD0ejJ=0=NVQ@2nUG/0ciE[0P2fQF<209e[BP0<08eJ@P1[>B40DR4@03TH
400Y40P0Ne9208eSBP2VNeX0[W=B0<NMQ@3G[Xd0aiE[3P3hn?P>000002@0oooo000R0?ooo`h00000
00h0YW]J08eSBP25HdX0SEY208EJ@P2MHcT0SF=:0:IkH`2nSF<0]Xec0=NVQ@3`ajh0l<nf0?S?]P80
n=Nn0P3hgll0203`elL0n=o?0?SOc`3hekh0n=o?0?SG_P3hgll0n=Nn0P3`elL00`3hekh0l=O70?SG
_P020?SG_P030?37[P3hakH0l<n^0080l<N^00<0l<NV0>RfW@3X]Yd00P3O[YD0503GYXd0ejJ50;jE
N`3GWG<0]XE[09ecDP2EJe80QEY207=:<@1J<B40>AP@02T@2012:B40QF=:09E[DP2MJdX0UF=20<NE
J`37WHD0j=oG3@3hn?P?00000200oooo3P0000003P2VNeX0SEY208ESBP2=FT80QEY209eS>@1c@RT0
YW]S0;j=H`2fSG<0ejJ50>RnW@3`ckH0n<nf0`3hekh00`3hgll0l=O70?SOc`030?SOc`030?SG_P3`
elL0n=o?0080l=O700<0n=Nn0?3Ga`3`elL00`3hekh01`3`ajh0n<Nf0?37[P3`ajh0l;JM0?37YP3X
]Yd00P3O[YD04@3O[Xd0ejJ=0=NVQ@3GWG<0]Xec0;J5J`2MLe80UF]B07=:<@25DST0FS4Q03TH4012
:B40:A0808ESBP2EJe80WF]:0080aiE[00<0aif50>SOe`3hn?P0303hn?P?00000200oooo3P000000
3P2VNeX0SF=:08ESBP2=FT80QEY209eS>@2=HdX0YW]S0;j=H`2fSG<0ejJ50?37[P3`ckH0n<nf0P3h
ekh20?SOc`080?3Ga`3hgll0n=o?0?SG_P3hgll0n=Nn0?SOc`3hekh20?3Ga`030?SG_P3`elL0n=Nn
0080n=Nn00<0l<N^0?S7]P3`cjh00P3`ajh00`3`ajH0j;JM0>RfW@020=n^U@0D0=NVS@3GYXD0_YEk
0=NML`2fQF/0WG=B09E[DP25FT80LdXa05Xa8@0i6100:A08048Y8@25HdX0UF]B09e[BP2EHd80aiE[
0<NMQ@3XgmL=0?Shn0l00000903oool00280oooo3P0000003@1kFT80QE8i08EB>@25DS40QEY208EB
>@2=HdX0YW]J0;J=L`37WHD0ejJ=0?37[P3`ckH00`3hekh20?SOc`050?SG_P3hgll0n=o?0?SG_P3`
elL00P3hekh20?3Ga`<0n=Nn00<0l=O70?SG_P3hekh00P3hckH30?37[P040?37YP3X]Yd0j;JM0=n^
U@80gjj=00@0ejJ50<NMQ@3GWG/0YW]S0P2MLe800`2MJdX0NeY205Xa8@0203TH4007048Y8@2EJe80
UF]B09ecDP2MHcT0aiE[0=NVS@0>0?Shn0l00000803oool>00000080NeY200/0QE8i08EB<@25FT80
QE8i08eSBP2VNeX0]Xec0<NMQ@3GYXd0j;jM0?3?]P020?SG_P0<0?3Ga`3hekh0n=o?0?SG_P3hgll0
n=Nn0?SOc`3`elL0n=Nn0?SOc`3hekh0l=O71P3hekh00`3hakH0n<nf0?S?]P020?37[P040?2fW@3`
ajH0j;JM0=n^U@<0gjj=00@0ejJ50=NMN`2fQF/0YW]S0P2MLe801P1kFT80JcTQ05Xa8@0i6100@RTQ
03TH4080UF]B00@0WG=B0<NEJ`37WHD0ejJ=3P3hn?P?00000200oooo3P0000003@1kFT80QE8i08EB
>@25DS40QEY208EB>@2=HdX0YW]J0;J=L`37WHD0ejJ=0?37[P3`ckH00`3hekh20?SOc`050?SG_P3h
gll0n=o?0?SG_P3`elL00P3hekh20?3Ga`<0n=Nn00<0l=O70?SG_P3hekh00P3hckH30?37[P040?37
YP3X]Yd0j;JM0=n^U@80gjj=00@0ejJ50<NMQ@3GWG/0YW]S0P2MLe800`2MJdX0NeY205Xa8@0203TH
4007048Y8@2EJe80UF]B09ecDP2MHcT0aiE[0=NVS@0>0?Shn0l00000903oool00280oooo3`000000
2`25DST0QE8a08EB>@25DST0Le9209e[BP2VNf<0]Xec0<NMQ@3O[Yd0l<N^0080n<nf00@0n=Nn0?3G
a`3hgll0l=O7103hgll01`3`elL0n=o?0?3Ga`3hgll0l=O70?SG_P3`elL00`3hekh20?S?]P050?S7
]P3`cjh0l<N^0?37[P3`ajH00P3X]Yd0103O[Yd0gjj=0=NVQ@3GYXd20<nEJ`0>0:IkH`2VNeX0WG=B
08eJ@P1J>BT0@R4H048Y8@0a61P0@R4H0:IkH`2fQF/0SEY20:icDP37UF/20?Shn0030?S`n03hn?P0
n?Sh00T0n?Sh4000000P0?ooo`l0000000/0QE8i08EB<@25DST0QE8i07=B@P25DST0YW]S0;J=L`37
WHD0gjjM0>RnYP020?S?]P040?SG_P3`elL0l=O70?3Ga`@0n=o?00<0l=O70?SOc`3hekh00P3`elL0
0`3hekh0l=O70?SG_P020?SG_P040?S?]P3hekh0n<nf0?S7]P80l<N^0P3`ajH03`3X]Yd0gjjM0=n^
S@3O[Xd0ejJ50=NVS@3?UF/0_XeS0:IkH`2VNeX0WG=B05Xi:@1J<B40@R4H048Y8@02048Q60050:Ik
H`2fQF/0SEY20<NEJ`3X_Yd00P3hn?P00`3hl?P0n?Sh0?Shn0090?Shn1000000803oool?0000000;
08EB>@25DS40QE8i08EB>@1cDT80WF]:0:IkH`2fSG<0aif50=n^W@3`ajh00P3hckH0103hekh0l=O7
0?SOc`3`elL40?SOc`070?3Ga`3hgll0l=O70?SOc`3`elL0n=Nn0?3Ga`030?SG_P80n<nf00D0n<Nf
0?3?[P3`ajh0l<N^0?37YP020>RfW@040=n^W@3O[Xd0ejJ50=NVS@80ciE[00h0YW]S0:IkFP2MLe80
SEY205Xi:@128AP0@RTQ034H60128AP0YW]S0;J5J`2=FT80[W=B0<NEJ`80n?Sh00<0n?3h0?Shn03h
n?P02@3hn?P@000002@0oooo000R0?ooo`l0000000h0LdXa07=B@P1cDT80QE8i07]J@P2EJe80]XES
0;jEN`3GYXD0gjjE0?37[P3`akH0l<nf0?S?]P@0n=Nn0P3hgll0103`elL0n=Nn0?SG_P3hekh20?3G
a`80n=Nn00L0l=O70?SG_P3hekh0n<nf0?3?[P3hckH0n<Nf0080l<N^0P3X_ZH0103X_Yd0j;JE0=n^
S@3GYXd20=NMN`080;J=L`2VNf<0WG=B08eSBP25DST0FSTY048Y8@128AP2058Y600509e[BP2fQF<0
WF]:0<N5FP3GYXD03@3hn?PA00000200oooo4000000207=B@P0;08EB>@1kFT80Le920;J5H`2nUG/0
ejJ50=n^U@3`ajH0l<Nf0?3?]P3hckH0103hekh00`3hgll0n=Nn0?SOc`020?SG_P030?3Ga`3hekh0
l=O700<0n=Nn00H0l=O70?SG_P3hckH0n<nf0?3?[P3hckH30?37[P80j;jV01D0j;JE0=n^S@3O[Xd0
ejJ=0=NMN`2fSG<0_XeS0:IkH`2MLe80SF=:05Xi:@1J<B40@RTQ048Q601B:AP0>AP@09e[BP2fQF<0
WF]:0=NVQ@3Ocll03@3hn?PA00000200oooo3`0000003P1cBS40Le9207=B@P25DST0NeY209E[DP2f
QF<0_YEk0=NVQ@3O[YD0l<N^0?37]P3`ckH0n<nf103hekh20?SOc`040?3Ga`3hekh0n=Nn0?SG_P80
l=O70P3hekh01`3`elL0n=Nn0?SG_P3hckH0l<n^0?S?]P3hakH00P3`ajh20>RnYP040>RnW@3X]YD0
gjj=0=NVS@80eiek00P0]Xec0:IkH`2MLe80SF=:08EB>@1J>BT0@RTQ048Q6080DRTH00D0WF]:0;J5
H`2MJdX0ahEJ0=NVQ@0=0?Shn1400000903oool00280oooo3`0000002`1cDT80QEY207]J@P1cDT80
NeY209E[DP2MLe80aiE[0=N^S@3X_ZH0l<N^0080n<nf0P3hekh20?3Ga`80n=o?0P3hekh30?3Ga`80
n=Nn00@0l=O70?SG_P3hekh0n=Nn0P3hckH20?3?[P080?37[P3`ajH0l<NV0>RnYP3X_Yd0j;JE0>R^
U@3O[Xd20=nVQ@0@0<nEJ`2fSG<0[W=B09e[BP2=FT80LdXa05Xi:@1B:AP0@R4H058Y600i6100UF]B
09ecDP2MJdX0_XeS0=n^S@d0n?Sh4@00000P0?oooa00000000P0QEY207]J@P1cDT80NeY208EJ@P2M
Le80aiE[0=N^S@80j;jV0P3hckH30?SG_P050?3Ga`3hgll0n=o?0?3Ga`3hekh0103`elL00`3hekh0
l=O70?SG_P020?SG_P<0n<nf0P3`cjh20?37YP040?37[P3X_ZH0j;jM0>R^U@80gjj=0P3OYXD01@2f
SG<0]XE[0:icDP2MJdX0SEY20080FSTY00T0DRTH048Q600i6100:A0809E[DP2MLe80WF]:0=n^S@3`
l>P03@3hn?PA00000200oooo3`0000002`1cDT80QEY207]J@P1cDT80NeY209E[DP2MLe80aiE[0=N^
S@3X_ZH0l<N^0080n<nf0P3hekh20?3Ga`80n=o?0P3hekh30?3Ga`80n=Nn00@0l=O70?SG_P3hekh0
n=Nn0P3hckH20?3?[P080?37[P3`ajH0l<NV0>RnYP3X_Yd0j;JE0>R^U@3O[Xd20=nVQ@0@0<nEJ`2f
SG<0[W=B09e[BP2=FT80LdXa05Xi:@1B:AP0@R4H058Y600i6100UF]B09ecDP2MJdX0_XeS0=n^S@d0
n?Sh4@00000T0?ooo`008P3oool@000000<0UF]B00H0NeY209E[DP2VQF/0]Xec0=NMN`3X]Yd20?37
[P030?S?]P3`ckH0l=O700<0l=O700D0n=Nn0?3Ga`3hgll0n=Nn0?3Ga`030?SG_P030?S?]P3hekh0
n<nf0080n<nf00<0n=Nn0?S?]P3`ajH00`3`ajH01@3X_ZH0j;jM0>RfU@3O[YD0j;JE0080ejJ50P2f
SG<03`2VNeX0SF=:08EB>@1c@RT0LdXa05Xa8@128AP0>AP@024@202fQF/0WG=B0;IcBP3?UF/0cjjE
0?S`n00<0?Shn1400000803oool@000000<0UF]B0P1kFT802@2VQF/0]Xec0=NMN`3X]Yd0l<NV0?37
[P3hckH0l<nf0?S?]P030?3Ga`80n=Nn00<0l=O70?SG_P3`elL00`3hekh00`3hckH0n=Nn0?S?]P02
0?S?]P030?SG_P3hakH0n<nf00<0l<NV00D0l;JM0>RnYP3X_Yd0gjjE0>RfU@030=NVQ@060;J=L`2V
Nf<0YW]J08eSBP25DST0LdXa0P1J<B402@128AP08A0805Xi:@2fQF/0WG=B0;IcBP3?[YD0n?Sh0?S`
n00<0?Shn1400000803oool@000000<0UF]B00H0NeY209E[DP2VQF/0]Xec0=NMN`3X]Yd20?37[P03
0?S?]P3`ckH0l=O700<0l=O700D0n=Nn0?3Ga`3hgll0n=Nn0?3Ga`030?SG_P030?S?]P3hekh0n<nf
0080n<nf00<0n=Nn0?S?]P3`ajH00`3`ajH01@3X_ZH0j;jM0>RfU@3O[YD0j;JE0080ejJ50P2fSG<0
3`2VNeX0SF=:08EB>@1c@RT0LdXa05Xa8@128AP0>AP@024@202fQF/0WG=B0;IcBP3?UF/0cjjE0?S`
n00<0?Shn1400000903oool00280oooo400000000`2ELeX0UF]B08EJ@P0208eSBP040:icDP2nUG/0
aif50=n^U@80l<N^0P3hckH0103hekh0n<nf0?3Ga`3`elL:0?SG_P80n<nf00<0n=Nn0?S?]P3`ajh0
0P3`ajh00`3`ajH0l<N^0>RfW@020>RfW@030>RfU@3O[Xd0ejJ=0080_YEk00l0_XeS09EJ@P25DST0
QEY207=2:@1J>BT0@RTQ058Y600Q61P08A080:IkH`2EHd80]W]J0<N=H`3Xckh03@3hn?PA00000200
oooo400000002`2ELeX0UF]B08EJ@P2=HdX0QF=:0:icDP2nUG/0aif50=n^U@3`ajH0l<N^0080n<nf
0P3hekh20?3Ga`D0n=Nn00<0l=O70?SG_P3hekh00P3hekh20?S?]P030?SG_P3hckH0l<N^0080l<N^
00<0l<NV0?37[P3`_Yd00P3X]Yd02P3X]YD0gjj=0=NMN`3GYXd0_YEk0;j=H`2^Le80UEY208EB>@25
FT8205Xi:@08048Y8@1B:AP08A080:IkFP2VNf<0UF=20;IkFP3Xckh>0?Shn1400000803oool@0000
000309EcFP2EJe80QEY20080SF=:00@0[W=B0;jEN`37WHD0gjjE0P3`ajh20?S?]P040?SG_P3hckH0
l=O70?3Ga`X0n=Nn0P3hckH00`3hekh0n<nf0?37[P020?37[P030?37YP3`ajh0j;JM0080j;JM00<0
j;JE0=n^S@3GYXd00P2nUG/03`2nSF<0UEY208EB>@25FT80Ld8Y05Xi:@12:B40DRTH024H600Q40P0
YW]S09ES@P2fNeX0aheS0>S?_P0=0?Shn1400000903oool00280oooo4P0000003`25FT80YW]J0:Ik
FP2VNeX0_XeS0<NMQ@3O[YD0j<N^0?37[P3`ajH0l<N^0?S?]P3hekh0n<nf0?3?_P050?SG_P80n<nf
00D0n=Nn0?S?]P3`ajh0l<N^0?S?]P040?37[P80l<NV01L0j;jM0>RfU@3X]YD0gjjM0=n^S@3?[YD0
eiek0<nEJ`2fQF/0YW]S09e[BP25FT80LdXa07=B@P2EJe80>AP@03TQ601kFT80QE8i09e[BP2^Le80
aiE[0>RnYP020?S`n0030?ooo`3hn?P0n?Sh00L0n?Sh4`00000P0?oooa80000000/0QEY20:IkFP1k
FT80YW]J0;j=H`37WHD0gjjE0>RnW@3`ajh0l<NV0?37[P030?S?]P030?3?_P3hekh0n<nf00@0n=Nn
00D0n<nf0?SG_P3hckH0l<N^0?S?]P030?37[P060?37YP3`ajh0l<N^0?37YP3X_Yd0l;jM0P3X]YD0
5`3O[Xd0cjjE0;jEN`3GWG/0ciE[0:IkH`2MLe80WF]:08EJ@P1cBS40UF]B048Q600i6100>B4H08EB
>@2VNeX0WF]:0:icDP37UF/0n?3h0?Shn03hl?P0oooo00T0n?Sh4`00000P0?oooa80000000l0QEY2
0:IkFP2VNeX0YW]J0;j=H`37WHD0gjjE0>S7[P3`ajh0l<NV0?37[P3hckH0n=Nn0?S?]P3`ckh01@3h
ekh20?S?]P050?SG_P3hckH0l<N^0?37[P3hckH0103`ajh20?37YP0G0>RnW@3X]YD0j;JE0=n^W@3O
[Xd0cjjE0=NMN`3?UF/0]XE[0:IkH`2MJdX0QEY207=:<@1cDT80UF]B03TH400i8AP0NeY208EB>@2M
JdX0[W=B0<NEJ`3X_ZH00P3hl?P00`3oool0n?Sh0?Shn0070?Shn1<00000903oool00280oooo4P00
000208EB>@080:IkH`2VNeX0_XeS0=NMN`3O[YD0j;jV0?37[P3`ajH20?37[P030?SG_P3`cjh0n<nf
00D0n<nf0P3hakH40?37[P@0l<NV00D0l<N^0?37YP3`ajH0j;JE0>RfW@020=n^U@060=n^S@3GYXD0
_YEk0;J5J`2^Le80WG=B0P25FT8208EB>@80FSTY00L0LdXa07=2:@2VNf<0]XES0;j=H`3G[Xd0ekj^
00`0n?Sh4`00000P0?oooa8000000P25DST03025HdX0YW]J0;j=H`3GWG/0gjjE0=n^W@3`ajh0l<NV
0?37[P3hakH0l<N^0?3?[PH0n<nf00<0n=Nn0?S7]P3`ajh00P3`ajh00`3`]Yd0l<N^0?37YP030?37
YP080?37[P3`ajH0j;JE0>RfU@3X]Yd0gjjE0=n^S@3GYXD20;jEN`030;J5J`2MLe80UF=20080QEY2
00`0QE8i05Xi:@1cBS40FSTY07=:<@2VNf<0WG=B0;J5H`2nSF<0ejj=0?Shn03oool;0?Shn1<00000
803ooolB00000080QE8i00P0YW]S0:IkFP2nSF<0eiek0=n^U@3X_ZH0l<N^0?37YP80l<N^00<0n=Nn
0?3?[P3hckH01@3hckH20?S7]P@0l<N^103`ajH01@3`ajh0l<NV0?37YP3X]YD0j;JM0080gjjE00H0
gjj=0=NVQ@2nUG/0]XE[0:icDP2MLe8208EJ@P80QE8i0P1J>BT01`1cBS40Ld8Y0:IkH`2fQF<0_XeS
0=N^S@3G_Zh0303hn?PC000002@0oooo000R0?oooa<0000000/0QE8a08eJ@P2MLe80]XES0;jEN`37
WHD0j;JM0>RnYP3`ajH0l;JM0?S7]P020?3?]P060?37]P3`ajh0n<nf0?S?]P3hekh0l<Nf0P3`ajh0
103`ajH0l;JM0>RfW@3`]YD20?37YP80l;jM00D0l;JE0>RfW@3X]Yd0gjj=0=n^U@020=NVS@060=NM
N`2nUG/0]Xec0;J5J`2^Le80YW]J0P1cDT8207=:<@0805Y2>@1J<B40YXE[09E[DP2MLe80eiek0<NE
J`3X_Yd20?Shn0040?S`n03hn?P0n?Sh0?ooo`H0n?Sh5000000P0?oooa<0000000X0QE8a07]J@P2M
Le80]XES0;jEN`37WHD0ekJV0>RnYP3`ajH0l;JM0P3hakH02`3`ckH0l<Nf0?37[P3hakH0n<nf0?SG
_P3`akH0l<nf0?37[P3`ajH0l;JM0080j;JM00`0l;JE0?37YP3`_Yd0l;JM0?2nW@3`]YD0j;JM0=n^
S@3X[YD0gjjE0=NVS@3GWG/20;jEN`040;J=L`2fQF/0YW]J09e[BP80Le9200X0LdXa05Y2>@1c@RT0
FS4Q0:J5J`2MLe80WF]:0=NMN`37UF/0j;jM0P3hn?P00`3hl?P0n?Sh0?Shn0070?Shn1@00000803o
oolC0000000;08EB<@2=FT80WG=B0;J5H`2nUG/0aif50>RfW@3X_ZH0l<NV0?2fW@3hakH00P3`ckH0
1P3`akH0l<N^0?S?]P3hckH0n=Nn0?37]P80l<N^00@0l<NV0?2fW@3X]Yd0l;JE0P3`ajH20?2nW@05
0?2fU@3X]Yd0j;JM0=n^S@3O[YD00P3GYXd01P3GWG/0_YEk0;J=L`2fQF/0[W=B0:IkFP80Le920P1c
BS40201J@ST0FS4Q0:J5J`2EJe80WG=B0=NMN`37UF/0j;jM0P3hn?P0103hl?P0n?Sh0?Shn03oool6
0?Shn1@00000903oool00280oooo500000001`25DST0WG=B0:J5J`2fSG<0ejJ=0=n^W@3X]Yd00P3`
]Yd0103`ajh0j<N^0?37[P3`ckH20?37[P0:0?37]P3`ajh0l<NV0?37[P3`_Yd0j;JM0>R^S@3X[YD0
j;JE0?2fU@<0j:j=00<0gjJ50=n^S@3X[YD00`3GYXD00`37WHD0eiec0;jEN`020;J5H`0?0:IkFP2M
Le80QEY207]J@P1cDT80SF]B07]J@P2=Je80]XE[09EcFP2VNf<0ejJ50>RnW@3G_Zh0n?3h0080n?Sh
00<0oooo0?Shn03hn?P01@3hn?PE00000200oooo500000001`2MJdX0WG=B0:J5J`2fSG<0ejJ=0=n^
U@3X]Yd00P3`]Yd0103`ajH0l<N^0?37[P3`ckH40?37[P050?37YP3`ajh0l<N^0>RfW@3X[Xd00P3X
[YD00`3X]YD0j:j=0>R^S@020>R^S@040=nVQ@3X[YD0ejJ50=n^S@80ejJ500<0eiec0;jEN`2fQF/0
0P2fQF<03P2MLe80SEY208EJ@P1kFT80Le9207]J@P1cBS40SF]B0;J5J`2VNf<0_XeS0=NVQ@3X_Yd0
ekj^0`3hn?P00`3oool0n?Sh0?Shn0050?Shn1D00000803ooolD0000000708EB>@2MLe80YXE[0;J=
L`3GYXd0gjjM0>RfW@020?2fW@040?37[P3Xajh0l<N^0?3?]P80l<N^00X0l<Nf0?37[P3`ajH0l<N^
0?2nW@3X]Yd0j:j=0>R^U@3X]YD0l;JE0`3X[Xd00`3OYXD0gjj=0>R^U@030=NVQ@030<NMQ@3GWG<0
_YEk0080]XES00l0YW]J09ecDP25FT80NeY207=B@P2=Je80NeY208e[DP2fQF/0UG=J0:IkH`3GYXD0
j;jM0=Nn[P3hl?P00P3hn?P00`3oool0n?Sh0?Shn0050?Shn1D00000903oool00280oooo50000000
2@2EJe80SF=:09ecDP2VNf<0_YEk0>RnW@3O[Yd0ekJV0>RfW@040?37[P060>S7[P3X_ZH0j;jV0>Rn
YP3X]Yd0gjj=0P3O[YD20=NVQ@80eiek00D0eiec0=nMN`3GWG<0eiec0;jEN`030<nEJ`090<N5J`2f
SG<0_YEk0;J=L`2fNeX0WF]:08eSBP2ELeX0LeY:0080UF]B00T0LdXa08eSBP2MJdX0WG=B09e[BP2n
SF<0gjjE0>RnW@3hl>P02`3hn?PE00000200oooo5@0000001`2=HdX0WG=B0:IkH`2nUG/0ejJ=0=n^
W@3G]ZH00P3X]Yd30?37[P080>S7[P3X_ZH0j;jV0>RnYP3X]Yd0gjjM0=n^S@3O[YD20=NVQ@80eiek
00<0eiec0=nMN`3GWG/00P3GWG<40<nEJ`090<N5J`2nUG/0]Xec0;J5J`2fNeX0WF]:09EcFP2EJe80
LeY:0080UF]B00T0SF=:09e[BP2MJdX0WG=B0;j=H`2fQF<0gjjE0>RnW@3hl>P02P3hn?PF00000200
oooo500000002@2EJe80SF=:09ecDP2VNf<0_YEk0>RnW@3O[Yd0ekJV0>RfW@040?37[P060>S7[P3X
_ZH0j;jV0>RnYP3X]Yd0gjj=0P3O[YD20=NVQ@80eiek00D0eiec0=nMN`3GWG<0eiec0;jEN`030<nE
J`090<N5J`2fSG<0_YEk0;J=L`2fNeX0WF]:08eSBP2ELeX0LeY:0080UF]B00T0LdXa08eSBP2MJdX0
WG=B09e[BP2nSF<0gjjE0>RnW@3hl>P02`3hn?PE000002@0oooo000R0?oooaD0000000H0NeY209ec
DP2VNeX0SF=:0<NMQ@3G_Zh20>S7]P80j;jV00<0ekJV0=n^W@3GYXD00P3GYXd00`3GYXD0ejJ=0=NV
Q@020<NEJ`<0]Xec0100]XE[0:icDP2fQF/0WG=B09e[BP2fQF/0WG=B0;J5H`2^Le80YW]S0:IkFP2V
Nf<0SF=:09EcFP2^Le80UG=J0P2MLe801025DST0QEY208e[DP2MJdX20:IkFP030<NEJ`3G]ZH0aif5
00`0n?Sh5P00000P0?oooaD0000000H0NeY209ecDP2VNeX0SF=:0;J=L`3G_Zh30>S7]P080>RnYP3G
]ZH0gjjM0=NVQ@3?[YD0ejJ=0=NVQ@3GYXd20=NVQ@0>0<NEJ`2fSG<0]Xec0;J5J`2fSG<0[W=B0;J5
J`2fQF<0WG=B09e[BP2MLe80]XES09ecDP2^Le820:IkH`0;08eSBP2EJe80UG=J0:icDP2MLe80UG=J
09ecDP25DST0QEY209e[BP2MLe800P2VNeX20=NfYP050<NMQ@3hn?P0n?Sh0?Shn03hl?P0203hn?PF
00000200oooo5@0000001P1kFT80WG=B0:IkFP2=HdX0aif50=Nn[P80j<Nf0P3X_ZH00`3G]ZH0gjjM
0=NVQ@020=NVS@030=NVQ@3GYXd0ejJ50080aiE[0`2fSG<0402fQF/0[W=B0;J5J`2MLe80WF]:0;J5
J`2MLe80]XES0:icDP2VNf<0YW]J0:IkH`2=HdX0UG=J0:icDP2ELeX209ecDP0408EB>@25FT80SF]B
09e[BP80YW]J00<0aiE[0=NfYP37WHD0303hn?PF000002@0oooo000R0?oooaH0000000l0WG=S0:J=
L`37YYD0_Yf=0=n^W@3?YYD0gjjM0=Nn[P3O[Yd0gjjE0=NVS@3GYXD0_YEk0<NMQ@3GYXD00P37WHD0
802nUG/0ahE[0;J5H`2fQF/0_YEk0:IkH`2nUG/0]XES0;j=H`2VNeX0WF]:0;jEN`2VNeX0YW]S0:Ik
FP2VQF/0YXec08ESBP2VNeX0WG]S08e[DP2ELeX0UF=209e[BP2EHd80WF]:09ES@P2fQF<0ejj50<nf
YP3?[YD0j<o72`3hn?PG00000200oooo5P0000001`2MLf<0YXec0<NVU@3?YYD0gjjM0<nVU@3O[Yd0
0P3G_Zh03@3O[YD0ejJ=0=NVQ@3GYXd0_YEk0=NVQ@37WHD0aiE[0<NMQ@37QF/0]XES0;J5J`2MLe80
0P2nUG/04P2fQF<0YW]S0;j=H`2VNeX0_YEk0:IkFP2fQF/0YW]S0:IkFP2VSG<0QF=:09E[DP2VNeX0
WG]S09EcFP2VNf<0UF=209e[BP80UF=200H0WG=B0;J5H`3G[XD0cjjE0=N^S@3XclL30?Shn0030?oo
o`3hn?P0n?Sh00D0n?Sh5`00000P0?oooaH0000000l0WG=S0:J=L`37YYD0_Yf=0=n^W@3?YYD0gjjM
0=Nn[P3O[Yd0gjjE0=NVS@3GYXD0_YEk0<NMQ@3GYXD00P37WHD0802nUG/0ahE[0;J5H`2fQF/0_YEk
0:IkH`2nUG/0]XES0;j=H`2VNeX0WF]:0;jEN`2VNeX0YW]S0:IkFP2VQF/0YXec08ESBP2VNeX0WG]S
08e[DP2ELeX0UF=209e[BP2EHd80WF]:09ES@P2fQF<0ejj50<nfYP3?[YD0j<o72`3hn?PG000002@0
oooo000R0?oooaL0000000T0UF]B0:J5J`2fSG<0_Yf=0=n^W@3G]ZH0cjjE0=NVS@3G[Xd00P37WHD0
0`2fSG<0_YEk0;J=L`020;jEN`0@0;J5J`2nUG/0YW]J09ecDP2EHd80YXE[0:IkFP2fSG<0YW]S0:Ik
FP2VNf<0aiE[08eSBP2MLe80]XE[0:IkFP80UF]B00D0NeY207=:<@1cDT80SF=:08EB>@0207]J@P06
09ES@P2fLdX0ejj50>S7[P2nWHd0ejj=2`3hn?PH00000200oooo5`0000002@2EJe80YXE[0;J=L`2n
WHd0gjjM0=NfYP3O[YD0cjjE0=N^S@030<NMQ@80]Xec00l0_YEk0;J=L`2nUG/0_YEk0:IkFP2MLe80
YW][09ES@P2VNeX0]Xec09ecDP2VNf<0YW]J0<NEJ`2=HdX00P2MLe801`2fQF/0UF]B09E[DP25FT80
NeY207=:<@2=HdX00P25DST207]J@P060;IcBP37UF/0ejj50>S7[P3G[Xd0]XES2`3hn?PH00000200
oooo5`0000002@2EJe80YXE[0;J=L`2nWHd0gjjM0=NfYP3?[YD0ejJ=0=N^S@020<NMQ@030;J=L`2n
UG/0]Xec0080_YEk0100]XE[0;jEN`2VNeX0WG=B09ES@P2VQF/0YW]J0;J=L`2VNf<0YW]J0:IkH`37
UF/0SF=:09ecDP2fQF/0YW]J0P2EJe801@1kFT80LdXa07=B@P2=HdX0QE8i0080NeY200H0UF=20;Ic
BP3G[XD0j<N^0;jMS@3G[Xd;0?Shn1P00000903oool00280oooo600000000`2nWID0ajJE0=NfYP02
0=NfYP@0aif50`2nUG/20;J5J`0:0;J5H`2VNeX0YW]S09ES@P2VQF/0SF=:07=:<@2VNf<0QEY20:Ik
FP80YW]S01D0SEY209e[BP1c@RT0LdXa09eS>@2=FT80QEY209eS>@2EHd80WF]:09ES@P25DST0WF<i
09e[BP3?[YD0_YEk0=Nn[P2=HdX0_Yf=0:J5J`3oool01P3hn?P00`3hl?P0n?Sh0?Shn00I00000200
oooo600000000`2nWID0aif50=NfYP030=NfYP<0aif500<0_YEk0<NMQ@2nUG/00P2fQF/0102nUG/0
]XES0:IkH`2EHd820:J5J`0?08eSBP2VNf<0QEY20;J5H`2VNeX0YW]S08eJ@P2MJdX0YW]J07=2:@1c
BS40SEY208EJ@P2=FT80WF<i00<0UF=200X0QE8i09eS>@2MJdX0_YEk0=N^S@3G_Zh0SF=:0:J5J`3O
cll0oooo1P3hn?P00`3hl?P0n?Sh0?Shn00I00000200oooo600000000`2nWID0ajJE0=NfYP020=Nf
YP@0aif50`2nUG/20;J5J`0:0;J5H`2VNeX0YW]S09ES@P2VQF/0SF=:07=:<@2VNf<0QEY20:IkFP80
YW]S01D0SEY209e[BP1c@RT0LdXa09eS>@2=FT80QEY209eS>@2EHd80WF]:09ES@P25DST0WF<i09e[
BP3?[YD0_YEk0=Nn[P2=HdX0_Yf=0:J5J`3oool01P3hn?P00`3hl?P0n?Sh0?Shn00I000002@0oooo
000R0?oooaT0000000D0YXE[0<NVW@3?]ZH0gjjM0<NVU@020;jEN`060;J=L`2nUG/0]Xec0:J5J`2V
SG<0]Xec0P2fQF<0302=HdX0aiE[0:IkFP2nUG/0SF=:08EJ@P2VNf<0SF=:09E[DP25FT80SEY208EB
<@80QE8i00L0WF<i08EB>@1kFT80SEY208EB>@25BS40SEY20080]XES00L0aif50;jEN`3X_Yd0YXE[
0:IkFP2nWHd0YXE[00@0n?Sh00<0n?3h0?Shn03hl?P00P3hn?PJ00000200oooo6P0000001`37YYd0
ckJV0=n^W@3G]ZH0ajJE0;jEN`2fSG<00P2nUG/0302fSG<0YXec0;J=L`2VNf<0]XES08eSBP37UF/0
YW]J08eSBP2nUG/0QEY20:IkH`80SF=:00@0UF]B08eJ@P25DS40Ld8Y0`25DST01P1kFT80UF=208eJ
@P25DST0SEY209ecDP80]XES00H0aif50>RnW@3G]ZH0YXE[0:IkFP2VQF/40?Shn0050?S`n03hn?P0
n?Sh0?S`n03hn?P06`00000P0?oooaT0000000D0YXE[0<NVW@3?]ZH0gjjM0<NVU@020;jEN`060;J=
L`2nUG/0]Xec0:J5J`2VSG<0]Xec0P2fQF<0302=HdX0aiE[0:IkFP2nUG/0SF=:08EJ@P2VNf<0SF=:
09E[DP25FT80SEY208EB<@80QE8i00L0WF<i08EB>@1kFT80SEY208EB>@25BS40SEY20080]XES00L0
aif50;jEN`3X_Yd0YXE[0:IkFP2nWHd0YXE[00@0n?Sh00<0n?3h0?Shn03hl?P00P3hn?PJ000002@0
oooo000R0?oooa/0000000D0]YEk0=NfYP37[Yd0YW]J0;J=L`020:IkH`0D0:IkFP2ELeX0YXE[0:J5
J`2VNf<0UG=J0:IkH`25FT80YW]J09E[DP1cDT80LdXa0:IkFP1kFT80QEY207]J@P25DS40LdXa06/i
8@1J>BT307=2:@0>09e[BP25FT80SF=:0:J5J`2nUG/0j;jV0<nfYP2nWHd0YXec0<NMQ@2EJe80l>SX
0?ooo`3hl?P60?Shn1`00000803ooolK000000050;JEN`3G]ZH0ekJV0<N^W@2fSG<00P2VNf<01@2f
QF<0YW]J0:J5J`2VQF/0UG=J0080YW]S00X0QEY20:IkFP2MJdX0UF]B07=:<@2VNeX0Le9207]J@P25
FT80QE8a0P1cBS40401[>B40FSTY07=2:@1c@RT0QE8a09e[BP25FT80YXE[0<NMQ@2nUG/0j;jV0<nf
YP2VSG<0UF]B0<NMQ@2EJe820?ooo`030?S`n03hn?P0n?Sh00@0n?Sh7000000P0?oooa/0000000D0
]YEk0=NfYP37[Yd0YW]J0;J=L`020:IkH`0D0:IkFP2ELeX0YXE[0:J5J`2VNf<0UG=J0:IkH`25FT80
YW]J09E[DP1cDT80LdXa0:IkFP1kFT80QEY207]J@P25DS40LdXa06/i8@1J>BT307=2:@0>09e[BP25
FT80SF=:0:J5J`2nUG/0j;jV0<nfYP2nWHd0YXec0<NMQ@2EJe80l>SX0?ooo`3hl?P60?Shn1`00000
903oool00280oooo700000002`3?]ZH0ajjM0:IkFP2EJe80]YEk0:IkH`2fUG/0]XES09E[DP2VQF/0
SF=:0080YW]S00L0SF=:09ecDP2ELeX0SF]B05Xa8@1cBS40YW]J0080QE8i00D0JcTQ08EB>@1[>B40
FS4Q05Xi:@0205Xa8@0;08eJ@P2VQF/0_YEk0;J5J`3?]ZH0]YEk08ESBP2ENf/0]XES09e[BP37YYd0
1@3hn?P00`3hl?P0n?Sh0?Shn00M00000200oooo700000006P3?]ZH0ekj^0<N^W@2EJe80]YEk0:Ik
H`2fSG<0]YEk09E[DP2VQF/0YW]J08eSBP2VNf<0SF=:09ecDP2VNeX0UG=J05Xa8@1cBS40NeY20:Ik
FP25DST0JcTQ08EB>@1c@RT0JcTQ0`1J<B40301cBS40SEY20:J5J`2fQF/0_YEk0<nfYP2fUG/0QF=:
0;J5H`2VQF/0WF]:0<NVW@H0n?Sh00<0oooo0?Shn00000007000000P0?oooa`0000000/0ckJV0<N^
W@2VNeX0UF]B0;JEN`2VNf<0]YEk0;J5H`2EJe80YXE[08eSBP020:IkH`0708eSBP2MLe80UG=J08e[
DP1J<B40LdXa0:IkFP0208EB>@0506/i8@25DST0JcTQ05Xa8@1J>BT00P1J<B402`2=FT80YXE[0;jE
N`2fQF/0ckJV0;JEN`25HdX0UG][0;J5H`2MJdX0ajJM00D0n?Sh00<0n?3h0?Shn03hn?P07@00000T
0?ooo`008P3ooolM0000000D0=NfYP2VQF/0UF]B0:IkFP2fSG<0UG=J0:IkH`2=Je80SF=:09EcFP2=
Je80UF]B0:IkH`2ELeX0YW]J09ecDP2=Je80SF=:07=:<@25HdX208EB>@0@08eJ@P2MJdX0QE8a08EB
<@2EFS40WF]:0:IkH`2nSF<0aif50=o7]P2nWHd0WG][07=:<@2ELeX0YXE[0;JEN`D0n?Sh00<0oooo
0?Shn03hl?P07P00000P0?oooah0000000@0ekJV09E[DP2VNeX0]Xec0P2ELeX02`2=Je80SF=:09ec
H`2ELeX0UF]B0:IkH`2ELeX0SF=:0:IkFP2=Je80SF=:0080LdXa0140QF=:08EB>@2=FT80QE8a09e[
BP25DS40UEXa09e[BP2^Le80YW]S0;j=H`3OakH0]YEk0;jMS@2MNf/0LdXa0:J5J`020;JEN`D0n?Sh
00<0oooo0?S`n00000007P00000P0?oooad0000001@0ekJV0:J5J`2EJe80YW]J0;J=L`2ELeX0YW]S
08e[DP2=HdX0UG=J08e[DP2EJe80YW]S09EcFP2VNeX0WG=B08e[DP2=HdX0LdXa08ESBP80QE8i0100
SEY209e[BP25DS40QE8a09EJ<@2MJdX0YW]S0;j=H`37WHD0glNf0;jMS@2MNf/0LdXa09EcFP2VQF/0
]YEk1@3hn?P00`3oool0n?Sh0?S`n00N000002@0oooo000R0?oooah0000000P0ekJV08eSBP2=Je80
WG]S09EcFP2EJe80QEY207]J@P80SF=:01`0UF]B09EcFP2=HdX0YW]J0:J5J`2MLe80UG=J0:IkFP25
DST0QE8a09EcFP2EJe80UF=209e[BP2VNeX0]XES0<NMQ@2nUG/0ekJV0;jMS@2fWHd0YXec07]J@P2M
Lf<0YXec0:J5J`3oool0n?Sh0P3oool0103hl?P0oooo0?S`n03ooolO00000200oooo7`0000001P2=
HdX0SF]B09ekH`2fQF<0UG=J08EJ@P80NeY200<0SF=:09E[DP2ELeX00P2=HdX04@2VNeX0WG=B09Ec
FP1kFT80YW]J08EB>@2ELeX0UF]B08eSBP2EHd80WF]:0;J5H`37WHD0]Xec0;jEN`3G]ZH0]Yf=0080
YXec00/0NeY209ecH`2VQF/0YW][0?ooo`3hn?P0oooo0?Shn03hl?P0oooo0?S`n00P00000200oooo
7P000000203G]ZH0SF=:08e[DP2MNf<0UG=J09E[DP25FT80NeY20P2=HdX0702EJe80UG=J08eSBP2V
NeX0YXE[09ecDP2ELeX0YW]J08EB>@25DS40UG=J09E[DP2EHd80WF]:0:IkFP2fQF<0aif50;jEN`3G
]ZH0_Yf=0;JMS@2VSG<0NeY209ecH`2VSG<0YXE[0?ooo`3hn?P20?ooo`040?S`n03oool0n?3h0?oo
oal00000903oool00280oooo8000000208e[DP0>0:J5J`2EJe80YXE[08EB>@25FT80WF]:09E[DP2M
Le80QE8i09ecDP2fSG<0YW]S0;J5J`2EJe8208eJ@P80WG=B00<0]XES0;j=H`2nSF<00P3GYXD02@2V
Nf<0WG][09ekJ`2=FT80QE8i0:IkH`2VQF/0WG]S0;jEN`030?Shn0030?ooo`3hn?P0n?Sh02400000
803ooolP00000080SF]B0`2VQF/03@25DST0QEY208EJ@P2EJe80WG=B08EB>@2VNf/0WG=B0:IkH`2f
QF/0]YEk09E[DP2=FT800P2MLe820;J5H`0=0;j=H`3GYXD0ejJ50<NVU@2VNf<0WG][08eJ@P1c@RT0
QE8i0:IkH`2VQF/0_YEk0?ooo`020?Shn080oooo0P3hn?PQ00000200oooo8000000208e[DP0>0:J5
J`2EJe80YXE[08EB>@25FT80WF]:09E[DP2MLe80QE8i09ecDP2fSG<0YW]S0;J5J`2EJe8208eJ@P80
WG=B00<0]XES0;j=H`2nSF<00P3GYXD02@2VNf<0WG][09ekJ`2=FT80QE8i0:IkH`2VQF/0WG]S0;jE
N`030?Shn0030?ooo`3hn?P0n?Sh02400000903oool00280oooo8`0000004P2VQG<0YXek0:IkJ`37
YYD0WG][07]B@P2=Je80Ne920;JEN`37YYD0_Yf=0:J=N`3G_[H0ekj^0=o7]P3XelL0j<o70<NMQ@80
]YEk00T0YXEc09EcH`2EJe80Le9208EB>@2ELeX0_YEk0:IkH`2fUG/00P3hn?P00`3hl?P0n?Sh0?Sh
n00T00000200oooo900000007@2VSG/0YW][0;jEN`37YYD0Ne9208e[DP1kDT80UG=J0;JEN`2nWHd0
YXek0=Nn[P3G_[H0ekj^0>SGa`3XclL0ekj^0<NMQ@2fUG/0YXEc09EcH`2ELeX0UF]B07=B@P2ELeX0
WG]S0;jEN`2VNf<0]YEk0080n?Sh00<0n?3h0?Shn00000009000000P0?ooob<000000180YXEc0:J=
N`2VNf/0ajJE09ekJ`1kDT80SF]B07]B@P2fUG/0ajJE0;jMS@2VSG/0ekjf0=Nn[P3OakH0j=O70>S?
a`37WHD20;JEN`090:J5L`2ELf<0UF]B07=B@P25DST0UG=J0;jEN`2VNf<0]YEk0080n?Sh00<0n?3h
0?Shn03hn?P09000000T0?ooo`008P3ooolV000000090<NVW@3XclL0l=O70?S`j03`j=l0j<o70>S?
_P3G_Zh0glnn0080glNf00D0j<nn0<nfYP2VSG<0YXec09ekH`0209ekJ`0708eSBP1cFTX0YW]S0:J=
L`2VQF/0YW]S0?ooo`020?Shn0030?ooo`000000000002D00000803ooolV000000090=Nn]P37YYd0
l=O70?S`j03`j=l0l=O70>S?a`3G_Zh0glnn00<0glNf00X0ckJV0:J=L`37YYD0YXec09ekH`2MNf/0
SF=:08e[DP1cFTX0YW]S0P2VQF/01@2VNf<0oooo0?Shn03oool0n?3h02L00000803ooolV00000009
0<NVW@3XclL0l=O70?S`j03`j=l0j<o70>S?_P3G_Zh0glnn0080glNf00D0j<nn0<nfYP2VSG<0YXec
09ekH`0209ekJ`0708eSBP1cFTX0YW]S0:J=L`2VQF/0YW]S0?ooo`020?Shn0030?ooo`0000000000
02D00000903oool00280oooo:00000005@3OakH0j<Nf0>S?_P3`elL0l=o?0>SGc`3Ockh0ckJV0;jM
U@3G_Zh0_Yf=0;JMS@2=LeX0YW]J08eSBP2=Je80WG][0;jMS@37WHD0]Xec0:J5J`020?Shn0030?S`
n0000000000002L00000803ooolX0000000F0=o7]P3XakH0j<nn0>S7]P3`elL0j=O?0=o?_P3XclL0
ckJV0;jMU@2nWHd0]Yf=0;jMU@2=LeX0YW]J08e[DP2MNf/0YXEc0;jMS@37WHD0YXE[0<NVW@80n?Sh
00<0n?3h0000000000009`00000P0?ooobP0000001D0glNf0>S7]P3Xckh0l=O70?3Oc`3Xell0glnn
0<nfYP2nWID0ekj^0;jMS@2fWHd0SG=J0:IkFP2=HdX0SF]B09ekJ`2nWHd0aif50;J=L`2VQF/00P3h
n?P00`3hl?P000000000000W000002@0oooo000R0?ooob/000000180j=O?0?3Oc`3XclL0glnn0<o7
_P2fWHd0YXf50;jMU@2MNf<0UG=J0:J=L`25He80YXek0;jMS@2fWHd0YXek0<NMQ@3Xgml/00000200
oooo;00000004@3Xell0j<o70=o?_P3G_[H0clNn0;JMS@2nWID0WG]S09ekJ`2ELeX0YXec0:J=N`2n
WHd0aif50;JMS@2VSG/0j=oO02d00000803oool[0000000B0>SGc`3`gll0j<o70=o?_P3?akh0]Yf=
0:J=Q@2nWID0WG]S09EcFP2VSG<0QF=B0:J=N`2nWHd0]Yf=0:J=N`37WHD0j=oO;000000T0?ooo`00
8P3ooomY00000200ooooJP00000P0?ooofT00000903oool00280ooooJ@00000P0?ooofX00000803o
oomY000002@0oooo000R0?ooofT00000803ooomZ00000200ooooJ@00000T0?ooo`008P3ooomY0000
0200ooooJP00000P0?ooofT00000903oool00280ooooJ@00000P0?ooofX00000803ooomY000002@0
oooo000R0?ooofT00000803ooomZ00000200ooooJ@00000T0?ooo`008P3ooomY00000200ooooJP00
000P0?ooofT00000903oool00280ooooJ@00000P0?ooofX00000803ooomY000002@0oooo000R0?oo
ofT00000803ooomZ00000200ooooJ@00000T0?ooo`008P3ooomY00000200ooooJP00000P0?ooofT0
0000903oool00280ooooJ@00000P0?ooofX00000803ooomY000002@0oooo000R0?ooofT00000803o
oomZ00000200ooooJ@00000T0?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00
o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00DP3oool00d000000oooo0?ooo`060?oo
o`03@000003oool0oooo07d0oooo00=000000?ooo`3oool01P3oool00d000000oooo0?ooo`1m0?oo
o`03@000003oool0oooo00H0oooo00=000000?ooo`3oool0DP3oool00540oooo00=000000?ooo`3o
ool0203oool00d000000oooo0?ooo`1k0?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3o
ool0N`3oool00d000000oooo0?ooo`080?ooo`03@000003oool0oooo0540oooo001@0?ooo`04@000
003oool0oooo0?ooo`A000001@3oool00d000000oooo0?ooo`1i0?ooo`03@000003oool0oooo0080
oooo0d0000050?ooo`03@000003oool0oooo07T0oooo00=000000?ooo`3oool00`3oool3@00000@0
oooo00=000000?ooo`3oool0D03oool00500oooo00=000000?ooo`3oool00P3oool014000000oooo
0?oood0000040?ooo`03@000003oool0oooo07T0oooo00=000000?ooo`3oool00P3oool00d000000
oooo0?ooo`050?ooo`03@000003oool0oooo07T0oooo00=000000?ooo`3oool00P3oool014000000
oooo0?oood0000040?ooo`03@000003oool0oooo0500oooo001@0?ooo`03@000003oool0oooo0080
oooo00A000000?ooo`3ooom00000103oool00d000000oooo0?ooo`1i0?ooo`03@000003oool0oooo
0080oooo00=000000?ooo`3oool01@3oool00d000000oooo0?ooo`1i0?ooo`03@000003oool0oooo
0080oooo00A000000?ooo`3ooom00000103oool00d000000oooo0?ooo`1@0?ooo`00D03oool00d00
0000oooo0?ooo`020?ooo`=000001@3oool00d000000oooo0?ooo`1i0?ooo`03@000003oool0oooo
0080oooo0d0000050?ooo`03@000003oool0oooo07T0oooo00=000000?ooo`3oool00`3oool3@000
00@0oooo00=000000?ooo`3oool0D03oool00540oooo00E000000?ooo`3oool0oooo@00000060?oo
o`03@000003oool0oooo07/0oooo00=000000?ooo`3oool0203oool00d000000oooo0?ooo`1k0?oo
o`03@000003oool0oooo00@0oooo00E000000?ooo`3oool0oooo@000001C0?ooo`00DP3oool01400
0000oooo@000040000050?ooo`03@000003oool0oooo07d0oooo00=000000?ooo`3oool01P3oool0
0d000000oooo0?ooo`1m0?ooo`03@000003oool0oooo0080oooo0T0000020?ooo`03@000003oool0
oooo0580oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o
0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o
0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo002T0?ooo`900000K`3o
ool2@0000:/0oooo002V0?ooo`03@000003oool0oooo06h0oooo00=000000?ooo`3oool0Z03oool0
09P0oooo0d0000030?ooo`=000000`3oool3@00000D0oooo00=000000?ooo`3oool02T0000050?oo
o`03@000003oool0oooo00L0oooo0d000000103ooom000000?ooo`3oool2@0000080oooo0d000003
0?ooo`9000000`3oool2@00000<0oooo0T0000020?ooo`=000000`3oool2@00000<0oooo0d00000@
0?ooo`=0000000L0oooo@000003ooom000000?oood000000oooo00A000000P3oool3@0000080oooo
0T0000020?ooo`900000XP3oool009T0oooo00=000000?ooo`3oool00`3oool01D000000oooo0?oo
o`3ooom000000080oooo00=000000?ooo`3oool0203oool00d000000oooo0?ooo`020?ooo`03@000
003oool0oooo0100oooo00I000000?ooo`3ooom000000?oood0000040?ooo`03@000003oool0oooo
0080oooo00A000000?ooo`3ooom000000P3oool2@0000080oooo00=000000?ooo`3oool00`3oool0
1D000000oooo0?ooo`3ooom0000000@0oooo00A000000?ooo`3ooom000004@3oool02D000000oooo
0?oood000000oooo@000003ooom000000?ooo`03@0000080oooo00I000000?ooo`3ooom000000?oo
od0000060?ooo`03@000003oool0oooo09l0oooo002I0?ooo`03@000003oool0oooo00<0oooo00E0
00000?ooo`3oool0oooo@00000020?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool0
0P3oool00d000000oooo0?ooo`0@0?ooo`=000000P3oool3@0000080oooo00=000000?ooo`3oool0
0P3oool01T000000oooo0?oood000000oooo@0000080oooo00=000000?oood0000000T0000030?oo
o`04@000003oool0oooo0?ooo`=000000P3oool014000000oooo0?oood00000A0?ooo`08@000003o
ool0oooo@000003ooom000000?oood0000030?ooo`04@000003oool0oooo@0000080oooo00=00000
0?oood0000000T0000030?ooo`03@000003oool0oooo0:00oooo002I0?ooo`9000000`3oool2@000
00@0oooo0d00000:0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool0403oool01D00
0000oooo0?oood000000oooo00=000000P3oool3@00000<0oooo0T0000000`3ooom00000@0000002
0?ooo`03@000003ooom00000009000000P3oool4@00000040?oood0000100000@00000<0oooo0d00
000@0?ooo`9000000P3oool2@00000030?oood000000oooo0080oooo0T0000030?ooo`=0000000@0
oooo@0000400001000000`3oool2@0000:40oooo002I0?ooo`04@000003oool0oooo@00001@0oooo
00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`0@0?ooo`04@000003oool0oooo@00002L0
oooo00=000000?ooo`3oool0b`3oool009P0oooo1D0000020?ooo`03@000003oool0oooo00h0oooo
0T0000030?ooo`9000004@3oool4@00002L0oooo0T00000A0?ooo`03@000003oool0oooo0;T0oooo
003o0?oool<0oooo003o0?oool<0oooo0000\
\>"],
  ImageRangeCache->{{{0, 449}, {149, 0}} -> {-0.184538, -0.0234427, 
  0.00750352, 0.00750352}, {{24.5625, 149.5}, {145.875, 
  20.875}} -> {-41.3325, -6.98281, 1.21028, 1.21028}, {{162, 286.938}, {
  145.875, 20.875}} -> {-207.671, -6.98281, 1.21028, 1.21028}, {{299.438, 
  424.375}, {145.875, 20.875}} -> {-374.009, -6.98281, 1.21028, 1.21028}}]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "Computation of the correlation coefficients between the images in Fig. \
9(a) and in Fig. 11 suggests that all of the sample images in Fig. 9 are the \
same ones. Finally, we remove the needless variables and check the used \
memories.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
Table[corRelation[Flatten[sampleWD[[1]]],recover3D[[i]]],{i,3}]\
\>", "Input",
  CellLabel->"In[87]:="],

Cell[BoxData[
    \({0.999997974328315031`, 0.99999797432830757`, 0.999997974328315031`}
      \)], "Output",
  CellLabel->"Out[87]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["memoryUsed", "Input",
  CellLabel->"In[88]:="],

Cell[BoxData[
    InterpretationBox[\(4028\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ 4028, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.4 Summary", "Section",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "In this chapter, we have discussed about the image eigen pattern not the \
eigen values. Derivation of the eigen patterns has been based on the \
nonlinear transformation employing a rectangular transform matrix. Depending \
on the image as well as resolution, even if the transform matrix is a \
rectangular, we have successfully recovered the images from their eigen \
patterns. The wavelet transform has extracted one of the eigen patterns. The \
wavelet spectrum of an image has extracted the characteristics of the image \
but not extracted the common characteristics of among the images. On the \
other side, the method described in this chapter has been able to extract the \
common characteristics among the images. We have defined the eigen pattern \
representing the common image characteristics. According to this definition, \
it has been demonstrated that any angled and low-resolution images have the \
same eigen pattern as long as the angled and low-resolution images visualize \
the same object. In the other words, when keeping the distinct eigen pattern \
of an image, we can identify the image from the others. This means that the \
image eigen pattern defined above may have an enormous applications for the \
image identification, cognition and visualization \n\tIn the first section of \
this chapter, we have described a key idea deriving an eigen pattern. In the \
second section, we have described to the practical ",
    TextAlignment->Left,
    TextJustification->1],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontSlant->"Italic"],
  StyleBox[
  " codes deriving the eigen pattern. Also, we have examined the nature of \
eigen pattern employing several one-dimensional image examples, which are the \
time domain sinusoidal waves. The third section has derived an eigen pattern \
of the monochrome images. This has verified the angle and resolution \
independencies of the image eigen pattern. In addition to this section, the \
fourth section has derived the eigen pattern of color images, and recovered \
the original images from their eigen patterns.",
    TextAlignment->Left,
    TextJustification->1]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["REFERENCES", "Section",
  FontFamily->"Century",
  FontSize->12]], "Subsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["[1] Stephen Wolfram, ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10],
  StyleBox["The Mathematica Book",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10,
    FontSlant->"Italic"],
  StyleBox[
  ", 3rd ed. (Wolfram Media/Cambridge University Press, 1996).\n[2] \
J.D.Jackson, \"Classical Electrodynamics 3",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10],
  StyleBox["rd",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" Edition,\" John Wiley & Sons, New York (1998).",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10]
}], "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 740}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{676, 633},
WindowMargins->{{2, Automatic}, {Automatic, 5}},
PrintingStartingPageNumber->78,
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          OptionValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True},
ShowCellLabel->False,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the Notebook level. \
 \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {2, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 4}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 8}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{10, 4}, {2, 50}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{47, 62}, {0, 14}},
    CellFrameMargins->5,
    CellFrameColor->RGBColor[0, 0.2, 1],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 62}, {0, 14}},
    CellFrameColor->GrayLevel[0.700008],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.    \
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{56, 4}, {3, 9}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {3, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{57, 4}, {5, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->StandardForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{56, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{40, 4}, {4, 2}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextTop"],
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{10, 4}, {2, 80}},
    CellHorizontalScrolling->True,
    CellFrameMargins->4,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextTop", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.39, 0.59}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.325}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.23,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.145, 0.345, 0.145, 0.345}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.195}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.23, 0.13, 0.13, 0.23, 0.13}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 271, 8, 50, "Title"],

Cell[CellGroupData[{
Cell[2027, 63, 138, 3, 84, "Section"],
Cell[2168, 68, 4095, 69, 541, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6300, 142, 186, 6, 85, "Section"],

Cell[CellGroupData[{
Cell[6511, 152, 304, 11, 37, "Subsection"],
Cell[6818, 165, 1468, 47, 59, "Text"],
Cell[8289, 214, 203, 6, 92, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8529, 225, 291, 11, 37, "Subsection"],
Cell[8823, 238, 762, 18, 59, "Text"],

Cell[CellGroupData[{
Cell[9610, 260, 111, 2, 35, "Subsubsection"],
Cell[9724, 264, 702, 20, 42, "Text"],
Cell[10429, 286, 463, 8, 190, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10929, 299, 115, 2, 29, "Subsubsection"],
Cell[11047, 303, 702, 20, 42, "Text"],
Cell[11752, 325, 458, 10, 170, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[12247, 340, 116, 2, 29, "Subsubsection"],
Cell[12366, 344, 556, 13, 59, "Text"],
Cell[12925, 359, 474, 14, 210, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[13436, 378, 116, 2, 29, "Subsubsection"],
Cell[13555, 382, 589, 13, 42, "Text"],
Cell[14147, 397, 248, 6, 92, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[14432, 408, 130, 2, 31, "Subsubsection"],
Cell[14565, 412, 258, 6, 42, "Text"],
Cell[14826, 420, 254, 5, 72, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[15117, 430, 118, 2, 31, "Subsubsection"],
Cell[15238, 434, 972, 20, 76, "Text"],
Cell[16213, 456, 451, 8, 170, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[16701, 469, 121, 2, 31, "Subsubsection"],
Cell[16825, 473, 543, 14, 42, "Text"],
Cell[17371, 489, 275, 8, 72, "Input",
  PageBreakWithin->Automatic]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17695, 503, 248, 9, 31, "Subsection"],

Cell[CellGroupData[{
Cell[17968, 516, 137, 3, 37, "Subsubsection"],
Cell[18108, 521, 214, 8, 25, "Text"],
Cell[18325, 531, 64, 1, 32, "Input"],
Cell[18392, 534, 645, 14, 59, "Text"],
Cell[19040, 550, 89, 2, 50, "Input"],
Cell[19132, 554, 548, 16, 50, "Text"],
Cell[19683, 572, 133, 6, 92, "Input"],
Cell[19819, 580, 235, 8, 25, "Text"],

Cell[CellGroupData[{
Cell[20079, 592, 55, 1, 32, "Input"],
Cell[20137, 595, 616, 15, 51, "Output"]
}, Open  ]],
Cell[20768, 613, 270, 6, 25, "Text"],

Cell[CellGroupData[{
Cell[21063, 623, 47, 1, 32, "Input"],
Cell[21113, 626, 74, 2, 24, "Output"]
}, Open  ]],
Cell[21202, 631, 1028, 24, 101, "Text"],

Cell[CellGroupData[{
Cell[22255, 659, 93, 2, 30, "Input"],
Cell[22351, 663, 274, 8, 51, "Output"]
}, Open  ]],
Cell[22640, 674, 491, 11, 59, "Text"],

Cell[CellGroupData[{
Cell[23156, 689, 128, 5, 48, "Input"],
Cell[23287, 696, 467, 14, 147, "Output"]
}, Open  ]],
Cell[23769, 713, 297, 8, 25, "Text"],

Cell[CellGroupData[{
Cell[24091, 725, 63, 2, 30, "Input"],
Cell[24157, 729, 104, 2, 24, "Output"]
}, Open  ]],
Cell[24276, 734, 861, 15, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25174, 754, 236, 8, 37, "Subsubsection"],
Cell[25413, 764, 819, 23, 50, "Text"],
Cell[26235, 789, 544, 10, 190, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26816, 804, 237, 8, 37, "Subsubsection"],
Cell[27056, 814, 538, 13, 42, "Text"],
Cell[27597, 829, 328, 6, 130, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27962, 840, 243, 8, 37, "Subsubsection"],
Cell[28208, 850, 776, 21, 59, "Text"],
Cell[28987, 873, 535, 11, 170, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29559, 889, 156, 3, 37, "Subsubsection"],
Cell[29718, 894, 625, 14, 59, "Text"],
Cell[30346, 910, 806, 17, 150, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[31213, 934, 84, 1, 84, "Section"],

Cell[CellGroupData[{
Cell[31322, 939, 118, 2, 37, "Subsection"],

Cell[CellGroupData[{
Cell[31465, 945, 141, 3, 37, "Subsubsection"],
Cell[31609, 950, 373, 12, 42, "Text"],
Cell[31985, 964, 291, 7, 112, "Input"],
Cell[32279, 973, 295, 10, 25, "Text"],
Cell[32577, 985, 371, 9, 120, "Input"],

Cell[CellGroupData[{
Cell[32973, 998, 119, 2, 30, "Input"],
Cell[33095, 1002, 148361, 6272, 258, 92376, 5576, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[181505, 7280, 142, 3, 37, "Subsubsection"],
Cell[181650, 7285, 191, 6, 25, "Text"],
Cell[181844, 7293, 127, 2, 30, "Input"],
Cell[181974, 7297, 229, 6, 25, "Text"],
Cell[182206, 7305, 122, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[182353, 7311, 401, 10, 138, "Input"],
Cell[182757, 7323, 86051, 2641, 258, 37428, 2036, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[268823, 9967, 524, 14, 59, "Text"],

Cell[CellGroupData[{
Cell[269372, 9985, 146, 6, 66, "Input"],
Cell[269521, 9993, 135, 3, 24, "Output"]
}, Open  ]],
Cell[269671, 9999, 346, 12, 25, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[270054, 10016, 145, 3, 37, "Subsubsection"],
Cell[270202, 10021, 905, 23, 101, "Text"],
Cell[271110, 10046, 112, 2, 30, "Input"],
Cell[271225, 10050, 343, 11, 42, "Text"],

Cell[CellGroupData[{
Cell[271593, 10065, 260, 7, 84, "Input"],
Cell[271856, 10074, 39785, 1598, 186, 22874, 1384, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[311656, 11675, 320, 10, 42, "Text"],

Cell[CellGroupData[{
Cell[312001, 11689, 95, 2, 30, "Input"],
Cell[312099, 11693, 81, 2, 24, "Output"]
}, Open  ]],
Cell[312195, 11698, 785, 24, 59, "Text"],

Cell[CellGroupData[{
Cell[313005, 11726, 213, 6, 66, "Input"],
Cell[313221, 11734, 153, 3, 28, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[313435, 11744, 132, 2, 37, "Subsection"],

Cell[CellGroupData[{
Cell[313592, 11750, 141, 3, 37, "Subsubsection"],
Cell[313736, 11755, 307, 10, 25, "Text"],
Cell[314046, 11767, 104, 2, 31, "Input"],
Cell[314153, 11771, 329, 10, 42, "Text"],

Cell[CellGroupData[{
Cell[314507, 11785, 259, 7, 88, "Input"],
Cell[314769, 11794, 175367, 2613, 296, 36081, 888, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[490151, 14410, 514, 14, 50, "Text"],
Cell[490668, 14426, 68, 1, 32, "Input"],
Cell[490739, 14429, 465, 12, 59, "Text"],
Cell[491207, 14443, 296, 7, 84, "Input"],
Cell[491506, 14452, 298, 7, 112, "Input"],

Cell[CellGroupData[{
Cell[491829, 14463, 236, 7, 84, "Input"],
Cell[492068, 14472, 304164, 5212, 408, 112137, 2837, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[796281, 19690, 142, 3, 37, "Subsubsection"],
Cell[796426, 19695, 660, 15, 76, "Text"],
Cell[797089, 19712, 195, 8, 102, "Input"],
Cell[797287, 19722, 262, 7, 84, "Input"],

Cell[CellGroupData[{
Cell[797574, 19733, 197, 5, 72, "Input"],
Cell[797774, 19740, 170099, 4148, 408, 94680, 3212, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[967888, 23891, 933, 22, 126, "Text"],

Cell[CellGroupData[{
Cell[968846, 23917, 97, 1, 32, "Input"],
Cell[968946, 23920, 134, 3, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[969117, 23928, 128, 4, 52, "Input"],
Cell[969248, 23934, 153, 3, 28, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[969450, 23943, 145, 3, 37, "Subsubsection"],
Cell[969598, 23948, 878, 17, 110, "Text"],
Cell[970479, 23967, 152, 4, 52, "Input"],
Cell[970634, 23973, 282, 8, 102, "Input"],

Cell[CellGroupData[{
Cell[970941, 23985, 145, 4, 52, "Input"],
Cell[971089, 23991, 198650, 3830, 158, 109853, 2730, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[1169754, 27824, 464, 12, 59, "Text"],

Cell[CellGroupData[{
Cell[1170243, 27840, 117, 3, 32, "Input"],
Cell[1170363, 27845, 134, 3, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1170534, 27853, 127, 4, 52, "Input"],
Cell[1170664, 27859, 153, 3, 28, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1170878, 27869, 127, 2, 37, "Subsection"],

Cell[CellGroupData[{
Cell[1171030, 27875, 141, 3, 37, "Subsubsection"],
Cell[1171174, 27880, 528, 17, 42, "Text"],

Cell[CellGroupData[{
Cell[1171727, 27901, 186, 5, 50, "Input"],
Cell[1171916, 27908, 242864, 3261, 296, 102902, 1528, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[1414795, 31172, 451, 12, 42, "Text"],
Cell[1415249, 31186, 358, 9, 120, "Input"],
Cell[1415610, 31197, 213, 6, 92, "Input"],

Cell[CellGroupData[{
Cell[1415848, 31207, 224, 6, 66, "Input"],
Cell[1416075, 31215, 504921, 7198, 408, 312757, 4821, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[1921011, 38416, 700, 21, 59, "Text"],

Cell[CellGroupData[{
Cell[1921736, 38441, 106, 4, 52, "Input"],
Cell[1921845, 38447, 153, 3, 28, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1922047, 38456, 142, 3, 37, "Subsubsection"],
Cell[1922192, 38461, 561, 13, 59, "Text"],
Cell[1922756, 38476, 147, 5, 48, "Input"],
Cell[1922906, 38483, 262, 7, 84, "Input"],

Cell[CellGroupData[{
Cell[1923193, 38494, 198, 5, 72, "Input"],
Cell[1923394, 38501, 145741, 3451, 408, 85992, 2709, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[2069150, 41955, 788, 20, 84, "Text"],

Cell[CellGroupData[{
Cell[2069963, 41979, 97, 1, 32, "Input"],
Cell[2070063, 41982, 135, 3, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2070235, 41990, 93, 4, 52, "Input"],
Cell[2070331, 41996, 153, 3, 28, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2070533, 42005, 145, 3, 37, "Subsubsection"],
Cell[2070681, 42010, 842, 17, 110, "Text"],
Cell[2071526, 42029, 148, 4, 52, "Input"],
Cell[2071677, 42035, 254, 8, 102, "Input"],
Cell[2071934, 42045, 240, 7, 84, "Input"],

Cell[CellGroupData[{
Cell[2072199, 42056, 146, 4, 52, "Input"],
Cell[2072348, 42062, 399037, 5749, 158, 310338, 4650, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[2471400, 47814, 422, 12, 42, "Text"],

Cell[CellGroupData[{
Cell[2471847, 47830, 113, 3, 32, "Input"],
Cell[2471963, 47835, 134, 3, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2472134, 47843, 52, 1, 32, "Input"],
Cell[2472189, 47846, 153, 3, 28, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2472415, 47857, 63, 1, 84, "Section"],
Cell[2472481, 47860, 2369, 43, 288, "Text"],

Cell[CellGroupData[{
Cell[2474875, 47907, 137, 3, 38, "Subsection"],
Cell[2475015, 47912, 918, 32, 54, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

